{
 "cells": [
  {
   "cell_type": "markdown",
   "id": "7dbb1cd1",
   "metadata": {},
   "source": [
    "# First two examples of Altair Charts\n",
    "We give two examples, one produced with random data from NumPy, and one using a Kaggle dataset about top 2020-2021 Spotify songs."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "id": "8b0a21b8",
   "metadata": {},
   "outputs": [],
   "source": [
    "import altair as alt\n",
    "import pandas as pd\n",
    "import numpy as np\n",
    "rng = np.random.default_rng()"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "02025ead",
   "metadata": {},
   "source": [
    "## Basic example with random data\n",
    "We first make a $20 \\times 4$ NumPy array of random integers in NumPy, and then convert it to a pandas DataFrame."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "id": "179f867d",
   "metadata": {},
   "outputs": [],
   "source": [
    "A = rng.integers(0,100,size = (20,4))\n",
    "rand_df = pd.DataFrame(A, columns = [\"a\",\"b\",\"c\",\"d\"])"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "id": "9a29a8ce",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>a</th>\n",
       "      <th>b</th>\n",
       "      <th>c</th>\n",
       "      <th>d</th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>72</td>\n",
       "      <td>41</td>\n",
       "      <td>17</td>\n",
       "      <td>31</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>28</td>\n",
       "      <td>73</td>\n",
       "      <td>48</td>\n",
       "      <td>16</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>2</td>\n",
       "      <td>72</td>\n",
       "      <td>45</td>\n",
       "      <td>26</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>20</td>\n",
       "      <td>54</td>\n",
       "      <td>97</td>\n",
       "      <td>58</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>4</th>\n",
       "      <td>23</td>\n",
       "      <td>85</td>\n",
       "      <td>23</td>\n",
       "      <td>41</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>5</th>\n",
       "      <td>33</td>\n",
       "      <td>64</td>\n",
       "      <td>86</td>\n",
       "      <td>37</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>6</th>\n",
       "      <td>3</td>\n",
       "      <td>30</td>\n",
       "      <td>38</td>\n",
       "      <td>83</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>7</th>\n",
       "      <td>45</td>\n",
       "      <td>37</td>\n",
       "      <td>56</td>\n",
       "      <td>31</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>8</th>\n",
       "      <td>59</td>\n",
       "      <td>66</td>\n",
       "      <td>53</td>\n",
       "      <td>74</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>9</th>\n",
       "      <td>79</td>\n",
       "      <td>48</td>\n",
       "      <td>51</td>\n",
       "      <td>69</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>10</th>\n",
       "      <td>3</td>\n",
       "      <td>52</td>\n",
       "      <td>35</td>\n",
       "      <td>95</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>11</th>\n",
       "      <td>35</td>\n",
       "      <td>40</td>\n",
       "      <td>47</td>\n",
       "      <td>21</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>12</th>\n",
       "      <td>49</td>\n",
       "      <td>59</td>\n",
       "      <td>60</td>\n",
       "      <td>86</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>13</th>\n",
       "      <td>7</td>\n",
       "      <td>75</td>\n",
       "      <td>51</td>\n",
       "      <td>90</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>14</th>\n",
       "      <td>31</td>\n",
       "      <td>12</td>\n",
       "      <td>38</td>\n",
       "      <td>60</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>15</th>\n",
       "      <td>35</td>\n",
       "      <td>23</td>\n",
       "      <td>60</td>\n",
       "      <td>5</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>16</th>\n",
       "      <td>29</td>\n",
       "      <td>99</td>\n",
       "      <td>52</td>\n",
       "      <td>37</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>17</th>\n",
       "      <td>33</td>\n",
       "      <td>29</td>\n",
       "      <td>73</td>\n",
       "      <td>44</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>18</th>\n",
       "      <td>19</td>\n",
       "      <td>99</td>\n",
       "      <td>40</td>\n",
       "      <td>13</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>19</th>\n",
       "      <td>18</td>\n",
       "      <td>43</td>\n",
       "      <td>28</td>\n",
       "      <td>20</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "</div>"
      ],
      "text/plain": [
       "     a   b   c   d\n",
       "0   72  41  17  31\n",
       "1   28  73  48  16\n",
       "2    2  72  45  26\n",
       "3   20  54  97  58\n",
       "4   23  85  23  41\n",
       "5   33  64  86  37\n",
       "6    3  30  38  83\n",
       "7   45  37  56  31\n",
       "8   59  66  53  74\n",
       "9   79  48  51  69\n",
       "10   3  52  35  95\n",
       "11  35  40  47  21\n",
       "12  49  59  60  86\n",
       "13   7  75  51  90\n",
       "14  31  12  38  60\n",
       "15  35  23  60   5\n",
       "16  29  99  52  37\n",
       "17  33  29  73  44\n",
       "18  19  99  40  13\n",
       "19  18  43  28  20"
      ]
     },
     "execution_count": 3,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "rand_df"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "417a48a2",
   "metadata": {},
   "source": [
    "Each row in the DataFrame will correspond to a point in our chart.  The values in the $a$ column and $b$ column correspond to the $x$-coordinate and the $y$-coordinate, respectively.\n",
    "\n",
    "Here we use `mark_line` to connect the datapoints with lines.\n",
    "\n",
    "The syntax for making an Altair chart can be intimidating.  The faster you can get comfortable with it, the better."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "id": "68fd80c1",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-c448c2ad4aa049beb36a63ca2af8b9e1\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-c448c2ad4aa049beb36a63ca2af8b9e1\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-c448c2ad4aa049beb36a63ca2af8b9e1\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-a3e6c641625115a26584f9c6df756149\"}, \"mark\": \"line\", \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"a\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"b\"}}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-a3e6c641625115a26584f9c6df756149\": [{\"a\": 72, \"b\": 41, \"c\": 17, \"d\": 31}, {\"a\": 28, \"b\": 73, \"c\": 48, \"d\": 16}, {\"a\": 2, \"b\": 72, \"c\": 45, \"d\": 26}, {\"a\": 20, \"b\": 54, \"c\": 97, \"d\": 58}, {\"a\": 23, \"b\": 85, \"c\": 23, \"d\": 41}, {\"a\": 33, \"b\": 64, \"c\": 86, \"d\": 37}, {\"a\": 3, \"b\": 30, \"c\": 38, \"d\": 83}, {\"a\": 45, \"b\": 37, \"c\": 56, \"d\": 31}, {\"a\": 59, \"b\": 66, \"c\": 53, \"d\": 74}, {\"a\": 79, \"b\": 48, \"c\": 51, \"d\": 69}, {\"a\": 3, \"b\": 52, \"c\": 35, \"d\": 95}, {\"a\": 35, \"b\": 40, \"c\": 47, \"d\": 21}, {\"a\": 49, \"b\": 59, \"c\": 60, \"d\": 86}, {\"a\": 7, \"b\": 75, \"c\": 51, \"d\": 90}, {\"a\": 31, \"b\": 12, \"c\": 38, \"d\": 60}, {\"a\": 35, \"b\": 23, \"c\": 60, \"d\": 5}, {\"a\": 29, \"b\": 99, \"c\": 52, \"d\": 37}, {\"a\": 33, \"b\": 29, \"c\": 73, \"d\": 44}, {\"a\": 19, \"b\": 99, \"c\": 40, \"d\": 13}, {\"a\": 18, \"b\": 43, \"c\": 28, \"d\": 20}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 4,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "alt.Chart(rand_df).mark_line().encode(\n",
    "    x = \"a\",\n",
    "    y = \"b\"\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "c30fb2d1",
   "metadata": {},
   "source": [
    "The same data, but with disks drawn instead of lines: we changed from `mark_line` to `mark_circle`."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "id": "8abd6eef",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-6b27acea30264911ae7de36058e1413a\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-6b27acea30264911ae7de36058e1413a\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-6b27acea30264911ae7de36058e1413a\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-a3e6c641625115a26584f9c6df756149\"}, \"mark\": \"circle\", \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"a\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"b\"}}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-a3e6c641625115a26584f9c6df756149\": [{\"a\": 72, \"b\": 41, \"c\": 17, \"d\": 31}, {\"a\": 28, \"b\": 73, \"c\": 48, \"d\": 16}, {\"a\": 2, \"b\": 72, \"c\": 45, \"d\": 26}, {\"a\": 20, \"b\": 54, \"c\": 97, \"d\": 58}, {\"a\": 23, \"b\": 85, \"c\": 23, \"d\": 41}, {\"a\": 33, \"b\": 64, \"c\": 86, \"d\": 37}, {\"a\": 3, \"b\": 30, \"c\": 38, \"d\": 83}, {\"a\": 45, \"b\": 37, \"c\": 56, \"d\": 31}, {\"a\": 59, \"b\": 66, \"c\": 53, \"d\": 74}, {\"a\": 79, \"b\": 48, \"c\": 51, \"d\": 69}, {\"a\": 3, \"b\": 52, \"c\": 35, \"d\": 95}, {\"a\": 35, \"b\": 40, \"c\": 47, \"d\": 21}, {\"a\": 49, \"b\": 59, \"c\": 60, \"d\": 86}, {\"a\": 7, \"b\": 75, \"c\": 51, \"d\": 90}, {\"a\": 31, \"b\": 12, \"c\": 38, \"d\": 60}, {\"a\": 35, \"b\": 23, \"c\": 60, \"d\": 5}, {\"a\": 29, \"b\": 99, \"c\": 52, \"d\": 37}, {\"a\": 33, \"b\": 29, \"c\": 73, \"d\": 44}, {\"a\": 19, \"b\": 99, \"c\": 40, \"d\": 13}, {\"a\": 18, \"b\": 43, \"c\": 28, \"d\": 20}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 5,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "alt.Chart(rand_df).mark_circle().encode(\n",
    "    x = \"a\",\n",
    "    y = \"b\"\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "39671f49",
   "metadata": {},
   "source": [
    "By looking at the chart, how many points have an `a` value less than 30?  Let's verify that in the dataset."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "id": "f70f4024",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "10"
      ]
     },
     "execution_count": 6,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "(rand_df[\"a\"] < 30).sum()"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "e7e0d9bc",
   "metadata": {},
   "source": [
    "Here are those points explicitly."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "id": "b9993983",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>a</th>\n",
       "      <th>b</th>\n",
       "      <th>c</th>\n",
       "      <th>d</th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>28</td>\n",
       "      <td>73</td>\n",
       "      <td>48</td>\n",
       "      <td>16</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>2</td>\n",
       "      <td>72</td>\n",
       "      <td>45</td>\n",
       "      <td>26</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>20</td>\n",
       "      <td>54</td>\n",
       "      <td>97</td>\n",
       "      <td>58</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>4</th>\n",
       "      <td>23</td>\n",
       "      <td>85</td>\n",
       "      <td>23</td>\n",
       "      <td>41</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>6</th>\n",
       "      <td>3</td>\n",
       "      <td>30</td>\n",
       "      <td>38</td>\n",
       "      <td>83</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>10</th>\n",
       "      <td>3</td>\n",
       "      <td>52</td>\n",
       "      <td>35</td>\n",
       "      <td>95</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>13</th>\n",
       "      <td>7</td>\n",
       "      <td>75</td>\n",
       "      <td>51</td>\n",
       "      <td>90</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>16</th>\n",
       "      <td>29</td>\n",
       "      <td>99</td>\n",
       "      <td>52</td>\n",
       "      <td>37</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>18</th>\n",
       "      <td>19</td>\n",
       "      <td>99</td>\n",
       "      <td>40</td>\n",
       "      <td>13</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>19</th>\n",
       "      <td>18</td>\n",
       "      <td>43</td>\n",
       "      <td>28</td>\n",
       "      <td>20</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "</div>"
      ],
      "text/plain": [
       "     a   b   c   d\n",
       "1   28  73  48  16\n",
       "2    2  72  45  26\n",
       "3   20  54  97  58\n",
       "4   23  85  23  41\n",
       "6    3  30  38  83\n",
       "10   3  52  35  95\n",
       "13   7  75  51  90\n",
       "16  29  99  52  37\n",
       "18  19  99  40  13\n",
       "19  18  43  28  20"
      ]
     },
     "execution_count": 7,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "rand_df[rand_df[\"a\"] < 30]"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "41aec9d1",
   "metadata": {},
   "source": [
    "Here is another chart, where we color the points using column `c`, and we change the size of the points using column `d`.  We add a tooltip showing all the values, so put your mouse over a point to see its values of a,b,c,d."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "id": "ea9ec9ce",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-85d6234f875243459fccd99f93adf044\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-85d6234f875243459fccd99f93adf044\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-85d6234f875243459fccd99f93adf044\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-a3e6c641625115a26584f9c6df756149\"}, \"mark\": \"circle\", \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"c\"}, \"size\": {\"type\": \"quantitative\", \"field\": \"d\"}, \"tooltip\": [{\"type\": \"quantitative\", \"field\": \"a\"}, {\"type\": \"quantitative\", \"field\": \"b\"}, {\"type\": \"quantitative\", \"field\": \"c\"}, {\"type\": \"quantitative\", \"field\": \"d\"}], \"x\": {\"type\": \"quantitative\", \"field\": \"a\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"b\"}}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-a3e6c641625115a26584f9c6df756149\": [{\"a\": 72, \"b\": 41, \"c\": 17, \"d\": 31}, {\"a\": 28, \"b\": 73, \"c\": 48, \"d\": 16}, {\"a\": 2, \"b\": 72, \"c\": 45, \"d\": 26}, {\"a\": 20, \"b\": 54, \"c\": 97, \"d\": 58}, {\"a\": 23, \"b\": 85, \"c\": 23, \"d\": 41}, {\"a\": 33, \"b\": 64, \"c\": 86, \"d\": 37}, {\"a\": 3, \"b\": 30, \"c\": 38, \"d\": 83}, {\"a\": 45, \"b\": 37, \"c\": 56, \"d\": 31}, {\"a\": 59, \"b\": 66, \"c\": 53, \"d\": 74}, {\"a\": 79, \"b\": 48, \"c\": 51, \"d\": 69}, {\"a\": 3, \"b\": 52, \"c\": 35, \"d\": 95}, {\"a\": 35, \"b\": 40, \"c\": 47, \"d\": 21}, {\"a\": 49, \"b\": 59, \"c\": 60, \"d\": 86}, {\"a\": 7, \"b\": 75, \"c\": 51, \"d\": 90}, {\"a\": 31, \"b\": 12, \"c\": 38, \"d\": 60}, {\"a\": 35, \"b\": 23, \"c\": 60, \"d\": 5}, {\"a\": 29, \"b\": 99, \"c\": 52, \"d\": 37}, {\"a\": 33, \"b\": 29, \"c\": 73, \"d\": 44}, {\"a\": 19, \"b\": 99, \"c\": 40, \"d\": 13}, {\"a\": 18, \"b\": 43, \"c\": 28, \"d\": 20}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 8,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "alt.Chart(rand_df).mark_circle().encode(\n",
    "    x = \"a\",\n",
    "    y = \"b\",\n",
    "    color = \"c\",\n",
    "    size = \"d\",\n",
    "    tooltip = [\"a\",\"b\",\"c\",\"d\"],\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "bba4d714",
   "metadata": {},
   "source": [
    "```{admonition} Exercise\n",
    ":class: tip\n",
    "Put your mouse over one of the points in the above chart.\n",
    "* How is the underlying data for that point reflected in its location, size, and color?  \n",
    "* Can you find the row in `rand_df` corresponding to this point?\n",
    "* Choose another row in the DataFrame.  What point does it correspond to in the chart?\n",
    "\n",
    "For your convenience, the original pandas DataFrame is shown below.\n",
    "```"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 9,
   "id": "4ffb7934",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>a</th>\n",
       "      <th>b</th>\n",
       "      <th>c</th>\n",
       "      <th>d</th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>72</td>\n",
       "      <td>41</td>\n",
       "      <td>17</td>\n",
       "      <td>31</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>28</td>\n",
       "      <td>73</td>\n",
       "      <td>48</td>\n",
       "      <td>16</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>2</td>\n",
       "      <td>72</td>\n",
       "      <td>45</td>\n",
       "      <td>26</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>20</td>\n",
       "      <td>54</td>\n",
       "      <td>97</td>\n",
       "      <td>58</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>4</th>\n",
       "      <td>23</td>\n",
       "      <td>85</td>\n",
       "      <td>23</td>\n",
       "      <td>41</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>5</th>\n",
       "      <td>33</td>\n",
       "      <td>64</td>\n",
       "      <td>86</td>\n",
       "      <td>37</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>6</th>\n",
       "      <td>3</td>\n",
       "      <td>30</td>\n",
       "      <td>38</td>\n",
       "      <td>83</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>7</th>\n",
       "      <td>45</td>\n",
       "      <td>37</td>\n",
       "      <td>56</td>\n",
       "      <td>31</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>8</th>\n",
       "      <td>59</td>\n",
       "      <td>66</td>\n",
       "      <td>53</td>\n",
       "      <td>74</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>9</th>\n",
       "      <td>79</td>\n",
       "      <td>48</td>\n",
       "      <td>51</td>\n",
       "      <td>69</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>10</th>\n",
       "      <td>3</td>\n",
       "      <td>52</td>\n",
       "      <td>35</td>\n",
       "      <td>95</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>11</th>\n",
       "      <td>35</td>\n",
       "      <td>40</td>\n",
       "      <td>47</td>\n",
       "      <td>21</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>12</th>\n",
       "      <td>49</td>\n",
       "      <td>59</td>\n",
       "      <td>60</td>\n",
       "      <td>86</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>13</th>\n",
       "      <td>7</td>\n",
       "      <td>75</td>\n",
       "      <td>51</td>\n",
       "      <td>90</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>14</th>\n",
       "      <td>31</td>\n",
       "      <td>12</td>\n",
       "      <td>38</td>\n",
       "      <td>60</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>15</th>\n",
       "      <td>35</td>\n",
       "      <td>23</td>\n",
       "      <td>60</td>\n",
       "      <td>5</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>16</th>\n",
       "      <td>29</td>\n",
       "      <td>99</td>\n",
       "      <td>52</td>\n",
       "      <td>37</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>17</th>\n",
       "      <td>33</td>\n",
       "      <td>29</td>\n",
       "      <td>73</td>\n",
       "      <td>44</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>18</th>\n",
       "      <td>19</td>\n",
       "      <td>99</td>\n",
       "      <td>40</td>\n",
       "      <td>13</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>19</th>\n",
       "      <td>18</td>\n",
       "      <td>43</td>\n",
       "      <td>28</td>\n",
       "      <td>20</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "</div>"
      ],
      "text/plain": [
       "     a   b   c   d\n",
       "0   72  41  17  31\n",
       "1   28  73  48  16\n",
       "2    2  72  45  26\n",
       "3   20  54  97  58\n",
       "4   23  85  23  41\n",
       "5   33  64  86  37\n",
       "6    3  30  38  83\n",
       "7   45  37  56  31\n",
       "8   59  66  53  74\n",
       "9   79  48  51  69\n",
       "10   3  52  35  95\n",
       "11  35  40  47  21\n",
       "12  49  59  60  86\n",
       "13   7  75  51  90\n",
       "14  31  12  38  60\n",
       "15  35  23  60   5\n",
       "16  29  99  52  37\n",
       "17  33  29  73  44\n",
       "18  19  99  40  13\n",
       "19  18  43  28  20"
      ]
     },
     "execution_count": 9,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "rand_df"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "deadb46b",
   "metadata": {},
   "source": [
    "Another example with more points, and where we add an *opacity* channel."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "id": "d9d06365",
   "metadata": {},
   "outputs": [],
   "source": [
    "A = rng.integers(0,100,size = (1000,5))\n",
    "rand_df2 = pd.DataFrame(A, columns = [\"a\",\"b\",\"c\",\"d\",\"e\"])"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 11,
   "id": "4c3eb8f3",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-24225633e627407eb898be62be01686e\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-24225633e627407eb898be62be01686e\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-24225633e627407eb898be62be01686e\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-90ebed9561316a43e29129bb24d18442\"}, \"mark\": \"circle\", \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"c\"}, \"opacity\": {\"type\": \"quantitative\", \"field\": \"e\"}, \"size\": {\"type\": \"quantitative\", \"field\": \"d\"}, \"tooltip\": [{\"type\": \"quantitative\", \"field\": \"a\"}, {\"type\": \"quantitative\", \"field\": \"b\"}, {\"type\": \"quantitative\", \"field\": \"c\"}, {\"type\": \"quantitative\", \"field\": \"d\"}, {\"type\": \"quantitative\", \"field\": \"e\"}], \"x\": {\"type\": \"quantitative\", \"field\": \"a\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"b\"}}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-90ebed9561316a43e29129bb24d18442\": [{\"a\": 72, \"b\": 34, \"c\": 3, \"d\": 39, \"e\": 61}, {\"a\": 47, \"b\": 85, \"c\": 85, \"d\": 82, \"e\": 28}, {\"a\": 79, \"b\": 40, \"c\": 81, \"d\": 2, \"e\": 82}, {\"a\": 89, \"b\": 93, \"c\": 41, \"d\": 19, \"e\": 38}, {\"a\": 61, \"b\": 15, \"c\": 54, \"d\": 21, \"e\": 48}, {\"a\": 45, \"b\": 62, \"c\": 12, \"d\": 41, \"e\": 4}, {\"a\": 40, \"b\": 55, \"c\": 17, \"d\": 0, \"e\": 17}, {\"a\": 39, \"b\": 93, \"c\": 28, \"d\": 61, \"e\": 9}, {\"a\": 98, \"b\": 55, \"c\": 72, \"d\": 88, \"e\": 94}, {\"a\": 75, \"b\": 86, \"c\": 39, \"d\": 85, \"e\": 99}, {\"a\": 8, \"b\": 8, \"c\": 77, \"d\": 99, \"e\": 62}, {\"a\": 40, \"b\": 90, \"c\": 28, \"d\": 57, \"e\": 99}, {\"a\": 64, \"b\": 20, \"c\": 85, \"d\": 54, \"e\": 30}, {\"a\": 17, \"b\": 55, \"c\": 63, \"d\": 61, \"e\": 18}, {\"a\": 83, \"b\": 2, \"c\": 45, \"d\": 84, \"e\": 94}, {\"a\": 46, \"b\": 67, \"c\": 67, \"d\": 70, \"e\": 78}, {\"a\": 29, \"b\": 35, \"c\": 89, \"d\": 44, \"e\": 34}, {\"a\": 67, \"b\": 21, \"c\": 88, \"d\": 64, \"e\": 71}, {\"a\": 71, \"b\": 13, \"c\": 94, \"d\": 33, \"e\": 53}, {\"a\": 19, \"b\": 38, \"c\": 15, \"d\": 13, \"e\": 20}, {\"a\": 73, \"b\": 8, \"c\": 97, \"d\": 23, \"e\": 84}, {\"a\": 14, \"b\": 77, \"c\": 41, \"d\": 99, \"e\": 37}, {\"a\": 9, \"b\": 22, \"c\": 64, \"d\": 96, \"e\": 88}, {\"a\": 94, \"b\": 15, \"c\": 24, \"d\": 72, \"e\": 39}, {\"a\": 90, \"b\": 99, \"c\": 59, \"d\": 39, \"e\": 49}, {\"a\": 99, \"b\": 55, \"c\": 2, \"d\": 38, \"e\": 90}, {\"a\": 57, \"b\": 95, \"c\": 64, \"d\": 62, \"e\": 83}, {\"a\": 67, \"b\": 97, \"c\": 42, \"d\": 12, \"e\": 77}, {\"a\": 33, \"b\": 76, \"c\": 61, \"d\": 67, \"e\": 99}, {\"a\": 37, \"b\": 47, \"c\": 27, \"d\": 31, \"e\": 14}, {\"a\": 91, \"b\": 62, \"c\": 35, \"d\": 97, \"e\": 9}, {\"a\": 77, \"b\": 21, \"c\": 28, \"d\": 45, \"e\": 81}, {\"a\": 57, \"b\": 87, \"c\": 20, \"d\": 51, \"e\": 16}, {\"a\": 52, \"b\": 42, \"c\": 78, \"d\": 85, \"e\": 43}, {\"a\": 94, \"b\": 35, \"c\": 86, \"d\": 55, \"e\": 6}, {\"a\": 26, \"b\": 58, \"c\": 38, \"d\": 14, \"e\": 80}, {\"a\": 17, \"b\": 36, \"c\": 49, \"d\": 33, \"e\": 20}, {\"a\": 48, \"b\": 41, \"c\": 53, \"d\": 54, \"e\": 79}, {\"a\": 16, \"b\": 34, \"c\": 46, \"d\": 30, \"e\": 92}, {\"a\": 10, \"b\": 18, \"c\": 38, \"d\": 89, \"e\": 63}, {\"a\": 37, \"b\": 96, \"c\": 75, \"d\": 22, \"e\": 43}, {\"a\": 56, \"b\": 81, \"c\": 13, \"d\": 91, \"e\": 16}, {\"a\": 71, \"b\": 46, \"c\": 78, \"d\": 83, \"e\": 28}, {\"a\": 73, \"b\": 75, \"c\": 19, \"d\": 85, \"e\": 80}, {\"a\": 27, \"b\": 18, \"c\": 71, \"d\": 22, \"e\": 13}, {\"a\": 53, \"b\": 6, \"c\": 8, \"d\": 38, \"e\": 53}, {\"a\": 59, \"b\": 69, \"c\": 74, \"d\": 31, \"e\": 93}, {\"a\": 65, \"b\": 77, \"c\": 73, \"d\": 67, \"e\": 67}, {\"a\": 9, \"b\": 71, \"c\": 57, \"d\": 61, \"e\": 42}, {\"a\": 74, \"b\": 37, \"c\": 78, \"d\": 84, \"e\": 0}, {\"a\": 64, \"b\": 42, \"c\": 61, \"d\": 6, \"e\": 8}, {\"a\": 3, \"b\": 8, \"c\": 85, \"d\": 68, \"e\": 26}, {\"a\": 96, \"b\": 65, \"c\": 49, \"d\": 65, \"e\": 16}, {\"a\": 75, \"b\": 33, \"c\": 96, \"d\": 3, \"e\": 34}, {\"a\": 59, \"b\": 98, \"c\": 96, \"d\": 40, \"e\": 56}, {\"a\": 14, \"b\": 72, \"c\": 28, \"d\": 25, \"e\": 24}, {\"a\": 76, \"b\": 71, \"c\": 88, \"d\": 34, \"e\": 41}, {\"a\": 51, \"b\": 9, \"c\": 43, \"d\": 55, \"e\": 62}, {\"a\": 68, \"b\": 83, \"c\": 80, \"d\": 67, \"e\": 45}, {\"a\": 57, \"b\": 70, \"c\": 59, \"d\": 31, \"e\": 9}, {\"a\": 70, \"b\": 31, \"c\": 49, \"d\": 0, \"e\": 50}, {\"a\": 39, \"b\": 45, \"c\": 51, \"d\": 45, \"e\": 68}, {\"a\": 54, \"b\": 71, \"c\": 95, \"d\": 45, \"e\": 19}, {\"a\": 94, \"b\": 95, \"c\": 13, \"d\": 66, \"e\": 75}, {\"a\": 96, \"b\": 8, \"c\": 2, \"d\": 74, \"e\": 8}, {\"a\": 7, \"b\": 36, \"c\": 72, \"d\": 71, \"e\": 74}, {\"a\": 20, \"b\": 76, \"c\": 52, \"d\": 5, \"e\": 11}, {\"a\": 17, \"b\": 38, \"c\": 13, \"d\": 57, \"e\": 63}, {\"a\": 29, \"b\": 17, \"c\": 48, \"d\": 88, \"e\": 69}, {\"a\": 26, \"b\": 73, \"c\": 46, \"d\": 23, \"e\": 11}, {\"a\": 53, \"b\": 14, \"c\": 81, \"d\": 14, \"e\": 15}, {\"a\": 25, \"b\": 80, \"c\": 97, \"d\": 81, \"e\": 66}, {\"a\": 44, \"b\": 30, \"c\": 74, \"d\": 46, \"e\": 4}, {\"a\": 1, \"b\": 87, \"c\": 27, \"d\": 47, \"e\": 16}, {\"a\": 27, \"b\": 90, \"c\": 5, \"d\": 11, \"e\": 51}, {\"a\": 98, \"b\": 52, \"c\": 52, \"d\": 5, \"e\": 39}, {\"a\": 94, \"b\": 49, \"c\": 32, \"d\": 54, \"e\": 0}, {\"a\": 76, \"b\": 21, \"c\": 14, \"d\": 87, \"e\": 95}, {\"a\": 33, \"b\": 8, \"c\": 22, \"d\": 95, \"e\": 65}, {\"a\": 57, \"b\": 91, \"c\": 34, \"d\": 63, \"e\": 78}, {\"a\": 96, \"b\": 26, \"c\": 5, \"d\": 99, \"e\": 55}, {\"a\": 8, \"b\": 87, \"c\": 77, \"d\": 59, \"e\": 90}, {\"a\": 93, \"b\": 56, \"c\": 48, \"d\": 80, \"e\": 51}, {\"a\": 11, \"b\": 32, \"c\": 47, \"d\": 6, \"e\": 18}, {\"a\": 36, \"b\": 57, \"c\": 69, \"d\": 4, \"e\": 41}, {\"a\": 86, \"b\": 78, \"c\": 20, \"d\": 21, \"e\": 21}, {\"a\": 87, \"b\": 81, \"c\": 65, \"d\": 80, \"e\": 2}, {\"a\": 10, \"b\": 23, \"c\": 52, \"d\": 16, \"e\": 86}, {\"a\": 20, \"b\": 38, \"c\": 25, \"d\": 81, \"e\": 39}, {\"a\": 80, \"b\": 91, \"c\": 91, \"d\": 12, \"e\": 58}, {\"a\": 28, \"b\": 9, \"c\": 75, \"d\": 42, \"e\": 57}, {\"a\": 72, \"b\": 43, \"c\": 74, \"d\": 72, \"e\": 12}, {\"a\": 29, \"b\": 42, \"c\": 12, \"d\": 24, \"e\": 46}, {\"a\": 65, \"b\": 96, \"c\": 2, \"d\": 59, \"e\": 0}, {\"a\": 24, \"b\": 55, \"c\": 72, \"d\": 7, \"e\": 49}, {\"a\": 58, \"b\": 11, \"c\": 19, \"d\": 87, \"e\": 90}, {\"a\": 62, \"b\": 59, \"c\": 54, \"d\": 23, \"e\": 8}, {\"a\": 21, \"b\": 43, \"c\": 92, \"d\": 18, \"e\": 95}, {\"a\": 48, \"b\": 62, \"c\": 44, \"d\": 90, \"e\": 9}, {\"a\": 40, \"b\": 14, \"c\": 0, \"d\": 65, \"e\": 5}, {\"a\": 57, \"b\": 57, \"c\": 46, \"d\": 40, \"e\": 10}, {\"a\": 88, \"b\": 51, \"c\": 26, \"d\": 69, \"e\": 26}, {\"a\": 94, \"b\": 22, \"c\": 98, \"d\": 31, \"e\": 37}, {\"a\": 32, \"b\": 57, \"c\": 40, \"d\": 74, \"e\": 49}, {\"a\": 55, \"b\": 18, \"c\": 44, \"d\": 1, \"e\": 42}, {\"a\": 28, \"b\": 73, \"c\": 43, \"d\": 28, \"e\": 10}, {\"a\": 87, \"b\": 61, \"c\": 44, \"d\": 90, \"e\": 11}, {\"a\": 30, \"b\": 50, \"c\": 46, \"d\": 7, \"e\": 89}, {\"a\": 4, \"b\": 96, \"c\": 5, \"d\": 50, \"e\": 87}, {\"a\": 73, \"b\": 45, \"c\": 92, \"d\": 18, \"e\": 57}, {\"a\": 30, \"b\": 50, \"c\": 10, \"d\": 96, \"e\": 37}, {\"a\": 33, \"b\": 87, \"c\": 97, \"d\": 9, \"e\": 18}, {\"a\": 59, \"b\": 6, \"c\": 42, \"d\": 58, \"e\": 9}, {\"a\": 44, \"b\": 49, \"c\": 20, \"d\": 85, \"e\": 2}, {\"a\": 8, \"b\": 93, \"c\": 52, \"d\": 31, \"e\": 53}, {\"a\": 88, \"b\": 46, \"c\": 70, \"d\": 52, \"e\": 69}, {\"a\": 64, \"b\": 64, \"c\": 23, \"d\": 57, \"e\": 13}, {\"a\": 44, \"b\": 52, \"c\": 22, \"d\": 66, \"e\": 98}, {\"a\": 36, \"b\": 18, \"c\": 1, \"d\": 6, \"e\": 21}, {\"a\": 33, \"b\": 11, \"c\": 54, \"d\": 88, \"e\": 79}, {\"a\": 62, \"b\": 68, \"c\": 78, \"d\": 76, \"e\": 82}, {\"a\": 27, \"b\": 31, \"c\": 66, \"d\": 57, \"e\": 4}, {\"a\": 97, \"b\": 15, \"c\": 61, \"d\": 35, \"e\": 99}, {\"a\": 66, \"b\": 33, \"c\": 95, \"d\": 4, \"e\": 69}, {\"a\": 40, \"b\": 37, \"c\": 43, \"d\": 58, \"e\": 70}, {\"a\": 6, \"b\": 47, \"c\": 96, \"d\": 87, \"e\": 48}, {\"a\": 26, \"b\": 42, \"c\": 57, \"d\": 25, \"e\": 83}, {\"a\": 81, \"b\": 17, \"c\": 82, \"d\": 1, \"e\": 57}, {\"a\": 95, \"b\": 97, \"c\": 22, \"d\": 30, \"e\": 34}, {\"a\": 32, \"b\": 58, \"c\": 25, \"d\": 86, \"e\": 80}, {\"a\": 16, \"b\": 59, \"c\": 3, \"d\": 67, \"e\": 90}, {\"a\": 75, \"b\": 56, \"c\": 96, \"d\": 93, \"e\": 59}, {\"a\": 19, \"b\": 19, \"c\": 40, \"d\": 34, \"e\": 75}, {\"a\": 3, \"b\": 3, \"c\": 99, \"d\": 79, \"e\": 48}, {\"a\": 53, \"b\": 6, \"c\": 93, \"d\": 83, \"e\": 46}, {\"a\": 74, \"b\": 23, \"c\": 34, \"d\": 70, \"e\": 40}, {\"a\": 11, \"b\": 52, \"c\": 90, \"d\": 17, \"e\": 55}, {\"a\": 98, \"b\": 53, \"c\": 44, \"d\": 53, \"e\": 51}, {\"a\": 56, \"b\": 59, \"c\": 34, \"d\": 41, \"e\": 4}, {\"a\": 90, \"b\": 15, \"c\": 76, \"d\": 84, \"e\": 42}, {\"a\": 54, \"b\": 83, \"c\": 4, \"d\": 23, \"e\": 7}, {\"a\": 48, \"b\": 89, \"c\": 87, \"d\": 80, \"e\": 3}, {\"a\": 61, \"b\": 52, \"c\": 35, \"d\": 37, \"e\": 6}, {\"a\": 48, \"b\": 14, \"c\": 83, \"d\": 5, \"e\": 22}, {\"a\": 39, \"b\": 78, \"c\": 85, \"d\": 70, \"e\": 6}, {\"a\": 47, \"b\": 48, \"c\": 72, \"d\": 57, \"e\": 90}, {\"a\": 62, \"b\": 49, \"c\": 85, \"d\": 68, \"e\": 28}, {\"a\": 7, \"b\": 40, \"c\": 98, \"d\": 9, \"e\": 79}, {\"a\": 44, \"b\": 49, \"c\": 82, \"d\": 36, \"e\": 83}, {\"a\": 21, \"b\": 68, \"c\": 76, \"d\": 11, \"e\": 8}, {\"a\": 31, \"b\": 53, \"c\": 0, \"d\": 46, \"e\": 54}, {\"a\": 51, \"b\": 3, \"c\": 53, \"d\": 12, \"e\": 54}, {\"a\": 30, \"b\": 30, \"c\": 88, \"d\": 88, \"e\": 77}, {\"a\": 18, \"b\": 42, \"c\": 39, \"d\": 0, \"e\": 69}, {\"a\": 78, \"b\": 1, \"c\": 9, \"d\": 51, \"e\": 92}, {\"a\": 64, \"b\": 20, \"c\": 52, \"d\": 25, \"e\": 71}, {\"a\": 76, \"b\": 52, \"c\": 92, \"d\": 26, \"e\": 70}, {\"a\": 50, \"b\": 52, \"c\": 96, \"d\": 89, \"e\": 60}, {\"a\": 33, \"b\": 41, \"c\": 42, \"d\": 63, \"e\": 92}, {\"a\": 22, \"b\": 91, \"c\": 12, \"d\": 53, \"e\": 71}, {\"a\": 38, \"b\": 88, \"c\": 82, \"d\": 90, \"e\": 0}, {\"a\": 66, \"b\": 30, \"c\": 38, \"d\": 31, \"e\": 29}, {\"a\": 39, \"b\": 27, \"c\": 17, \"d\": 36, \"e\": 28}, {\"a\": 12, \"b\": 63, \"c\": 14, \"d\": 37, \"e\": 72}, {\"a\": 53, \"b\": 84, \"c\": 58, \"d\": 95, \"e\": 18}, {\"a\": 42, \"b\": 21, \"c\": 42, \"d\": 66, \"e\": 47}, {\"a\": 14, \"b\": 13, \"c\": 0, \"d\": 17, \"e\": 14}, {\"a\": 16, \"b\": 28, \"c\": 0, \"d\": 62, \"e\": 88}, {\"a\": 1, \"b\": 13, \"c\": 66, \"d\": 91, \"e\": 15}, {\"a\": 55, \"b\": 26, \"c\": 1, \"d\": 65, \"e\": 24}, {\"a\": 38, \"b\": 31, \"c\": 81, \"d\": 79, \"e\": 84}, {\"a\": 0, \"b\": 28, \"c\": 29, \"d\": 16, \"e\": 39}, {\"a\": 47, \"b\": 21, \"c\": 13, \"d\": 8, \"e\": 8}, {\"a\": 42, \"b\": 93, \"c\": 82, \"d\": 65, \"e\": 26}, {\"a\": 70, \"b\": 29, \"c\": 72, \"d\": 35, \"e\": 97}, {\"a\": 0, \"b\": 99, \"c\": 3, \"d\": 14, \"e\": 77}, {\"a\": 50, \"b\": 66, \"c\": 88, \"d\": 15, \"e\": 64}, {\"a\": 65, \"b\": 74, \"c\": 26, \"d\": 82, \"e\": 24}, {\"a\": 91, \"b\": 46, \"c\": 61, \"d\": 38, \"e\": 80}, {\"a\": 27, \"b\": 77, \"c\": 80, \"d\": 55, \"e\": 63}, {\"a\": 0, \"b\": 88, \"c\": 95, \"d\": 67, \"e\": 12}, {\"a\": 76, \"b\": 66, \"c\": 70, \"d\": 14, \"e\": 14}, {\"a\": 43, \"b\": 90, \"c\": 30, \"d\": 37, \"e\": 16}, {\"a\": 0, \"b\": 18, \"c\": 94, \"d\": 26, \"e\": 64}, {\"a\": 97, \"b\": 12, \"c\": 68, \"d\": 18, \"e\": 12}, {\"a\": 28, \"b\": 54, \"c\": 76, \"d\": 8, \"e\": 19}, {\"a\": 38, \"b\": 51, \"c\": 81, \"d\": 35, \"e\": 39}, {\"a\": 69, \"b\": 56, \"c\": 40, \"d\": 17, \"e\": 42}, {\"a\": 78, \"b\": 44, \"c\": 86, \"d\": 22, \"e\": 72}, {\"a\": 5, \"b\": 16, \"c\": 21, \"d\": 23, \"e\": 78}, {\"a\": 74, \"b\": 25, \"c\": 36, \"d\": 48, \"e\": 8}, {\"a\": 98, \"b\": 99, \"c\": 9, \"d\": 52, \"e\": 76}, {\"a\": 5, \"b\": 74, \"c\": 18, \"d\": 99, \"e\": 97}, {\"a\": 37, \"b\": 13, \"c\": 61, \"d\": 93, \"e\": 80}, {\"a\": 81, \"b\": 28, \"c\": 7, \"d\": 1, \"e\": 35}, {\"a\": 70, \"b\": 65, \"c\": 22, \"d\": 16, \"e\": 15}, {\"a\": 88, \"b\": 77, \"c\": 82, \"d\": 93, \"e\": 87}, {\"a\": 50, \"b\": 94, \"c\": 91, \"d\": 64, \"e\": 93}, {\"a\": 21, \"b\": 35, \"c\": 87, \"d\": 55, \"e\": 66}, {\"a\": 45, \"b\": 11, \"c\": 69, \"d\": 18, \"e\": 37}, {\"a\": 27, \"b\": 93, \"c\": 47, \"d\": 22, \"e\": 62}, {\"a\": 74, \"b\": 13, \"c\": 59, \"d\": 39, \"e\": 33}, {\"a\": 68, \"b\": 62, \"c\": 95, \"d\": 47, \"e\": 92}, {\"a\": 72, \"b\": 10, \"c\": 49, \"d\": 44, \"e\": 12}, {\"a\": 8, \"b\": 53, \"c\": 17, \"d\": 89, \"e\": 16}, {\"a\": 56, \"b\": 17, \"c\": 3, \"d\": 2, \"e\": 63}, {\"a\": 61, \"b\": 14, \"c\": 28, \"d\": 86, \"e\": 23}, {\"a\": 42, \"b\": 61, \"c\": 17, \"d\": 86, \"e\": 55}, {\"a\": 50, \"b\": 67, \"c\": 1, \"d\": 51, \"e\": 92}, {\"a\": 28, \"b\": 24, \"c\": 85, \"d\": 30, \"e\": 41}, {\"a\": 96, \"b\": 26, \"c\": 70, \"d\": 41, \"e\": 57}, {\"a\": 48, \"b\": 56, \"c\": 1, \"d\": 36, \"e\": 86}, {\"a\": 73, \"b\": 27, \"c\": 90, \"d\": 78, \"e\": 22}, {\"a\": 77, \"b\": 62, \"c\": 92, \"d\": 54, \"e\": 90}, {\"a\": 38, \"b\": 5, \"c\": 39, \"d\": 47, \"e\": 60}, {\"a\": 87, \"b\": 29, \"c\": 89, \"d\": 6, \"e\": 24}, {\"a\": 84, \"b\": 66, \"c\": 14, \"d\": 57, \"e\": 56}, {\"a\": 45, \"b\": 30, \"c\": 73, \"d\": 21, \"e\": 30}, {\"a\": 59, \"b\": 90, \"c\": 6, \"d\": 23, \"e\": 23}, {\"a\": 90, \"b\": 19, \"c\": 55, \"d\": 94, \"e\": 32}, {\"a\": 60, \"b\": 91, \"c\": 17, \"d\": 0, \"e\": 37}, {\"a\": 8, \"b\": 43, \"c\": 50, \"d\": 42, \"e\": 41}, {\"a\": 85, \"b\": 62, \"c\": 77, \"d\": 85, \"e\": 27}, {\"a\": 91, \"b\": 2, \"c\": 89, \"d\": 92, \"e\": 6}, {\"a\": 6, \"b\": 45, \"c\": 88, \"d\": 21, \"e\": 81}, {\"a\": 18, \"b\": 46, \"c\": 30, \"d\": 3, \"e\": 15}, {\"a\": 87, \"b\": 44, \"c\": 57, \"d\": 76, \"e\": 91}, {\"a\": 51, \"b\": 69, \"c\": 62, \"d\": 56, \"e\": 83}, {\"a\": 10, \"b\": 58, \"c\": 12, \"d\": 27, \"e\": 86}, {\"a\": 39, \"b\": 25, \"c\": 93, \"d\": 52, \"e\": 62}, {\"a\": 67, \"b\": 34, \"c\": 28, \"d\": 14, \"e\": 56}, {\"a\": 82, \"b\": 55, \"c\": 44, \"d\": 29, \"e\": 35}, {\"a\": 67, \"b\": 17, \"c\": 69, \"d\": 14, \"e\": 93}, {\"a\": 36, \"b\": 4, \"c\": 80, \"d\": 99, \"e\": 34}, {\"a\": 52, \"b\": 41, \"c\": 26, \"d\": 22, \"e\": 20}, {\"a\": 41, \"b\": 13, \"c\": 13, \"d\": 33, \"e\": 17}, {\"a\": 46, \"b\": 18, \"c\": 78, \"d\": 62, \"e\": 85}, {\"a\": 47, \"b\": 86, \"c\": 58, \"d\": 63, \"e\": 83}, {\"a\": 45, \"b\": 40, \"c\": 50, \"d\": 3, \"e\": 50}, {\"a\": 82, \"b\": 4, \"c\": 86, \"d\": 31, \"e\": 18}, {\"a\": 7, \"b\": 63, \"c\": 46, \"d\": 19, \"e\": 10}, {\"a\": 31, \"b\": 40, \"c\": 2, \"d\": 19, \"e\": 83}, {\"a\": 20, \"b\": 33, \"c\": 55, \"d\": 9, \"e\": 6}, {\"a\": 44, \"b\": 75, \"c\": 53, \"d\": 22, \"e\": 78}, {\"a\": 18, \"b\": 52, \"c\": 26, \"d\": 12, \"e\": 11}, {\"a\": 36, \"b\": 56, \"c\": 60, \"d\": 55, \"e\": 78}, {\"a\": 73, \"b\": 68, \"c\": 45, \"d\": 53, \"e\": 9}, {\"a\": 60, \"b\": 12, \"c\": 92, \"d\": 38, \"e\": 85}, {\"a\": 24, \"b\": 83, \"c\": 35, \"d\": 63, \"e\": 43}, {\"a\": 92, \"b\": 39, \"c\": 86, \"d\": 38, \"e\": 84}, {\"a\": 4, \"b\": 32, \"c\": 11, \"d\": 97, \"e\": 60}, {\"a\": 94, \"b\": 50, \"c\": 35, \"d\": 84, \"e\": 21}, {\"a\": 71, \"b\": 60, \"c\": 64, \"d\": 45, \"e\": 72}, {\"a\": 15, \"b\": 53, \"c\": 80, \"d\": 17, \"e\": 34}, {\"a\": 45, \"b\": 94, \"c\": 91, \"d\": 83, \"e\": 78}, {\"a\": 62, \"b\": 35, \"c\": 2, \"d\": 30, \"e\": 69}, {\"a\": 14, \"b\": 29, \"c\": 83, \"d\": 50, \"e\": 5}, {\"a\": 54, \"b\": 79, \"c\": 69, \"d\": 53, \"e\": 1}, {\"a\": 47, \"b\": 86, \"c\": 45, \"d\": 91, \"e\": 30}, {\"a\": 24, \"b\": 66, \"c\": 0, \"d\": 50, \"e\": 12}, {\"a\": 99, \"b\": 69, \"c\": 75, \"d\": 3, \"e\": 56}, {\"a\": 31, \"b\": 67, \"c\": 41, \"d\": 37, \"e\": 88}, {\"a\": 59, \"b\": 60, \"c\": 64, \"d\": 25, \"e\": 1}, {\"a\": 17, \"b\": 48, \"c\": 16, \"d\": 87, \"e\": 19}, {\"a\": 60, \"b\": 4, \"c\": 37, \"d\": 83, \"e\": 8}, {\"a\": 74, \"b\": 58, \"c\": 97, \"d\": 62, \"e\": 62}, {\"a\": 32, \"b\": 7, \"c\": 13, \"d\": 43, \"e\": 12}, {\"a\": 73, \"b\": 13, \"c\": 19, \"d\": 98, \"e\": 55}, {\"a\": 88, \"b\": 3, \"c\": 87, \"d\": 2, \"e\": 56}, {\"a\": 57, \"b\": 32, \"c\": 74, \"d\": 25, \"e\": 43}, {\"a\": 80, \"b\": 3, \"c\": 89, \"d\": 30, \"e\": 1}, {\"a\": 94, \"b\": 24, \"c\": 99, \"d\": 22, \"e\": 81}, {\"a\": 79, \"b\": 65, \"c\": 50, \"d\": 10, \"e\": 44}, {\"a\": 11, \"b\": 82, \"c\": 6, \"d\": 12, \"e\": 99}, {\"a\": 76, \"b\": 95, \"c\": 51, \"d\": 2, \"e\": 38}, {\"a\": 63, \"b\": 91, \"c\": 13, \"d\": 40, \"e\": 72}, {\"a\": 54, \"b\": 29, \"c\": 53, \"d\": 71, \"e\": 95}, {\"a\": 48, \"b\": 15, \"c\": 1, \"d\": 7, \"e\": 38}, {\"a\": 5, \"b\": 17, \"c\": 67, \"d\": 11, \"e\": 89}, {\"a\": 70, \"b\": 7, \"c\": 66, \"d\": 44, \"e\": 22}, {\"a\": 11, \"b\": 13, \"c\": 82, \"d\": 14, \"e\": 44}, {\"a\": 59, \"b\": 16, \"c\": 46, \"d\": 51, \"e\": 23}, {\"a\": 77, \"b\": 66, \"c\": 70, \"d\": 1, \"e\": 61}, {\"a\": 70, \"b\": 74, \"c\": 39, \"d\": 85, \"e\": 28}, {\"a\": 61, \"b\": 16, \"c\": 8, \"d\": 45, \"e\": 57}, {\"a\": 27, \"b\": 90, \"c\": 95, \"d\": 1, \"e\": 38}, {\"a\": 40, \"b\": 24, \"c\": 86, \"d\": 53, \"e\": 32}, {\"a\": 5, \"b\": 75, \"c\": 3, \"d\": 70, \"e\": 56}, {\"a\": 58, \"b\": 92, \"c\": 74, \"d\": 65, \"e\": 11}, {\"a\": 96, \"b\": 54, \"c\": 25, \"d\": 77, \"e\": 57}, {\"a\": 13, \"b\": 55, \"c\": 12, \"d\": 26, \"e\": 2}, {\"a\": 49, \"b\": 85, \"c\": 66, \"d\": 33, \"e\": 52}, {\"a\": 38, \"b\": 15, \"c\": 27, \"d\": 17, \"e\": 83}, {\"a\": 93, \"b\": 71, \"c\": 14, \"d\": 61, \"e\": 15}, {\"a\": 32, \"b\": 58, \"c\": 2, \"d\": 30, \"e\": 0}, {\"a\": 86, \"b\": 22, \"c\": 74, \"d\": 31, \"e\": 93}, {\"a\": 36, \"b\": 42, \"c\": 54, \"d\": 2, \"e\": 36}, {\"a\": 77, \"b\": 38, \"c\": 3, \"d\": 7, \"e\": 0}, {\"a\": 51, \"b\": 29, \"c\": 70, \"d\": 94, \"e\": 83}, {\"a\": 43, \"b\": 88, \"c\": 35, \"d\": 36, \"e\": 35}, {\"a\": 74, \"b\": 97, \"c\": 12, \"d\": 55, \"e\": 89}, {\"a\": 19, \"b\": 57, \"c\": 63, \"d\": 88, \"e\": 54}, {\"a\": 48, \"b\": 4, \"c\": 37, \"d\": 13, \"e\": 69}, {\"a\": 90, \"b\": 4, \"c\": 43, \"d\": 90, \"e\": 32}, {\"a\": 84, \"b\": 73, \"c\": 81, \"d\": 55, \"e\": 93}, {\"a\": 36, \"b\": 61, \"c\": 15, \"d\": 0, \"e\": 78}, {\"a\": 73, \"b\": 70, \"c\": 82, \"d\": 17, \"e\": 63}, {\"a\": 91, \"b\": 39, \"c\": 33, \"d\": 8, \"e\": 75}, {\"a\": 70, \"b\": 47, \"c\": 7, \"d\": 91, \"e\": 80}, {\"a\": 89, \"b\": 44, \"c\": 84, \"d\": 75, \"e\": 44}, {\"a\": 86, \"b\": 46, \"c\": 42, \"d\": 94, \"e\": 35}, {\"a\": 13, \"b\": 46, \"c\": 71, \"d\": 99, \"e\": 51}, {\"a\": 43, \"b\": 71, \"c\": 50, \"d\": 97, \"e\": 75}, {\"a\": 37, \"b\": 5, \"c\": 41, \"d\": 17, \"e\": 52}, {\"a\": 70, \"b\": 41, \"c\": 73, \"d\": 62, \"e\": 93}, {\"a\": 68, \"b\": 25, \"c\": 14, \"d\": 19, \"e\": 9}, {\"a\": 56, \"b\": 18, \"c\": 40, \"d\": 29, \"e\": 82}, {\"a\": 79, \"b\": 16, \"c\": 28, \"d\": 18, \"e\": 96}, {\"a\": 94, \"b\": 20, \"c\": 16, \"d\": 55, \"e\": 34}, {\"a\": 98, \"b\": 23, \"c\": 19, \"d\": 15, \"e\": 56}, {\"a\": 18, \"b\": 32, \"c\": 40, \"d\": 46, \"e\": 55}, {\"a\": 74, \"b\": 96, \"c\": 64, \"d\": 10, \"e\": 57}, {\"a\": 53, \"b\": 16, \"c\": 25, \"d\": 28, \"e\": 76}, {\"a\": 72, \"b\": 76, \"c\": 20, \"d\": 18, \"e\": 50}, {\"a\": 87, \"b\": 61, \"c\": 44, \"d\": 20, \"e\": 81}, {\"a\": 73, \"b\": 27, \"c\": 29, \"d\": 30, \"e\": 54}, {\"a\": 76, \"b\": 10, \"c\": 37, \"d\": 83, \"e\": 59}, {\"a\": 77, \"b\": 85, \"c\": 29, \"d\": 31, \"e\": 79}, {\"a\": 85, \"b\": 89, \"c\": 63, \"d\": 48, \"e\": 19}, {\"a\": 38, \"b\": 69, \"c\": 50, \"d\": 85, \"e\": 61}, {\"a\": 65, \"b\": 92, \"c\": 68, \"d\": 19, \"e\": 3}, {\"a\": 56, \"b\": 90, \"c\": 2, \"d\": 64, \"e\": 56}, {\"a\": 53, \"b\": 0, \"c\": 41, \"d\": 94, \"e\": 99}, {\"a\": 13, \"b\": 17, \"c\": 62, \"d\": 60, \"e\": 87}, {\"a\": 12, \"b\": 42, \"c\": 52, \"d\": 3, \"e\": 98}, {\"a\": 46, \"b\": 95, \"c\": 87, \"d\": 15, \"e\": 21}, {\"a\": 75, \"b\": 53, \"c\": 62, \"d\": 63, \"e\": 35}, {\"a\": 37, \"b\": 36, \"c\": 57, \"d\": 19, \"e\": 31}, {\"a\": 86, \"b\": 85, \"c\": 96, \"d\": 65, \"e\": 67}, {\"a\": 64, \"b\": 20, \"c\": 64, \"d\": 95, \"e\": 88}, {\"a\": 82, \"b\": 52, \"c\": 21, \"d\": 66, \"e\": 87}, {\"a\": 6, \"b\": 52, \"c\": 8, \"d\": 14, \"e\": 50}, {\"a\": 36, \"b\": 93, \"c\": 23, \"d\": 30, \"e\": 90}, {\"a\": 34, \"b\": 94, \"c\": 31, \"d\": 82, \"e\": 72}, {\"a\": 61, \"b\": 95, \"c\": 36, \"d\": 85, \"e\": 91}, {\"a\": 68, \"b\": 7, \"c\": 27, \"d\": 10, \"e\": 45}, {\"a\": 67, \"b\": 81, \"c\": 9, \"d\": 66, \"e\": 37}, {\"a\": 57, \"b\": 39, \"c\": 97, \"d\": 27, \"e\": 11}, {\"a\": 30, \"b\": 34, \"c\": 46, \"d\": 64, \"e\": 86}, {\"a\": 28, \"b\": 69, \"c\": 71, \"d\": 36, \"e\": 76}, {\"a\": 76, \"b\": 43, \"c\": 90, \"d\": 17, \"e\": 38}, {\"a\": 87, \"b\": 22, \"c\": 16, \"d\": 16, \"e\": 57}, {\"a\": 39, \"b\": 30, \"c\": 8, \"d\": 54, \"e\": 54}, {\"a\": 83, \"b\": 47, \"c\": 80, \"d\": 28, \"e\": 19}, {\"a\": 20, \"b\": 68, \"c\": 33, \"d\": 11, \"e\": 33}, {\"a\": 55, \"b\": 45, \"c\": 28, \"d\": 6, \"e\": 8}, {\"a\": 76, \"b\": 72, \"c\": 46, \"d\": 8, \"e\": 10}, {\"a\": 19, \"b\": 39, \"c\": 10, \"d\": 97, \"e\": 64}, {\"a\": 7, \"b\": 78, \"c\": 94, \"d\": 10, \"e\": 2}, {\"a\": 92, \"b\": 43, \"c\": 78, \"d\": 21, \"e\": 80}, {\"a\": 83, \"b\": 49, \"c\": 79, \"d\": 15, \"e\": 50}, {\"a\": 88, \"b\": 58, \"c\": 69, \"d\": 33, \"e\": 44}, {\"a\": 76, \"b\": 74, \"c\": 91, \"d\": 34, \"e\": 52}, {\"a\": 72, \"b\": 96, \"c\": 44, \"d\": 88, \"e\": 60}, {\"a\": 21, \"b\": 15, \"c\": 44, \"d\": 41, \"e\": 86}, {\"a\": 70, \"b\": 42, \"c\": 3, \"d\": 13, \"e\": 4}, {\"a\": 52, \"b\": 79, \"c\": 65, \"d\": 23, \"e\": 12}, {\"a\": 32, \"b\": 29, \"c\": 49, \"d\": 75, \"e\": 39}, {\"a\": 40, \"b\": 64, \"c\": 42, \"d\": 84, \"e\": 32}, {\"a\": 54, \"b\": 15, \"c\": 91, \"d\": 56, \"e\": 80}, {\"a\": 49, \"b\": 15, \"c\": 2, \"d\": 56, \"e\": 25}, {\"a\": 78, \"b\": 14, \"c\": 73, \"d\": 15, \"e\": 48}, {\"a\": 87, \"b\": 92, \"c\": 63, \"d\": 14, \"e\": 55}, {\"a\": 13, \"b\": 0, \"c\": 72, \"d\": 28, \"e\": 97}, {\"a\": 48, \"b\": 69, \"c\": 97, \"d\": 11, \"e\": 62}, {\"a\": 77, \"b\": 87, \"c\": 84, \"d\": 55, \"e\": 79}, {\"a\": 12, \"b\": 5, \"c\": 83, \"d\": 89, \"e\": 59}, {\"a\": 16, \"b\": 23, \"c\": 5, \"d\": 15, \"e\": 58}, {\"a\": 21, \"b\": 38, \"c\": 95, \"d\": 97, \"e\": 88}, {\"a\": 83, \"b\": 51, \"c\": 54, \"d\": 65, \"e\": 47}, {\"a\": 73, \"b\": 79, \"c\": 18, \"d\": 72, \"e\": 66}, {\"a\": 90, \"b\": 33, \"c\": 10, \"d\": 38, \"e\": 75}, {\"a\": 23, \"b\": 98, \"c\": 22, \"d\": 72, \"e\": 3}, {\"a\": 73, \"b\": 9, \"c\": 42, \"d\": 81, \"e\": 47}, {\"a\": 88, \"b\": 22, \"c\": 23, \"d\": 66, \"e\": 70}, {\"a\": 79, \"b\": 10, \"c\": 50, \"d\": 17, \"e\": 2}, {\"a\": 89, \"b\": 75, \"c\": 55, \"d\": 97, \"e\": 75}, {\"a\": 58, \"b\": 55, \"c\": 20, \"d\": 26, \"e\": 63}, {\"a\": 39, \"b\": 24, \"c\": 65, \"d\": 78, \"e\": 57}, {\"a\": 4, \"b\": 76, \"c\": 26, \"d\": 71, \"e\": 9}, {\"a\": 12, \"b\": 9, \"c\": 3, \"d\": 89, \"e\": 88}, {\"a\": 97, \"b\": 51, \"c\": 65, \"d\": 71, \"e\": 79}, {\"a\": 65, \"b\": 6, \"c\": 22, \"d\": 41, \"e\": 15}, {\"a\": 35, \"b\": 82, \"c\": 94, \"d\": 94, \"e\": 10}, {\"a\": 98, \"b\": 68, \"c\": 54, \"d\": 20, \"e\": 81}, {\"a\": 90, \"b\": 32, \"c\": 61, \"d\": 33, \"e\": 18}, {\"a\": 23, \"b\": 83, \"c\": 87, \"d\": 93, \"e\": 42}, {\"a\": 59, \"b\": 2, \"c\": 41, \"d\": 44, \"e\": 64}, {\"a\": 89, \"b\": 75, \"c\": 95, \"d\": 11, \"e\": 30}, {\"a\": 58, \"b\": 37, \"c\": 60, \"d\": 22, \"e\": 2}, {\"a\": 26, \"b\": 60, \"c\": 86, \"d\": 43, \"e\": 66}, {\"a\": 30, \"b\": 42, \"c\": 72, \"d\": 83, \"e\": 23}, {\"a\": 94, \"b\": 46, \"c\": 11, \"d\": 51, \"e\": 65}, {\"a\": 44, \"b\": 53, \"c\": 63, \"d\": 58, \"e\": 1}, {\"a\": 55, \"b\": 28, \"c\": 32, \"d\": 64, \"e\": 22}, {\"a\": 30, \"b\": 84, \"c\": 94, \"d\": 71, \"e\": 49}, {\"a\": 99, \"b\": 53, \"c\": 73, \"d\": 65, \"e\": 91}, {\"a\": 6, \"b\": 53, \"c\": 99, \"d\": 80, \"e\": 71}, {\"a\": 14, \"b\": 4, \"c\": 94, \"d\": 25, \"e\": 85}, {\"a\": 78, \"b\": 78, \"c\": 0, \"d\": 49, \"e\": 14}, {\"a\": 3, \"b\": 40, \"c\": 87, \"d\": 65, \"e\": 96}, {\"a\": 10, \"b\": 60, \"c\": 72, \"d\": 48, \"e\": 23}, {\"a\": 22, \"b\": 34, \"c\": 8, \"d\": 61, \"e\": 78}, {\"a\": 46, \"b\": 81, \"c\": 24, \"d\": 93, \"e\": 68}, {\"a\": 56, \"b\": 98, \"c\": 43, \"d\": 69, \"e\": 96}, {\"a\": 31, \"b\": 8, \"c\": 34, \"d\": 42, \"e\": 19}, {\"a\": 55, \"b\": 96, \"c\": 29, \"d\": 12, \"e\": 46}, {\"a\": 66, \"b\": 36, \"c\": 74, \"d\": 46, \"e\": 97}, {\"a\": 88, \"b\": 13, \"c\": 42, \"d\": 7, \"e\": 87}, {\"a\": 51, \"b\": 26, \"c\": 27, \"d\": 99, \"e\": 75}, {\"a\": 8, \"b\": 16, \"c\": 91, \"d\": 60, \"e\": 66}, {\"a\": 91, \"b\": 75, \"c\": 52, \"d\": 69, \"e\": 25}, {\"a\": 27, \"b\": 28, \"c\": 96, \"d\": 3, \"e\": 32}, {\"a\": 95, \"b\": 45, \"c\": 6, \"d\": 96, \"e\": 39}, {\"a\": 97, \"b\": 20, \"c\": 6, \"d\": 3, \"e\": 49}, {\"a\": 18, \"b\": 37, \"c\": 24, \"d\": 68, \"e\": 19}, {\"a\": 73, \"b\": 50, \"c\": 50, \"d\": 63, \"e\": 87}, {\"a\": 68, \"b\": 17, \"c\": 39, \"d\": 36, \"e\": 13}, {\"a\": 17, \"b\": 7, \"c\": 52, \"d\": 90, \"e\": 38}, {\"a\": 10, \"b\": 10, \"c\": 3, \"d\": 46, \"e\": 80}, {\"a\": 1, \"b\": 6, \"c\": 7, \"d\": 71, \"e\": 57}, {\"a\": 52, \"b\": 68, \"c\": 33, \"d\": 82, \"e\": 87}, {\"a\": 33, \"b\": 35, \"c\": 83, \"d\": 64, \"e\": 47}, {\"a\": 49, \"b\": 61, \"c\": 15, \"d\": 57, \"e\": 50}, {\"a\": 52, \"b\": 53, \"c\": 43, \"d\": 64, \"e\": 19}, {\"a\": 53, \"b\": 77, \"c\": 22, \"d\": 94, \"e\": 70}, {\"a\": 98, \"b\": 78, \"c\": 86, \"d\": 39, \"e\": 40}, {\"a\": 72, \"b\": 52, \"c\": 42, \"d\": 16, \"e\": 59}, {\"a\": 71, \"b\": 40, \"c\": 32, \"d\": 38, \"e\": 87}, {\"a\": 29, \"b\": 12, \"c\": 7, \"d\": 3, \"e\": 8}, {\"a\": 64, \"b\": 83, \"c\": 58, \"d\": 2, \"e\": 42}, {\"a\": 47, \"b\": 54, \"c\": 58, \"d\": 90, \"e\": 1}, {\"a\": 80, \"b\": 88, \"c\": 50, \"d\": 59, \"e\": 90}, {\"a\": 39, \"b\": 8, \"c\": 71, \"d\": 19, \"e\": 23}, {\"a\": 74, \"b\": 88, \"c\": 27, \"d\": 85, \"e\": 21}, {\"a\": 37, \"b\": 37, \"c\": 39, \"d\": 8, \"e\": 14}, {\"a\": 75, \"b\": 17, \"c\": 8, \"d\": 32, \"e\": 87}, {\"a\": 31, \"b\": 43, \"c\": 98, \"d\": 15, \"e\": 47}, {\"a\": 70, \"b\": 64, \"c\": 81, \"d\": 18, \"e\": 31}, {\"a\": 35, \"b\": 23, \"c\": 80, \"d\": 95, \"e\": 73}, {\"a\": 79, \"b\": 69, \"c\": 2, \"d\": 13, \"e\": 93}, {\"a\": 77, \"b\": 48, \"c\": 64, \"d\": 66, \"e\": 77}, {\"a\": 25, \"b\": 16, \"c\": 60, \"d\": 32, \"e\": 98}, {\"a\": 73, \"b\": 92, \"c\": 69, \"d\": 63, \"e\": 31}, {\"a\": 48, \"b\": 29, \"c\": 17, \"d\": 48, \"e\": 75}, {\"a\": 74, \"b\": 25, \"c\": 80, \"d\": 49, \"e\": 59}, {\"a\": 64, \"b\": 97, \"c\": 3, \"d\": 38, \"e\": 24}, {\"a\": 75, \"b\": 26, \"c\": 94, \"d\": 93, \"e\": 62}, {\"a\": 65, \"b\": 28, \"c\": 39, \"d\": 46, \"e\": 91}, {\"a\": 40, \"b\": 82, \"c\": 44, \"d\": 81, \"e\": 98}, {\"a\": 22, \"b\": 61, \"c\": 50, \"d\": 53, \"e\": 47}, {\"a\": 33, \"b\": 71, \"c\": 56, \"d\": 72, \"e\": 21}, {\"a\": 24, \"b\": 69, \"c\": 4, \"d\": 68, \"e\": 47}, {\"a\": 61, \"b\": 21, \"c\": 28, \"d\": 8, \"e\": 7}, {\"a\": 43, \"b\": 71, \"c\": 8, \"d\": 29, \"e\": 28}, {\"a\": 33, \"b\": 61, \"c\": 90, \"d\": 77, \"e\": 41}, {\"a\": 30, \"b\": 61, \"c\": 69, \"d\": 36, \"e\": 31}, {\"a\": 2, \"b\": 8, \"c\": 53, \"d\": 17, \"e\": 30}, {\"a\": 16, \"b\": 66, \"c\": 63, \"d\": 53, \"e\": 62}, {\"a\": 37, \"b\": 57, \"c\": 75, \"d\": 61, \"e\": 21}, {\"a\": 19, \"b\": 77, \"c\": 73, \"d\": 33, \"e\": 48}, {\"a\": 67, \"b\": 98, \"c\": 93, \"d\": 84, \"e\": 73}, {\"a\": 18, \"b\": 78, \"c\": 58, \"d\": 68, \"e\": 80}, {\"a\": 42, \"b\": 44, \"c\": 27, \"d\": 54, \"e\": 50}, {\"a\": 38, \"b\": 12, \"c\": 84, \"d\": 55, \"e\": 47}, {\"a\": 11, \"b\": 91, \"c\": 38, \"d\": 90, \"e\": 16}, {\"a\": 5, \"b\": 75, \"c\": 19, \"d\": 33, \"e\": 81}, {\"a\": 82, \"b\": 94, \"c\": 22, \"d\": 78, \"e\": 27}, {\"a\": 91, \"b\": 33, \"c\": 97, \"d\": 79, \"e\": 17}, {\"a\": 49, \"b\": 82, \"c\": 79, \"d\": 79, \"e\": 90}, {\"a\": 99, \"b\": 13, \"c\": 53, \"d\": 85, \"e\": 40}, {\"a\": 82, \"b\": 27, \"c\": 11, \"d\": 36, \"e\": 48}, {\"a\": 8, \"b\": 68, \"c\": 73, \"d\": 75, \"e\": 92}, {\"a\": 54, \"b\": 2, \"c\": 50, \"d\": 78, \"e\": 21}, {\"a\": 40, \"b\": 68, \"c\": 35, \"d\": 4, \"e\": 85}, {\"a\": 11, \"b\": 18, \"c\": 90, \"d\": 84, \"e\": 93}, {\"a\": 83, \"b\": 49, \"c\": 95, \"d\": 81, \"e\": 56}, {\"a\": 52, \"b\": 99, \"c\": 12, \"d\": 63, \"e\": 37}, {\"a\": 36, \"b\": 0, \"c\": 46, \"d\": 40, \"e\": 64}, {\"a\": 7, \"b\": 16, \"c\": 85, \"d\": 46, \"e\": 29}, {\"a\": 45, \"b\": 87, \"c\": 84, \"d\": 95, \"e\": 60}, {\"a\": 52, \"b\": 33, \"c\": 38, \"d\": 70, \"e\": 35}, {\"a\": 66, \"b\": 56, \"c\": 6, \"d\": 36, \"e\": 81}, {\"a\": 38, \"b\": 86, \"c\": 67, \"d\": 72, \"e\": 22}, {\"a\": 30, \"b\": 5, \"c\": 22, \"d\": 50, \"e\": 78}, {\"a\": 57, \"b\": 20, \"c\": 8, \"d\": 93, \"e\": 5}, {\"a\": 80, \"b\": 88, \"c\": 64, \"d\": 45, \"e\": 6}, {\"a\": 99, \"b\": 70, \"c\": 86, \"d\": 21, \"e\": 44}, {\"a\": 59, \"b\": 38, \"c\": 11, \"d\": 86, \"e\": 45}, {\"a\": 80, \"b\": 0, \"c\": 55, \"d\": 0, \"e\": 24}, {\"a\": 75, \"b\": 27, \"c\": 45, \"d\": 58, \"e\": 15}, {\"a\": 37, \"b\": 53, \"c\": 47, \"d\": 20, \"e\": 39}, {\"a\": 62, \"b\": 98, \"c\": 61, \"d\": 12, \"e\": 75}, {\"a\": 88, \"b\": 67, \"c\": 56, \"d\": 19, \"e\": 56}, {\"a\": 39, \"b\": 99, \"c\": 93, \"d\": 36, \"e\": 13}, {\"a\": 34, \"b\": 25, \"c\": 68, \"d\": 32, \"e\": 71}, {\"a\": 79, \"b\": 16, \"c\": 67, \"d\": 81, \"e\": 99}, {\"a\": 38, \"b\": 40, \"c\": 88, \"d\": 30, \"e\": 47}, {\"a\": 90, \"b\": 26, \"c\": 87, \"d\": 5, \"e\": 3}, {\"a\": 10, \"b\": 44, \"c\": 33, \"d\": 43, \"e\": 13}, {\"a\": 38, \"b\": 5, \"c\": 69, \"d\": 68, \"e\": 99}, {\"a\": 93, \"b\": 83, \"c\": 45, \"d\": 72, \"e\": 82}, {\"a\": 62, \"b\": 13, \"c\": 49, \"d\": 33, \"e\": 39}, {\"a\": 37, \"b\": 32, \"c\": 31, \"d\": 27, \"e\": 94}, {\"a\": 30, \"b\": 39, \"c\": 43, \"d\": 71, \"e\": 82}, {\"a\": 82, \"b\": 71, \"c\": 24, \"d\": 26, \"e\": 16}, {\"a\": 13, \"b\": 3, \"c\": 85, \"d\": 54, \"e\": 82}, {\"a\": 80, \"b\": 47, \"c\": 40, \"d\": 65, \"e\": 75}, {\"a\": 48, \"b\": 3, \"c\": 0, \"d\": 60, \"e\": 29}, {\"a\": 72, \"b\": 71, \"c\": 70, \"d\": 84, \"e\": 0}, {\"a\": 2, \"b\": 83, \"c\": 72, \"d\": 70, \"e\": 33}, {\"a\": 1, \"b\": 4, \"c\": 36, \"d\": 81, \"e\": 66}, {\"a\": 99, \"b\": 58, \"c\": 95, \"d\": 70, \"e\": 62}, {\"a\": 62, \"b\": 9, \"c\": 55, \"d\": 15, \"e\": 75}, {\"a\": 81, \"b\": 62, \"c\": 75, \"d\": 61, \"e\": 29}, {\"a\": 55, \"b\": 55, \"c\": 92, \"d\": 10, \"e\": 42}, {\"a\": 4, \"b\": 13, \"c\": 12, \"d\": 4, \"e\": 96}, {\"a\": 63, \"b\": 33, \"c\": 73, \"d\": 41, \"e\": 95}, {\"a\": 97, \"b\": 51, \"c\": 81, \"d\": 62, \"e\": 35}, {\"a\": 92, \"b\": 94, \"c\": 92, \"d\": 18, \"e\": 77}, {\"a\": 65, \"b\": 1, \"c\": 45, \"d\": 6, \"e\": 78}, {\"a\": 22, \"b\": 46, \"c\": 59, \"d\": 44, \"e\": 20}, {\"a\": 38, \"b\": 66, \"c\": 56, \"d\": 68, \"e\": 24}, {\"a\": 65, \"b\": 23, \"c\": 72, \"d\": 67, \"e\": 24}, {\"a\": 69, \"b\": 91, \"c\": 64, \"d\": 68, \"e\": 96}, {\"a\": 69, \"b\": 63, \"c\": 39, \"d\": 21, \"e\": 60}, {\"a\": 29, \"b\": 75, \"c\": 29, \"d\": 62, \"e\": 71}, {\"a\": 17, \"b\": 37, \"c\": 3, \"d\": 38, \"e\": 11}, {\"a\": 52, \"b\": 14, \"c\": 17, \"d\": 5, \"e\": 89}, {\"a\": 30, \"b\": 6, \"c\": 35, \"d\": 18, \"e\": 21}, {\"a\": 79, \"b\": 44, \"c\": 96, \"d\": 5, \"e\": 77}, {\"a\": 16, \"b\": 43, \"c\": 3, \"d\": 6, \"e\": 33}, {\"a\": 78, \"b\": 41, \"c\": 88, \"d\": 76, \"e\": 14}, {\"a\": 1, \"b\": 23, \"c\": 42, \"d\": 80, \"e\": 32}, {\"a\": 68, \"b\": 78, \"c\": 79, \"d\": 1, \"e\": 23}, {\"a\": 14, \"b\": 97, \"c\": 30, \"d\": 24, \"e\": 97}, {\"a\": 11, \"b\": 8, \"c\": 46, \"d\": 51, \"e\": 34}, {\"a\": 22, \"b\": 7, \"c\": 59, \"d\": 79, \"e\": 47}, {\"a\": 41, \"b\": 31, \"c\": 17, \"d\": 30, \"e\": 85}, {\"a\": 98, \"b\": 40, \"c\": 12, \"d\": 40, \"e\": 31}, {\"a\": 97, \"b\": 82, \"c\": 22, \"d\": 9, \"e\": 47}, {\"a\": 47, \"b\": 38, \"c\": 57, \"d\": 53, \"e\": 59}, {\"a\": 69, \"b\": 62, \"c\": 78, \"d\": 70, \"e\": 70}, {\"a\": 64, \"b\": 57, \"c\": 43, \"d\": 85, \"e\": 13}, {\"a\": 70, \"b\": 74, \"c\": 56, \"d\": 97, \"e\": 36}, {\"a\": 70, \"b\": 2, \"c\": 31, \"d\": 72, \"e\": 3}, {\"a\": 19, \"b\": 16, \"c\": 30, \"d\": 28, \"e\": 77}, {\"a\": 21, \"b\": 44, \"c\": 50, \"d\": 7, \"e\": 94}, {\"a\": 10, \"b\": 11, \"c\": 85, \"d\": 10, \"e\": 50}, {\"a\": 66, \"b\": 93, \"c\": 18, \"d\": 12, \"e\": 84}, {\"a\": 30, \"b\": 6, \"c\": 84, \"d\": 91, \"e\": 75}, {\"a\": 66, \"b\": 59, \"c\": 33, \"d\": 71, \"e\": 14}, {\"a\": 19, \"b\": 88, \"c\": 82, \"d\": 70, \"e\": 42}, {\"a\": 0, \"b\": 99, \"c\": 22, \"d\": 39, \"e\": 51}, {\"a\": 13, \"b\": 19, \"c\": 62, \"d\": 21, \"e\": 65}, {\"a\": 30, \"b\": 70, \"c\": 20, \"d\": 74, \"e\": 89}, {\"a\": 58, \"b\": 7, \"c\": 78, \"d\": 53, \"e\": 19}, {\"a\": 83, \"b\": 10, \"c\": 35, \"d\": 20, \"e\": 11}, {\"a\": 62, \"b\": 9, \"c\": 60, \"d\": 80, \"e\": 59}, {\"a\": 53, \"b\": 42, \"c\": 89, \"d\": 87, \"e\": 38}, {\"a\": 96, \"b\": 93, \"c\": 53, \"d\": 53, \"e\": 16}, {\"a\": 23, \"b\": 27, \"c\": 27, \"d\": 7, \"e\": 62}, {\"a\": 24, \"b\": 67, \"c\": 65, \"d\": 38, \"e\": 77}, {\"a\": 35, \"b\": 50, \"c\": 4, \"d\": 68, \"e\": 87}, {\"a\": 19, \"b\": 59, \"c\": 29, \"d\": 42, \"e\": 20}, {\"a\": 21, \"b\": 12, \"c\": 41, \"d\": 95, \"e\": 95}, {\"a\": 74, \"b\": 66, \"c\": 78, \"d\": 62, \"e\": 14}, {\"a\": 9, \"b\": 18, \"c\": 6, \"d\": 72, \"e\": 79}, {\"a\": 75, \"b\": 79, \"c\": 38, \"d\": 23, \"e\": 13}, {\"a\": 80, \"b\": 48, \"c\": 66, \"d\": 30, \"e\": 23}, {\"a\": 4, \"b\": 82, \"c\": 70, \"d\": 69, \"e\": 61}, {\"a\": 99, \"b\": 67, \"c\": 57, \"d\": 7, \"e\": 82}, {\"a\": 24, \"b\": 0, \"c\": 57, \"d\": 46, \"e\": 81}, {\"a\": 15, \"b\": 1, \"c\": 98, \"d\": 95, \"e\": 28}, {\"a\": 3, \"b\": 45, \"c\": 24, \"d\": 40, \"e\": 75}, {\"a\": 25, \"b\": 36, \"c\": 41, \"d\": 65, \"e\": 13}, {\"a\": 86, \"b\": 42, \"c\": 53, \"d\": 52, \"e\": 46}, {\"a\": 37, \"b\": 5, \"c\": 93, \"d\": 55, \"e\": 0}, {\"a\": 75, \"b\": 15, \"c\": 35, \"d\": 88, \"e\": 5}, {\"a\": 36, \"b\": 12, \"c\": 66, \"d\": 99, \"e\": 31}, {\"a\": 48, \"b\": 29, \"c\": 4, \"d\": 58, \"e\": 95}, {\"a\": 62, \"b\": 75, \"c\": 9, \"d\": 96, \"e\": 42}, {\"a\": 45, \"b\": 81, \"c\": 78, \"d\": 15, \"e\": 34}, {\"a\": 58, \"b\": 98, \"c\": 89, \"d\": 98, \"e\": 60}, {\"a\": 70, \"b\": 9, \"c\": 73, \"d\": 13, \"e\": 76}, {\"a\": 87, \"b\": 8, \"c\": 89, \"d\": 56, \"e\": 12}, {\"a\": 78, \"b\": 72, \"c\": 42, \"d\": 16, \"e\": 34}, {\"a\": 9, \"b\": 77, \"c\": 48, \"d\": 50, \"e\": 18}, {\"a\": 41, \"b\": 50, \"c\": 58, \"d\": 38, \"e\": 55}, {\"a\": 97, \"b\": 7, \"c\": 7, \"d\": 31, \"e\": 91}, {\"a\": 2, \"b\": 19, \"c\": 89, \"d\": 62, \"e\": 52}, {\"a\": 71, \"b\": 94, \"c\": 78, \"d\": 55, \"e\": 98}, {\"a\": 38, \"b\": 50, \"c\": 90, \"d\": 99, \"e\": 6}, {\"a\": 39, \"b\": 67, \"c\": 29, \"d\": 63, \"e\": 99}, {\"a\": 80, \"b\": 96, \"c\": 3, \"d\": 41, \"e\": 97}, {\"a\": 85, \"b\": 6, \"c\": 41, \"d\": 71, \"e\": 20}, {\"a\": 64, \"b\": 45, \"c\": 66, \"d\": 68, \"e\": 39}, {\"a\": 21, \"b\": 49, \"c\": 79, \"d\": 69, \"e\": 35}, {\"a\": 82, \"b\": 23, \"c\": 88, \"d\": 79, \"e\": 71}, {\"a\": 31, \"b\": 35, \"c\": 49, \"d\": 41, \"e\": 73}, {\"a\": 17, \"b\": 57, \"c\": 84, \"d\": 36, \"e\": 58}, {\"a\": 92, \"b\": 35, \"c\": 92, \"d\": 69, \"e\": 25}, {\"a\": 62, \"b\": 29, \"c\": 31, \"d\": 55, \"e\": 73}, {\"a\": 94, \"b\": 37, \"c\": 46, \"d\": 74, \"e\": 97}, {\"a\": 1, \"b\": 51, \"c\": 87, \"d\": 76, \"e\": 2}, {\"a\": 65, \"b\": 18, \"c\": 39, \"d\": 37, \"e\": 76}, {\"a\": 76, \"b\": 27, \"c\": 51, \"d\": 33, \"e\": 6}, {\"a\": 3, \"b\": 79, \"c\": 95, \"d\": 42, \"e\": 21}, {\"a\": 33, \"b\": 98, \"c\": 85, \"d\": 5, \"e\": 33}, {\"a\": 64, \"b\": 35, \"c\": 63, \"d\": 74, \"e\": 97}, {\"a\": 52, \"b\": 12, \"c\": 16, \"d\": 61, \"e\": 49}, {\"a\": 39, \"b\": 48, \"c\": 39, \"d\": 6, \"e\": 0}, {\"a\": 6, \"b\": 5, \"c\": 39, \"d\": 40, \"e\": 66}, {\"a\": 8, \"b\": 55, \"c\": 3, \"d\": 1, \"e\": 47}, {\"a\": 87, \"b\": 34, \"c\": 15, \"d\": 71, \"e\": 48}, {\"a\": 77, \"b\": 63, \"c\": 14, \"d\": 17, \"e\": 47}, {\"a\": 97, \"b\": 64, \"c\": 1, \"d\": 67, \"e\": 57}, {\"a\": 82, \"b\": 22, \"c\": 11, \"d\": 7, \"e\": 44}, {\"a\": 67, \"b\": 66, \"c\": 64, \"d\": 52, \"e\": 82}, {\"a\": 15, \"b\": 16, \"c\": 31, \"d\": 45, \"e\": 43}, {\"a\": 83, \"b\": 64, \"c\": 79, \"d\": 90, \"e\": 30}, {\"a\": 21, \"b\": 62, \"c\": 85, \"d\": 10, \"e\": 37}, {\"a\": 42, \"b\": 74, \"c\": 96, \"d\": 47, \"e\": 72}, {\"a\": 53, \"b\": 72, \"c\": 23, \"d\": 17, \"e\": 47}, {\"a\": 66, \"b\": 88, \"c\": 23, \"d\": 97, \"e\": 83}, {\"a\": 73, \"b\": 93, \"c\": 22, \"d\": 59, \"e\": 91}, {\"a\": 37, \"b\": 30, \"c\": 90, \"d\": 42, \"e\": 16}, {\"a\": 81, \"b\": 58, \"c\": 66, \"d\": 77, \"e\": 51}, {\"a\": 82, \"b\": 18, \"c\": 69, \"d\": 9, \"e\": 55}, {\"a\": 58, \"b\": 55, \"c\": 41, \"d\": 4, \"e\": 35}, {\"a\": 94, \"b\": 0, \"c\": 37, \"d\": 91, \"e\": 87}, {\"a\": 9, \"b\": 61, \"c\": 71, \"d\": 4, \"e\": 63}, {\"a\": 97, \"b\": 4, \"c\": 14, \"d\": 23, \"e\": 74}, {\"a\": 58, \"b\": 66, \"c\": 44, \"d\": 77, \"e\": 18}, {\"a\": 81, \"b\": 53, \"c\": 65, \"d\": 89, \"e\": 11}, {\"a\": 12, \"b\": 34, \"c\": 16, \"d\": 45, \"e\": 37}, {\"a\": 18, \"b\": 54, \"c\": 19, \"d\": 23, \"e\": 59}, {\"a\": 90, \"b\": 64, \"c\": 0, \"d\": 8, \"e\": 10}, {\"a\": 25, \"b\": 30, \"c\": 3, \"d\": 49, \"e\": 94}, {\"a\": 69, \"b\": 37, \"c\": 79, \"d\": 59, \"e\": 79}, {\"a\": 82, \"b\": 68, \"c\": 14, \"d\": 28, \"e\": 15}, {\"a\": 59, \"b\": 34, \"c\": 16, \"d\": 3, \"e\": 59}, {\"a\": 12, \"b\": 83, \"c\": 47, \"d\": 71, \"e\": 26}, {\"a\": 13, \"b\": 53, \"c\": 53, \"d\": 96, \"e\": 94}, {\"a\": 67, \"b\": 87, \"c\": 85, \"d\": 59, \"e\": 5}, {\"a\": 91, \"b\": 16, \"c\": 85, \"d\": 54, \"e\": 98}, {\"a\": 20, \"b\": 1, \"c\": 61, \"d\": 23, \"e\": 46}, {\"a\": 34, \"b\": 95, \"c\": 32, \"d\": 6, \"e\": 68}, {\"a\": 26, \"b\": 68, \"c\": 7, \"d\": 66, \"e\": 35}, {\"a\": 94, \"b\": 12, \"c\": 9, \"d\": 92, \"e\": 49}, {\"a\": 59, \"b\": 55, \"c\": 22, \"d\": 25, \"e\": 25}, {\"a\": 40, \"b\": 19, \"c\": 92, \"d\": 51, \"e\": 42}, {\"a\": 50, \"b\": 73, \"c\": 60, \"d\": 53, \"e\": 4}, {\"a\": 66, \"b\": 13, \"c\": 5, \"d\": 67, \"e\": 23}, {\"a\": 21, \"b\": 75, \"c\": 70, \"d\": 15, \"e\": 33}, {\"a\": 93, \"b\": 79, \"c\": 61, \"d\": 71, \"e\": 52}, {\"a\": 42, \"b\": 0, \"c\": 46, \"d\": 87, \"e\": 91}, {\"a\": 89, \"b\": 9, \"c\": 85, \"d\": 28, \"e\": 85}, {\"a\": 92, \"b\": 46, \"c\": 77, \"d\": 24, \"e\": 88}, {\"a\": 65, \"b\": 80, \"c\": 69, \"d\": 56, \"e\": 84}, {\"a\": 15, \"b\": 73, \"c\": 35, \"d\": 81, \"e\": 98}, {\"a\": 52, \"b\": 46, \"c\": 91, \"d\": 33, \"e\": 40}, {\"a\": 90, \"b\": 16, \"c\": 16, \"d\": 63, \"e\": 75}, {\"a\": 28, \"b\": 30, \"c\": 81, \"d\": 49, \"e\": 25}, {\"a\": 46, \"b\": 98, \"c\": 97, \"d\": 35, \"e\": 26}, {\"a\": 78, \"b\": 66, \"c\": 64, \"d\": 86, \"e\": 92}, {\"a\": 91, \"b\": 80, \"c\": 70, \"d\": 34, \"e\": 95}, {\"a\": 18, \"b\": 85, \"c\": 19, \"d\": 68, \"e\": 67}, {\"a\": 22, \"b\": 18, \"c\": 22, \"d\": 20, \"e\": 43}, {\"a\": 32, \"b\": 75, \"c\": 19, \"d\": 90, \"e\": 81}, {\"a\": 80, \"b\": 50, \"c\": 39, \"d\": 47, \"e\": 92}, {\"a\": 49, \"b\": 24, \"c\": 5, \"d\": 62, \"e\": 24}, {\"a\": 82, \"b\": 61, \"c\": 11, \"d\": 81, \"e\": 22}, {\"a\": 58, \"b\": 6, \"c\": 18, \"d\": 54, \"e\": 29}, {\"a\": 89, \"b\": 65, \"c\": 69, \"d\": 32, \"e\": 28}, {\"a\": 65, \"b\": 67, \"c\": 30, \"d\": 47, \"e\": 5}, {\"a\": 40, \"b\": 97, \"c\": 9, \"d\": 55, \"e\": 8}, {\"a\": 54, \"b\": 25, \"c\": 31, \"d\": 45, \"e\": 46}, {\"a\": 41, \"b\": 40, \"c\": 69, \"d\": 53, \"e\": 31}, {\"a\": 70, \"b\": 4, \"c\": 5, \"d\": 79, \"e\": 3}, {\"a\": 92, \"b\": 54, \"c\": 20, \"d\": 80, \"e\": 54}, {\"a\": 87, \"b\": 51, \"c\": 46, \"d\": 7, \"e\": 86}, {\"a\": 56, \"b\": 79, \"c\": 90, \"d\": 93, \"e\": 4}, {\"a\": 94, \"b\": 52, \"c\": 67, \"d\": 45, \"e\": 5}, {\"a\": 14, \"b\": 74, \"c\": 22, \"d\": 46, \"e\": 1}, {\"a\": 0, \"b\": 78, \"c\": 58, \"d\": 14, \"e\": 23}, {\"a\": 98, \"b\": 43, \"c\": 21, \"d\": 28, \"e\": 76}, {\"a\": 99, \"b\": 87, \"c\": 82, \"d\": 73, \"e\": 94}, {\"a\": 50, \"b\": 21, \"c\": 98, \"d\": 12, \"e\": 90}, {\"a\": 99, \"b\": 22, \"c\": 37, \"d\": 10, \"e\": 32}, {\"a\": 76, \"b\": 36, \"c\": 16, \"d\": 33, \"e\": 10}, {\"a\": 92, \"b\": 25, \"c\": 74, \"d\": 82, \"e\": 77}, {\"a\": 46, \"b\": 56, \"c\": 10, \"d\": 17, \"e\": 86}, {\"a\": 36, \"b\": 31, \"c\": 28, \"d\": 84, \"e\": 18}, {\"a\": 29, \"b\": 39, \"c\": 4, \"d\": 52, \"e\": 32}, {\"a\": 37, \"b\": 26, \"c\": 46, \"d\": 92, \"e\": 23}, {\"a\": 33, \"b\": 45, \"c\": 29, \"d\": 97, \"e\": 4}, {\"a\": 65, \"b\": 49, \"c\": 51, \"d\": 78, \"e\": 12}, {\"a\": 71, \"b\": 75, \"c\": 18, \"d\": 0, \"e\": 30}, {\"a\": 77, \"b\": 19, \"c\": 87, \"d\": 92, \"e\": 28}, {\"a\": 84, \"b\": 38, \"c\": 51, \"d\": 2, \"e\": 91}, {\"a\": 41, \"b\": 67, \"c\": 68, \"d\": 14, \"e\": 5}, {\"a\": 0, \"b\": 28, \"c\": 42, \"d\": 81, \"e\": 2}, {\"a\": 71, \"b\": 4, \"c\": 5, \"d\": 39, \"e\": 11}, {\"a\": 79, \"b\": 31, \"c\": 4, \"d\": 1, \"e\": 91}, {\"a\": 75, \"b\": 47, \"c\": 77, \"d\": 72, \"e\": 25}, {\"a\": 99, \"b\": 81, \"c\": 47, \"d\": 84, \"e\": 23}, {\"a\": 99, \"b\": 74, \"c\": 50, \"d\": 73, \"e\": 62}, {\"a\": 84, \"b\": 60, \"c\": 47, \"d\": 42, \"e\": 67}, {\"a\": 94, \"b\": 35, \"c\": 47, \"d\": 4, \"e\": 46}, {\"a\": 59, \"b\": 29, \"c\": 90, \"d\": 7, \"e\": 23}, {\"a\": 39, \"b\": 45, \"c\": 82, \"d\": 15, \"e\": 71}, {\"a\": 76, \"b\": 80, \"c\": 87, \"d\": 53, \"e\": 74}, {\"a\": 55, \"b\": 89, \"c\": 16, \"d\": 3, \"e\": 25}, {\"a\": 56, \"b\": 53, \"c\": 19, \"d\": 10, \"e\": 51}, {\"a\": 95, \"b\": 56, \"c\": 51, \"d\": 50, \"e\": 32}, {\"a\": 82, \"b\": 13, \"c\": 19, \"d\": 84, \"e\": 5}, {\"a\": 98, \"b\": 55, \"c\": 90, \"d\": 44, \"e\": 0}, {\"a\": 92, \"b\": 11, \"c\": 62, \"d\": 74, \"e\": 5}, {\"a\": 84, \"b\": 75, \"c\": 8, \"d\": 69, \"e\": 34}, {\"a\": 47, \"b\": 98, \"c\": 48, \"d\": 12, \"e\": 40}, {\"a\": 46, \"b\": 52, \"c\": 76, \"d\": 46, \"e\": 66}, {\"a\": 14, \"b\": 73, \"c\": 60, \"d\": 70, \"e\": 55}, {\"a\": 0, \"b\": 4, \"c\": 34, \"d\": 24, \"e\": 21}, {\"a\": 82, \"b\": 17, \"c\": 98, \"d\": 86, \"e\": 29}, {\"a\": 29, \"b\": 11, \"c\": 84, \"d\": 58, \"e\": 26}, {\"a\": 26, \"b\": 15, \"c\": 63, \"d\": 61, \"e\": 85}, {\"a\": 30, \"b\": 43, \"c\": 91, \"d\": 6, \"e\": 98}, {\"a\": 85, \"b\": 63, \"c\": 33, \"d\": 75, \"e\": 76}, {\"a\": 82, \"b\": 21, \"c\": 99, \"d\": 60, \"e\": 47}, {\"a\": 96, \"b\": 76, \"c\": 92, \"d\": 89, \"e\": 43}, {\"a\": 51, \"b\": 51, \"c\": 51, \"d\": 33, \"e\": 85}, {\"a\": 88, \"b\": 46, \"c\": 64, \"d\": 37, \"e\": 92}, {\"a\": 96, \"b\": 62, \"c\": 61, \"d\": 61, \"e\": 45}, {\"a\": 56, \"b\": 50, \"c\": 94, \"d\": 1, \"e\": 39}, {\"a\": 64, \"b\": 86, \"c\": 8, \"d\": 40, \"e\": 75}, {\"a\": 35, \"b\": 7, \"c\": 84, \"d\": 43, \"e\": 72}, {\"a\": 1, \"b\": 33, \"c\": 25, \"d\": 11, \"e\": 82}, {\"a\": 79, \"b\": 84, \"c\": 98, \"d\": 95, \"e\": 91}, {\"a\": 29, \"b\": 14, \"c\": 48, \"d\": 44, \"e\": 83}, {\"a\": 79, \"b\": 89, \"c\": 19, \"d\": 6, \"e\": 94}, {\"a\": 80, \"b\": 7, \"c\": 2, \"d\": 82, \"e\": 6}, {\"a\": 75, \"b\": 44, \"c\": 79, \"d\": 53, \"e\": 85}, {\"a\": 95, \"b\": 94, \"c\": 19, \"d\": 19, \"e\": 62}, {\"a\": 91, \"b\": 84, \"c\": 92, \"d\": 55, \"e\": 67}, {\"a\": 52, \"b\": 54, \"c\": 87, \"d\": 61, \"e\": 4}, {\"a\": 26, \"b\": 21, \"c\": 45, \"d\": 48, \"e\": 2}, {\"a\": 85, \"b\": 53, \"c\": 39, \"d\": 79, \"e\": 48}, {\"a\": 71, \"b\": 34, \"c\": 60, \"d\": 99, \"e\": 24}, {\"a\": 95, \"b\": 77, \"c\": 84, \"d\": 80, \"e\": 61}, {\"a\": 64, \"b\": 61, \"c\": 99, \"d\": 93, \"e\": 8}, {\"a\": 45, \"b\": 98, \"c\": 91, \"d\": 21, \"e\": 36}, {\"a\": 34, \"b\": 58, \"c\": 81, \"d\": 31, \"e\": 88}, {\"a\": 62, \"b\": 17, \"c\": 66, \"d\": 47, \"e\": 54}, {\"a\": 76, \"b\": 65, \"c\": 36, \"d\": 97, \"e\": 4}, {\"a\": 5, \"b\": 7, \"c\": 2, \"d\": 96, \"e\": 71}, {\"a\": 38, \"b\": 8, \"c\": 25, \"d\": 48, \"e\": 73}, {\"a\": 52, \"b\": 10, \"c\": 82, \"d\": 15, \"e\": 24}, {\"a\": 34, \"b\": 4, \"c\": 82, \"d\": 60, \"e\": 26}, {\"a\": 65, \"b\": 72, \"c\": 84, \"d\": 88, \"e\": 79}, {\"a\": 70, \"b\": 35, \"c\": 91, \"d\": 31, \"e\": 97}, {\"a\": 74, \"b\": 31, \"c\": 64, \"d\": 38, \"e\": 85}, {\"a\": 26, \"b\": 72, \"c\": 93, \"d\": 8, \"e\": 99}, {\"a\": 44, \"b\": 50, \"c\": 58, \"d\": 39, \"e\": 44}, {\"a\": 30, \"b\": 39, \"c\": 61, \"d\": 51, \"e\": 85}, {\"a\": 45, \"b\": 20, \"c\": 14, \"d\": 69, \"e\": 38}, {\"a\": 64, \"b\": 5, \"c\": 49, \"d\": 45, \"e\": 54}, {\"a\": 84, \"b\": 62, \"c\": 90, \"d\": 15, \"e\": 85}, {\"a\": 64, \"b\": 68, \"c\": 82, \"d\": 51, \"e\": 95}, {\"a\": 37, \"b\": 92, \"c\": 13, \"d\": 56, \"e\": 10}, {\"a\": 56, \"b\": 16, \"c\": 69, \"d\": 99, \"e\": 85}, {\"a\": 39, \"b\": 39, \"c\": 51, \"d\": 51, \"e\": 90}, {\"a\": 47, \"b\": 56, \"c\": 46, \"d\": 7, \"e\": 28}, {\"a\": 22, \"b\": 48, \"c\": 32, \"d\": 98, \"e\": 28}, {\"a\": 69, \"b\": 95, \"c\": 69, \"d\": 40, \"e\": 4}, {\"a\": 79, \"b\": 67, \"c\": 39, \"d\": 3, \"e\": 77}, {\"a\": 52, \"b\": 27, \"c\": 47, \"d\": 20, \"e\": 6}, {\"a\": 31, \"b\": 48, \"c\": 93, \"d\": 78, \"e\": 96}, {\"a\": 28, \"b\": 86, \"c\": 4, \"d\": 73, \"e\": 9}, {\"a\": 21, \"b\": 1, \"c\": 69, \"d\": 45, \"e\": 92}, {\"a\": 89, \"b\": 22, \"c\": 46, \"d\": 19, \"e\": 78}, {\"a\": 89, \"b\": 67, \"c\": 61, \"d\": 77, \"e\": 81}, {\"a\": 32, \"b\": 15, \"c\": 4, \"d\": 4, \"e\": 12}, {\"a\": 10, \"b\": 33, \"c\": 68, \"d\": 34, \"e\": 91}, {\"a\": 54, \"b\": 60, \"c\": 86, \"d\": 30, \"e\": 44}, {\"a\": 0, \"b\": 35, \"c\": 93, \"d\": 15, \"e\": 88}, {\"a\": 86, \"b\": 59, \"c\": 60, \"d\": 50, \"e\": 87}, {\"a\": 62, \"b\": 53, \"c\": 67, \"d\": 38, \"e\": 28}, {\"a\": 51, \"b\": 3, \"c\": 0, \"d\": 0, \"e\": 33}, {\"a\": 3, \"b\": 52, \"c\": 46, \"d\": 60, \"e\": 8}, {\"a\": 32, \"b\": 96, \"c\": 70, \"d\": 23, \"e\": 25}, {\"a\": 47, \"b\": 28, \"c\": 18, \"d\": 98, \"e\": 22}, {\"a\": 3, \"b\": 96, \"c\": 26, \"d\": 56, \"e\": 67}, {\"a\": 66, \"b\": 15, \"c\": 87, \"d\": 33, \"e\": 82}, {\"a\": 94, \"b\": 44, \"c\": 62, \"d\": 16, \"e\": 91}, {\"a\": 95, \"b\": 83, \"c\": 67, \"d\": 28, \"e\": 28}, {\"a\": 95, \"b\": 66, \"c\": 2, \"d\": 52, \"e\": 52}, {\"a\": 75, \"b\": 87, \"c\": 63, \"d\": 40, \"e\": 17}, {\"a\": 78, \"b\": 7, \"c\": 81, \"d\": 76, \"e\": 55}, {\"a\": 97, \"b\": 46, \"c\": 25, \"d\": 59, \"e\": 41}, {\"a\": 46, \"b\": 18, \"c\": 29, \"d\": 40, \"e\": 31}, {\"a\": 88, \"b\": 47, \"c\": 33, \"d\": 37, \"e\": 37}, {\"a\": 89, \"b\": 27, \"c\": 98, \"d\": 53, \"e\": 99}, {\"a\": 92, \"b\": 12, \"c\": 49, \"d\": 19, \"e\": 56}, {\"a\": 47, \"b\": 64, \"c\": 36, \"d\": 76, \"e\": 51}, {\"a\": 17, \"b\": 71, \"c\": 58, \"d\": 49, \"e\": 68}, {\"a\": 55, \"b\": 76, \"c\": 3, \"d\": 40, \"e\": 73}, {\"a\": 7, \"b\": 93, \"c\": 21, \"d\": 88, \"e\": 76}, {\"a\": 51, \"b\": 60, \"c\": 1, \"d\": 27, \"e\": 42}, {\"a\": 81, \"b\": 99, \"c\": 75, \"d\": 72, \"e\": 27}, {\"a\": 96, \"b\": 81, \"c\": 86, \"d\": 26, \"e\": 58}, {\"a\": 57, \"b\": 5, \"c\": 87, \"d\": 95, \"e\": 49}, {\"a\": 59, \"b\": 18, \"c\": 2, \"d\": 15, \"e\": 96}, {\"a\": 43, \"b\": 47, \"c\": 39, \"d\": 7, \"e\": 41}, {\"a\": 37, \"b\": 67, \"c\": 99, \"d\": 66, \"e\": 82}, {\"a\": 49, \"b\": 24, \"c\": 96, \"d\": 74, \"e\": 12}, {\"a\": 7, \"b\": 20, \"c\": 74, \"d\": 96, \"e\": 16}, {\"a\": 79, \"b\": 22, \"c\": 59, \"d\": 79, \"e\": 11}, {\"a\": 46, \"b\": 10, \"c\": 74, \"d\": 66, \"e\": 48}, {\"a\": 67, \"b\": 43, \"c\": 28, \"d\": 5, \"e\": 9}, {\"a\": 1, \"b\": 9, \"c\": 21, \"d\": 40, \"e\": 73}, {\"a\": 80, \"b\": 3, \"c\": 7, \"d\": 85, \"e\": 72}, {\"a\": 86, \"b\": 99, \"c\": 69, \"d\": 3, \"e\": 87}, {\"a\": 32, \"b\": 13, \"c\": 93, \"d\": 82, \"e\": 20}, {\"a\": 24, \"b\": 59, \"c\": 53, \"d\": 4, \"e\": 23}, {\"a\": 28, \"b\": 15, \"c\": 47, \"d\": 42, \"e\": 12}, {\"a\": 4, \"b\": 67, \"c\": 40, \"d\": 67, \"e\": 68}, {\"a\": 70, \"b\": 56, \"c\": 89, \"d\": 95, \"e\": 6}, {\"a\": 56, \"b\": 38, \"c\": 40, \"d\": 1, \"e\": 28}, {\"a\": 55, \"b\": 57, \"c\": 94, \"d\": 16, \"e\": 9}, {\"a\": 79, \"b\": 48, \"c\": 16, \"d\": 60, \"e\": 87}, {\"a\": 63, \"b\": 79, \"c\": 28, \"d\": 49, \"e\": 0}, {\"a\": 30, \"b\": 51, \"c\": 88, \"d\": 31, \"e\": 3}, {\"a\": 90, \"b\": 87, \"c\": 63, \"d\": 43, \"e\": 86}, {\"a\": 8, \"b\": 64, \"c\": 73, \"d\": 95, \"e\": 28}, {\"a\": 24, \"b\": 43, \"c\": 37, \"d\": 80, \"e\": 96}, {\"a\": 19, \"b\": 59, \"c\": 14, \"d\": 35, \"e\": 63}, {\"a\": 10, \"b\": 55, \"c\": 12, \"d\": 6, \"e\": 49}, {\"a\": 19, \"b\": 68, \"c\": 23, \"d\": 66, \"e\": 32}, {\"a\": 63, \"b\": 33, \"c\": 35, \"d\": 90, \"e\": 31}, {\"a\": 80, \"b\": 97, \"c\": 31, \"d\": 40, \"e\": 12}, {\"a\": 50, \"b\": 86, \"c\": 56, \"d\": 53, \"e\": 94}, {\"a\": 51, \"b\": 17, \"c\": 63, \"d\": 16, \"e\": 88}, {\"a\": 50, \"b\": 93, \"c\": 15, \"d\": 33, \"e\": 69}, {\"a\": 48, \"b\": 56, \"c\": 38, \"d\": 18, \"e\": 74}, {\"a\": 85, \"b\": 24, \"c\": 11, \"d\": 77, \"e\": 28}, {\"a\": 49, \"b\": 77, \"c\": 75, \"d\": 34, \"e\": 23}, {\"a\": 52, \"b\": 21, \"c\": 46, \"d\": 71, \"e\": 69}, {\"a\": 69, \"b\": 98, \"c\": 64, \"d\": 36, \"e\": 17}, {\"a\": 6, \"b\": 55, \"c\": 95, \"d\": 14, \"e\": 93}, {\"a\": 41, \"b\": 14, \"c\": 22, \"d\": 4, \"e\": 94}, {\"a\": 23, \"b\": 60, \"c\": 91, \"d\": 9, \"e\": 0}, {\"a\": 2, \"b\": 44, \"c\": 7, \"d\": 96, \"e\": 59}, {\"a\": 26, \"b\": 69, \"c\": 12, \"d\": 13, \"e\": 13}, {\"a\": 5, \"b\": 58, \"c\": 88, \"d\": 78, \"e\": 39}, {\"a\": 63, \"b\": 5, \"c\": 75, \"d\": 87, \"e\": 73}, {\"a\": 55, \"b\": 1, \"c\": 20, \"d\": 16, \"e\": 20}, {\"a\": 5, \"b\": 34, \"c\": 49, \"d\": 5, \"e\": 29}, {\"a\": 4, \"b\": 48, \"c\": 86, \"d\": 99, \"e\": 24}, {\"a\": 38, \"b\": 61, \"c\": 99, \"d\": 45, \"e\": 59}, {\"a\": 86, \"b\": 82, \"c\": 83, \"d\": 61, \"e\": 27}, {\"a\": 2, \"b\": 49, \"c\": 53, \"d\": 37, \"e\": 46}, {\"a\": 46, \"b\": 26, \"c\": 37, \"d\": 90, \"e\": 33}, {\"a\": 17, \"b\": 73, \"c\": 79, \"d\": 57, \"e\": 43}, {\"a\": 12, \"b\": 17, \"c\": 34, \"d\": 55, \"e\": 92}, {\"a\": 61, \"b\": 54, \"c\": 40, \"d\": 73, \"e\": 21}, {\"a\": 3, \"b\": 30, \"c\": 11, \"d\": 7, \"e\": 54}, {\"a\": 88, \"b\": 37, \"c\": 80, \"d\": 45, \"e\": 2}, {\"a\": 54, \"b\": 89, \"c\": 86, \"d\": 48, \"e\": 7}, {\"a\": 2, \"b\": 13, \"c\": 53, \"d\": 10, \"e\": 51}, {\"a\": 5, \"b\": 80, \"c\": 90, \"d\": 22, \"e\": 38}, {\"a\": 23, \"b\": 42, \"c\": 64, \"d\": 9, \"e\": 27}, {\"a\": 82, \"b\": 10, \"c\": 67, \"d\": 55, \"e\": 21}, {\"a\": 32, \"b\": 55, \"c\": 75, \"d\": 99, \"e\": 16}, {\"a\": 65, \"b\": 19, \"c\": 91, \"d\": 29, \"e\": 36}, {\"a\": 16, \"b\": 70, \"c\": 17, \"d\": 61, \"e\": 22}, {\"a\": 5, \"b\": 17, \"c\": 76, \"d\": 97, \"e\": 89}, {\"a\": 74, \"b\": 59, \"c\": 44, \"d\": 87, \"e\": 99}, {\"a\": 93, \"b\": 19, \"c\": 96, \"d\": 41, \"e\": 16}, {\"a\": 34, \"b\": 35, \"c\": 80, \"d\": 88, \"e\": 86}, {\"a\": 6, \"b\": 53, \"c\": 36, \"d\": 89, \"e\": 42}, {\"a\": 82, \"b\": 64, \"c\": 13, \"d\": 83, \"e\": 29}, {\"a\": 17, \"b\": 25, \"c\": 20, \"d\": 82, \"e\": 54}, {\"a\": 27, \"b\": 0, \"c\": 85, \"d\": 35, \"e\": 72}, {\"a\": 78, \"b\": 30, \"c\": 35, \"d\": 86, \"e\": 33}, {\"a\": 13, \"b\": 74, \"c\": 64, \"d\": 1, \"e\": 24}, {\"a\": 44, \"b\": 72, \"c\": 68, \"d\": 71, \"e\": 97}, {\"a\": 95, \"b\": 90, \"c\": 3, \"d\": 97, \"e\": 49}, {\"a\": 75, \"b\": 96, \"c\": 47, \"d\": 95, \"e\": 65}, {\"a\": 95, \"b\": 30, \"c\": 16, \"d\": 94, \"e\": 86}, {\"a\": 2, \"b\": 81, \"c\": 5, \"d\": 74, \"e\": 76}, {\"a\": 29, \"b\": 74, \"c\": 8, \"d\": 79, \"e\": 4}, {\"a\": 87, \"b\": 84, \"c\": 4, \"d\": 17, \"e\": 92}, {\"a\": 75, \"b\": 69, \"c\": 80, \"d\": 72, \"e\": 63}, {\"a\": 30, \"b\": 40, \"c\": 81, \"d\": 20, \"e\": 40}, {\"a\": 15, \"b\": 86, \"c\": 72, \"d\": 30, \"e\": 42}, {\"a\": 27, \"b\": 1, \"c\": 64, \"d\": 56, \"e\": 41}, {\"a\": 98, \"b\": 2, \"c\": 49, \"d\": 36, \"e\": 15}, {\"a\": 81, \"b\": 88, \"c\": 28, \"d\": 14, \"e\": 59}, {\"a\": 3, \"b\": 77, \"c\": 7, \"d\": 74, \"e\": 40}, {\"a\": 88, \"b\": 94, \"c\": 39, \"d\": 26, \"e\": 51}, {\"a\": 40, \"b\": 1, \"c\": 4, \"d\": 44, \"e\": 38}, {\"a\": 6, \"b\": 24, \"c\": 45, \"d\": 2, \"e\": 50}, {\"a\": 25, \"b\": 82, \"c\": 28, \"d\": 48, \"e\": 59}, {\"a\": 73, \"b\": 80, \"c\": 70, \"d\": 72, \"e\": 50}, {\"a\": 54, \"b\": 10, \"c\": 8, \"d\": 94, \"e\": 81}, {\"a\": 53, \"b\": 11, \"c\": 61, \"d\": 83, \"e\": 51}, {\"a\": 41, \"b\": 58, \"c\": 5, \"d\": 46, \"e\": 94}, {\"a\": 93, \"b\": 88, \"c\": 71, \"d\": 11, \"e\": 50}, {\"a\": 49, \"b\": 62, \"c\": 15, \"d\": 12, \"e\": 28}, {\"a\": 1, \"b\": 93, \"c\": 13, \"d\": 98, \"e\": 50}, {\"a\": 35, \"b\": 61, \"c\": 56, \"d\": 3, \"e\": 18}, {\"a\": 43, \"b\": 69, \"c\": 53, \"d\": 63, \"e\": 98}, {\"a\": 28, \"b\": 36, \"c\": 25, \"d\": 68, \"e\": 4}, {\"a\": 62, \"b\": 5, \"c\": 70, \"d\": 59, \"e\": 96}, {\"a\": 45, \"b\": 0, \"c\": 57, \"d\": 13, \"e\": 30}, {\"a\": 56, \"b\": 68, \"c\": 83, \"d\": 90, \"e\": 40}, {\"a\": 10, \"b\": 87, \"c\": 46, \"d\": 2, \"e\": 97}, {\"a\": 64, \"b\": 94, \"c\": 25, \"d\": 72, \"e\": 52}, {\"a\": 60, \"b\": 46, \"c\": 67, \"d\": 14, \"e\": 60}, {\"a\": 28, \"b\": 92, \"c\": 80, \"d\": 74, \"e\": 36}, {\"a\": 3, \"b\": 62, \"c\": 56, \"d\": 16, \"e\": 52}, {\"a\": 78, \"b\": 58, \"c\": 85, \"d\": 75, \"e\": 49}, {\"a\": 82, \"b\": 66, \"c\": 29, \"d\": 3, \"e\": 82}, {\"a\": 42, \"b\": 81, \"c\": 59, \"d\": 66, \"e\": 72}, {\"a\": 83, \"b\": 74, \"c\": 18, \"d\": 40, \"e\": 38}, {\"a\": 8, \"b\": 17, \"c\": 98, \"d\": 77, \"e\": 68}, {\"a\": 29, \"b\": 30, \"c\": 68, \"d\": 88, \"e\": 83}, {\"a\": 88, \"b\": 45, \"c\": 83, \"d\": 54, \"e\": 41}, {\"a\": 91, \"b\": 15, \"c\": 62, \"d\": 76, \"e\": 53}, {\"a\": 49, \"b\": 14, \"c\": 31, \"d\": 58, \"e\": 71}, {\"a\": 8, \"b\": 36, \"c\": 85, \"d\": 54, \"e\": 24}, {\"a\": 8, \"b\": 63, \"c\": 8, \"d\": 77, \"e\": 22}, {\"a\": 34, \"b\": 8, \"c\": 69, \"d\": 50, \"e\": 64}, {\"a\": 92, \"b\": 30, \"c\": 2, \"d\": 71, \"e\": 95}, {\"a\": 64, \"b\": 48, \"c\": 35, \"d\": 89, \"e\": 49}, {\"a\": 20, \"b\": 31, \"c\": 15, \"d\": 62, \"e\": 98}, {\"a\": 60, \"b\": 2, \"c\": 36, \"d\": 9, \"e\": 81}, {\"a\": 56, \"b\": 19, \"c\": 94, \"d\": 84, \"e\": 21}, {\"a\": 30, \"b\": 22, \"c\": 11, \"d\": 72, \"e\": 4}, {\"a\": 95, \"b\": 98, \"c\": 12, \"d\": 90, \"e\": 70}, {\"a\": 61, \"b\": 97, \"c\": 97, \"d\": 28, \"e\": 47}, {\"a\": 45, \"b\": 92, \"c\": 96, \"d\": 4, \"e\": 59}, {\"a\": 90, \"b\": 64, \"c\": 65, \"d\": 78, \"e\": 73}, {\"a\": 26, \"b\": 91, \"c\": 13, \"d\": 2, \"e\": 12}, {\"a\": 90, \"b\": 16, \"c\": 27, \"d\": 62, \"e\": 69}, {\"a\": 39, \"b\": 9, \"c\": 68, \"d\": 7, \"e\": 55}, {\"a\": 92, \"b\": 36, \"c\": 57, \"d\": 48, \"e\": 53}, {\"a\": 68, \"b\": 62, \"c\": 93, \"d\": 11, \"e\": 36}, {\"a\": 89, \"b\": 26, \"c\": 25, \"d\": 87, \"e\": 77}, {\"a\": 47, \"b\": 3, \"c\": 34, \"d\": 68, \"e\": 14}, {\"a\": 71, \"b\": 17, \"c\": 81, \"d\": 20, \"e\": 71}, {\"a\": 98, \"b\": 42, \"c\": 2, \"d\": 58, \"e\": 22}, {\"a\": 89, \"b\": 63, \"c\": 9, \"d\": 38, \"e\": 30}, {\"a\": 80, \"b\": 34, \"c\": 27, \"d\": 21, \"e\": 51}, {\"a\": 68, \"b\": 11, \"c\": 77, \"d\": 26, \"e\": 39}, {\"a\": 80, \"b\": 96, \"c\": 54, \"d\": 39, \"e\": 37}, {\"a\": 80, \"b\": 83, \"c\": 8, \"d\": 38, \"e\": 63}, {\"a\": 20, \"b\": 49, \"c\": 94, \"d\": 58, \"e\": 81}, {\"a\": 62, \"b\": 76, \"c\": 80, \"d\": 22, \"e\": 66}, {\"a\": 99, \"b\": 40, \"c\": 28, \"d\": 33, \"e\": 69}, {\"a\": 50, \"b\": 42, \"c\": 33, \"d\": 92, \"e\": 78}, {\"a\": 69, \"b\": 91, \"c\": 48, \"d\": 18, \"e\": 52}, {\"a\": 27, \"b\": 15, \"c\": 48, \"d\": 92, \"e\": 61}, {\"a\": 56, \"b\": 83, \"c\": 5, \"d\": 51, \"e\": 65}, {\"a\": 80, \"b\": 44, \"c\": 41, \"d\": 44, \"e\": 76}, {\"a\": 21, \"b\": 26, \"c\": 47, \"d\": 40, \"e\": 34}, {\"a\": 19, \"b\": 10, \"c\": 21, \"d\": 26, \"e\": 88}, {\"a\": 77, \"b\": 76, \"c\": 4, \"d\": 3, \"e\": 58}, {\"a\": 37, \"b\": 9, \"c\": 75, \"d\": 74, \"e\": 90}, {\"a\": 27, \"b\": 39, \"c\": 89, \"d\": 46, \"e\": 47}, {\"a\": 22, \"b\": 65, \"c\": 70, \"d\": 73, \"e\": 41}, {\"a\": 84, \"b\": 89, \"c\": 26, \"d\": 4, \"e\": 0}, {\"a\": 66, \"b\": 76, \"c\": 10, \"d\": 76, \"e\": 8}, {\"a\": 0, \"b\": 22, \"c\": 20, \"d\": 22, \"e\": 24}, {\"a\": 24, \"b\": 34, \"c\": 63, \"d\": 29, \"e\": 34}, {\"a\": 29, \"b\": 86, \"c\": 17, \"d\": 80, \"e\": 50}, {\"a\": 97, \"b\": 7, \"c\": 33, \"d\": 14, \"e\": 50}, {\"a\": 96, \"b\": 79, \"c\": 87, \"d\": 3, \"e\": 27}, {\"a\": 84, \"b\": 28, \"c\": 22, \"d\": 4, \"e\": 91}, {\"a\": 9, \"b\": 73, \"c\": 48, \"d\": 44, \"e\": 0}, {\"a\": 50, \"b\": 11, \"c\": 17, \"d\": 54, \"e\": 98}, {\"a\": 48, \"b\": 93, \"c\": 29, \"d\": 73, \"e\": 82}, {\"a\": 33, \"b\": 72, \"c\": 73, \"d\": 14, \"e\": 57}, {\"a\": 8, \"b\": 94, \"c\": 1, \"d\": 95, \"e\": 50}, {\"a\": 71, \"b\": 75, \"c\": 49, \"d\": 95, \"e\": 76}, {\"a\": 82, \"b\": 90, \"c\": 64, \"d\": 59, \"e\": 71}, {\"a\": 1, \"b\": 8, \"c\": 95, \"d\": 55, \"e\": 56}, {\"a\": 80, \"b\": 36, \"c\": 23, \"d\": 25, \"e\": 64}, {\"a\": 98, \"b\": 13, \"c\": 63, \"d\": 5, \"e\": 60}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 11,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "alt.Chart(rand_df2).mark_circle().encode(\n",
    "    x = \"a\",\n",
    "    y = \"b\",\n",
    "    color = \"c\",\n",
    "    size = \"d\",\n",
    "    opacity = \"e\",\n",
    "    tooltip = [\"a\",\"b\",\"c\",\"d\",\"e\"],\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "848f3d9a",
   "metadata": {},
   "source": [
    "```{admonition} Exercise\n",
    ":class: tip\n",
    "I don't like the `d` and `e` parts of the legend.  Can you figure out how to remove them, by mimicking an example from the [documentation](https://altair-viz.github.io/user_guide/customization.html?highlight=legend#adjusting-the-legend)?\n",
    "```"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "6319ef5a",
   "metadata": {},
   "source": [
    "It's hard to recognize the opacity in the above example.  Let's change the DataFrame so that all the points to the left of $a = 40$ are only 15% transparent, and the rest of the points are 100% opaque.  We add a `scale=None` to the opacity channel so we have complete control over the opacity."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 12,
   "id": "0e86e329",
   "metadata": {},
   "outputs": [],
   "source": [
    "rand_df2[\"e\"] = 1\n",
    "rand_df2.loc[(rand_df2[\"a\"] < 40),\"e\"] = 0.15"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 13,
   "id": "349adfe8",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-c93cced0074e41f6afbb4da5e84ed0d5\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-c93cced0074e41f6afbb4da5e84ed0d5\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-c93cced0074e41f6afbb4da5e84ed0d5\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-2ecf181441529ef9a19cabbec462b9cb\"}, \"mark\": \"circle\", \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"c\"}, \"opacity\": {\"type\": \"quantitative\", \"field\": \"e\", \"scale\": null}, \"size\": {\"type\": \"quantitative\", \"field\": \"d\"}, \"tooltip\": [{\"type\": \"quantitative\", \"field\": \"a\"}, {\"type\": \"quantitative\", \"field\": \"b\"}, {\"type\": \"quantitative\", \"field\": \"c\"}, {\"type\": \"quantitative\", \"field\": \"d\"}, {\"type\": \"quantitative\", \"field\": \"e\"}], \"x\": {\"type\": \"quantitative\", \"field\": \"a\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"b\"}}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-2ecf181441529ef9a19cabbec462b9cb\": [{\"a\": 72, \"b\": 34, \"c\": 3, \"d\": 39, \"e\": 1.0}, {\"a\": 47, \"b\": 85, \"c\": 85, \"d\": 82, \"e\": 1.0}, {\"a\": 79, \"b\": 40, \"c\": 81, \"d\": 2, \"e\": 1.0}, {\"a\": 89, \"b\": 93, \"c\": 41, \"d\": 19, \"e\": 1.0}, {\"a\": 61, \"b\": 15, \"c\": 54, \"d\": 21, \"e\": 1.0}, {\"a\": 45, \"b\": 62, \"c\": 12, \"d\": 41, \"e\": 1.0}, {\"a\": 40, \"b\": 55, \"c\": 17, \"d\": 0, \"e\": 1.0}, {\"a\": 39, \"b\": 93, \"c\": 28, \"d\": 61, \"e\": 0.15}, {\"a\": 98, \"b\": 55, \"c\": 72, \"d\": 88, \"e\": 1.0}, {\"a\": 75, \"b\": 86, \"c\": 39, \"d\": 85, \"e\": 1.0}, {\"a\": 8, \"b\": 8, \"c\": 77, \"d\": 99, \"e\": 0.15}, {\"a\": 40, \"b\": 90, \"c\": 28, \"d\": 57, \"e\": 1.0}, {\"a\": 64, \"b\": 20, \"c\": 85, \"d\": 54, \"e\": 1.0}, {\"a\": 17, \"b\": 55, \"c\": 63, \"d\": 61, \"e\": 0.15}, {\"a\": 83, \"b\": 2, \"c\": 45, \"d\": 84, \"e\": 1.0}, {\"a\": 46, \"b\": 67, \"c\": 67, \"d\": 70, \"e\": 1.0}, {\"a\": 29, \"b\": 35, \"c\": 89, \"d\": 44, \"e\": 0.15}, {\"a\": 67, \"b\": 21, \"c\": 88, \"d\": 64, \"e\": 1.0}, {\"a\": 71, \"b\": 13, \"c\": 94, \"d\": 33, \"e\": 1.0}, {\"a\": 19, \"b\": 38, \"c\": 15, \"d\": 13, \"e\": 0.15}, {\"a\": 73, \"b\": 8, \"c\": 97, \"d\": 23, \"e\": 1.0}, {\"a\": 14, \"b\": 77, \"c\": 41, \"d\": 99, \"e\": 0.15}, {\"a\": 9, \"b\": 22, \"c\": 64, \"d\": 96, \"e\": 0.15}, {\"a\": 94, \"b\": 15, \"c\": 24, \"d\": 72, \"e\": 1.0}, {\"a\": 90, \"b\": 99, \"c\": 59, \"d\": 39, \"e\": 1.0}, {\"a\": 99, \"b\": 55, \"c\": 2, \"d\": 38, \"e\": 1.0}, {\"a\": 57, \"b\": 95, \"c\": 64, \"d\": 62, \"e\": 1.0}, {\"a\": 67, \"b\": 97, \"c\": 42, \"d\": 12, \"e\": 1.0}, {\"a\": 33, \"b\": 76, \"c\": 61, \"d\": 67, \"e\": 0.15}, {\"a\": 37, \"b\": 47, \"c\": 27, \"d\": 31, \"e\": 0.15}, {\"a\": 91, \"b\": 62, \"c\": 35, \"d\": 97, \"e\": 1.0}, {\"a\": 77, \"b\": 21, \"c\": 28, \"d\": 45, \"e\": 1.0}, {\"a\": 57, \"b\": 87, \"c\": 20, \"d\": 51, \"e\": 1.0}, {\"a\": 52, \"b\": 42, \"c\": 78, \"d\": 85, \"e\": 1.0}, {\"a\": 94, \"b\": 35, \"c\": 86, \"d\": 55, \"e\": 1.0}, {\"a\": 26, \"b\": 58, \"c\": 38, \"d\": 14, \"e\": 0.15}, {\"a\": 17, \"b\": 36, \"c\": 49, \"d\": 33, \"e\": 0.15}, {\"a\": 48, \"b\": 41, \"c\": 53, \"d\": 54, \"e\": 1.0}, {\"a\": 16, \"b\": 34, \"c\": 46, \"d\": 30, \"e\": 0.15}, {\"a\": 10, \"b\": 18, \"c\": 38, \"d\": 89, \"e\": 0.15}, {\"a\": 37, \"b\": 96, \"c\": 75, \"d\": 22, \"e\": 0.15}, {\"a\": 56, \"b\": 81, \"c\": 13, \"d\": 91, \"e\": 1.0}, {\"a\": 71, \"b\": 46, \"c\": 78, \"d\": 83, \"e\": 1.0}, {\"a\": 73, \"b\": 75, \"c\": 19, \"d\": 85, \"e\": 1.0}, {\"a\": 27, \"b\": 18, \"c\": 71, \"d\": 22, \"e\": 0.15}, {\"a\": 53, \"b\": 6, \"c\": 8, \"d\": 38, \"e\": 1.0}, {\"a\": 59, \"b\": 69, \"c\": 74, \"d\": 31, \"e\": 1.0}, {\"a\": 65, \"b\": 77, \"c\": 73, \"d\": 67, \"e\": 1.0}, {\"a\": 9, \"b\": 71, \"c\": 57, \"d\": 61, \"e\": 0.15}, {\"a\": 74, \"b\": 37, \"c\": 78, \"d\": 84, \"e\": 1.0}, {\"a\": 64, \"b\": 42, \"c\": 61, \"d\": 6, \"e\": 1.0}, {\"a\": 3, \"b\": 8, \"c\": 85, \"d\": 68, \"e\": 0.15}, {\"a\": 96, \"b\": 65, \"c\": 49, \"d\": 65, \"e\": 1.0}, {\"a\": 75, \"b\": 33, \"c\": 96, \"d\": 3, \"e\": 1.0}, {\"a\": 59, \"b\": 98, \"c\": 96, \"d\": 40, \"e\": 1.0}, {\"a\": 14, \"b\": 72, \"c\": 28, \"d\": 25, \"e\": 0.15}, {\"a\": 76, \"b\": 71, \"c\": 88, \"d\": 34, \"e\": 1.0}, {\"a\": 51, \"b\": 9, \"c\": 43, \"d\": 55, \"e\": 1.0}, {\"a\": 68, \"b\": 83, \"c\": 80, \"d\": 67, \"e\": 1.0}, {\"a\": 57, \"b\": 70, \"c\": 59, \"d\": 31, \"e\": 1.0}, {\"a\": 70, \"b\": 31, \"c\": 49, \"d\": 0, \"e\": 1.0}, {\"a\": 39, \"b\": 45, \"c\": 51, \"d\": 45, \"e\": 0.15}, {\"a\": 54, \"b\": 71, \"c\": 95, \"d\": 45, \"e\": 1.0}, {\"a\": 94, \"b\": 95, \"c\": 13, \"d\": 66, \"e\": 1.0}, {\"a\": 96, \"b\": 8, \"c\": 2, \"d\": 74, \"e\": 1.0}, {\"a\": 7, \"b\": 36, \"c\": 72, \"d\": 71, \"e\": 0.15}, {\"a\": 20, \"b\": 76, \"c\": 52, \"d\": 5, \"e\": 0.15}, {\"a\": 17, \"b\": 38, \"c\": 13, \"d\": 57, \"e\": 0.15}, {\"a\": 29, \"b\": 17, \"c\": 48, \"d\": 88, \"e\": 0.15}, {\"a\": 26, \"b\": 73, \"c\": 46, \"d\": 23, \"e\": 0.15}, {\"a\": 53, \"b\": 14, \"c\": 81, \"d\": 14, \"e\": 1.0}, {\"a\": 25, \"b\": 80, \"c\": 97, \"d\": 81, \"e\": 0.15}, {\"a\": 44, \"b\": 30, \"c\": 74, \"d\": 46, \"e\": 1.0}, {\"a\": 1, \"b\": 87, \"c\": 27, \"d\": 47, \"e\": 0.15}, {\"a\": 27, \"b\": 90, \"c\": 5, \"d\": 11, \"e\": 0.15}, {\"a\": 98, \"b\": 52, \"c\": 52, \"d\": 5, \"e\": 1.0}, {\"a\": 94, \"b\": 49, \"c\": 32, \"d\": 54, \"e\": 1.0}, {\"a\": 76, \"b\": 21, \"c\": 14, \"d\": 87, \"e\": 1.0}, {\"a\": 33, \"b\": 8, \"c\": 22, \"d\": 95, \"e\": 0.15}, {\"a\": 57, \"b\": 91, \"c\": 34, \"d\": 63, \"e\": 1.0}, {\"a\": 96, \"b\": 26, \"c\": 5, \"d\": 99, \"e\": 1.0}, {\"a\": 8, \"b\": 87, \"c\": 77, \"d\": 59, \"e\": 0.15}, {\"a\": 93, \"b\": 56, \"c\": 48, \"d\": 80, \"e\": 1.0}, {\"a\": 11, \"b\": 32, \"c\": 47, \"d\": 6, \"e\": 0.15}, {\"a\": 36, \"b\": 57, \"c\": 69, \"d\": 4, \"e\": 0.15}, {\"a\": 86, \"b\": 78, \"c\": 20, \"d\": 21, \"e\": 1.0}, {\"a\": 87, \"b\": 81, \"c\": 65, \"d\": 80, \"e\": 1.0}, {\"a\": 10, \"b\": 23, \"c\": 52, \"d\": 16, \"e\": 0.15}, {\"a\": 20, \"b\": 38, \"c\": 25, \"d\": 81, \"e\": 0.15}, {\"a\": 80, \"b\": 91, \"c\": 91, \"d\": 12, \"e\": 1.0}, {\"a\": 28, \"b\": 9, \"c\": 75, \"d\": 42, \"e\": 0.15}, {\"a\": 72, \"b\": 43, \"c\": 74, \"d\": 72, \"e\": 1.0}, {\"a\": 29, \"b\": 42, \"c\": 12, \"d\": 24, \"e\": 0.15}, {\"a\": 65, \"b\": 96, \"c\": 2, \"d\": 59, \"e\": 1.0}, {\"a\": 24, \"b\": 55, \"c\": 72, \"d\": 7, \"e\": 0.15}, {\"a\": 58, \"b\": 11, \"c\": 19, \"d\": 87, \"e\": 1.0}, {\"a\": 62, \"b\": 59, \"c\": 54, \"d\": 23, \"e\": 1.0}, {\"a\": 21, \"b\": 43, \"c\": 92, \"d\": 18, \"e\": 0.15}, {\"a\": 48, \"b\": 62, \"c\": 44, \"d\": 90, \"e\": 1.0}, {\"a\": 40, \"b\": 14, \"c\": 0, \"d\": 65, \"e\": 1.0}, {\"a\": 57, \"b\": 57, \"c\": 46, \"d\": 40, \"e\": 1.0}, {\"a\": 88, \"b\": 51, \"c\": 26, \"d\": 69, \"e\": 1.0}, {\"a\": 94, \"b\": 22, \"c\": 98, \"d\": 31, \"e\": 1.0}, {\"a\": 32, \"b\": 57, \"c\": 40, \"d\": 74, \"e\": 0.15}, {\"a\": 55, \"b\": 18, \"c\": 44, \"d\": 1, \"e\": 1.0}, {\"a\": 28, \"b\": 73, \"c\": 43, \"d\": 28, \"e\": 0.15}, {\"a\": 87, \"b\": 61, \"c\": 44, \"d\": 90, \"e\": 1.0}, {\"a\": 30, \"b\": 50, \"c\": 46, \"d\": 7, \"e\": 0.15}, {\"a\": 4, \"b\": 96, \"c\": 5, \"d\": 50, \"e\": 0.15}, {\"a\": 73, \"b\": 45, \"c\": 92, \"d\": 18, \"e\": 1.0}, {\"a\": 30, \"b\": 50, \"c\": 10, \"d\": 96, \"e\": 0.15}, {\"a\": 33, \"b\": 87, \"c\": 97, \"d\": 9, \"e\": 0.15}, {\"a\": 59, \"b\": 6, \"c\": 42, \"d\": 58, \"e\": 1.0}, {\"a\": 44, \"b\": 49, \"c\": 20, \"d\": 85, \"e\": 1.0}, {\"a\": 8, \"b\": 93, \"c\": 52, \"d\": 31, \"e\": 0.15}, {\"a\": 88, \"b\": 46, \"c\": 70, \"d\": 52, \"e\": 1.0}, {\"a\": 64, \"b\": 64, \"c\": 23, \"d\": 57, \"e\": 1.0}, {\"a\": 44, \"b\": 52, \"c\": 22, \"d\": 66, \"e\": 1.0}, {\"a\": 36, \"b\": 18, \"c\": 1, \"d\": 6, \"e\": 0.15}, {\"a\": 33, \"b\": 11, \"c\": 54, \"d\": 88, \"e\": 0.15}, {\"a\": 62, \"b\": 68, \"c\": 78, \"d\": 76, \"e\": 1.0}, {\"a\": 27, \"b\": 31, \"c\": 66, \"d\": 57, \"e\": 0.15}, {\"a\": 97, \"b\": 15, \"c\": 61, \"d\": 35, \"e\": 1.0}, {\"a\": 66, \"b\": 33, \"c\": 95, \"d\": 4, \"e\": 1.0}, {\"a\": 40, \"b\": 37, \"c\": 43, \"d\": 58, \"e\": 1.0}, {\"a\": 6, \"b\": 47, \"c\": 96, \"d\": 87, \"e\": 0.15}, {\"a\": 26, \"b\": 42, \"c\": 57, \"d\": 25, \"e\": 0.15}, {\"a\": 81, \"b\": 17, \"c\": 82, \"d\": 1, \"e\": 1.0}, {\"a\": 95, \"b\": 97, \"c\": 22, \"d\": 30, \"e\": 1.0}, {\"a\": 32, \"b\": 58, \"c\": 25, \"d\": 86, \"e\": 0.15}, {\"a\": 16, \"b\": 59, \"c\": 3, \"d\": 67, \"e\": 0.15}, {\"a\": 75, \"b\": 56, \"c\": 96, \"d\": 93, \"e\": 1.0}, {\"a\": 19, \"b\": 19, \"c\": 40, \"d\": 34, \"e\": 0.15}, {\"a\": 3, \"b\": 3, \"c\": 99, \"d\": 79, \"e\": 0.15}, {\"a\": 53, \"b\": 6, \"c\": 93, \"d\": 83, \"e\": 1.0}, {\"a\": 74, \"b\": 23, \"c\": 34, \"d\": 70, \"e\": 1.0}, {\"a\": 11, \"b\": 52, \"c\": 90, \"d\": 17, \"e\": 0.15}, {\"a\": 98, \"b\": 53, \"c\": 44, \"d\": 53, \"e\": 1.0}, {\"a\": 56, \"b\": 59, \"c\": 34, \"d\": 41, \"e\": 1.0}, {\"a\": 90, \"b\": 15, \"c\": 76, \"d\": 84, \"e\": 1.0}, {\"a\": 54, \"b\": 83, \"c\": 4, \"d\": 23, \"e\": 1.0}, {\"a\": 48, \"b\": 89, \"c\": 87, \"d\": 80, \"e\": 1.0}, {\"a\": 61, \"b\": 52, \"c\": 35, \"d\": 37, \"e\": 1.0}, {\"a\": 48, \"b\": 14, \"c\": 83, \"d\": 5, \"e\": 1.0}, {\"a\": 39, \"b\": 78, \"c\": 85, \"d\": 70, \"e\": 0.15}, {\"a\": 47, \"b\": 48, \"c\": 72, \"d\": 57, \"e\": 1.0}, {\"a\": 62, \"b\": 49, \"c\": 85, \"d\": 68, \"e\": 1.0}, {\"a\": 7, \"b\": 40, \"c\": 98, \"d\": 9, \"e\": 0.15}, {\"a\": 44, \"b\": 49, \"c\": 82, \"d\": 36, \"e\": 1.0}, {\"a\": 21, \"b\": 68, \"c\": 76, \"d\": 11, \"e\": 0.15}, {\"a\": 31, \"b\": 53, \"c\": 0, \"d\": 46, \"e\": 0.15}, {\"a\": 51, \"b\": 3, \"c\": 53, \"d\": 12, \"e\": 1.0}, {\"a\": 30, \"b\": 30, \"c\": 88, \"d\": 88, \"e\": 0.15}, {\"a\": 18, \"b\": 42, \"c\": 39, \"d\": 0, \"e\": 0.15}, {\"a\": 78, \"b\": 1, \"c\": 9, \"d\": 51, \"e\": 1.0}, {\"a\": 64, \"b\": 20, \"c\": 52, \"d\": 25, \"e\": 1.0}, {\"a\": 76, \"b\": 52, \"c\": 92, \"d\": 26, \"e\": 1.0}, {\"a\": 50, \"b\": 52, \"c\": 96, \"d\": 89, \"e\": 1.0}, {\"a\": 33, \"b\": 41, \"c\": 42, \"d\": 63, \"e\": 0.15}, {\"a\": 22, \"b\": 91, \"c\": 12, \"d\": 53, \"e\": 0.15}, {\"a\": 38, \"b\": 88, \"c\": 82, \"d\": 90, \"e\": 0.15}, {\"a\": 66, \"b\": 30, \"c\": 38, \"d\": 31, \"e\": 1.0}, {\"a\": 39, \"b\": 27, \"c\": 17, \"d\": 36, \"e\": 0.15}, {\"a\": 12, \"b\": 63, \"c\": 14, \"d\": 37, \"e\": 0.15}, {\"a\": 53, \"b\": 84, \"c\": 58, \"d\": 95, \"e\": 1.0}, {\"a\": 42, \"b\": 21, \"c\": 42, \"d\": 66, \"e\": 1.0}, {\"a\": 14, \"b\": 13, \"c\": 0, \"d\": 17, \"e\": 0.15}, {\"a\": 16, \"b\": 28, \"c\": 0, \"d\": 62, \"e\": 0.15}, {\"a\": 1, \"b\": 13, \"c\": 66, \"d\": 91, \"e\": 0.15}, {\"a\": 55, \"b\": 26, \"c\": 1, \"d\": 65, \"e\": 1.0}, {\"a\": 38, \"b\": 31, \"c\": 81, \"d\": 79, \"e\": 0.15}, {\"a\": 0, \"b\": 28, \"c\": 29, \"d\": 16, \"e\": 0.15}, {\"a\": 47, \"b\": 21, \"c\": 13, \"d\": 8, \"e\": 1.0}, {\"a\": 42, \"b\": 93, \"c\": 82, \"d\": 65, \"e\": 1.0}, {\"a\": 70, \"b\": 29, \"c\": 72, \"d\": 35, \"e\": 1.0}, {\"a\": 0, \"b\": 99, \"c\": 3, \"d\": 14, \"e\": 0.15}, {\"a\": 50, \"b\": 66, \"c\": 88, \"d\": 15, \"e\": 1.0}, {\"a\": 65, \"b\": 74, \"c\": 26, \"d\": 82, \"e\": 1.0}, {\"a\": 91, \"b\": 46, \"c\": 61, \"d\": 38, \"e\": 1.0}, {\"a\": 27, \"b\": 77, \"c\": 80, \"d\": 55, \"e\": 0.15}, {\"a\": 0, \"b\": 88, \"c\": 95, \"d\": 67, \"e\": 0.15}, {\"a\": 76, \"b\": 66, \"c\": 70, \"d\": 14, \"e\": 1.0}, {\"a\": 43, \"b\": 90, \"c\": 30, \"d\": 37, \"e\": 1.0}, {\"a\": 0, \"b\": 18, \"c\": 94, \"d\": 26, \"e\": 0.15}, {\"a\": 97, \"b\": 12, \"c\": 68, \"d\": 18, \"e\": 1.0}, {\"a\": 28, \"b\": 54, \"c\": 76, \"d\": 8, \"e\": 0.15}, {\"a\": 38, \"b\": 51, \"c\": 81, \"d\": 35, \"e\": 0.15}, {\"a\": 69, \"b\": 56, \"c\": 40, \"d\": 17, \"e\": 1.0}, {\"a\": 78, \"b\": 44, \"c\": 86, \"d\": 22, \"e\": 1.0}, {\"a\": 5, \"b\": 16, \"c\": 21, \"d\": 23, \"e\": 0.15}, {\"a\": 74, \"b\": 25, \"c\": 36, \"d\": 48, \"e\": 1.0}, {\"a\": 98, \"b\": 99, \"c\": 9, \"d\": 52, \"e\": 1.0}, {\"a\": 5, \"b\": 74, \"c\": 18, \"d\": 99, \"e\": 0.15}, {\"a\": 37, \"b\": 13, \"c\": 61, \"d\": 93, \"e\": 0.15}, {\"a\": 81, \"b\": 28, \"c\": 7, \"d\": 1, \"e\": 1.0}, {\"a\": 70, \"b\": 65, \"c\": 22, \"d\": 16, \"e\": 1.0}, {\"a\": 88, \"b\": 77, \"c\": 82, \"d\": 93, \"e\": 1.0}, {\"a\": 50, \"b\": 94, \"c\": 91, \"d\": 64, \"e\": 1.0}, {\"a\": 21, \"b\": 35, \"c\": 87, \"d\": 55, \"e\": 0.15}, {\"a\": 45, \"b\": 11, \"c\": 69, \"d\": 18, \"e\": 1.0}, {\"a\": 27, \"b\": 93, \"c\": 47, \"d\": 22, \"e\": 0.15}, {\"a\": 74, \"b\": 13, \"c\": 59, \"d\": 39, \"e\": 1.0}, {\"a\": 68, \"b\": 62, \"c\": 95, \"d\": 47, \"e\": 1.0}, {\"a\": 72, \"b\": 10, \"c\": 49, \"d\": 44, \"e\": 1.0}, {\"a\": 8, \"b\": 53, \"c\": 17, \"d\": 89, \"e\": 0.15}, {\"a\": 56, \"b\": 17, \"c\": 3, \"d\": 2, \"e\": 1.0}, {\"a\": 61, \"b\": 14, \"c\": 28, \"d\": 86, \"e\": 1.0}, {\"a\": 42, \"b\": 61, \"c\": 17, \"d\": 86, \"e\": 1.0}, {\"a\": 50, \"b\": 67, \"c\": 1, \"d\": 51, \"e\": 1.0}, {\"a\": 28, \"b\": 24, \"c\": 85, \"d\": 30, \"e\": 0.15}, {\"a\": 96, \"b\": 26, \"c\": 70, \"d\": 41, \"e\": 1.0}, {\"a\": 48, \"b\": 56, \"c\": 1, \"d\": 36, \"e\": 1.0}, {\"a\": 73, \"b\": 27, \"c\": 90, \"d\": 78, \"e\": 1.0}, {\"a\": 77, \"b\": 62, \"c\": 92, \"d\": 54, \"e\": 1.0}, {\"a\": 38, \"b\": 5, \"c\": 39, \"d\": 47, \"e\": 0.15}, {\"a\": 87, \"b\": 29, \"c\": 89, \"d\": 6, \"e\": 1.0}, {\"a\": 84, \"b\": 66, \"c\": 14, \"d\": 57, \"e\": 1.0}, {\"a\": 45, \"b\": 30, \"c\": 73, \"d\": 21, \"e\": 1.0}, {\"a\": 59, \"b\": 90, \"c\": 6, \"d\": 23, \"e\": 1.0}, {\"a\": 90, \"b\": 19, \"c\": 55, \"d\": 94, \"e\": 1.0}, {\"a\": 60, \"b\": 91, \"c\": 17, \"d\": 0, \"e\": 1.0}, {\"a\": 8, \"b\": 43, \"c\": 50, \"d\": 42, \"e\": 0.15}, {\"a\": 85, \"b\": 62, \"c\": 77, \"d\": 85, \"e\": 1.0}, {\"a\": 91, \"b\": 2, \"c\": 89, \"d\": 92, \"e\": 1.0}, {\"a\": 6, \"b\": 45, \"c\": 88, \"d\": 21, \"e\": 0.15}, {\"a\": 18, \"b\": 46, \"c\": 30, \"d\": 3, \"e\": 0.15}, {\"a\": 87, \"b\": 44, \"c\": 57, \"d\": 76, \"e\": 1.0}, {\"a\": 51, \"b\": 69, \"c\": 62, \"d\": 56, \"e\": 1.0}, {\"a\": 10, \"b\": 58, \"c\": 12, \"d\": 27, \"e\": 0.15}, {\"a\": 39, \"b\": 25, \"c\": 93, \"d\": 52, \"e\": 0.15}, {\"a\": 67, \"b\": 34, \"c\": 28, \"d\": 14, \"e\": 1.0}, {\"a\": 82, \"b\": 55, \"c\": 44, \"d\": 29, \"e\": 1.0}, {\"a\": 67, \"b\": 17, \"c\": 69, \"d\": 14, \"e\": 1.0}, {\"a\": 36, \"b\": 4, \"c\": 80, \"d\": 99, \"e\": 0.15}, {\"a\": 52, \"b\": 41, \"c\": 26, \"d\": 22, \"e\": 1.0}, {\"a\": 41, \"b\": 13, \"c\": 13, \"d\": 33, \"e\": 1.0}, {\"a\": 46, \"b\": 18, \"c\": 78, \"d\": 62, \"e\": 1.0}, {\"a\": 47, \"b\": 86, \"c\": 58, \"d\": 63, \"e\": 1.0}, {\"a\": 45, \"b\": 40, \"c\": 50, \"d\": 3, \"e\": 1.0}, {\"a\": 82, \"b\": 4, \"c\": 86, \"d\": 31, \"e\": 1.0}, {\"a\": 7, \"b\": 63, \"c\": 46, \"d\": 19, \"e\": 0.15}, {\"a\": 31, \"b\": 40, \"c\": 2, \"d\": 19, \"e\": 0.15}, {\"a\": 20, \"b\": 33, \"c\": 55, \"d\": 9, \"e\": 0.15}, {\"a\": 44, \"b\": 75, \"c\": 53, \"d\": 22, \"e\": 1.0}, {\"a\": 18, \"b\": 52, \"c\": 26, \"d\": 12, \"e\": 0.15}, {\"a\": 36, \"b\": 56, \"c\": 60, \"d\": 55, \"e\": 0.15}, {\"a\": 73, \"b\": 68, \"c\": 45, \"d\": 53, \"e\": 1.0}, {\"a\": 60, \"b\": 12, \"c\": 92, \"d\": 38, \"e\": 1.0}, {\"a\": 24, \"b\": 83, \"c\": 35, \"d\": 63, \"e\": 0.15}, {\"a\": 92, \"b\": 39, \"c\": 86, \"d\": 38, \"e\": 1.0}, {\"a\": 4, \"b\": 32, \"c\": 11, \"d\": 97, \"e\": 0.15}, {\"a\": 94, \"b\": 50, \"c\": 35, \"d\": 84, \"e\": 1.0}, {\"a\": 71, \"b\": 60, \"c\": 64, \"d\": 45, \"e\": 1.0}, {\"a\": 15, \"b\": 53, \"c\": 80, \"d\": 17, \"e\": 0.15}, {\"a\": 45, \"b\": 94, \"c\": 91, \"d\": 83, \"e\": 1.0}, {\"a\": 62, \"b\": 35, \"c\": 2, \"d\": 30, \"e\": 1.0}, {\"a\": 14, \"b\": 29, \"c\": 83, \"d\": 50, \"e\": 0.15}, {\"a\": 54, \"b\": 79, \"c\": 69, \"d\": 53, \"e\": 1.0}, {\"a\": 47, \"b\": 86, \"c\": 45, \"d\": 91, \"e\": 1.0}, {\"a\": 24, \"b\": 66, \"c\": 0, \"d\": 50, \"e\": 0.15}, {\"a\": 99, \"b\": 69, \"c\": 75, \"d\": 3, \"e\": 1.0}, {\"a\": 31, \"b\": 67, \"c\": 41, \"d\": 37, \"e\": 0.15}, {\"a\": 59, \"b\": 60, \"c\": 64, \"d\": 25, \"e\": 1.0}, {\"a\": 17, \"b\": 48, \"c\": 16, \"d\": 87, \"e\": 0.15}, {\"a\": 60, \"b\": 4, \"c\": 37, \"d\": 83, \"e\": 1.0}, {\"a\": 74, \"b\": 58, \"c\": 97, \"d\": 62, \"e\": 1.0}, {\"a\": 32, \"b\": 7, \"c\": 13, \"d\": 43, \"e\": 0.15}, {\"a\": 73, \"b\": 13, \"c\": 19, \"d\": 98, \"e\": 1.0}, {\"a\": 88, \"b\": 3, \"c\": 87, \"d\": 2, \"e\": 1.0}, {\"a\": 57, \"b\": 32, \"c\": 74, \"d\": 25, \"e\": 1.0}, {\"a\": 80, \"b\": 3, \"c\": 89, \"d\": 30, \"e\": 1.0}, {\"a\": 94, \"b\": 24, \"c\": 99, \"d\": 22, \"e\": 1.0}, {\"a\": 79, \"b\": 65, \"c\": 50, \"d\": 10, \"e\": 1.0}, {\"a\": 11, \"b\": 82, \"c\": 6, \"d\": 12, \"e\": 0.15}, {\"a\": 76, \"b\": 95, \"c\": 51, \"d\": 2, \"e\": 1.0}, {\"a\": 63, \"b\": 91, \"c\": 13, \"d\": 40, \"e\": 1.0}, {\"a\": 54, \"b\": 29, \"c\": 53, \"d\": 71, \"e\": 1.0}, {\"a\": 48, \"b\": 15, \"c\": 1, \"d\": 7, \"e\": 1.0}, {\"a\": 5, \"b\": 17, \"c\": 67, \"d\": 11, \"e\": 0.15}, {\"a\": 70, \"b\": 7, \"c\": 66, \"d\": 44, \"e\": 1.0}, {\"a\": 11, \"b\": 13, \"c\": 82, \"d\": 14, \"e\": 0.15}, {\"a\": 59, \"b\": 16, \"c\": 46, \"d\": 51, \"e\": 1.0}, {\"a\": 77, \"b\": 66, \"c\": 70, \"d\": 1, \"e\": 1.0}, {\"a\": 70, \"b\": 74, \"c\": 39, \"d\": 85, \"e\": 1.0}, {\"a\": 61, \"b\": 16, \"c\": 8, \"d\": 45, \"e\": 1.0}, {\"a\": 27, \"b\": 90, \"c\": 95, \"d\": 1, \"e\": 0.15}, {\"a\": 40, \"b\": 24, \"c\": 86, \"d\": 53, \"e\": 1.0}, {\"a\": 5, \"b\": 75, \"c\": 3, \"d\": 70, \"e\": 0.15}, {\"a\": 58, \"b\": 92, \"c\": 74, \"d\": 65, \"e\": 1.0}, {\"a\": 96, \"b\": 54, \"c\": 25, \"d\": 77, \"e\": 1.0}, {\"a\": 13, \"b\": 55, \"c\": 12, \"d\": 26, \"e\": 0.15}, {\"a\": 49, \"b\": 85, \"c\": 66, \"d\": 33, \"e\": 1.0}, {\"a\": 38, \"b\": 15, \"c\": 27, \"d\": 17, \"e\": 0.15}, {\"a\": 93, \"b\": 71, \"c\": 14, \"d\": 61, \"e\": 1.0}, {\"a\": 32, \"b\": 58, \"c\": 2, \"d\": 30, \"e\": 0.15}, {\"a\": 86, \"b\": 22, \"c\": 74, \"d\": 31, \"e\": 1.0}, {\"a\": 36, \"b\": 42, \"c\": 54, \"d\": 2, \"e\": 0.15}, {\"a\": 77, \"b\": 38, \"c\": 3, \"d\": 7, \"e\": 1.0}, {\"a\": 51, \"b\": 29, \"c\": 70, \"d\": 94, \"e\": 1.0}, {\"a\": 43, \"b\": 88, \"c\": 35, \"d\": 36, \"e\": 1.0}, {\"a\": 74, \"b\": 97, \"c\": 12, \"d\": 55, \"e\": 1.0}, {\"a\": 19, \"b\": 57, \"c\": 63, \"d\": 88, \"e\": 0.15}, {\"a\": 48, \"b\": 4, \"c\": 37, \"d\": 13, \"e\": 1.0}, {\"a\": 90, \"b\": 4, \"c\": 43, \"d\": 90, \"e\": 1.0}, {\"a\": 84, \"b\": 73, \"c\": 81, \"d\": 55, \"e\": 1.0}, {\"a\": 36, \"b\": 61, \"c\": 15, \"d\": 0, \"e\": 0.15}, {\"a\": 73, \"b\": 70, \"c\": 82, \"d\": 17, \"e\": 1.0}, {\"a\": 91, \"b\": 39, \"c\": 33, \"d\": 8, \"e\": 1.0}, {\"a\": 70, \"b\": 47, \"c\": 7, \"d\": 91, \"e\": 1.0}, {\"a\": 89, \"b\": 44, \"c\": 84, \"d\": 75, \"e\": 1.0}, {\"a\": 86, \"b\": 46, \"c\": 42, \"d\": 94, \"e\": 1.0}, {\"a\": 13, \"b\": 46, \"c\": 71, \"d\": 99, \"e\": 0.15}, {\"a\": 43, \"b\": 71, \"c\": 50, \"d\": 97, \"e\": 1.0}, {\"a\": 37, \"b\": 5, \"c\": 41, \"d\": 17, \"e\": 0.15}, {\"a\": 70, \"b\": 41, \"c\": 73, \"d\": 62, \"e\": 1.0}, {\"a\": 68, \"b\": 25, \"c\": 14, \"d\": 19, \"e\": 1.0}, {\"a\": 56, \"b\": 18, \"c\": 40, \"d\": 29, \"e\": 1.0}, {\"a\": 79, \"b\": 16, \"c\": 28, \"d\": 18, \"e\": 1.0}, {\"a\": 94, \"b\": 20, \"c\": 16, \"d\": 55, \"e\": 1.0}, {\"a\": 98, \"b\": 23, \"c\": 19, \"d\": 15, \"e\": 1.0}, {\"a\": 18, \"b\": 32, \"c\": 40, \"d\": 46, \"e\": 0.15}, {\"a\": 74, \"b\": 96, \"c\": 64, \"d\": 10, \"e\": 1.0}, {\"a\": 53, \"b\": 16, \"c\": 25, \"d\": 28, \"e\": 1.0}, {\"a\": 72, \"b\": 76, \"c\": 20, \"d\": 18, \"e\": 1.0}, {\"a\": 87, \"b\": 61, \"c\": 44, \"d\": 20, \"e\": 1.0}, {\"a\": 73, \"b\": 27, \"c\": 29, \"d\": 30, \"e\": 1.0}, {\"a\": 76, \"b\": 10, \"c\": 37, \"d\": 83, \"e\": 1.0}, {\"a\": 77, \"b\": 85, \"c\": 29, \"d\": 31, \"e\": 1.0}, {\"a\": 85, \"b\": 89, \"c\": 63, \"d\": 48, \"e\": 1.0}, {\"a\": 38, \"b\": 69, \"c\": 50, \"d\": 85, \"e\": 0.15}, {\"a\": 65, \"b\": 92, \"c\": 68, \"d\": 19, \"e\": 1.0}, {\"a\": 56, \"b\": 90, \"c\": 2, \"d\": 64, \"e\": 1.0}, {\"a\": 53, \"b\": 0, \"c\": 41, \"d\": 94, \"e\": 1.0}, {\"a\": 13, \"b\": 17, \"c\": 62, \"d\": 60, \"e\": 0.15}, {\"a\": 12, \"b\": 42, \"c\": 52, \"d\": 3, \"e\": 0.15}, {\"a\": 46, \"b\": 95, \"c\": 87, \"d\": 15, \"e\": 1.0}, {\"a\": 75, \"b\": 53, \"c\": 62, \"d\": 63, \"e\": 1.0}, {\"a\": 37, \"b\": 36, \"c\": 57, \"d\": 19, \"e\": 0.15}, {\"a\": 86, \"b\": 85, \"c\": 96, \"d\": 65, \"e\": 1.0}, {\"a\": 64, \"b\": 20, \"c\": 64, \"d\": 95, \"e\": 1.0}, {\"a\": 82, \"b\": 52, \"c\": 21, \"d\": 66, \"e\": 1.0}, {\"a\": 6, \"b\": 52, \"c\": 8, \"d\": 14, \"e\": 0.15}, {\"a\": 36, \"b\": 93, \"c\": 23, \"d\": 30, \"e\": 0.15}, {\"a\": 34, \"b\": 94, \"c\": 31, \"d\": 82, \"e\": 0.15}, {\"a\": 61, \"b\": 95, \"c\": 36, \"d\": 85, \"e\": 1.0}, {\"a\": 68, \"b\": 7, \"c\": 27, \"d\": 10, \"e\": 1.0}, {\"a\": 67, \"b\": 81, \"c\": 9, \"d\": 66, \"e\": 1.0}, {\"a\": 57, \"b\": 39, \"c\": 97, \"d\": 27, \"e\": 1.0}, {\"a\": 30, \"b\": 34, \"c\": 46, \"d\": 64, \"e\": 0.15}, {\"a\": 28, \"b\": 69, \"c\": 71, \"d\": 36, \"e\": 0.15}, {\"a\": 76, \"b\": 43, \"c\": 90, \"d\": 17, \"e\": 1.0}, {\"a\": 87, \"b\": 22, \"c\": 16, \"d\": 16, \"e\": 1.0}, {\"a\": 39, \"b\": 30, \"c\": 8, \"d\": 54, \"e\": 0.15}, {\"a\": 83, \"b\": 47, \"c\": 80, \"d\": 28, \"e\": 1.0}, {\"a\": 20, \"b\": 68, \"c\": 33, \"d\": 11, \"e\": 0.15}, {\"a\": 55, \"b\": 45, \"c\": 28, \"d\": 6, \"e\": 1.0}, {\"a\": 76, \"b\": 72, \"c\": 46, \"d\": 8, \"e\": 1.0}, {\"a\": 19, \"b\": 39, \"c\": 10, \"d\": 97, \"e\": 0.15}, {\"a\": 7, \"b\": 78, \"c\": 94, \"d\": 10, \"e\": 0.15}, {\"a\": 92, \"b\": 43, \"c\": 78, \"d\": 21, \"e\": 1.0}, {\"a\": 83, \"b\": 49, \"c\": 79, \"d\": 15, \"e\": 1.0}, {\"a\": 88, \"b\": 58, \"c\": 69, \"d\": 33, \"e\": 1.0}, {\"a\": 76, \"b\": 74, \"c\": 91, \"d\": 34, \"e\": 1.0}, {\"a\": 72, \"b\": 96, \"c\": 44, \"d\": 88, \"e\": 1.0}, {\"a\": 21, \"b\": 15, \"c\": 44, \"d\": 41, \"e\": 0.15}, {\"a\": 70, \"b\": 42, \"c\": 3, \"d\": 13, \"e\": 1.0}, {\"a\": 52, \"b\": 79, \"c\": 65, \"d\": 23, \"e\": 1.0}, {\"a\": 32, \"b\": 29, \"c\": 49, \"d\": 75, \"e\": 0.15}, {\"a\": 40, \"b\": 64, \"c\": 42, \"d\": 84, \"e\": 1.0}, {\"a\": 54, \"b\": 15, \"c\": 91, \"d\": 56, \"e\": 1.0}, {\"a\": 49, \"b\": 15, \"c\": 2, \"d\": 56, \"e\": 1.0}, {\"a\": 78, \"b\": 14, \"c\": 73, \"d\": 15, \"e\": 1.0}, {\"a\": 87, \"b\": 92, \"c\": 63, \"d\": 14, \"e\": 1.0}, {\"a\": 13, \"b\": 0, \"c\": 72, \"d\": 28, \"e\": 0.15}, {\"a\": 48, \"b\": 69, \"c\": 97, \"d\": 11, \"e\": 1.0}, {\"a\": 77, \"b\": 87, \"c\": 84, \"d\": 55, \"e\": 1.0}, {\"a\": 12, \"b\": 5, \"c\": 83, \"d\": 89, \"e\": 0.15}, {\"a\": 16, \"b\": 23, \"c\": 5, \"d\": 15, \"e\": 0.15}, {\"a\": 21, \"b\": 38, \"c\": 95, \"d\": 97, \"e\": 0.15}, {\"a\": 83, \"b\": 51, \"c\": 54, \"d\": 65, \"e\": 1.0}, {\"a\": 73, \"b\": 79, \"c\": 18, \"d\": 72, \"e\": 1.0}, {\"a\": 90, \"b\": 33, \"c\": 10, \"d\": 38, \"e\": 1.0}, {\"a\": 23, \"b\": 98, \"c\": 22, \"d\": 72, \"e\": 0.15}, {\"a\": 73, \"b\": 9, \"c\": 42, \"d\": 81, \"e\": 1.0}, {\"a\": 88, \"b\": 22, \"c\": 23, \"d\": 66, \"e\": 1.0}, {\"a\": 79, \"b\": 10, \"c\": 50, \"d\": 17, \"e\": 1.0}, {\"a\": 89, \"b\": 75, \"c\": 55, \"d\": 97, \"e\": 1.0}, {\"a\": 58, \"b\": 55, \"c\": 20, \"d\": 26, \"e\": 1.0}, {\"a\": 39, \"b\": 24, \"c\": 65, \"d\": 78, \"e\": 0.15}, {\"a\": 4, \"b\": 76, \"c\": 26, \"d\": 71, \"e\": 0.15}, {\"a\": 12, \"b\": 9, \"c\": 3, \"d\": 89, \"e\": 0.15}, {\"a\": 97, \"b\": 51, \"c\": 65, \"d\": 71, \"e\": 1.0}, {\"a\": 65, \"b\": 6, \"c\": 22, \"d\": 41, \"e\": 1.0}, {\"a\": 35, \"b\": 82, \"c\": 94, \"d\": 94, \"e\": 0.15}, {\"a\": 98, \"b\": 68, \"c\": 54, \"d\": 20, \"e\": 1.0}, {\"a\": 90, \"b\": 32, \"c\": 61, \"d\": 33, \"e\": 1.0}, {\"a\": 23, \"b\": 83, \"c\": 87, \"d\": 93, \"e\": 0.15}, {\"a\": 59, \"b\": 2, \"c\": 41, \"d\": 44, \"e\": 1.0}, {\"a\": 89, \"b\": 75, \"c\": 95, \"d\": 11, \"e\": 1.0}, {\"a\": 58, \"b\": 37, \"c\": 60, \"d\": 22, \"e\": 1.0}, {\"a\": 26, \"b\": 60, \"c\": 86, \"d\": 43, \"e\": 0.15}, {\"a\": 30, \"b\": 42, \"c\": 72, \"d\": 83, \"e\": 0.15}, {\"a\": 94, \"b\": 46, \"c\": 11, \"d\": 51, \"e\": 1.0}, {\"a\": 44, \"b\": 53, \"c\": 63, \"d\": 58, \"e\": 1.0}, {\"a\": 55, \"b\": 28, \"c\": 32, \"d\": 64, \"e\": 1.0}, {\"a\": 30, \"b\": 84, \"c\": 94, \"d\": 71, \"e\": 0.15}, {\"a\": 99, \"b\": 53, \"c\": 73, \"d\": 65, \"e\": 1.0}, {\"a\": 6, \"b\": 53, \"c\": 99, \"d\": 80, \"e\": 0.15}, {\"a\": 14, \"b\": 4, \"c\": 94, \"d\": 25, \"e\": 0.15}, {\"a\": 78, \"b\": 78, \"c\": 0, \"d\": 49, \"e\": 1.0}, {\"a\": 3, \"b\": 40, \"c\": 87, \"d\": 65, \"e\": 0.15}, {\"a\": 10, \"b\": 60, \"c\": 72, \"d\": 48, \"e\": 0.15}, {\"a\": 22, \"b\": 34, \"c\": 8, \"d\": 61, \"e\": 0.15}, {\"a\": 46, \"b\": 81, \"c\": 24, \"d\": 93, \"e\": 1.0}, {\"a\": 56, \"b\": 98, \"c\": 43, \"d\": 69, \"e\": 1.0}, {\"a\": 31, \"b\": 8, \"c\": 34, \"d\": 42, \"e\": 0.15}, {\"a\": 55, \"b\": 96, \"c\": 29, \"d\": 12, \"e\": 1.0}, {\"a\": 66, \"b\": 36, \"c\": 74, \"d\": 46, \"e\": 1.0}, {\"a\": 88, \"b\": 13, \"c\": 42, \"d\": 7, \"e\": 1.0}, {\"a\": 51, \"b\": 26, \"c\": 27, \"d\": 99, \"e\": 1.0}, {\"a\": 8, \"b\": 16, \"c\": 91, \"d\": 60, \"e\": 0.15}, {\"a\": 91, \"b\": 75, \"c\": 52, \"d\": 69, \"e\": 1.0}, {\"a\": 27, \"b\": 28, \"c\": 96, \"d\": 3, \"e\": 0.15}, {\"a\": 95, \"b\": 45, \"c\": 6, \"d\": 96, \"e\": 1.0}, {\"a\": 97, \"b\": 20, \"c\": 6, \"d\": 3, \"e\": 1.0}, {\"a\": 18, \"b\": 37, \"c\": 24, \"d\": 68, \"e\": 0.15}, {\"a\": 73, \"b\": 50, \"c\": 50, \"d\": 63, \"e\": 1.0}, {\"a\": 68, \"b\": 17, \"c\": 39, \"d\": 36, \"e\": 1.0}, {\"a\": 17, \"b\": 7, \"c\": 52, \"d\": 90, \"e\": 0.15}, {\"a\": 10, \"b\": 10, \"c\": 3, \"d\": 46, \"e\": 0.15}, {\"a\": 1, \"b\": 6, \"c\": 7, \"d\": 71, \"e\": 0.15}, {\"a\": 52, \"b\": 68, \"c\": 33, \"d\": 82, \"e\": 1.0}, {\"a\": 33, \"b\": 35, \"c\": 83, \"d\": 64, \"e\": 0.15}, {\"a\": 49, \"b\": 61, \"c\": 15, \"d\": 57, \"e\": 1.0}, {\"a\": 52, \"b\": 53, \"c\": 43, \"d\": 64, \"e\": 1.0}, {\"a\": 53, \"b\": 77, \"c\": 22, \"d\": 94, \"e\": 1.0}, {\"a\": 98, \"b\": 78, \"c\": 86, \"d\": 39, \"e\": 1.0}, {\"a\": 72, \"b\": 52, \"c\": 42, \"d\": 16, \"e\": 1.0}, {\"a\": 71, \"b\": 40, \"c\": 32, \"d\": 38, \"e\": 1.0}, {\"a\": 29, \"b\": 12, \"c\": 7, \"d\": 3, \"e\": 0.15}, {\"a\": 64, \"b\": 83, \"c\": 58, \"d\": 2, \"e\": 1.0}, {\"a\": 47, \"b\": 54, \"c\": 58, \"d\": 90, \"e\": 1.0}, {\"a\": 80, \"b\": 88, \"c\": 50, \"d\": 59, \"e\": 1.0}, {\"a\": 39, \"b\": 8, \"c\": 71, \"d\": 19, \"e\": 0.15}, {\"a\": 74, \"b\": 88, \"c\": 27, \"d\": 85, \"e\": 1.0}, {\"a\": 37, \"b\": 37, \"c\": 39, \"d\": 8, \"e\": 0.15}, {\"a\": 75, \"b\": 17, \"c\": 8, \"d\": 32, \"e\": 1.0}, {\"a\": 31, \"b\": 43, \"c\": 98, \"d\": 15, \"e\": 0.15}, {\"a\": 70, \"b\": 64, \"c\": 81, \"d\": 18, \"e\": 1.0}, {\"a\": 35, \"b\": 23, \"c\": 80, \"d\": 95, \"e\": 0.15}, {\"a\": 79, \"b\": 69, \"c\": 2, \"d\": 13, \"e\": 1.0}, {\"a\": 77, \"b\": 48, \"c\": 64, \"d\": 66, \"e\": 1.0}, {\"a\": 25, \"b\": 16, \"c\": 60, \"d\": 32, \"e\": 0.15}, {\"a\": 73, \"b\": 92, \"c\": 69, \"d\": 63, \"e\": 1.0}, {\"a\": 48, \"b\": 29, \"c\": 17, \"d\": 48, \"e\": 1.0}, {\"a\": 74, \"b\": 25, \"c\": 80, \"d\": 49, \"e\": 1.0}, {\"a\": 64, \"b\": 97, \"c\": 3, \"d\": 38, \"e\": 1.0}, {\"a\": 75, \"b\": 26, \"c\": 94, \"d\": 93, \"e\": 1.0}, {\"a\": 65, \"b\": 28, \"c\": 39, \"d\": 46, \"e\": 1.0}, {\"a\": 40, \"b\": 82, \"c\": 44, \"d\": 81, \"e\": 1.0}, {\"a\": 22, \"b\": 61, \"c\": 50, \"d\": 53, \"e\": 0.15}, {\"a\": 33, \"b\": 71, \"c\": 56, \"d\": 72, \"e\": 0.15}, {\"a\": 24, \"b\": 69, \"c\": 4, \"d\": 68, \"e\": 0.15}, {\"a\": 61, \"b\": 21, \"c\": 28, \"d\": 8, \"e\": 1.0}, {\"a\": 43, \"b\": 71, \"c\": 8, \"d\": 29, \"e\": 1.0}, {\"a\": 33, \"b\": 61, \"c\": 90, \"d\": 77, \"e\": 0.15}, {\"a\": 30, \"b\": 61, \"c\": 69, \"d\": 36, \"e\": 0.15}, {\"a\": 2, \"b\": 8, \"c\": 53, \"d\": 17, \"e\": 0.15}, {\"a\": 16, \"b\": 66, \"c\": 63, \"d\": 53, \"e\": 0.15}, {\"a\": 37, \"b\": 57, \"c\": 75, \"d\": 61, \"e\": 0.15}, {\"a\": 19, \"b\": 77, \"c\": 73, \"d\": 33, \"e\": 0.15}, {\"a\": 67, \"b\": 98, \"c\": 93, \"d\": 84, \"e\": 1.0}, {\"a\": 18, \"b\": 78, \"c\": 58, \"d\": 68, \"e\": 0.15}, {\"a\": 42, \"b\": 44, \"c\": 27, \"d\": 54, \"e\": 1.0}, {\"a\": 38, \"b\": 12, \"c\": 84, \"d\": 55, \"e\": 0.15}, {\"a\": 11, \"b\": 91, \"c\": 38, \"d\": 90, \"e\": 0.15}, {\"a\": 5, \"b\": 75, \"c\": 19, \"d\": 33, \"e\": 0.15}, {\"a\": 82, \"b\": 94, \"c\": 22, \"d\": 78, \"e\": 1.0}, {\"a\": 91, \"b\": 33, \"c\": 97, \"d\": 79, \"e\": 1.0}, {\"a\": 49, \"b\": 82, \"c\": 79, \"d\": 79, \"e\": 1.0}, {\"a\": 99, \"b\": 13, \"c\": 53, \"d\": 85, \"e\": 1.0}, {\"a\": 82, \"b\": 27, \"c\": 11, \"d\": 36, \"e\": 1.0}, {\"a\": 8, \"b\": 68, \"c\": 73, \"d\": 75, \"e\": 0.15}, {\"a\": 54, \"b\": 2, \"c\": 50, \"d\": 78, \"e\": 1.0}, {\"a\": 40, \"b\": 68, \"c\": 35, \"d\": 4, \"e\": 1.0}, {\"a\": 11, \"b\": 18, \"c\": 90, \"d\": 84, \"e\": 0.15}, {\"a\": 83, \"b\": 49, \"c\": 95, \"d\": 81, \"e\": 1.0}, {\"a\": 52, \"b\": 99, \"c\": 12, \"d\": 63, \"e\": 1.0}, {\"a\": 36, \"b\": 0, \"c\": 46, \"d\": 40, \"e\": 0.15}, {\"a\": 7, \"b\": 16, \"c\": 85, \"d\": 46, \"e\": 0.15}, {\"a\": 45, \"b\": 87, \"c\": 84, \"d\": 95, \"e\": 1.0}, {\"a\": 52, \"b\": 33, \"c\": 38, \"d\": 70, \"e\": 1.0}, {\"a\": 66, \"b\": 56, \"c\": 6, \"d\": 36, \"e\": 1.0}, {\"a\": 38, \"b\": 86, \"c\": 67, \"d\": 72, \"e\": 0.15}, {\"a\": 30, \"b\": 5, \"c\": 22, \"d\": 50, \"e\": 0.15}, {\"a\": 57, \"b\": 20, \"c\": 8, \"d\": 93, \"e\": 1.0}, {\"a\": 80, \"b\": 88, \"c\": 64, \"d\": 45, \"e\": 1.0}, {\"a\": 99, \"b\": 70, \"c\": 86, \"d\": 21, \"e\": 1.0}, {\"a\": 59, \"b\": 38, \"c\": 11, \"d\": 86, \"e\": 1.0}, {\"a\": 80, \"b\": 0, \"c\": 55, \"d\": 0, \"e\": 1.0}, {\"a\": 75, \"b\": 27, \"c\": 45, \"d\": 58, \"e\": 1.0}, {\"a\": 37, \"b\": 53, \"c\": 47, \"d\": 20, \"e\": 0.15}, {\"a\": 62, \"b\": 98, \"c\": 61, \"d\": 12, \"e\": 1.0}, {\"a\": 88, \"b\": 67, \"c\": 56, \"d\": 19, \"e\": 1.0}, {\"a\": 39, \"b\": 99, \"c\": 93, \"d\": 36, \"e\": 0.15}, {\"a\": 34, \"b\": 25, \"c\": 68, \"d\": 32, \"e\": 0.15}, {\"a\": 79, \"b\": 16, \"c\": 67, \"d\": 81, \"e\": 1.0}, {\"a\": 38, \"b\": 40, \"c\": 88, \"d\": 30, \"e\": 0.15}, {\"a\": 90, \"b\": 26, \"c\": 87, \"d\": 5, \"e\": 1.0}, {\"a\": 10, \"b\": 44, \"c\": 33, \"d\": 43, \"e\": 0.15}, {\"a\": 38, \"b\": 5, \"c\": 69, \"d\": 68, \"e\": 0.15}, {\"a\": 93, \"b\": 83, \"c\": 45, \"d\": 72, \"e\": 1.0}, {\"a\": 62, \"b\": 13, \"c\": 49, \"d\": 33, \"e\": 1.0}, {\"a\": 37, \"b\": 32, \"c\": 31, \"d\": 27, \"e\": 0.15}, {\"a\": 30, \"b\": 39, \"c\": 43, \"d\": 71, \"e\": 0.15}, {\"a\": 82, \"b\": 71, \"c\": 24, \"d\": 26, \"e\": 1.0}, {\"a\": 13, \"b\": 3, \"c\": 85, \"d\": 54, \"e\": 0.15}, {\"a\": 80, \"b\": 47, \"c\": 40, \"d\": 65, \"e\": 1.0}, {\"a\": 48, \"b\": 3, \"c\": 0, \"d\": 60, \"e\": 1.0}, {\"a\": 72, \"b\": 71, \"c\": 70, \"d\": 84, \"e\": 1.0}, {\"a\": 2, \"b\": 83, \"c\": 72, \"d\": 70, \"e\": 0.15}, {\"a\": 1, \"b\": 4, \"c\": 36, \"d\": 81, \"e\": 0.15}, {\"a\": 99, \"b\": 58, \"c\": 95, \"d\": 70, \"e\": 1.0}, {\"a\": 62, \"b\": 9, \"c\": 55, \"d\": 15, \"e\": 1.0}, {\"a\": 81, \"b\": 62, \"c\": 75, \"d\": 61, \"e\": 1.0}, {\"a\": 55, \"b\": 55, \"c\": 92, \"d\": 10, \"e\": 1.0}, {\"a\": 4, \"b\": 13, \"c\": 12, \"d\": 4, \"e\": 0.15}, {\"a\": 63, \"b\": 33, \"c\": 73, \"d\": 41, \"e\": 1.0}, {\"a\": 97, \"b\": 51, \"c\": 81, \"d\": 62, \"e\": 1.0}, {\"a\": 92, \"b\": 94, \"c\": 92, \"d\": 18, \"e\": 1.0}, {\"a\": 65, \"b\": 1, \"c\": 45, \"d\": 6, \"e\": 1.0}, {\"a\": 22, \"b\": 46, \"c\": 59, \"d\": 44, \"e\": 0.15}, {\"a\": 38, \"b\": 66, \"c\": 56, \"d\": 68, \"e\": 0.15}, {\"a\": 65, \"b\": 23, \"c\": 72, \"d\": 67, \"e\": 1.0}, {\"a\": 69, \"b\": 91, \"c\": 64, \"d\": 68, \"e\": 1.0}, {\"a\": 69, \"b\": 63, \"c\": 39, \"d\": 21, \"e\": 1.0}, {\"a\": 29, \"b\": 75, \"c\": 29, \"d\": 62, \"e\": 0.15}, {\"a\": 17, \"b\": 37, \"c\": 3, \"d\": 38, \"e\": 0.15}, {\"a\": 52, \"b\": 14, \"c\": 17, \"d\": 5, \"e\": 1.0}, {\"a\": 30, \"b\": 6, \"c\": 35, \"d\": 18, \"e\": 0.15}, {\"a\": 79, \"b\": 44, \"c\": 96, \"d\": 5, \"e\": 1.0}, {\"a\": 16, \"b\": 43, \"c\": 3, \"d\": 6, \"e\": 0.15}, {\"a\": 78, \"b\": 41, \"c\": 88, \"d\": 76, \"e\": 1.0}, {\"a\": 1, \"b\": 23, \"c\": 42, \"d\": 80, \"e\": 0.15}, {\"a\": 68, \"b\": 78, \"c\": 79, \"d\": 1, \"e\": 1.0}, {\"a\": 14, \"b\": 97, \"c\": 30, \"d\": 24, \"e\": 0.15}, {\"a\": 11, \"b\": 8, \"c\": 46, \"d\": 51, \"e\": 0.15}, {\"a\": 22, \"b\": 7, \"c\": 59, \"d\": 79, \"e\": 0.15}, {\"a\": 41, \"b\": 31, \"c\": 17, \"d\": 30, \"e\": 1.0}, {\"a\": 98, \"b\": 40, \"c\": 12, \"d\": 40, \"e\": 1.0}, {\"a\": 97, \"b\": 82, \"c\": 22, \"d\": 9, \"e\": 1.0}, {\"a\": 47, \"b\": 38, \"c\": 57, \"d\": 53, \"e\": 1.0}, {\"a\": 69, \"b\": 62, \"c\": 78, \"d\": 70, \"e\": 1.0}, {\"a\": 64, \"b\": 57, \"c\": 43, \"d\": 85, \"e\": 1.0}, {\"a\": 70, \"b\": 74, \"c\": 56, \"d\": 97, \"e\": 1.0}, {\"a\": 70, \"b\": 2, \"c\": 31, \"d\": 72, \"e\": 1.0}, {\"a\": 19, \"b\": 16, \"c\": 30, \"d\": 28, \"e\": 0.15}, {\"a\": 21, \"b\": 44, \"c\": 50, \"d\": 7, \"e\": 0.15}, {\"a\": 10, \"b\": 11, \"c\": 85, \"d\": 10, \"e\": 0.15}, {\"a\": 66, \"b\": 93, \"c\": 18, \"d\": 12, \"e\": 1.0}, {\"a\": 30, \"b\": 6, \"c\": 84, \"d\": 91, \"e\": 0.15}, {\"a\": 66, \"b\": 59, \"c\": 33, \"d\": 71, \"e\": 1.0}, {\"a\": 19, \"b\": 88, \"c\": 82, \"d\": 70, \"e\": 0.15}, {\"a\": 0, \"b\": 99, \"c\": 22, \"d\": 39, \"e\": 0.15}, {\"a\": 13, \"b\": 19, \"c\": 62, \"d\": 21, \"e\": 0.15}, {\"a\": 30, \"b\": 70, \"c\": 20, \"d\": 74, \"e\": 0.15}, {\"a\": 58, \"b\": 7, \"c\": 78, \"d\": 53, \"e\": 1.0}, {\"a\": 83, \"b\": 10, \"c\": 35, \"d\": 20, \"e\": 1.0}, {\"a\": 62, \"b\": 9, \"c\": 60, \"d\": 80, \"e\": 1.0}, {\"a\": 53, \"b\": 42, \"c\": 89, \"d\": 87, \"e\": 1.0}, {\"a\": 96, \"b\": 93, \"c\": 53, \"d\": 53, \"e\": 1.0}, {\"a\": 23, \"b\": 27, \"c\": 27, \"d\": 7, \"e\": 0.15}, {\"a\": 24, \"b\": 67, \"c\": 65, \"d\": 38, \"e\": 0.15}, {\"a\": 35, \"b\": 50, \"c\": 4, \"d\": 68, \"e\": 0.15}, {\"a\": 19, \"b\": 59, \"c\": 29, \"d\": 42, \"e\": 0.15}, {\"a\": 21, \"b\": 12, \"c\": 41, \"d\": 95, \"e\": 0.15}, {\"a\": 74, \"b\": 66, \"c\": 78, \"d\": 62, \"e\": 1.0}, {\"a\": 9, \"b\": 18, \"c\": 6, \"d\": 72, \"e\": 0.15}, {\"a\": 75, \"b\": 79, \"c\": 38, \"d\": 23, \"e\": 1.0}, {\"a\": 80, \"b\": 48, \"c\": 66, \"d\": 30, \"e\": 1.0}, {\"a\": 4, \"b\": 82, \"c\": 70, \"d\": 69, \"e\": 0.15}, {\"a\": 99, \"b\": 67, \"c\": 57, \"d\": 7, \"e\": 1.0}, {\"a\": 24, \"b\": 0, \"c\": 57, \"d\": 46, \"e\": 0.15}, {\"a\": 15, \"b\": 1, \"c\": 98, \"d\": 95, \"e\": 0.15}, {\"a\": 3, \"b\": 45, \"c\": 24, \"d\": 40, \"e\": 0.15}, {\"a\": 25, \"b\": 36, \"c\": 41, \"d\": 65, \"e\": 0.15}, {\"a\": 86, \"b\": 42, \"c\": 53, \"d\": 52, \"e\": 1.0}, {\"a\": 37, \"b\": 5, \"c\": 93, \"d\": 55, \"e\": 0.15}, {\"a\": 75, \"b\": 15, \"c\": 35, \"d\": 88, \"e\": 1.0}, {\"a\": 36, \"b\": 12, \"c\": 66, \"d\": 99, \"e\": 0.15}, {\"a\": 48, \"b\": 29, \"c\": 4, \"d\": 58, \"e\": 1.0}, {\"a\": 62, \"b\": 75, \"c\": 9, \"d\": 96, \"e\": 1.0}, {\"a\": 45, \"b\": 81, \"c\": 78, \"d\": 15, \"e\": 1.0}, {\"a\": 58, \"b\": 98, \"c\": 89, \"d\": 98, \"e\": 1.0}, {\"a\": 70, \"b\": 9, \"c\": 73, \"d\": 13, \"e\": 1.0}, {\"a\": 87, \"b\": 8, \"c\": 89, \"d\": 56, \"e\": 1.0}, {\"a\": 78, \"b\": 72, \"c\": 42, \"d\": 16, \"e\": 1.0}, {\"a\": 9, \"b\": 77, \"c\": 48, \"d\": 50, \"e\": 0.15}, {\"a\": 41, \"b\": 50, \"c\": 58, \"d\": 38, \"e\": 1.0}, {\"a\": 97, \"b\": 7, \"c\": 7, \"d\": 31, \"e\": 1.0}, {\"a\": 2, \"b\": 19, \"c\": 89, \"d\": 62, \"e\": 0.15}, {\"a\": 71, \"b\": 94, \"c\": 78, \"d\": 55, \"e\": 1.0}, {\"a\": 38, \"b\": 50, \"c\": 90, \"d\": 99, \"e\": 0.15}, {\"a\": 39, \"b\": 67, \"c\": 29, \"d\": 63, \"e\": 0.15}, {\"a\": 80, \"b\": 96, \"c\": 3, \"d\": 41, \"e\": 1.0}, {\"a\": 85, \"b\": 6, \"c\": 41, \"d\": 71, \"e\": 1.0}, {\"a\": 64, \"b\": 45, \"c\": 66, \"d\": 68, \"e\": 1.0}, {\"a\": 21, \"b\": 49, \"c\": 79, \"d\": 69, \"e\": 0.15}, {\"a\": 82, \"b\": 23, \"c\": 88, \"d\": 79, \"e\": 1.0}, {\"a\": 31, \"b\": 35, \"c\": 49, \"d\": 41, \"e\": 0.15}, {\"a\": 17, \"b\": 57, \"c\": 84, \"d\": 36, \"e\": 0.15}, {\"a\": 92, \"b\": 35, \"c\": 92, \"d\": 69, \"e\": 1.0}, {\"a\": 62, \"b\": 29, \"c\": 31, \"d\": 55, \"e\": 1.0}, {\"a\": 94, \"b\": 37, \"c\": 46, \"d\": 74, \"e\": 1.0}, {\"a\": 1, \"b\": 51, \"c\": 87, \"d\": 76, \"e\": 0.15}, {\"a\": 65, \"b\": 18, \"c\": 39, \"d\": 37, \"e\": 1.0}, {\"a\": 76, \"b\": 27, \"c\": 51, \"d\": 33, \"e\": 1.0}, {\"a\": 3, \"b\": 79, \"c\": 95, \"d\": 42, \"e\": 0.15}, {\"a\": 33, \"b\": 98, \"c\": 85, \"d\": 5, \"e\": 0.15}, {\"a\": 64, \"b\": 35, \"c\": 63, \"d\": 74, \"e\": 1.0}, {\"a\": 52, \"b\": 12, \"c\": 16, \"d\": 61, \"e\": 1.0}, {\"a\": 39, \"b\": 48, \"c\": 39, \"d\": 6, \"e\": 0.15}, {\"a\": 6, \"b\": 5, \"c\": 39, \"d\": 40, \"e\": 0.15}, {\"a\": 8, \"b\": 55, \"c\": 3, \"d\": 1, \"e\": 0.15}, {\"a\": 87, \"b\": 34, \"c\": 15, \"d\": 71, \"e\": 1.0}, {\"a\": 77, \"b\": 63, \"c\": 14, \"d\": 17, \"e\": 1.0}, {\"a\": 97, \"b\": 64, \"c\": 1, \"d\": 67, \"e\": 1.0}, {\"a\": 82, \"b\": 22, \"c\": 11, \"d\": 7, \"e\": 1.0}, {\"a\": 67, \"b\": 66, \"c\": 64, \"d\": 52, \"e\": 1.0}, {\"a\": 15, \"b\": 16, \"c\": 31, \"d\": 45, \"e\": 0.15}, {\"a\": 83, \"b\": 64, \"c\": 79, \"d\": 90, \"e\": 1.0}, {\"a\": 21, \"b\": 62, \"c\": 85, \"d\": 10, \"e\": 0.15}, {\"a\": 42, \"b\": 74, \"c\": 96, \"d\": 47, \"e\": 1.0}, {\"a\": 53, \"b\": 72, \"c\": 23, \"d\": 17, \"e\": 1.0}, {\"a\": 66, \"b\": 88, \"c\": 23, \"d\": 97, \"e\": 1.0}, {\"a\": 73, \"b\": 93, \"c\": 22, \"d\": 59, \"e\": 1.0}, {\"a\": 37, \"b\": 30, \"c\": 90, \"d\": 42, \"e\": 0.15}, {\"a\": 81, \"b\": 58, \"c\": 66, \"d\": 77, \"e\": 1.0}, {\"a\": 82, \"b\": 18, \"c\": 69, \"d\": 9, \"e\": 1.0}, {\"a\": 58, \"b\": 55, \"c\": 41, \"d\": 4, \"e\": 1.0}, {\"a\": 94, \"b\": 0, \"c\": 37, \"d\": 91, \"e\": 1.0}, {\"a\": 9, \"b\": 61, \"c\": 71, \"d\": 4, \"e\": 0.15}, {\"a\": 97, \"b\": 4, \"c\": 14, \"d\": 23, \"e\": 1.0}, {\"a\": 58, \"b\": 66, \"c\": 44, \"d\": 77, \"e\": 1.0}, {\"a\": 81, \"b\": 53, \"c\": 65, \"d\": 89, \"e\": 1.0}, {\"a\": 12, \"b\": 34, \"c\": 16, \"d\": 45, \"e\": 0.15}, {\"a\": 18, \"b\": 54, \"c\": 19, \"d\": 23, \"e\": 0.15}, {\"a\": 90, \"b\": 64, \"c\": 0, \"d\": 8, \"e\": 1.0}, {\"a\": 25, \"b\": 30, \"c\": 3, \"d\": 49, \"e\": 0.15}, {\"a\": 69, \"b\": 37, \"c\": 79, \"d\": 59, \"e\": 1.0}, {\"a\": 82, \"b\": 68, \"c\": 14, \"d\": 28, \"e\": 1.0}, {\"a\": 59, \"b\": 34, \"c\": 16, \"d\": 3, \"e\": 1.0}, {\"a\": 12, \"b\": 83, \"c\": 47, \"d\": 71, \"e\": 0.15}, {\"a\": 13, \"b\": 53, \"c\": 53, \"d\": 96, \"e\": 0.15}, {\"a\": 67, \"b\": 87, \"c\": 85, \"d\": 59, \"e\": 1.0}, {\"a\": 91, \"b\": 16, \"c\": 85, \"d\": 54, \"e\": 1.0}, {\"a\": 20, \"b\": 1, \"c\": 61, \"d\": 23, \"e\": 0.15}, {\"a\": 34, \"b\": 95, \"c\": 32, \"d\": 6, \"e\": 0.15}, {\"a\": 26, \"b\": 68, \"c\": 7, \"d\": 66, \"e\": 0.15}, {\"a\": 94, \"b\": 12, \"c\": 9, \"d\": 92, \"e\": 1.0}, {\"a\": 59, \"b\": 55, \"c\": 22, \"d\": 25, \"e\": 1.0}, {\"a\": 40, \"b\": 19, \"c\": 92, \"d\": 51, \"e\": 1.0}, {\"a\": 50, \"b\": 73, \"c\": 60, \"d\": 53, \"e\": 1.0}, {\"a\": 66, \"b\": 13, \"c\": 5, \"d\": 67, \"e\": 1.0}, {\"a\": 21, \"b\": 75, \"c\": 70, \"d\": 15, \"e\": 0.15}, {\"a\": 93, \"b\": 79, \"c\": 61, \"d\": 71, \"e\": 1.0}, {\"a\": 42, \"b\": 0, \"c\": 46, \"d\": 87, \"e\": 1.0}, {\"a\": 89, \"b\": 9, \"c\": 85, \"d\": 28, \"e\": 1.0}, {\"a\": 92, \"b\": 46, \"c\": 77, \"d\": 24, \"e\": 1.0}, {\"a\": 65, \"b\": 80, \"c\": 69, \"d\": 56, \"e\": 1.0}, {\"a\": 15, \"b\": 73, \"c\": 35, \"d\": 81, \"e\": 0.15}, {\"a\": 52, \"b\": 46, \"c\": 91, \"d\": 33, \"e\": 1.0}, {\"a\": 90, \"b\": 16, \"c\": 16, \"d\": 63, \"e\": 1.0}, {\"a\": 28, \"b\": 30, \"c\": 81, \"d\": 49, \"e\": 0.15}, {\"a\": 46, \"b\": 98, \"c\": 97, \"d\": 35, \"e\": 1.0}, {\"a\": 78, \"b\": 66, \"c\": 64, \"d\": 86, \"e\": 1.0}, {\"a\": 91, \"b\": 80, \"c\": 70, \"d\": 34, \"e\": 1.0}, {\"a\": 18, \"b\": 85, \"c\": 19, \"d\": 68, \"e\": 0.15}, {\"a\": 22, \"b\": 18, \"c\": 22, \"d\": 20, \"e\": 0.15}, {\"a\": 32, \"b\": 75, \"c\": 19, \"d\": 90, \"e\": 0.15}, {\"a\": 80, \"b\": 50, \"c\": 39, \"d\": 47, \"e\": 1.0}, {\"a\": 49, \"b\": 24, \"c\": 5, \"d\": 62, \"e\": 1.0}, {\"a\": 82, \"b\": 61, \"c\": 11, \"d\": 81, \"e\": 1.0}, {\"a\": 58, \"b\": 6, \"c\": 18, \"d\": 54, \"e\": 1.0}, {\"a\": 89, \"b\": 65, \"c\": 69, \"d\": 32, \"e\": 1.0}, {\"a\": 65, \"b\": 67, \"c\": 30, \"d\": 47, \"e\": 1.0}, {\"a\": 40, \"b\": 97, \"c\": 9, \"d\": 55, \"e\": 1.0}, {\"a\": 54, \"b\": 25, \"c\": 31, \"d\": 45, \"e\": 1.0}, {\"a\": 41, \"b\": 40, \"c\": 69, \"d\": 53, \"e\": 1.0}, {\"a\": 70, \"b\": 4, \"c\": 5, \"d\": 79, \"e\": 1.0}, {\"a\": 92, \"b\": 54, \"c\": 20, \"d\": 80, \"e\": 1.0}, {\"a\": 87, \"b\": 51, \"c\": 46, \"d\": 7, \"e\": 1.0}, {\"a\": 56, \"b\": 79, \"c\": 90, \"d\": 93, \"e\": 1.0}, {\"a\": 94, \"b\": 52, \"c\": 67, \"d\": 45, \"e\": 1.0}, {\"a\": 14, \"b\": 74, \"c\": 22, \"d\": 46, \"e\": 0.15}, {\"a\": 0, \"b\": 78, \"c\": 58, \"d\": 14, \"e\": 0.15}, {\"a\": 98, \"b\": 43, \"c\": 21, \"d\": 28, \"e\": 1.0}, {\"a\": 99, \"b\": 87, \"c\": 82, \"d\": 73, \"e\": 1.0}, {\"a\": 50, \"b\": 21, \"c\": 98, \"d\": 12, \"e\": 1.0}, {\"a\": 99, \"b\": 22, \"c\": 37, \"d\": 10, \"e\": 1.0}, {\"a\": 76, \"b\": 36, \"c\": 16, \"d\": 33, \"e\": 1.0}, {\"a\": 92, \"b\": 25, \"c\": 74, \"d\": 82, \"e\": 1.0}, {\"a\": 46, \"b\": 56, \"c\": 10, \"d\": 17, \"e\": 1.0}, {\"a\": 36, \"b\": 31, \"c\": 28, \"d\": 84, \"e\": 0.15}, {\"a\": 29, \"b\": 39, \"c\": 4, \"d\": 52, \"e\": 0.15}, {\"a\": 37, \"b\": 26, \"c\": 46, \"d\": 92, \"e\": 0.15}, {\"a\": 33, \"b\": 45, \"c\": 29, \"d\": 97, \"e\": 0.15}, {\"a\": 65, \"b\": 49, \"c\": 51, \"d\": 78, \"e\": 1.0}, {\"a\": 71, \"b\": 75, \"c\": 18, \"d\": 0, \"e\": 1.0}, {\"a\": 77, \"b\": 19, \"c\": 87, \"d\": 92, \"e\": 1.0}, {\"a\": 84, \"b\": 38, \"c\": 51, \"d\": 2, \"e\": 1.0}, {\"a\": 41, \"b\": 67, \"c\": 68, \"d\": 14, \"e\": 1.0}, {\"a\": 0, \"b\": 28, \"c\": 42, \"d\": 81, \"e\": 0.15}, {\"a\": 71, \"b\": 4, \"c\": 5, \"d\": 39, \"e\": 1.0}, {\"a\": 79, \"b\": 31, \"c\": 4, \"d\": 1, \"e\": 1.0}, {\"a\": 75, \"b\": 47, \"c\": 77, \"d\": 72, \"e\": 1.0}, {\"a\": 99, \"b\": 81, \"c\": 47, \"d\": 84, \"e\": 1.0}, {\"a\": 99, \"b\": 74, \"c\": 50, \"d\": 73, \"e\": 1.0}, {\"a\": 84, \"b\": 60, \"c\": 47, \"d\": 42, \"e\": 1.0}, {\"a\": 94, \"b\": 35, \"c\": 47, \"d\": 4, \"e\": 1.0}, {\"a\": 59, \"b\": 29, \"c\": 90, \"d\": 7, \"e\": 1.0}, {\"a\": 39, \"b\": 45, \"c\": 82, \"d\": 15, \"e\": 0.15}, {\"a\": 76, \"b\": 80, \"c\": 87, \"d\": 53, \"e\": 1.0}, {\"a\": 55, \"b\": 89, \"c\": 16, \"d\": 3, \"e\": 1.0}, {\"a\": 56, \"b\": 53, \"c\": 19, \"d\": 10, \"e\": 1.0}, {\"a\": 95, \"b\": 56, \"c\": 51, \"d\": 50, \"e\": 1.0}, {\"a\": 82, \"b\": 13, \"c\": 19, \"d\": 84, \"e\": 1.0}, {\"a\": 98, \"b\": 55, \"c\": 90, \"d\": 44, \"e\": 1.0}, {\"a\": 92, \"b\": 11, \"c\": 62, \"d\": 74, \"e\": 1.0}, {\"a\": 84, \"b\": 75, \"c\": 8, \"d\": 69, \"e\": 1.0}, {\"a\": 47, \"b\": 98, \"c\": 48, \"d\": 12, \"e\": 1.0}, {\"a\": 46, \"b\": 52, \"c\": 76, \"d\": 46, \"e\": 1.0}, {\"a\": 14, \"b\": 73, \"c\": 60, \"d\": 70, \"e\": 0.15}, {\"a\": 0, \"b\": 4, \"c\": 34, \"d\": 24, \"e\": 0.15}, {\"a\": 82, \"b\": 17, \"c\": 98, \"d\": 86, \"e\": 1.0}, {\"a\": 29, \"b\": 11, \"c\": 84, \"d\": 58, \"e\": 0.15}, {\"a\": 26, \"b\": 15, \"c\": 63, \"d\": 61, \"e\": 0.15}, {\"a\": 30, \"b\": 43, \"c\": 91, \"d\": 6, \"e\": 0.15}, {\"a\": 85, \"b\": 63, \"c\": 33, \"d\": 75, \"e\": 1.0}, {\"a\": 82, \"b\": 21, \"c\": 99, \"d\": 60, \"e\": 1.0}, {\"a\": 96, \"b\": 76, \"c\": 92, \"d\": 89, \"e\": 1.0}, {\"a\": 51, \"b\": 51, \"c\": 51, \"d\": 33, \"e\": 1.0}, {\"a\": 88, \"b\": 46, \"c\": 64, \"d\": 37, \"e\": 1.0}, {\"a\": 96, \"b\": 62, \"c\": 61, \"d\": 61, \"e\": 1.0}, {\"a\": 56, \"b\": 50, \"c\": 94, \"d\": 1, \"e\": 1.0}, {\"a\": 64, \"b\": 86, \"c\": 8, \"d\": 40, \"e\": 1.0}, {\"a\": 35, \"b\": 7, \"c\": 84, \"d\": 43, \"e\": 0.15}, {\"a\": 1, \"b\": 33, \"c\": 25, \"d\": 11, \"e\": 0.15}, {\"a\": 79, \"b\": 84, \"c\": 98, \"d\": 95, \"e\": 1.0}, {\"a\": 29, \"b\": 14, \"c\": 48, \"d\": 44, \"e\": 0.15}, {\"a\": 79, \"b\": 89, \"c\": 19, \"d\": 6, \"e\": 1.0}, {\"a\": 80, \"b\": 7, \"c\": 2, \"d\": 82, \"e\": 1.0}, {\"a\": 75, \"b\": 44, \"c\": 79, \"d\": 53, \"e\": 1.0}, {\"a\": 95, \"b\": 94, \"c\": 19, \"d\": 19, \"e\": 1.0}, {\"a\": 91, \"b\": 84, \"c\": 92, \"d\": 55, \"e\": 1.0}, {\"a\": 52, \"b\": 54, \"c\": 87, \"d\": 61, \"e\": 1.0}, {\"a\": 26, \"b\": 21, \"c\": 45, \"d\": 48, \"e\": 0.15}, {\"a\": 85, \"b\": 53, \"c\": 39, \"d\": 79, \"e\": 1.0}, {\"a\": 71, \"b\": 34, \"c\": 60, \"d\": 99, \"e\": 1.0}, {\"a\": 95, \"b\": 77, \"c\": 84, \"d\": 80, \"e\": 1.0}, {\"a\": 64, \"b\": 61, \"c\": 99, \"d\": 93, \"e\": 1.0}, {\"a\": 45, \"b\": 98, \"c\": 91, \"d\": 21, \"e\": 1.0}, {\"a\": 34, \"b\": 58, \"c\": 81, \"d\": 31, \"e\": 0.15}, {\"a\": 62, \"b\": 17, \"c\": 66, \"d\": 47, \"e\": 1.0}, {\"a\": 76, \"b\": 65, \"c\": 36, \"d\": 97, \"e\": 1.0}, {\"a\": 5, \"b\": 7, \"c\": 2, \"d\": 96, \"e\": 0.15}, {\"a\": 38, \"b\": 8, \"c\": 25, \"d\": 48, \"e\": 0.15}, {\"a\": 52, \"b\": 10, \"c\": 82, \"d\": 15, \"e\": 1.0}, {\"a\": 34, \"b\": 4, \"c\": 82, \"d\": 60, \"e\": 0.15}, {\"a\": 65, \"b\": 72, \"c\": 84, \"d\": 88, \"e\": 1.0}, {\"a\": 70, \"b\": 35, \"c\": 91, \"d\": 31, \"e\": 1.0}, {\"a\": 74, \"b\": 31, \"c\": 64, \"d\": 38, \"e\": 1.0}, {\"a\": 26, \"b\": 72, \"c\": 93, \"d\": 8, \"e\": 0.15}, {\"a\": 44, \"b\": 50, \"c\": 58, \"d\": 39, \"e\": 1.0}, {\"a\": 30, \"b\": 39, \"c\": 61, \"d\": 51, \"e\": 0.15}, {\"a\": 45, \"b\": 20, \"c\": 14, \"d\": 69, \"e\": 1.0}, {\"a\": 64, \"b\": 5, \"c\": 49, \"d\": 45, \"e\": 1.0}, {\"a\": 84, \"b\": 62, \"c\": 90, \"d\": 15, \"e\": 1.0}, {\"a\": 64, \"b\": 68, \"c\": 82, \"d\": 51, \"e\": 1.0}, {\"a\": 37, \"b\": 92, \"c\": 13, \"d\": 56, \"e\": 0.15}, {\"a\": 56, \"b\": 16, \"c\": 69, \"d\": 99, \"e\": 1.0}, {\"a\": 39, \"b\": 39, \"c\": 51, \"d\": 51, \"e\": 0.15}, {\"a\": 47, \"b\": 56, \"c\": 46, \"d\": 7, \"e\": 1.0}, {\"a\": 22, \"b\": 48, \"c\": 32, \"d\": 98, \"e\": 0.15}, {\"a\": 69, \"b\": 95, \"c\": 69, \"d\": 40, \"e\": 1.0}, {\"a\": 79, \"b\": 67, \"c\": 39, \"d\": 3, \"e\": 1.0}, {\"a\": 52, \"b\": 27, \"c\": 47, \"d\": 20, \"e\": 1.0}, {\"a\": 31, \"b\": 48, \"c\": 93, \"d\": 78, \"e\": 0.15}, {\"a\": 28, \"b\": 86, \"c\": 4, \"d\": 73, \"e\": 0.15}, {\"a\": 21, \"b\": 1, \"c\": 69, \"d\": 45, \"e\": 0.15}, {\"a\": 89, \"b\": 22, \"c\": 46, \"d\": 19, \"e\": 1.0}, {\"a\": 89, \"b\": 67, \"c\": 61, \"d\": 77, \"e\": 1.0}, {\"a\": 32, \"b\": 15, \"c\": 4, \"d\": 4, \"e\": 0.15}, {\"a\": 10, \"b\": 33, \"c\": 68, \"d\": 34, \"e\": 0.15}, {\"a\": 54, \"b\": 60, \"c\": 86, \"d\": 30, \"e\": 1.0}, {\"a\": 0, \"b\": 35, \"c\": 93, \"d\": 15, \"e\": 0.15}, {\"a\": 86, \"b\": 59, \"c\": 60, \"d\": 50, \"e\": 1.0}, {\"a\": 62, \"b\": 53, \"c\": 67, \"d\": 38, \"e\": 1.0}, {\"a\": 51, \"b\": 3, \"c\": 0, \"d\": 0, \"e\": 1.0}, {\"a\": 3, \"b\": 52, \"c\": 46, \"d\": 60, \"e\": 0.15}, {\"a\": 32, \"b\": 96, \"c\": 70, \"d\": 23, \"e\": 0.15}, {\"a\": 47, \"b\": 28, \"c\": 18, \"d\": 98, \"e\": 1.0}, {\"a\": 3, \"b\": 96, \"c\": 26, \"d\": 56, \"e\": 0.15}, {\"a\": 66, \"b\": 15, \"c\": 87, \"d\": 33, \"e\": 1.0}, {\"a\": 94, \"b\": 44, \"c\": 62, \"d\": 16, \"e\": 1.0}, {\"a\": 95, \"b\": 83, \"c\": 67, \"d\": 28, \"e\": 1.0}, {\"a\": 95, \"b\": 66, \"c\": 2, \"d\": 52, \"e\": 1.0}, {\"a\": 75, \"b\": 87, \"c\": 63, \"d\": 40, \"e\": 1.0}, {\"a\": 78, \"b\": 7, \"c\": 81, \"d\": 76, \"e\": 1.0}, {\"a\": 97, \"b\": 46, \"c\": 25, \"d\": 59, \"e\": 1.0}, {\"a\": 46, \"b\": 18, \"c\": 29, \"d\": 40, \"e\": 1.0}, {\"a\": 88, \"b\": 47, \"c\": 33, \"d\": 37, \"e\": 1.0}, {\"a\": 89, \"b\": 27, \"c\": 98, \"d\": 53, \"e\": 1.0}, {\"a\": 92, \"b\": 12, \"c\": 49, \"d\": 19, \"e\": 1.0}, {\"a\": 47, \"b\": 64, \"c\": 36, \"d\": 76, \"e\": 1.0}, {\"a\": 17, \"b\": 71, \"c\": 58, \"d\": 49, \"e\": 0.15}, {\"a\": 55, \"b\": 76, \"c\": 3, \"d\": 40, \"e\": 1.0}, {\"a\": 7, \"b\": 93, \"c\": 21, \"d\": 88, \"e\": 0.15}, {\"a\": 51, \"b\": 60, \"c\": 1, \"d\": 27, \"e\": 1.0}, {\"a\": 81, \"b\": 99, \"c\": 75, \"d\": 72, \"e\": 1.0}, {\"a\": 96, \"b\": 81, \"c\": 86, \"d\": 26, \"e\": 1.0}, {\"a\": 57, \"b\": 5, \"c\": 87, \"d\": 95, \"e\": 1.0}, {\"a\": 59, \"b\": 18, \"c\": 2, \"d\": 15, \"e\": 1.0}, {\"a\": 43, \"b\": 47, \"c\": 39, \"d\": 7, \"e\": 1.0}, {\"a\": 37, \"b\": 67, \"c\": 99, \"d\": 66, \"e\": 0.15}, {\"a\": 49, \"b\": 24, \"c\": 96, \"d\": 74, \"e\": 1.0}, {\"a\": 7, \"b\": 20, \"c\": 74, \"d\": 96, \"e\": 0.15}, {\"a\": 79, \"b\": 22, \"c\": 59, \"d\": 79, \"e\": 1.0}, {\"a\": 46, \"b\": 10, \"c\": 74, \"d\": 66, \"e\": 1.0}, {\"a\": 67, \"b\": 43, \"c\": 28, \"d\": 5, \"e\": 1.0}, {\"a\": 1, \"b\": 9, \"c\": 21, \"d\": 40, \"e\": 0.15}, {\"a\": 80, \"b\": 3, \"c\": 7, \"d\": 85, \"e\": 1.0}, {\"a\": 86, \"b\": 99, \"c\": 69, \"d\": 3, \"e\": 1.0}, {\"a\": 32, \"b\": 13, \"c\": 93, \"d\": 82, \"e\": 0.15}, {\"a\": 24, \"b\": 59, \"c\": 53, \"d\": 4, \"e\": 0.15}, {\"a\": 28, \"b\": 15, \"c\": 47, \"d\": 42, \"e\": 0.15}, {\"a\": 4, \"b\": 67, \"c\": 40, \"d\": 67, \"e\": 0.15}, {\"a\": 70, \"b\": 56, \"c\": 89, \"d\": 95, \"e\": 1.0}, {\"a\": 56, \"b\": 38, \"c\": 40, \"d\": 1, \"e\": 1.0}, {\"a\": 55, \"b\": 57, \"c\": 94, \"d\": 16, \"e\": 1.0}, {\"a\": 79, \"b\": 48, \"c\": 16, \"d\": 60, \"e\": 1.0}, {\"a\": 63, \"b\": 79, \"c\": 28, \"d\": 49, \"e\": 1.0}, {\"a\": 30, \"b\": 51, \"c\": 88, \"d\": 31, \"e\": 0.15}, {\"a\": 90, \"b\": 87, \"c\": 63, \"d\": 43, \"e\": 1.0}, {\"a\": 8, \"b\": 64, \"c\": 73, \"d\": 95, \"e\": 0.15}, {\"a\": 24, \"b\": 43, \"c\": 37, \"d\": 80, \"e\": 0.15}, {\"a\": 19, \"b\": 59, \"c\": 14, \"d\": 35, \"e\": 0.15}, {\"a\": 10, \"b\": 55, \"c\": 12, \"d\": 6, \"e\": 0.15}, {\"a\": 19, \"b\": 68, \"c\": 23, \"d\": 66, \"e\": 0.15}, {\"a\": 63, \"b\": 33, \"c\": 35, \"d\": 90, \"e\": 1.0}, {\"a\": 80, \"b\": 97, \"c\": 31, \"d\": 40, \"e\": 1.0}, {\"a\": 50, \"b\": 86, \"c\": 56, \"d\": 53, \"e\": 1.0}, {\"a\": 51, \"b\": 17, \"c\": 63, \"d\": 16, \"e\": 1.0}, {\"a\": 50, \"b\": 93, \"c\": 15, \"d\": 33, \"e\": 1.0}, {\"a\": 48, \"b\": 56, \"c\": 38, \"d\": 18, \"e\": 1.0}, {\"a\": 85, \"b\": 24, \"c\": 11, \"d\": 77, \"e\": 1.0}, {\"a\": 49, \"b\": 77, \"c\": 75, \"d\": 34, \"e\": 1.0}, {\"a\": 52, \"b\": 21, \"c\": 46, \"d\": 71, \"e\": 1.0}, {\"a\": 69, \"b\": 98, \"c\": 64, \"d\": 36, \"e\": 1.0}, {\"a\": 6, \"b\": 55, \"c\": 95, \"d\": 14, \"e\": 0.15}, {\"a\": 41, \"b\": 14, \"c\": 22, \"d\": 4, \"e\": 1.0}, {\"a\": 23, \"b\": 60, \"c\": 91, \"d\": 9, \"e\": 0.15}, {\"a\": 2, \"b\": 44, \"c\": 7, \"d\": 96, \"e\": 0.15}, {\"a\": 26, \"b\": 69, \"c\": 12, \"d\": 13, \"e\": 0.15}, {\"a\": 5, \"b\": 58, \"c\": 88, \"d\": 78, \"e\": 0.15}, {\"a\": 63, \"b\": 5, \"c\": 75, \"d\": 87, \"e\": 1.0}, {\"a\": 55, \"b\": 1, \"c\": 20, \"d\": 16, \"e\": 1.0}, {\"a\": 5, \"b\": 34, \"c\": 49, \"d\": 5, \"e\": 0.15}, {\"a\": 4, \"b\": 48, \"c\": 86, \"d\": 99, \"e\": 0.15}, {\"a\": 38, \"b\": 61, \"c\": 99, \"d\": 45, \"e\": 0.15}, {\"a\": 86, \"b\": 82, \"c\": 83, \"d\": 61, \"e\": 1.0}, {\"a\": 2, \"b\": 49, \"c\": 53, \"d\": 37, \"e\": 0.15}, {\"a\": 46, \"b\": 26, \"c\": 37, \"d\": 90, \"e\": 1.0}, {\"a\": 17, \"b\": 73, \"c\": 79, \"d\": 57, \"e\": 0.15}, {\"a\": 12, \"b\": 17, \"c\": 34, \"d\": 55, \"e\": 0.15}, {\"a\": 61, \"b\": 54, \"c\": 40, \"d\": 73, \"e\": 1.0}, {\"a\": 3, \"b\": 30, \"c\": 11, \"d\": 7, \"e\": 0.15}, {\"a\": 88, \"b\": 37, \"c\": 80, \"d\": 45, \"e\": 1.0}, {\"a\": 54, \"b\": 89, \"c\": 86, \"d\": 48, \"e\": 1.0}, {\"a\": 2, \"b\": 13, \"c\": 53, \"d\": 10, \"e\": 0.15}, {\"a\": 5, \"b\": 80, \"c\": 90, \"d\": 22, \"e\": 0.15}, {\"a\": 23, \"b\": 42, \"c\": 64, \"d\": 9, \"e\": 0.15}, {\"a\": 82, \"b\": 10, \"c\": 67, \"d\": 55, \"e\": 1.0}, {\"a\": 32, \"b\": 55, \"c\": 75, \"d\": 99, \"e\": 0.15}, {\"a\": 65, \"b\": 19, \"c\": 91, \"d\": 29, \"e\": 1.0}, {\"a\": 16, \"b\": 70, \"c\": 17, \"d\": 61, \"e\": 0.15}, {\"a\": 5, \"b\": 17, \"c\": 76, \"d\": 97, \"e\": 0.15}, {\"a\": 74, \"b\": 59, \"c\": 44, \"d\": 87, \"e\": 1.0}, {\"a\": 93, \"b\": 19, \"c\": 96, \"d\": 41, \"e\": 1.0}, {\"a\": 34, \"b\": 35, \"c\": 80, \"d\": 88, \"e\": 0.15}, {\"a\": 6, \"b\": 53, \"c\": 36, \"d\": 89, \"e\": 0.15}, {\"a\": 82, \"b\": 64, \"c\": 13, \"d\": 83, \"e\": 1.0}, {\"a\": 17, \"b\": 25, \"c\": 20, \"d\": 82, \"e\": 0.15}, {\"a\": 27, \"b\": 0, \"c\": 85, \"d\": 35, \"e\": 0.15}, {\"a\": 78, \"b\": 30, \"c\": 35, \"d\": 86, \"e\": 1.0}, {\"a\": 13, \"b\": 74, \"c\": 64, \"d\": 1, \"e\": 0.15}, {\"a\": 44, \"b\": 72, \"c\": 68, \"d\": 71, \"e\": 1.0}, {\"a\": 95, \"b\": 90, \"c\": 3, \"d\": 97, \"e\": 1.0}, {\"a\": 75, \"b\": 96, \"c\": 47, \"d\": 95, \"e\": 1.0}, {\"a\": 95, \"b\": 30, \"c\": 16, \"d\": 94, \"e\": 1.0}, {\"a\": 2, \"b\": 81, \"c\": 5, \"d\": 74, \"e\": 0.15}, {\"a\": 29, \"b\": 74, \"c\": 8, \"d\": 79, \"e\": 0.15}, {\"a\": 87, \"b\": 84, \"c\": 4, \"d\": 17, \"e\": 1.0}, {\"a\": 75, \"b\": 69, \"c\": 80, \"d\": 72, \"e\": 1.0}, {\"a\": 30, \"b\": 40, \"c\": 81, \"d\": 20, \"e\": 0.15}, {\"a\": 15, \"b\": 86, \"c\": 72, \"d\": 30, \"e\": 0.15}, {\"a\": 27, \"b\": 1, \"c\": 64, \"d\": 56, \"e\": 0.15}, {\"a\": 98, \"b\": 2, \"c\": 49, \"d\": 36, \"e\": 1.0}, {\"a\": 81, \"b\": 88, \"c\": 28, \"d\": 14, \"e\": 1.0}, {\"a\": 3, \"b\": 77, \"c\": 7, \"d\": 74, \"e\": 0.15}, {\"a\": 88, \"b\": 94, \"c\": 39, \"d\": 26, \"e\": 1.0}, {\"a\": 40, \"b\": 1, \"c\": 4, \"d\": 44, \"e\": 1.0}, {\"a\": 6, \"b\": 24, \"c\": 45, \"d\": 2, \"e\": 0.15}, {\"a\": 25, \"b\": 82, \"c\": 28, \"d\": 48, \"e\": 0.15}, {\"a\": 73, \"b\": 80, \"c\": 70, \"d\": 72, \"e\": 1.0}, {\"a\": 54, \"b\": 10, \"c\": 8, \"d\": 94, \"e\": 1.0}, {\"a\": 53, \"b\": 11, \"c\": 61, \"d\": 83, \"e\": 1.0}, {\"a\": 41, \"b\": 58, \"c\": 5, \"d\": 46, \"e\": 1.0}, {\"a\": 93, \"b\": 88, \"c\": 71, \"d\": 11, \"e\": 1.0}, {\"a\": 49, \"b\": 62, \"c\": 15, \"d\": 12, \"e\": 1.0}, {\"a\": 1, \"b\": 93, \"c\": 13, \"d\": 98, \"e\": 0.15}, {\"a\": 35, \"b\": 61, \"c\": 56, \"d\": 3, \"e\": 0.15}, {\"a\": 43, \"b\": 69, \"c\": 53, \"d\": 63, \"e\": 1.0}, {\"a\": 28, \"b\": 36, \"c\": 25, \"d\": 68, \"e\": 0.15}, {\"a\": 62, \"b\": 5, \"c\": 70, \"d\": 59, \"e\": 1.0}, {\"a\": 45, \"b\": 0, \"c\": 57, \"d\": 13, \"e\": 1.0}, {\"a\": 56, \"b\": 68, \"c\": 83, \"d\": 90, \"e\": 1.0}, {\"a\": 10, \"b\": 87, \"c\": 46, \"d\": 2, \"e\": 0.15}, {\"a\": 64, \"b\": 94, \"c\": 25, \"d\": 72, \"e\": 1.0}, {\"a\": 60, \"b\": 46, \"c\": 67, \"d\": 14, \"e\": 1.0}, {\"a\": 28, \"b\": 92, \"c\": 80, \"d\": 74, \"e\": 0.15}, {\"a\": 3, \"b\": 62, \"c\": 56, \"d\": 16, \"e\": 0.15}, {\"a\": 78, \"b\": 58, \"c\": 85, \"d\": 75, \"e\": 1.0}, {\"a\": 82, \"b\": 66, \"c\": 29, \"d\": 3, \"e\": 1.0}, {\"a\": 42, \"b\": 81, \"c\": 59, \"d\": 66, \"e\": 1.0}, {\"a\": 83, \"b\": 74, \"c\": 18, \"d\": 40, \"e\": 1.0}, {\"a\": 8, \"b\": 17, \"c\": 98, \"d\": 77, \"e\": 0.15}, {\"a\": 29, \"b\": 30, \"c\": 68, \"d\": 88, \"e\": 0.15}, {\"a\": 88, \"b\": 45, \"c\": 83, \"d\": 54, \"e\": 1.0}, {\"a\": 91, \"b\": 15, \"c\": 62, \"d\": 76, \"e\": 1.0}, {\"a\": 49, \"b\": 14, \"c\": 31, \"d\": 58, \"e\": 1.0}, {\"a\": 8, \"b\": 36, \"c\": 85, \"d\": 54, \"e\": 0.15}, {\"a\": 8, \"b\": 63, \"c\": 8, \"d\": 77, \"e\": 0.15}, {\"a\": 34, \"b\": 8, \"c\": 69, \"d\": 50, \"e\": 0.15}, {\"a\": 92, \"b\": 30, \"c\": 2, \"d\": 71, \"e\": 1.0}, {\"a\": 64, \"b\": 48, \"c\": 35, \"d\": 89, \"e\": 1.0}, {\"a\": 20, \"b\": 31, \"c\": 15, \"d\": 62, \"e\": 0.15}, {\"a\": 60, \"b\": 2, \"c\": 36, \"d\": 9, \"e\": 1.0}, {\"a\": 56, \"b\": 19, \"c\": 94, \"d\": 84, \"e\": 1.0}, {\"a\": 30, \"b\": 22, \"c\": 11, \"d\": 72, \"e\": 0.15}, {\"a\": 95, \"b\": 98, \"c\": 12, \"d\": 90, \"e\": 1.0}, {\"a\": 61, \"b\": 97, \"c\": 97, \"d\": 28, \"e\": 1.0}, {\"a\": 45, \"b\": 92, \"c\": 96, \"d\": 4, \"e\": 1.0}, {\"a\": 90, \"b\": 64, \"c\": 65, \"d\": 78, \"e\": 1.0}, {\"a\": 26, \"b\": 91, \"c\": 13, \"d\": 2, \"e\": 0.15}, {\"a\": 90, \"b\": 16, \"c\": 27, \"d\": 62, \"e\": 1.0}, {\"a\": 39, \"b\": 9, \"c\": 68, \"d\": 7, \"e\": 0.15}, {\"a\": 92, \"b\": 36, \"c\": 57, \"d\": 48, \"e\": 1.0}, {\"a\": 68, \"b\": 62, \"c\": 93, \"d\": 11, \"e\": 1.0}, {\"a\": 89, \"b\": 26, \"c\": 25, \"d\": 87, \"e\": 1.0}, {\"a\": 47, \"b\": 3, \"c\": 34, \"d\": 68, \"e\": 1.0}, {\"a\": 71, \"b\": 17, \"c\": 81, \"d\": 20, \"e\": 1.0}, {\"a\": 98, \"b\": 42, \"c\": 2, \"d\": 58, \"e\": 1.0}, {\"a\": 89, \"b\": 63, \"c\": 9, \"d\": 38, \"e\": 1.0}, {\"a\": 80, \"b\": 34, \"c\": 27, \"d\": 21, \"e\": 1.0}, {\"a\": 68, \"b\": 11, \"c\": 77, \"d\": 26, \"e\": 1.0}, {\"a\": 80, \"b\": 96, \"c\": 54, \"d\": 39, \"e\": 1.0}, {\"a\": 80, \"b\": 83, \"c\": 8, \"d\": 38, \"e\": 1.0}, {\"a\": 20, \"b\": 49, \"c\": 94, \"d\": 58, \"e\": 0.15}, {\"a\": 62, \"b\": 76, \"c\": 80, \"d\": 22, \"e\": 1.0}, {\"a\": 99, \"b\": 40, \"c\": 28, \"d\": 33, \"e\": 1.0}, {\"a\": 50, \"b\": 42, \"c\": 33, \"d\": 92, \"e\": 1.0}, {\"a\": 69, \"b\": 91, \"c\": 48, \"d\": 18, \"e\": 1.0}, {\"a\": 27, \"b\": 15, \"c\": 48, \"d\": 92, \"e\": 0.15}, {\"a\": 56, \"b\": 83, \"c\": 5, \"d\": 51, \"e\": 1.0}, {\"a\": 80, \"b\": 44, \"c\": 41, \"d\": 44, \"e\": 1.0}, {\"a\": 21, \"b\": 26, \"c\": 47, \"d\": 40, \"e\": 0.15}, {\"a\": 19, \"b\": 10, \"c\": 21, \"d\": 26, \"e\": 0.15}, {\"a\": 77, \"b\": 76, \"c\": 4, \"d\": 3, \"e\": 1.0}, {\"a\": 37, \"b\": 9, \"c\": 75, \"d\": 74, \"e\": 0.15}, {\"a\": 27, \"b\": 39, \"c\": 89, \"d\": 46, \"e\": 0.15}, {\"a\": 22, \"b\": 65, \"c\": 70, \"d\": 73, \"e\": 0.15}, {\"a\": 84, \"b\": 89, \"c\": 26, \"d\": 4, \"e\": 1.0}, {\"a\": 66, \"b\": 76, \"c\": 10, \"d\": 76, \"e\": 1.0}, {\"a\": 0, \"b\": 22, \"c\": 20, \"d\": 22, \"e\": 0.15}, {\"a\": 24, \"b\": 34, \"c\": 63, \"d\": 29, \"e\": 0.15}, {\"a\": 29, \"b\": 86, \"c\": 17, \"d\": 80, \"e\": 0.15}, {\"a\": 97, \"b\": 7, \"c\": 33, \"d\": 14, \"e\": 1.0}, {\"a\": 96, \"b\": 79, \"c\": 87, \"d\": 3, \"e\": 1.0}, {\"a\": 84, \"b\": 28, \"c\": 22, \"d\": 4, \"e\": 1.0}, {\"a\": 9, \"b\": 73, \"c\": 48, \"d\": 44, \"e\": 0.15}, {\"a\": 50, \"b\": 11, \"c\": 17, \"d\": 54, \"e\": 1.0}, {\"a\": 48, \"b\": 93, \"c\": 29, \"d\": 73, \"e\": 1.0}, {\"a\": 33, \"b\": 72, \"c\": 73, \"d\": 14, \"e\": 0.15}, {\"a\": 8, \"b\": 94, \"c\": 1, \"d\": 95, \"e\": 0.15}, {\"a\": 71, \"b\": 75, \"c\": 49, \"d\": 95, \"e\": 1.0}, {\"a\": 82, \"b\": 90, \"c\": 64, \"d\": 59, \"e\": 1.0}, {\"a\": 1, \"b\": 8, \"c\": 95, \"d\": 55, \"e\": 0.15}, {\"a\": 80, \"b\": 36, \"c\": 23, \"d\": 25, \"e\": 1.0}, {\"a\": 98, \"b\": 13, \"c\": 63, \"d\": 5, \"e\": 1.0}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 13,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "alt.Chart(rand_df2).mark_circle().encode(\n",
    "    x = \"a\",\n",
    "    y = \"b\",\n",
    "    color = \"c\",\n",
    "    size = \"d\",\n",
    "    opacity = alt.Opacity(\"e\",scale=None),\n",
    "    tooltip = [\"a\",\"b\",\"c\",\"d\",\"e\"],\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "fef377b5",
   "metadata": {},
   "source": [
    "## Example with data from Spotify\n",
    "Here we use the `spotify_dataset.csv` file from Canvas. The dataset originally came from Kaggle [here](https://www.kaggle.com/sashankpillai/spotify-top-200-charts-20202021).  The Kaggle page includes a description of the columns.\n",
    "\n",
    "We perform some \"cleaning\" of the dataset.  By the end of Math 10, all of the following cell should be understandable, but for now, you shouldn't worry about the details of this \"cleaning\".\n",
    "\n",
    "**Important**: You may need to change the path from `data/spotify_dataset.csv`, depending on where you have this csv file stored."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 14,
   "id": "200e1c9d",
   "metadata": {},
   "outputs": [],
   "source": [
    "df = pd.read_csv(\"../data/spotify_dataset.csv\") # change path if necessary\n",
    "df = df.replace(\" \",np.nan)\n",
    "df[\"Streams\"] = df[\"Streams\"].str.replace(\",\",\"\")\n",
    "df.iloc[:,[5,7]] = df.iloc[:,[5,7]].apply(pd.to_numeric,axis=0).copy()\n",
    "df.iloc[:,12:22] = df.iloc[:,12:22].apply(pd.to_numeric,axis=0).copy()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 15,
   "id": "0678f2b9",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>Index</th>\n",
       "      <th>Highest Charting Position</th>\n",
       "      <th>Number of Times Charted</th>\n",
       "      <th>Week of Highest Charting</th>\n",
       "      <th>Song Name</th>\n",
       "      <th>Streams</th>\n",
       "      <th>Artist</th>\n",
       "      <th>Artist Followers</th>\n",
       "      <th>Song ID</th>\n",
       "      <th>Genre</th>\n",
       "      <th>...</th>\n",
       "      <th>Danceability</th>\n",
       "      <th>Energy</th>\n",
       "      <th>Loudness</th>\n",
       "      <th>Speechiness</th>\n",
       "      <th>Acousticness</th>\n",
       "      <th>Liveness</th>\n",
       "      <th>Tempo</th>\n",
       "      <th>Duration (ms)</th>\n",
       "      <th>Valence</th>\n",
       "      <th>Chord</th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>1</td>\n",
       "      <td>1</td>\n",
       "      <td>8</td>\n",
       "      <td>2021-07-23--2021-07-30</td>\n",
       "      <td>Beggin'</td>\n",
       "      <td>48633449</td>\n",
       "      <td>Måneskin</td>\n",
       "      <td>3377762.0</td>\n",
       "      <td>3Wrjm47oTz2sjIgck11l5e</td>\n",
       "      <td>['indie rock italiano', 'italian pop']</td>\n",
       "      <td>...</td>\n",
       "      <td>0.714</td>\n",
       "      <td>0.800</td>\n",
       "      <td>-4.808</td>\n",
       "      <td>0.0504</td>\n",
       "      <td>0.1270</td>\n",
       "      <td>0.3590</td>\n",
       "      <td>134.002</td>\n",
       "      <td>211560.0</td>\n",
       "      <td>0.589</td>\n",
       "      <td>B</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>2</td>\n",
       "      <td>2</td>\n",
       "      <td>3</td>\n",
       "      <td>2021-07-23--2021-07-30</td>\n",
       "      <td>STAY (with Justin Bieber)</td>\n",
       "      <td>47248719</td>\n",
       "      <td>The Kid LAROI</td>\n",
       "      <td>2230022.0</td>\n",
       "      <td>5HCyWlXZPP0y6Gqq8TgA20</td>\n",
       "      <td>['australian hip hop']</td>\n",
       "      <td>...</td>\n",
       "      <td>0.591</td>\n",
       "      <td>0.764</td>\n",
       "      <td>-5.484</td>\n",
       "      <td>0.0483</td>\n",
       "      <td>0.0383</td>\n",
       "      <td>0.1030</td>\n",
       "      <td>169.928</td>\n",
       "      <td>141806.0</td>\n",
       "      <td>0.478</td>\n",
       "      <td>C#/Db</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>3</td>\n",
       "      <td>1</td>\n",
       "      <td>11</td>\n",
       "      <td>2021-06-25--2021-07-02</td>\n",
       "      <td>good 4 u</td>\n",
       "      <td>40162559</td>\n",
       "      <td>Olivia Rodrigo</td>\n",
       "      <td>6266514.0</td>\n",
       "      <td>4ZtFanR9U6ndgddUvNcjcG</td>\n",
       "      <td>['pop']</td>\n",
       "      <td>...</td>\n",
       "      <td>0.563</td>\n",
       "      <td>0.664</td>\n",
       "      <td>-5.044</td>\n",
       "      <td>0.1540</td>\n",
       "      <td>0.3350</td>\n",
       "      <td>0.0849</td>\n",
       "      <td>166.928</td>\n",
       "      <td>178147.0</td>\n",
       "      <td>0.688</td>\n",
       "      <td>A</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>4</td>\n",
       "      <td>3</td>\n",
       "      <td>5</td>\n",
       "      <td>2021-07-02--2021-07-09</td>\n",
       "      <td>Bad Habits</td>\n",
       "      <td>37799456</td>\n",
       "      <td>Ed Sheeran</td>\n",
       "      <td>83293380.0</td>\n",
       "      <td>6PQ88X9TkUIAUIZJHW2upE</td>\n",
       "      <td>['pop', 'uk pop']</td>\n",
       "      <td>...</td>\n",
       "      <td>0.808</td>\n",
       "      <td>0.897</td>\n",
       "      <td>-3.712</td>\n",
       "      <td>0.0348</td>\n",
       "      <td>0.0469</td>\n",
       "      <td>0.3640</td>\n",
       "      <td>126.026</td>\n",
       "      <td>231041.0</td>\n",
       "      <td>0.591</td>\n",
       "      <td>B</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>4</th>\n",
       "      <td>5</td>\n",
       "      <td>5</td>\n",
       "      <td>1</td>\n",
       "      <td>2021-07-23--2021-07-30</td>\n",
       "      <td>INDUSTRY BABY (feat. Jack Harlow)</td>\n",
       "      <td>33948454</td>\n",
       "      <td>Lil Nas X</td>\n",
       "      <td>5473565.0</td>\n",
       "      <td>27NovPIUIRrOZoCHxABJwK</td>\n",
       "      <td>['lgbtq+ hip hop', 'pop rap']</td>\n",
       "      <td>...</td>\n",
       "      <td>0.736</td>\n",
       "      <td>0.704</td>\n",
       "      <td>-7.409</td>\n",
       "      <td>0.0615</td>\n",
       "      <td>0.0203</td>\n",
       "      <td>0.0501</td>\n",
       "      <td>149.995</td>\n",
       "      <td>212000.0</td>\n",
       "      <td>0.894</td>\n",
       "      <td>D#/Eb</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "<p>5 rows × 23 columns</p>\n",
       "</div>"
      ],
      "text/plain": [
       "   Index  Highest Charting Position  Number of Times Charted  \\\n",
       "0      1                          1                        8   \n",
       "1      2                          2                        3   \n",
       "2      3                          1                       11   \n",
       "3      4                          3                        5   \n",
       "4      5                          5                        1   \n",
       "\n",
       "  Week of Highest Charting                          Song Name   Streams  \\\n",
       "0   2021-07-23--2021-07-30                            Beggin'  48633449   \n",
       "1   2021-07-23--2021-07-30          STAY (with Justin Bieber)  47248719   \n",
       "2   2021-06-25--2021-07-02                           good 4 u  40162559   \n",
       "3   2021-07-02--2021-07-09                         Bad Habits  37799456   \n",
       "4   2021-07-23--2021-07-30  INDUSTRY BABY (feat. Jack Harlow)  33948454   \n",
       "\n",
       "           Artist  Artist Followers                 Song ID  \\\n",
       "0        Måneskin         3377762.0  3Wrjm47oTz2sjIgck11l5e   \n",
       "1   The Kid LAROI         2230022.0  5HCyWlXZPP0y6Gqq8TgA20   \n",
       "2  Olivia Rodrigo         6266514.0  4ZtFanR9U6ndgddUvNcjcG   \n",
       "3      Ed Sheeran        83293380.0  6PQ88X9TkUIAUIZJHW2upE   \n",
       "4       Lil Nas X         5473565.0  27NovPIUIRrOZoCHxABJwK   \n",
       "\n",
       "                                    Genre  ... Danceability Energy  Loudness  \\\n",
       "0  ['indie rock italiano', 'italian pop']  ...        0.714  0.800    -4.808   \n",
       "1                  ['australian hip hop']  ...        0.591  0.764    -5.484   \n",
       "2                                 ['pop']  ...        0.563  0.664    -5.044   \n",
       "3                       ['pop', 'uk pop']  ...        0.808  0.897    -3.712   \n",
       "4           ['lgbtq+ hip hop', 'pop rap']  ...        0.736  0.704    -7.409   \n",
       "\n",
       "   Speechiness  Acousticness  Liveness    Tempo  Duration (ms)  Valence  Chord  \n",
       "0       0.0504        0.1270    0.3590  134.002       211560.0    0.589      B  \n",
       "1       0.0483        0.0383    0.1030  169.928       141806.0    0.478  C#/Db  \n",
       "2       0.1540        0.3350    0.0849  166.928       178147.0    0.688      A  \n",
       "3       0.0348        0.0469    0.3640  126.026       231041.0    0.591      B  \n",
       "4       0.0615        0.0203    0.0501  149.995       212000.0    0.894  D#/Eb  \n",
       "\n",
       "[5 rows x 23 columns]"
      ]
     },
     "execution_count": 15,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "df.head()"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "361d2f4f",
   "metadata": {},
   "source": [
    "If there are more than 5000 rows, then we need to do some data preprocessing before giving the DataFrame to Altair.  But in this case, there are only 1556 rows."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 16,
   "id": "898c1e2d",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "(1556, 23)"
      ]
     },
     "execution_count": 16,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "df.shape"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "58491c75",
   "metadata": {},
   "source": [
    "If a column has type `object`, that often means it is a string, even if the values look numerical.  If you're having a hard time plotting data, make sure the values are numbers and not strings.  The main point of the data-cleaning we did above was to make more of the columns numerical.  Of course, a column like *Song Name* is never going to be numerical."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 17,
   "id": "2fda62e1",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "Index                          int64\n",
       "Highest Charting Position      int64\n",
       "Number of Times Charted        int64\n",
       "Week of Highest Charting      object\n",
       "Song Name                     object\n",
       "Streams                        int64\n",
       "Artist                        object\n",
       "Artist Followers             float64\n",
       "Song ID                       object\n",
       "Genre                         object\n",
       "Release Date                  object\n",
       "Weeks Charted                 object\n",
       "Popularity                   float64\n",
       "Danceability                 float64\n",
       "Energy                       float64\n",
       "Loudness                     float64\n",
       "Speechiness                  float64\n",
       "Acousticness                 float64\n",
       "Liveness                     float64\n",
       "Tempo                        float64\n",
       "Duration (ms)                float64\n",
       "Valence                      float64\n",
       "Chord                         object\n",
       "dtype: object"
      ]
     },
     "execution_count": 17,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "df.dtypes"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "be6e21a4",
   "metadata": {},
   "source": [
    "### Scatter plot"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "9e43a081",
   "metadata": {},
   "source": [
    "The following Altair chart is just like what we made above with our random DataFrame.  We again use the column names to specify which parts of the data to use.  Before we used column names like \"a\" and \"b\".  Here the column names are more descriptive, like \"Energy\" and \"Loudness\"."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 18,
   "id": "5124efbe",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-9f3485bf40204f339955766513dc263a\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-9f3485bf40204f339955766513dc263a\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-9f3485bf40204f339955766513dc263a\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-67c9fb159873386c9c7303ca2ad81ad2\"}, \"mark\": \"circle\", \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"Acousticness\"}, \"tooltip\": [{\"type\": \"nominal\", \"field\": \"Artist\"}, {\"type\": \"nominal\", \"field\": \"Song Name\"}, {\"type\": \"nominal\", \"field\": \"Release Date\"}, {\"type\": \"nominal\", \"field\": \"Chord\"}], \"x\": {\"type\": \"quantitative\", \"field\": \"Energy\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"Loudness\"}}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-67c9fb159873386c9c7303ca2ad81ad2\": [{\"Index\": 1, \"Highest Charting Position\": 1, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Beggin'\", \"Streams\": 48633449, \"Artist\": \"M\\u00e5neskin\", \"Artist Followers\": 3377762.0, \"Song ID\": \"3Wrjm47oTz2sjIgck11l5e\", \"Genre\": \"['indie rock italiano', 'italian pop']\", \"Release Date\": \"2017-12-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 100.0, \"Danceability\": 0.714, \"Energy\": 0.8, \"Loudness\": -4.808, \"Speechiness\": 0.0504, \"Acousticness\": 0.127, \"Liveness\": 0.359, \"Tempo\": 134.002, \"Duration (ms)\": 211560.0, \"Valence\": 0.589, \"Chord\": \"B\"}, {\"Index\": 2, \"Highest Charting Position\": 2, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"STAY (with Justin Bieber)\", \"Streams\": 47248719, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2230022.0, \"Song ID\": \"5HCyWlXZPP0y6Gqq8TgA20\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 99.0, \"Danceability\": 0.591, \"Energy\": 0.764, \"Loudness\": -5.484, \"Speechiness\": 0.0483, \"Acousticness\": 0.0383, \"Liveness\": 0.103, \"Tempo\": 169.928, \"Duration (ms)\": 141806.0, \"Valence\": 0.478, \"Chord\": \"C#/Db\"}, {\"Index\": 3, \"Highest Charting Position\": 1, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"good 4 u\", \"Streams\": 40162559, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"4ZtFanR9U6ndgddUvNcjcG\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 99.0, \"Danceability\": 0.563, \"Energy\": 0.664, \"Loudness\": -5.044, \"Speechiness\": 0.154, \"Acousticness\": 0.335, \"Liveness\": 0.0849, \"Tempo\": 166.928, \"Duration (ms)\": 178147.0, \"Valence\": 0.688, \"Chord\": \"A\"}, {\"Index\": 4, \"Highest Charting Position\": 3, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Bad Habits\", \"Streams\": 37799456, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83293380.0, \"Song ID\": \"6PQ88X9TkUIAUIZJHW2upE\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 98.0, \"Danceability\": 0.808, \"Energy\": 0.897, \"Loudness\": -3.712, \"Speechiness\": 0.0348, \"Acousticness\": 0.0469, \"Liveness\": 0.364, \"Tempo\": 126.026, \"Duration (ms)\": 231041.0, \"Valence\": 0.591, \"Chord\": \"B\"}, {\"Index\": 5, \"Highest Charting Position\": 5, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"INDUSTRY BABY (feat. Jack Harlow)\", \"Streams\": 33948454, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5473565.0, \"Song ID\": \"27NovPIUIRrOZoCHxABJwK\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2021-07-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 96.0, \"Danceability\": 0.736, \"Energy\": 0.704, \"Loudness\": -7.409, \"Speechiness\": 0.0615, \"Acousticness\": 0.0203, \"Liveness\": 0.0501, \"Tempo\": 149.995, \"Duration (ms)\": 212000.0, \"Valence\": 0.894, \"Chord\": \"D#/Eb\"}, {\"Index\": 6, \"Highest Charting Position\": 1, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"MONTERO (Call Me By Your Name)\", \"Streams\": 30071134, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5473565.0, \"Song ID\": \"67BtfxlNbhBmCDR2L2l8qd\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2021-03-31\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 97.0, \"Danceability\": 0.61, \"Energy\": 0.508, \"Loudness\": -6.682, \"Speechiness\": 0.152, \"Acousticness\": 0.297, \"Liveness\": 0.384, \"Tempo\": 178.818, \"Duration (ms)\": 137876.0, \"Valence\": 0.758, \"Chord\": \"G#/Ab\"}, {\"Index\": 7, \"Highest Charting Position\": 3, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Kiss Me More (feat. SZA)\", \"Streams\": 29356736, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"748mdHapucXQri7IAO8yFK\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 94.0, \"Danceability\": 0.762, \"Energy\": 0.701, \"Loudness\": -3.541, \"Speechiness\": 0.0286, \"Acousticness\": 0.235, \"Liveness\": 0.123, \"Tempo\": 110.968, \"Duration (ms)\": 208867.0, \"Valence\": 0.742, \"Chord\": \"G#/Ab\"}, {\"Index\": 8, \"Highest Charting Position\": 2, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Todo De Ti\", \"Streams\": 26951613, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6080597.0, \"Song ID\": \"4fSIb4hdOQ151TILNsSEaF\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2021-05-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 95.0, \"Danceability\": 0.78, \"Energy\": 0.718, \"Loudness\": -3.605, \"Speechiness\": 0.0506, \"Acousticness\": 0.31, \"Liveness\": 0.0932, \"Tempo\": 127.949, \"Duration (ms)\": 199604.0, \"Valence\": 0.342, \"Chord\": \"D#/Eb\"}, {\"Index\": 9, \"Highest Charting Position\": 3, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Yonaguni\", \"Streams\": 25030128, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36142273.0, \"Song ID\": \"2JPLbjOn0wPCngEot2STUS\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 96.0, \"Danceability\": 0.644, \"Energy\": 0.648, \"Loudness\": -4.601, \"Speechiness\": 0.118, \"Acousticness\": 0.276, \"Liveness\": 0.135, \"Tempo\": 179.951, \"Duration (ms)\": 206710.0, \"Valence\": 0.44, \"Chord\": \"C#/Db\"}, {\"Index\": 10, \"Highest Charting Position\": 8, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"I WANNA BE YOUR SLAVE\", \"Streams\": 24551591, \"Artist\": \"M\\u00e5neskin\", \"Artist Followers\": 3377762.0, \"Song ID\": \"4pt5fDVTg5GhEvEtlz9dKk\", \"Genre\": \"['indie rock italiano', 'italian pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 95.0, \"Danceability\": 0.75, \"Energy\": 0.608, \"Loudness\": -4.008, \"Speechiness\": 0.0387, \"Acousticness\": 0.00165, \"Liveness\": 0.178, \"Tempo\": 132.507, \"Duration (ms)\": 173347.0, \"Valence\": 0.958, \"Chord\": \"C#/Db\"}, {\"Index\": 11, \"Highest Charting Position\": 4, \"Number of Times Charted\": 43, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Levitating (feat. DaBaby)\", \"Streams\": 23518010, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"463CkQjx2Zk1yXoBuierM9\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-10-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 89.0, \"Danceability\": 0.702, \"Energy\": 0.825, \"Loudness\": -3.787, \"Speechiness\": 0.0601, \"Acousticness\": 0.00883, \"Liveness\": 0.0674, \"Tempo\": 102.977, \"Duration (ms)\": 203064.0, \"Valence\": 0.915, \"Chord\": \"F#/Gb\"}, {\"Index\": 12, \"Highest Charting Position\": 9, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Qu\\u00e9 M\\u00e1s Pues?\", \"Streams\": 22405111, \"Artist\": \"J Balvin, Maria Becerra\", \"Artist Followers\": 29051363.0, \"Song ID\": \"6hf0RpxTbOprT5nnwzkk8e\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\", \"Popularity\": 95.0, \"Danceability\": 0.891, \"Energy\": 0.819, \"Loudness\": -3.964, \"Speechiness\": 0.106, \"Acousticness\": 0.0261, \"Liveness\": 0.173, \"Tempo\": 101.968, \"Duration (ms)\": 217773.0, \"Valence\": 0.768, \"Chord\": \"G#/Ab\"}, {\"Index\": 13, \"Highest Charting Position\": 5, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Permission to Dance\", \"Streams\": 22062812, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"0LThjFY2iTtNdd4wviwVV2\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 95.0, \"Danceability\": 0.702, \"Energy\": 0.741, \"Loudness\": -5.33, \"Speechiness\": 0.0427, \"Acousticness\": 0.00544, \"Liveness\": 0.337, \"Tempo\": 124.925, \"Duration (ms)\": 187585.0, \"Valence\": 0.646, \"Chord\": \"A\"}, {\"Index\": 14, \"Highest Charting Position\": 1, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Peaches (feat. Daniel Caesar & Giveon)\", \"Streams\": 20294457, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48504126.0, \"Song ID\": \"4iJyoBOLtHqaGxP12qzhQI\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 94.0, \"Danceability\": 0.677, \"Energy\": 0.696, \"Loudness\": -6.181, \"Speechiness\": 0.119, \"Acousticness\": 0.321, \"Liveness\": 0.42, \"Tempo\": 90.03, \"Duration (ms)\": 198082.0, \"Valence\": 0.464, \"Chord\": \"C\"}, {\"Index\": 15, \"Highest Charting Position\": 2, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Butter\", \"Streams\": 19985713, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"2bgTY4UwhfBYhGT4HUYStN\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 95.0, \"Danceability\": 0.759, \"Energy\": 0.459, \"Loudness\": -5.187, \"Speechiness\": 0.0948, \"Acousticness\": 0.00323, \"Liveness\": 0.0906, \"Tempo\": 109.997, \"Duration (ms)\": 164442.0, \"Valence\": 0.695, \"Chord\": \"G#/Ab\"}, {\"Index\": 16, \"Highest Charting Position\": 7, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"traitor\", \"Streams\": 19480679, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"5CZ40GBx1sQ9agT82CLQCT\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 94.0, \"Danceability\": 0.38, \"Energy\": 0.339, \"Loudness\": -7.885, \"Speechiness\": 0.0338, \"Acousticness\": 0.691, \"Liveness\": 0.12, \"Tempo\": 100.607, \"Duration (ms)\": 229227.0, \"Valence\": 0.0849, \"Chord\": \"D#/Eb\"}, {\"Index\": 17, \"Highest Charting Position\": 3, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"deja vu\", \"Streams\": 18571755, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"6HU7h9RYOaPRFeh0R3UeAr\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 93.0, \"Danceability\": 0.442, \"Energy\": 0.612, \"Loudness\": -7.222, \"Speechiness\": 0.112, \"Acousticness\": 0.584, \"Liveness\": 0.37, \"Tempo\": 180.917, \"Duration (ms)\": 215507.0, \"Valence\": 0.178, \"Chord\": \"D\"}, {\"Index\": 18, \"Highest Charting Position\": 5, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Save Your Tears (with Ariana Grande) (Remix)\", \"Streams\": 18053141, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"37BZB0z9T8Xu7U3e65qxFy\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 94.0, \"Danceability\": 0.65, \"Energy\": 0.825, \"Loudness\": -4.645, \"Speechiness\": 0.0325, \"Acousticness\": 0.0215, \"Liveness\": 0.0936, \"Tempo\": 118.091, \"Duration (ms)\": 191014.0, \"Valence\": 0.593, \"Chord\": \"C\"}, {\"Index\": 19, \"Highest Charting Position\": 14, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"AM Remix\", \"Streams\": 17617965, \"Artist\": \"Nio Garcia, J Balvin, Bad Bunny\", \"Artist Followers\": 2123734.0, \"Song ID\": \"05bfbizlM5AX6Mf1RRyMho\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-24\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 93.0, \"Danceability\": 0.743, \"Energy\": 0.655, \"Loudness\": -5.015, \"Speechiness\": 0.159, \"Acousticness\": 0.114, \"Liveness\": 0.0764, \"Tempo\": 172.031, \"Duration (ms)\": 261335.0, \"Valence\": 0.785, \"Chord\": \"F#/Gb\"}, {\"Index\": 20, \"Highest Charting Position\": 20, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Need To Know\", \"Streams\": 16908917, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"3Vi5XqYrmQgOYBajMWSvCi\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 90.0, \"Danceability\": 0.664, \"Energy\": 0.609, \"Loudness\": -6.509, \"Speechiness\": 0.0707, \"Acousticness\": 0.304, \"Liveness\": 0.0926, \"Tempo\": 130.041, \"Duration (ms)\": 210560.0, \"Valence\": 0.194, \"Chord\": \"C#/Db\"}, {\"Index\": 21, \"Highest Charting Position\": 19, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Volando - Remix\", \"Streams\": 16606925, \"Artist\": \"Mora, Bad Bunny, Sech\", \"Artist Followers\": 151486.0, \"Song ID\": \"0G2zPzWqVjR68iNPmx2TBe\", \"Genre\": \"['reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 91.0, \"Danceability\": 0.659, \"Energy\": 0.688, \"Loudness\": -4.649, \"Speechiness\": 0.0673, \"Acousticness\": 0.207, \"Liveness\": 0.113, \"Tempo\": 153.979, \"Duration (ms)\": 273474.0, \"Valence\": 0.632, \"Chord\": \"F#/Gb\"}, {\"Index\": 22, \"Highest Charting Position\": 22, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Ain't Shit\", \"Streams\": 16126897, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"5lAnYvAIkSDNXqfo7DyFUm\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 90.0, \"Danceability\": 0.855, \"Energy\": 0.488, \"Loudness\": -4.601, \"Speechiness\": 0.208, \"Acousticness\": 0.506, \"Liveness\": 0.347, \"Tempo\": 124.097, \"Duration (ms)\": 174253.0, \"Valence\": 0.619, \"Chord\": \"D#/Eb\"}, {\"Index\": 23, \"Highest Charting Position\": 1, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"drivers license\", \"Streams\": 15684978, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"5wANPM4fQCJwkGd4rN57mH\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 92.0, \"Danceability\": 0.561, \"Energy\": 0.431, \"Loudness\": -8.81, \"Speechiness\": 0.0578, \"Acousticness\": 0.768, \"Liveness\": 0.106, \"Tempo\": 143.875, \"Duration (ms)\": 242013.0, \"Valence\": 0.137, \"Chord\": \"A#/Bb\"}, {\"Index\": 24, \"Highest Charting Position\": 24, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Heat Waves\", \"Streams\": 15089184, \"Artist\": \"Glass Animals\", \"Artist Followers\": 1890510.0, \"Song ID\": \"3USxtqRwSYz57Ewm6wWRMp\", \"Genre\": \"['gauze pop', 'indietronica', 'shiver pop']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 85.0, \"Danceability\": 0.761, \"Energy\": 0.525, \"Loudness\": -6.9, \"Speechiness\": 0.0944, \"Acousticness\": 0.44, \"Liveness\": 0.0921, \"Tempo\": 80.87, \"Duration (ms)\": 238805.0, \"Valence\": 0.531, \"Chord\": \"B\"}, {\"Index\": 25, \"Highest Charting Position\": 1, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Blinding Lights\", \"Streams\": 15011809, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"0VjIjW4GlUZAMYd2vXMi3b\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 92.0, \"Danceability\": 0.514, \"Energy\": 0.73, \"Loudness\": -5.934, \"Speechiness\": 0.0598, \"Acousticness\": 0.00146, \"Liveness\": 0.0897, \"Tempo\": 171.005, \"Duration (ms)\": 200040.0, \"Valence\": 0.334, \"Chord\": \"C#/Db\"}, {\"Index\": 26, \"Highest Charting Position\": 12, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"happier\", \"Streams\": 14849078, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"2tGvwE8GcFKwNdAXMnlbfl\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 92.0, \"Danceability\": 0.395, \"Energy\": 0.443, \"Loudness\": -9.72, \"Speechiness\": 0.133, \"Acousticness\": 0.765, \"Liveness\": 0.0839, \"Tempo\": 168.924, \"Duration (ms)\": 175933.0, \"Valence\": 0.338, \"Chord\": \"F#/Gb\"}, {\"Index\": 27, \"Highest Charting Position\": 27, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Pepas\", \"Streams\": 14809458, \"Artist\": \"Farruko\", \"Artist Followers\": 10502148.0, \"Song ID\": \"5fwSHlTEWpluwOM0Sxnh5k\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-24\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 92.0, \"Danceability\": 0.762, \"Energy\": 0.766, \"Loudness\": -3.955, \"Speechiness\": 0.0343, \"Acousticness\": 0.00776, \"Liveness\": 0.128, \"Tempo\": 130.001, \"Duration (ms)\": 287120.0, \"Valence\": 0.442, \"Chord\": \"G\"}, {\"Index\": 28, \"Highest Charting Position\": 18, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Motley Crew\", \"Streams\": 14329162, \"Artist\": \"Post Malone\", \"Artist Followers\": 33651775.0, \"Song ID\": \"40uMIn2zJLAQhNXghRjBed\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 90.0, \"Danceability\": 0.797, \"Energy\": 0.631, \"Loudness\": -3.818, \"Speechiness\": 0.0786, \"Acousticness\": 0.0904, \"Liveness\": 0.0998, \"Tempo\": 129.915, \"Duration (ms)\": 184213.0, \"Valence\": 0.288, \"Chord\": \"D#/Eb\"}, {\"Index\": 29, \"Highest Charting Position\": 15, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Friday (feat. Mufasa & Hypeman) - Dopamine Re-Edit\", \"Streams\": 14273637, \"Artist\": \"Riton, Nightcrawlers\", \"Artist Followers\": 83689.0, \"Song ID\": \"4cG7HUWYHBV6R6tHn1gxrl\", \"Genre\": \"['dance pop', 'house', 'pop dance', 'tropical house', 'uk dance']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 92.0, \"Danceability\": 0.824, \"Energy\": 0.862, \"Loudness\": -3.424, \"Speechiness\": 0.126, \"Acousticness\": 0.0076, \"Liveness\": 0.303, \"Tempo\": 122.98, \"Duration (ms)\": 169153.0, \"Valence\": 0.801, \"Chord\": \"D\"}, {\"Index\": 30, \"Highest Charting Position\": 3, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Astronaut In The Ocean\", \"Streams\": 14174752, \"Artist\": \"Masked Wolf\", \"Artist Followers\": 365975.0, \"Song ID\": \"3Ofmpyhv5UAQ70mENzB277\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2021-01-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 89.0, \"Danceability\": 0.778, \"Energy\": 0.695, \"Loudness\": -6.865, \"Speechiness\": 0.0913, \"Acousticness\": 0.175, \"Liveness\": 0.15, \"Tempo\": 149.996, \"Duration (ms)\": 132780.0, \"Valence\": 0.472, \"Chord\": \"E\"}, {\"Index\": 31, \"Highest Charting Position\": 5, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Leave The Door Open\", \"Streams\": 13963568, \"Artist\": \"Bruno Mars, Anderson .Paak, Silk Sonic\", \"Artist Followers\": 32574754.0, \"Song ID\": \"7MAibcTli4IisCtbHKrGMh\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 92.0, \"Danceability\": 0.586, \"Energy\": 0.616, \"Loudness\": -7.964, \"Speechiness\": 0.0324, \"Acousticness\": 0.182, \"Liveness\": 0.0927, \"Tempo\": 148.088, \"Duration (ms)\": 242096.0, \"Valence\": 0.719, \"Chord\": \"F\"}, {\"Index\": 32, \"Highest Charting Position\": 32, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Don't Go Yet\", \"Streams\": 13205250, \"Artist\": \"Camila Cabello\", \"Artist Followers\": 22683756.0, \"Song ID\": \"1058fW9H3fZA6QjYCdOBad\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-07-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 88.0, \"Danceability\": 0.666, \"Energy\": 0.796, \"Loudness\": -6.967, \"Speechiness\": 0.103, \"Acousticness\": 0.0492, \"Liveness\": 0.0442, \"Tempo\": 110.108, \"Duration (ms)\": 164842.0, \"Valence\": 0.61, \"Chord\": \"A#/Bb\"}, {\"Index\": 33, \"Highest Charting Position\": 11, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"favorite crime\", \"Streams\": 12818935, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"5JCoSi02qi3jJeHdZXMmR8\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 91.0, \"Danceability\": 0.369, \"Energy\": 0.272, \"Loudness\": -10.497, \"Speechiness\": 0.0364, \"Acousticness\": 0.866, \"Liveness\": 0.147, \"Tempo\": 172.929, \"Duration (ms)\": 152667.0, \"Valence\": 0.218, \"Chord\": \"A\"}, {\"Index\": 34, \"Highest Charting Position\": 10, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Pareja Del A\\u00f1o\", \"Streams\": 12572307, \"Artist\": \"Sebastian Yatra, Myke Towers\", \"Artist Followers\": 16216789.0, \"Song ID\": \"2rCbl9naJYhaxjLsfx88uM\", \"Genre\": \"['colombian pop', 'latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 91.0, \"Danceability\": 0.715, \"Energy\": 0.622, \"Loudness\": -5.102, \"Speechiness\": 0.046, \"Acousticness\": 0.163, \"Liveness\": 0.0948, \"Tempo\": 80.015, \"Duration (ms)\": 195053.0, \"Valence\": 0.808, \"Chord\": \"E\"}, {\"Index\": 35, \"Highest Charting Position\": 4, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Watermelon Sugar\", \"Streams\": 11996689, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16112621.0, \"Song ID\": \"6UelLqGlWMcVH1E5c4H7lY\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 90.0, \"Danceability\": 0.548, \"Energy\": 0.816, \"Loudness\": -4.209, \"Speechiness\": 0.0465, \"Acousticness\": 0.122, \"Liveness\": 0.335, \"Tempo\": 95.39, \"Duration (ms)\": 174000.0, \"Valence\": 0.557, \"Chord\": \"C\"}, {\"Index\": 36, \"Highest Charting Position\": 36, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"NOT SOBER (feat. Polo G & Stunna Gambino)\", \"Streams\": 11869336, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 37, \"Highest Charting Position\": 3, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"RAPSTAR\", \"Streams\": 11683383, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"43PGPuHIlVOc04jrZVh9L6\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 89.0, \"Danceability\": 0.789, \"Energy\": 0.536, \"Loudness\": -6.862, \"Speechiness\": 0.242, \"Acousticness\": 0.41, \"Liveness\": 0.129, \"Tempo\": 81.039, \"Duration (ms)\": 165926.0, \"Valence\": 0.437, \"Chord\": \"F#/Gb\"}, {\"Index\": 38, \"Highest Charting Position\": 15, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"You Right\", \"Streams\": 11629418, \"Artist\": \"Doja Cat, The Weeknd\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0k4d5YPDr1r7FX77VdqWez\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 89.0, \"Danceability\": 0.828, \"Energy\": 0.621, \"Loudness\": -6.414, \"Speechiness\": 0.0565, \"Acousticness\": 0.0164, \"Liveness\": 0.0845, \"Tempo\": 128.986, \"Duration (ms)\": 186173.0, \"Valence\": 0.436, \"Chord\": \"G#/Ab\"}, {\"Index\": 39, \"Highest Charting Position\": 39, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"911 - Remix\", \"Streams\": 11553846, \"Artist\": \"Sech, Jhay Cortez\", \"Artist Followers\": 8758283.0, \"Song ID\": \"27RSJHEA99Y0Vsow7nA37A\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 89.0, \"Danceability\": 0.816, \"Energy\": 0.71, \"Loudness\": -3.728, \"Speechiness\": 0.0398, \"Acousticness\": 0.165, \"Liveness\": 0.292, \"Tempo\": 93.02, \"Duration (ms)\": 208631.0, \"Valence\": 0.784, \"Chord\": \"G\"}, {\"Index\": 40, \"Highest Charting Position\": 1, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"D\\u00c1KITI\", \"Streams\": 11524288, \"Artist\": \"Bad Bunny, Jhay Cortez\", \"Artist Followers\": 36142273.0, \"Song ID\": \"4MzXwWMhyBbmu6hOcLVD49\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 86.0, \"Danceability\": 0.731, \"Energy\": 0.573, \"Loudness\": -10.059, \"Speechiness\": 0.0544, \"Acousticness\": 0.401, \"Liveness\": 0.113, \"Tempo\": 109.928, \"Duration (ms)\": 205090.0, \"Valence\": 0.145, \"Chord\": \"E\"}, {\"Index\": 41, \"Highest Charting Position\": 41, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Mi\\u00e9nteme\", \"Streams\": 11477024, \"Artist\": \"TINI, Maria Becerra\", \"Artist Followers\": 2936204.0, \"Song ID\": \"0cOa970mzTWAxKtltpkpLc\", \"Genre\": \"['latin pop', 'pop argentino']\", \"Release Date\": \"2021-04-29\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 90.0, \"Danceability\": 0.85, \"Energy\": 0.541, \"Loudness\": -4.522, \"Speechiness\": 0.0674, \"Acousticness\": 0.161, \"Liveness\": 0.286, \"Tempo\": 92.003, \"Duration (ms)\": 165275.0, \"Valence\": 0.916, \"Chord\": \"D\"}, {\"Index\": 42, \"Highest Charting Position\": 17, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"jealousy, jealousy\", \"Streams\": 11287301, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"0MMyJUC3WNnFS1lit5pTjk\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 90.0, \"Danceability\": 0.695, \"Energy\": 0.575, \"Loudness\": -6.334, \"Speechiness\": 0.116, \"Acousticness\": 0.198, \"Liveness\": 0.0614, \"Tempo\": 163.929, \"Duration (ms)\": 173160.0, \"Valence\": 0.699, \"Chord\": \"A#/Bb\"}, {\"Index\": 43, \"Highest Charting Position\": 33, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Poblado - Remix\", \"Streams\": 11283626, \"Artist\": \"J Balvin, KAROL G, Nicky Jam, Crissin, Totoy El Frio, Natan & Shander\", \"Artist Followers\": 29051363.0, \"Song ID\": \"1WedZeiezCmCEOzLwhx0hV\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 89.0, \"Danceability\": 0.813, \"Energy\": 0.809, \"Loudness\": -5.382, \"Speechiness\": 0.0846, \"Acousticness\": 0.102, \"Liveness\": 0.377, \"Tempo\": 93.005, \"Duration (ms)\": 393280.0, \"Valence\": 0.646, \"Chord\": \"D#/Eb\"}, {\"Index\": 44, \"Highest Charting Position\": 2, \"Number of Times Charted\": 49, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Dynamite\", \"Streams\": 11196819, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"4saklk6nie3yiGePpBwUoc\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 89.0, \"Danceability\": 0.746, \"Energy\": 0.765, \"Loudness\": -4.41, \"Speechiness\": 0.0993, \"Acousticness\": 0.0112, \"Liveness\": 0.0936, \"Tempo\": 114.044, \"Duration (ms)\": 199054.0, \"Valence\": 0.737, \"Chord\": \"F#/Gb\"}, {\"Index\": 45, \"Highest Charting Position\": 9, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"The Business\", \"Streams\": 10739770, \"Artist\": \"Ti\\u00ebsto\", \"Artist Followers\": 5785065.0, \"Song ID\": \"6f3Slt0GbA2bPZlz0aIFXN\", \"Genre\": \"['big room', 'brostep', 'dance pop', 'dutch edm', 'edm', 'electro house', 'house', 'pop dance', 'slap house', 'trance', 'tropical house']\", \"Release Date\": \"2020-09-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 90.0, \"Danceability\": 0.798, \"Energy\": 0.62, \"Loudness\": -7.079, \"Speechiness\": 0.232, \"Acousticness\": 0.414, \"Liveness\": 0.112, \"Tempo\": 120.031, \"Duration (ms)\": 164000.0, \"Valence\": 0.235, \"Chord\": \"G#/Ab\"}, {\"Index\": 46, \"Highest Charting Position\": 46, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Heartbreak Anthem (with David Guetta & Little Mix)\", \"Streams\": 10315460, \"Artist\": \"Galantis\", \"Artist Followers\": 3120157.0, \"Song ID\": \"5K6Ssv4Z3zRvxt0P6EKUAP\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2021-05-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 89.0, \"Danceability\": 0.595, \"Energy\": 0.784, \"Loudness\": -4.878, \"Speechiness\": 0.102, \"Acousticness\": 0.216, \"Liveness\": 0.0608, \"Tempo\": 124.111, \"Duration (ms)\": 183726.0, \"Valence\": 0.479, \"Chord\": \"C#/Db\"}, {\"Index\": 47, \"Highest Charting Position\": 1, \"Number of Times Charted\": 51, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Mood (feat. iann dior)\", \"Streams\": 10222056, \"Artist\": \"24kGoldn\", \"Artist Followers\": 1274433.0, \"Song ID\": \"4jPy3l0RUwlUI9T5XHBW2m\", \"Genre\": \"['cali rap']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 89.0, \"Danceability\": 0.701, \"Energy\": 0.716, \"Loudness\": -3.671, \"Speechiness\": 0.0361, \"Acousticness\": 0.174, \"Liveness\": 0.324, \"Tempo\": 91.007, \"Duration (ms)\": 140533.0, \"Valence\": 0.732, \"Chord\": \"G\"}, {\"Index\": 48, \"Highest Charting Position\": 48, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Entre Nosotros\", \"Streams\": 10215216, \"Artist\": \"Tiago PZK, LIT killah\", \"Artist Followers\": 375865.0, \"Song ID\": \"6w8yBI2vthyN9UnwO4UBWb\", \"Genre\": \"['trap argentino']\", \"Release Date\": \"2021-07-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 89.0, \"Danceability\": 0.729, \"Energy\": 0.513, \"Loudness\": -6.345, \"Speechiness\": 0.0455, \"Acousticness\": 0.494, \"Liveness\": 0.137, \"Tempo\": 170.064, \"Duration (ms)\": 192353.0, \"Valence\": 0.789, \"Chord\": \"F\"}, {\"Index\": 49, \"Highest Charting Position\": 29, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Fiel - Remix\", \"Streams\": 10032746, \"Artist\": \"Wisin, Jhay Cortez, Anuel AA, Los Legendarios, Myke Towers\", \"Artist Followers\": 6929075.0, \"Song ID\": \"43qcs9NpJhDxtG91zxFkj7\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 89.0, \"Danceability\": 0.839, \"Energy\": 0.711, \"Loudness\": -4.733, \"Speechiness\": 0.0473, \"Acousticness\": 0.398, \"Liveness\": 0.118, \"Tempo\": 97.99, \"Duration (ms)\": 349547.0, \"Valence\": 0.573, \"Chord\": \"F#/Gb\"}, {\"Index\": 50, \"Highest Charting Position\": 20, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Build a Bitch\", \"Streams\": 9841998, \"Artist\": \"Bella Poarch\", \"Artist Followers\": 389076.0, \"Song ID\": \"7BoobGhD4x5K96Me0hqC8Q\", \"Genre\": \"[]\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 89.0, \"Danceability\": 0.855, \"Energy\": 0.463, \"Loudness\": -7.454, \"Speechiness\": 0.0367, \"Acousticness\": 0.217, \"Liveness\": 0.347, \"Tempo\": 102.931, \"Duration (ms)\": 122773.0, \"Valence\": 0.866, \"Chord\": \"D#/Eb\"}, {\"Index\": 51, \"Highest Charting Position\": 19, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Nicky Jam: Bzrp Music Sessions, Vol. 41\", \"Streams\": 9799701, \"Artist\": \"Bizarrap, Nicky Jam\", \"Artist Followers\": 3126961.0, \"Song ID\": \"03LfOYi0icz4souspZVVhq\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2021-06-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 88.0, \"Danceability\": 0.627, \"Energy\": 0.849, \"Loudness\": -3.167, \"Speechiness\": 0.153, \"Acousticness\": 0.0913, \"Liveness\": 0.145, \"Tempo\": 89.907, \"Duration (ms)\": 158087.0, \"Valence\": 0.818, \"Chord\": \"C#/Db\"}, {\"Index\": 52, \"Highest Charting Position\": 52, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Tiroteo - Remix\", \"Streams\": 9781153, \"Artist\": \"Marc Segu\\u00ed, Rauw Alejandro, Pol Granch\", \"Artist Followers\": 45362.0, \"Song ID\": \"4OwhwvKESFtuu06dTgct7i\", \"Genre\": \"[]\", \"Release Date\": \"2021-04-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 88.0, \"Danceability\": 0.75, \"Energy\": 0.522, \"Loudness\": -7.018, \"Speechiness\": 0.0293, \"Acousticness\": 0.282, \"Liveness\": 0.0743, \"Tempo\": 110.427, \"Duration (ms)\": 321556.0, \"Valence\": 0.601, \"Chord\": \"A\"}, {\"Index\": 53, \"Highest Charting Position\": 19, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"NDA\", \"Streams\": 9635619, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47014200.0, \"Song ID\": \"38GBNKZUhfBkk3oNlWzRYd\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-07-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 84.0, \"Danceability\": 0.765, \"Energy\": 0.373, \"Loudness\": -9.921, \"Speechiness\": 0.0713, \"Acousticness\": 0.341, \"Liveness\": 0.112, \"Tempo\": 85.016, \"Duration (ms)\": 195777.0, \"Valence\": 0.554, \"Chord\": \"G#/Ab\"}, {\"Index\": 54, \"Highest Charting Position\": 40, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Rasputin\", \"Streams\": 9600707, \"Artist\": \"Majestic, Boney M.\", \"Artist Followers\": 32178.0, \"Song ID\": \"6FO4K7MrMoYkc5BlpX5LNV\", \"Genre\": \"['house', 'pop dance', 'uk dance']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 49.0, \"Danceability\": 0.83, \"Energy\": 0.839, \"Loudness\": -6.985, \"Speechiness\": 0.0699, \"Acousticness\": 0.00201, \"Liveness\": 0.0353, \"Tempo\": 128.012, \"Duration (ms)\": 345543.0, \"Valence\": 0.59, \"Chord\": \"F#/Gb\"}, {\"Index\": 55, \"Highest Charting Position\": 52, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Leave Before You Love Me (with Jonas Brothers)\", \"Streams\": 9428494, \"Artist\": \"Marshmello\", \"Artist Followers\": 31541310.0, \"Song ID\": \"4qu63nuBpdn0qHUHuObEj1\", \"Genre\": \"['brostep', 'edm', 'pop', 'pop dance', 'progressive electro house']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\", \"Popularity\": 89.0, \"Danceability\": 0.721, \"Energy\": 0.738, \"Loudness\": -4.77, \"Speechiness\": 0.0403, \"Acousticness\": 0.00226, \"Liveness\": 0.118, \"Tempo\": 119.976, \"Duration (ms)\": 154983.0, \"Valence\": 0.637, \"Chord\": \"G\"}, {\"Index\": 56, \"Highest Charting Position\": 56, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Freaks\", \"Streams\": 9319465, \"Artist\": \"Surf Curse\", \"Artist Followers\": 495226.0, \"Song ID\": \"7EkWXAI1wn8Ii883ecd9xr\", \"Genre\": \"['dreamo', 'indie surf', 'surf punk', 'vegas indie']\", \"Release Date\": \"2021-05-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 89.0, \"Danceability\": 0.345, \"Energy\": 0.941, \"Loudness\": -9.918, \"Speechiness\": 0.0466, \"Acousticness\": 3.84e-05, \"Liveness\": 0.0511, \"Tempo\": 179.626, \"Duration (ms)\": 147062.0, \"Valence\": 0.407, \"Chord\": \"A\"}, {\"Index\": 57, \"Highest Charting Position\": 57, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Meu Peda\\u00e7o de Pecado\", \"Streams\": 9206366, \"Artist\": \"Jo\\u00e3o Gomes\", \"Artist Followers\": 409173.0, \"Song ID\": \"2kJRlOyrxsy7Ot3c5TZ8Q6\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 83.0, \"Danceability\": 0.668, \"Energy\": 0.887, \"Loudness\": -4.404, \"Speechiness\": 0.0564, \"Acousticness\": 0.369, \"Liveness\": 0.257, \"Tempo\": 151.92, \"Duration (ms)\": 157176.0, \"Valence\": 0.907, \"Chord\": \"B\"}, {\"Index\": 58, \"Highest Charting Position\": 31, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"2/Catorce\", \"Streams\": 9086979, \"Artist\": \"Rauw Alejandro, Mr. Naisgai\", \"Artist Followers\": 6080597.0, \"Song ID\": \"71R8HJxQk5qMiRstrlXN9t\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2021-02-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 87.0, \"Danceability\": 0.54, \"Energy\": 0.455, \"Loudness\": -5.988, \"Speechiness\": 0.224, \"Acousticness\": 0.675, \"Liveness\": 0.12, \"Tempo\": 83.876, \"Duration (ms)\": 212032.0, \"Valence\": 0.432, \"Chord\": \"D#/Eb\"}, {\"Index\": 59, \"Highest Charting Position\": 34, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Beautiful Mistakes (feat. Megan Thee Stallion)\", \"Streams\": 9048966, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32262679.0, \"Song ID\": \"5zFglKYiknIxks8geR8rcL\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 88.0, \"Danceability\": 0.713, \"Energy\": 0.676, \"Loudness\": -5.483, \"Speechiness\": 0.027, \"Acousticness\": 0.0377, \"Liveness\": 0.154, \"Tempo\": 99.048, \"Duration (ms)\": 227395.0, \"Valence\": 0.721, \"Chord\": \"A#/Bb\"}, {\"Index\": 60, \"Highest Charting Position\": 31, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Run\", \"Streams\": 9017356, \"Artist\": \"OneRepublic\", \"Artist Followers\": 12169108.0, \"Song ID\": \"2UbVnbE5FH6008mAm6Mmgw\", \"Genre\": \"['dance pop', 'piano rock', 'pop', 'pop rock']\", \"Release Date\": \"2021-05-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2020-09-25--2020-10-02\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 88.0, \"Danceability\": 0.682, \"Energy\": 0.72, \"Loudness\": -8.173, \"Speechiness\": 0.0381, \"Acousticness\": 0.326, \"Liveness\": 0.148, \"Tempo\": 117.003, \"Duration (ms)\": 169011.0, \"Valence\": 0.673, \"Chord\": \"B\"}, {\"Index\": 61, \"Highest Charting Position\": 46, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Thot Shit\", \"Streams\": 8977336, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4787261.0, \"Song ID\": \"5zNW5ARjYhJQJz1AChP33n\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 88.0, \"Danceability\": 0.95, \"Energy\": 0.693, \"Loudness\": -3.424, \"Speechiness\": 0.0898, \"Acousticness\": 0.0133, \"Liveness\": 0.173, \"Tempo\": 130.02, \"Duration (ms)\": 184635.0, \"Valence\": 0.891, \"Chord\": \"A\"}, {\"Index\": 62, \"Highest Charting Position\": 26, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Your Love (9PM)\", \"Streams\": 8935418, \"Artist\": \"ATB, Topic, A7S\", \"Artist Followers\": 291777.0, \"Song ID\": \"5YaskwnGDZFDRipaqzbwQx\", \"Genre\": \"['german dance', 'german techno', 'german trance', 'trance']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 88.0, \"Danceability\": 0.669, \"Energy\": 0.784, \"Loudness\": -5.603, \"Speechiness\": 0.112, \"Acousticness\": 0.194, \"Liveness\": 0.115, \"Tempo\": 125.993, \"Duration (ms)\": 150053.0, \"Valence\": 0.517, \"Chord\": \"G\"}, {\"Index\": 63, \"Highest Charting Position\": 9, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"brutal\", \"Streams\": 8881356, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"6SRsiMl7w1USE4mFqrOhHC\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 89.0, \"Danceability\": 0.672, \"Energy\": 0.526, \"Loudness\": -6.446, \"Speechiness\": 0.0599, \"Acousticness\": 0.0311, \"Liveness\": 0.28, \"Tempo\": 123.999, \"Duration (ms)\": 143747.0, \"Valence\": 0.28, \"Chord\": \"E\"}, {\"Index\": 64, \"Highest Charting Position\": 2, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Save Your Tears\", \"Streams\": 8843110, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"37BZB0z9T8Xu7U3e65qxFy\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 94.0, \"Danceability\": 0.65, \"Energy\": 0.825, \"Loudness\": -4.645, \"Speechiness\": 0.0325, \"Acousticness\": 0.0215, \"Liveness\": 0.0936, \"Tempo\": 118.091, \"Duration (ms)\": 191014.0, \"Valence\": 0.593, \"Chord\": \"C\"}, {\"Index\": 65, \"Highest Charting Position\": 8, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Heartbreak Anniversary\", \"Streams\": 8832945, \"Artist\": \"Giveon\", \"Artist Followers\": 1398563.0, \"Song ID\": \"3FAJ6O0NOHQV8Mc5Ri6ENp\", \"Genre\": \"['pop', 'r&b']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 87.0, \"Danceability\": 0.449, \"Energy\": 0.465, \"Loudness\": -8.964, \"Speechiness\": 0.0791, \"Acousticness\": 0.524, \"Liveness\": 0.303, \"Tempo\": 89.087, \"Duration (ms)\": 198371.0, \"Valence\": 0.543, \"Chord\": \"C\"}, {\"Index\": 66, \"Highest Charting Position\": 2, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Don't Start Now\", \"Streams\": 8821971, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 1250353.0, \"Song ID\": \"7njGslFmqBmOSSOpTyZCs9\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.793, \"Energy\": 0.793, \"Loudness\": -4.521, \"Speechiness\": 0.083, \"Acousticness\": 0.0123, \"Liveness\": 0.0951, \"Tempo\": 123.95, \"Duration (ms)\": 183290.0, \"Valence\": 0.679, \"Chord\": \"B\"}, {\"Index\": 67, \"Highest Charting Position\": 33, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Dinero\", \"Streams\": 8564775, \"Artist\": \"Trinidad Cardona\", \"Artist Followers\": 116817.0, \"Song ID\": \"3ggtU1ZOKO8ZNiqPNyXGcm\", \"Genre\": \"[]\", \"Release Date\": \"2018-02-02\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 87.0, \"Danceability\": 0.708, \"Energy\": 0.782, \"Loudness\": -4.687, \"Speechiness\": 0.0674, \"Acousticness\": 0.00772, \"Liveness\": 0.107, \"Tempo\": 119.997, \"Duration (ms)\": 160880.0, \"Valence\": 0.484, \"Chord\": \"D\"}, {\"Index\": 68, \"Highest Charting Position\": 35, \"Number of Times Charted\": 48, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Sweater Weather\", \"Streams\": 8564017, \"Artist\": \"The Neighbourhood\", \"Artist Followers\": 6662605.0, \"Song ID\": \"2QjOHCTQ1Jl3zawyYOpxh6\", \"Genre\": \"['modern alternative rock', 'modern rock', 'pop']\", \"Release Date\": \"2013-04-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 87.0, \"Danceability\": 0.612, \"Energy\": 0.807, \"Loudness\": -2.81, \"Speechiness\": 0.0336, \"Acousticness\": 0.0495, \"Liveness\": 0.101, \"Tempo\": 124.053, \"Duration (ms)\": 240400.0, \"Valence\": 0.398, \"Chord\": \"A#/Bb\"}, {\"Index\": 69, \"Highest Charting Position\": 69, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Sobrio\", \"Streams\": 8514480, \"Artist\": \"Maluma\", \"Artist Followers\": 26769304.0, \"Song ID\": \"4HzqWEdAbzcVFDv0pvxV4w\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-07-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 87.0, \"Danceability\": 0.762, \"Energy\": 0.77, \"Loudness\": -2.758, \"Speechiness\": 0.223, \"Acousticness\": 0.138, \"Liveness\": 0.15, \"Tempo\": 177.998, \"Duration (ms)\": 201181.0, \"Valence\": 0.631, \"Chord\": \"F\"}, {\"Index\": 70, \"Highest Charting Position\": 12, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Someone You Loved\", \"Streams\": 8490162, \"Artist\": \"Lewis Capaldi\", \"Artist Followers\": 8384096.0, \"Song ID\": \"7qEHsqek33rTcFNT9PFqLf\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.501, \"Energy\": 0.405, \"Loudness\": -5.679, \"Speechiness\": 0.0319, \"Acousticness\": 0.751, \"Liveness\": 0.105, \"Tempo\": 109.891, \"Duration (ms)\": 182161.0, \"Valence\": 0.446, \"Chord\": \"C#/Db\"}, {\"Index\": 71, \"Highest Charting Position\": 71, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Over The Top (feat. Drake)\", \"Streams\": 8269753, \"Artist\": \"Smiley\", \"Artist Followers\": 26131.0, \"Song ID\": \"3yaYgjEFkRw3PVjW9mV1TO\", \"Genre\": \"['canadian hip hop', 'toronto rap']\", \"Release Date\": \"2021-07-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 83.0, \"Danceability\": 0.833, \"Energy\": 0.498, \"Loudness\": -5.196, \"Speechiness\": 0.117, \"Acousticness\": 0.0493, \"Liveness\": 0.119, \"Tempo\": 139.928, \"Duration (ms)\": 153406.0, \"Valence\": 0.259, \"Chord\": \"A#/Bb\"}, {\"Index\": 72, \"Highest Charting Position\": 72, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"2055\", \"Streams\": 8133401, \"Artist\": \"Sleepy Hallow\", \"Artist Followers\": 408696.0, \"Song ID\": \"4XvcHTUfIlWfyJTRG0aqlo\", \"Genre\": \"['brooklyn drill', 'nyc rap']\", \"Release Date\": \"2021-06-02\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 85.0, \"Danceability\": 0.829, \"Energy\": 0.512, \"Loudness\": -5.865, \"Speechiness\": 0.187, \"Acousticness\": 0.492, \"Liveness\": 0.12, \"Tempo\": 80.511, \"Duration (ms)\": 123987.0, \"Valence\": 0.638, \"Chord\": \"F#/Gb\"}, {\"Index\": 73, \"Highest Charting Position\": 33, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"EL MAKINON\", \"Streams\": 8102107, \"Artist\": \"KAROL G, Mariah Angeliq\", \"Artist Followers\": 17775316.0, \"Song ID\": \"2FSGUA0gFgGeQdprjtGM2M\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 87.0, \"Danceability\": 0.635, \"Energy\": 0.706, \"Loudness\": -3.224, \"Speechiness\": 0.125, \"Acousticness\": 0.256, \"Liveness\": 0.108, \"Tempo\": 88.863, \"Duration (ms)\": 209160.0, \"Valence\": 0.443, \"Chord\": \"F\"}, {\"Index\": 74, \"Highest Charting Position\": 74, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Loco\", \"Streams\": 8093413, \"Artist\": \"Justin Quiles, Chimbala, Zion & Lennox\", \"Artist Followers\": 2895789.0, \"Song ID\": \"6PDlkWmrq2ZKiUuFt2aQsH\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 87.0, \"Danceability\": 0.77, \"Energy\": 0.899, \"Loudness\": -2.981, \"Speechiness\": 0.0494, \"Acousticness\": 0.222, \"Liveness\": 0.0894, \"Tempo\": 128.05, \"Duration (ms)\": 231604.0, \"Valence\": 0.851, \"Chord\": \"G#/Ab\"}, {\"Index\": 75, \"Highest Charting Position\": 75, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Love Tonight - Edit\", \"Streams\": 8006336, \"Artist\": \"Shouse\", \"Artist Followers\": 27116.0, \"Song ID\": \"6OufwUcCqo81guU2jAlDVP\", \"Genre\": \"['aussietronica']\", \"Release Date\": \"2017-12-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 87.0, \"Danceability\": 0.727, \"Energy\": 0.681, \"Loudness\": -7.114, \"Speechiness\": 0.0265, \"Acousticness\": 0.00214, \"Liveness\": 0.0861, \"Tempo\": 123.028, \"Duration (ms)\": 241970.0, \"Valence\": 0.448, \"Chord\": \"F\"}, {\"Index\": 76, \"Highest Charting Position\": 12, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"ZITTI E BUONI\", \"Streams\": 7975148, \"Artist\": \"M\\u00e5neskin\", \"Artist Followers\": 3377762.0, \"Song ID\": \"776AftMmFFAWUIEAb3lHhw\", \"Genre\": \"['indie rock italiano', 'italian pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-03-05--2021-03-12\", \"Popularity\": 86.0, \"Danceability\": 0.625, \"Energy\": 0.939, \"Loudness\": -3.115, \"Speechiness\": 0.0669, \"Acousticness\": 0.00138, \"Liveness\": 0.424, \"Tempo\": 102.999, \"Duration (ms)\": 194787.0, \"Valence\": 0.644, \"Chord\": \"E\"}, {\"Index\": 77, \"Highest Charting Position\": 2, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"telepat\\u00eda\", \"Streams\": 7912399, \"Artist\": \"Kali Uchis\", \"Artist Followers\": 1999954.0, \"Song ID\": \"6tDDoYIxWvMLTdKpjFkc1B\", \"Genre\": \"['colombian pop', 'pop']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 88.0, \"Danceability\": 0.653, \"Energy\": 0.524, \"Loudness\": -9.016, \"Speechiness\": 0.0502, \"Acousticness\": 0.112, \"Liveness\": 0.203, \"Tempo\": 83.97, \"Duration (ms)\": 160191.0, \"Valence\": 0.553, \"Chord\": \"B\"}, {\"Index\": 78, \"Highest Charting Position\": 9, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Botella Tras Botella\", \"Streams\": 7735223, \"Artist\": \"Gera MX, Christian Nodal\", \"Artist Followers\": 2043294.0, \"Song ID\": \"2MnLkFqY9Rpg9s3Zv6ZJdK\", \"Genre\": \"['mexican hip hop', 'rap conciencia']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 87.0, \"Danceability\": 0.727, \"Energy\": 0.546, \"Loudness\": -4.572, \"Speechiness\": 0.0437, \"Acousticness\": 0.656, \"Liveness\": 0.122, \"Tempo\": 106.891, \"Duration (ms)\": 197333.0, \"Valence\": 0.69, \"Chord\": \"C\"}, {\"Index\": 79, \"Highest Charting Position\": 7, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Fiel\", \"Streams\": 7717211, \"Artist\": \"Los Legendarios, Wisin, Jhay Cortez\", \"Artist Followers\": 31488.0, \"Song ID\": \"7Bk0uXKk1uPT0XuQbpFzvs\", \"Genre\": \"['reggaeton', 'trap latino']\", \"Release Date\": \"2021-02-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 88.0, \"Danceability\": 0.849, \"Energy\": 0.701, \"Loudness\": -4.407, \"Speechiness\": 0.06, \"Acousticness\": 0.407, \"Liveness\": 0.112, \"Tempo\": 98.005, \"Duration (ms)\": 261667.0, \"Valence\": 0.505, \"Chord\": \"F#/Gb\"}, {\"Index\": 80, \"Highest Charting Position\": 1, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Dance Monkey\", \"Streams\": 7687058, \"Artist\": \"Tones And I\", \"Artist Followers\": 2819593.0, \"Song ID\": \"2XU0oxnq2qxCpomAAuJY8K\", \"Genre\": \"['australian pop', 'pop']\", \"Release Date\": \"2019-10-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.824, \"Energy\": 0.588, \"Loudness\": -6.4, \"Speechiness\": 0.0924, \"Acousticness\": 0.692, \"Liveness\": 0.149, \"Tempo\": 98.027, \"Duration (ms)\": 209438.0, \"Valence\": 0.513, \"Chord\": \"F#/Gb\"}, {\"Index\": 81, \"Highest Charting Position\": 7, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"WITHOUT YOU\", \"Streams\": 7642130, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2230022.0, \"Song ID\": \"27OeeYzk6klgBh83TSvGMA\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 87.0, \"Danceability\": 0.662, \"Energy\": 0.413, \"Loudness\": -7.357, \"Speechiness\": 0.0299, \"Acousticness\": 0.213, \"Liveness\": 0.134, \"Tempo\": 93.005, \"Duration (ms)\": 161385.0, \"Valence\": 0.467, \"Chord\": \"C\"}, {\"Index\": 82, \"Highest Charting Position\": 6, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Wants and Needs (feat. Lil Baby)\", \"Streams\": 7637626, \"Artist\": \"Drake\", \"Artist Followers\": 56308172.0, \"Song ID\": \"65OVbaJR5O1RmwOQx0875b\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 87.0, \"Danceability\": 0.578, \"Energy\": 0.449, \"Loudness\": -6.349, \"Speechiness\": 0.286, \"Acousticness\": 0.0618, \"Liveness\": 0.119, \"Tempo\": 136.006, \"Duration (ms)\": 192956.0, \"Valence\": 0.1, \"Chord\": \"C#/Db\"}, {\"Index\": 83, \"Highest Charting Position\": 83, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Bezos I\", \"Streams\": 7516291, \"Artist\": \"Bo Burnham\", \"Artist Followers\": 1042079.0, \"Song ID\": \"0Kdj7nwaYQmvhxnqZaIQuW\", \"Genre\": \"['comic']\", \"Release Date\": \"2021-06-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 84.0, \"Danceability\": 0.694, \"Energy\": 0.948, \"Loudness\": -5.307, \"Speechiness\": 0.0361, \"Acousticness\": 0.00936, \"Liveness\": 0.139, \"Tempo\": 115.044, \"Duration (ms)\": 58149.0, \"Valence\": 0.705, \"Chord\": \"D\"}, {\"Index\": 84, \"Highest Charting Position\": 76, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Love Again\", \"Streams\": 7465445, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 1250353.0, \"Song ID\": \"2sN1pMv6d2t5GlvN6IBMlK\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2020-03-27--2020-04-03\", \"Popularity\": 0.0, \"Danceability\": 0.659, \"Energy\": 0.667, \"Loudness\": -4.668, \"Speechiness\": 0.0339, \"Acousticness\": 0.00173, \"Liveness\": 0.1, \"Tempo\": 115.982, \"Duration (ms)\": 258004.0, \"Valence\": 0.468, \"Chord\": \"B\"}, {\"Index\": 85, \"Highest Charting Position\": 32, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Goosebumps - Remix\", \"Streams\": 7452633, \"Artist\": \"Travis Scott, HVME\", \"Artist Followers\": 17719446.0, \"Song ID\": \"5uEYRdEIh9Bo4fpjDd4Na9\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 87.0, \"Danceability\": 0.841, \"Energy\": 0.593, \"Loudness\": -7.846, \"Speechiness\": 0.0379, \"Acousticness\": 0.418, \"Liveness\": 0.124, \"Tempo\": 124.917, \"Duration (ms)\": 162803.0, \"Valence\": 0.808, \"Chord\": \"C#/Db\"}, {\"Index\": 86, \"Highest Charting Position\": 11, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Head & Heart (feat. MNEK)\", \"Streams\": 7434252, \"Artist\": \"Joel Corry\", \"Artist Followers\": 207547.0, \"Song ID\": \"6cx06DFPPHchuUAcTxznu9\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance', 'tropical house', 'uk dance']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 87.0, \"Danceability\": 0.734, \"Energy\": 0.874, \"Loudness\": -3.158, \"Speechiness\": 0.0662, \"Acousticness\": 0.168, \"Liveness\": 0.0489, \"Tempo\": 122.953, \"Duration (ms)\": 166028.0, \"Valence\": 0.905, \"Chord\": \"G#/Ab\"}, {\"Index\": 87, \"Highest Charting Position\": 42, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"BED\", \"Streams\": 7383369, \"Artist\": \"Joel Corry, RAYE, David Guetta\", \"Artist Followers\": 207547.0, \"Song ID\": \"0siYMEsGrzzzlWLXK5zJfS\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance', 'tropical house', 'uk dance']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 87.0, \"Danceability\": 0.671, \"Energy\": 0.782, \"Loudness\": -4.593, \"Speechiness\": 0.0341, \"Acousticness\": 0.0142, \"Liveness\": 0.333, \"Tempo\": 123.989, \"Duration (ms)\": 178088.0, \"Valence\": 0.618, \"Chord\": \"F#/Gb\"}, {\"Index\": 88, \"Highest Charting Position\": 78, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Iko Iko (My Bestie)\", \"Streams\": 7381585, \"Artist\": \"Justin Wellington, Small Jam\", \"Artist Followers\": 18228.0, \"Song ID\": \"7MC4XR9M9amdmKQr2iDF7i\", \"Genre\": \"['melanesian pop', 'pacific islands pop', 'png pop']\", \"Release Date\": \"2019-06-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 87.0, \"Danceability\": 0.862, \"Energy\": 0.753, \"Loudness\": -5.356, \"Speechiness\": 0.0625, \"Acousticness\": 0.131, \"Liveness\": 0.077, \"Tempo\": 105.039, \"Duration (ms)\": 182857.0, \"Valence\": 0.827, \"Chord\": \"F\"}, {\"Index\": 89, \"Highest Charting Position\": 89, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Better Believe\", \"Streams\": 7365053, \"Artist\": \"Belly, The Weeknd, Young Thug\", \"Artist Followers\": 203972.0, \"Song ID\": \"3zs87EV3EZSh2UpiXxT52Y\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'pop rap', 'rap', 'southern hip hop', 'trap', 'trap soul', 'underground hip hop']\", \"Release Date\": \"2021-07-22\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 80.0, \"Danceability\": 0.797, \"Energy\": 0.573, \"Loudness\": -7.85, \"Speechiness\": 0.319, \"Acousticness\": 0.159, \"Liveness\": 0.144, \"Tempo\": 124.995, \"Duration (ms)\": 206629.0, \"Valence\": 0.445, \"Chord\": \"C\"}, {\"Index\": 90, \"Highest Charting Position\": 23, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Arcade\", \"Streams\": 7353795, \"Artist\": \"Duncan Laurence\", \"Artist Followers\": 287361.0, \"Song ID\": \"1Xi84slp6FryDSCbzq4UCD\", \"Genre\": \"['dutch pop']\", \"Release Date\": \"2019-03-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 84.0, \"Danceability\": 0.45, \"Energy\": 0.329, \"Loudness\": -12.603, \"Speechiness\": 0.0441, \"Acousticness\": 0.818, \"Liveness\": 0.135, \"Tempo\": 71.884, \"Duration (ms)\": 183624.0, \"Valence\": 0.266, \"Chord\": \"A\"}, {\"Index\": 91, \"Highest Charting Position\": 55, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"512\", \"Streams\": 7336542, \"Artist\": \"Mora, Jhay Cortez\", \"Artist Followers\": 151486.0, \"Song ID\": \"5jzEwSyyymBlf1fa1o39T2\", \"Genre\": \"['reggaeton', 'trap latino']\", \"Release Date\": \"2021-02-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 87.0, \"Danceability\": 0.818, \"Energy\": 0.673, \"Loudness\": -7.542, \"Speechiness\": 0.148, \"Acousticness\": 0.348, \"Liveness\": 0.172, \"Tempo\": 87.961, \"Duration (ms)\": 193636.0, \"Valence\": 0.695, \"Chord\": \"E\"}, {\"Index\": 92, \"Highest Charting Position\": 1, \"Number of Times Charted\": 40, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"positions\", \"Streams\": 7244853, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67158068.0, \"Song ID\": \"35mvY5S1H3J2QZyna3TFe0\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 86.0, \"Danceability\": 0.737, \"Energy\": 0.802, \"Loudness\": -4.771, \"Speechiness\": 0.0878, \"Acousticness\": 0.468, \"Liveness\": 0.0931, \"Tempo\": 144.015, \"Duration (ms)\": 172325.0, \"Valence\": 0.682, \"Chord\": \"C\"}, {\"Index\": 93, \"Highest Charting Position\": 6, \"Number of Times Charted\": 84, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Circles\", \"Streams\": 7156162, \"Artist\": \"Post Malone\", \"Artist Followers\": 33651775.0, \"Song ID\": \"21jGcNKet2qwijlDFuPiPb\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 87.0, \"Danceability\": 0.695, \"Energy\": 0.762, \"Loudness\": -3.497, \"Speechiness\": 0.0395, \"Acousticness\": 0.192, \"Liveness\": 0.0863, \"Tempo\": 120.042, \"Duration (ms)\": 215280.0, \"Valence\": 0.553, \"Chord\": \"C\"}, {\"Index\": 94, \"Highest Charting Position\": 94, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Blaues Licht\", \"Streams\": 7084292, \"Artist\": \"RAF Camora, Bonez MC\", \"Artist Followers\": 1329531.0, \"Song ID\": \"08EPQiLMyGB8GJX2EiVoCM\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 78.0, \"Danceability\": 0.819, \"Energy\": 0.835, \"Loudness\": -4.899, \"Speechiness\": 0.102, \"Acousticness\": 0.398, \"Liveness\": 0.252, \"Tempo\": 144.955, \"Duration (ms)\": 144264.0, \"Valence\": 0.703, \"Chord\": \"G#/Ab\"}, {\"Index\": 95, \"Highest Charting Position\": 75, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Ram Pam Pam\", \"Streams\": 7064003, \"Artist\": \"Natti Natasha, Becky G\", \"Artist Followers\": 6341942.0, \"Song ID\": \"4DHDIdeayp8xvlyg22wREO\", \"Genre\": \"['latin', 'latin pop', 'rap latina', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-04-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 86.0, \"Danceability\": 0.908, \"Energy\": 0.813, \"Loudness\": -2.749, \"Speechiness\": 0.0777, \"Acousticness\": 0.305, \"Liveness\": 0.278, \"Tempo\": 97.018, \"Duration (ms)\": 200785.0, \"Valence\": 0.924, \"Chord\": \"F\"}, {\"Index\": 96, \"Highest Charting Position\": 96, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"In Da Getto\", \"Streams\": 6984262, \"Artist\": \"J Balvin, Skrillex\", \"Artist Followers\": 1250353.0, \"Song ID\": \"5lGtPshEJlsJgmqKLi41LY\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 2.0, \"Danceability\": 0.915, \"Energy\": 0.72, \"Loudness\": -3.126, \"Speechiness\": 0.0459, \"Acousticness\": 0.025, \"Liveness\": 0.0942, \"Tempo\": 126.986, \"Duration (ms)\": 131067.0, \"Valence\": 0.631, \"Chord\": \"G#/Ab\"}, {\"Index\": 97, \"Highest Charting Position\": 97, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Woman\", \"Streams\": 6858466, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"6Uj1ctrBOjOas8xZXGqKk4\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-06-25--2021-07-02\", \"Popularity\": 86.0, \"Danceability\": 0.824, \"Energy\": 0.764, \"Loudness\": -4.175, \"Speechiness\": 0.0854, \"Acousticness\": 0.0888, \"Liveness\": 0.117, \"Tempo\": 107.998, \"Duration (ms)\": 172627.0, \"Valence\": 0.881, \"Chord\": \"F\"}, {\"Index\": 98, \"Highest Charting Position\": 60, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"t r a n s p a r e n t s o u l feat. Travis Barker\", \"Streams\": 6853994, \"Artist\": \"WILLOW\", \"Artist Followers\": 1521837.0, \"Song ID\": \"1QL7nSDZCwZMnbisV4KOXt\", \"Genre\": \"['afrofuturism', 'dance pop', 'electropop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2021-04-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 85.0, \"Danceability\": 0.39, \"Energy\": 0.83, \"Loudness\": -5.201, \"Speechiness\": 0.0563, \"Acousticness\": 0.0021, \"Liveness\": 0.156, \"Tempo\": 90.021, \"Duration (ms)\": 168030.0, \"Valence\": 0.191, \"Chord\": \"B\"}, {\"Index\": 99, \"Highest Charting Position\": 99, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Clash (feat. Stormzy)\", \"Streams\": 6825463, \"Artist\": \"Dave\", \"Artist Followers\": 1427540.0, \"Song ID\": \"2oUwMN5VfdGX10XeQJLBBi\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2021-07-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-09--2021-07-16\", \"Popularity\": 79.0, \"Danceability\": 0.871, \"Energy\": 0.519, \"Loudness\": -6.549, \"Speechiness\": 0.258, \"Acousticness\": 0.313, \"Liveness\": 0.0869, \"Tempo\": 140.013, \"Duration (ms)\": 251733.0, \"Valence\": 0.532, \"Chord\": \"D\"}, {\"Index\": 100, \"Highest Charting Position\": 22, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Before You Go\", \"Streams\": 6813800, \"Artist\": \"Lewis Capaldi\", \"Artist Followers\": 8384096.0, \"Song ID\": \"2gMXnyrvIjhVBUZwvLZDMP\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.459, \"Energy\": 0.575, \"Loudness\": -4.858, \"Speechiness\": 0.0573, \"Acousticness\": 0.604, \"Liveness\": 0.0885, \"Tempo\": 111.881, \"Duration (ms)\": 215107.0, \"Valence\": 0.183, \"Chord\": \"D#/Eb\"}, {\"Index\": 101, \"Highest Charting Position\": 52, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Levitating\", \"Streams\": 6799831, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"463CkQjx2Zk1yXoBuierM9\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-10-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 89.0, \"Danceability\": 0.702, \"Energy\": 0.825, \"Loudness\": -3.787, \"Speechiness\": 0.0601, \"Acousticness\": 0.00883, \"Liveness\": 0.0674, \"Tempo\": 102.977, \"Duration (ms)\": 203064.0, \"Valence\": 0.915, \"Chord\": \"F#/Gb\"}, {\"Index\": 102, \"Highest Charting Position\": 85, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Reckless\", \"Streams\": 6711375, \"Artist\": \"Madison Beer\", \"Artist Followers\": 3363988.0, \"Song ID\": \"5ajjAnNRh8bxFvaVHzpPjh\", \"Genre\": \"['alt z', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 86.0, \"Danceability\": 0.386, \"Energy\": 0.426, \"Loudness\": -6.642, \"Speechiness\": 0.0363, \"Acousticness\": 0.807, \"Liveness\": 0.14, \"Tempo\": 180.104, \"Duration (ms)\": 203385.0, \"Valence\": 0.261, \"Chord\": \"D#/Eb\"}, {\"Index\": 103, \"Highest Charting Position\": 103, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"No Me Conocen (Remix) [con DUKI, Rei & Tiago PZK]\", \"Streams\": 6709106, \"Artist\": \"BANDIDO\", \"Artist Followers\": 16074.0, \"Song ID\": \"7COGuXyTr12KvdaYXMqheC\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 85.0, \"Danceability\": 0.769, \"Energy\": 0.812, \"Loudness\": -2.088, \"Speechiness\": 0.0825, \"Acousticness\": 0.281, \"Liveness\": 0.0781, \"Tempo\": 180.003, \"Duration (ms)\": 280274.0, \"Valence\": 0.926, \"Chord\": \"C#/Db\"}, {\"Index\": 104, \"Highest Charting Position\": 88, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Believer\", \"Streams\": 6699895, \"Artist\": \"Imagine Dragons\", \"Artist Followers\": 35285425.0, \"Song ID\": \"0pqnGHJpmpxLKifKRmU6WP\", \"Genre\": \"['modern rock', 'pop', 'rock']\", \"Release Date\": \"2017-06-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.776, \"Energy\": 0.78, \"Loudness\": -4.374, \"Speechiness\": 0.128, \"Acousticness\": 0.0622, \"Liveness\": 0.081, \"Tempo\": 124.949, \"Duration (ms)\": 204347.0, \"Valence\": 0.666, \"Chord\": \"A#/Bb\"}, {\"Index\": 105, \"Highest Charting Position\": 2, \"Number of Times Charted\": 48, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Lemonade (feat. Gunna, Don Toliver & NAV)\", \"Streams\": 6697067, \"Artist\": \"Internet Money\", \"Artist Followers\": 411579.0, \"Song ID\": \"02kDW379Yfd5PzW5A6vuGt\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 82.0, \"Danceability\": 0.799, \"Energy\": 0.66, \"Loudness\": -6.153, \"Speechiness\": 0.079, \"Acousticness\": 0.256, \"Liveness\": 0.111, \"Tempo\": 140.04, \"Duration (ms)\": 195429.0, \"Valence\": 0.471, \"Chord\": \"C#/Db\"}, {\"Index\": 106, \"Highest Charting Position\": 45, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Talking to the Moon\", \"Streams\": 6660319, \"Artist\": \"Bruno Mars\", \"Artist Followers\": 32574754.0, \"Song ID\": \"161DnLWsx1i3u1JT05lzqU\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2010-10-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 83.0, \"Danceability\": 0.523, \"Energy\": 0.606, \"Loudness\": -4.754, \"Speechiness\": 0.0301, \"Acousticness\": 0.512, \"Liveness\": 0.106, \"Tempo\": 145.837, \"Duration (ms)\": 217867.0, \"Valence\": 0.065, \"Chord\": \"C#/Db\"}, {\"Index\": 107, \"Highest Charting Position\": 3, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Roses - Imanbek Remix\", \"Streams\": 6653690, \"Artist\": \"SAINt JHN\", \"Artist Followers\": 742692.0, \"Song ID\": \"0zLCBJZSiELJf02ucPP9wb\", \"Genre\": \"['melodic rap', 'pop rap', 'rap', 'slap house', 'trap']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.769, \"Energy\": 0.719, \"Loudness\": -5.472, \"Speechiness\": 0.0474, \"Acousticness\": 0.0143, \"Liveness\": 0.359, \"Tempo\": 121.955, \"Duration (ms)\": 176867.0, \"Valence\": 0.863, \"Chord\": \"G#/Ab\"}, {\"Index\": 108, \"Highest Charting Position\": 59, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Sal y Perrea\", \"Streams\": 6635076, \"Artist\": \"Sech\", \"Artist Followers\": 8758283.0, \"Song ID\": \"5u7twkeask1VIyDeNTElSU\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-04-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 86.0, \"Danceability\": 0.786, \"Energy\": 0.899, \"Loudness\": -0.515, \"Speechiness\": 0.127, \"Acousticness\": 0.192, \"Liveness\": 0.299, \"Tempo\": 90.025, \"Duration (ms)\": 216510.0, \"Valence\": 0.813, \"Chord\": \"A#/Bb\"}, {\"Index\": 109, \"Highest Charting Position\": 109, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Fulanito\", \"Streams\": 6614072, \"Artist\": \"Becky G, El Alfa\", \"Artist Followers\": 10356559.0, \"Song ID\": \"59L8x0xy8njj75vzVCPMqg\", \"Genre\": \"['dance pop', 'latin', 'latin pop', 'latin viral pop', 'pop', 'rap latina', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 86.0, \"Danceability\": 0.93, \"Energy\": 0.837, \"Loudness\": -4.632, \"Speechiness\": 0.187, \"Acousticness\": 0.256, \"Liveness\": 0.239, \"Tempo\": 111.898, \"Duration (ms)\": 158532.0, \"Valence\": 0.821, \"Chord\": \"G\"}, {\"Index\": 110, \"Highest Charting Position\": 110, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Par\\u00eds\", \"Streams\": 6584896, \"Artist\": \"Ingratax\", \"Artist Followers\": 56699.0, \"Song ID\": \"4bF2y8rR7GUjrd5LNEvej3\", \"Genre\": \"[]\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 86.0, \"Danceability\": 0.57, \"Energy\": 0.455, \"Loudness\": -5.748, \"Speechiness\": 0.0996, \"Acousticness\": 0.441, \"Liveness\": 0.0654, \"Tempo\": 167.933, \"Duration (ms)\": 151429.0, \"Valence\": 0.399, \"Chord\": \"C#/Db\"}, {\"Index\": 111, \"Highest Charting Position\": 46, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"lovely (with Khalid)\", \"Streams\": 6569547, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47014200.0, \"Song ID\": \"0u2P5u6lvoDfwTYjAADbn4\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2018-04-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.351, \"Energy\": 0.296, \"Loudness\": -10.109, \"Speechiness\": 0.0333, \"Acousticness\": 0.934, \"Liveness\": 0.095, \"Tempo\": 115.284, \"Duration (ms)\": 200186.0, \"Valence\": 0.12, \"Chord\": \"E\"}, {\"Index\": 112, \"Highest Charting Position\": 24, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Sunflower - Spider-Man: Into the Spider-Verse\", \"Streams\": 6546948, \"Artist\": \"Post Malone, Swae Lee\", \"Artist Followers\": 1250353.0, \"Song ID\": \"3KkXRkHbMCARz0aVfEt68P\", \"Genre\": \"[]\", \"Release Date\": \"2018-12-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.76, \"Energy\": 0.479, \"Loudness\": -5.574, \"Speechiness\": 0.0466, \"Acousticness\": 0.556, \"Liveness\": 0.0703, \"Tempo\": 89.911, \"Duration (ms)\": 158040.0, \"Valence\": 0.913, \"Chord\": \"D\"}, {\"Index\": 113, \"Highest Charting Position\": 113, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"double take\", \"Streams\": 6539852, \"Artist\": \"dhruv\", \"Artist Followers\": 73211.0, \"Song ID\": \"2CVChktEKBsM6v4IfdFU5k\", \"Genre\": \"['chill r&b', 'nyc pop']\", \"Release Date\": \"2019-05-24\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 86.0, \"Danceability\": 0.663, \"Energy\": 0.434, \"Loudness\": -11.177, \"Speechiness\": 0.0648, \"Acousticness\": 0.828, \"Liveness\": 0.249, \"Tempo\": 109.075, \"Duration (ms)\": 171743.0, \"Valence\": 0.225, \"Chord\": \"G#/Ab\"}, {\"Index\": 114, \"Highest Charting Position\": 9, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Streets\", \"Streams\": 6502302, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"60ynsPSSKe6O3sfwRnIBRf\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 86.0, \"Danceability\": 0.749, \"Energy\": 0.463, \"Loudness\": -8.433, \"Speechiness\": 0.0842, \"Acousticness\": 0.21, \"Liveness\": 0.338, \"Tempo\": 90.035, \"Duration (ms)\": 226987.0, \"Valence\": 0.189, \"Chord\": \"B\"}, {\"Index\": 115, \"Highest Charting Position\": 80, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"By Your Side (feat. Tom Grennan)\", \"Streams\": 6488622, \"Artist\": \"Calvin Harris\", \"Artist Followers\": 21942793.0, \"Song ID\": \"0vR2rIVORmgeKiGIgNT0fV\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'house', 'pop', 'progressive house', 'uk dance']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 85.0, \"Danceability\": 0.733, \"Energy\": 0.96, \"Loudness\": -3.597, \"Speechiness\": 0.0295, \"Acousticness\": 0.0514, \"Liveness\": 0.287, \"Tempo\": 124.01, \"Duration (ms)\": 189672.0, \"Valence\": 0.811, \"Chord\": \"G\"}, {\"Index\": 116, \"Highest Charting Position\": 116, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"MORENA\", \"Streams\": 6469500, \"Artist\": \"Luan Santana\", \"Artist Followers\": 5420471.0, \"Song ID\": \"4PQdrXMDHDPl1RczrrlADd\", \"Genre\": \"['sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2021-06-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 85.0, \"Danceability\": 0.526, \"Energy\": 0.731, \"Loudness\": -4.662, \"Speechiness\": 0.0887, \"Acousticness\": 0.18, \"Liveness\": 0.0891, \"Tempo\": 86.959, \"Duration (ms)\": 193221.0, \"Valence\": 0.476, \"Chord\": \"B\"}, {\"Index\": 117, \"Highest Charting Position\": 80, \"Number of Times Charted\": 80, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Shape of You\", \"Streams\": 6452492, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83293380.0, \"Song ID\": \"7qiZfU4dY1lWllzX7mPBI3\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2017-03-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.825, \"Energy\": 0.652, \"Loudness\": -3.183, \"Speechiness\": 0.0802, \"Acousticness\": 0.581, \"Liveness\": 0.0931, \"Tempo\": 95.977, \"Duration (ms)\": 233713.0, \"Valence\": 0.931, \"Chord\": \"C#/Db\"}, {\"Index\": 118, \"Highest Charting Position\": 9, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Se\\u00f1orita\", \"Streams\": 6317487, \"Artist\": \"Shawn Mendes, Camila Cabello\", \"Artist Followers\": 33879560.0, \"Song ID\": \"0TK2YIli7K1leLovkQiNik\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.759, \"Energy\": 0.54, \"Loudness\": -6.039, \"Speechiness\": 0.0287, \"Acousticness\": 0.037, \"Liveness\": 0.0945, \"Tempo\": 116.947, \"Duration (ms)\": 190960.0, \"Valence\": 0.75, \"Chord\": \"A\"}, {\"Index\": 119, \"Highest Charting Position\": 5, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Hold On\", \"Streams\": 6300416, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 1250353.0, \"Song ID\": \"49xx65gvlD7xXjDTavFqaJ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 0.0, \"Danceability\": 0.658, \"Energy\": 0.634, \"Loudness\": -5.797, \"Speechiness\": 0.0413, \"Acousticness\": 0.0106, \"Liveness\": 0.132, \"Tempo\": 139.98, \"Duration (ms)\": 170813.0, \"Valence\": 0.29, \"Chord\": \"C#/Db\"}, {\"Index\": 120, \"Highest Charting Position\": 99, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Perfect\", \"Streams\": 6278765, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83293380.0, \"Song ID\": \"0tgVpDi06FyKpA1z0VMD4v\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2017-03-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.599, \"Energy\": 0.448, \"Loudness\": -6.312, \"Speechiness\": 0.0232, \"Acousticness\": 0.163, \"Liveness\": 0.106, \"Tempo\": 95.05, \"Duration (ms)\": 263400.0, \"Valence\": 0.168, \"Chord\": \"G#/Ab\"}, {\"Index\": 121, \"Highest Charting Position\": 80, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"2:50 Remix\", \"Streams\": 6244011, \"Artist\": \"MYA, TINI, Duki\", \"Artist Followers\": 282045.0, \"Song ID\": \"74znaWw1hmQBusGPSOuTFy\", \"Genre\": \"['latin pop']\", \"Release Date\": \"2021-06-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 85.0, \"Danceability\": 0.818, \"Energy\": 0.812, \"Loudness\": -4.425, \"Speechiness\": 0.0475, \"Acousticness\": 0.112, \"Liveness\": 0.234, \"Tempo\": 139.966, \"Duration (ms)\": 231708.0, \"Valence\": 0.844, \"Chord\": \"A\"}, {\"Index\": 122, \"Highest Charting Position\": 2, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"LA NOCHE DE ANOCHE\", \"Streams\": 6242863, \"Artist\": \"Bad Bunny, ROSAL\\u00cdA\", \"Artist Followers\": 36142273.0, \"Song ID\": \"2XIc1pqjXV3Cr2BQUGNBck\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 86.0, \"Danceability\": 0.856, \"Energy\": 0.618, \"Loudness\": -4.892, \"Speechiness\": 0.286, \"Acousticness\": 0.0303, \"Liveness\": 0.0866, \"Tempo\": 81.993, \"Duration (ms)\": 203201.0, \"Valence\": 0.391, \"Chord\": \"G\"}, {\"Index\": 123, \"Highest Charting Position\": 1, \"Number of Times Charted\": 67, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"ROCKSTAR (feat. Roddy Ricch)\", \"Streams\": 6180056, \"Artist\": \"DaBaby\", \"Artist Followers\": 7593046.0, \"Song ID\": \"7ytR5pFWmSjzHJIeQkgog4\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 86.0, \"Danceability\": 0.746, \"Energy\": 0.69, \"Loudness\": -7.956, \"Speechiness\": 0.164, \"Acousticness\": 0.247, \"Liveness\": 0.101, \"Tempo\": 89.977, \"Duration (ms)\": 181733.0, \"Valence\": 0.497, \"Chord\": \"B\"}, {\"Index\": 124, \"Highest Charting Position\": 12, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Heather\", \"Streams\": 6164795, \"Artist\": \"Conan Gray\", \"Artist Followers\": 3794081.0, \"Song ID\": \"4xqrdfXkTW4T0RauPLv3WA\", \"Genre\": \"['alt z', 'bedroom pop', 'electropop', 'indie pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 86.0, \"Danceability\": 0.357, \"Energy\": 0.425, \"Loudness\": -7.301, \"Speechiness\": 0.0333, \"Acousticness\": 0.584, \"Liveness\": 0.322, \"Tempo\": 102.078, \"Duration (ms)\": 198040.0, \"Valence\": 0.27, \"Chord\": \"F\"}, {\"Index\": 125, \"Highest Charting Position\": 13, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"you broke me first\", \"Streams\": 6152121, \"Artist\": \"Tate McRae\", \"Artist Followers\": 1647262.0, \"Song ID\": \"45bE4HXI0AwGZXfZtMp8JR\", \"Genre\": \"['alt z', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 86.0, \"Danceability\": 0.667, \"Energy\": 0.373, \"Loudness\": -9.389, \"Speechiness\": 0.05, \"Acousticness\": 0.785, \"Liveness\": 0.0906, \"Tempo\": 124.148, \"Duration (ms)\": 169266.0, \"Valence\": 0.0823, \"Chord\": \"E\"}, {\"Index\": 126, \"Highest Charting Position\": 126, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"The Nights\", \"Streams\": 6136340, \"Artist\": \"Avicii\", \"Artist Followers\": 20270895.0, \"Song ID\": \"0ct6r3EGTcMLPtrXHDvVjc\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance']\", \"Release Date\": \"2014-01-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 85.0, \"Danceability\": 0.527, \"Energy\": 0.835, \"Loudness\": -5.298, \"Speechiness\": 0.0433, \"Acousticness\": 0.0166, \"Liveness\": 0.249, \"Tempo\": 125.983, \"Duration (ms)\": 176658.0, \"Valence\": 0.654, \"Chord\": \"F#/Gb\"}, {\"Index\": 127, \"Highest Charting Position\": 122, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Riptide\", \"Streams\": 6089242, \"Artist\": \"Vance Joy\", \"Artist Followers\": 2421254.0, \"Song ID\": \"3JvrhDOgAt6p7K8mDyZwRd\", \"Genre\": \"['folk-pop', 'modern rock', 'pop', 'pop rock']\", \"Release Date\": \"2014-09-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 78.0, \"Danceability\": 0.484, \"Energy\": 0.731, \"Loudness\": -6.694, \"Speechiness\": 0.0379, \"Acousticness\": 0.431, \"Liveness\": 0.151, \"Tempo\": 101.654, \"Duration (ms)\": 204280.0, \"Valence\": 0.51, \"Chord\": \"C#/Db\"}, {\"Index\": 128, \"Highest Charting Position\": 128, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Smells Like Teen Spirit\", \"Streams\": 6065267, \"Artist\": \"Nirvana\", \"Artist Followers\": 13261089.0, \"Song ID\": \"5ghIJDpPoe3CfHMGu71E6T\", \"Genre\": \"['grunge', 'permanent wave', 'rock']\", \"Release Date\": \"1991-09-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\", \"Popularity\": 77.0, \"Danceability\": 0.502, \"Energy\": 0.912, \"Loudness\": -4.556, \"Speechiness\": 0.0564, \"Acousticness\": 2.55e-05, \"Liveness\": 0.106, \"Tempo\": 116.761, \"Duration (ms)\": 301920.0, \"Valence\": 0.72, \"Chord\": \"C#/Db\"}, {\"Index\": 129, \"Highest Charting Position\": 11, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"enough for you\", \"Streams\": 6040918, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"2TOzTqQXNmR2zDJXihjZ2e\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 86.0, \"Danceability\": 0.638, \"Energy\": 0.259, \"Loudness\": -10.706, \"Speechiness\": 0.0898, \"Acousticness\": 0.753, \"Liveness\": 0.219, \"Tempo\": 88.485, \"Duration (ms)\": 202827.0, \"Valence\": 0.269, \"Chord\": \"G\"}, {\"Index\": 130, \"Highest Charting Position\": 99, \"Number of Times Charted\": 42, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Daddy Issues\", \"Streams\": 6014443, \"Artist\": \"The Neighbourhood\", \"Artist Followers\": 6662605.0, \"Song ID\": \"5E30LdtzQTGqRvNd7l6kG5\", \"Genre\": \"['modern alternative rock', 'modern rock', 'pop']\", \"Release Date\": \"2015-10-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 85.0, \"Danceability\": 0.588, \"Energy\": 0.521, \"Loudness\": -9.461, \"Speechiness\": 0.0329, \"Acousticness\": 0.0678, \"Liveness\": 0.123, \"Tempo\": 85.012, \"Duration (ms)\": 260173.0, \"Valence\": 0.337, \"Chord\": \"A#/Bb\"}, {\"Index\": 131, \"Highest Charting Position\": 131, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Aquelas Coisas\", \"Streams\": 6012839, \"Artist\": \"Jo\\u00e3o Gomes\", \"Artist Followers\": 409173.0, \"Song ID\": \"0FqVtQxRD3HsPltldG5v5M\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 84.0, \"Danceability\": 0.682, \"Energy\": 0.873, \"Loudness\": -4.163, \"Speechiness\": 0.0449, \"Acousticness\": 0.402, \"Liveness\": 0.0946, \"Tempo\": 150.006, \"Duration (ms)\": 147072.0, \"Valence\": 0.964, \"Chord\": \"F#/Gb\"}, {\"Index\": 132, \"Highest Charting Position\": 19, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Miss The Rage (feat. Playboi Carti)\", \"Streams\": 5952490, \"Artist\": \"Trippie Redd\", \"Artist Followers\": 6430522.0, \"Song ID\": \"2BITQ360Knh6qNAOqR7Dyq\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2021-05-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 85.0, \"Danceability\": 0.584, \"Energy\": 0.859, \"Loudness\": -5.616, \"Speechiness\": 0.121, \"Acousticness\": 0.0144, \"Liveness\": 0.847, \"Tempo\": 77.005, \"Duration (ms)\": 236883.0, \"Valence\": 0.369, \"Chord\": \"G#/Ab\"}, {\"Index\": 133, \"Highest Charting Position\": 4, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Memories\", \"Streams\": 5928329, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32262679.0, \"Song ID\": \"4cktbXiXOapiLBMprHFErI\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.775, \"Energy\": 0.327, \"Loudness\": -7.241, \"Speechiness\": 0.0557, \"Acousticness\": 0.841, \"Liveness\": 0.0821, \"Tempo\": 91.05, \"Duration (ms)\": 189486.0, \"Valence\": 0.595, \"Chord\": \"B\"}, {\"Index\": 134, \"Highest Charting Position\": 76, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Another Love\", \"Streams\": 5914661, \"Artist\": \"Tom Odell\", \"Artist Followers\": 1838616.0, \"Song ID\": \"7otCGmgp9h4CsR2LhwB6gt\", \"Genre\": \"['pop']\", \"Release Date\": \"2013-09-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 67.0, \"Danceability\": 0.445, \"Energy\": 0.537, \"Loudness\": -8.532, \"Speechiness\": 0.04, \"Acousticness\": 0.695, \"Liveness\": 0.0941, \"Tempo\": 122.764, \"Duration (ms)\": 244360.0, \"Valence\": 0.131, \"Chord\": \"E\"}, {\"Index\": 135, \"Highest Charting Position\": 135, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Here's Your Perfect\", \"Streams\": 5912784, \"Artist\": \"Jamie Miller\", \"Artist Followers\": 64288.0, \"Song ID\": \"2aTKrdenCq5qBOoJPFdn4P\", \"Genre\": \"['pop soul']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 85.0, \"Danceability\": 0.558, \"Energy\": 0.454, \"Loudness\": -5.335, \"Speechiness\": 0.0551, \"Acousticness\": 0.499, \"Liveness\": 0.146, \"Tempo\": 113.12, \"Duration (ms)\": 158594.0, \"Valence\": 0.424, \"Chord\": \"F#/Gb\"}, {\"Index\": 136, \"Highest Charting Position\": 108, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Take Me To Church\", \"Streams\": 5907750, \"Artist\": \"Hozier\", \"Artist Followers\": 4781906.0, \"Song ID\": \"1CS7Sd1u5tWkstBhpssyjP\", \"Genre\": \"['irish singer-songwriter', 'modern rock', 'pop']\", \"Release Date\": \"2014-09-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 74.0, \"Danceability\": 0.566, \"Energy\": 0.664, \"Loudness\": -5.303, \"Speechiness\": 0.0464, \"Acousticness\": 0.634, \"Liveness\": 0.116, \"Tempo\": 128.945, \"Duration (ms)\": 241693.0, \"Valence\": 0.437, \"Chord\": \"E\"}, {\"Index\": 137, \"Highest Charting Position\": 110, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Little Bit of Love\", \"Streams\": 5848466, \"Artist\": \"Tom Grennan\", \"Artist Followers\": 261225.0, \"Song ID\": \"2sX7lJXsOYGP1Us6CqM9t1\", \"Genre\": \"['modern rock', 'uk pop']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 80.0, \"Danceability\": 0.689, \"Energy\": 0.706, \"Loudness\": -4.48, \"Speechiness\": 0.0312, \"Acousticness\": 0.0833, \"Liveness\": 0.105, \"Tempo\": 106.52, \"Duration (ms)\": 226268.0, \"Valence\": 0.623, \"Chord\": \"C#/Db\"}, {\"Index\": 138, \"Highest Charting Position\": 138, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Ficha Limpa\", \"Streams\": 5847975, \"Artist\": \"Gusttavo Lima\", \"Artist Followers\": 12969190.0, \"Song ID\": \"5SwyN9hzmWjBsINlif8li8\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2021-06-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 85.0, \"Danceability\": 0.774, \"Energy\": 0.732, \"Loudness\": -4.227, \"Speechiness\": 0.0308, \"Acousticness\": 0.108, \"Liveness\": 0.243, \"Tempo\": 135.005, \"Duration (ms)\": 192725.0, \"Valence\": 0.734, \"Chord\": \"A\"}, {\"Index\": 139, \"Highest Charting Position\": 14, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Up\", \"Streams\": 5845156, \"Artist\": \"Cardi B\", \"Artist Followers\": 17353707.0, \"Song ID\": \"1XXimziG1uhM0eDNCZCrUl\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'rap']\", \"Release Date\": \"2021-02-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 83.0, \"Danceability\": 0.868, \"Energy\": 0.795, \"Loudness\": -6.044, \"Speechiness\": 0.269, \"Acousticness\": 0.0012, \"Liveness\": 0.0461, \"Tempo\": 166.0, \"Duration (ms)\": 156945.0, \"Valence\": 0.819, \"Chord\": \"B\"}, {\"Index\": 140, \"Highest Charting Position\": 2, \"Number of Times Charted\": 52, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Haw\\u00e1i\", \"Streams\": 5769714, \"Artist\": \"Maluma\", \"Artist Followers\": 26769304.0, \"Song ID\": \"0GzuHFG4Ql6DoyxFRnIk3F\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-11-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 77.0, \"Danceability\": 0.766, \"Energy\": 0.788, \"Loudness\": -3.128, \"Speechiness\": 0.312, \"Acousticness\": 0.105, \"Liveness\": 0.142, \"Tempo\": 179.984, \"Duration (ms)\": 200482.0, \"Valence\": 0.609, \"Chord\": \"F#/Gb\"}, {\"Index\": 141, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"New Normal\", \"Streams\": 5768653, \"Artist\": \"Khalid\", \"Artist Followers\": 14187747.0, \"Song ID\": \"2CIYemjFXdmCWpJnfbtrD6\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-07-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 79.0, \"Danceability\": 0.39, \"Energy\": 0.534, \"Loudness\": -9.575, \"Speechiness\": 0.0709, \"Acousticness\": 0.0807, \"Liveness\": 0.184, \"Tempo\": 92.047, \"Duration (ms)\": 198765.0, \"Valence\": 0.244, \"Chord\": \"C\"}, {\"Index\": 142, \"Highest Charting Position\": 81, \"Number of Times Charted\": 81, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Bohemian Rhapsody - Remastered 2011\", \"Streams\": 5756583, \"Artist\": \"Queen\", \"Artist Followers\": 35888760.0, \"Song ID\": \"7tFiyTwD0nx5a1eklYtX2J\", \"Genre\": \"['classic rock', 'glam rock', 'rock']\", \"Release Date\": \"1975-11-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.392, \"Energy\": 0.402, \"Loudness\": -9.961, \"Speechiness\": 0.0536, \"Acousticness\": 0.288, \"Liveness\": 0.243, \"Tempo\": 143.883, \"Duration (ms)\": 354320.0, \"Valence\": 0.228, \"Chord\": \"C\"}, {\"Index\": 143, \"Highest Charting Position\": 5, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Bandido\", \"Streams\": 5734402, \"Artist\": \"Myke Towers, Juhn\", \"Artist Followers\": 6150675.0, \"Song ID\": \"1xK1Gg9SxG8fy2Ya373oqb\", \"Genre\": \"['trap latino']\", \"Release Date\": \"2020-12-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\", \"Popularity\": 85.0, \"Danceability\": 0.713, \"Energy\": 0.617, \"Loudness\": -4.637, \"Speechiness\": 0.0887, \"Acousticness\": 0.122, \"Liveness\": 0.0962, \"Tempo\": 168.021, \"Duration (ms)\": 232853.0, \"Valence\": 0.682, \"Chord\": \"G#/Ab\"}, {\"Index\": 144, \"Highest Charting Position\": 25, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Paradise (feat. Dermot Kennedy)\", \"Streams\": 5693848, \"Artist\": \"MEDUZA\", \"Artist Followers\": 441674.0, \"Song ID\": \"6ft4hAq6yde8jPZY2i5zLr\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop house', 'tropical house']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 85.0, \"Danceability\": 0.632, \"Energy\": 0.595, \"Loudness\": -7.644, \"Speechiness\": 0.0401, \"Acousticness\": 0.0689, \"Liveness\": 0.209, \"Tempo\": 124.114, \"Duration (ms)\": 167903.0, \"Valence\": 0.435, \"Chord\": \"G#/Ab\"}, {\"Index\": 145, \"Highest Charting Position\": 13, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"goosebumps\", \"Streams\": 5691540, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17719446.0, \"Song ID\": \"5uEYRdEIh9Bo4fpjDd4Na9\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 87.0, \"Danceability\": 0.841, \"Energy\": 0.593, \"Loudness\": -7.846, \"Speechiness\": 0.0379, \"Acousticness\": 0.418, \"Liveness\": 0.124, \"Tempo\": 124.917, \"Duration (ms)\": 162803.0, \"Valence\": 0.808, \"Chord\": \"C#/Db\"}, {\"Index\": 146, \"Highest Charting Position\": 90, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Wasted Love (feat. Lagique)\", \"Streams\": 5690260, \"Artist\": \"Ofenbach\", \"Artist Followers\": 432581.0, \"Song ID\": \"2pPO9YecZimmuVQfIzfV6U\", \"Genre\": \"['edm', 'new french touch', 'pop dance', 'tropical house']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 85.0, \"Danceability\": 0.734, \"Energy\": 0.855, \"Loudness\": -4.578, \"Speechiness\": 0.135, \"Acousticness\": 0.0821, \"Liveness\": 0.0901, \"Tempo\": 121.955, \"Duration (ms)\": 139563.0, \"Valence\": 0.54, \"Chord\": \"F#/Gb\"}, {\"Index\": 147, \"Highest Charting Position\": 100, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"KESI - Remix\", \"Streams\": 5682062, \"Artist\": \"Camilo, Shawn Mendes\", \"Artist Followers\": 10561047.0, \"Song ID\": \"0IqCoZ168iRc9LqfrYgpZy\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2021-07-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 83.0, \"Danceability\": 0.871, \"Energy\": 0.815, \"Loudness\": -4.439, \"Speechiness\": 0.0477, \"Acousticness\": 0.127, \"Liveness\": 0.094, \"Tempo\": 122.959, \"Duration (ms)\": 176575.0, \"Valence\": 0.823, \"Chord\": \"E\"}, {\"Index\": 148, \"Highest Charting Position\": 59, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Shallow\", \"Streams\": 5672480, \"Artist\": \"Lady Gaga, Bradley Cooper\", \"Artist Followers\": 18572085.0, \"Song ID\": \"2VxeLyX666F8uXCJ0dZF8B\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-10-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.572, \"Energy\": 0.385, \"Loudness\": -6.362, \"Speechiness\": 0.0308, \"Acousticness\": 0.371, \"Liveness\": 0.231, \"Tempo\": 95.799, \"Duration (ms)\": 215733.0, \"Valence\": 0.323, \"Chord\": \"G\"}, {\"Index\": 149, \"Highest Charting Position\": 110, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Tell Em\", \"Streams\": 5668576, \"Artist\": \"Cochise, $NOT\", \"Artist Followers\": 159647.0, \"Song ID\": \"7nc7mlSdWYeFom84zZ8Wr8\", \"Genre\": \"['plugg', 'vapor trap', 'viral rap']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\", \"Popularity\": 85.0, \"Danceability\": 0.672, \"Energy\": 0.717, \"Loudness\": -7.476, \"Speechiness\": 0.226, \"Acousticness\": 0.103, \"Liveness\": 0.398, \"Tempo\": 157.905, \"Duration (ms)\": 180380.0, \"Valence\": 0.473, \"Chord\": \"F\"}, {\"Index\": 150, \"Highest Charting Position\": 103, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"N\\u00e3o, N\\u00e3o Vou\", \"Streams\": 5652272, \"Artist\": \"Mari Fernandez\", \"Artist Followers\": 15889.0, \"Song ID\": \"0xBQvhJAm6f7J142ympKOn\", \"Genre\": \"[]\", \"Release Date\": \"2021-04-29\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.631, \"Energy\": 0.861, \"Loudness\": -1.891, \"Speechiness\": 0.0424, \"Acousticness\": 0.427, \"Liveness\": 0.215, \"Tempo\": 149.95, \"Duration (ms)\": 173038.0, \"Valence\": 0.822, \"Chord\": \"B\"}, {\"Index\": 151, \"Highest Charting Position\": 147, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Counting Stars\", \"Streams\": 5647568, \"Artist\": \"OneRepublic\", \"Artist Followers\": 12169108.0, \"Song ID\": \"6sy3LkhNFjJWlaeSMNwQ62\", \"Genre\": \"['dance pop', 'piano rock', 'pop', 'pop rock']\", \"Release Date\": \"2014-01-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 74.0, \"Danceability\": 0.664, \"Energy\": 0.705, \"Loudness\": -4.972, \"Speechiness\": 0.0382, \"Acousticness\": 0.0654, \"Liveness\": 0.115, \"Tempo\": 122.017, \"Duration (ms)\": 257840.0, \"Valence\": 0.477, \"Chord\": \"C#/Db\"}, {\"Index\": 152, \"Highest Charting Position\": 121, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Yellow\", \"Streams\": 5628703, \"Artist\": \"Coldplay\", \"Artist Followers\": 31151294.0, \"Song ID\": \"3AJwUDP919kvQ9QcozQPxg\", \"Genre\": \"['permanent wave', 'pop']\", \"Release Date\": \"2000-07-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 85.0, \"Danceability\": 0.429, \"Energy\": 0.661, \"Loudness\": -7.227, \"Speechiness\": 0.0281, \"Acousticness\": 0.00239, \"Liveness\": 0.234, \"Tempo\": 173.372, \"Duration (ms)\": 266773.0, \"Valence\": 0.285, \"Chord\": \"B\"}, {\"Index\": 153, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Como Si No Importara\", \"Streams\": 5627257, \"Artist\": \"Emilia, Duki\", \"Artist Followers\": 205590.0, \"Song ID\": \"1GYJpuLq41vEVKXiHGEY9j\", \"Genre\": \"[]\", \"Release Date\": \"2021-07-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 83.0, \"Danceability\": 0.843, \"Energy\": 0.534, \"Loudness\": -6.658, \"Speechiness\": 0.142, \"Acousticness\": 0.467, \"Liveness\": 0.0984, \"Tempo\": 94.984, \"Duration (ms)\": 173053.0, \"Valence\": 0.528, \"Chord\": \"C#/Db\"}, {\"Index\": 154, \"Highest Charting Position\": 154, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Se For Amor\", \"Streams\": 5618268, \"Artist\": \"Jo\\u00e3o Gomes, Vitor Fernandes\", \"Artist Followers\": 409173.0, \"Song ID\": \"5F2xRvRFkxDvqdFtUNAEyw\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 81.0, \"Danceability\": 0.667, \"Energy\": 0.899, \"Loudness\": -4.402, \"Speechiness\": 0.0322, \"Acousticness\": 0.423, \"Liveness\": 0.332, \"Tempo\": 147.962, \"Duration (ms)\": 239928.0, \"Valence\": 0.835, \"Chord\": \"B\"}, {\"Index\": 155, \"Highest Charting Position\": 142, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Wake Me Up\", \"Streams\": 5607285, \"Artist\": \"Avicii\", \"Artist Followers\": 20270895.0, \"Song ID\": \"0nrRP2bk19rLc0orkWPQk2\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance']\", \"Release Date\": \"2013-01-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-01--2021-01-08\\n2020-08-07--2020-08-14\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.532, \"Energy\": 0.783, \"Loudness\": -5.697, \"Speechiness\": 0.0523, \"Acousticness\": 0.0038, \"Liveness\": 0.161, \"Tempo\": 124.08, \"Duration (ms)\": 247427.0, \"Valence\": 0.643, \"Chord\": \"D\"}, {\"Index\": 156, \"Highest Charting Position\": 128, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Baby Me Atende\", \"Streams\": 5594505, \"Artist\": \"Matheus Fernandes, Dilsinho\", \"Artist Followers\": 77034.0, \"Song ID\": \"5R9KPXQVeyqsHZoPLMgfNy\", \"Genre\": \"['forro', 'sertanejo pop']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 83.0, \"Danceability\": 0.65, \"Energy\": 0.792, \"Loudness\": -3.825, \"Speechiness\": 0.0393, \"Acousticness\": 0.607, \"Liveness\": 0.92, \"Tempo\": 154.027, \"Duration (ms)\": 225672.0, \"Valence\": 0.872, \"Chord\": \"F#/Gb\"}, {\"Index\": 157, \"Highest Charting Position\": 68, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Ramenez la coupe \\u00e0 la maison\", \"Streams\": 5576844, \"Artist\": \"Vegedream\", \"Artist Followers\": 1250353.0, \"Song ID\": \"0dqVP9CnGjaYNjya3gYbYy\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 0.0, \"Danceability\": 0.808, \"Energy\": 0.66, \"Loudness\": -6.237, \"Speechiness\": 0.0395, \"Acousticness\": 0.0358, \"Liveness\": 0.138, \"Tempo\": 107.994, \"Duration (ms)\": 235556.0, \"Valence\": 0.804, \"Chord\": \"C\"}, {\"Index\": 158, \"Highest Charting Position\": 6, \"Number of Times Charted\": 47, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"What You Know Bout Love\", \"Streams\": 5570735, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"1tkg4EHVoqnhR6iFEXb60y\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-07-03--2020-07-10\", \"Popularity\": 85.0, \"Danceability\": 0.709, \"Energy\": 0.548, \"Loudness\": -8.493, \"Speechiness\": 0.353, \"Acousticness\": 0.65, \"Liveness\": 0.133, \"Tempo\": 83.995, \"Duration (ms)\": 160000.0, \"Valence\": 0.543, \"Chord\": \"A#/Bb\"}, {\"Index\": 159, \"Highest Charting Position\": 19, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Runaway\", \"Streams\": 5566150, \"Artist\": \"AURORA\", \"Artist Followers\": 1687399.0, \"Song ID\": \"0TCmhnbMpw5zwPsTvlXTJi\", \"Genre\": \"['art pop', 'norwegian pop']\", \"Release Date\": \"2014\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 77.0, \"Danceability\": 0.521, \"Energy\": 0.277, \"Loudness\": -10.34, \"Speechiness\": 0.0356, \"Acousticness\": 0.634, \"Liveness\": 0.103, \"Tempo\": 115.01, \"Duration (ms)\": 248827.0, \"Valence\": 0.13, \"Chord\": \"B\"}, {\"Index\": 160, \"Highest Charting Position\": 121, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Red Light Green Light\", \"Streams\": 5493760, \"Artist\": \"DaBaby\", \"Artist Followers\": 7593046.0, \"Song ID\": \"1YDebgap5OFwXEBG18NJvy\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.933, \"Energy\": 0.656, \"Loudness\": -5.85, \"Speechiness\": 0.322, \"Acousticness\": 0.129, \"Liveness\": 0.161, \"Tempo\": 119.987, \"Duration (ms)\": 159083.0, \"Valence\": 0.934, \"Chord\": \"D\"}, {\"Index\": 161, \"Highest Charting Position\": 120, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Ball If I Want To\", \"Streams\": 5478055, \"Artist\": \"DaBaby\", \"Artist Followers\": 7593046.0, \"Song ID\": \"0cu0rhnlCnJ7JIeHRiLpj3\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\", \"Popularity\": 84.0, \"Danceability\": 0.902, \"Energy\": 0.669, \"Loudness\": -5.049, \"Speechiness\": 0.457, \"Acousticness\": 0.161, \"Liveness\": 0.0728, \"Tempo\": 139.949, \"Duration (ms)\": 112547.0, \"Valence\": 0.628, \"Chord\": \"C#/Db\"}, {\"Index\": 162, \"Highest Charting Position\": 31, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lucid Dreams\", \"Streams\": 5477563, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"285pBltuF7vW8TeWk8hdRR\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2018-12-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.511, \"Energy\": 0.566, \"Loudness\": -7.23, \"Speechiness\": 0.2, \"Acousticness\": 0.349, \"Liveness\": 0.34, \"Tempo\": 83.903, \"Duration (ms)\": 239836.0, \"Valence\": 0.218, \"Chord\": \"F#/Gb\"}, {\"Index\": 163, \"Highest Charting Position\": 4, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Calling My Phone\", \"Streams\": 5467753, \"Artist\": \"Lil Tjay, 6LACK\", \"Artist Followers\": 3553442.0, \"Song ID\": \"3J8EOeKLTLXORtWPpOU5bE\", \"Genre\": \"['brooklyn drill', 'melodic rap', 'nyc rap']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 85.0, \"Danceability\": 0.907, \"Energy\": 0.393, \"Loudness\": -7.636, \"Speechiness\": 0.0539, \"Acousticness\": 0.451, \"Liveness\": 0.135, \"Tempo\": 104.949, \"Duration (ms)\": 205458.0, \"Valence\": 0.202, \"Chord\": \"E\"}, {\"Index\": 164, \"Highest Charting Position\": 5, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"34+35\", \"Streams\": 5453159, \"Artist\": \"Ariana Grande\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 165, \"Highest Charting Position\": 13, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"bad guy\", \"Streams\": 5436286, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"1hewNsVmijBqjKvFRQfk4m\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.701, \"Energy\": 0.425, \"Loudness\": -10.965, \"Speechiness\": 0.375, \"Acousticness\": 0.328, \"Liveness\": 0.1, \"Tempo\": 135.128, \"Duration (ms)\": 194088.0, \"Valence\": 0.562, \"Chord\": \"G\"}, {\"Index\": 166, \"Highest Charting Position\": 59, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Cover Me In Sunshine\", \"Streams\": 5434073, \"Artist\": \"P!nk, Willow Sage Hart\", \"Artist Followers\": 11477164.0, \"Song ID\": \"6Tio0ZoDeSQnI7EBAqWer2\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-02-12\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 83.0, \"Danceability\": 0.476, \"Energy\": 0.594, \"Loudness\": -6.879, \"Speechiness\": 0.135, \"Acousticness\": 0.0599, \"Liveness\": 0.0785, \"Tempo\": 159.702, \"Duration (ms)\": 141050.0, \"Valence\": 0.314, \"Chord\": \"F\"}, {\"Index\": 167, \"Highest Charting Position\": 7, \"Number of Times Charted\": 56, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"For The Night (feat. Lil Baby & DaBaby)\", \"Streams\": 5431375, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"0PvFJmanyNQMseIFrU708S\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 84.0, \"Danceability\": 0.823, \"Energy\": 0.586, \"Loudness\": -6.606, \"Speechiness\": 0.2, \"Acousticness\": 0.114, \"Liveness\": 0.193, \"Tempo\": 125.971, \"Duration (ms)\": 190476.0, \"Valence\": 0.347, \"Chord\": \"F#/Gb\"}, {\"Index\": 168, \"Highest Charting Position\": 13, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"1 step forward, 3 steps back\", \"Streams\": 5420003, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"4wcBRRpIfesgcyUtis7PEg\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 85.0, \"Danceability\": 0.473, \"Energy\": 0.203, \"Loudness\": -12.627, \"Speechiness\": 0.102, \"Acousticness\": 0.941, \"Liveness\": 0.126, \"Tempo\": 168.884, \"Duration (ms)\": 163587.0, \"Valence\": 0.419, \"Chord\": \"D\"}, {\"Index\": 169, \"Highest Charting Position\": 1, \"Number of Times Charted\": 51, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"WAP (feat. Megan Thee Stallion)\", \"Streams\": 5386268, \"Artist\": \"Cardi B\", \"Artist Followers\": 17353707.0, \"Song ID\": \"4Oun2ylbjFKMPTiaSbbCih\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'rap']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 84.0, \"Danceability\": 0.935, \"Energy\": 0.454, \"Loudness\": -7.509, \"Speechiness\": 0.375, \"Acousticness\": 0.0194, \"Liveness\": 0.0824, \"Tempo\": 133.073, \"Duration (ms)\": 187541.0, \"Valence\": 0.357, \"Chord\": \"C#/Db\"}, {\"Index\": 170, \"Highest Charting Position\": 155, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Mr. Brightside\", \"Streams\": 5382191, \"Artist\": \"The Killers\", \"Artist Followers\": 6118063.0, \"Song ID\": \"7oK9VyNzrYvRFo7nQEYkWN\", \"Genre\": \"['dance rock', 'modern rock', 'permanent wave', 'rock']\", \"Release Date\": \"2004-06-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-12--2021-03-19\\n2021-02-26--2021-03-05\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 75.0, \"Danceability\": 0.356, \"Energy\": 0.924, \"Loudness\": -3.74, \"Speechiness\": 0.0808, \"Acousticness\": 0.00101, \"Liveness\": 0.0953, \"Tempo\": 148.017, \"Duration (ms)\": 222587.0, \"Valence\": 0.232, \"Chord\": \"C#/Db\"}, {\"Index\": 171, \"Highest Charting Position\": 144, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Every Breath You Take\", \"Streams\": 5379704, \"Artist\": \"The Police\", \"Artist Followers\": 4339245.0, \"Song ID\": \"1JSTJqkT5qHq8MDJnJbRE1\", \"Genre\": \"['album rock', 'art rock', 'classic rock', 'mellow gold', 'new wave', 'permanent wave', 'rock', 'soft rock']\", \"Release Date\": \"1983-06-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-01-01--2021-01-08\\n2020-06-19--2020-06-26\\n2020-06-05--2020-06-12\", \"Popularity\": 83.0, \"Danceability\": 0.82, \"Energy\": 0.452, \"Loudness\": -9.796, \"Speechiness\": 0.0348, \"Acousticness\": 0.543, \"Liveness\": 0.0714, \"Tempo\": 117.401, \"Duration (ms)\": 253920.0, \"Valence\": 0.74, \"Chord\": \"C#/Db\"}, {\"Index\": 172, \"Highest Charting Position\": 20, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Dreams - 2004 Remaster\", \"Streams\": 5378971, \"Artist\": \"Fleetwood Mac\", \"Artist Followers\": 6930669.0, \"Song ID\": \"0ofHAoxe9vBkTCp2UQIavz\", \"Genre\": \"['album rock', 'classic rock', 'mellow gold', 'rock', 'soft rock', 'yacht rock']\", \"Release Date\": \"1977-02-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 84.0, \"Danceability\": 0.828, \"Energy\": 0.492, \"Loudness\": -9.744, \"Speechiness\": 0.0276, \"Acousticness\": 0.0644, \"Liveness\": 0.128, \"Tempo\": 120.151, \"Duration (ms)\": 257800.0, \"Valence\": 0.789, \"Chord\": \"C\"}, {\"Index\": 173, \"Highest Charting Position\": 94, \"Number of Times Charted\": 82, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Say You Won't Let Go\", \"Streams\": 5375426, \"Artist\": \"James Arthur\", \"Artist Followers\": 8441598.0, \"Song ID\": \"5uCax9HTNlzGybIStD3vDh\", \"Genre\": \"['pop', 'post-teen pop', 'talent show', 'uk pop']\", \"Release Date\": \"2016-10-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.358, \"Energy\": 0.557, \"Loudness\": -7.398, \"Speechiness\": 0.059, \"Acousticness\": 0.695, \"Liveness\": 0.0902, \"Tempo\": 85.043, \"Duration (ms)\": 211467.0, \"Valence\": 0.494, \"Chord\": \"A#/Bb\"}, {\"Index\": 174, \"Highest Charting Position\": 110, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Wild Side (feat. Cardi B)\", \"Streams\": 5366242, \"Artist\": \"Normani\", \"Artist Followers\": 1304510.0, \"Song ID\": \"2vXgyN14LX2zl7JEASw242\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop', 'r&b', 'urban contemporary']\", \"Release Date\": \"2021-07-22\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 75.0, \"Danceability\": 0.74, \"Energy\": 0.576, \"Loudness\": -6.744, \"Speechiness\": 0.146, \"Acousticness\": 0.0249, \"Liveness\": 0.104, \"Tempo\": 110.095, \"Duration (ms)\": 209476.0, \"Valence\": 0.315, \"Chord\": \"F#/Gb\"}, {\"Index\": 175, \"Highest Charting Position\": 65, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Bout A Million (feat. 42 Dugg & 21 Savage)\", \"Streams\": 5315734, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"4LaGu95Ui2s4vprSQYWUAZ\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 81.0, \"Danceability\": 0.716, \"Energy\": 0.67, \"Loudness\": -6.995, \"Speechiness\": 0.101, \"Acousticness\": 0.526, \"Liveness\": 0.13, \"Tempo\": 145.043, \"Duration (ms)\": 203586.0, \"Valence\": 0.411, \"Chord\": \"C\"}, {\"Index\": 176, \"Highest Charting Position\": 72, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Demeanor (feat. Dua Lipa)\", \"Streams\": 5245618, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"3DMs7bahbQTnoxCjgP7qoK\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 81.0, \"Danceability\": 0.675, \"Energy\": 0.608, \"Loudness\": -6.934, \"Speechiness\": 0.103, \"Acousticness\": 0.336, \"Liveness\": 0.11, \"Tempo\": 99.865, \"Duration (ms)\": 184800.0, \"Valence\": 0.728, \"Chord\": \"D#/Eb\"}, {\"Index\": 177, \"Highest Charting Position\": 4, \"Number of Times Charted\": 76, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"death bed (coffee for your head)\", \"Streams\": 5238547, \"Artist\": \"Powfu, beabadoobee\", \"Artist Followers\": 924083.0, \"Song ID\": \"7eJMfftS33KTjuF7lTsMCx\", \"Genre\": \"['sad rap']\", \"Release Date\": \"2020-02-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 85.0, \"Danceability\": 0.726, \"Energy\": 0.431, \"Loudness\": -8.765, \"Speechiness\": 0.135, \"Acousticness\": 0.731, \"Liveness\": 0.696, \"Tempo\": 144.026, \"Duration (ms)\": 173333.0, \"Valence\": 0.348, \"Chord\": \"G#/Ab\"}, {\"Index\": 178, \"Highest Charting Position\": 100, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Our Song\", \"Streams\": 5235335, \"Artist\": \"Anne-Marie, Niall Horan\", \"Artist Followers\": 8148393.0, \"Song ID\": \"5zqObw7wjBgL9TDiAymxPn\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 83.0, \"Danceability\": 0.595, \"Energy\": 0.759, \"Loudness\": -4.245, \"Speechiness\": 0.0423, \"Acousticness\": 0.141, \"Liveness\": 0.172, \"Tempo\": 80.953, \"Duration (ms)\": 163733.0, \"Valence\": 0.515, \"Chord\": \"B\"}, {\"Index\": 179, \"Highest Charting Position\": 138, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Another One Bites The Dust - Remastered 2011\", \"Streams\": 5204983, \"Artist\": \"Queen\", \"Artist Followers\": 35888760.0, \"Song ID\": \"57JVGBtBLCfHw2muk5416J\", \"Genre\": \"['classic rock', 'glam rock', 'rock']\", \"Release Date\": \"1980-06-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.933, \"Energy\": 0.528, \"Loudness\": -6.472, \"Speechiness\": 0.162, \"Acousticness\": 0.112, \"Liveness\": 0.163, \"Tempo\": 109.975, \"Duration (ms)\": 214653.0, \"Valence\": 0.756, \"Chord\": \"F\"}, {\"Index\": 180, \"Highest Charting Position\": 149, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"One Dance\", \"Streams\": 5178490, \"Artist\": \"Drake, WizKid, Kyla\", \"Artist Followers\": 56308172.0, \"Song ID\": \"1zi7xx7UVEFkmKfv06H8x0\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2016-05-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 84.0, \"Danceability\": 0.792, \"Energy\": 0.625, \"Loudness\": -5.609, \"Speechiness\": 0.0536, \"Acousticness\": 0.00776, \"Liveness\": 0.329, \"Tempo\": 103.967, \"Duration (ms)\": 173987.0, \"Valence\": 0.37, \"Chord\": \"C#/Db\"}, {\"Index\": 181, \"Highest Charting Position\": 15, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Adore You\", \"Streams\": 5166847, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16112621.0, \"Song ID\": \"3jjujdWJ72nww5eGnfs2E7\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.676, \"Energy\": 0.771, \"Loudness\": -3.675, \"Speechiness\": 0.0483, \"Acousticness\": 0.0237, \"Liveness\": 0.102, \"Tempo\": 99.048, \"Duration (ms)\": 207133.0, \"Valence\": 0.569, \"Chord\": \"G#/Ab\"}, {\"Index\": 182, \"Highest Charting Position\": 181, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"As the World Caves In\", \"Streams\": 5145493, \"Artist\": \"Sarah Cothran\", \"Artist Followers\": 180723.0, \"Song ID\": \"2xXNLutYAOELYVObYb1C1S\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-04--2021-06-11\", \"Popularity\": 71.0, \"Danceability\": 0.422, \"Energy\": 0.25, \"Loudness\": -6.836, \"Speechiness\": 0.0351, \"Acousticness\": 0.441, \"Liveness\": 0.35, \"Tempo\": 124.026, \"Duration (ms)\": 161613.0, \"Valence\": 0.246, \"Chord\": \"C\"}, {\"Index\": 183, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Fancy Like\", \"Streams\": 5145432, \"Artist\": \"Walker Hayes\", \"Artist Followers\": 304995.0, \"Song ID\": \"3ZozFqJJlDBNIm4xqxn2ZD\", \"Genre\": \"['contemporary country', 'country', 'country road', 'modern country rock']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 83.0, \"Danceability\": 0.649, \"Energy\": 0.76, \"Loudness\": -6.487, \"Speechiness\": 0.0574, \"Acousticness\": 0.114, \"Liveness\": 0.317, \"Tempo\": 80.018, \"Duration (ms)\": 161853.0, \"Valence\": 0.843, \"Chord\": \"C#/Db\"}, {\"Index\": 184, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"C\\u00farame\", \"Streams\": 5104206, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6080597.0, \"Song ID\": \"3PwRuzdphgedcWVUOVYJ7I\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 85.0, \"Danceability\": 0.765, \"Energy\": 0.625, \"Loudness\": -3.599, \"Speechiness\": 0.0548, \"Acousticness\": 0.584, \"Liveness\": 0.112, \"Tempo\": 102.101, \"Duration (ms)\": 164706.0, \"Valence\": 0.262, \"Chord\": \"A\"}, {\"Index\": 185, \"Highest Charting Position\": 110, \"Number of Times Charted\": 78, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"All of Me\", \"Streams\": 5103014, \"Artist\": \"John Legend\", \"Artist Followers\": 5799137.0, \"Song ID\": \"3U4isOIWM3VvDubwSI3y7a\", \"Genre\": \"['neo soul', 'pop', 'pop soul', 'r&b', 'urban contemporary']\", \"Release Date\": \"2013-08-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.422, \"Energy\": 0.264, \"Loudness\": -7.064, \"Speechiness\": 0.0322, \"Acousticness\": 0.922, \"Liveness\": 0.132, \"Tempo\": 119.93, \"Duration (ms)\": 269560.0, \"Valence\": 0.331, \"Chord\": \"G#/Ab\"}, {\"Index\": 186, \"Highest Charting Position\": 80, \"Number of Times Charted\": 41, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Martin & Gina\", \"Streams\": 5098609, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"1VLtjHwRWOVJiE5Py7JxoQ\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 85.0, \"Danceability\": 0.832, \"Energy\": 0.534, \"Loudness\": -7.813, \"Speechiness\": 0.253, \"Acousticness\": 0.345, \"Liveness\": 0.165, \"Tempo\": 93.924, \"Duration (ms)\": 132833.0, \"Valence\": 0.116, \"Chord\": \"C#/Db\"}, {\"Index\": 187, \"Highest Charting Position\": 40, \"Number of Times Charted\": 65, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Dior\", \"Streams\": 5092354, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"79s5XnCN4TJKTVMSmOx8Ep\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2019-07-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-06-18--2021-06-25\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 83.0, \"Danceability\": 0.548, \"Energy\": 0.805, \"Loudness\": -5.732, \"Speechiness\": 0.351, \"Acousticness\": 0.212, \"Liveness\": 0.408, \"Tempo\": 142.094, \"Duration (ms)\": 216387.0, \"Valence\": 0.648, \"Chord\": \"G\"}, {\"Index\": 188, \"Highest Charting Position\": 45, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Best Friend (feat. Doja Cat)\", \"Streams\": 5090062, \"Artist\": \"Saweetie\", \"Artist Followers\": 1254432.0, \"Song ID\": \"2etHQJxIbV0soyPhelVs9Y\", \"Genre\": \"['cali rap', 'dance pop', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2021-01-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 83.0, \"Danceability\": 0.84, \"Energy\": 0.766, \"Loudness\": -4.12, \"Speechiness\": 0.136, \"Acousticness\": 0.00302, \"Liveness\": 0.0684, \"Tempo\": 94.018, \"Duration (ms)\": 155884.0, \"Valence\": 0.402, \"Chord\": \"E\"}, {\"Index\": 189, \"Highest Charting Position\": 52, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"The Hills\", \"Streams\": 5068864, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"7fBv7CLKzipRk6EC6TWHOB\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2015-08-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 84.0, \"Danceability\": 0.585, \"Energy\": 0.564, \"Loudness\": -7.063, \"Speechiness\": 0.0515, \"Acousticness\": 0.0671, \"Liveness\": 0.135, \"Tempo\": 113.003, \"Duration (ms)\": 242253.0, \"Valence\": 0.137, \"Chord\": \"C\"}, {\"Index\": 190, \"Highest Charting Position\": 5, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Good Days\", \"Streams\": 5065132, \"Artist\": \"SZA\", \"Artist Followers\": 5881963.0, \"Song ID\": \"3YJJjQPAbDT7mGpX3WtQ9A\", \"Genre\": \"['pop', 'pop rap', 'r&b']\", \"Release Date\": \"2020-12-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 84.0, \"Danceability\": 0.436, \"Energy\": 0.655, \"Loudness\": -8.37, \"Speechiness\": 0.0583, \"Acousticness\": 0.499, \"Liveness\": 0.688, \"Tempo\": 121.002, \"Duration (ms)\": 279204.0, \"Valence\": 0.412, \"Chord\": \"C#/Db\"}, {\"Index\": 191, \"Highest Charting Position\": 191, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Kiss My (Uh Oh)\", \"Streams\": 5063181, \"Artist\": \"Anne-Marie, Little Mix\", \"Artist Followers\": 8148393.0, \"Song ID\": \"0MWiSBKm8Avs8iDIxcertp\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2021-07-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 78.0, \"Danceability\": 0.638, \"Energy\": 0.878, \"Loudness\": -3.639, \"Speechiness\": 0.0484, \"Acousticness\": 0.0151, \"Liveness\": 0.308, \"Tempo\": 103.948, \"Duration (ms)\": 176800.0, \"Valence\": 0.481, \"Chord\": \"F\"}, {\"Index\": 192, \"Highest Charting Position\": 64, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"De Museo\", \"Streams\": 5016125, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36142273.0, \"Song ID\": \"267NGliXM8YLVZiKAD9Otm\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 83.0, \"Danceability\": 0.592, \"Energy\": 0.494, \"Loudness\": -10.618, \"Speechiness\": 0.0747, \"Acousticness\": 0.237, \"Liveness\": 0.13, \"Tempo\": 132.037, \"Duration (ms)\": 209771.0, \"Valence\": 0.231, \"Chord\": \"E\"}, {\"Index\": 193, \"Highest Charting Position\": 41, \"Number of Times Charted\": 81, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"7 rings\", \"Streams\": 5002227, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67158068.0, \"Song ID\": \"6ocbgoVGwYJhOv1GgI9NsF\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-02-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.778, \"Energy\": 0.317, \"Loudness\": -10.732, \"Speechiness\": 0.334, \"Acousticness\": 0.592, \"Liveness\": 0.0881, \"Tempo\": 140.048, \"Duration (ms)\": 178627.0, \"Valence\": 0.327, \"Chord\": \"C#/Db\"}, {\"Index\": 194, \"Highest Charting Position\": 194, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Chosen (feat. Ty Dolla $ign)\", \"Streams\": 4992405, \"Artist\": \"Blxst, Tyga\", \"Artist Followers\": 167628.0, \"Song ID\": \"1dIWPXMX4kRHj6Dt2DStUQ\", \"Genre\": \"[]\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 84.0, \"Danceability\": 0.571, \"Energy\": 0.767, \"Loudness\": -5.16, \"Speechiness\": 0.287, \"Acousticness\": 0.336, \"Liveness\": 0.0809, \"Tempo\": 93.421, \"Duration (ms)\": 161684.0, \"Valence\": 0.605, \"Chord\": \"D\"}, {\"Index\": 195, \"Highest Charting Position\": 149, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"N\\u00e3o Nasceu pra Namorar\", \"Streams\": 4978559, \"Artist\": \"MC Zaquin, MC Rick\", \"Artist Followers\": 130627.0, \"Song ID\": \"6pQKUKBpwr6GhfhcFFFozo\", \"Genre\": \"['funk bh', 'funk carioca']\", \"Release Date\": \"2021-02-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.525, \"Energy\": 0.448, \"Loudness\": -4.075, \"Speechiness\": 0.0443, \"Acousticness\": 0.14, \"Liveness\": 0.0922, \"Tempo\": 83.406, \"Duration (ms)\": 140308.0, \"Valence\": 0.527, \"Chord\": \"C#/Db\"}, {\"Index\": 196, \"Highest Charting Position\": 8, \"Number of Times Charted\": 71, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Breaking Me\", \"Streams\": 4977498, \"Artist\": \"Topic, A7S\", \"Artist Followers\": 151832.0, \"Song ID\": \"3H7ihDc1dqLriiWXwsc2po\", \"Genre\": \"['dance pop', 'edm', 'german dance', 'pop dance', 'pop edm', 'tropical house']\", \"Release Date\": \"2019-12-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 84.0, \"Danceability\": 0.789, \"Energy\": 0.72, \"Loudness\": -5.652, \"Speechiness\": 0.218, \"Acousticness\": 0.223, \"Liveness\": 0.129, \"Tempo\": 122.031, \"Duration (ms)\": 166794.0, \"Valence\": 0.664, \"Chord\": \"G#/Ab\"}, {\"Index\": 197, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"penhasco.\", \"Streams\": 4973937, \"Artist\": \"Lu\\u00edsa Sonza\", \"Artist Followers\": 1909059.0, \"Song ID\": \"5VTqW8raQYnj2avZ27nO2a\", \"Genre\": \"['funk carioca', 'pop nacional']\", \"Release Date\": \"2021-07-18\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 80.0, \"Danceability\": 0.43, \"Energy\": 0.467, \"Loudness\": -8.56, \"Speechiness\": 0.051, \"Acousticness\": 0.775, \"Liveness\": 0.0933, \"Tempo\": 77.249, \"Duration (ms)\": 186121.0, \"Valence\": 0.382, \"Chord\": \"G#/Ab\"}, {\"Index\": 198, \"Highest Charting Position\": 58, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Late At Night\", \"Streams\": 4954899, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6603627.0, \"Song ID\": \"1fxYz1s15pyZLsJT0Hdh1m\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 84.0, \"Danceability\": 0.643, \"Energy\": 0.403, \"Loudness\": -11.254, \"Speechiness\": 0.41, \"Acousticness\": 0.343, \"Liveness\": 0.138, \"Tempo\": 98.54, \"Duration (ms)\": 174682.0, \"Valence\": 0.111, \"Chord\": \"C#/Db\"}, {\"Index\": 199, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Verdansk\", \"Streams\": 4950275, \"Artist\": \"Dave\", \"Artist Followers\": 1427540.0, \"Song ID\": \"7IPKXYU2rTMnrLW5IZ7ZI5\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2021-07-22\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 77.0, \"Danceability\": 0.961, \"Energy\": 0.502, \"Loudness\": -8.605, \"Speechiness\": 0.312, \"Acousticness\": 0.28, \"Liveness\": 0.145, \"Tempo\": 117.078, \"Duration (ms)\": 182285.0, \"Valence\": 0.536, \"Chord\": \"D\"}, {\"Index\": 200, \"Highest Charting Position\": 172, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"The Real Slim Shady\", \"Streams\": 4948965, \"Artist\": \"Eminem\", \"Artist Followers\": 46785561.0, \"Song ID\": \"3yfqSUWxFvZELEM4PmlwIR\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2000-05-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 84.0, \"Danceability\": 0.949, \"Energy\": 0.661, \"Loudness\": -4.244, \"Speechiness\": 0.0572, \"Acousticness\": 0.0302, \"Liveness\": 0.0454, \"Tempo\": 104.504, \"Duration (ms)\": 284200.0, \"Valence\": 0.76, \"Chord\": \"F\"}, {\"Index\": 201, \"Highest Charting Position\": 66, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Tell The Vision (feat. Kanye West & Pusha T)\", \"Streams\": 8859168, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"1Eu51GaXEehPMrDMh5QghA\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 57.0, \"Danceability\": 0.662, \"Energy\": 0.686, \"Loudness\": -8.302, \"Speechiness\": 0.332, \"Acousticness\": 0.251, \"Liveness\": 0.349, \"Tempo\": 143.971, \"Duration (ms)\": 215000.0, \"Valence\": 0.678, \"Chord\": \"G\"}, {\"Index\": 202, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Woo Baby (feat. Chris Brown)\", \"Streams\": 7371935, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"6bsqes8Zg9gUULzuCkMUs0\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 56.0, \"Danceability\": 0.563, \"Energy\": 0.672, \"Loudness\": -7.226, \"Speechiness\": 0.0765, \"Acousticness\": 0.359, \"Liveness\": 0.0972, \"Tempo\": 99.772, \"Duration (ms)\": 156000.0, \"Valence\": 0.284, \"Chord\": \"A\"}, {\"Index\": 203, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Holy Smokes\", \"Streams\": 6464206, \"Artist\": \"Trippie Redd, Lil Uzi Vert\", \"Artist Followers\": 6430522.0, \"Song ID\": \"3EpF150nXMSNjiH0bbmXIL\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 79.0, \"Danceability\": 0.437, \"Energy\": 0.527, \"Loudness\": -6.967, \"Speechiness\": 0.465, \"Acousticness\": 0.185, \"Liveness\": 0.153, \"Tempo\": 187.815, \"Duration (ms)\": 181714.0, \"Valence\": 0.701, \"Chord\": \"F#/Gb\"}, {\"Index\": 204, \"Highest Charting Position\": 127, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"More Time\", \"Streams\": 6238351, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"7wAnRqccDr2tzcSKLR4jKl\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 55.0, \"Danceability\": 0.628, \"Energy\": 0.581, \"Loudness\": -8.377, \"Speechiness\": 0.188, \"Acousticness\": 0.46, \"Liveness\": 0.152, \"Tempo\": 145.396, \"Duration (ms)\": 120828.0, \"Valence\": 0.259, \"Chord\": \"D\"}, {\"Index\": 205, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Coupe\", \"Streams\": 6161664, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"7LB3ilSpX1mSMKKztNTnu2\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 54.0, \"Danceability\": 0.912, \"Energy\": 0.589, \"Loudness\": -7.476, \"Speechiness\": 0.2, \"Acousticness\": 0.0332, \"Liveness\": 0.0795, \"Tempo\": 135.921, \"Duration (ms)\": 123549.0, \"Valence\": 0.486, \"Chord\": \"G#/Ab\"}, {\"Index\": 206, \"Highest Charting Position\": 76, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Holiday\", \"Streams\": 5883145, \"Artist\": \"KSI\", \"Artist Followers\": 2008516.0, \"Song ID\": \"6nV2dFZXpv1JlqDWBeTXRl\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 81.0, \"Danceability\": 0.356, \"Energy\": 0.684, \"Loudness\": -7.347, \"Speechiness\": 0.0878, \"Acousticness\": 0.152, \"Liveness\": 0.101, \"Tempo\": 87.188, \"Duration (ms)\": 193733.0, \"Valence\": 0.347, \"Chord\": \"G#/Ab\"}, {\"Index\": 207, \"Highest Charting Position\": 150, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Manslaughter (feat. Rick Ross & The-Dream)\", \"Streams\": 5822266, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"4byRwLo7EmkCNBU6S8G6u0\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 55.0, \"Danceability\": 0.441, \"Energy\": 0.623, \"Loudness\": -7.331, \"Speechiness\": 0.0414, \"Acousticness\": 0.135, \"Liveness\": 0.14, \"Tempo\": 78.082, \"Duration (ms)\": 249231.0, \"Valence\": 0.285, \"Chord\": \"C#/Db\"}, {\"Index\": 208, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Genius (feat. Lil Tjay & Swae Lee)\", \"Streams\": 5702636, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"2mmRtchzDVpCj9LSyexgjS\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 53.0, \"Danceability\": 0.723, \"Energy\": 0.667, \"Loudness\": -7.524, \"Speechiness\": 0.351, \"Acousticness\": 0.256, \"Liveness\": 0.261, \"Tempo\": 143.044, \"Duration (ms)\": 208112.0, \"Valence\": 0.396, \"Chord\": \"D\"}, {\"Index\": 209, \"Highest Charting Position\": 22, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"WUSYANAME (feat. Youngboy Never Broke Again & Ty Dolla $ign)\", \"Streams\": 5696113, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"5B0kgjHULYJhAQkK5XsMoC\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.493, \"Energy\": 0.653, \"Loudness\": -5.666, \"Speechiness\": 0.0466, \"Acousticness\": 0.269, \"Liveness\": 0.511, \"Tempo\": 142.347, \"Duration (ms)\": 121573.0, \"Valence\": 0.852, \"Chord\": \"C\"}, {\"Index\": 210, \"Highest Charting Position\": 105, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Sommergewitter\", \"Streams\": 5627519, \"Artist\": \"Pashanim\", \"Artist Followers\": 208554.0, \"Song ID\": \"2H7jZg2HliuQhZjfBblLrZ\", \"Genre\": \"['german alternative rap', 'german drill', 'german hip hop', 'german trap']\", \"Release Date\": \"2021-06-24\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.787, \"Energy\": 0.531, \"Loudness\": -10.569, \"Speechiness\": 0.101, \"Acousticness\": 0.132, \"Liveness\": 0.112, \"Tempo\": 91.996, \"Duration (ms)\": 138533.0, \"Valence\": 0.721, \"Chord\": \"B\"}, {\"Index\": 211, \"Highest Charting Position\": 17, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Body (Remix) [feat. ArrDee, E1 (3x3), ZT (3x3), Bugzy Malone, Buni, Fivio Foreign & Darkoo]\", \"Streams\": 5383125, \"Artist\": \"Tion Wayne, Russ Millions\", \"Artist Followers\": 323203.0, \"Song ID\": \"6uvMKqNlrSvcC4NaKnrwjZ\", \"Genre\": \"['london rap']\", \"Release Date\": \"2021-04-22\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 84.0, \"Danceability\": 0.883, \"Energy\": 0.674, \"Loudness\": -8.043, \"Speechiness\": 0.357, \"Acousticness\": 0.21, \"Liveness\": 0.0678, \"Tempo\": 141.02, \"Duration (ms)\": 278085.0, \"Valence\": 0.73, \"Chord\": \"B\"}, {\"Index\": 212, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Brush Em (feat. Rah Swish)\", \"Streams\": 5335271, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"58aW6yZGFl7rVM7SLfLnLL\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 54.0, \"Danceability\": 0.654, \"Energy\": 0.724, \"Loudness\": -6.59, \"Speechiness\": 0.355, \"Acousticness\": 0.106, \"Liveness\": 0.655, \"Tempo\": 71.696, \"Duration (ms)\": 150449.0, \"Valence\": 0.717, \"Chord\": \"D#/Eb\"}, {\"Index\": 213, \"Highest Charting Position\": 13, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"AM\", \"Streams\": 5288927, \"Artist\": \"Nio Garcia, Flow La Movie\", \"Artist Followers\": 2123734.0, \"Song ID\": \"2dNhNlpZAtV4lwAFW45LIv\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-01-28\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 85.0, \"Danceability\": 0.83, \"Energy\": 0.517, \"Loudness\": -6.416, \"Speechiness\": 0.333, \"Acousticness\": 0.399, \"Liveness\": 0.0916, \"Tempo\": 171.959, \"Duration (ms)\": 182496.0, \"Valence\": 0.616, \"Chord\": \"F#/Gb\"}, {\"Index\": 214, \"Highest Charting Position\": 175, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"MI FAI IMPAZZIRE\", \"Streams\": 5242097, \"Artist\": \"BLANCO, Sfera Ebbasta\", \"Artist Followers\": 127364.0, \"Song ID\": \"1x3Qb8np6S1UvpSLthwEJN\", \"Genre\": \"['italian hip hop', 'italian pop']\", \"Release Date\": \"2021-06-17\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\", \"Popularity\": 83.0, \"Danceability\": 0.477, \"Energy\": 0.844, \"Loudness\": -4.87, \"Speechiness\": 0.0458, \"Acousticness\": 0.00273, \"Liveness\": 0.137, \"Tempo\": 169.941, \"Duration (ms)\": 220235.0, \"Valence\": 0.203, \"Chord\": \"B\"}, {\"Index\": 215, \"Highest Charting Position\": 20, \"Number of Times Charted\": 82, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Ride It\", \"Streams\": 5235088, \"Artist\": \"Regard\", \"Artist Followers\": 152226.0, \"Song ID\": \"2tnVG71enUj33Ic2nFN6kZ\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop edm', 'slap house', 'tropical house']\", \"Release Date\": \"2019-07-26\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.88, \"Energy\": 0.751, \"Loudness\": -4.258, \"Speechiness\": 0.0874, \"Acousticness\": 0.177, \"Liveness\": 0.106, \"Tempo\": 117.948, \"Duration (ms)\": 157606.0, \"Valence\": 0.884, \"Chord\": \"G\"}, {\"Index\": 216, \"Highest Charting Position\": 15, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Lost Cause\", \"Streams\": 5203319, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"36fhyo5QlxBW7DrDHIOn1G\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 0.0, \"Danceability\": 0.671, \"Energy\": 0.336, \"Loudness\": -8.494, \"Speechiness\": 0.241, \"Acousticness\": 0.705, \"Liveness\": 0.0577, \"Tempo\": 75.051, \"Duration (ms)\": 212496.0, \"Valence\": 0.518, \"Chord\": \"A#/Bb\"}, {\"Index\": 217, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Shot in the Dark\", \"Streams\": 5173308, \"Artist\": \"John Mayer\", \"Artist Followers\": 5178156.0, \"Song ID\": \"239yM7BAQ2CkNc61ogPGXo\", \"Genre\": \"['neo mellow', 'pop rock', 'singer-songwriter']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 76.0, \"Danceability\": 0.741, \"Energy\": 0.556, \"Loudness\": -9.184, \"Speechiness\": 0.0266, \"Acousticness\": 0.0629, \"Liveness\": 0.103, \"Tempo\": 122.008, \"Duration (ms)\": 249080.0, \"Valence\": 0.587, \"Chord\": \"D\"}, {\"Index\": 218, \"Highest Charting Position\": 71, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Wrecked\", \"Streams\": 5150909, \"Artist\": \"Imagine Dragons\", \"Artist Followers\": 35285425.0, \"Song ID\": \"2d1MywHy6FwKdzxFuSJnwl\", \"Genre\": \"['modern rock', 'pop', 'rock']\", \"Release Date\": \"2021-07-02\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 83.0, \"Danceability\": 0.626, \"Energy\": 0.56, \"Loudness\": -5.82, \"Speechiness\": 0.0288, \"Acousticness\": 0.148, \"Liveness\": 0.109, \"Tempo\": 93.989, \"Duration (ms)\": 244005.0, \"Valence\": 0.229, \"Chord\": \"C\"}, {\"Index\": 219, \"Highest Charting Position\": 79, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Bipolar\", \"Streams\": 5116589, \"Artist\": \"Mc Davi, Mc Pedrinho, Mc Don Juan\", \"Artist Followers\": 2586114.0, \"Song ID\": \"0qxLQ6opocOGyFnlXqJ53x\", \"Genre\": \"['funk carioca', 'funk ostentacao', 'funk paulista']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 84.0, \"Danceability\": 0.601, \"Energy\": 0.36, \"Loudness\": -7.791, \"Speechiness\": 0.0877, \"Acousticness\": 0.586, \"Liveness\": 0.0882, \"Tempo\": 124.993, \"Duration (ms)\": 276480.0, \"Valence\": 0.335, \"Chord\": \"A\"}, {\"Index\": 220, \"Highest Charting Position\": 122, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"His & Hers (feat. Don Toliver, Lil Uzi Vert & Gunna)\", \"Streams\": 5110475, \"Artist\": \"Internet Money\", \"Artist Followers\": 411579.0, \"Song ID\": \"2IePEfMAtqWS6rLXXFZIgI\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-05-14--2021-05-21\", \"Popularity\": 84.0, \"Danceability\": 0.792, \"Energy\": 0.707, \"Loudness\": -5.218, \"Speechiness\": 0.0623, \"Acousticness\": 0.116, \"Liveness\": 0.12, \"Tempo\": 134.997, \"Duration (ms)\": 224042.0, \"Valence\": 0.408, \"Chord\": \"G\"}, {\"Index\": 221, \"Highest Charting Position\": 75, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Follow You\", \"Streams\": 5097187, \"Artist\": \"Imagine Dragons\", \"Artist Followers\": 35285425.0, \"Song ID\": \"7FdUvDkaE24o3FPIWTvzv2\", \"Genre\": \"['modern rock', 'pop', 'rock']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 84.0, \"Danceability\": 0.542, \"Energy\": 0.732, \"Loudness\": -5.956, \"Speechiness\": 0.0521, \"Acousticness\": 0.00209, \"Liveness\": 0.496, \"Tempo\": 124.912, \"Duration (ms)\": 175644.0, \"Valence\": 0.489, \"Chord\": \"A\"}, {\"Index\": 222, \"Highest Charting Position\": 22, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"We're Good\", \"Streams\": 6318660, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"1diS6nkxMQc3wwC4G1j0bh\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 83.0, \"Danceability\": 0.722, \"Energy\": 0.588, \"Loudness\": -5.932, \"Speechiness\": 0.0544, \"Acousticness\": 0.0319, \"Liveness\": 0.183, \"Tempo\": 134.01, \"Duration (ms)\": 165507.0, \"Valence\": 0.59, \"Chord\": \"F#/Gb\"}, {\"Index\": 223, \"Highest Charting Position\": 4, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Life Goes On\", \"Streams\": 6142975, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"249gnXrbfmV8NG6jTEMSwD\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 84.0, \"Danceability\": 0.566, \"Energy\": 0.716, \"Loudness\": -5.733, \"Speechiness\": 0.0424, \"Acousticness\": 0.00691, \"Liveness\": 0.37, \"Tempo\": 81.068, \"Duration (ms)\": 207481.0, \"Valence\": 0.45, \"Chord\": \"C#/Db\"}, {\"Index\": 224, \"Highest Charting Position\": 28, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"911\", \"Streams\": 6111108, \"Artist\": \"Sech\", \"Artist Followers\": 8758283.0, \"Song ID\": \"27RSJHEA99Y0Vsow7nA37A\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2020-05-29--2020-06-05\", \"Popularity\": 89.0, \"Danceability\": 0.816, \"Energy\": 0.71, \"Loudness\": -3.728, \"Speechiness\": 0.0398, \"Acousticness\": 0.165, \"Liveness\": 0.292, \"Tempo\": 93.02, \"Duration (ms)\": 208631.0, \"Valence\": 0.784, \"Chord\": \"G\"}, {\"Index\": 225, \"Highest Charting Position\": 17, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Baila Conmigo (with Rauw Alejandro)\", \"Streams\": 5588217, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28909504.0, \"Song ID\": \"079Ey5uxL04AKPQgVQwx5h\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 84.0, \"Danceability\": 0.823, \"Energy\": 0.544, \"Loudness\": -7.132, \"Speechiness\": 0.0715, \"Acousticness\": 0.0215, \"Liveness\": 0.0966, \"Tempo\": 149.903, \"Duration (ms)\": 186088.0, \"Valence\": 0.664, \"Chord\": \"F\"}, {\"Index\": 226, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"The Jackie (with J. Cole & Lil Tjay)\", \"Streams\": 5454994, \"Artist\": \"Bas\", \"Artist Followers\": 386757.0, \"Song ID\": \"15qKrPi4Kg0z7g9HlwWyeb\", \"Genre\": \"['hip hop', 'pop rap', 'queens hip hop', 'rap', 'sudanese pop', 'underground hip hop']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-09--2021-07-16\", \"Popularity\": 76.0, \"Danceability\": 0.784, \"Energy\": 0.474, \"Loudness\": -6.139, \"Speechiness\": 0.0524, \"Acousticness\": 0.333, \"Liveness\": 0.278, \"Tempo\": 128.012, \"Duration (ms)\": 204434.0, \"Valence\": 0.64, \"Chord\": \"G#/Ab\"}, {\"Index\": 227, \"Highest Charting Position\": 22, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"hope ur ok\", \"Streams\": 5435614, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"1zejeOnykpCoyVSit6Bwp3\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 84.0, \"Danceability\": 0.443, \"Energy\": 0.298, \"Loudness\": -12.181, \"Speechiness\": 0.0644, \"Acousticness\": 0.388, \"Liveness\": 0.103, \"Tempo\": 77.253, \"Duration (ms)\": 209560.0, \"Valence\": 0.172, \"Chord\": \"C\"}, {\"Index\": 228, \"Highest Charting Position\": 169, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Faz Amor Comigo S\\u00f3 Hoje - Ao Vivo\", \"Streams\": 5269757, \"Artist\": \"Israel & Rodolffo, Wesley Safad\\u00e3o\", \"Artist Followers\": 1097789.0, \"Song ID\": \"7Kba4OaxQFQ1zlknQUpNqN\", \"Genre\": \"['sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2021-05-26\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 82.0, \"Danceability\": 0.624, \"Energy\": 0.922, \"Loudness\": -4.628, \"Speechiness\": 0.0439, \"Acousticness\": 0.3, \"Liveness\": 0.112, \"Tempo\": 164.819, \"Duration (ms)\": 148228.0, \"Valence\": 0.884, \"Chord\": \"C#/Db\"}, {\"Index\": 229, \"Highest Charting Position\": 80, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Alcohol-Free\", \"Streams\": 5259503, \"Artist\": \"TWICE\", \"Artist Followers\": 9987114.0, \"Song ID\": \"0BTaaKT4RMbs5M73tOHX5Y\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 82.0, \"Danceability\": 0.688, \"Energy\": 0.909, \"Loudness\": -1.992, \"Speechiness\": 0.0624, \"Acousticness\": 0.0474, \"Liveness\": 0.0674, \"Tempo\": 97.097, \"Duration (ms)\": 210573.0, \"Valence\": 0.702, \"Chord\": \"G#/Ab\"}, {\"Index\": 230, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"WHOLE LOTTA MONEY (feat. Nicki Minaj) - Remix\", \"Streams\": 5186354, \"Artist\": \"BIA\", \"Artist Followers\": 151870.0, \"Song ID\": \"67G6iaOw8DZqp1z8STR89R\", \"Genre\": \"['escape room', 'r&b', 'rap latina', 'trap queen']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-09--2021-07-16\", \"Popularity\": 80.0, \"Danceability\": 0.893, \"Energy\": 0.463, \"Loudness\": -5.301, \"Speechiness\": 0.36, \"Acousticness\": 0.199, \"Liveness\": 0.318, \"Tempo\": 81.026, \"Duration (ms)\": 229601.0, \"Valence\": 0.591, \"Chord\": \"C#/Db\"}, {\"Index\": 231, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Memory\", \"Streams\": 5173178, \"Artist\": \"Kane Brown, blackbear\", \"Artist Followers\": 3507622.0, \"Song ID\": \"34chhNX59Wo9HMFCsI3K8Y\", \"Genre\": \"['contemporary country', 'country road']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-09--2021-07-16\", \"Popularity\": 80.0, \"Danceability\": 0.434, \"Energy\": 0.889, \"Loudness\": -5.684, \"Speechiness\": 0.0509, \"Acousticness\": 0.395, \"Liveness\": 0.273, \"Tempo\": 113.326, \"Duration (ms)\": 153338.0, \"Valence\": 0.845, \"Chord\": \"A\"}, {\"Index\": 232, \"Highest Charting Position\": 183, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Me Fije\", \"Streams\": 5068677, \"Artist\": \"Alex Rose, Rauw Alejandro\", \"Artist Followers\": 2166191.0, \"Song ID\": \"6Et5KimMg3IXwD6lJPGmQw\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2021-03-18\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-05-07--2021-05-14\", \"Popularity\": 83.0, \"Danceability\": 0.76, \"Energy\": 0.674, \"Loudness\": -4.039, \"Speechiness\": 0.0636, \"Acousticness\": 0.396, \"Liveness\": 0.0977, \"Tempo\": 172.024, \"Duration (ms)\": 202307.0, \"Valence\": 0.735, \"Chord\": \"G\"}, {\"Index\": 233, \"Highest Charting Position\": 71, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Volta Beb\\u00ea, Volta Nen\\u00e9m\", \"Streams\": 5041120, \"Artist\": \"Dj Guuga, DJ Ivis\", \"Artist Followers\": 608109.0, \"Song ID\": \"4wQUopWk9Ed7Ng5qpKN5qd\", \"Genre\": \"['funk carioca', 'funk paulista', 'rave funk']\", \"Release Date\": \"2021-03-27\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 79.0, \"Danceability\": 0.583, \"Energy\": 0.918, \"Loudness\": -3.612, \"Speechiness\": 0.0518, \"Acousticness\": 0.288, \"Liveness\": 0.0701, \"Tempo\": 164.081, \"Duration (ms)\": 172973.0, \"Valence\": 0.836, \"Chord\": \"F#/Gb\"}, {\"Index\": 234, \"Highest Charting Position\": 95, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Aloha\", \"Streams\": 5036030, \"Artist\": \"Maluma, Be\\u00e9le, Rauw Alejandro, Mambo Kingz, DJ Luian, Darell\", \"Artist Followers\": 26769304.0, \"Song ID\": \"5RAIMjdrCEjpjaR5tBATXU\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 84.0, \"Danceability\": 0.807, \"Energy\": 0.712, \"Loudness\": -5.757, \"Speechiness\": 0.1, \"Acousticness\": 0.532, \"Liveness\": 0.163, \"Tempo\": 100.004, \"Duration (ms)\": 241659.0, \"Valence\": 0.792, \"Chord\": \"C#/Db\"}, {\"Index\": 235, \"Highest Charting Position\": 184, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Sexo Virtual\", \"Streams\": 4975786, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6080597.0, \"Song ID\": \"0giiXonRhODYy4J1iy4Lb3\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 82.0, \"Danceability\": 0.704, \"Energy\": 0.739, \"Loudness\": -3.286, \"Speechiness\": 0.112, \"Acousticness\": 0.328, \"Liveness\": 0.0856, \"Tempo\": 179.879, \"Duration (ms)\": 208292.0, \"Valence\": 0.425, \"Chord\": \"G#/Ab\"}, {\"Index\": 236, \"Highest Charting Position\": 141, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Closer\", \"Streams\": 4954679, \"Artist\": \"The Chainsmokers, Halsey\", \"Artist Followers\": 18191658.0, \"Song ID\": \"7BKLCZ1jbUBVqRi2FVlTVw\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2016-07-29\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-01--2021-01-08\\n2020-08-14--2020-08-21\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.748, \"Energy\": 0.524, \"Loudness\": -5.599, \"Speechiness\": 0.0338, \"Acousticness\": 0.414, \"Liveness\": 0.111, \"Tempo\": 95.01, \"Duration (ms)\": 244960.0, \"Valence\": 0.661, \"Chord\": \"G#/Ab\"}, {\"Index\": 237, \"Highest Charting Position\": 194, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Wonderwall - Remastered\", \"Streams\": 4938180, \"Artist\": \"Oasis\", \"Artist Followers\": 6475631.0, \"Song ID\": \"7ygpwy2qP3NbrxVkHvUhXY\", \"Genre\": \"['beatlesque', 'britpop', 'madchester', 'permanent wave', 'rock']\", \"Release Date\": \"1995\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-05-28--2021-06-04\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 78.0, \"Danceability\": 0.375, \"Energy\": 0.893, \"Loudness\": -4.097, \"Speechiness\": 0.0406, \"Acousticness\": 0.000509, \"Liveness\": 0.187, \"Tempo\": 174.323, \"Duration (ms)\": 258773.0, \"Valence\": 0.434, \"Chord\": \"D\"}, {\"Index\": 238, \"Highest Charting Position\": 101, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Wasting Time ( feat. Drake )\", \"Streams\": 6731106, \"Artist\": \"Brent Faiyaz\", \"Artist Followers\": 1724414.0, \"Song ID\": \"48WidxP9CqyYtk97pwGZ3c\", \"Genre\": \"['dmv rap', 'pop', 'r&b', 'rap']\", \"Release Date\": \"2021-07-01\", \"Weeks Charted\": \"2021-07-02--2021-07-09\", \"Popularity\": 78.0, \"Danceability\": 0.652, \"Energy\": 0.717, \"Loudness\": -3.751, \"Speechiness\": 0.0581, \"Acousticness\": 0.0694, \"Liveness\": 0.0906, \"Tempo\": 89.982, \"Duration (ms)\": 301304.0, \"Valence\": 0.377, \"Chord\": \"G\"}, {\"Index\": 239, \"Highest Charting Position\": 55, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"I Don't Do Drugs (feat. Ariana Grande)\", \"Streams\": 5912293, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0FFsgUoFibYISzMxuGS61W\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 80.0, \"Danceability\": 0.683, \"Energy\": 0.615, \"Loudness\": -5.737, \"Speechiness\": 0.0966, \"Acousticness\": 0.222, \"Liveness\": 0.154, \"Tempo\": 77.014, \"Duration (ms)\": 188893.0, \"Valence\": 0.45, \"Chord\": \"F\"}, {\"Index\": 240, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Renegade (feat. Taylor Swift)\", \"Streams\": 5876058, \"Artist\": \"Big Red Machine\", \"Artist Followers\": 98503.0, \"Song ID\": \"1aU1wpYBSpP0M6IiihY5Ue\", \"Genre\": \"['eau claire indie', 'folktronica']\", \"Release Date\": \"2021-07-02\", \"Weeks Charted\": \"2021-07-02--2021-07-09\", \"Popularity\": 77.0, \"Danceability\": 0.532, \"Energy\": 0.708, \"Loudness\": -8.121, \"Speechiness\": 0.0505, \"Acousticness\": 0.435, \"Liveness\": 0.107, \"Tempo\": 167.977, \"Duration (ms)\": 254467.0, \"Valence\": 0.586, \"Chord\": \"C\"}, {\"Index\": 241, \"Highest Charting Position\": 40, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"JUGGERNAUT (feat. Lil Uzi Vert & Pharrell Williams)\", \"Streams\": 5392334, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"7z4xW9WY86uH3gd1V9pfCM\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 80.0, \"Danceability\": 0.827, \"Energy\": 0.571, \"Loudness\": -7.949, \"Speechiness\": 0.366, \"Acousticness\": 0.0195, \"Liveness\": 0.166, \"Tempo\": 142.034, \"Duration (ms)\": 146419.0, \"Valence\": 0.62, \"Chord\": \"B\"}, {\"Index\": 242, \"Highest Charting Position\": 152, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"All Eyes On Me\", \"Streams\": 5347263, \"Artist\": \"Bo Burnham\", \"Artist Followers\": 1042079.0, \"Song ID\": \"3rV5y8rcQrwRt9fWGLmjOQ\", \"Genre\": \"['comic']\", \"Release Date\": \"2021-06-10\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 81.0, \"Danceability\": 0.352, \"Energy\": 0.424, \"Loudness\": -10.131, \"Speechiness\": 0.0394, \"Acousticness\": 0.733, \"Liveness\": 0.0664, \"Tempo\": 127.047, \"Duration (ms)\": 302951.0, \"Valence\": 0.141, \"Chord\": \"F#/Gb\"}, {\"Index\": 243, \"Highest Charting Position\": 101, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"EVERY CHANCE I GET (feat. Lil Baby & Lil Durk)\", \"Streams\": 5321544, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6278835.0, \"Song ID\": \"1EJIcDYXwSqipW5dFe4uJz\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 83.0, \"Danceability\": 0.477, \"Energy\": 0.727, \"Loudness\": -4.053, \"Speechiness\": 0.286, \"Acousticness\": 0.000866, \"Liveness\": 0.108, \"Tempo\": 150.062, \"Duration (ms)\": 236524.0, \"Valence\": 0.227, \"Chord\": \"D\"}, {\"Index\": 244, \"Highest Charting Position\": 72, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Dick (feat. Doja Cat)\", \"Streams\": 5258628, \"Artist\": \"StarBoi3\", \"Artist Followers\": 17202.0, \"Song ID\": \"3nY8AqaMNNHHLYV4380ol0\", \"Genre\": \"[]\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 83.0, \"Danceability\": 0.647, \"Energy\": 0.608, \"Loudness\": -6.831, \"Speechiness\": 0.42, \"Acousticness\": 0.13, \"Liveness\": 0.0584, \"Tempo\": 125.994, \"Duration (ms)\": 175238.0, \"Valence\": 0.474, \"Chord\": \"A\"}, {\"Index\": 245, \"Highest Charting Position\": 25, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Solar Power\", \"Streams\": 5234112, \"Artist\": \"Lorde\", \"Artist Followers\": 8083566.0, \"Song ID\": \"3KdoeNlEN0BoAKWzaRLNZa\", \"Genre\": \"['art pop', 'dance pop', 'electropop', 'metropopolis', 'nz pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-06-10\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 81.0, \"Danceability\": 0.735, \"Energy\": 0.47, \"Loudness\": -9.405, \"Speechiness\": 0.1, \"Acousticness\": 0.266, \"Liveness\": 0.32, \"Tempo\": 87.971, \"Duration (ms)\": 192621.0, \"Valence\": 0.897, \"Chord\": \"E\"}, {\"Index\": 246, \"Highest Charting Position\": 4, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Your Power\", \"Streams\": 5135380, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47014200.0, \"Song ID\": \"042Sl6Mn83JHyLEqdK7uI0\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-07-30\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 81.0, \"Danceability\": 0.632, \"Energy\": 0.284, \"Loudness\": -14.025, \"Speechiness\": 0.0801, \"Acousticness\": 0.932, \"Liveness\": 0.233, \"Tempo\": 129.642, \"Duration (ms)\": 245897.0, \"Valence\": 0.208, \"Chord\": \"A\"}, {\"Index\": 247, \"Highest Charting Position\": 189, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Lieben wir\", \"Streams\": 5029898, \"Artist\": \"Shirin David\", \"Artist Followers\": 558345.0, \"Song ID\": \"49gzU1IS1B6P3GATSZ5eCE\", \"Genre\": \"['frauenrap', 'german hip hop', 'german pop']\", \"Release Date\": \"2021-07-01\", \"Weeks Charted\": \"2021-07-02--2021-07-09\", \"Popularity\": 77.0, \"Danceability\": 0.871, \"Energy\": 0.669, \"Loudness\": -7.62, \"Speechiness\": 0.329, \"Acousticness\": 0.0113, \"Liveness\": 0.0795, \"Tempo\": 95.939, \"Duration (ms)\": 155363.0, \"Valence\": 0.806, \"Chord\": \"A#/Bb\"}, {\"Index\": 248, \"Highest Charting Position\": 8, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Whoopty\", \"Streams\": 5013017, \"Artist\": \"CJ\", \"Artist Followers\": 180454.0, \"Song ID\": \"5vGLcdRuSbUhD8ScwsGSdA\", \"Genre\": \"['nyc rap']\", \"Release Date\": \"2020-08-20\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 81.0, \"Danceability\": 0.719, \"Energy\": 0.648, \"Loudness\": -7.6, \"Speechiness\": 0.125, \"Acousticness\": 0.2, \"Liveness\": 0.127, \"Tempo\": 140.201, \"Duration (ms)\": 123263.0, \"Valence\": 0.66, \"Chord\": \"D#/Eb\"}, {\"Index\": 249, \"Highest Charting Position\": 55, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Batom de Cereja - Ao Vivo\", \"Streams\": 5011753, \"Artist\": \"Israel & Rodolffo\", \"Artist Followers\": 1097789.0, \"Song ID\": \"2MZQAvsA7aZDssppBLRxYp\", \"Genre\": \"['sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2021-01-29\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 83.0, \"Danceability\": 0.606, \"Energy\": 0.908, \"Loudness\": -6.201, \"Speechiness\": 0.0565, \"Acousticness\": 0.556, \"Liveness\": 0.19, \"Tempo\": 171.966, \"Duration (ms)\": 140942.0, \"Valence\": 0.798, \"Chord\": \"F#/Gb\"}, {\"Index\": 250, \"Highest Charting Position\": 11, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Prisoner (feat. Dua Lipa)\", \"Streams\": 5005018, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15770302.0, \"Song ID\": \"5JqZ3oqF00jkT81foAFvqg\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 79.0, \"Danceability\": 0.781, \"Energy\": 0.67, \"Loudness\": -3.912, \"Speechiness\": 0.0452, \"Acousticness\": 0.0103, \"Liveness\": 0.0761, \"Tempo\": 127.99, \"Duration (ms)\": 169333.0, \"Valence\": 0.595, \"Chord\": \"D#/Eb\"}, {\"Index\": 251, \"Highest Charting Position\": 136, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Stereo Hearts (feat. Adam Levine)\", \"Streams\": 4992345, \"Artist\": \"Gym Class Heroes\", \"Artist Followers\": 1275345.0, \"Song ID\": \"0qOnSQQF0yzuPWsXrQ9paz\", \"Genre\": \"['dance pop', 'pop rap']\", \"Release Date\": \"2011-11-11\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 82.0, \"Danceability\": 0.646, \"Energy\": 0.795, \"Loudness\": -3.293, \"Speechiness\": 0.0976, \"Acousticness\": 0.0319, \"Liveness\": 0.267, \"Tempo\": 89.99, \"Duration (ms)\": 210960.0, \"Valence\": 0.796, \"Chord\": \"A\"}, {\"Index\": 252, \"Highest Charting Position\": 32, \"Number of Times Charted\": 36, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Reloj\", \"Streams\": 4980155, \"Artist\": \"Rauw Alejandro, Anuel AA\", \"Artist Followers\": 6080597.0, \"Song ID\": \"7r9ZhitdQBONTFOiJW5mr8\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-10-22\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 79.0, \"Danceability\": 0.823, \"Energy\": 0.537, \"Loudness\": -2.639, \"Speechiness\": 0.209, \"Acousticness\": 0.176, \"Liveness\": 0.123, \"Tempo\": 175.946, \"Duration (ms)\": 231595.0, \"Valence\": 0.615, \"Chord\": \"G#/Ab\"}, {\"Index\": 253, \"Highest Charting Position\": 81, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"malibu\", \"Streams\": 4973063, \"Artist\": \"sangiovanni\", \"Artist Followers\": 384097.0, \"Song ID\": \"01hEpx8jnOG4q7nDK14Rhi\", \"Genre\": \"[]\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.733, \"Energy\": 0.736, \"Loudness\": -5.123, \"Speechiness\": 0.111, \"Acousticness\": 0.028, \"Liveness\": 0.131, \"Tempo\": 147.897, \"Duration (ms)\": 166216.0, \"Valence\": 0.669, \"Chord\": \"G\"}, {\"Index\": 254, \"Highest Charting Position\": 101, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Eladio Carrion: Bzrp Music Sessions, Vol. 40\", \"Streams\": 4965913, \"Artist\": \"Bizarrap, Eladio Carrion\", \"Artist Followers\": 3126961.0, \"Song ID\": \"1VauUM5CBX7nkLcgafQL2B\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2021-06-09\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 81.0, \"Danceability\": 0.783, \"Energy\": 0.524, \"Loudness\": -6.455, \"Speechiness\": 0.0554, \"Acousticness\": 0.241, \"Liveness\": 0.271, \"Tempo\": 117.496, \"Duration (ms)\": 164896.0, \"Valence\": 0.839, \"Chord\": \"F\"}, {\"Index\": 255, \"Highest Charting Position\": 117, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Do I Wanna Know?\", \"Streams\": 4938586, \"Artist\": \"Arctic Monkeys\", \"Artist Followers\": 12369079.0, \"Song ID\": \"5FVd6KXrgO9B3JPmC8OPst\", \"Genre\": \"['garage rock', 'permanent wave', 'rock', 'sheffield indie']\", \"Release Date\": \"2013-09-09\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 84.0, \"Danceability\": 0.548, \"Energy\": 0.532, \"Loudness\": -7.596, \"Speechiness\": 0.0323, \"Acousticness\": 0.186, \"Liveness\": 0.217, \"Tempo\": 85.03, \"Duration (ms)\": 272394.0, \"Valence\": 0.405, \"Chord\": \"F\"}, {\"Index\": 256, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"LUMBERJACK\", \"Streams\": 11756283, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"0BiK5BbYNFLb88CCOxBFJe\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 76.0, \"Danceability\": 0.386, \"Energy\": 0.762, \"Loudness\": -6.341, \"Speechiness\": 0.564, \"Acousticness\": 0.122, \"Liveness\": 0.527, \"Tempo\": 170.691, \"Duration (ms)\": 138312.0, \"Valence\": 0.433, \"Chord\": \"A\"}, {\"Index\": 257, \"Highest Charting Position\": 47, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"LEMONHEAD (feat. 42 Dugg)\", \"Streams\": 11380679, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"5fbHRCsGpFIOLRtlhCRFDR\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 78.0, \"Danceability\": 0.62, \"Energy\": 0.586, \"Loudness\": -6.612, \"Speechiness\": 0.212, \"Acousticness\": 0.155, \"Liveness\": 0.535, \"Tempo\": 137.131, \"Duration (ms)\": 130980.0, \"Valence\": 0.487, \"Chord\": \"C#/Db\"}, {\"Index\": 258, \"Highest Charting Position\": 59, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"HOT WIND BLOWS (feat. Lil Wayne)\", \"Streams\": 9889197, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"3JJL91ilRV6fXhKqu0FGXs\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 77.0, \"Danceability\": 0.371, \"Energy\": 0.75, \"Loudness\": -5.382, \"Speechiness\": 0.402, \"Acousticness\": 0.601, \"Liveness\": 0.482, \"Tempo\": 173.456, \"Duration (ms)\": 155293.0, \"Valence\": 0.729, \"Chord\": \"G\"}, {\"Index\": 259, \"Highest Charting Position\": 63, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"CORSO\", \"Streams\": 9503981, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"46oHvXwpEZOFX518we1nJD\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 77.0, \"Danceability\": 0.703, \"Energy\": 0.845, \"Loudness\": -4.851, \"Speechiness\": 0.337, \"Acousticness\": 0.169, \"Liveness\": 0.122, \"Tempo\": 97.672, \"Duration (ms)\": 146482.0, \"Valence\": 0.745, \"Chord\": \"A#/Bb\"}, {\"Index\": 260, \"Highest Charting Position\": 69, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"SWEET / I THOUGHT YOU WANTED TO DANCE (feat. Brent Faiyaz & Fana Hues)\", \"Streams\": 9142721, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"3EG9FJ0ToLfgnc1IG2Z1wz\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 79.0, \"Danceability\": 0.468, \"Energy\": 0.652, \"Loudness\": -4.912, \"Speechiness\": 0.0722, \"Acousticness\": 0.333, \"Liveness\": 0.55, \"Tempo\": 140.223, \"Duration (ms)\": 588139.0, \"Valence\": 0.39, \"Chord\": \"C\"}, {\"Index\": 261, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"SIR BAUDELAIRE (feat. DJ Drama)\", \"Streams\": 8884283, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"4ydmav4vl7hebadtfZtMrg\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 75.0, \"Danceability\": 0.467, \"Energy\": 0.635, \"Loudness\": -6.115, \"Speechiness\": 0.154, \"Acousticness\": 0.314, \"Liveness\": 0.844, \"Tempo\": 127.596, \"Duration (ms)\": 88625.0, \"Valence\": 0.51, \"Chord\": \"G\"}, {\"Index\": 262, \"Highest Charting Position\": 82, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"MASSA\", \"Streams\": 8218423, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"2goHCrsDJaflEwQ930ef0o\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 74.0, \"Danceability\": 0.685, \"Energy\": 0.855, \"Loudness\": -6.724, \"Speechiness\": 0.438, \"Acousticness\": 0.329, \"Liveness\": 0.301, \"Tempo\": 157.181, \"Duration (ms)\": 223719.0, \"Valence\": 0.46, \"Chord\": \"C#/Db\"}, {\"Index\": 263, \"Highest Charting Position\": 85, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"RUNITUP (feat. Teezo Touchdown)\", \"Streams\": 7917707, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"13HsOwrwTA5HgLuoaDHncP\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 75.0, \"Danceability\": 0.665, \"Energy\": 0.469, \"Loudness\": -7.778, \"Speechiness\": 0.13, \"Acousticness\": 0.565, \"Liveness\": 0.219, \"Tempo\": 115.852, \"Duration (ms)\": 229565.0, \"Valence\": 0.142, \"Chord\": \"A#/Bb\"}, {\"Index\": 264, \"Highest Charting Position\": 108, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"MANIFESTO (feat. Domo Genesis)\", \"Streams\": 6988886, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"6qouBO0wJtYc3k7DfKRUBx\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.454, \"Energy\": 0.866, \"Loudness\": -5.348, \"Speechiness\": 0.391, \"Acousticness\": 0.121, \"Liveness\": 0.167, \"Tempo\": 92.463, \"Duration (ms)\": 175123.0, \"Valence\": 0.518, \"Chord\": \"D\"}, {\"Index\": 265, \"Highest Charting Position\": 121, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Get Into It (Yuh)\", \"Streams\": 6503281, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0W6I02J9xcqK8MtSeosEXb\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 80.0, \"Danceability\": 0.912, \"Energy\": 0.655, \"Loudness\": -6.029, \"Speechiness\": 0.162, \"Acousticness\": 0.315, \"Liveness\": 0.0894, \"Tempo\": 91.942, \"Duration (ms)\": 138293.0, \"Valence\": 0.793, \"Chord\": \"G#/Ab\"}, {\"Index\": 266, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"WILSHIRE\", \"Streams\": 6268542, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"1pbbsI2KGPOMu0HmuGccBu\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.555, \"Energy\": 0.712, \"Loudness\": -7.446, \"Speechiness\": 0.323, \"Acousticness\": 0.0451, \"Liveness\": 0.182, \"Tempo\": 78.958, \"Duration (ms)\": 515865.0, \"Valence\": 0.555, \"Chord\": \"C#/Db\"}, {\"Index\": 267, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"RISE! (feat. DAISY WORLD)\", \"Streams\": 6034281, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"4Hta7Oy5W9HD0UgT1P8PPV\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.766, \"Energy\": 0.814, \"Loudness\": -3.367, \"Speechiness\": 0.0733, \"Acousticness\": 0.044, \"Liveness\": 0.195, \"Tempo\": 108.07, \"Duration (ms)\": 203588.0, \"Valence\": 0.481, \"Chord\": \"D\"}, {\"Index\": 268, \"Highest Charting Position\": 165, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Naked\", \"Streams\": 5527865, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0CsR9Y9SnC6ZWmekmVqSHz\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 75.0, \"Danceability\": 0.733, \"Energy\": 0.862, \"Loudness\": -5.736, \"Speechiness\": 0.197, \"Acousticness\": 0.374, \"Liveness\": 0.131, \"Tempo\": 111.076, \"Duration (ms)\": 223560.0, \"Valence\": 0.536, \"Chord\": \"G\"}, {\"Index\": 269, \"Highest Charting Position\": 50, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Having Our Way (feat. Drake)\", \"Streams\": 5424579, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"2NM0qHzx4Ohy8iXHEEgwlO\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 79.0, \"Danceability\": 0.927, \"Energy\": 0.538, \"Loudness\": -3.917, \"Speechiness\": 0.116, \"Acousticness\": 0.0312, \"Liveness\": 0.0945, \"Tempo\": 125.983, \"Duration (ms)\": 278191.0, \"Valence\": 0.221, \"Chord\": \"C#/Db\"}, {\"Index\": 270, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Payday (feat. Young Thug)\", \"Streams\": 5393789, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"2HolBGR6tpiWI80MXoV1dJ\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.619, \"Energy\": 0.707, \"Loudness\": -5.791, \"Speechiness\": 0.0499, \"Acousticness\": 0.0366, \"Liveness\": 0.13, \"Tempo\": 168.995, \"Duration (ms)\": 212947.0, \"Valence\": 0.558, \"Chord\": \"C#/Db\"}, {\"Index\": 271, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Been Like This\", \"Streams\": 5362817, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"7y3xU9vEC1s8DSuuoSYKih\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 74.0, \"Danceability\": 0.678, \"Energy\": 0.531, \"Loudness\": -5.029, \"Speechiness\": 0.0374, \"Acousticness\": 0.126, \"Liveness\": 0.377, \"Tempo\": 99.008, \"Duration (ms)\": 177373.0, \"Valence\": 0.176, \"Chord\": \"A#/Bb\"}, {\"Index\": 272, \"Highest Charting Position\": 138, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"MILLE (feat. Orietta Berti)\", \"Streams\": 5341887, \"Artist\": \"Fedez, Achille Lauro\", \"Artist Followers\": 1650683.0, \"Song ID\": \"6qdMhG7pRFi0csRlFGvLE4\", \"Genre\": \"['italian adult pop', 'italian pop']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 82.0, \"Danceability\": 0.527, \"Energy\": 0.764, \"Loudness\": -4.297, \"Speechiness\": 0.322, \"Acousticness\": 0.016, \"Liveness\": 0.0273, \"Tempo\": 184.339, \"Duration (ms)\": 175924.0, \"Valence\": 0.829, \"Chord\": \"D\"}, {\"Index\": 273, \"Highest Charting Position\": 10, \"Number of Times Charted\": 49, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"UN DIA (ONE DAY) (Feat. Tainy)\", \"Streams\": 5203364, \"Artist\": \"J Balvin, Dua Lipa, Bad Bunny\", \"Artist Followers\": 29051363.0, \"Song ID\": \"0EhpEsp4L0oRGM0vmeaN5e\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 83.0, \"Danceability\": 0.571, \"Energy\": 0.693, \"Loudness\": -8.234, \"Speechiness\": 0.0545, \"Acousticness\": 0.00536, \"Liveness\": 0.173, \"Tempo\": 168.169, \"Duration (ms)\": 232253.0, \"Valence\": 0.393, \"Chord\": \"F#/Gb\"}, {\"Index\": 274, \"Highest Charting Position\": 1, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Savage Love (Laxed - Siren Beat)\", \"Streams\": 5108950, \"Artist\": \"Jawsh 685, Jason Derulo\", \"Artist Followers\": 100604.0, \"Song ID\": \"1xQ6trAsedVPCdbtDAmk0c\", \"Genre\": \"['nz pop']\", \"Release Date\": \"2020-06-11\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 82.0, \"Danceability\": 0.767, \"Energy\": 0.481, \"Loudness\": -8.52, \"Speechiness\": 0.0803, \"Acousticness\": 0.234, \"Liveness\": 0.269, \"Tempo\": 150.076, \"Duration (ms)\": 171375.0, \"Valence\": 0.761, \"Chord\": \"C\"}, {\"Index\": 275, \"Highest Charting Position\": 59, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Poblado\", \"Streams\": 6893939, \"Artist\": \"Crissin, Totoy El Frio, Natan & Shander\", \"Artist Followers\": 29051363.0, \"Song ID\": \"1WedZeiezCmCEOzLwhx0hV\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 89.0, \"Danceability\": 0.813, \"Energy\": 0.809, \"Loudness\": -5.382, \"Speechiness\": 0.0846, \"Acousticness\": 0.102, \"Liveness\": 0.377, \"Tempo\": 93.005, \"Duration (ms)\": 393280.0, \"Valence\": 0.646, \"Chord\": \"D#/Eb\"}, {\"Index\": 276, \"Highest Charting Position\": 17, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Hecha Pa' Mi\", \"Streams\": 6308369, \"Artist\": \"Boza\", \"Artist Followers\": 278679.0, \"Song ID\": \"3VvA1wSxukMLsvXoXtlwWx\", \"Genre\": \"['reggaeton']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 83.0, \"Danceability\": 0.725, \"Energy\": 0.756, \"Loudness\": -5.013, \"Speechiness\": 0.0572, \"Acousticness\": 0.362, \"Liveness\": 0.103, \"Tempo\": 100.07, \"Duration (ms)\": 186133.0, \"Valence\": 0.828, \"Chord\": \"E\"}, {\"Index\": 277, \"Highest Charting Position\": 146, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"working\", \"Streams\": 5666770, \"Artist\": \"Tate McRae, Khalid\", \"Artist Followers\": 1647262.0, \"Song ID\": \"31sSFHIe4NaxltVFOEIcTa\", \"Genre\": \"['alt z', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-06-17\", \"Weeks Charted\": \"2021-06-18--2021-06-25\", \"Popularity\": 80.0, \"Danceability\": 0.783, \"Energy\": 0.435, \"Loudness\": -7.78, \"Speechiness\": 0.0588, \"Acousticness\": 0.282, \"Liveness\": 0.0833, \"Tempo\": 106.974, \"Duration (ms)\": 210220.0, \"Valence\": 0.512, \"Chord\": \"G\"}, {\"Index\": 278, \"Highest Charting Position\": 112, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Petrouchka (feat. PLK)\", \"Streams\": 5511544, \"Artist\": \"Soso Maness\", \"Artist Followers\": 289437.0, \"Song ID\": \"03y045SZqaC94yfXl1cU4E\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais', 'rap marseille']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 79.0, \"Danceability\": 0.624, \"Energy\": 0.802, \"Loudness\": -4.818, \"Speechiness\": 0.311, \"Acousticness\": 0.0597, \"Liveness\": 0.252, \"Tempo\": 133.888, \"Duration (ms)\": 189933.0, \"Valence\": 0.818, \"Chord\": \"F#/Gb\"}, {\"Index\": 279, \"Highest Charting Position\": 11, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"p r i d e . i s . t h e . d e v i l (with Lil Baby)\", \"Streams\": 5430260, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5W8jRrZ6tWrTrqnKRtIQBf\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.861, \"Energy\": 0.656, \"Loudness\": -7.867, \"Speechiness\": 0.425, \"Acousticness\": 0.104, \"Liveness\": 0.0986, \"Tempo\": 88.967, \"Duration (ms)\": 218210.0, \"Valence\": 0.331, \"Chord\": \"E\"}, {\"Index\": 280, \"Highest Charting Position\": 6, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"m y . l i f e (with 21 Savage & Morray)\", \"Streams\": 5246577, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"1D3z6HTiQsNmZxjl7F7eoG\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.597, \"Energy\": 0.587, \"Loudness\": -7.026, \"Speechiness\": 0.137, \"Acousticness\": 0.0622, \"Liveness\": 0.214, \"Tempo\": 140.021, \"Duration (ms)\": 218802.0, \"Valence\": 0.0753, \"Chord\": \"G\"}, {\"Index\": 281, \"Highest Charting Position\": 96, \"Number of Times Charted\": 77, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Jocelyn Flores\", \"Streams\": 5220422, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29539807.0, \"Song ID\": \"7m9OqQk4RVRkw9JJdeAw96\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2017-08-25\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.872, \"Energy\": 0.391, \"Loudness\": -9.144, \"Speechiness\": 0.242, \"Acousticness\": 0.469, \"Liveness\": 0.297, \"Tempo\": 134.021, \"Duration (ms)\": 119133.0, \"Valence\": 0.437, \"Chord\": \"C\"}, {\"Index\": 282, \"Highest Charting Position\": 66, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"No Return (with The Kid LAROI & Lil Durk)\", \"Streams\": 5189427, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"23OYT3SFtoJqhiAUqktbc1\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 80.0, \"Danceability\": 0.479, \"Energy\": 0.645, \"Loudness\": -7.336, \"Speechiness\": 0.302, \"Acousticness\": 0.135, \"Liveness\": 0.0825, \"Tempo\": 155.057, \"Duration (ms)\": 168729.0, \"Valence\": 0.381, \"Chord\": \"F\"}, {\"Index\": 283, \"Highest Charting Position\": 1, \"Number of Times Charted\": 78, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"The Box\", \"Streams\": 5145099, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6603627.0, \"Song ID\": \"0nbXyq5TXYPCO7pr3N8S4I\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.896, \"Energy\": 0.586, \"Loudness\": -6.687, \"Speechiness\": 0.0559, \"Acousticness\": 0.104, \"Liveness\": 0.79, \"Tempo\": 116.971, \"Duration (ms)\": 196653.0, \"Valence\": 0.642, \"Chord\": \"A#/Bb\"}, {\"Index\": 284, \"Highest Charting Position\": 31, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Wellerman - Sea Shanty / 220 KID x Billen Ted Remix\", \"Streams\": 5124606, \"Artist\": \"Nathan Evans\", \"Artist Followers\": 140812.0, \"Song ID\": \"3iw6V4LH7yPj1ESORX9RIN\", \"Genre\": \"[]\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 83.0, \"Danceability\": 0.722, \"Energy\": 0.893, \"Loudness\": -3.255, \"Speechiness\": 0.0475, \"Acousticness\": 0.0441, \"Liveness\": 0.0673, \"Tempo\": 119.932, \"Duration (ms)\": 116750.0, \"Valence\": 0.439, \"Chord\": \"C\"}, {\"Index\": 285, \"Highest Charting Position\": 170, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Can't Hold Us - feat. Ray Dalton\", \"Streams\": 5085147, \"Artist\": \"Macklemore & Ryan Lewis\", \"Artist Followers\": 2562082.0, \"Song ID\": \"3bidbhpOYeV4knp8AIu8Xn\", \"Genre\": \"['modern rock', 'pop rap', 'seattle hip hop']\", \"Release Date\": \"2012-10-09\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.641, \"Energy\": 0.922, \"Loudness\": -4.457, \"Speechiness\": 0.0786, \"Acousticness\": 0.0291, \"Liveness\": 0.0862, \"Tempo\": 146.078, \"Duration (ms)\": 258343.0, \"Valence\": 0.847, \"Chord\": \"D\"}, {\"Index\": 286, \"Highest Charting Position\": 6, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Anyone\", \"Streams\": 5079587, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 1250353.0, \"Song ID\": \"2RwMwWo43LapkA4raptxaB\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-01-31--2020-02-07\", \"Popularity\": 0.0, \"Danceability\": 0.686, \"Energy\": 0.538, \"Loudness\": -8.026, \"Speechiness\": 0.0345, \"Acousticness\": 0.181, \"Liveness\": 0.113, \"Tempo\": 115.884, \"Duration (ms)\": 190779.0, \"Valence\": 0.584, \"Chord\": \"D\"}, {\"Index\": 287, \"Highest Charting Position\": 39, \"Number of Times Charted\": 45, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"my ex's best friend (with blackbear)\", \"Streams\": 5048079, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3864419.0, \"Song ID\": \"7kDUspsoYfLkWnZR7qwHZl\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 83.0, \"Danceability\": 0.731, \"Energy\": 0.675, \"Loudness\": -5.134, \"Speechiness\": 0.0434, \"Acousticness\": 0.00473, \"Liveness\": 0.141, \"Tempo\": 124.939, \"Duration (ms)\": 139461.0, \"Valence\": 0.298, \"Chord\": \"F\"}, {\"Index\": 288, \"Highest Charting Position\": 133, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Just the Way You Are\", \"Streams\": 5043647, \"Artist\": \"Bruno Mars\", \"Artist Followers\": 32574754.0, \"Song ID\": \"7BqBn9nzAq8spo5e7cZ0dJ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2010-10-05\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 80.0, \"Danceability\": 0.637, \"Energy\": 0.843, \"Loudness\": -5.413, \"Speechiness\": 0.0432, \"Acousticness\": 0.0151, \"Liveness\": 0.0876, \"Tempo\": 109.012, \"Duration (ms)\": 220733.0, \"Valence\": 0.434, \"Chord\": \"F\"}, {\"Index\": 289, \"Highest Charting Position\": 17, \"Number of Times Charted\": 78, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"HIGHEST IN THE ROOM\", \"Streams\": 4975720, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17719446.0, \"Song ID\": \"3eekarcy7kvN4yt5ZFzltW\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.598, \"Energy\": 0.427, \"Loudness\": -8.764, \"Speechiness\": 0.0317, \"Acousticness\": 0.0546, \"Liveness\": 0.21, \"Tempo\": 76.469, \"Duration (ms)\": 175721.0, \"Valence\": 0.0605, \"Chord\": \"G\"}, {\"Index\": 290, \"Highest Charting Position\": 7, \"Number of Times Charted\": 65, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Break My Heart\", \"Streams\": 4971176, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"017PF4Q3l4DBUiWoXk4OWT\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 80.0, \"Danceability\": 0.73, \"Energy\": 0.729, \"Loudness\": -3.434, \"Speechiness\": 0.0884, \"Acousticness\": 0.167, \"Liveness\": 0.349, \"Tempo\": 113.011, \"Duration (ms)\": 221820.0, \"Valence\": 0.467, \"Chord\": \"E\"}, {\"Index\": 291, \"Highest Charting Position\": 2, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Laugh Now Cry Later (feat. Lil Durk)\", \"Streams\": 4916860, \"Artist\": \"Drake\", \"Artist Followers\": 56308172.0, \"Song ID\": \"2SAqBLGA283SUiwJ3xOUVI\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 83.0, \"Danceability\": 0.761, \"Energy\": 0.518, \"Loudness\": -8.871, \"Speechiness\": 0.134, \"Acousticness\": 0.244, \"Liveness\": 0.107, \"Tempo\": 133.976, \"Duration (ms)\": 261493.0, \"Valence\": 0.522, \"Chord\": \"C\"}, {\"Index\": 292, \"Highest Charting Position\": 175, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"We Are The People (feat. Bono & The Edge) - Official UEFA EURO 2020 Song\", \"Streams\": 4912036, \"Artist\": \"Martin Garrix\", \"Artist Followers\": 14917926.0, \"Song ID\": \"2iL0W5qi0ivZ9WRXbZ74cS\", \"Genre\": \"['dance pop', 'dutch edm', 'edm', 'pop', 'pop dance', 'progressive house', 'tropical house']\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.66, \"Energy\": 0.733, \"Loudness\": -4.619, \"Speechiness\": 0.0359, \"Acousticness\": 0.248, \"Liveness\": 0.17, \"Tempo\": 119.933, \"Duration (ms)\": 217000.0, \"Valence\": 0.304, \"Chord\": \"C\"}, {\"Index\": 293, \"Highest Charting Position\": 23, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Ella No Es Tuya - Remix\", \"Streams\": 4911162, \"Artist\": \"Rochy RD, Myke Towers, Nicki Nicole\", \"Artist Followers\": 319192.0, \"Song ID\": \"5YYW3yRktprLRr47WK219Y\", \"Genre\": \"['dembow', 'dominican pop', 'rap dominicano', 'trap latino']\", \"Release Date\": \"2021-02-03\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 82.0, \"Danceability\": 0.585, \"Energy\": 0.611, \"Loudness\": -4.132, \"Speechiness\": 0.288, \"Acousticness\": 0.39, \"Liveness\": 0.649, \"Tempo\": 97.041, \"Duration (ms)\": 218107.0, \"Valence\": 0.962, \"Chord\": \"F#/Gb\"}, {\"Index\": 294, \"Highest Charting Position\": 176, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"In the End\", \"Streams\": 4910070, \"Artist\": \"Linkin Park\", \"Artist Followers\": 19584111.0, \"Song ID\": \"60a0Rd6pjrkxjPbaKzXjfq\", \"Genre\": \"['alternative metal', 'nu metal', 'post-grunge', 'rap metal']\", \"Release Date\": \"2000-10-24\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-03-19--2021-03-26\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 83.0, \"Danceability\": 0.556, \"Energy\": 0.864, \"Loudness\": -5.87, \"Speechiness\": 0.0584, \"Acousticness\": 0.00958, \"Liveness\": 0.209, \"Tempo\": 105.143, \"Duration (ms)\": 216880.0, \"Valence\": 0.4, \"Chord\": \"D#/Eb\"}, {\"Index\": 295, \"Highest Charting Position\": 119, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"No Role Modelz\", \"Streams\": 4904401, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"62vpWI1CHwFy7tMIcSStl8\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2014-12-09\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 84.0, \"Danceability\": 0.692, \"Energy\": 0.521, \"Loudness\": -8.465, \"Speechiness\": 0.33, \"Acousticness\": 0.301, \"Liveness\": 0.0565, \"Tempo\": 100.45, \"Duration (ms)\": 292987.0, \"Valence\": 0.463, \"Chord\": \"A#/Bb\"}, {\"Index\": 296, \"Highest Charting Position\": 7, \"Number of Times Charted\": 74, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"SICKO MODE\", \"Streams\": 4898977, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17719446.0, \"Song ID\": \"2xLMifQCjDGFmkHkpNLD9h\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2018-08-03\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.834, \"Energy\": 0.73, \"Loudness\": -3.714, \"Speechiness\": 0.222, \"Acousticness\": 0.00513, \"Liveness\": 0.124, \"Tempo\": 155.008, \"Duration (ms)\": 312820.0, \"Valence\": 0.446, \"Chord\": \"G#/Ab\"}, {\"Index\": 297, \"Highest Charting Position\": 161, \"Number of Times Charted\": 41, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Something Just Like This\", \"Streams\": 4862683, \"Artist\": \"The Chainsmokers, Coldplay\", \"Artist Followers\": 18191658.0, \"Song ID\": \"6RUKPb4LETWmmr3iAEQktW\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2017-04-07\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-02-26--2021-03-05\\n2021-01-01--2021-01-08\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.617, \"Energy\": 0.635, \"Loudness\": -6.769, \"Speechiness\": 0.0317, \"Acousticness\": 0.0498, \"Liveness\": 0.164, \"Tempo\": 103.019, \"Duration (ms)\": 247160.0, \"Valence\": 0.446, \"Chord\": \"B\"}, {\"Index\": 298, \"Highest Charting Position\": 84, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"You\", \"Streams\": 4846549, \"Artist\": \"Regard, Troye Sivan, Tate McRae\", \"Artist Followers\": 152226.0, \"Song ID\": \"2cc8Sw1OnCuA5bV8nqWqpE\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop edm', 'slap house', 'tropical house']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 83.0, \"Danceability\": 0.691, \"Energy\": 0.695, \"Loudness\": -5.6, \"Speechiness\": 0.0367, \"Acousticness\": 0.0592, \"Liveness\": 0.0647, \"Tempo\": 106.064, \"Duration (ms)\": 233386.0, \"Valence\": 0.514, \"Chord\": \"C\"}, {\"Index\": 299, \"Highest Charting Position\": 84, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Straightenin\", \"Streams\": 7615531, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"3X2r2CnHOJeV5YekPTgBnK\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 77.0, \"Danceability\": 0.847, \"Energy\": 0.629, \"Loudness\": -5.81, \"Speechiness\": 0.102, \"Acousticness\": 0.0318, \"Liveness\": 0.152, \"Tempo\": 135.976, \"Duration (ms)\": 255532.0, \"Valence\": 0.109, \"Chord\": \"A\"}, {\"Index\": 300, \"Highest Charting Position\": 71, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"GANG GANG (with Lil Wayne)\", \"Streams\": 7506580, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"4VW44pawoOHPUjlN7DX5vk\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 78.0, \"Danceability\": 0.752, \"Energy\": 0.563, \"Loudness\": -8.066, \"Speechiness\": 0.209, \"Acousticness\": 0.146, \"Liveness\": 0.103, \"Tempo\": 145.05, \"Duration (ms)\": 178776.0, \"Valence\": 0.551, \"Chord\": \"D#/Eb\"}, {\"Index\": 301, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Black Hearted\", \"Streams\": 6989528, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"25qk9xa71F1POdI4vj7rbi\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 75.0, \"Danceability\": 0.506, \"Energy\": 0.563, \"Loudness\": -7.664, \"Speechiness\": 0.411, \"Acousticness\": 0.0326, \"Liveness\": 0.0856, \"Tempo\": 168.146, \"Duration (ms)\": 190509.0, \"Valence\": 0.153, \"Chord\": \"C#/Db\"}, {\"Index\": 302, \"Highest Charting Position\": 124, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Lost\", \"Streams\": 6410263, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32262679.0, \"Song ID\": \"18XlJEroUwFo0tLZxscgXE\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 79.0, \"Danceability\": 0.766, \"Energy\": 0.706, \"Loudness\": -6.553, \"Speechiness\": 0.16, \"Acousticness\": 0.223, \"Liveness\": 0.064, \"Tempo\": 142.989, \"Duration (ms)\": 172598.0, \"Valence\": 0.766, \"Chord\": \"G\"}, {\"Index\": 303, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Avalanche\", \"Streams\": 6323268, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"4KD0lLJ4OGonZhBeKtct9I\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 71.0, \"Danceability\": 0.917, \"Energy\": 0.623, \"Loudness\": -8.231, \"Speechiness\": 0.135, \"Acousticness\": 0.0985, \"Liveness\": 0.0833, \"Tempo\": 126.063, \"Duration (ms)\": 206272.0, \"Valence\": 0.687, \"Chord\": \"C#/Db\"}, {\"Index\": 304, \"Highest Charting Position\": 59, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"My Head & My Heart\", \"Streams\": 5470147, \"Artist\": \"Ava Max\", \"Artist Followers\": 3911473.0, \"Song ID\": \"1KixkQVDUHggZMU9dUobgm\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 83.0, \"Danceability\": 0.614, \"Energy\": 0.934, \"Loudness\": -3.709, \"Speechiness\": 0.07, \"Acousticness\": 0.0697, \"Liveness\": 0.121, \"Tempo\": 116.001, \"Duration (ms)\": 174760.0, \"Valence\": 0.436, \"Chord\": \"A\"}, {\"Index\": 305, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Malibu (feat. Polo G)\", \"Streams\": 5456648, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"3v1zVVdzNVNt7vmI9VG2gq\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 72.0, \"Danceability\": 0.831, \"Energy\": 0.719, \"Loudness\": -6.836, \"Speechiness\": 0.235, \"Acousticness\": 0.514, \"Liveness\": 0.0675, \"Tempo\": 155.038, \"Duration (ms)\": 248652.0, \"Valence\": 0.859, \"Chord\": \"A#/Bb\"}, {\"Index\": 306, \"Highest Charting Position\": 36, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"GIRL LIKE ME\", \"Streams\": 5395181, \"Artist\": \"Black Eyed Peas, Shakira\", \"Artist Followers\": 5963840.0, \"Song ID\": \"1zLBsSVxETQOfINOLYvT5m\", \"Genre\": \"['dance pop', 'pop', 'pop rap']\", \"Release Date\": \"2020-11-02\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\", \"Popularity\": 82.0, \"Danceability\": 0.965, \"Energy\": 0.485, \"Loudness\": -8.784, \"Speechiness\": 0.191, \"Acousticness\": 0.0206, \"Liveness\": 0.0655, \"Tempo\": 124.025, \"Duration (ms)\": 222523.0, \"Valence\": 0.312, \"Chord\": \"D\"}, {\"Index\": 307, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Clueless (with Pop Smoke & Fivio Foreign)\", \"Streams\": 5335308, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"4CPcZHzSvIBM8AKhdHUwnL\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 74.0, \"Danceability\": 0.734, \"Energy\": 0.712, \"Loudness\": -6.217, \"Speechiness\": 0.201, \"Acousticness\": 0.391, \"Liveness\": 0.103, \"Tempo\": 140.369, \"Duration (ms)\": 165405.0, \"Valence\": 0.674, \"Chord\": \"F#/Gb\"}, {\"Index\": 308, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Modern Day\", \"Streams\": 5322745, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"2Igem6Q4sfvXGJ3JkG7Baw\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 78.0, \"Danceability\": 0.87, \"Energy\": 0.629, \"Loudness\": -7.598, \"Speechiness\": 0.279, \"Acousticness\": 0.173, \"Liveness\": 0.101, \"Tempo\": 134.944, \"Duration (ms)\": 241790.0, \"Valence\": 0.512, \"Chord\": \"B\"}, {\"Index\": 309, \"Highest Charting Position\": 2, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Therefore I Am\", \"Streams\": 5265630, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"0aACcc1jEv2C6VSmmJbllJ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 0.0, \"Danceability\": 0.889, \"Energy\": 0.34, \"Loudness\": -7.773, \"Speechiness\": 0.0697, \"Acousticness\": 0.218, \"Liveness\": 0.055, \"Tempo\": 94.009, \"Duration (ms)\": 174321.0, \"Valence\": 0.716, \"Chord\": \"B\"}, {\"Index\": 310, \"Highest Charting Position\": 12, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"TE MUDASTE\", \"Streams\": 5242347, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36142273.0, \"Song ID\": \"5RubKOuDoPn5Kj5TLVxSxY\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 82.0, \"Danceability\": 0.811, \"Energy\": 0.637, \"Loudness\": -4.835, \"Speechiness\": 0.0591, \"Acousticness\": 0.234, \"Liveness\": 0.118, \"Tempo\": 92.025, \"Duration (ms)\": 130014.0, \"Valence\": 0.471, \"Chord\": \"A#/Bb\"}, {\"Index\": 311, \"Highest Charting Position\": 108, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Tipo Gin - Ao Vivo\", \"Streams\": 5155238, \"Artist\": \"MC Kevin o Chris\", \"Artist Followers\": 2753929.0, \"Song ID\": \"4llr8mcoauwrHBtjGb7F9S\", \"Genre\": \"['funk 150 bpm', 'funk carioca']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 81.0, \"Danceability\": 0.75, \"Energy\": 0.668, \"Loudness\": -4.49, \"Speechiness\": 0.061, \"Acousticness\": 0.78, \"Liveness\": 0.338, \"Tempo\": 94.998, \"Duration (ms)\": 159147.0, \"Valence\": 0.786, \"Chord\": \"C\"}, {\"Index\": 312, \"Highest Charting Position\": 39, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Higher Power\", \"Streams\": 5142982, \"Artist\": \"Coldplay\", \"Artist Followers\": 1250353.0, \"Song ID\": \"4rOEoKL0fHrxBMhVljpbGW\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 0.0, \"Danceability\": 0.507, \"Energy\": 0.828, \"Loudness\": -6.023, \"Speechiness\": 0.0449, \"Acousticness\": 0.00711, \"Liveness\": 0.261, \"Tempo\": 178.032, \"Duration (ms)\": 211295.0, \"Valence\": 0.489, \"Chord\": \"A#/Bb\"}, {\"Index\": 313, \"Highest Charting Position\": 54, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"SUN GOES DOWN\", \"Streams\": 5125477, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5473565.0, \"Song ID\": \"34eF4BoV8FPk0uhAAoqU7h\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 80.0, \"Danceability\": 0.551, \"Energy\": 0.636, \"Loudness\": -6.798, \"Speechiness\": 0.054, \"Acousticness\": 0.0837, \"Liveness\": 0.112, \"Tempo\": 174.065, \"Duration (ms)\": 168276.0, \"Valence\": 0.148, \"Chord\": \"D\"}, {\"Index\": 314, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Painting Pictures\", \"Streams\": 5119845, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"25uBGaikHi0DhMiGMfuXYE\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 72.0, \"Danceability\": 0.522, \"Energy\": 0.466, \"Loudness\": -8.05, \"Speechiness\": 0.458, \"Acousticness\": 0.331, \"Liveness\": 0.11, \"Tempo\": 78.43, \"Duration (ms)\": 137692.0, \"Valence\": 0.459, \"Chord\": \"D#/Eb\"}, {\"Index\": 315, \"Highest Charting Position\": 1, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Rain On Me (with Ariana Grande)\", \"Streams\": 5041656, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18572085.0, \"Song ID\": \"24ySl2hOPGCDcxBxFIqWBu\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 79.0, \"Danceability\": 0.672, \"Energy\": 0.855, \"Loudness\": -3.764, \"Speechiness\": 0.0397, \"Acousticness\": 0.021, \"Liveness\": 0.323, \"Tempo\": 123.056, \"Duration (ms)\": 182200.0, \"Valence\": 0.646, \"Chord\": \"A\"}, {\"Index\": 316, \"Highest Charting Position\": 97, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Hats Off (feat. Travis Scott)\", \"Streams\": 7324233, \"Artist\": \"Lil Baby, Lil Durk\", \"Artist Followers\": 7805880.0, \"Song ID\": \"4lUmnwRybYH7mMzf16xB0y\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-06-04--2021-06-11\", \"Popularity\": 81.0, \"Danceability\": 0.596, \"Energy\": 0.65, \"Loudness\": -5.167, \"Speechiness\": 0.337, \"Acousticness\": 0.138, \"Liveness\": 0.14, \"Tempo\": 133.997, \"Duration (ms)\": 257428.0, \"Valence\": 0.188, \"Chord\": \"A\"}, {\"Index\": 317, \"Highest Charting Position\": 117, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Last Train Home\", \"Streams\": 6439718, \"Artist\": \"John Mayer\", \"Artist Followers\": 5178156.0, \"Song ID\": \"0tgBtQ0ISnMQOKorrN9HLX\", \"Genre\": \"['neo mellow', 'pop rock', 'singer-songwriter']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-06-04--2021-06-11\", \"Popularity\": 75.0, \"Danceability\": 0.591, \"Energy\": 0.831, \"Loudness\": -6.612, \"Speechiness\": 0.0355, \"Acousticness\": 0.235, \"Liveness\": 0.0571, \"Tempo\": 93.007, \"Duration (ms)\": 187307.0, \"Valence\": 0.678, \"Chord\": \"E\"}, {\"Index\": 318, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Voice of the Heroes\", \"Streams\": 6249801, \"Artist\": \"Lil Baby, Lil Durk\", \"Artist Followers\": 7805880.0, \"Song ID\": \"4lUmnwRybYH7mMzf16xB0y\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-06-04--2021-06-11\", \"Popularity\": 81.0, \"Danceability\": 0.596, \"Energy\": 0.65, \"Loudness\": -5.167, \"Speechiness\": 0.337, \"Acousticness\": 0.138, \"Liveness\": 0.14, \"Tempo\": 133.997, \"Duration (ms)\": 257428.0, \"Valence\": 0.188, \"Chord\": \"A\"}, {\"Index\": 319, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"0X1=LOVESONG (I Know I Love you)\", \"Streams\": 6040553, \"Artist\": \"TOMORROW X TOGETHER, Seori\", \"Artist Followers\": 4136553.0, \"Song ID\": \"1Z8TPHiKeCUyClxV6WTTIf\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-05-31\", \"Weeks Charted\": \"2021-06-04--2021-06-11\", \"Popularity\": 81.0, \"Danceability\": 0.584, \"Energy\": 0.836, \"Loudness\": -4.925, \"Speechiness\": 0.079, \"Acousticness\": 0.0558, \"Liveness\": 0.0663, \"Tempo\": 104.973, \"Duration (ms)\": 202204.0, \"Valence\": 0.484, \"Chord\": \"C\"}, {\"Index\": 320, \"Highest Charting Position\": 10, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"a m a r i\", \"Streams\": 5645966, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"2cnKST6T9qUo2i907lm8zX\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 79.0, \"Danceability\": 0.725, \"Energy\": 0.713, \"Loudness\": -6.173, \"Speechiness\": 0.187, \"Acousticness\": 0.127, \"Liveness\": 0.617, \"Tempo\": 65.988, \"Duration (ms)\": 148421.0, \"Valence\": 0.207, \"Chord\": \"E\"}, {\"Index\": 321, \"Highest Charting Position\": 72, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"NEVER LEFT\", \"Streams\": 5552212, \"Artist\": \"Lil Tecca\", \"Artist Followers\": 4016497.0, \"Song ID\": \"21UkXrc9kD48rNpTMI2ecz\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2021-05-06\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 82.0, \"Danceability\": 0.807, \"Energy\": 0.659, \"Loudness\": -6.92, \"Speechiness\": 0.332, \"Acousticness\": 0.0224, \"Liveness\": 0.309, \"Tempo\": 82.465, \"Duration (ms)\": 168727.0, \"Valence\": 0.438, \"Chord\": \"B\"}, {\"Index\": 322, \"Highest Charting Position\": 27, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Solid (feat. Drake)\", \"Streams\": 5347781, \"Artist\": \"Young Stoner Life, Young Thug, Gunna\", \"Artist Followers\": 61930.0, \"Song ID\": \"6rTInqW3YECMkQsBEHw4sd\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 82.0, \"Danceability\": 0.887, \"Energy\": 0.485, \"Loudness\": -9.358, \"Speechiness\": 0.2, \"Acousticness\": 0.0392, \"Liveness\": 0.141, \"Tempo\": 125.987, \"Duration (ms)\": 215693.0, \"Valence\": 0.328, \"Chord\": \"B\"}, {\"Index\": 323, \"Highest Charting Position\": 21, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"La Nota\", \"Streams\": 5300884, \"Artist\": \"Manuel Turizo, Rauw Alejandro, Myke Towers\", \"Artist Followers\": 7904381.0, \"Song ID\": \"7ndTONDDRFGiPnnhOzOXxq\", \"Genre\": \"['colombian pop', 'latin', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2020-10-08\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 79.0, \"Danceability\": 0.736, \"Energy\": 0.632, \"Loudness\": -4.939, \"Speechiness\": 0.0648, \"Acousticness\": 0.18, \"Liveness\": 0.349, \"Tempo\": 92.03, \"Duration (ms)\": 216107.0, \"Valence\": 0.503, \"Chord\": \"B\"}, {\"Index\": 324, \"Highest Charting Position\": 47, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Golden\", \"Streams\": 5298893, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16112621.0, \"Song ID\": \"45S5WTQEGOB1VHr1Q4FuPl\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 83.0, \"Danceability\": 0.448, \"Energy\": 0.838, \"Loudness\": -5.257, \"Speechiness\": 0.0557, \"Acousticness\": 0.21, \"Liveness\": 0.131, \"Tempo\": 139.863, \"Duration (ms)\": 208907.0, \"Valence\": 0.254, \"Chord\": \"E\"}, {\"Index\": 325, \"Highest Charting Position\": 127, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"CORALINE\", \"Streams\": 5241813, \"Artist\": \"M\\u00e5neskin\", \"Artist Followers\": 3377762.0, \"Song ID\": \"7HMz8o0m7ASQ3ImFPfhWTY\", \"Genre\": \"['indie rock italiano', 'italian pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\", \"Popularity\": 81.0, \"Danceability\": 0.363, \"Energy\": 0.678, \"Loudness\": -4.939, \"Speechiness\": 0.0995, \"Acousticness\": 0.0299, \"Liveness\": 0.324, \"Tempo\": 162.124, \"Duration (ms)\": 300413.0, \"Valence\": 0.321, \"Chord\": \"D\"}, {\"Index\": 326, \"Highest Charting Position\": 3, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"BICHOTA\", \"Streams\": 5201714, \"Artist\": \"KAROL G\", \"Artist Followers\": 1250353.0, \"Song ID\": \"4nYLZSNXJyPq8Jj3cEdykP\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 0.0, \"Danceability\": 0.863, \"Energy\": 0.666, \"Loudness\": -4.158, \"Speechiness\": 0.152, \"Acousticness\": 0.212, \"Liveness\": 0.103, \"Tempo\": 163.908, \"Duration (ms)\": 178947.0, \"Valence\": 0.838, \"Chord\": \"C#/Db\"}, {\"Index\": 327, \"Highest Charting Position\": 96, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Slumber Party (feat. Princess Nokia)\", \"Streams\": 5113574, \"Artist\": \"Ashnikko\", \"Artist Followers\": 1246335.0, \"Song ID\": \"11ZulcYY4lowvcQm4oe3VJ\", \"Genre\": \"['electropop', 'escape room', 'pop']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 82.0, \"Danceability\": 0.964, \"Energy\": 0.398, \"Loudness\": -8.981, \"Speechiness\": 0.0795, \"Acousticness\": 0.00151, \"Liveness\": 0.101, \"Tempo\": 105.012, \"Duration (ms)\": 178405.0, \"Valence\": 0.563, \"Chord\": \"B\"}, {\"Index\": 328, \"Highest Charting Position\": 170, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Killer (feat. Jack Harlow & Cordae) - Remix\", \"Streams\": 5404939, \"Artist\": \"Eminem\", \"Artist Followers\": 46785561.0, \"Song ID\": \"7zl7kehxesNEo2pYkKXTSe\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-05-28--2021-06-04\", \"Popularity\": 76.0, \"Danceability\": 0.924, \"Energy\": 0.73, \"Loudness\": -6.125, \"Speechiness\": 0.274, \"Acousticness\": 0.0525, \"Liveness\": 0.113, \"Tempo\": 99.01, \"Duration (ms)\": 236666.0, \"Valence\": 0.848, \"Chord\": \"B\"}, {\"Index\": 329, \"Highest Charting Position\": 105, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Liberdade (Quando o Grave Bate Forte)\", \"Streams\": 5378350, \"Artist\": \"Alok, Mc Don Juan, Dj GBR\", \"Artist Followers\": 10334543.0, \"Song ID\": \"2QLbRVzixE282JSQjBz2DG\", \"Genre\": \"['electro house', 'pop nacional', 'slap house']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 80.0, \"Danceability\": 0.81, \"Energy\": 0.789, \"Loudness\": -4.032, \"Speechiness\": 0.0498, \"Acousticness\": 0.0254, \"Liveness\": 0.104, \"Tempo\": 129.988, \"Duration (ms)\": 150462.0, \"Valence\": 0.432, \"Chord\": \"F#/Gb\"}, {\"Index\": 330, \"Highest Charting Position\": 108, \"Number of Times Charted\": 51, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"All Girls Are The Same\", \"Streams\": 5372180, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"4VXIryQMWpIdGgYR4TrjT1\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2018-12-10\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-08--2020-05-15\\n2020-04-24--2020-05-01\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.671, \"Energy\": 0.529, \"Loudness\": -7.226, \"Speechiness\": 0.307, \"Acousticness\": 0.0769, \"Liveness\": 0.0856, \"Tempo\": 161.989, \"Duration (ms)\": 165820.0, \"Valence\": 0.203, \"Chord\": \"C\"}, {\"Index\": 331, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"734\", \"Streams\": 5368759, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"6vB8bdQCCTDDIH8fhRfuXA\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-05-28--2021-06-04\", \"Popularity\": 75.0, \"Danceability\": 0.663, \"Energy\": 0.545, \"Loudness\": -3.93, \"Speechiness\": 0.036, \"Acousticness\": 0.123, \"Liveness\": 0.106, \"Tempo\": 78.452, \"Duration (ms)\": 196147.0, \"Valence\": 0.344, \"Chord\": \"D\"}, {\"Index\": 332, \"Highest Charting Position\": 85, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Boy With Luv (feat. Halsey)\", \"Streams\": 5266625, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"5KawlOMHjWeUjQtnuRs22c\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2019-04-12\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2020-11-20--2020-11-27\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-01-17--2020-01-24\", \"Popularity\": 82.0, \"Danceability\": 0.645, \"Energy\": 0.862, \"Loudness\": -4.757, \"Speechiness\": 0.0965, \"Acousticness\": 0.0923, \"Liveness\": 0.192, \"Tempo\": 119.991, \"Duration (ms)\": 229773.0, \"Valence\": 0.798, \"Chord\": \"B\"}, {\"Index\": 333, \"Highest Charting Position\": 82, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Disco Arranhado - Funk Remix\", \"Streams\": 5207186, \"Artist\": \"Malu, DJ Lucas Beat\", \"Artist Followers\": 74814.0, \"Song ID\": \"2Gjt4rUHBUH0rMKpBg0hF4\", \"Genre\": \"[]\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 80.0, \"Danceability\": 0.747, \"Energy\": 0.725, \"Loudness\": -2.564, \"Speechiness\": 0.363, \"Acousticness\": 0.551, \"Liveness\": 0.0626, \"Tempo\": 129.96, \"Duration (ms)\": 125558.0, \"Valence\": 0.904, \"Chord\": \"D\"}, {\"Index\": 334, \"Highest Charting Position\": 4, \"Number of Times Charted\": 70, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Godzilla (feat. Juice WRLD)\", \"Streams\": 5143522, \"Artist\": \"Eminem\", \"Artist Followers\": 46785561.0, \"Song ID\": \"7FIWs0pqAYbP91WWM0vlTQ\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 83.0, \"Danceability\": 0.808, \"Energy\": 0.745, \"Loudness\": -5.26, \"Speechiness\": 0.342, \"Acousticness\": 0.145, \"Liveness\": 0.292, \"Tempo\": 165.995, \"Duration (ms)\": 210800.0, \"Valence\": 0.829, \"Chord\": \"A#/Bb\"}, {\"Index\": 335, \"Highest Charting Position\": 8, \"Number of Times Charted\": 68, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Blueberry Faygo\", \"Streams\": 5085511, \"Artist\": \"Lil Mosey\", \"Artist Followers\": 3816446.0, \"Song ID\": \"6wJYhPfqk3KGhHRG76WzOh\", \"Genre\": \"['melodic rap', 'rap', 'rap conscient', 'trap', 'vapor trap']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 79.0, \"Danceability\": 0.774, \"Energy\": 0.554, \"Loudness\": -7.909, \"Speechiness\": 0.0383, \"Acousticness\": 0.207, \"Liveness\": 0.132, \"Tempo\": 99.034, \"Duration (ms)\": 162547.0, \"Valence\": 0.349, \"Chord\": \"C\"}, {\"Index\": 336, \"Highest Charting Position\": 129, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Somebody That I Used To Know\", \"Streams\": 5068972, \"Artist\": \"Gotye, Kimbra\", \"Artist Followers\": 2263960.0, \"Song ID\": \"4wCmqSrbyCgxEXROQE6vtV\", \"Genre\": \"['australian pop']\", \"Release Date\": \"2011-01-01\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 76.0, \"Danceability\": 0.864, \"Energy\": 0.495, \"Loudness\": -7.036, \"Speechiness\": 0.037, \"Acousticness\": 0.591, \"Liveness\": 0.0992, \"Tempo\": 129.062, \"Duration (ms)\": 244973.0, \"Valence\": 0.72, \"Chord\": \"C\"}, {\"Index\": 337, \"Highest Charting Position\": 4, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Holy (feat. Chance The Rapper)\", \"Streams\": 5063015, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48504126.0, \"Song ID\": \"5u1n1kITHCxxp8twBcZxWy\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 81.0, \"Danceability\": 0.673, \"Energy\": 0.704, \"Loudness\": -8.056, \"Speechiness\": 0.36, \"Acousticness\": 0.196, \"Liveness\": 0.0898, \"Tempo\": 86.919, \"Duration (ms)\": 212093.0, \"Valence\": 0.372, \"Chord\": \"F#/Gb\"}, {\"Index\": 338, \"Highest Charting Position\": 200, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Vida Louca\", \"Streams\": 5051514, \"Artist\": \"Mc Poze do Rodo, Neo Beats, Mainstreet\", \"Artist Followers\": 448447.0, \"Song ID\": \"7IG7laqVpcvIIULrwWP5SA\", \"Genre\": \"['funk carioca', 'funk ostentacao']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-05-28--2021-06-04\", \"Popularity\": 82.0, \"Danceability\": 0.852, \"Energy\": 0.62, \"Loudness\": -5.79, \"Speechiness\": 0.227, \"Acousticness\": 0.359, \"Liveness\": 0.101, \"Tempo\": 92.464, \"Duration (ms)\": 155676.0, \"Valence\": 0.744, \"Chord\": \"F#/Gb\"}, {\"Index\": 339, \"Highest Charting Position\": 15, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"i n t e r l u d e\", \"Streams\": 7880155, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"08LwMWf5Tcfsd752EPzFV0\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 76.0, \"Danceability\": 0.77, \"Energy\": 0.574, \"Loudness\": -5.525, \"Speechiness\": 0.106, \"Acousticness\": 0.0617, \"Liveness\": 0.104, \"Tempo\": 98.962, \"Duration (ms)\": 133022.0, \"Valence\": 0.104, \"Chord\": \"C#/Db\"}, {\"Index\": 340, \"Highest Charting Position\": 95, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Butter (Instrumental)\", \"Streams\": 7450126, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"2Ol2sv6gePRdJrZC1hDVNY\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 70.0, \"Danceability\": 0.429, \"Energy\": 0.387, \"Loudness\": -7.486, \"Speechiness\": 0.0753, \"Acousticness\": 0.000178, \"Liveness\": 0.142, \"Tempo\": 109.893, \"Duration (ms)\": 162147.0, \"Valence\": 0.41, \"Chord\": \"C#/Db\"}, {\"Index\": 341, \"Highest Charting Position\": 25, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Film out\", \"Streams\": 7198095, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"3UHPGOkUcE4hE7sqBF4Snt\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-04-01\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 81.0, \"Danceability\": 0.499, \"Energy\": 0.709, \"Loudness\": -6.404, \"Speechiness\": 0.134, \"Acousticness\": 0.296, \"Liveness\": 0.331, \"Tempo\": 164.032, \"Duration (ms)\": 214621.0, \"Valence\": 0.314, \"Chord\": \"A#/Bb\"}, {\"Index\": 342, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Voil\\u00e0\", \"Streams\": 6935400, \"Artist\": \"Barbara Pravi\", \"Artist Followers\": 75496.0, \"Song ID\": \"1uAOCTevGnyKIDbgZdOCnE\", \"Genre\": \"['eurovision', 'nouvelle chanson francaise']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 72.0, \"Danceability\": 0.447, \"Energy\": 0.337, \"Loudness\": -8.665, \"Speechiness\": 0.0631, \"Acousticness\": 0.773, \"Liveness\": 0.298, \"Tempo\": 135.379, \"Duration (ms)\": 176816.0, \"Valence\": 0.603, \"Chord\": \"D\"}, {\"Index\": 343, \"Highest Charting Position\": 53, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Shy Away\", \"Streams\": 6634722, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20823062.0, \"Song ID\": \"2nG54Y4a3sH9YpfxMolOyi\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 77.0, \"Danceability\": 0.588, \"Energy\": 0.856, \"Loudness\": -5.242, \"Speechiness\": 0.0316, \"Acousticness\": 0.000818, \"Liveness\": 0.238, \"Tempo\": 96.966, \"Duration (ms)\": 175044.0, \"Valence\": 0.635, \"Chord\": \"A\"}, {\"Index\": 344, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Saturday\", \"Streams\": 6628638, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20823062.0, \"Song ID\": \"60dwJ8dnqZ4WrIdiu7LkNR\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 75.0, \"Danceability\": 0.687, \"Energy\": 0.89, \"Loudness\": -5.99, \"Speechiness\": 0.0344, \"Acousticness\": 0.00396, \"Liveness\": 0.0436, \"Tempo\": 113.06, \"Duration (ms)\": 172232.0, \"Valence\": 0.854, \"Chord\": \"G#/Ab\"}, {\"Index\": 345, \"Highest Charting Position\": 18, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"9 5 . s o u t h\", \"Streams\": 6333126, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5R691ipUYRDYW6ehapjoj6\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 75.0, \"Danceability\": 0.713, \"Energy\": 0.793, \"Loudness\": -5.277, \"Speechiness\": 0.397, \"Acousticness\": 0.271, \"Liveness\": 0.727, \"Tempo\": 71.724, \"Duration (ms)\": 196946.0, \"Valence\": 0.203, \"Chord\": \"D\"}, {\"Index\": 346, \"Highest Charting Position\": 67, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Seeing Green (with Drake & Lil Wayne)\", \"Streams\": 6299936, \"Artist\": \"Nicki Minaj\", \"Artist Followers\": 22161310.0, \"Song ID\": \"1TZv3bujNaYz646eezRE91\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'pop rap', 'post-teen pop', 'queens hip hop']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 77.0, \"Danceability\": 0.573, \"Energy\": 0.867, \"Loudness\": -2.876, \"Speechiness\": 0.168, \"Acousticness\": 0.0853, \"Liveness\": 0.38, \"Tempo\": 74.861, \"Duration (ms)\": 339506.0, \"Valence\": 0.231, \"Chord\": \"F\"}, {\"Index\": 347, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Dark Side\", \"Streams\": 6277641, \"Artist\": \"Blind Channel\", \"Artist Followers\": 121225.0, \"Song ID\": \"1ovFnZv6mUe0LzAbfVqOmh\", \"Genre\": \"['eurovision', 'oulu metal', 'trancecore']\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 72.0, \"Danceability\": 0.571, \"Energy\": 0.955, \"Loudness\": -3.795, \"Speechiness\": 0.105, \"Acousticness\": 0.00254, \"Liveness\": 0.274, \"Tempo\": 98.01, \"Duration (ms)\": 177790.0, \"Valence\": 0.437, \"Chord\": \"G\"}, {\"Index\": 348, \"Highest Charting Position\": 137, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"SHUM\", \"Streams\": 6237019, \"Artist\": \"Go_A\", \"Artist Followers\": 107553.0, \"Song ID\": \"7mEDVrAHDnQJStDo8jKJJm\", \"Genre\": \"['eurovision']\", \"Release Date\": \"2021-03-10\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 75.0, \"Danceability\": 0.527, \"Energy\": 0.737, \"Loudness\": -5.34, \"Speechiness\": 0.0642, \"Acousticness\": 0.05, \"Liveness\": 0.105, \"Tempo\": 116.431, \"Duration (ms)\": 172675.0, \"Valence\": 0.499, \"Chord\": \"E\"}, {\"Index\": 349, \"Highest Charting Position\": 69, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"In the morning\", \"Streams\": 5738325, \"Artist\": \"ITZY\", \"Artist Followers\": 2379448.0, \"Song ID\": \"2QdH0rKlV3d9Y6lWzcnlBH\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 79.0, \"Danceability\": 0.847, \"Energy\": 0.814, \"Loudness\": -4.668, \"Speechiness\": 0.152, \"Acousticness\": 0.0825, \"Liveness\": 0.0948, \"Tempo\": 140.057, \"Duration (ms)\": 172359.0, \"Valence\": 0.711, \"Chord\": \"B\"}, {\"Index\": 350, \"Highest Charting Position\": 27, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"l e t . g o . m y . h a n d (with Bas & 6LACK)\", \"Streams\": 5393643, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"0GAyuCo975IHGxxiLKDufB\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 73.0, \"Danceability\": 0.583, \"Energy\": 0.625, \"Loudness\": -8.011, \"Speechiness\": 0.277, \"Acousticness\": 0.506, \"Liveness\": 0.196, \"Tempo\": 89.812, \"Duration (ms)\": 266291.0, \"Valence\": 0.516, \"Chord\": \"C#/Db\"}, {\"Index\": 351, \"Highest Charting Position\": 2, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"What\\u2019s Next\", \"Streams\": 5335112, \"Artist\": \"Drake\", \"Artist Followers\": 56308172.0, \"Song ID\": \"3aQem4jVGdhtg116TmJnHz\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 81.0, \"Danceability\": 0.781, \"Energy\": 0.594, \"Loudness\": -6.959, \"Speechiness\": 0.0485, \"Acousticness\": 0.0136, \"Liveness\": 0.162, \"Tempo\": 129.895, \"Duration (ms)\": 178154.0, \"Valence\": 0.0628, \"Chord\": \"C\"}, {\"Index\": 352, \"Highest Charting Position\": 154, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Ramen & OJ\", \"Streams\": 5282702, \"Artist\": \"Joyner Lucas, Lil Baby\", \"Artist Followers\": 1725025.0, \"Song ID\": \"4TIqzdAssasqx3DAe6cG9J\", \"Genre\": \"['boston hip hop', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 81.0, \"Danceability\": 0.597, \"Energy\": 0.571, \"Loudness\": -6.205, \"Speechiness\": 0.293, \"Acousticness\": 0.492, \"Liveness\": 0.093, \"Tempo\": 106.196, \"Duration (ms)\": 218448.0, \"Valence\": 0.165, \"Chord\": \"C#/Db\"}, {\"Index\": 353, \"Highest Charting Position\": 91, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Cloud 9\", \"Streams\": 5252767, \"Artist\": \"Beach Bunny\", \"Artist Followers\": 618444.0, \"Song ID\": \"6vFsBXYczYsP0H3lgunZOm\", \"Genre\": \"['bubblegrunge', 'chicago indie', 'indie pop', 'pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 81.0, \"Danceability\": 0.637, \"Energy\": 0.929, \"Loudness\": -3.593, \"Speechiness\": 0.0491, \"Acousticness\": 0.00167, \"Liveness\": 0.344, \"Tempo\": 80.974, \"Duration (ms)\": 147351.0, \"Valence\": 0.902, \"Chord\": \"E\"}, {\"Index\": 354, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Tout l'univers\", \"Streams\": 5174437, \"Artist\": \"Gjon's Tears\", \"Artist Followers\": 32257.0, \"Song ID\": \"3MvY2XbGYFi6p2dgmdcOYG\", \"Genre\": \"[]\", \"Release Date\": \"2021-03-10\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 69.0, \"Danceability\": 0.534, \"Energy\": 0.365, \"Loudness\": -9.187, \"Speechiness\": 0.033, \"Acousticness\": 0.81, \"Liveness\": 0.158, \"Tempo\": 123.466, \"Duration (ms)\": 183707.0, \"Valence\": 0.237, \"Chord\": \"A\"}, {\"Index\": 355, \"Highest Charting Position\": 64, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Headshot (feat. Polo G & Fivio Foreign)\", \"Streams\": 5174298, \"Artist\": \"Lil Tjay\", \"Artist Followers\": 3553442.0, \"Song ID\": \"4eNOLmx8r2IJAVKvBBL1jv\", \"Genre\": \"['brooklyn drill', 'melodic rap', 'nyc rap']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 81.0, \"Danceability\": 0.808, \"Energy\": 0.639, \"Loudness\": -7.266, \"Speechiness\": 0.279, \"Acousticness\": 0.0802, \"Liveness\": 0.15, \"Tempo\": 118.0, \"Duration (ms)\": 144349.0, \"Valence\": 0.395, \"Chord\": \"C#/Db\"}, {\"Index\": 356, \"Highest Charting Position\": 198, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Mask\", \"Streams\": 5156496, \"Artist\": \"Dream\", \"Artist Followers\": 727731.0, \"Song ID\": \"3IxMaULfjq4IT2IN6v54PB\", \"Genre\": \"['dream smp']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 76.0, \"Danceability\": 0.636, \"Energy\": 0.749, \"Loudness\": -4.197, \"Speechiness\": 0.0631, \"Acousticness\": 0.195, \"Liveness\": 0.107, \"Tempo\": 117.904, \"Duration (ms)\": 174936.0, \"Valence\": 0.653, \"Chord\": \"C#/Db\"}, {\"Index\": 357, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"10 Years\", \"Streams\": 5152139, \"Artist\": \"Da\\u00f0i Freyr\", \"Artist Followers\": 169137.0, \"Song ID\": \"4O0LQKVT6hGmVGNwizmydg\", \"Genre\": \"['icelandic pop', 'sunnlensk tonlist']\", \"Release Date\": \"2021-03-13\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 70.0, \"Danceability\": 0.798, \"Energy\": 0.621, \"Loudness\": -6.916, \"Speechiness\": 0.0391, \"Acousticness\": 0.0141, \"Liveness\": 0.0926, \"Tempo\": 123.038, \"Duration (ms)\": 166000.0, \"Valence\": 0.443, \"Chord\": \"D\"}, {\"Index\": 358, \"Highest Charting Position\": 127, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Choker\", \"Streams\": 5150176, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20823062.0, \"Song ID\": \"732E6ibFkQR5lNIPEeiEnx\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-04-30--2021-05-07\", \"Popularity\": 72.0, \"Danceability\": 0.7, \"Energy\": 0.664, \"Loudness\": -8.211, \"Speechiness\": 0.0394, \"Acousticness\": 0.306, \"Liveness\": 0.249, \"Tempo\": 142.009, \"Duration (ms)\": 223066.0, \"Valence\": 0.585, \"Chord\": \"G\"}, {\"Index\": 359, \"Highest Charting Position\": 25, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"a p p l y i n g . p r e s s u r e\", \"Streams\": 15967986, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"1d7q712nXjG98HiwHk7HFS\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 71.0, \"Danceability\": 0.699, \"Energy\": 0.759, \"Loudness\": -5.302, \"Speechiness\": 0.311, \"Acousticness\": 0.0814, \"Liveness\": 0.312, \"Tempo\": 83.092, \"Duration (ms)\": 177337.0, \"Valence\": 0.404, \"Chord\": \"C#/Db\"}, {\"Index\": 360, \"Highest Charting Position\": 30, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"1 0 0 . m i l \\u2018 (with Bas)\", \"Streams\": 15171655, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"4n6NDfYake476trCjJRNl0\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 72.0, \"Danceability\": 0.711, \"Energy\": 0.647, \"Loudness\": -5.667, \"Speechiness\": 0.0822, \"Acousticness\": 0.334, \"Liveness\": 0.312, \"Tempo\": 125.092, \"Duration (ms)\": 163302.0, \"Valence\": 0.227, \"Chord\": \"D\"}, {\"Index\": 361, \"Highest Charting Position\": 32, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"p u n c h i n \\u2018 . t h e . c l o c k\", \"Streams\": 14051831, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"57ZUX6TNyKLBydAdVVd02x\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 70.0, \"Danceability\": 0.769, \"Energy\": 0.74, \"Loudness\": -6.579, \"Speechiness\": 0.378, \"Acousticness\": 0.197, \"Liveness\": 0.171, \"Tempo\": 94.104, \"Duration (ms)\": 112579.0, \"Valence\": 0.692, \"Chord\": \"B\"}, {\"Index\": 362, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"t h e . c l i m b . b a c k\", \"Streams\": 12648655, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5lLNBIyjp72btcnrjBG751\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.618, \"Energy\": 0.632, \"Loudness\": -6.973, \"Speechiness\": 0.346, \"Acousticness\": 0.0526, \"Liveness\": 0.353, \"Tempo\": 81.446, \"Duration (ms)\": 306257.0, \"Valence\": 0.319, \"Chord\": \"B\"}, {\"Index\": 363, \"Highest Charting Position\": 48, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"h u n g e r . o n . h i l l s i d e (with Bas)\", \"Streams\": 11647489, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5BwQjRasNcdRPuVWKcHto2\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 71.0, \"Danceability\": 0.563, \"Energy\": 0.703, \"Loudness\": -5.756, \"Speechiness\": 0.0702, \"Acousticness\": 0.126, \"Liveness\": 0.213, \"Tempo\": 94.983, \"Duration (ms)\": 238972.0, \"Valence\": 0.294, \"Chord\": \"D\"}, {\"Index\": 364, \"Highest Charting Position\": 55, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"c l o s e\", \"Streams\": 10712648, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"1D3z6HTiQsNmZxjl7F7eoG\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.597, \"Energy\": 0.587, \"Loudness\": -7.026, \"Speechiness\": 0.137, \"Acousticness\": 0.0622, \"Liveness\": 0.214, \"Tempo\": 140.021, \"Duration (ms)\": 218802.0, \"Valence\": 0.0753, \"Chord\": \"G\"}, {\"Index\": 365, \"Highest Charting Position\": 34, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"WITHOUT YOU (with Miley Cyrus)\", \"Streams\": 6081034, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2230022.0, \"Song ID\": \"1EHUQesfVKwbthtNcpBi9g\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 81.0, \"Danceability\": 0.655, \"Energy\": 0.469, \"Loudness\": -6.257, \"Speechiness\": 0.0292, \"Acousticness\": 0.173, \"Liveness\": 0.0956, \"Tempo\": 92.56, \"Duration (ms)\": 161385.0, \"Valence\": 0.467, \"Chord\": \"C\"}, {\"Index\": 366, \"Highest Charting Position\": 92, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Snow Tha Product: Bzrp Music Sessions, Vol. 39\", \"Streams\": 5595839, \"Artist\": \"Bizarrap, Snow Tha Product\", \"Artist Followers\": 3126961.0, \"Song ID\": \"3ke6it1vTmHtz2ApcIVUz5\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2021-04-28\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 78.0, \"Danceability\": 0.83, \"Energy\": 0.748, \"Loudness\": -5.362, \"Speechiness\": 0.162, \"Acousticness\": 0.354, \"Liveness\": 0.0992, \"Tempo\": 133.028, \"Duration (ms)\": 177443.0, \"Valence\": 0.523, \"Chord\": \"C#/Db\"}, {\"Index\": 367, \"Highest Charting Position\": 87, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Travesuras - Remix\", \"Streams\": 5518444, \"Artist\": \"Nio Garcia, Casper Magico, Ozuna, Wisin & Yandel, Myke Towers, Flow La Movie\", \"Artist Followers\": 2123734.0, \"Song ID\": \"0VWLId2RwPCno9s1cJm2Vy\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-03-11\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 81.0, \"Danceability\": 0.739, \"Energy\": 0.788, \"Loudness\": -5.198, \"Speechiness\": 0.0731, \"Acousticness\": 0.0513, \"Liveness\": 0.282, \"Tempo\": 175.996, \"Duration (ms)\": 324426.0, \"Valence\": 0.473, \"Chord\": \"C#/Db\"}, {\"Index\": 368, \"Highest Charting Position\": 148, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Bubblegum Bitch\", \"Streams\": 5375782, \"Artist\": \"MARINA\", \"Artist Followers\": 2918229.0, \"Song ID\": \"0ZFBKLOZLIM16RAUb5eomN\", \"Genre\": \"['dance pop', 'electropop', 'metropopolis', 'pop', 'post-teen pop', 'uk alternative pop']\", \"Release Date\": \"2012-04-30\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 73.0, \"Danceability\": 0.495, \"Energy\": 0.856, \"Loudness\": -5.123, \"Speechiness\": 0.0311, \"Acousticness\": 0.000219, \"Liveness\": 0.103, \"Tempo\": 158.024, \"Duration (ms)\": 154667.0, \"Valence\": 0.609, \"Chord\": \"C\"}, {\"Index\": 369, \"Highest Charting Position\": 5, \"Number of Times Charted\": 142, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Falling\", \"Streams\": 5294368, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16112621.0, \"Song ID\": \"1ZMiCix7XSAbfAJlEZWMCp\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.567, \"Energy\": 0.267, \"Loudness\": -6.502, \"Speechiness\": 0.0299, \"Acousticness\": 0.839, \"Liveness\": 0.089, \"Tempo\": 110.011, \"Duration (ms)\": 240133.0, \"Valence\": 0.0592, \"Chord\": \"E\"}, {\"Index\": 370, \"Highest Charting Position\": 182, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Expl\\u00edcito\", \"Streams\": 5278449, \"Artist\": \"Myke Towers\", \"Artist Followers\": 6150675.0, \"Song ID\": \"6qraVL4IJaIj0IuEexYJNa\", \"Genre\": \"['trap latino']\", \"Release Date\": \"2020-12-15\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-03-26--2021-04-02\", \"Popularity\": 81.0, \"Danceability\": 0.828, \"Energy\": 0.83, \"Loudness\": -3.371, \"Speechiness\": 0.047, \"Acousticness\": 0.348, \"Liveness\": 0.0613, \"Tempo\": 95.007, \"Duration (ms)\": 195066.0, \"Valence\": 0.422, \"Chord\": \"D\"}, {\"Index\": 371, \"Highest Charting Position\": 58, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"No Te Enamores - Remix\", \"Streams\": 5218146, \"Artist\": \"Milly, Farruko, Nio Garcia, Jay Wheeler, Amenazzy\", \"Artist Followers\": 22718.0, \"Song ID\": \"2mM3gZ0BbPwPPMelbA8vgt\", \"Genre\": \"['reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 79.0, \"Danceability\": 0.824, \"Energy\": 0.837, \"Loudness\": -4.603, \"Speechiness\": 0.107, \"Acousticness\": 0.573, \"Liveness\": 0.271, \"Tempo\": 100.021, \"Duration (ms)\": 289933.0, \"Valence\": 0.58, \"Chord\": \"F\"}, {\"Index\": 372, \"Highest Charting Position\": 110, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"PROBLEMA\", \"Streams\": 5215973, \"Artist\": \"Daddy Yankee\", \"Artist Followers\": 1250353.0, \"Song ID\": \"7vzPjsX8UzlPKKtV47qGPn\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 0.0, \"Danceability\": 0.773, \"Energy\": 0.8, \"Loudness\": -3.17, \"Speechiness\": 0.0987, \"Acousticness\": 0.0613, \"Liveness\": 0.0327, \"Tempo\": 89.988, \"Duration (ms)\": 184507.0, \"Valence\": 0.842, \"Chord\": \"A#/Bb\"}, {\"Index\": 373, \"Highest Charting Position\": 5, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Lonely (with benny blanco)\", \"Streams\": 5191697, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48504126.0, \"Song ID\": \"4y4spB9m0Q6026KfkAvy9Q\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 80.0, \"Danceability\": 0.631, \"Energy\": 0.239, \"Loudness\": -7.071, \"Speechiness\": 0.0398, \"Acousticness\": 0.864, \"Liveness\": 0.116, \"Tempo\": 79.859, \"Duration (ms)\": 149297.0, \"Valence\": 0.0927, \"Chord\": \"B\"}, {\"Index\": 374, \"Highest Charting Position\": 77, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Cupid's Chokehold / Breakfast in America\", \"Streams\": 5165035, \"Artist\": \"Gym Class Heroes\", \"Artist Followers\": 1275345.0, \"Song ID\": \"2Lhdl74nwwVGOE2Gv35QuK\", \"Genre\": \"['dance pop', 'pop rap']\", \"Release Date\": \"2005-02-22\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 81.0, \"Danceability\": 0.72, \"Energy\": 0.744, \"Loudness\": -6.938, \"Speechiness\": 0.12, \"Acousticness\": 0.237, \"Liveness\": 0.255, \"Tempo\": 78.953, \"Duration (ms)\": 243773.0, \"Valence\": 0.619, \"Chord\": \"C#/Db\"}, {\"Index\": 375, \"Highest Charting Position\": 38, \"Number of Times Charted\": 72, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"If the World Was Ending - feat. Julia Michaels\", \"Streams\": 5127736, \"Artist\": \"JP Saxe\", \"Artist Followers\": 280585.0, \"Song ID\": \"2kJwzbxV2ppxnQoYw4GLBZ\", \"Genre\": \"['alt z', 'canadian contemporary r&b', 'indie cafe pop', 'pop', 'pop rock', 'post-teen pop']\", \"Release Date\": \"2019-10-17\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.464, \"Energy\": 0.473, \"Loudness\": -10.086, \"Speechiness\": 0.129, \"Acousticness\": 0.866, \"Liveness\": 0.109, \"Tempo\": 75.801, \"Duration (ms)\": 208687.0, \"Valence\": 0.604, \"Chord\": \"C#/Db\"}, {\"Index\": 376, \"Highest Charting Position\": 47, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"I DID IT (feat. Post Malone, Megan Thee Stallion, Lil Baby & DaBaby)\", \"Streams\": 7347891, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6278835.0, \"Song ID\": \"20GrahbI4AzAOWxpYfDKkf\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 76.0, \"Danceability\": 0.757, \"Energy\": 0.721, \"Loudness\": -2.906, \"Speechiness\": 0.0691, \"Acousticness\": 0.00196, \"Liveness\": 0.647, \"Tempo\": 124.036, \"Duration (ms)\": 165366.0, \"Valence\": 0.364, \"Chord\": \"E\"}, {\"Index\": 377, \"Highest Charting Position\": 61, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Body\", \"Streams\": 5831357, \"Artist\": \"Russ Millions, Tion Wayne\", \"Artist Followers\": 323203.0, \"Song ID\": \"6uvMKqNlrSvcC4NaKnrwjZ\", \"Genre\": \"['london rap']\", \"Release Date\": \"2021-04-22\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 84.0, \"Danceability\": 0.883, \"Energy\": 0.674, \"Loudness\": -8.043, \"Speechiness\": 0.357, \"Acousticness\": 0.21, \"Liveness\": 0.0678, \"Tempo\": 141.02, \"Duration (ms)\": 278085.0, \"Valence\": 0.73, \"Chord\": \"B\"}, {\"Index\": 378, \"Highest Charting Position\": 10, \"Number of Times Charted\": 69, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"everything i wanted\", \"Streams\": 5448680, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"1OC8hMoqAuWmTWJ4heJNlO\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.704, \"Energy\": 0.225, \"Loudness\": -14.454, \"Speechiness\": 0.0994, \"Acousticness\": 0.901, \"Liveness\": 0.106, \"Tempo\": 120.006, \"Duration (ms)\": 245426.0, \"Valence\": 0.243, \"Chord\": \"F#/Gb\"}, {\"Index\": 379, \"Highest Charting Position\": 169, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"What You Need\", \"Streams\": 5346005, \"Artist\": \"Don Toliver\", \"Artist Followers\": 1605329.0, \"Song ID\": \"6LcX2hBbXaJcK4AuefE936\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2021-05-04\", \"Weeks Charted\": \"2021-05-07--2021-05-14\", \"Popularity\": 76.0, \"Danceability\": 0.664, \"Energy\": 0.655, \"Loudness\": -7.327, \"Speechiness\": 0.0461, \"Acousticness\": 0.059, \"Liveness\": 0.17, \"Tempo\": 129.987, \"Duration (ms)\": 217609.0, \"Valence\": 0.13, \"Chord\": \"A#/Bb\"}, {\"Index\": 380, \"Highest Charting Position\": 115, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"L-Gante: Bzrp Music Sessions, Vol.38\", \"Streams\": 5290877, \"Artist\": \"Bizarrap, L-Gante\", \"Artist Followers\": 3126961.0, \"Song ID\": \"1Crj1zkRMpsEjb9NOR6Zof\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2021-03-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 80.0, \"Danceability\": 0.553, \"Energy\": 0.819, \"Loudness\": -3.083, \"Speechiness\": 0.257, \"Acousticness\": 0.368, \"Liveness\": 0.0915, \"Tempo\": 87.913, \"Duration (ms)\": 192348.0, \"Valence\": 0.761, \"Chord\": \"D\"}, {\"Index\": 381, \"Highest Charting Position\": 19, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"HOLIDAY\", \"Streams\": 5264232, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5473565.0, \"Song ID\": \"6zFMeegAMYQo0mt8rXtrli\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 83.0, \"Danceability\": 0.81, \"Energy\": 0.511, \"Loudness\": -6.924, \"Speechiness\": 0.164, \"Acousticness\": 0.12, \"Liveness\": 0.0832, \"Tempo\": 151.947, \"Duration (ms)\": 154998.0, \"Valence\": 0.837, \"Chord\": \"F\"}, {\"Index\": 382, \"Highest Charting Position\": 71, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"At My Worst\", \"Streams\": 5258000, \"Artist\": \"Pink Sweat$\", \"Artist Followers\": 942628.0, \"Song ID\": \"0ri0Han4IRJhzvERHOZTMr\", \"Genre\": \"['bedroom soul', 'pop']\", \"Release Date\": \"2020-07-17\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 79.0, \"Danceability\": 0.813, \"Energy\": 0.415, \"Loudness\": -5.926, \"Speechiness\": 0.0349, \"Acousticness\": 0.777, \"Liveness\": 0.131, \"Tempo\": 91.921, \"Duration (ms)\": 170345.0, \"Valence\": 0.667, \"Chord\": \"C\"}, {\"Index\": 383, \"Highest Charting Position\": 3, \"Number of Times Charted\": 70, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Life Is Good (feat. Drake)\", \"Streams\": 5241227, \"Artist\": \"Future\", \"Artist Followers\": 10488292.0, \"Song ID\": \"5yY9lUy8nbvjM1Uyo1Uqoc\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 81.0, \"Danceability\": 0.676, \"Energy\": 0.609, \"Loudness\": -5.831, \"Speechiness\": 0.481, \"Acousticness\": 0.0706, \"Liveness\": 0.152, \"Tempo\": 142.037, \"Duration (ms)\": 237735.0, \"Valence\": 0.508, \"Chord\": \"D\"}, {\"Index\": 384, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Extasy\", \"Streams\": 5203700, \"Artist\": \"187 Strassenbande, Bonez MC, Frauenarzt\", \"Artist Followers\": 1223734.0, \"Song ID\": \"79lc69ZXfL4WmJIzVSDmWT\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-05-07--2021-05-14\", \"Popularity\": 67.0, \"Danceability\": 0.863, \"Energy\": 0.739, \"Loudness\": -5.879, \"Speechiness\": 0.153, \"Acousticness\": 0.0289, \"Liveness\": 0.0931, \"Tempo\": 129.964, \"Duration (ms)\": 174021.0, \"Valence\": 0.547, \"Chord\": \"A\"}, {\"Index\": 385, \"Highest Charting Position\": 7, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Wishing Well\", \"Streams\": 5125706, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"2U5WueTLIK5WJLD7mvDODv\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 83.0, \"Danceability\": 0.65, \"Energy\": 0.613, \"Loudness\": -6.13, \"Speechiness\": 0.128, \"Acousticness\": 0.00336, \"Liveness\": 0.267, \"Tempo\": 149.972, \"Duration (ms)\": 194621.0, \"Valence\": 0.0804, \"Chord\": \"A\"}, {\"Index\": 386, \"Highest Charting Position\": 164, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Fan de Tus Fotos\", \"Streams\": 5103863, \"Artist\": \"Nicky Jam, Romeo Santos\", \"Artist Followers\": 14826679.0, \"Song ID\": \"1mauYRwbpoGQX6itP2FAJC\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-02-08\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\", \"Popularity\": 79.0, \"Danceability\": 0.728, \"Energy\": 0.689, \"Loudness\": -5.718, \"Speechiness\": 0.0725, \"Acousticness\": 0.293, \"Liveness\": 0.109, \"Tempo\": 170.089, \"Duration (ms)\": 197647.0, \"Valence\": 0.431, \"Chord\": \"G\"}, {\"Index\": 387, \"Highest Charting Position\": 82, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Tap\\u00e3o Na Raba\", \"Streams\": 5088848, \"Artist\": \"Ra\\u00ed Saia Rodada\", \"Artist Followers\": 1260752.0, \"Song ID\": \"58pgi1RpcU2fVJsxhm7BIr\", \"Genre\": \"['forro']\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 80.0, \"Danceability\": 0.808, \"Energy\": 0.796, \"Loudness\": -3.169, \"Speechiness\": 0.0305, \"Acousticness\": 0.462, \"Liveness\": 0.155, \"Tempo\": 128.048, \"Duration (ms)\": 175047.0, \"Valence\": 0.799, \"Chord\": \"C#/Db\"}, {\"Index\": 388, \"Highest Charting Position\": 66, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Machu Picchu\", \"Streams\": 5062404, \"Artist\": \"Camilo, Evaluna Montaner\", \"Artist Followers\": 10561047.0, \"Song ID\": \"1LXb70u8SLsvBAPWHMCTMe\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2021-03-01\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 76.0, \"Danceability\": 0.788, \"Energy\": 0.789, \"Loudness\": -2.39, \"Speechiness\": 0.124, \"Acousticness\": 0.397, \"Liveness\": 0.226, \"Tempo\": 167.897, \"Duration (ms)\": 179005.0, \"Valence\": 0.867, \"Chord\": \"C\"}, {\"Index\": 389, \"Highest Charting Position\": 4, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Come & Go (with Marshmello)\", \"Streams\": 5037124, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"2Y0wPrPQBrGhoLn14xRYCG\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 83.0, \"Danceability\": 0.625, \"Energy\": 0.814, \"Loudness\": -5.181, \"Speechiness\": 0.0657, \"Acousticness\": 0.0172, \"Liveness\": 0.158, \"Tempo\": 144.991, \"Duration (ms)\": 205485.0, \"Valence\": 0.535, \"Chord\": \"C\"}, {\"Index\": 390, \"Highest Charting Position\": 71, \"Number of Times Charted\": 72, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Robbery\", \"Streams\": 5024884, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"6Hj9jySrnFppAI0sEMCZpJ\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2019-03-08\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.685, \"Energy\": 0.692, \"Loudness\": -5.122, \"Speechiness\": 0.0457, \"Acousticness\": 0.328, \"Liveness\": 0.153, \"Tempo\": 159.966, \"Duration (ms)\": 240051.0, \"Valence\": 0.578, \"Chord\": \"D\"}, {\"Index\": 391, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Paradigmas\", \"Streams\": 5018076, \"Artist\": \"Jorge & Mateus\", \"Artist Followers\": 15013645.0, \"Song ID\": \"17UfXrL7Run3GyZJW4uRjC\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2021-04-22\", \"Weeks Charted\": \"2021-05-07--2021-05-14\", \"Popularity\": 72.0, \"Danceability\": 0.686, \"Energy\": 0.789, \"Loudness\": -4.103, \"Speechiness\": 0.126, \"Acousticness\": 0.322, \"Liveness\": 0.4, \"Tempo\": 157.932, \"Duration (ms)\": 157355.0, \"Valence\": 0.822, \"Chord\": \"C#/Db\"}, {\"Index\": 392, \"Highest Charting Position\": 53, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"SugarCrash!\", \"Streams\": 5018005, \"Artist\": \"ElyOtto\", \"Artist Followers\": 85617.0, \"Song ID\": \"2ePtv8MlBO9nuuXABqAfEX\", \"Genre\": \"['weirdcore']\", \"Release Date\": \"2020-08-25\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 80.0, \"Danceability\": 0.748, \"Energy\": 0.734, \"Loudness\": -6.499, \"Speechiness\": 0.124, \"Acousticness\": 0.524, \"Liveness\": 0.0975, \"Tempo\": 97.753, \"Duration (ms)\": 80081.0, \"Valence\": 0.368, \"Chord\": \"C\"}, {\"Index\": 393, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"durag activity (with Travis Scott)\", \"Streams\": 7939784, \"Artist\": \"Baby Keem\", \"Artist Followers\": 279741.0, \"Song ID\": \"4JJcP0Rv9AgyPD6ZGaC8EE\", \"Genre\": \"['hip hop', 'rap', 'trap', 'underground hip hop']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-04-30--2021-05-07\", \"Popularity\": 75.0, \"Danceability\": 0.89, \"Energy\": 0.701, \"Loudness\": -5.712, \"Speechiness\": 0.342, \"Acousticness\": 0.00306, \"Liveness\": 0.0895, \"Tempo\": 80.462, \"Duration (ms)\": 225020.0, \"Valence\": 0.505, \"Chord\": \"C\"}, {\"Index\": 394, \"Highest Charting Position\": 113, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"love race (feat. Kellin Quinn)\", \"Streams\": 6325080, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3864419.0, \"Song ID\": \"1F9kEuwT29fgqlovIclu81\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2021-04-29\", \"Weeks Charted\": \"2021-04-30--2021-05-07\", \"Popularity\": 76.0, \"Danceability\": 0.517, \"Energy\": 0.848, \"Loudness\": -4.054, \"Speechiness\": 0.0521, \"Acousticness\": 0.00581, \"Liveness\": 0.214, \"Tempo\": 95.906, \"Duration (ms)\": 188779.0, \"Valence\": 0.429, \"Chord\": \"A#/Bb\"}, {\"Index\": 395, \"Highest Charting Position\": 7, \"Number of Times Charted\": 40, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"POPSTAR (feat. Drake)\", \"Streams\": 6127103, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6278835.0, \"Song ID\": \"6EDO9iiTtwNv6waLwa1UUq\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-07-17\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 80.0, \"Danceability\": 0.8, \"Energy\": 0.56, \"Loudness\": -4.818, \"Speechiness\": 0.261, \"Acousticness\": 0.057, \"Liveness\": 0.134, \"Tempo\": 163.071, \"Duration (ms)\": 200221.0, \"Valence\": 0.45, \"Chord\": \"F\"}, {\"Index\": 396, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"LET IT GO (feat. Justin Bieber & 21 Savage)\", \"Streams\": 6083338, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6278835.0, \"Song ID\": \"1cEhrSF6EylAEqdhUGuNpX\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-04-30--2021-05-07\", \"Popularity\": 75.0, \"Danceability\": 0.877, \"Energy\": 0.444, \"Loudness\": -7.547, \"Speechiness\": 0.172, \"Acousticness\": 0.24, \"Liveness\": 0.169, \"Tempo\": 129.06, \"Duration (ms)\": 165527.0, \"Valence\": 0.658, \"Chord\": \"G#/Ab\"}, {\"Index\": 397, \"Highest Charting Position\": 137, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Girl From Rio\", \"Streams\": 5768836, \"Artist\": \"Anitta\", \"Artist Followers\": 10740222.0, \"Song ID\": \"6CF085Ol0cVda1WqelybEQ\", \"Genre\": \"['funk carioca', 'funk pop', 'pagode baiano', 'pop nacional']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-04-30--2021-05-07\", \"Popularity\": 69.0, \"Danceability\": 0.732, \"Energy\": 0.604, \"Loudness\": -7.472, \"Speechiness\": 0.0443, \"Acousticness\": 0.0112, \"Liveness\": 0.219, \"Tempo\": 139.982, \"Duration (ms)\": 195429.0, \"Valence\": 0.732, \"Chord\": \"C\"}, {\"Index\": 398, \"Highest Charting Position\": 10, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"On The Ground\", \"Streams\": 5655879, \"Artist\": \"ROS\\u00c9\", \"Artist Followers\": 1094731.0, \"Song ID\": \"2pn8dNVSpYnAtlKFC8Q0DJ\", \"Genre\": \"[]\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 74.0, \"Danceability\": 0.311, \"Energy\": 0.607, \"Loudness\": -6.578, \"Speechiness\": 0.11, \"Acousticness\": 0.0174, \"Liveness\": 0.131, \"Tempo\": 188.7, \"Duration (ms)\": 168086.0, \"Valence\": 0.286, \"Chord\": \"C#/Db\"}, {\"Index\": 399, \"Highest Charting Position\": 20, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Mr. Perfectly Fine (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5480722, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2CYVETnhM9aytqrazYYwrK\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 74.0, \"Danceability\": 0.66, \"Energy\": 0.817, \"Loudness\": -6.269, \"Speechiness\": 0.0521, \"Acousticness\": 0.162, \"Liveness\": 0.0667, \"Tempo\": 135.942, \"Duration (ms)\": 277592.0, \"Valence\": 0.714, \"Chord\": \"B\"}, {\"Index\": 400, \"Highest Charting Position\": 42, \"Number of Times Charted\": 60, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"when the party's over\", \"Streams\": 5467596, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"5KWwUzVxubgSPmLIUAQhYt\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.484, \"Energy\": 0.103, \"Loudness\": -14.075, \"Speechiness\": 0.0627, \"Acousticness\": 0.979, \"Liveness\": 0.0895, \"Tempo\": 124.011, \"Duration (ms)\": 199931.0, \"Valence\": 0.194, \"Chord\": \"C#/Db\"}, {\"Index\": 401, \"Highest Charting Position\": 63, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Otra Noche Sin Ti\", \"Streams\": 5377794, \"Artist\": \"J Balvin, Khalid\", \"Artist Followers\": 29051363.0, \"Song ID\": \"2CdTLdDjwZdVcm0bresVWx\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 80.0, \"Danceability\": 0.503, \"Energy\": 0.548, \"Loudness\": -7.564, \"Speechiness\": 0.164, \"Acousticness\": 0.0751, \"Liveness\": 0.145, \"Tempo\": 94.036, \"Duration (ms)\": 228920.0, \"Valence\": 0.441, \"Chord\": \"C\"}, {\"Index\": 402, \"Highest Charting Position\": 33, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Met Him Last Night (feat. Ariana Grande)\", \"Streams\": 5200695, \"Artist\": \"Demi Lovato\", \"Artist Followers\": 20331923.0, \"Song ID\": \"0BI0hfbmqybnd3TezrDME3\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 72.0, \"Danceability\": 0.538, \"Energy\": 0.512, \"Loudness\": -4.548, \"Speechiness\": 0.0262, \"Acousticness\": 0.22, \"Liveness\": 0.101, \"Tempo\": 144.978, \"Duration (ms)\": 204632.0, \"Valence\": 0.12, \"Chord\": \"E\"}, {\"Index\": 403, \"Highest Charting Position\": 100, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Back In Blood (feat. Lil Durk)\", \"Streams\": 5198209, \"Artist\": \"Pooh Shiesty\", \"Artist Followers\": 423237.0, \"Song ID\": \"7JuHVG3qQKQKxC4doneXVW\", \"Genre\": \"['memphis hip hop', 'rap', 'southern hip hop', 'tennessee hip hop', 'trap']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 75.0, \"Danceability\": 0.759, \"Energy\": 0.538, \"Loudness\": -8.256, \"Speechiness\": 0.384, \"Acousticness\": 0.151, \"Liveness\": 0.126, \"Tempo\": 146.933, \"Duration (ms)\": 184490.0, \"Valence\": 0.831, \"Chord\": \"G#/Ab\"}, {\"Index\": 404, \"Highest Charting Position\": 94, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Run It Up (feat. Offset & Moneybagg Yo)\", \"Streams\": 5107084, \"Artist\": \"Lil Tjay\", \"Artist Followers\": 3553442.0, \"Song ID\": \"1dg3qy5DjoJodawfOCgrTP\", \"Genre\": \"['brooklyn drill', 'melodic rap', 'nyc rap']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 81.0, \"Danceability\": 0.88, \"Energy\": 0.575, \"Loudness\": -6.091, \"Speechiness\": 0.163, \"Acousticness\": 0.415, \"Liveness\": 0.109, \"Tempo\": 120.031, \"Duration (ms)\": 232048.0, \"Valence\": 0.671, \"Chord\": \"F#/Gb\"}, {\"Index\": 405, \"Highest Charting Position\": 37, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Mi Ni\\u00f1a\", \"Streams\": 5026961, \"Artist\": \"Wisin, Myke Towers, Los Legendarios\", \"Artist Followers\": 6929075.0, \"Song ID\": \"2bgcUk2A3jjKbCJ7KPquTi\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-23\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 79.0, \"Danceability\": 0.823, \"Energy\": 0.821, \"Loudness\": -3.402, \"Speechiness\": 0.166, \"Acousticness\": 0.31, \"Liveness\": 0.143, \"Tempo\": 99.999, \"Duration (ms)\": 213314.0, \"Valence\": 0.791, \"Chord\": \"G#/Ab\"}, {\"Index\": 406, \"Highest Charting Position\": 9, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"As I Am (feat. Khalid)\", \"Streams\": 5896065, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6F2r4HgpJnvKDmkN6JEN6J\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 72.0, \"Danceability\": 0.595, \"Energy\": 0.543, \"Loudness\": -8.149, \"Speechiness\": 0.038, \"Acousticness\": 0.127, \"Liveness\": 0.0975, \"Tempo\": 99.928, \"Duration (ms)\": 174406.0, \"Valence\": 0.109, \"Chord\": \"B\"}, {\"Index\": 407, \"Highest Charting Position\": 150, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Come Through (feat. Chris Brown)\", \"Streams\": 5531998, \"Artist\": \"H.E.R.\", \"Artist Followers\": 4138951.0, \"Song ID\": \"3krZxyBsWEHfEfJegYaWTd\", \"Genre\": \"['alternative r&b', 'dance pop', 'pop', 'r&b']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-04-23--2021-04-30\", \"Popularity\": 74.0, \"Danceability\": 0.615, \"Energy\": 0.422, \"Loudness\": -8.019, \"Speechiness\": 0.0504, \"Acousticness\": 0.604, \"Liveness\": 0.112, \"Tempo\": 135.859, \"Duration (ms)\": 214094.0, \"Valence\": 0.185, \"Chord\": \"F\"}, {\"Index\": 408, \"Highest Charting Position\": 33, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Goosebumps\", \"Streams\": 5496962, \"Artist\": \"HVME\", \"Artist Followers\": 17719446.0, \"Song ID\": \"5uEYRdEIh9Bo4fpjDd4Na9\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 87.0, \"Danceability\": 0.841, \"Energy\": 0.593, \"Loudness\": -7.846, \"Speechiness\": 0.0379, \"Acousticness\": 0.418, \"Liveness\": 0.124, \"Tempo\": 124.917, \"Duration (ms)\": 162803.0, \"Valence\": 0.808, \"Chord\": \"C#/Db\"}, {\"Index\": 409, \"Highest Charting Position\": 18, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Put Your Records On\", \"Streams\": 5181180, \"Artist\": \"Ritt Momney\", \"Artist Followers\": 100463.0, \"Song ID\": \"6AGOKlMZWLCaEJGnaROtF9\", \"Genre\": \"['bedroom pop']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 81.0, \"Danceability\": 0.399, \"Energy\": 0.491, \"Loudness\": -10.778, \"Speechiness\": 0.0538, \"Acousticness\": 0.0563, \"Liveness\": 0.11, \"Tempo\": 91.066, \"Duration (ms)\": 210463.0, \"Valence\": 0.151, \"Chord\": \"F#/Gb\"}, {\"Index\": 410, \"Highest Charting Position\": 137, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Facas - Ao Vivo\", \"Streams\": 5141640, \"Artist\": \"Diego & Victor Hugo, Bruno & Marrone\", \"Artist Followers\": 1585593.0, \"Song ID\": \"1ere9b9vDw2N3m9d4uiXxa\", \"Genre\": \"['sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2020-10-15\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 79.0, \"Danceability\": 0.443, \"Energy\": 0.509, \"Loudness\": -5.995, \"Speechiness\": 0.0536, \"Acousticness\": 0.615, \"Liveness\": 0.472, \"Tempo\": 160.984, \"Duration (ms)\": 196380.0, \"Valence\": 0.69, \"Chord\": \"D\"}, {\"Index\": 411, \"Highest Charting Position\": 62, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Train Wreck\", \"Streams\": 5081800, \"Artist\": \"James Arthur\", \"Artist Followers\": 8446147.0, \"Song ID\": \"55Am8neGJkdj2ADaM3aw5H\", \"Genre\": \"['pop', 'post-teen pop', 'talent show', 'uk pop']\", \"Release Date\": \"2016-10-28\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 82.0, \"Danceability\": 0.311, \"Energy\": 0.485, \"Loudness\": -5.726, \"Speechiness\": 0.0365, \"Acousticness\": 0.701, \"Liveness\": 0.0726, \"Tempo\": 77.355, \"Duration (ms)\": 208827.0, \"Valence\": 0.225, \"Chord\": \"F#/Gb\"}, {\"Index\": 412, \"Highest Charting Position\": 7, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Monster (Shawn Mendes & Justin Bieber)\", \"Streams\": 5069268, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 33893352.0, \"Song ID\": \"2Z8yfpFX0ZMavHkcIeHiO1\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 79.0, \"Danceability\": 0.652, \"Energy\": 0.383, \"Loudness\": -7.076, \"Speechiness\": 0.0516, \"Acousticness\": 0.0676, \"Liveness\": 0.0828, \"Tempo\": 145.765, \"Duration (ms)\": 178994.0, \"Valence\": 0.549, \"Chord\": \"D\"}, {\"Index\": 413, \"Highest Charting Position\": 6, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"In Your Eyes\", \"Streams\": 5054319, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"7szuecWAPwGoV1e5vGu8tl\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 81.0, \"Danceability\": 0.667, \"Energy\": 0.719, \"Loudness\": -5.371, \"Speechiness\": 0.0346, \"Acousticness\": 0.00285, \"Liveness\": 0.0736, \"Tempo\": 100.021, \"Duration (ms)\": 237520.0, \"Valence\": 0.717, \"Chord\": \"G\"}, {\"Index\": 414, \"Highest Charting Position\": 101, \"Number of Times Charted\": 68, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"SAD!\", \"Streams\": 5051338, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"3ee8Jmje8o58CHK66QrVC2\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2018-03-16\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.74, \"Energy\": 0.613, \"Loudness\": -4.88, \"Speechiness\": 0.145, \"Acousticness\": 0.258, \"Liveness\": 0.123, \"Tempo\": 75.023, \"Duration (ms)\": 166606.0, \"Valence\": 0.473, \"Chord\": \"G#/Ab\"}, {\"Index\": 415, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Good Without\", \"Streams\": 4998044, \"Artist\": \"Mimi Webb\", \"Artist Followers\": 130801.0, \"Song ID\": \"15OCqNPYoLziEAsbVnqRj5\", \"Genre\": \"['alt z', 'indie cafe pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-04-23--2021-04-30\", \"Popularity\": 81.0, \"Danceability\": 0.616, \"Energy\": 0.576, \"Loudness\": -5.495, \"Speechiness\": 0.0532, \"Acousticness\": 0.0723, \"Liveness\": 0.375, \"Tempo\": 89.962, \"Duration (ms)\": 182121.0, \"Valence\": 0.269, \"Chord\": \"B\"}, {\"Index\": 416, \"Highest Charting Position\": 19, \"Number of Times Charted\": 66, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"hot girl bummer\", \"Streams\": 4992396, \"Artist\": \"blackbear\", \"Artist Followers\": 4270131.0, \"Song ID\": \"2mt1IqcFyY1zmYZT8Q3xw9\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.782, \"Energy\": 0.559, \"Loudness\": -7.106, \"Speechiness\": 0.0767, \"Acousticness\": 0.125, \"Liveness\": 0.385, \"Tempo\": 129.992, \"Duration (ms)\": 188344.0, \"Valence\": 0.685, \"Chord\": \"F#/Gb\"}, {\"Index\": 417, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"When I Was Your Man\", \"Streams\": 4945935, \"Artist\": \"Bruno Mars\", \"Artist Followers\": 32603394.0, \"Song ID\": \"0nJW01T7XtvILxQgC5J7Wh\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2012-12-07\", \"Weeks Charted\": \"2021-04-23--2021-04-30\", \"Popularity\": 82.0, \"Danceability\": 0.612, \"Energy\": 0.28, \"Loudness\": -8.648, \"Speechiness\": 0.0434, \"Acousticness\": 0.932, \"Liveness\": 0.088, \"Tempo\": 72.795, \"Duration (ms)\": 213827.0, \"Valence\": 0.387, \"Chord\": \"C\"}, {\"Index\": 418, \"Highest Charting Position\": 73, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"LOCATION\", \"Streams\": 4940701, \"Artist\": \"KAROL G, Anuel AA, J Balvin\", \"Artist Followers\": 1250353.0, \"Song ID\": \"1aH3EQY5LTXjRZQLpl1Gby\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 0.0, \"Danceability\": 0.772, \"Energy\": 0.758, \"Loudness\": -3.891, \"Speechiness\": 0.0482, \"Acousticness\": 0.0433, \"Liveness\": 0.295, \"Tempo\": 115.977, \"Duration (ms)\": 265240.0, \"Valence\": 0.654, \"Chord\": \"A\"}, {\"Index\": 419, \"Highest Charting Position\": 177, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Stressed Out\", \"Streams\": 4913147, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20823062.0, \"Song ID\": \"3CRDbSIZ4r5MsZ0YwxuEkn\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2015-05-15\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 83.0, \"Danceability\": 0.734, \"Energy\": 0.637, \"Loudness\": -5.677, \"Speechiness\": 0.141, \"Acousticness\": 0.0462, \"Liveness\": 0.0602, \"Tempo\": 169.977, \"Duration (ms)\": 202333.0, \"Valence\": 0.648, \"Chord\": \"E\"}, {\"Index\": 420, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Ski\", \"Streams\": 7753784, \"Artist\": \"Young Stoner Life, Young Thug, Gunna\", \"Artist Followers\": 61930.0, \"Song ID\": \"6755DFiZ7CWe2WMdTGW5C1\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-04-16--2021-04-23\", \"Popularity\": 78.0, \"Danceability\": 0.953, \"Energy\": 0.621, \"Loudness\": -7.638, \"Speechiness\": 0.221, \"Acousticness\": 0.017, \"Liveness\": 0.0398, \"Tempo\": 123.016, \"Duration (ms)\": 152333.0, \"Valence\": 0.883, \"Chord\": \"G#/Ab\"}, {\"Index\": 421, \"Highest Charting Position\": 75, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Diamonds Dancing (feat. Travis Scott)\", \"Streams\": 7515766, \"Artist\": \"Young Stoner Life, Young Thug, Gunna\", \"Artist Followers\": 61930.0, \"Song ID\": \"7uZqvqXzzYMKrexKxdcGmd\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-04-16--2021-04-23\", \"Popularity\": 69.0, \"Danceability\": 0.851, \"Energy\": 0.703, \"Loudness\": -7.351, \"Speechiness\": 0.303, \"Acousticness\": 0.00949, \"Liveness\": 0.0895, \"Tempo\": 74.017, \"Duration (ms)\": 242600.0, \"Valence\": 0.596, \"Chord\": \"E\"}, {\"Index\": 422, \"Highest Charting Position\": 8, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Love Story (Taylor\\u2019s Version)\", \"Streams\": 6202933, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6YvqWjhGD8mB5QXcbcUKtx\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 73.0, \"Danceability\": 0.627, \"Energy\": 0.792, \"Loudness\": -4.311, \"Speechiness\": 0.031, \"Acousticness\": 0.13, \"Liveness\": 0.0845, \"Tempo\": 119.054, \"Duration (ms)\": 235767.0, \"Valence\": 0.415, \"Chord\": \"D\"}, {\"Index\": 423, \"Highest Charting Position\": 107, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Ele \\u00c9 Ele, Eu Sou Eu\", \"Streams\": 5380517, \"Artist\": \"Wesley Safad\\u00e3o, Os Bar\\u00f5es Da Pisadinha\", \"Artist Followers\": 9907270.0, \"Song ID\": \"7EWXP47VlXKO3r7mNxuWHw\", \"Genre\": \"['forro']\", \"Release Date\": \"2020-11-12\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 73.0, \"Danceability\": 0.758, \"Energy\": 0.763, \"Loudness\": -8.754, \"Speechiness\": 0.0768, \"Acousticness\": 0.23, \"Liveness\": 0.0703, \"Tempo\": 163.946, \"Duration (ms)\": 155210.0, \"Valence\": 0.854, \"Chord\": \"C#/Db\"}, {\"Index\": 424, \"Highest Charting Position\": 186, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Quero Ver \\u00e9 Me Esquecer (feat. Jorge) - Ao Vivo\", \"Streams\": 5159208, \"Artist\": \"Os Bar\\u00f5es Da Pisadinha\", \"Artist Followers\": 4271775.0, \"Song ID\": \"2SUPbyD77tJuOUbqbxct6l\", \"Genre\": \"['forro', 'piseiro']\", \"Release Date\": \"2021-02-19\", \"Weeks Charted\": \"2021-04-16--2021-04-23\", \"Popularity\": 80.0, \"Danceability\": 0.593, \"Energy\": 0.932, \"Loudness\": -2.324, \"Speechiness\": 0.0526, \"Acousticness\": 0.302, \"Liveness\": 0.133, \"Tempo\": 171.977, \"Duration (ms)\": 147876.0, \"Valence\": 0.913, \"Chord\": \"G#/Ab\"}, {\"Index\": 425, \"Highest Charting Position\": 3, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"willow\", \"Streams\": 5016865, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0lx2cLdOt3piJbcaXIV74f\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 79.0, \"Danceability\": 0.392, \"Energy\": 0.574, \"Loudness\": -9.195, \"Speechiness\": 0.17, \"Acousticness\": 0.833, \"Liveness\": 0.145, \"Tempo\": 81.112, \"Duration (ms)\": 214707.0, \"Valence\": 0.529, \"Chord\": \"G\"}, {\"Index\": 426, \"Highest Charting Position\": 104, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Why'd You Only Call Me When You're High?\", \"Streams\": 4976405, \"Artist\": \"Arctic Monkeys\", \"Artist Followers\": 12375514.0, \"Song ID\": \"086myS9r57YsLbJpU0TgK9\", \"Genre\": \"['garage rock', 'permanent wave', 'rock', 'sheffield indie']\", \"Release Date\": \"2013-09-09\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 82.0, \"Danceability\": 0.691, \"Energy\": 0.631, \"Loudness\": -6.478, \"Speechiness\": 0.0368, \"Acousticness\": 0.0483, \"Liveness\": 0.104, \"Tempo\": 92.004, \"Duration (ms)\": 161124.0, \"Valence\": 0.8, \"Chord\": \"D\"}, {\"Index\": 427, \"Highest Charting Position\": 18, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Afterglow\", \"Streams\": 4965330, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 1250353.0, \"Song ID\": \"5dA45onYgYACRp8C5xEOS9\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\", \"Popularity\": 0.0, \"Danceability\": 0.641, \"Energy\": 0.324, \"Loudness\": -5.851, \"Speechiness\": 0.0299, \"Acousticness\": 0.698, \"Liveness\": 0.328, \"Tempo\": 110.184, \"Duration (ms)\": 185487.0, \"Valence\": 0.273, \"Chord\": \"B\"}, {\"Index\": 428, \"Highest Charting Position\": 43, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"LA CANCI\\u00d3N\", \"Streams\": 4959754, \"Artist\": \"J Balvin, Bad Bunny\", \"Artist Followers\": 29051363.0, \"Song ID\": \"0fea68AdmYNygeTGI4RC18\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.754, \"Energy\": 0.646, \"Loudness\": -5.795, \"Speechiness\": 0.317, \"Acousticness\": 0.152, \"Liveness\": 0.108, \"Tempo\": 176.089, \"Duration (ms)\": 242573.0, \"Valence\": 0.429, \"Chord\": \"G\"}, {\"Index\": 429, \"Highest Charting Position\": 52, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"You Belong With Me (Taylor\\u2019s Version)\", \"Streams\": 9872084, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1qrpoAMXodY6895hGKoUpA\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 73.0, \"Danceability\": 0.632, \"Energy\": 0.773, \"Loudness\": -4.856, \"Speechiness\": 0.0346, \"Acousticness\": 0.0623, \"Liveness\": 0.0885, \"Tempo\": 130.033, \"Duration (ms)\": 231124.0, \"Valence\": 0.474, \"Chord\": \"F#/Gb\"}, {\"Index\": 430, \"Highest Charting Position\": 54, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Fearless (Taylor\\u2019s Version)\", \"Streams\": 9676024, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"77sMIMlNaSURUAXq5coCxE\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 69.0, \"Danceability\": 0.569, \"Energy\": 0.741, \"Loudness\": -4.963, \"Speechiness\": 0.0282, \"Acousticness\": 0.0122, \"Liveness\": 0.333, \"Tempo\": 100.118, \"Duration (ms)\": 241592.0, \"Valence\": 0.43, \"Chord\": \"F\"}, {\"Index\": 431, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"X Gon' Give It To Ya\", \"Streams\": 8638360, \"Artist\": \"DMX\", \"Artist Followers\": 2815928.0, \"Song ID\": \"1zzxoZVylsna2BQB65Ppcb\", \"Genre\": \"['east coast hip hop', 'gangster rap', 'hardcore hip hop', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2007-06-12\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 73.0, \"Danceability\": 0.761, \"Energy\": 0.899, \"Loudness\": -3.09, \"Speechiness\": 0.183, \"Acousticness\": 0.0135, \"Liveness\": 0.0719, \"Tempo\": 95.027, \"Duration (ms)\": 217587.0, \"Valence\": 0.673, \"Chord\": \"A#/Bb\"}, {\"Index\": 432, \"Highest Charting Position\": 80, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Fifteen (Taylor\\u2019s Version)\", \"Streams\": 7852063, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2nqio0SfWg6gh2eCtfuMa5\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 66.0, \"Danceability\": 0.559, \"Energy\": 0.646, \"Loudness\": -4.61, \"Speechiness\": 0.0272, \"Acousticness\": 0.116, \"Liveness\": 0.32, \"Tempo\": 95.466, \"Duration (ms)\": 294419.0, \"Valence\": 0.289, \"Chord\": \"G\"}, {\"Index\": 433, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"The Way I Loved You (Taylor\\u2019s Version)\", \"Streams\": 7736262, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"22bPsP2jCgbLUvh82U0Z3M\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 72.0, \"Danceability\": 0.402, \"Energy\": 0.732, \"Loudness\": -4.665, \"Speechiness\": 0.0484, \"Acousticness\": 0.0033, \"Liveness\": 0.108, \"Tempo\": 161.032, \"Duration (ms)\": 243137.0, \"Valence\": 0.472, \"Chord\": \"F\"}, {\"Index\": 434, \"Highest Charting Position\": 51, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"You All Over Me (feat. Maren Morris) (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 7712896, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5pcjystBtalYeqaiXCcgEY\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 65.0, \"Danceability\": 0.589, \"Energy\": 0.496, \"Loudness\": -7.606, \"Speechiness\": 0.0377, \"Acousticness\": 0.818, \"Liveness\": 0.101, \"Tempo\": 142.731, \"Duration (ms)\": 220839.0, \"Valence\": 0.44, \"Chord\": \"D\"}, {\"Index\": 435, \"Highest Charting Position\": 93, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Hey Stephen (Taylor\\u2019s Version)\", \"Streams\": 7385864, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"550erGcdD9n6PnwxrvYqZT\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 66.0, \"Danceability\": 0.788, \"Energy\": 0.571, \"Loudness\": -6.135, \"Speechiness\": 0.0296, \"Acousticness\": 0.106, \"Liveness\": 0.0934, \"Tempo\": 115.99, \"Duration (ms)\": 254255.0, \"Valence\": 0.797, \"Chord\": \"F#/Gb\"}, {\"Index\": 436, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"White Horse (Taylor\\u2019s Version)\", \"Streams\": 7039222, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5YL553x8sHderRBDlm3NM3\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 65.0, \"Danceability\": 0.423, \"Energy\": 0.517, \"Loudness\": -7.377, \"Speechiness\": 0.0486, \"Acousticness\": 0.369, \"Liveness\": 0.177, \"Tempo\": 185.262, \"Duration (ms)\": 234516.0, \"Valence\": 0.366, \"Chord\": \"C\"}, {\"Index\": 437, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Forever & Always (Taylor\\u2019s Version)\", \"Streams\": 6566059, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1msEuwSBneBKpVCZQcFTsU\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 66.0, \"Danceability\": 0.598, \"Energy\": 0.821, \"Loudness\": -4.433, \"Speechiness\": 0.0447, \"Acousticness\": 0.0231, \"Liveness\": 0.143, \"Tempo\": 128.03, \"Duration (ms)\": 225328.0, \"Valence\": 0.673, \"Chord\": \"A#/Bb\"}, {\"Index\": 438, \"Highest Charting Position\": 119, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Breathe (feat. Colbie Caillat) (Taylor\\u2019s Version)\", \"Streams\": 6508683, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7HC7R2D8WjXVcUHJyEGjRs\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 64.0, \"Danceability\": 0.506, \"Energy\": 0.626, \"Loudness\": -6.066, \"Speechiness\": 0.0287, \"Acousticness\": 0.156, \"Liveness\": 0.228, \"Tempo\": 148.035, \"Duration (ms)\": 263377.0, \"Valence\": 0.321, \"Chord\": \"C#/Db\"}, {\"Index\": 439, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Ruff Ryders' Anthem\", \"Streams\": 5988511, \"Artist\": \"DMX\", \"Artist Followers\": 2815928.0, \"Song ID\": \"1BKT2I9x4RGKaKqW4up34s\", \"Genre\": \"['east coast hip hop', 'gangster rap', 'hardcore hip hop', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"1998-05-01\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 72.0, \"Danceability\": 0.88, \"Energy\": 0.577, \"Loudness\": -8.093, \"Speechiness\": 0.302, \"Acousticness\": 0.0564, \"Liveness\": 0.201, \"Tempo\": 90.991, \"Duration (ms)\": 214440.0, \"Valence\": 0.74, \"Chord\": \"A#/Bb\"}, {\"Index\": 440, \"Highest Charting Position\": 146, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"That\\u2019s When (feat. Keith Urban) (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5889939, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7eResoqEJJAVTkQYSqvO3P\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 67.0, \"Danceability\": 0.588, \"Energy\": 0.608, \"Loudness\": -7.062, \"Speechiness\": 0.0365, \"Acousticness\": 0.225, \"Liveness\": 0.092, \"Tempo\": 90.201, \"Duration (ms)\": 189496.0, \"Valence\": 0.508, \"Chord\": \"F\"}, {\"Index\": 441, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Tell Me Why (Taylor\\u2019s Version)\", \"Streams\": 5885151, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0k0vFacOHNuArLWMiH60p7\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 63.0, \"Danceability\": 0.578, \"Energy\": 0.909, \"Loudness\": -3.669, \"Speechiness\": 0.0628, \"Acousticness\": 0.0222, \"Liveness\": 0.333, \"Tempo\": 100.023, \"Duration (ms)\": 200576.0, \"Valence\": 0.541, \"Chord\": \"G\"}, {\"Index\": 442, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"You\\u2019re Not Sorry (Taylor\\u2019s Version)\", \"Streams\": 5860405, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6iiAfo4wTA2CVC3Uwx9uh8\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 64.0, \"Danceability\": 0.506, \"Energy\": 0.444, \"Loudness\": -4.99, \"Speechiness\": 0.0285, \"Acousticness\": 0.0538, \"Liveness\": 0.123, \"Tempo\": 133.873, \"Duration (ms)\": 261843.0, \"Valence\": 0.241, \"Chord\": \"F#/Gb\"}, {\"Index\": 443, \"Highest Charting Position\": 40, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Chica Ideal\", \"Streams\": 5217052, \"Artist\": \"Sebastian Yatra, Guaynaa\", \"Artist Followers\": 1250353.0, \"Song ID\": \"6M3Bdl5UtQtmjnYDW69LZQ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 0.0, \"Danceability\": 0.574, \"Energy\": 0.891, \"Loudness\": -3.665, \"Speechiness\": 0.157, \"Acousticness\": 0.0847, \"Liveness\": 0.16, \"Tempo\": 100.978, \"Duration (ms)\": 183240.0, \"Valence\": 0.707, \"Chord\": \"C\"}, {\"Index\": 444, \"Highest Charting Position\": 15, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Relaci\\u00f3n - Remix\", \"Streams\": 5206614, \"Artist\": \"Sech, Daddy Yankee, J Balvin, ROSAL\\u00cdA, Farruko\", \"Artist Followers\": 8758283.0, \"Song ID\": \"35UUpTmrcFXNIVIN26ujXl\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 80.0, \"Danceability\": 0.793, \"Energy\": 0.771, \"Loudness\": -3.417, \"Speechiness\": 0.0959, \"Acousticness\": 0.0337, \"Liveness\": 0.284, \"Tempo\": 171.943, \"Duration (ms)\": 247308.0, \"Valence\": 0.835, \"Chord\": \"F\"}, {\"Index\": 445, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Don\\u2019t You (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5197564, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"4uuEGH5SVuzkkSFjo2DEiY\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 65.0, \"Danceability\": 0.563, \"Energy\": 0.473, \"Loudness\": -11.548, \"Speechiness\": 0.0503, \"Acousticness\": 0.514, \"Liveness\": 0.109, \"Tempo\": 101.934, \"Duration (ms)\": 208609.0, \"Valence\": 0.405, \"Chord\": \"D#/Eb\"}, {\"Index\": 446, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"We Were Happy (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5189423, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"34V9RiEPe8MNdU32qJsJa1\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 64.0, \"Danceability\": 0.609, \"Energy\": 0.373, \"Loudness\": -8.819, \"Speechiness\": 0.0263, \"Acousticness\": 0.849, \"Liveness\": 0.0779, \"Tempo\": 106.007, \"Duration (ms)\": 244237.0, \"Valence\": 0.13, \"Chord\": \"C\"}, {\"Index\": 447, \"Highest Charting Position\": 153, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"WACHA\", \"Streams\": 5172999, \"Artist\": \"KHEA, Duki\", \"Artist Followers\": 3198705.0, \"Song ID\": \"5RmSunLqeDqNWww8LWhAiK\", \"Genre\": \"['argentine hip hop', 'trap argentino', 'trap latino', 'trap triste']\", \"Release Date\": \"2021-04-01\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 75.0, \"Danceability\": 0.737, \"Energy\": 0.634, \"Loudness\": -4.25, \"Speechiness\": 0.0424, \"Acousticness\": 0.345, \"Liveness\": 0.111, \"Tempo\": 94.927, \"Duration (ms)\": 206360.0, \"Valence\": 0.528, \"Chord\": \"D#/Eb\"}, {\"Index\": 448, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Dancing With The Devil\", \"Streams\": 5836326, \"Artist\": \"Demi Lovato\", \"Artist Followers\": 20338833.0, \"Song ID\": \"2kONpeXXK70YEs7c0UQbmq\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-04-02--2021-04-09\", \"Popularity\": 66.0, \"Danceability\": 0.413, \"Energy\": 0.64, \"Loudness\": -5.811, \"Speechiness\": 0.0427, \"Acousticness\": 0.273, \"Liveness\": 0.11, \"Tempo\": 75.245, \"Duration (ms)\": 243992.0, \"Valence\": 0.149, \"Chord\": \"G#/Ab\"}, {\"Index\": 449, \"Highest Charting Position\": 26, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Gone\", \"Streams\": 5427638, \"Artist\": \"ROS\\u00c9\", \"Artist Followers\": 1099480.0, \"Song ID\": \"2dHoVW9AxJVSRebPRyV2aA\", \"Genre\": \"[]\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 71.0, \"Danceability\": 0.647, \"Energy\": 0.377, \"Loudness\": -6.003, \"Speechiness\": 0.0375, \"Acousticness\": 0.594, \"Liveness\": 0.0768, \"Tempo\": 79.936, \"Duration (ms)\": 207164.0, \"Valence\": 0.653, \"Chord\": \"F#/Gb\"}, {\"Index\": 450, \"Highest Charting Position\": 160, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"What Other People Say\", \"Streams\": 5413003, \"Artist\": \"Sam Fischer, Demi Lovato\", \"Artist Followers\": 122746.0, \"Song ID\": \"2h9TDNEXRhcDIV3fsoEVq9\", \"Genre\": \"['alt z', 'australian pop', 'dance pop', 'indie cafe pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2021-02-04\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\", \"Popularity\": 77.0, \"Danceability\": 0.652, \"Energy\": 0.472, \"Loudness\": -8.084, \"Speechiness\": 0.0399, \"Acousticness\": 0.158, \"Liveness\": 0.121, \"Tempo\": 126.904, \"Duration (ms)\": 194890.0, \"Valence\": 0.24, \"Chord\": \"G\"}, {\"Index\": 451, \"Highest Charting Position\": 88, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Hello (feat. A Boogie Wit da Hoodie)\", \"Streams\": 5323062, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"2r6OAV3WsYtXuXjvJ1lIDi\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-20\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 82.0, \"Danceability\": 0.905, \"Energy\": 0.647, \"Loudness\": -5.065, \"Speechiness\": 0.107, \"Acousticness\": 0.0187, \"Liveness\": 0.282, \"Tempo\": 130.97, \"Duration (ms)\": 190534.0, \"Valence\": 0.367, \"Chord\": \"A#/Bb\"}, {\"Index\": 452, \"Highest Charting Position\": 91, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Hasta Abajo\", \"Streams\": 5269163, \"Artist\": \"Kevin Roldan, Bryant Myers, Lyanno\", \"Artist Followers\": 4026643.0, \"Song ID\": \"4PEfJZpVjdclfzZ9XO8uDw\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'reggaeton colombiano', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 77.0, \"Danceability\": 0.714, \"Energy\": 0.671, \"Loudness\": -5.119, \"Speechiness\": 0.362, \"Acousticness\": 0.289, \"Liveness\": 0.325, \"Tempo\": 169.732, \"Duration (ms)\": 229827.0, \"Valence\": 0.641, \"Chord\": \"F\"}, {\"Index\": 453, \"Highest Charting Position\": 30, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Take You Dancing\", \"Streams\": 5176493, \"Artist\": \"Jason Derulo\", \"Artist Followers\": 9778632.0, \"Song ID\": \"59qrUpoplZxbIZxk6X0Bm3\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2020-07-22\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 82.0, \"Danceability\": 0.789, \"Energy\": 0.711, \"Loudness\": -4.248, \"Speechiness\": 0.041, \"Acousticness\": 0.0332, \"Liveness\": 0.0876, \"Tempo\": 112.985, \"Duration (ms)\": 190306.0, \"Valence\": 0.753, \"Chord\": \"D\"}, {\"Index\": 454, \"Highest Charting Position\": 28, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Unstable (feat. The Kid LAROI)\", \"Streams\": 5137645, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"137mSruegm1u6x9NvwiagR\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 74.0, \"Danceability\": 0.495, \"Energy\": 0.333, \"Loudness\": -10.109, \"Speechiness\": 0.0288, \"Acousticness\": 0.737, \"Liveness\": 0.112, \"Tempo\": 99.757, \"Duration (ms)\": 158324.0, \"Valence\": 0.37, \"Chord\": \"E\"}, {\"Index\": 455, \"Highest Charting Position\": 2, \"Number of Times Charted\": 48, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Stuck with U (with Justin Bieber)\", \"Streams\": 5094660, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"4HBZA5flZLE435QTztThqH\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 84.0, \"Danceability\": 0.597, \"Energy\": 0.45, \"Loudness\": -6.658, \"Speechiness\": 0.0418, \"Acousticness\": 0.223, \"Liveness\": 0.382, \"Tempo\": 178.765, \"Duration (ms)\": 228482.0, \"Valence\": 0.537, \"Chord\": \"G#/Ab\"}, {\"Index\": 456, \"Highest Charting Position\": 120, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Hayloft\", \"Streams\": 5086382, \"Artist\": \"Mother Mother\", \"Artist Followers\": 2110870.0, \"Song ID\": \"2kS6td1yvmpNgZTt1q5pQq\", \"Genre\": \"['indie pop', 'vancouver indie']\", \"Release Date\": \"2008-09-23\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 81.0, \"Danceability\": 0.527, \"Energy\": 0.922, \"Loudness\": -2.666, \"Speechiness\": 0.0728, \"Acousticness\": 0.00475, \"Liveness\": 0.422, \"Tempo\": 95.975, \"Duration (ms)\": 181680.0, \"Valence\": 0.49, \"Chord\": \"A\"}, {\"Index\": 457, \"Highest Charting Position\": 191, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Esquema Preferido (feat. Tarc\\u00edsio do Acordeon)\", \"Streams\": 5078174, \"Artist\": \"DJ Ivis\", \"Artist Followers\": 342930.0, \"Song ID\": \"0e6NlGJxYlHvAN8SKxad7N\", \"Genre\": \"['piseiro']\", \"Release Date\": \"2020-11-26\", \"Weeks Charted\": \"2021-04-02--2021-04-09\", \"Popularity\": 73.0, \"Danceability\": 0.676, \"Energy\": 0.823, \"Loudness\": -4.386, \"Speechiness\": 0.102, \"Acousticness\": 0.242, \"Liveness\": 0.0773, \"Tempo\": 160.013, \"Duration (ms)\": 190680.0, \"Valence\": 0.907, \"Chord\": \"F\"}, {\"Index\": 458, \"Highest Charting Position\": 75, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Adem\\u00e1s de M\\u00ed - Remix\", \"Streams\": 5060336, \"Artist\": \"Rusherking, KHEA, Duki, Maria Becerra, LIT killah, Tiago PZK\", \"Artist Followers\": 301217.0, \"Song ID\": \"7I8L3vYCLThw2FDrE6LuzE\", \"Genre\": \"['trap argentino', 'trap latino', 'trap triste']\", \"Release Date\": \"2021-03-04\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 78.0, \"Danceability\": 0.397, \"Energy\": 0.613, \"Loudness\": -5.077, \"Speechiness\": 0.0549, \"Acousticness\": 0.0396, \"Liveness\": 0.192, \"Tempo\": 78.4, \"Duration (ms)\": 330040.0, \"Valence\": 0.405, \"Chord\": \"F#/Gb\"}, {\"Index\": 459, \"Highest Charting Position\": 193, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Payphone\", \"Streams\": 5052717, \"Artist\": \"Maroon 5, Wiz Khalifa\", \"Artist Followers\": 32279979.0, \"Song ID\": \"1LmN9SSHISbtp9LoaR5ZVJ\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2012-01-01\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 74.0, \"Danceability\": 0.739, \"Energy\": 0.756, \"Loudness\": -4.828, \"Speechiness\": 0.0394, \"Acousticness\": 0.0136, \"Liveness\": 0.37, \"Tempo\": 110.028, \"Duration (ms)\": 231387.0, \"Valence\": 0.523, \"Chord\": \"E\"}, {\"Index\": 460, \"Highest Charting Position\": 50, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Ghost\", \"Streams\": 5013450, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6I3mqTwhRpn34SLVafSH7G\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 71.0, \"Danceability\": 0.601, \"Energy\": 0.741, \"Loudness\": -5.569, \"Speechiness\": 0.0478, \"Acousticness\": 0.185, \"Liveness\": 0.415, \"Tempo\": 153.96, \"Duration (ms)\": 153190.0, \"Valence\": 0.441, \"Chord\": \"D\"}, {\"Index\": 461, \"Highest Charting Position\": 37, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Off My Face\", \"Streams\": 5004111, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"3T03rPwlL8NVk1yIaxeD8U\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 75.0, \"Danceability\": 0.509, \"Energy\": 0.228, \"Loudness\": -8.68, \"Speechiness\": 0.0332, \"Acousticness\": 0.92, \"Liveness\": 0.104, \"Tempo\": 90.674, \"Duration (ms)\": 156468.0, \"Valence\": 0.586, \"Chord\": \"E\"}, {\"Index\": 462, \"Highest Charting Position\": 140, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Whats Poppin (feat. DaBaby, Tory Lanez & Lil Wayne) [Remix] - Bonus Track\", \"Streams\": 4972518, \"Artist\": \"Jack Harlow\", \"Artist Followers\": 1053324.0, \"Song ID\": \"0ZLuW8uOXdFNWcI40C0OC2\", \"Genre\": \"['deep underground hip hop', 'kentucky hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\", \"Popularity\": 73.0, \"Danceability\": 0.904, \"Energy\": 0.723, \"Loudness\": -5.224, \"Speechiness\": 0.26, \"Acousticness\": 0.0631, \"Liveness\": 0.185, \"Tempo\": 145.013, \"Duration (ms)\": 227478.0, \"Valence\": 0.835, \"Chord\": \"B\"}, {\"Index\": 463, \"Highest Charting Position\": 188, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Take on Me\", \"Streams\": 4969662, \"Artist\": \"a-ha\", \"Artist Followers\": 1560784.0, \"Song ID\": \"2WfaOiMkCvy7F5fcp2zZ8L\", \"Genre\": \"['new romantic', 'new wave', 'new wave pop', 'permanent wave', 'soft rock', 'synthpop']\", \"Release Date\": \"1985-06-01\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 84.0, \"Danceability\": 0.573, \"Energy\": 0.902, \"Loudness\": -7.638, \"Speechiness\": 0.054, \"Acousticness\": 0.018, \"Liveness\": 0.0928, \"Tempo\": 84.412, \"Duration (ms)\": 225280.0, \"Valence\": 0.876, \"Chord\": \"F#/Gb\"}, {\"Index\": 464, \"Highest Charting Position\": 45, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"BEB\\u00c9\", \"Streams\": 4967348, \"Artist\": \"Camilo, El Alfa\", \"Artist Followers\": 10580764.0, \"Song ID\": \"7D7EH7MGyNHWSkqrszerI1\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-11-25\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 78.0, \"Danceability\": 0.862, \"Energy\": 0.72, \"Loudness\": -4.048, \"Speechiness\": 0.0379, \"Acousticness\": 0.487, \"Liveness\": 0.0604, \"Tempo\": 129.972, \"Duration (ms)\": 198707.0, \"Valence\": 0.965, \"Chord\": \"E\"}, {\"Index\": 465, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Richer (feat. Polo G)\", \"Streams\": 6292362, \"Artist\": \"Rod Wave\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-03-26--2021-04-02\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 466, \"Highest Charting Position\": 128, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Tu Veneno\", \"Streams\": 6007541, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"5KFHrrBMyGj5MhVbZMM3ts\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 76.0, \"Danceability\": 0.664, \"Energy\": 0.659, \"Loudness\": -4.232, \"Speechiness\": 0.0873, \"Acousticness\": 0.0625, \"Liveness\": 0.0874, \"Tempo\": 175.826, \"Duration (ms)\": 157320.0, \"Valence\": 0.797, \"Chord\": \"A#/Bb\"}, {\"Index\": 467, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Deserve You\", \"Streams\": 5837372, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5NU40QTlXrDUJzDBdv79bg\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 69.0, \"Danceability\": 0.677, \"Energy\": 0.633, \"Loudness\": -7.831, \"Speechiness\": 0.0771, \"Acousticness\": 0.0314, \"Liveness\": 0.112, \"Tempo\": 89.934, \"Duration (ms)\": 187239.0, \"Valence\": 0.409, \"Chord\": \"G\"}, {\"Index\": 468, \"Highest Charting Position\": 44, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"2 Much\", \"Streams\": 5794583, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"0oaY19dUwZimIgzn3ZZLZO\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 70.0, \"Danceability\": 0.583, \"Energy\": 0.444, \"Loudness\": -8.601, \"Speechiness\": 0.0456, \"Acousticness\": 0.593, \"Liveness\": 0.353, \"Tempo\": 119.59, \"Duration (ms)\": 152796.0, \"Valence\": 0.167, \"Chord\": \"A\"}, {\"Index\": 469, \"Highest Charting Position\": 3, \"Number of Times Charted\": 66, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Tusa\", \"Streams\": 5510113, \"Artist\": \"KAROL G, Nicki Minaj\", \"Artist Followers\": 17792779.0, \"Song ID\": \"7k4t7uLgtOxPwTpFmtJNTY\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.803, \"Energy\": 0.715, \"Loudness\": -3.28, \"Speechiness\": 0.298, \"Acousticness\": 0.295, \"Liveness\": 0.0574, \"Tempo\": 101.085, \"Duration (ms)\": 200960.0, \"Valence\": 0.574, \"Chord\": \"D\"}, {\"Index\": 470, \"Highest Charting Position\": 34, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Una Locura\", \"Streams\": 5466954, \"Artist\": \"Ozuna, J Balvin, Chencho Corleone\", \"Artist Followers\": 29238936.0, \"Song ID\": \"5y7DaS3jAc9eZzcSOoUIwU\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 81.0, \"Danceability\": 0.714, \"Energy\": 0.761, \"Loudness\": -4.596, \"Speechiness\": 0.0427, \"Acousticness\": 0.139, \"Liveness\": 0.241, \"Tempo\": 168.022, \"Duration (ms)\": 230693.0, \"Valence\": 0.906, \"Chord\": \"F\"}, {\"Index\": 471, \"Highest Charting Position\": 61, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Loved By You (feat. Burna Boy)\", \"Streams\": 5419040, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2tB9OFgAHjAds3cqquLlvp\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 69.0, \"Danceability\": 0.79, \"Energy\": 0.724, \"Loudness\": -6.972, \"Speechiness\": 0.0852, \"Acousticness\": 0.0696, \"Liveness\": 0.113, \"Tempo\": 101.04, \"Duration (ms)\": 159250.0, \"Valence\": 0.642, \"Chord\": \"C#/Db\"}, {\"Index\": 472, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Girls Like Us\", \"Streams\": 5410730, \"Artist\": \"Zoe Wees\", \"Artist Followers\": 203555.0, \"Song ID\": \"5SFXOMJJ334Wn2PwBHeRZN\", \"Genre\": \"['german pop']\", \"Release Date\": \"2021-01-12\", \"Weeks Charted\": \"2021-03-26--2021-04-02\", \"Popularity\": 78.0, \"Danceability\": 0.444, \"Energy\": 0.648, \"Loudness\": -4.955, \"Speechiness\": 0.0476, \"Acousticness\": 0.288, \"Liveness\": 0.059, \"Tempo\": 125.706, \"Duration (ms)\": 189000.0, \"Valence\": 0.171, \"Chord\": \"C#/Db\"}, {\"Index\": 473, \"Highest Charting Position\": 17, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Lemon Pepper Freestyle (feat. Rick Ross)\", \"Streams\": 5365747, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"4FRW5Nza1Ym91BGV4nFWXI\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 76.0, \"Danceability\": 0.77, \"Energy\": 0.637, \"Loudness\": -5.53, \"Speechiness\": 0.345, \"Acousticness\": 0.103, \"Liveness\": 0.171, \"Tempo\": 94.966, \"Duration (ms)\": 383037.0, \"Valence\": 0.431, \"Chord\": \"C#/Db\"}, {\"Index\": 474, \"Highest Charting Position\": 97, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Esquema Preferido\", \"Streams\": 5356696, \"Artist\": \"DJ Ivis, Tarc\\u00edsio do Acordeon\", \"Artist Followers\": 342930.0, \"Song ID\": \"0e6NlGJxYlHvAN8SKxad7N\", \"Genre\": \"['piseiro']\", \"Release Date\": \"2020-11-26\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 73.0, \"Danceability\": 0.676, \"Energy\": 0.823, \"Loudness\": -4.386, \"Speechiness\": 0.102, \"Acousticness\": 0.242, \"Liveness\": 0.0773, \"Tempo\": 160.013, \"Duration (ms)\": 190680.0, \"Valence\": 0.907, \"Chord\": \"F\"}, {\"Index\": 475, \"Highest Charting Position\": 105, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Love Not War (The Tampa Beat)\", \"Streams\": 5326719, \"Artist\": \"Jason Derulo, Nuka\", \"Artist Followers\": 9778632.0, \"Song ID\": \"4Lt6GXGzYsa1tgkv3nGSTm\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 79.0, \"Danceability\": 0.738, \"Energy\": 0.85, \"Loudness\": -3.049, \"Speechiness\": 0.0642, \"Acousticness\": 0.105, \"Liveness\": 0.23, \"Tempo\": 98.013, \"Duration (ms)\": 192921.0, \"Valence\": 0.865, \"Chord\": \"G#/Ab\"}, {\"Index\": 476, \"Highest Charting Position\": 57, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Die For You (feat. Dominic Fike)\", \"Streams\": 5323412, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"7aely3H8kMj9o0gt6vXHE1\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 67.0, \"Danceability\": 0.728, \"Energy\": 0.629, \"Loudness\": -6.629, \"Speechiness\": 0.0318, \"Acousticness\": 0.00196, \"Liveness\": 0.0847, \"Tempo\": 135.031, \"Duration (ms)\": 198426.0, \"Valence\": 0.71, \"Chord\": \"C#/Db\"}, {\"Index\": 477, \"Highest Charting Position\": 64, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Starboy\", \"Streams\": 5302285, \"Artist\": \"The Weeknd, Daft Punk\", \"Artist Followers\": 35340069.0, \"Song ID\": \"7MXVkk9YMctZqd1Srtv4MB\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2016-11-25\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 83.0, \"Danceability\": 0.679, \"Energy\": 0.587, \"Loudness\": -7.015, \"Speechiness\": 0.276, \"Acousticness\": 0.141, \"Liveness\": 0.137, \"Tempo\": 186.003, \"Duration (ms)\": 230453.0, \"Valence\": 0.486, \"Chord\": \"G\"}, {\"Index\": 478, \"Highest Charting Position\": 22, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"La T\\u00f3xica\", \"Streams\": 5255393, \"Artist\": \"Farruko\", \"Artist Followers\": 10510156.0, \"Song ID\": \"15OjBeqNX3bShsGYQbteRv\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 78.0, \"Danceability\": 0.659, \"Energy\": 0.701, \"Loudness\": -4.107, \"Speechiness\": 0.164, \"Acousticness\": 0.0882, \"Liveness\": 0.0866, \"Tempo\": 91.97, \"Duration (ms)\": 180520.0, \"Valence\": 0.623, \"Chord\": \"A\"}, {\"Index\": 479, \"Highest Charting Position\": 181, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Cora\\u00e7\\u00e3o Na Cama - Ao Vivo\", \"Streams\": 5211351, \"Artist\": \"Hugo & Guilherme\", \"Artist Followers\": 435936.0, \"Song ID\": \"2nZj5YymF54qhAu7RneVP6\", \"Genre\": \"['sertanejo pop']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 77.0, \"Danceability\": 0.764, \"Energy\": 0.794, \"Loudness\": -4.096, \"Speechiness\": 0.0589, \"Acousticness\": 0.663, \"Liveness\": 0.34, \"Tempo\": 110.013, \"Duration (ms)\": 173227.0, \"Valence\": 0.721, \"Chord\": \"G#/Ab\"}, {\"Index\": 480, \"Highest Charting Position\": 60, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Love You Different (feat. BEAM)\", \"Streams\": 10024729, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"27UcQ6dAvQrgH9C880rCM3\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-19--2021-03-26\", \"Popularity\": 66.0, \"Danceability\": 0.759, \"Energy\": 0.584, \"Loudness\": -6.655, \"Speechiness\": 0.06, \"Acousticness\": 0.0652, \"Liveness\": 0.16, \"Tempo\": 127.138, \"Duration (ms)\": 186696.0, \"Valence\": 0.374, \"Chord\": \"G#/Ab\"}, {\"Index\": 481, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Somebody\", \"Streams\": 8912458, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"3rLIv187BhjyweFe89SgLn\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2010-01-01\", \"Weeks Charted\": \"2021-03-19--2021-03-26\", \"Popularity\": 67.0, \"Danceability\": 0.714, \"Energy\": 0.833, \"Loudness\": -5.239, \"Speechiness\": 0.0259, \"Acousticness\": 0.00249, \"Liveness\": 0.298, \"Tempo\": 129.964, \"Duration (ms)\": 220920.0, \"Valence\": 0.663, \"Chord\": \"F\"}, {\"Index\": 482, \"Highest Charting Position\": 152, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"White Dress\", \"Streams\": 5796978, \"Artist\": \"Lana Del Rey\", \"Artist Followers\": 13697048.0, \"Song ID\": \"4Hl9rOqYomojCmxYfr25im\", \"Genre\": \"['art pop', 'pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-19--2021-03-26\", \"Popularity\": 65.0, \"Danceability\": 0.493, \"Energy\": 0.263, \"Loudness\": -12.805, \"Speechiness\": 0.0351, \"Acousticness\": 0.926, \"Liveness\": 0.0879, \"Tempo\": 122.792, \"Duration (ms)\": 333710.0, \"Valence\": 0.158, \"Chord\": \"C\"}, {\"Index\": 483, \"Highest Charting Position\": 82, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Polvo\", \"Streams\": 5528508, \"Artist\": \"Nicky Jam, Myke Towers\", \"Artist Followers\": 14831925.0, \"Song ID\": \"68mrW6gXHgupgSiDHgaDi5\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 76.0, \"Danceability\": 0.763, \"Energy\": 0.621, \"Loudness\": -6.169, \"Speechiness\": 0.066, \"Acousticness\": 0.0105, \"Liveness\": 0.106, \"Tempo\": 82.042, \"Duration (ms)\": 211130.0, \"Valence\": 0.582, \"Chord\": \"B\"}, {\"Index\": 484, \"Highest Charting Position\": 138, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Chemtrails Over The Country Club\", \"Streams\": 5418816, \"Artist\": \"Lana Del Rey\", \"Artist Followers\": 13697048.0, \"Song ID\": \"7bPWdJgx8vek7S5i5yAtvG\", \"Genre\": \"['art pop', 'pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-01-15--2021-01-22\", \"Popularity\": 73.0, \"Danceability\": 0.334, \"Energy\": 0.276, \"Loudness\": -13.125, \"Speechiness\": 0.0643, \"Acousticness\": 0.877, \"Liveness\": 0.113, \"Tempo\": 201.025, \"Duration (ms)\": 271177.0, \"Valence\": 0.429, \"Chord\": \"E\"}, {\"Index\": 485, \"Highest Charting Position\": 37, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Parce (feat. Justin Quiles)\", \"Streams\": 5312876, \"Artist\": \"Maluma, Lenny Tav\\u00e1rez\", \"Artist Followers\": 26769304.0, \"Song ID\": \"4RJz8NfIe09gpKMiRUWKhJ\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 78.0, \"Danceability\": 0.691, \"Energy\": 0.739, \"Loudness\": -3.09, \"Speechiness\": 0.229, \"Acousticness\": 0.422, \"Liveness\": 0.11, \"Tempo\": 83.897, \"Duration (ms)\": 248345.0, \"Valence\": 0.884, \"Chord\": \"F\"}, {\"Index\": 486, \"Highest Charting Position\": 40, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Ropa Cara\", \"Streams\": 5249427, \"Artist\": \"Camilo\", \"Artist Followers\": 10580764.0, \"Song ID\": \"7BIy3EGQhg98CsRdKYHnJC\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2021-01-18\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 73.0, \"Danceability\": 0.813, \"Energy\": 0.526, \"Loudness\": -4.787, \"Speechiness\": 0.125, \"Acousticness\": 0.105, \"Liveness\": 0.11, \"Tempo\": 170.002, \"Duration (ms)\": 163320.0, \"Valence\": 0.608, \"Chord\": \"E\"}, {\"Index\": 487, \"Highest Charting Position\": 25, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Vida de Rico\", \"Streams\": 5189822, \"Artist\": \"Camilo\", \"Artist Followers\": 10580764.0, \"Song ID\": \"73nAK3HgQK8dak83Y2WQ8F\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-09-21\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 79.0, \"Danceability\": 0.824, \"Energy\": 0.457, \"Loudness\": -5.428, \"Speechiness\": 0.0543, \"Acousticness\": 0.167, \"Liveness\": 0.041, \"Tempo\": 87.977, \"Duration (ms)\": 187427.0, \"Valence\": 0.95, \"Chord\": \"F#/Gb\"}, {\"Index\": 488, \"Highest Charting Position\": 182, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Devil Eyes\", \"Streams\": 5098581, \"Artist\": \"Hippie Sabotage\", \"Artist Followers\": 713486.0, \"Song ID\": \"7MiZjKawmXTsTNePyTfPyL\", \"Genre\": \"['edm', 'electronic trap']\", \"Release Date\": \"2016-02-05\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 80.0, \"Danceability\": 0.391, \"Energy\": 0.396, \"Loudness\": -8.621, \"Speechiness\": 0.189, \"Acousticness\": 0.702, \"Liveness\": 0.315, \"Tempo\": 99.112, \"Duration (ms)\": 131272.0, \"Valence\": 0.199, \"Chord\": \"C#/Db\"}, {\"Index\": 489, \"Highest Charting Position\": 141, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Ponte Pa' Mi\", \"Streams\": 5082870, \"Artist\": \"Justin Quiles\", \"Artist Followers\": 2897862.0, \"Song ID\": \"4C6BlqqMwjFzOXzqpTeoWR\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 76.0, \"Danceability\": 0.878, \"Energy\": 0.713, \"Loudness\": -4.566, \"Speechiness\": 0.0948, \"Acousticness\": 0.0581, \"Liveness\": 0.0822, \"Tempo\": 92.028, \"Duration (ms)\": 202373.0, \"Valence\": 0.615, \"Chord\": \"F\"}, {\"Index\": 490, \"Highest Charting Position\": 109, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"D\\u00e1melo To\\u2019 (feat. Myke Towers)\", \"Streams\": 6426522, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"36CiGk9oRdwTnBDMgKEfjl\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 64.0, \"Danceability\": 0.787, \"Energy\": 0.641, \"Loudness\": -7.376, \"Speechiness\": 0.315, \"Acousticness\": 0.101, \"Liveness\": 0.07, \"Tempo\": 182.003, \"Duration (ms)\": 184134.0, \"Valence\": 0.437, \"Chord\": \"G#/Ab\"}, {\"Index\": 491, \"Highest Charting Position\": 121, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Patience (feat. YUNGBLUD & Polo G)\", \"Streams\": 6155698, \"Artist\": \"KSI\", \"Artist Followers\": 2010879.0, \"Song ID\": \"5J5CpT6bgE6KYKk23jgp9W\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 71.0, \"Danceability\": 0.616, \"Energy\": 0.741, \"Loudness\": -4.272, \"Speechiness\": 0.0426, \"Acousticness\": 0.00251, \"Liveness\": 0.307, \"Tempo\": 122.012, \"Duration (ms)\": 181720.0, \"Valence\": 0.431, \"Chord\": \"G\"}, {\"Index\": 492, \"Highest Charting Position\": 56, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Selfish Love (with Selena Gomez)\", \"Streams\": 6020785, \"Artist\": \"DJ Snake\", \"Artist Followers\": 7408249.0, \"Song ID\": \"3XoflnowYPFRPOh3uFvHcm\", \"Genre\": \"['dance pop', 'edm', 'electronic trap', 'pop', 'pop dance']\", \"Release Date\": \"2021-03-04\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 74.0, \"Danceability\": 0.723, \"Energy\": 0.646, \"Loudness\": -7.973, \"Speechiness\": 0.102, \"Acousticness\": 0.0206, \"Liveness\": 0.0994, \"Tempo\": 110.971, \"Duration (ms)\": 168649.0, \"Valence\": 0.443, \"Chord\": \"F\"}, {\"Index\": 493, \"Highest Charting Position\": 12, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Snowman\", \"Streams\": 5454807, \"Artist\": \"Sia\", \"Artist Followers\": 20528724.0, \"Song ID\": \"7uoFMmxln0GPXQ0AcCBXRq\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'pop']\", \"Release Date\": \"2018-11-01\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 77.0, \"Danceability\": 0.716, \"Energy\": 0.512, \"Loudness\": -6.257, \"Speechiness\": 0.0331, \"Acousticness\": 0.483, \"Liveness\": 0.0928, \"Tempo\": 104.957, \"Duration (ms)\": 165907.0, \"Valence\": 0.326, \"Chord\": \"C#/Db\"}, {\"Index\": 494, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"DAYWALKER! (feat. CORPSE)\", \"Streams\": 5439646, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3868320.0, \"Song ID\": \"2NnJpRXIlx35Vij3bPZO0h\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 74.0, \"Danceability\": 0.632, \"Energy\": 0.922, \"Loudness\": -2.173, \"Speechiness\": 0.0794, \"Acousticness\": 0.00558, \"Liveness\": 0.0927, \"Tempo\": 88.972, \"Duration (ms)\": 137747.0, \"Valence\": 0.497, \"Chord\": \"G\"}, {\"Index\": 495, \"Highest Charting Position\": 19, \"Number of Times Charted\": 38, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"La Curiosidad\", \"Streams\": 5198514, \"Artist\": \"Jay Wheeler, DJ Nelson, Myke Towers\", \"Artist Followers\": 1650912.0, \"Song ID\": \"4HYDUMY0xSpeBr0AMY9cUz\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 82.0, \"Danceability\": 0.845, \"Energy\": 0.677, \"Loudness\": -4.798, \"Speechiness\": 0.136, \"Acousticness\": 0.269, \"Liveness\": 0.108, \"Tempo\": 90.013, \"Duration (ms)\": 219048.0, \"Valence\": 0.68, \"Chord\": \"B\"}, {\"Index\": 496, \"Highest Charting Position\": 86, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"All We Got (feat. KIDDO)\", \"Streams\": 5156937, \"Artist\": \"Robin Schulz\", \"Artist Followers\": 2786366.0, \"Song ID\": \"1FP9s72rDYty6mfoOEYKnE\", \"Genre\": \"['dance pop', 'deep euro house', 'deep house', 'edm', 'german dance', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 74.0, \"Danceability\": 0.504, \"Energy\": 0.76, \"Loudness\": -4.246, \"Speechiness\": 0.0426, \"Acousticness\": 0.286, \"Liveness\": 0.151, \"Tempo\": 183.933, \"Duration (ms)\": 190218.0, \"Valence\": 0.64, \"Chord\": \"E\"}, {\"Index\": 497, \"Highest Charting Position\": 6, \"Number of Times Charted\": 60, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Say So\", \"Streams\": 5103528, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"3Dv1eDb0MEgF93GpLXlucZ\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-02-26--2021-03-05\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.787, \"Energy\": 0.673, \"Loudness\": -4.583, \"Speechiness\": 0.159, \"Acousticness\": 0.264, \"Liveness\": 0.0904, \"Tempo\": 110.962, \"Duration (ms)\": 237893.0, \"Valence\": 0.779, \"Chord\": \"B\"}, {\"Index\": 498, \"Highest Charting Position\": 157, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Hope\", \"Streams\": 5085527, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"2ZRo7axmMPeSVUvDbGkJah\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2018-03-16\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 84.0, \"Danceability\": 0.592, \"Energy\": 0.457, \"Loudness\": -6.081, \"Speechiness\": 0.0603, \"Acousticness\": 0.661, \"Liveness\": 0.146, \"Tempo\": 146.04, \"Duration (ms)\": 110886.0, \"Valence\": 0.225, \"Chord\": \"A\"}, {\"Index\": 499, \"Highest Charting Position\": 149, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"The Less I Know The Better\", \"Streams\": 5084635, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"6K4t31amVTZDgR3sKmwUJJ\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2015-07-17\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-01-03--2020-01-10\", \"Popularity\": 84.0, \"Danceability\": 0.64, \"Energy\": 0.74, \"Loudness\": -4.083, \"Speechiness\": 0.0284, \"Acousticness\": 0.0115, \"Liveness\": 0.167, \"Tempo\": 116.879, \"Duration (ms)\": 216320.0, \"Valence\": 0.785, \"Chord\": \"E\"}, {\"Index\": 500, \"Highest Charting Position\": 109, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"I Feel It Coming\", \"Streams\": 5079857, \"Artist\": \"The Weeknd, Daft Punk\", \"Artist Followers\": 35340069.0, \"Song ID\": \"3dhjNA0jGA8vHBQ1VdD6vV\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2016-11-25\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 80.0, \"Danceability\": 0.773, \"Energy\": 0.819, \"Loudness\": -5.946, \"Speechiness\": 0.118, \"Acousticness\": 0.428, \"Liveness\": 0.0679, \"Tempo\": 92.987, \"Duration (ms)\": 269187.0, \"Valence\": 0.585, \"Chord\": \"C\"}, {\"Index\": 501, \"Highest Charting Position\": 12, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Mood Swings (feat. Lil Tjay)\", \"Streams\": 5068349, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"5rZlwNFl01HqLWBQGryKSm\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 82.0, \"Danceability\": 0.48, \"Energy\": 0.602, \"Loudness\": -6.335, \"Speechiness\": 0.368, \"Acousticness\": 0.487, \"Liveness\": 0.0848, \"Tempo\": 179.798, \"Duration (ms)\": 213333.0, \"Valence\": 0.269, \"Chord\": \"A#/Bb\"}, {\"Index\": 502, \"Highest Charting Position\": 123, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Someone To You\", \"Streams\": 5054881, \"Artist\": \"BANNERS\", \"Artist Followers\": 419151.0, \"Song ID\": \"2f0pn9DkEJwAzXApnFh5cr\", \"Genre\": \"['indie cafe pop', 'indie poptimism', 'modern rock', 'pop', 'pop rock']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 79.0, \"Danceability\": 0.52, \"Energy\": 0.903, \"Loudness\": -5.497, \"Speechiness\": 0.042, \"Acousticness\": 0.00517, \"Liveness\": 0.254, \"Tempo\": 74.988, \"Duration (ms)\": 219801.0, \"Valence\": 0.652, \"Chord\": \"D\"}, {\"Index\": 503, \"Highest Charting Position\": 198, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"To the Bone\", \"Streams\": 5052557, \"Artist\": \"Pamungkas\", \"Artist Followers\": 1643882.0, \"Song ID\": \"3pCt2wRdBDa2kCisIdHWgF\", \"Genre\": \"['indonesian pop']\", \"Release Date\": \"2019-06-14\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 81.0, \"Danceability\": 0.668, \"Energy\": 0.727, \"Loudness\": -6.55, \"Speechiness\": 0.027, \"Acousticness\": 0.514, \"Liveness\": 0.1, \"Tempo\": 139.991, \"Duration (ms)\": 344571.0, \"Valence\": 0.939, \"Chord\": \"G\"}, {\"Index\": 504, \"Highest Charting Position\": 4, \"Number of Times Charted\": 38, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"How You Like That\", \"Streams\": 5023592, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"4SFknyjLcyTLJFPKD2m96o\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 79.0, \"Danceability\": 0.812, \"Energy\": 0.761, \"Loudness\": -5.222, \"Speechiness\": 0.0812, \"Acousticness\": 0.0465, \"Liveness\": 0.0601, \"Tempo\": 130.032, \"Duration (ms)\": 182956.0, \"Valence\": 0.344, \"Chord\": \"B\"}, {\"Index\": 505, \"Highest Charting Position\": 200, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"LOST\", \"Streams\": 5013851, \"Artist\": \"NF, Hopsin\", \"Artist Followers\": 5831194.0, \"Song ID\": \"2MZrOmrVxRmmOoFW6dhenG\", \"Genre\": \"['hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2021-03-11\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 66.0, \"Danceability\": 0.637, \"Energy\": 0.912, \"Loudness\": -3.123, \"Speechiness\": 0.308, \"Acousticness\": 0.352, \"Liveness\": 0.0657, \"Tempo\": 116.919, \"Duration (ms)\": 234852.0, \"Valence\": 0.451, \"Chord\": \"F\"}, {\"Index\": 506, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"VOCE\", \"Streams\": 5510906, \"Artist\": \"Madame\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6CAVxdHTkls5loqUmfM52V\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 0.0, \"Danceability\": 0.615, \"Energy\": 0.834, \"Loudness\": -5.471, \"Speechiness\": 0.0667, \"Acousticness\": 0.105, \"Liveness\": 0.157, \"Tempo\": 112.602, \"Duration (ms)\": 211411.0, \"Valence\": 0.341, \"Chord\": \"G#/Ab\"}, {\"Index\": 507, \"Highest Charting Position\": 64, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"AP - Music from the film Boogie\", \"Streams\": 5462333, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"17vGPZ5EsdvtgAOCD4FLWI\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\", \"Popularity\": 75.0, \"Danceability\": 0.751, \"Energy\": 0.744, \"Loudness\": -6.859, \"Speechiness\": 0.177, \"Acousticness\": 0.152, \"Liveness\": 0.252, \"Tempo\": 148.014, \"Duration (ms)\": 171892.0, \"Valence\": 0.634, \"Chord\": \"C#/Db\"}, {\"Index\": 508, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Life's A Mess II (with Clever & Post Malone)\", \"Streams\": 5393459, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4O3RwH1TFG1EjPezLIYehI\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 72.0, \"Danceability\": 0.53, \"Energy\": 0.37, \"Loudness\": -9.989, \"Speechiness\": 0.0279, \"Acousticness\": 0.806, \"Liveness\": 0.112, \"Tempo\": 140.061, \"Duration (ms)\": 206734.0, \"Valence\": 0.701, \"Chord\": \"F#/Gb\"}, {\"Index\": 509, \"Highest Charting Position\": 170, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"CHIAMAMI PER NOME\", \"Streams\": 5321946, \"Artist\": \"Francesca Michielin, Fedez\", \"Artist Followers\": 568711.0, \"Song ID\": \"0ZqHo6eTBHUcOVjZzPvftT\", \"Genre\": \"['italian adult pop', 'italian indie pop', 'italian pop', 'italian pop rock']\", \"Release Date\": \"2021-03-03\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 67.0, \"Danceability\": 0.641, \"Energy\": 0.636, \"Loudness\": -4.318, \"Speechiness\": 0.0414, \"Acousticness\": 0.289, \"Liveness\": 0.125, \"Tempo\": 89.826, \"Duration (ms)\": 222667.0, \"Valence\": 0.285, \"Chord\": \"A#/Bb\"}, {\"Index\": 510, \"Highest Charting Position\": 54, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Antes\", \"Streams\": 5232377, \"Artist\": \"Anuel AA, Ozuna\", \"Artist Followers\": 18306226.0, \"Song ID\": \"73O30uMI7n6DuzBmbtO7kC\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 73.0, \"Danceability\": 0.817, \"Energy\": 0.737, \"Loudness\": -5.453, \"Speechiness\": 0.102, \"Acousticness\": 0.046, \"Liveness\": 0.092, \"Tempo\": 93.985, \"Duration (ms)\": 206587.0, \"Valence\": 0.67, \"Chord\": \"F#/Gb\"}, {\"Index\": 511, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Mona Lisa\", \"Streams\": 5208787, \"Artist\": \"Booba, JSX\", \"Artist Followers\": 2161609.0, \"Song ID\": \"5LYRIyhmlrDAQsYdHEvP0f\", \"Genre\": \"['french hip hop', 'old school rap francais', 'pop urbaine', 'rap conscient']\", \"Release Date\": \"2021-03-04\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 72.0, \"Danceability\": 0.784, \"Energy\": 0.529, \"Loudness\": -7.681, \"Speechiness\": 0.0742, \"Acousticness\": 0.683, \"Liveness\": 0.118, \"Tempo\": 134.041, \"Duration (ms)\": 187362.0, \"Valence\": 0.246, \"Chord\": \"B\"}, {\"Index\": 512, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Real As It Gets (feat. EST Gee)\", \"Streams\": 5170861, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"7eX3um6NpOQKWJMGCi97XD\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2021-03-04\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 74.0, \"Danceability\": 0.779, \"Energy\": 0.705, \"Loudness\": -5.891, \"Speechiness\": 0.163, \"Acousticness\": 0.00471, \"Liveness\": 0.0971, \"Tempo\": 140.005, \"Duration (ms)\": 192804.0, \"Valence\": 0.196, \"Chord\": \"F#/Gb\"}, {\"Index\": 513, \"Highest Charting Position\": 24, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Se Te Nota (with Guaynaa)\", \"Streams\": 5168240, \"Artist\": \"Lele Pons\", \"Artist Followers\": 786461.0, \"Song ID\": \"11EnQRgRMJwMAesfkB5pnu\", \"Genre\": \"['latin pop', 'viral pop']\", \"Release Date\": \"2020-09-02\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 77.0, \"Danceability\": 0.905, \"Energy\": 0.686, \"Loudness\": -3.152, \"Speechiness\": 0.0664, \"Acousticness\": 0.0907, \"Liveness\": 0.266, \"Tempo\": 103.013, \"Duration (ms)\": 155825.0, \"Valence\": 0.963, \"Chord\": \"C\"}, {\"Index\": 514, \"Highest Charting Position\": 91, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Head Shoulders Knees & Toes (feat. Norma Jean Martine)\", \"Streams\": 5093408, \"Artist\": \"Ofenbach, Quarterhead\", \"Artist Followers\": 432511.0, \"Song ID\": \"6i7zAdNhzUN2k1HcrBxPHG\", \"Genre\": \"['edm', 'new french touch', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 79.0, \"Danceability\": 0.798, \"Energy\": 0.828, \"Loudness\": -5.36, \"Speechiness\": 0.193, \"Acousticness\": 0.0247, \"Liveness\": 0.121, \"Tempo\": 124.962, \"Duration (ms)\": 156960.0, \"Valence\": 0.6, \"Chord\": \"D\"}, {\"Index\": 515, \"Highest Charting Position\": 152, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Star Shopping\", \"Streams\": 5073657, \"Artist\": \"Lil Peep\", \"Artist Followers\": 7535054.0, \"Song ID\": \"30bqVoKjX479ab90a8Pafp\", \"Genre\": \"['emo rap', 'lgbtq+ hip hop']\", \"Release Date\": \"2015\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 82.0, \"Danceability\": 0.585, \"Energy\": 0.471, \"Loudness\": -9.934, \"Speechiness\": 0.0616, \"Acousticness\": 0.0967, \"Liveness\": 0.115, \"Tempo\": 93.099, \"Duration (ms)\": 142000.0, \"Valence\": 0.323, \"Chord\": \"E\"}, {\"Index\": 516, \"Highest Charting Position\": 61, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Electric Love\", \"Streams\": 5060903, \"Artist\": \"B\\u00d8RNS\", \"Artist Followers\": 1027085.0, \"Song ID\": \"2GiJYvgVaD2HtM8GqD9EgQ\", \"Genre\": \"['modern alternative rock', 'modern rock', 'pop']\", \"Release Date\": \"2015-10-16\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 83.0, \"Danceability\": 0.611, \"Energy\": 0.797, \"Loudness\": -7.627, \"Speechiness\": 0.0533, \"Acousticness\": 0.00543, \"Liveness\": 0.26, \"Tempo\": 120.041, \"Duration (ms)\": 218107.0, \"Valence\": 0.518, \"Chord\": \"F#/Gb\"}, {\"Index\": 517, \"Highest Charting Position\": 112, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Maniac\", \"Streams\": 5044929, \"Artist\": \"Conan Gray\", \"Artist Followers\": 3799104.0, \"Song ID\": \"6KfoDhO4XUWSbnyKjNp9c4\", \"Genre\": \"['alt z', 'bedroom pop', 'electropop', 'indie pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.628, \"Energy\": 0.639, \"Loudness\": -5.46, \"Speechiness\": 0.0435, \"Acousticness\": 0.00162, \"Liveness\": 0.354, \"Tempo\": 108.045, \"Duration (ms)\": 185773.0, \"Valence\": 0.493, \"Chord\": \"G#/Ab\"}, {\"Index\": 518, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Only Wanna Be With You - Pok\\u00e9mon 25 Version\", \"Streams\": 7464020, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"3SawmGBjjq8EOYZJV11cJm\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2021-02-25\", \"Weeks Charted\": \"2021-02-26--2021-03-05\", \"Popularity\": 72.0, \"Danceability\": 0.47, \"Energy\": 0.709, \"Loudness\": -4.563, \"Speechiness\": 0.0299, \"Acousticness\": 0.00124, \"Liveness\": 0.302, \"Tempo\": 98.036, \"Duration (ms)\": 241360.0, \"Valence\": 0.247, \"Chord\": \"G\"}, {\"Index\": 519, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"test drive\", \"Streams\": 6591829, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3eZYOQO4UzKrUDYDghtnFw\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-02-19\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 71.0, \"Danceability\": 0.698, \"Energy\": 0.708, \"Loudness\": -4.943, \"Speechiness\": 0.0454, \"Acousticness\": 0.0251, \"Liveness\": 0.124, \"Tempo\": 115.036, \"Duration (ms)\": 122174.0, \"Valence\": 0.322, \"Chord\": \"A\"}, {\"Index\": 520, \"Highest Charting Position\": 42, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"T\\u00fa Me Dejaste De Querer\", \"Streams\": 5874460, \"Artist\": \"C. Tangana, Ni\\u00f1o de Elche, La H\\u00fangara\", \"Artist Followers\": 1453875.0, \"Song ID\": \"5ddFjrPG8NgQQ6xlOQIVd2\", \"Genre\": \"['urbano espanol']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 75.0, \"Danceability\": 0.823, \"Energy\": 0.723, \"Loudness\": -4.778, \"Speechiness\": 0.229, \"Acousticness\": 0.311, \"Liveness\": 0.0998, \"Tempo\": 83.97, \"Duration (ms)\": 198493.0, \"Valence\": 0.505, \"Chord\": \"E\"}, {\"Index\": 521, \"Highest Charting Position\": 46, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"SO DONE\", \"Streams\": 5440707, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"5psEZhQu6lukjhavJo4AbC\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-10-23\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 74.0, \"Danceability\": 0.719, \"Energy\": 0.598, \"Loudness\": -6.254, \"Speechiness\": 0.077, \"Acousticness\": 0.232, \"Liveness\": 0.115, \"Tempo\": 142.592, \"Duration (ms)\": 126521.0, \"Valence\": 0.303, \"Chord\": \"A\"}, {\"Index\": 522, \"Highest Charting Position\": 35, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Jeans\", \"Streams\": 5145966, \"Artist\": \"Justin Quiles\", \"Artist Followers\": 2897862.0, \"Song ID\": \"3GtnId3Cm1Xa6joCj08nzW\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 75.0, \"Danceability\": 0.807, \"Energy\": 0.656, \"Loudness\": -4.395, \"Speechiness\": 0.105, \"Acousticness\": 0.0165, \"Liveness\": 0.0693, \"Tempo\": 83.943, \"Duration (ms)\": 185840.0, \"Valence\": 0.89, \"Chord\": \"D#/Eb\"}, {\"Index\": 523, \"Highest Charting Position\": 2, \"Number of Times Charted\": 61, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"ROXANNE\", \"Streams\": 5124742, \"Artist\": \"Arizona Zervas\", \"Artist Followers\": 621200.0, \"Song ID\": \"696DnlkuDOXcMAnKlTgXXK\", \"Genre\": \"['pop rap', 'rhode island rap']\", \"Release Date\": \"2019-10-10\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.621, \"Energy\": 0.601, \"Loudness\": -5.616, \"Speechiness\": 0.148, \"Acousticness\": 0.0522, \"Liveness\": 0.46, \"Tempo\": 116.735, \"Duration (ms)\": 163636.0, \"Valence\": 0.457, \"Chord\": \"F#/Gb\"}, {\"Index\": 524, \"Highest Charting Position\": 83, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"rockstar (feat. 21 Savage)\", \"Streams\": 5115990, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"0e7ipj03S05BNilyu5bRzt\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2018-04-27\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-01-29--2021-02-05\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.585, \"Energy\": 0.52, \"Loudness\": -6.136, \"Speechiness\": 0.0712, \"Acousticness\": 0.124, \"Liveness\": 0.131, \"Tempo\": 159.801, \"Duration (ms)\": 218147.0, \"Valence\": 0.129, \"Chord\": \"F\"}, {\"Index\": 525, \"Highest Charting Position\": 185, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"P\\u00e1rteme La Cara\", \"Streams\": 5079580, \"Artist\": \"C. Tangana, Ed Maverick\", \"Artist Followers\": 1453875.0, \"Song ID\": \"5gEUDNQvoQjdjklrwPdGwD\", \"Genre\": \"['urbano espanol']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-02-26--2021-03-05\", \"Popularity\": 70.0, \"Danceability\": 0.761, \"Energy\": 0.296, \"Loudness\": -10.22, \"Speechiness\": 0.0484, \"Acousticness\": 0.551, \"Liveness\": 0.134, \"Tempo\": 127.938, \"Duration (ms)\": 167867.0, \"Valence\": 0.579, \"Chord\": \"C\"}, {\"Index\": 526, \"Highest Charting Position\": 80, \"Number of Times Charted\": 57, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Without Me\", \"Streams\": 5016283, \"Artist\": \"Halsey\", \"Artist Followers\": 15663384.0, \"Song ID\": \"5p7ujcrUXASCNwRaWNHR1C\", \"Genre\": \"['dance pop', 'electropop', 'etherpop', 'indie poptimism', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-10-04\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.752, \"Energy\": 0.488, \"Loudness\": -7.05, \"Speechiness\": 0.0705, \"Acousticness\": 0.297, \"Liveness\": 0.0936, \"Tempo\": 136.041, \"Duration (ms)\": 201661.0, \"Valence\": 0.533, \"Chord\": \"F#/Gb\"}, {\"Index\": 527, \"Highest Charting Position\": 33, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"BOOKER T\", \"Streams\": 4995965, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"26w9NTiE9NGjW1ZvIOd1So\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 77.0, \"Danceability\": 0.883, \"Energy\": 0.6, \"Loudness\": -7.188, \"Speechiness\": 0.37, \"Acousticness\": 0.114, \"Liveness\": 0.0931, \"Tempo\": 113.903, \"Duration (ms)\": 156430.0, \"Valence\": 0.691, \"Chord\": \"G\"}, {\"Index\": 528, \"Highest Charting Position\": 5, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Intentions (feat. Quavo)\", \"Streams\": 4994138, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"4umIPjkehX1r7uhmGvXiSV\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 77.0, \"Danceability\": 0.806, \"Energy\": 0.546, \"Loudness\": -6.637, \"Speechiness\": 0.0575, \"Acousticness\": 0.3, \"Liveness\": 0.102, \"Tempo\": 147.986, \"Duration (ms)\": 212867.0, \"Valence\": 0.874, \"Chord\": \"A\"}, {\"Index\": 529, \"Highest Charting Position\": 49, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Sofia\", \"Streams\": 4982892, \"Artist\": \"Clairo\", \"Artist Followers\": 2722638.0, \"Song ID\": \"7B3z0ySL9Rr0XvZEAjWZzM\", \"Genre\": \"['bedroom pop', 'indie pop', 'pop']\", \"Release Date\": \"2019-08-02\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 81.0, \"Danceability\": 0.744, \"Energy\": 0.619, \"Loudness\": -9.805, \"Speechiness\": 0.039, \"Acousticness\": 0.598, \"Liveness\": 0.231, \"Tempo\": 112.997, \"Duration (ms)\": 188387.0, \"Valence\": 0.641, \"Chord\": \"C\"}, {\"Index\": 530, \"Highest Charting Position\": 176, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Photograph\", \"Streams\": 4974880, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"1HNkqx9Ahdgi1Ixy2xkKkL\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2014-06-21\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-02-07--2020-02-14\\n2020-01-03--2020-01-10\", \"Popularity\": 83.0, \"Danceability\": 0.614, \"Energy\": 0.379, \"Loudness\": -10.48, \"Speechiness\": 0.0476, \"Acousticness\": 0.607, \"Liveness\": 0.0986, \"Tempo\": 107.989, \"Duration (ms)\": 258987.0, \"Valence\": 0.201, \"Chord\": \"E\"}, {\"Index\": 531, \"Highest Charting Position\": 20, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"34+35 Remix (feat. Doja Cat, Megan Thee Stallion) - Remix\", \"Streams\": 6162453, \"Artist\": \"Ariana Grande\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 532, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"Madonna\", \"Streams\": 5936752, \"Artist\": \"Bausa, Apache 207\", \"Artist Followers\": 961181.0, \"Song ID\": \"6a3kNt1UlUOapDKmEr3JzZ\", \"Genre\": \"['german hip hop', 'german pop']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-02-19--2021-02-26\", \"Popularity\": 68.0, \"Danceability\": 0.806, \"Energy\": 0.565, \"Loudness\": -8.96, \"Speechiness\": 0.113, \"Acousticness\": 0.47, \"Liveness\": 0.0824, \"Tempo\": 116.963, \"Duration (ms)\": 195734.0, \"Valence\": 0.311, \"Chord\": \"B\"}, {\"Index\": 533, \"Highest Charting Position\": 144, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"CLOUDS\", \"Streams\": 5897983, \"Artist\": \"NF\", \"Artist Followers\": 5831194.0, \"Song ID\": \"5UMMPHPp6vRP6ghPpSUOzp\", \"Genre\": \"['hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2021-02-18\", \"Weeks Charted\": \"2021-02-19--2021-02-26\", \"Popularity\": 69.0, \"Danceability\": 0.793, \"Energy\": 0.65, \"Loudness\": -3.944, \"Speechiness\": 0.397, \"Acousticness\": 0.371, \"Liveness\": 0.854, \"Tempo\": 128.111, \"Duration (ms)\": 243750.0, \"Valence\": 0.809, \"Chord\": \"C#/Db\"}, {\"Index\": 534, \"Highest Charting Position\": 12, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Wonder\", \"Streams\": 5535339, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 1251372.0, \"Song ID\": \"7jjS2fSD9zuzbEHeVEFJ2w\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 0.0, \"Danceability\": 0.333, \"Energy\": 0.637, \"Loudness\": -4.904, \"Speechiness\": 0.0581, \"Acousticness\": 0.131, \"Liveness\": 0.149, \"Tempo\": 139.898, \"Duration (ms)\": 172693.0, \"Valence\": 0.132, \"Chord\": \"C#/Db\"}, {\"Index\": 535, \"Highest Charting Position\": 50, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Skin\", \"Streams\": 5497942, \"Artist\": \"Sabrina Carpenter\", \"Artist Followers\": 3689546.0, \"Song ID\": \"03B2SfXuvDh1m9F4tqrX07\", \"Genre\": \"['alt z', 'dance pop', 'electropop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 76.0, \"Danceability\": 0.557, \"Energy\": 0.457, \"Loudness\": -5.372, \"Speechiness\": 0.0335, \"Acousticness\": 0.428, \"Liveness\": 0.0567, \"Tempo\": 105.918, \"Duration (ms)\": 177500.0, \"Valence\": 0.328, \"Chord\": \"G\"}, {\"Index\": 536, \"Highest Charting Position\": 62, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Tyler Herro\", \"Streams\": 5168107, \"Artist\": \"Jack Harlow\", \"Artist Followers\": 1053324.0, \"Song ID\": \"4DuUwzP4ALMqpquHU0ltAB\", \"Genre\": \"['deep underground hip hop', 'kentucky hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-10-22\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 76.0, \"Danceability\": 0.794, \"Energy\": 0.756, \"Loudness\": -7.16, \"Speechiness\": 0.136, \"Acousticness\": 0.11, \"Liveness\": 0.247, \"Tempo\": 123.066, \"Duration (ms)\": 156498.0, \"Valence\": 0.775, \"Chord\": \"F\"}, {\"Index\": 537, \"Highest Charting Position\": 173, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Remember That Night?\", \"Streams\": 5116325, \"Artist\": \"Sara Kays\", \"Artist Followers\": 251549.0, \"Song ID\": \"1nYzjrdVQ8RpF93M0jPFW7\", \"Genre\": \"['alt z', 'indie cafe pop', 'modern indie pop', 'pop', 'social media pop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 78.0, \"Danceability\": 0.679, \"Energy\": 0.61, \"Loudness\": -10.936, \"Speechiness\": 0.0305, \"Acousticness\": 0.585, \"Liveness\": 0.156, \"Tempo\": 123.978, \"Duration (ms)\": 227186.0, \"Valence\": 0.554, \"Chord\": \"G\"}, {\"Index\": 538, \"Highest Charting Position\": 128, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Lifestyle (feat. Adam Levine)\", \"Streams\": 5059891, \"Artist\": \"Jason Derulo, Maroon 5\", \"Artist Followers\": 9778632.0, \"Song ID\": \"0osvOdeD3YXZiWkT8MKolJ\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 78.0, \"Danceability\": 0.749, \"Energy\": 0.674, \"Loudness\": -5.128, \"Speechiness\": 0.0366, \"Acousticness\": 0.0209, \"Liveness\": 0.169, \"Tempo\": 123.055, \"Duration (ms)\": 153865.0, \"Valence\": 0.711, \"Chord\": \"A#/Bb\"}, {\"Index\": 539, \"Highest Charting Position\": 177, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Fly Away\", \"Streams\": 5053713, \"Artist\": \"Tones And I\", \"Artist Followers\": 2820477.0, \"Song ID\": \"5ri4zqtWhG07hIuNNDWP76\", \"Genre\": \"['australian pop', 'pop']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 79.0, \"Danceability\": 0.806, \"Energy\": 0.513, \"Loudness\": -6.208, \"Speechiness\": 0.0685, \"Acousticness\": 0.217, \"Liveness\": 0.217, \"Tempo\": 124.988, \"Duration (ms)\": 178157.0, \"Valence\": 0.503, \"Chord\": \"E\"}, {\"Index\": 540, \"Highest Charting Position\": 37, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Despeinada\", \"Streams\": 5004462, \"Artist\": \"Ozuna, Camilo\", \"Artist Followers\": 29238936.0, \"Song ID\": \"0JAZWvvqttGFm4UMDsPQXC\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 75.0, \"Danceability\": 0.734, \"Energy\": 0.775, \"Loudness\": -3.855, \"Speechiness\": 0.0614, \"Acousticness\": 0.186, \"Liveness\": 0.123, \"Tempo\": 166.039, \"Duration (ms)\": 224187.0, \"Valence\": 0.72, \"Chord\": \"G#/Ab\"}, {\"Index\": 541, \"Highest Charting Position\": 14, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"motive (with Doja Cat)\", \"Streams\": 4986037, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"5GkQIP5mWPi4KZLLXeuFTT\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 80.0, \"Danceability\": 0.789, \"Energy\": 0.742, \"Loudness\": -5.664, \"Speechiness\": 0.0652, \"Acousticness\": 0.0681, \"Liveness\": 0.166, \"Tempo\": 116.965, \"Duration (ms)\": 167990.0, \"Valence\": 0.661, \"Chord\": \"A#/Bb\"}, {\"Index\": 542, \"Highest Charting Position\": 28, \"Number of Times Charted\": 57, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"I Don't Care (with Justin Bieber)\", \"Streams\": 4984399, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"3HVWdVOQ0ZA45FuZGSfvns\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-05-10\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.798, \"Energy\": 0.675, \"Loudness\": -5.041, \"Speechiness\": 0.0442, \"Acousticness\": 0.0912, \"Liveness\": 0.0894, \"Tempo\": 101.956, \"Duration (ms)\": 219947.0, \"Valence\": 0.842, \"Chord\": \"F#/Gb\"}, {\"Index\": 543, \"Highest Charting Position\": 14, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Ay, DiOs M\\u00edo!\", \"Streams\": 5344862, \"Artist\": \"KAROL G\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3PF1mUoD0NgK4ykdt5sk3g\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 0.0, \"Danceability\": 0.715, \"Energy\": 0.706, \"Loudness\": -4.423, \"Speechiness\": 0.195, \"Acousticness\": 0.496, \"Liveness\": 0.106, \"Tempo\": 179.997, \"Duration (ms)\": 189840.0, \"Valence\": 0.522, \"Chord\": \"B\"}, {\"Index\": 544, \"Highest Charting Position\": 83, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Nathy Peluso: Bzrp Music Sessions, Vol. 36\", \"Streams\": 5232509, \"Artist\": \"Bizarrap, Nathy Peluso\", \"Artist Followers\": 3134041.0, \"Song ID\": \"78SeXVRJ7KCqVmOwTiFjnI\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 77.0, \"Danceability\": 0.65, \"Energy\": 0.655, \"Loudness\": -3.71, \"Speechiness\": 0.405, \"Acousticness\": 0.25, \"Liveness\": 0.0691, \"Tempo\": 94.059, \"Duration (ms)\": 171215.0, \"Valence\": 0.735, \"Chord\": \"C#/Db\"}, {\"Index\": 545, \"Highest Charting Position\": 17, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Haw\\u00e1i - Remix\", \"Streams\": 5163323, \"Artist\": \"Maluma, The Weeknd\", \"Artist Followers\": 26784251.0, \"Song ID\": \"0GzuHFG4Ql6DoyxFRnIk3F\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-11-05\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 77.0, \"Danceability\": 0.766, \"Energy\": 0.788, \"Loudness\": -3.128, \"Speechiness\": 0.312, \"Acousticness\": 0.105, \"Liveness\": 0.142, \"Tempo\": 179.984, \"Duration (ms)\": 200482.0, \"Valence\": 0.609, \"Chord\": \"F#/Gb\"}, {\"Index\": 546, \"Highest Charting Position\": 22, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Tattoo - Remix with Camilo\", \"Streams\": 5120753, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6096559.0, \"Song ID\": \"4ZRrLHqzhGRXYj2qcB4s5S\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-07-09\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 78.0, \"Danceability\": 0.848, \"Energy\": 0.637, \"Loudness\": -5.132, \"Speechiness\": 0.156, \"Acousticness\": 0.0413, \"Liveness\": 0.0521, \"Tempo\": 96.988, \"Duration (ms)\": 222680.0, \"Valence\": 0.698, \"Chord\": \"A\"}, {\"Index\": 547, \"Highest Charting Position\": 151, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Meia Noite (Voc\\u00ea tem meu Whatsapp)\", \"Streams\": 5044252, \"Artist\": \"Tarc\\u00edsio do Acordeon\", \"Artist Followers\": 1200248.0, \"Song ID\": \"6sPBi0qLI6KM3yXX56NxsA\", \"Genre\": \"[]\", \"Release Date\": \"2020-12-17\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 67.0, \"Danceability\": 0.709, \"Energy\": 0.816, \"Loudness\": -4.787, \"Speechiness\": 0.0346, \"Acousticness\": 0.685, \"Liveness\": 0.146, \"Tempo\": 150.06, \"Duration (ms)\": 237900.0, \"Valence\": 0.921, \"Chord\": \"B\"}, {\"Index\": 548, \"Highest Charting Position\": 143, \"Number of Times Charted\": 42, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Moonlight\", \"Streams\": 5003825, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"0JP9xo3adEtGSdUEISiszL\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2018-03-16\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2020-09-18--2020-09-25\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.921, \"Energy\": 0.537, \"Loudness\": -5.723, \"Speechiness\": 0.0804, \"Acousticness\": 0.556, \"Liveness\": 0.102, \"Tempo\": 128.009, \"Duration (ms)\": 135090.0, \"Valence\": 0.711, \"Chord\": \"A\"}, {\"Index\": 549, \"Highest Charting Position\": 182, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Thinking out Loud\", \"Streams\": 4995623, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"34gCuhDGsG4bRPIf9bb02f\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2014-06-21\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 82.0, \"Danceability\": 0.781, \"Energy\": 0.445, \"Loudness\": -6.061, \"Speechiness\": 0.0295, \"Acousticness\": 0.474, \"Liveness\": 0.184, \"Tempo\": 78.998, \"Duration (ms)\": 281560.0, \"Valence\": 0.591, \"Chord\": \"D\"}, {\"Index\": 550, \"Highest Charting Position\": 2, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Toosie Slide\", \"Streams\": 4966878, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"127QTOFJsJQp5LbJbu3A1y\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 78.0, \"Danceability\": 0.834, \"Energy\": 0.454, \"Loudness\": -9.75, \"Speechiness\": 0.201, \"Acousticness\": 0.321, \"Liveness\": 0.114, \"Tempo\": 81.618, \"Duration (ms)\": 247059.0, \"Valence\": 0.837, \"Chord\": \"C#/Db\"}, {\"Index\": 551, \"Highest Charting Position\": 167, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Earned It (Fifty Shades Of Grey)\", \"Streams\": 4929647, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"4frLb7nWtsz2ymBE6k2GRP\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2015-08-28\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 69.0, \"Danceability\": 0.659, \"Energy\": 0.291, \"Loudness\": -8.275, \"Speechiness\": 0.0348, \"Acousticness\": 0.405, \"Liveness\": 0.0771, \"Tempo\": 119.829, \"Duration (ms)\": 277680.0, \"Valence\": 0.406, \"Chord\": \"D\"}, {\"Index\": 552, \"Highest Charting Position\": 9, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"ily (i love you baby) (feat. Emilee)\", \"Streams\": 4908929, \"Artist\": \"Surf Mesa\", \"Artist Followers\": 132855.0, \"Song ID\": \"62aP9fBQKYKxi7PDXwcUAS\", \"Genre\": \"['tropical house']\", \"Release Date\": \"2019-11-26\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 81.0, \"Danceability\": 0.674, \"Energy\": 0.774, \"Loudness\": -7.567, \"Speechiness\": 0.0892, \"Acousticness\": 0.0686, \"Liveness\": 0.393, \"Tempo\": 112.05, \"Duration (ms)\": 176547.0, \"Valence\": 0.33, \"Chord\": \"B\"}, {\"Index\": 553, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Wonderwall\", \"Streams\": 4902737, \"Artist\": \"Oasis\", \"Artist Followers\": 6478565.0, \"Song ID\": \"7ygpwy2qP3NbrxVkHvUhXY\", \"Genre\": \"['beatlesque', 'britpop', 'madchester', 'permanent wave', 'rock']\", \"Release Date\": \"1995\", \"Weeks Charted\": \"2021-02-12--2021-02-19\", \"Popularity\": 78.0, \"Danceability\": 0.375, \"Energy\": 0.893, \"Loudness\": -4.097, \"Speechiness\": 0.0406, \"Acousticness\": 0.000509, \"Liveness\": 0.187, \"Tempo\": 174.323, \"Duration (ms)\": 258773.0, \"Valence\": 0.434, \"Chord\": \"D\"}, {\"Index\": 554, \"Highest Charting Position\": 181, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Everybody Dies In Their Nightmares\", \"Streams\": 4847224, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"3GVkPk8mqxz0itaAriG1L7\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2017-08-25\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\", \"Popularity\": 83.0, \"Danceability\": 0.734, \"Energy\": 0.57, \"Loudness\": -7.066, \"Speechiness\": 0.133, \"Acousticness\": 0.847, \"Liveness\": 0.112, \"Tempo\": 129.953, \"Duration (ms)\": 95467.0, \"Valence\": 0.689, \"Chord\": \"G\"}, {\"Index\": 555, \"Highest Charting Position\": 27, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Bad Boy (with Young Thug)\", \"Streams\": 6011642, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"43CIWpJaJHRcI4mUSjqgc2\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 76.0, \"Danceability\": 0.697, \"Energy\": 0.674, \"Loudness\": -6.326, \"Speechiness\": 0.0533, \"Acousticness\": 0.00215, \"Liveness\": 0.138, \"Tempo\": 81.535, \"Duration (ms)\": 157355.0, \"Valence\": 0.198, \"Chord\": \"C#/Db\"}, {\"Index\": 556, \"Highest Charting Position\": 19, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Lo Vas A Olvidar (with ROSAL\\u00cdA)\", \"Streams\": 5963380, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"0psS4i5YooJrXfDnGvWRLi\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 68.0, \"Danceability\": 0.343, \"Energy\": 0.243, \"Loudness\": -14.66, \"Speechiness\": 0.0777, \"Acousticness\": 0.721, \"Liveness\": 0.0668, \"Tempo\": 135.154, \"Duration (ms)\": 203464.0, \"Valence\": 0.032, \"Chord\": \"E\"}, {\"Index\": 557, \"Highest Charting Position\": 152, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Floating Through Space\", \"Streams\": 5579697, \"Artist\": \"Sia, David Guetta\", \"Artist Followers\": 20528724.0, \"Song ID\": \"2AceGjiX9isUbXmMZa0Dl1\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'pop']\", \"Release Date\": \"2021-02-04\", \"Weeks Charted\": \"2021-02-05--2021-02-12\", \"Popularity\": 78.0, \"Danceability\": 0.575, \"Energy\": 0.844, \"Loudness\": -4.89, \"Speechiness\": 0.072, \"Acousticness\": 0.00172, \"Liveness\": 0.114, \"Tempo\": 104.914, \"Duration (ms)\": 177801.0, \"Valence\": 0.277, \"Chord\": \"F#/Gb\"}, {\"Index\": 558, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Can't Feel My Face\", \"Streams\": 5479407, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"22VdIZQfgXJea34mQxlt81\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2015-08-28\", \"Weeks Charted\": \"2021-02-05--2021-02-12\", \"Popularity\": 80.0, \"Danceability\": 0.705, \"Energy\": 0.769, \"Loudness\": -5.526, \"Speechiness\": 0.0425, \"Acousticness\": 0.113, \"Liveness\": 0.105, \"Tempo\": 107.949, \"Duration (ms)\": 213520.0, \"Valence\": 0.583, \"Chord\": \"A\"}, {\"Index\": 559, \"Highest Charting Position\": 89, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"You (with Marshmello & Vance Joy)\", \"Streams\": 5342938, \"Artist\": \"benny blanco\", \"Artist Followers\": 804613.0, \"Song ID\": \"1GkHyypTFkUf0QQKwYoXH4\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2021-01-29\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 73.0, \"Danceability\": 0.668, \"Energy\": 0.563, \"Loudness\": -6.433, \"Speechiness\": 0.0522, \"Acousticness\": 0.0493, \"Liveness\": 0.119, \"Tempo\": 103.116, \"Duration (ms)\": 169632.0, \"Valence\": 0.305, \"Chord\": \"B\"}, {\"Index\": 560, \"Highest Charting Position\": 168, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Call Out My Name\", \"Streams\": 5233359, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"09mEdoA6zrmBPgTEN5qXmN\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2018-03-30\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\", \"Popularity\": 80.0, \"Danceability\": 0.461, \"Energy\": 0.593, \"Loudness\": -4.954, \"Speechiness\": 0.0356, \"Acousticness\": 0.17, \"Liveness\": 0.307, \"Tempo\": 134.17, \"Duration (ms)\": 228373.0, \"Valence\": 0.175, \"Chord\": \"C#/Db\"}, {\"Index\": 561, \"Highest Charting Position\": 14, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Midnight Sky\", \"Streams\": 5208100, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"27ycaQnQAxaPiyeg3nr2aB\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 76.0, \"Danceability\": 0.705, \"Energy\": 0.814, \"Loudness\": -5.466, \"Speechiness\": 0.0346, \"Acousticness\": 0.00115, \"Liveness\": 0.203, \"Tempo\": 110.0, \"Duration (ms)\": 223279.0, \"Valence\": 0.259, \"Chord\": \"E\"}, {\"Index\": 562, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Pressure (feat. Tove Lo)\", \"Streams\": 5197587, \"Artist\": \"Martin Garrix\", \"Artist Followers\": 14921269.0, \"Song ID\": \"4ga4WvRNhMsIL38pkBbnIN\", \"Genre\": \"['dance pop', 'dutch edm', 'edm', 'pop', 'pop dance', 'progressive house', 'tropical house']\", \"Release Date\": \"2021-02-05\", \"Weeks Charted\": \"2021-02-05--2021-02-12\", \"Popularity\": 76.0, \"Danceability\": 0.859, \"Energy\": 0.558, \"Loudness\": -8.991, \"Speechiness\": 0.0902, \"Acousticness\": 0.659, \"Liveness\": 0.124, \"Tempo\": 114.978, \"Duration (ms)\": 144391.0, \"Valence\": 0.357, \"Chord\": \"G\"}, {\"Index\": 563, \"Highest Charting Position\": 140, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Can You Feel My Heart\", \"Streams\": 5092250, \"Artist\": \"Bring Me The Horizon\", \"Artist Followers\": 3912138.0, \"Song ID\": \"0WSa1sucoNRcEeULlZVQXj\", \"Genre\": \"['melodic metalcore', 'metalcore', 'rock', 'uk metalcore']\", \"Release Date\": \"2013-04-01\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 77.0, \"Danceability\": 0.15, \"Energy\": 0.859, \"Loudness\": -2.827, \"Speechiness\": 0.0595, \"Acousticness\": 0.00201, \"Liveness\": 0.387, \"Tempo\": 170.527, \"Duration (ms)\": 228147.0, \"Valence\": 0.354, \"Chord\": \"E\"}, {\"Index\": 564, \"Highest Charting Position\": 167, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Agua de Jamaica\", \"Streams\": 5072462, \"Artist\": \"Maluma\", \"Artist Followers\": 26784251.0, \"Song ID\": \"41BzKiCrKpUQHS3TP0jmdr\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-01-28\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 75.0, \"Danceability\": 0.664, \"Energy\": 0.665, \"Loudness\": -3.616, \"Speechiness\": 0.0879, \"Acousticness\": 0.123, \"Liveness\": 0.411, \"Tempo\": 173.961, \"Duration (ms)\": 176970.0, \"Valence\": 0.726, \"Chord\": \"A#/Bb\"}, {\"Index\": 565, \"Highest Charting Position\": 162, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Mds\", \"Streams\": 5046418, \"Artist\": \"Kawe, Mc Lele JP\", \"Artist Followers\": 444736.0, \"Song ID\": \"0QglpM23kl9ldvVdoYNZwF\", \"Genre\": \"['brazilian hip hop', 'funk ostentacao']\", \"Release Date\": \"2020-05-19\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 72.0, \"Danceability\": 0.885, \"Energy\": 0.561, \"Loudness\": -5.331, \"Speechiness\": 0.249, \"Acousticness\": 0.261, \"Liveness\": 0.121, \"Tempo\": 140.02, \"Duration (ms)\": 125143.0, \"Valence\": 0.644, \"Chord\": \"F#/Gb\"}, {\"Index\": 566, \"Highest Charting Position\": 18, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Heartless\", \"Streams\": 4995578, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"6bnF93Rx87YqUBLSgjiMU8\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.537, \"Energy\": 0.746, \"Loudness\": -5.507, \"Speechiness\": 0.15, \"Acousticness\": 0.0236, \"Liveness\": 0.156, \"Tempo\": 170.062, \"Duration (ms)\": 198267.0, \"Valence\": 0.252, \"Chord\": \"A#/Bb\"}, {\"Index\": 567, \"Highest Charting Position\": 20, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"pov\", \"Streams\": 4906738, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3UoULw70kMsiVXxW0L3A33\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 79.0, \"Danceability\": 0.487, \"Energy\": 0.534, \"Loudness\": -5.664, \"Speechiness\": 0.0555, \"Acousticness\": 0.36, \"Liveness\": 0.1, \"Tempo\": 131.798, \"Duration (ms)\": 201882.0, \"Valence\": 0.173, \"Chord\": \"C\"}, {\"Index\": 568, \"Highest Charting Position\": 138, \"Number of Times Charted\": 49, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Be Alright\", \"Streams\": 4900492, \"Artist\": \"Dean Lewis\", \"Artist Followers\": 1692635.0, \"Song ID\": \"3EPXxR3ImUwfayaurPi3cm\", \"Genre\": \"['australian pop', 'indie cafe pop', 'pop', 'pop rock', 'post-teen pop']\", \"Release Date\": \"2018-06-29\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.553, \"Energy\": 0.586, \"Loudness\": -6.319, \"Speechiness\": 0.0362, \"Acousticness\": 0.697, \"Liveness\": 0.0813, \"Tempo\": 126.684, \"Duration (ms)\": 196373.0, \"Valence\": 0.443, \"Chord\": \"B\"}, {\"Index\": 569, \"Highest Charting Position\": 174, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Cry Baby (feat. DaBaby)\", \"Streams\": 4884711, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"4aarlAfLKVCTxUDNgbwhjH\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 76.0, \"Danceability\": 0.957, \"Energy\": 0.437, \"Loudness\": -7.882, \"Speechiness\": 0.359, \"Acousticness\": 0.00402, \"Liveness\": 0.219, \"Tempo\": 130.058, \"Duration (ms)\": 137984.0, \"Valence\": 0.616, \"Chord\": \"B\"}, {\"Index\": 570, \"Highest Charting Position\": 47, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Mi Cuarto\", \"Streams\": 4873380, \"Artist\": \"Jerry Di\", \"Artist Followers\": 149682.0, \"Song ID\": \"6fmQjRuo7XvRFCK2qex5hQ\", \"Genre\": \"['cubaton', 'dominican pop', 'pop venezolano', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 76.0, \"Danceability\": 0.854, \"Energy\": 0.525, \"Loudness\": -4.426, \"Speechiness\": 0.214, \"Acousticness\": 0.819, \"Liveness\": 0.146, \"Tempo\": 97.054, \"Duration (ms)\": 197587.0, \"Valence\": 0.63, \"Chord\": \"C#/Db\"}, {\"Index\": 571, \"Highest Charting Position\": 99, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Ohne Dich\", \"Streams\": 5487774, \"Artist\": \"KASIMIR1441, badm\\u00f3mzjay, WILDBWOYS\", \"Artist Followers\": 197320.0, \"Song ID\": \"4hSJUp6k7QeHLxU32MrLIU\", \"Genre\": \"['german alternative rap', 'german hip hop', 'german trap', 'tekk']\", \"Release Date\": \"2021-01-14\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 70.0, \"Danceability\": 0.807, \"Energy\": 0.535, \"Loudness\": -6.519, \"Speechiness\": 0.349, \"Acousticness\": 0.191, \"Liveness\": 0.125, \"Tempo\": 156.013, \"Duration (ms)\": 125720.0, \"Valence\": 0.925, \"Chord\": \"B\"}, {\"Index\": 572, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Gravity (feat. Tyler, The Creator)\", \"Streams\": 5136895, \"Artist\": \"Brent Faiyaz, DJ Dahi\", \"Artist Followers\": 1726216.0, \"Song ID\": \"6u3CPnFMKANYgfdiifFOiJ\", \"Genre\": \"['dmv rap', 'pop', 'r&b', 'rap']\", \"Release Date\": \"2021-01-29\", \"Weeks Charted\": \"2021-01-29--2021-02-05\", \"Popularity\": 76.0, \"Danceability\": 0.539, \"Energy\": 0.615, \"Loudness\": -8.746, \"Speechiness\": 0.252, \"Acousticness\": 0.173, \"Liveness\": 0.144, \"Tempo\": 163.924, \"Duration (ms)\": 214693.0, \"Valence\": 0.493, \"Chord\": \"C#/Db\"}, {\"Index\": 573, \"Highest Charting Position\": 55, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Vibez\", \"Streams\": 5071718, \"Artist\": \"ZAYN\", \"Artist Followers\": 16655692.0, \"Song ID\": \"709F3MwiVvLD0LQXeKs5Cz\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 69.0, \"Danceability\": 0.635, \"Energy\": 0.659, \"Loudness\": -7.499, \"Speechiness\": 0.116, \"Acousticness\": 0.242, \"Liveness\": 0.105, \"Tempo\": 96.855, \"Duration (ms)\": 163127.0, \"Valence\": 0.34, \"Chord\": \"G\"}, {\"Index\": 574, \"Highest Charting Position\": 103, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"All I Want - From \\\"High School Musical: The Musical: The Series\\\"\", \"Streams\": 5052801, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6313514.0, \"Song ID\": \"4Yxc55NX3tAXC2mHRAhtcW\", \"Genre\": \"['pop']\", \"Release Date\": \"2019-11-27\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 76.0, \"Danceability\": 0.376, \"Energy\": 0.43, \"Loudness\": -6.585, \"Speechiness\": 0.0328, \"Acousticness\": 0.0902, \"Liveness\": 0.0912, \"Tempo\": 77.599, \"Duration (ms)\": 177323.0, \"Valence\": 0.129, \"Chord\": \"C\"}, {\"Index\": 575, \"Highest Charting Position\": 45, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Daisy\", \"Streams\": 5030670, \"Artist\": \"Ashnikko\", \"Artist Followers\": 1248499.0, \"Song ID\": \"0AUvWawuP0ibk4SQ3sIZjk\", \"Genre\": \"['electropop', 'escape room', 'pop']\", \"Release Date\": \"2020-07-09\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 76.0, \"Danceability\": 0.834, \"Energy\": 0.663, \"Loudness\": -6.143, \"Speechiness\": 0.133, \"Acousticness\": 0.235, \"Liveness\": 0.372, \"Tempo\": 121.876, \"Duration (ms)\": 146523.0, \"Valence\": 0.774, \"Chord\": \"G#/Ab\"}, {\"Index\": 576, \"Highest Charting Position\": 83, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Wasted On You\", \"Streams\": 4948563, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"3cBsEDNhFI9E82vPj3kvi3\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 76.0, \"Danceability\": 0.505, \"Energy\": 0.657, \"Loudness\": -5.24, \"Speechiness\": 0.0318, \"Acousticness\": 0.373, \"Liveness\": 0.126, \"Tempo\": 196.0, \"Duration (ms)\": 178520.0, \"Valence\": 0.252, \"Chord\": \"B\"}, {\"Index\": 577, \"Highest Charting Position\": 13, \"Number of Times Charted\": 38, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"La Jeepeta - Remix\", \"Streams\": 4942545, \"Artist\": \"Nio Garcia, Anuel AA, Myke Towers, Brray, Juanka\", \"Artist Followers\": 2127531.0, \"Song ID\": \"1mohfLaTJtB2RplHLQVM70\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 75.0, \"Danceability\": 0.815, \"Energy\": 0.715, \"Loudness\": -4.65, \"Speechiness\": 0.207, \"Acousticness\": 0.3, \"Liveness\": 0.091, \"Tempo\": 176.007, \"Duration (ms)\": 345241.0, \"Valence\": 0.786, \"Chord\": \"E\"}, {\"Index\": 578, \"Highest Charting Position\": 137, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Los Dioses\", \"Streams\": 5929507, \"Artist\": \"Anuel AA, Ozuna\", \"Artist Followers\": 18306226.0, \"Song ID\": \"73O30uMI7n6DuzBmbtO7kC\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-01-22--2021-01-29\", \"Popularity\": 73.0, \"Danceability\": 0.817, \"Energy\": 0.737, \"Loudness\": -5.453, \"Speechiness\": 0.102, \"Acousticness\": 0.046, \"Liveness\": 0.092, \"Tempo\": 93.985, \"Duration (ms)\": 206587.0, \"Valence\": 0.67, \"Chord\": \"F#/Gb\"}, {\"Index\": 579, \"Highest Charting Position\": 132, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Si Me Tomo Una Cerveza\", \"Streams\": 5427534, \"Artist\": \"Migrantes, Alico\", \"Artist Followers\": 114348.0, \"Song ID\": \"3lCbsHaN1wCxyDzcNN2x4N\", \"Genre\": \"['cumbia pop']\", \"Release Date\": \"2020-11-07\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 74.0, \"Danceability\": 0.72, \"Energy\": 0.613, \"Loudness\": -6.899, \"Speechiness\": 0.0572, \"Acousticness\": 0.185, \"Liveness\": 0.155, \"Tempo\": 84.974, \"Duration (ms)\": 182199.0, \"Valence\": 0.857, \"Chord\": \"C#/Db\"}, {\"Index\": 580, \"Highest Charting Position\": 90, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Somebody\\u2019s Problem\", \"Streams\": 5332437, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"0SErdEdRcVX1uJCf1eTGYH\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2020-11-20--2020-11-27\", \"Popularity\": 70.0, \"Danceability\": 0.657, \"Energy\": 0.54, \"Loudness\": -7.675, \"Speechiness\": 0.0287, \"Acousticness\": 0.662, \"Liveness\": 0.123, \"Tempo\": 136.97, \"Duration (ms)\": 161773.0, \"Valence\": 0.625, \"Chord\": \"F\"}, {\"Index\": 581, \"Highest Charting Position\": 66, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"De Una Vez\", \"Streams\": 5186567, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"1v3lhrZEsOcazqR2QIyyRu\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 70.0, \"Danceability\": 0.659, \"Energy\": 0.479, \"Loudness\": -6.79, \"Speechiness\": 0.2, \"Acousticness\": 0.152, \"Liveness\": 0.268, \"Tempo\": 163.882, \"Duration (ms)\": 155956.0, \"Valence\": 0.0395, \"Chord\": \"B\"}, {\"Index\": 582, \"Highest Charting Position\": 121, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Way Out (feat. Big Sean)\", \"Streams\": 4962949, \"Artist\": \"Jack Harlow\", \"Artist Followers\": 1053324.0, \"Song ID\": \"6rLi6PyWXu1rPlShuIZpj6\", \"Genre\": \"['deep underground hip hop', 'kentucky hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-09\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 72.0, \"Danceability\": 0.945, \"Energy\": 0.582, \"Loudness\": -8.357, \"Speechiness\": 0.0719, \"Acousticness\": 0.114, \"Liveness\": 0.103, \"Tempo\": 108.025, \"Duration (ms)\": 168906.0, \"Valence\": 0.907, \"Chord\": \"B\"}, {\"Index\": 583, \"Highest Charting Position\": 42, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Diamonds\", \"Streams\": 4931163, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"5hvwx5i67IwnCkjl9VHkNv\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-09-17\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 77.0, \"Danceability\": 0.653, \"Energy\": 0.667, \"Loudness\": -6.764, \"Speechiness\": 0.0423, \"Acousticness\": 0.154, \"Liveness\": 0.107, \"Tempo\": 104.181, \"Duration (ms)\": 213869.0, \"Valence\": 0.556, \"Chord\": \"A#/Bb\"}, {\"Index\": 584, \"Highest Charting Position\": 190, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Dancing in My Room\", \"Streams\": 4914093, \"Artist\": \"347aidan\", \"Artist Followers\": 211500.0, \"Song ID\": \"6Pgmqg15yVexuOgtzuxwoX\", \"Genre\": \"['sad rap']\", \"Release Date\": \"2020-10-26\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\", \"Popularity\": 79.0, \"Danceability\": 0.98, \"Energy\": 0.413, \"Loudness\": -11.052, \"Speechiness\": 0.101, \"Acousticness\": 0.671, \"Liveness\": 0.17, \"Tempo\": 119.993, \"Duration (ms)\": 180139.0, \"Valence\": 0.764, \"Chord\": \"G#/Ab\"}, {\"Index\": 585, \"Highest Charting Position\": 116, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"De Cora <3\", \"Streams\": 4864544, \"Artist\": \"Rauw Alejandro, J Balvin\", \"Artist Followers\": 6096559.0, \"Song ID\": \"22Sh5dlwbERqJAq1fZk5b2\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 73.0, \"Danceability\": 0.811, \"Energy\": 0.683, \"Loudness\": -2.028, \"Speechiness\": 0.241, \"Acousticness\": 0.46, \"Liveness\": 0.128, \"Tempo\": 176.037, \"Duration (ms)\": 190101.0, \"Valence\": 0.571, \"Chord\": \"B\"}, {\"Index\": 586, \"Highest Charting Position\": 10, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"champagne problems\", \"Streams\": 4848954, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0sY6ZUTh4yoctD8VIXz339\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 75.0, \"Danceability\": 0.462, \"Energy\": 0.24, \"Loudness\": -12.077, \"Speechiness\": 0.0377, \"Acousticness\": 0.92, \"Liveness\": 0.113, \"Tempo\": 171.319, \"Duration (ms)\": 244000.0, \"Valence\": 0.32, \"Chord\": \"C\"}, {\"Index\": 587, \"Highest Charting Position\": 37, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Go Crazy\", \"Streams\": 4833081, \"Artist\": \"Chris Brown, Young Thug\", \"Artist Followers\": 14073083.0, \"Song ID\": \"1IIKrJVP1C9N7iPtG6eOsK\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'r&b', 'rap']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 80.0, \"Danceability\": 0.755, \"Energy\": 0.578, \"Loudness\": -8.932, \"Speechiness\": 0.145, \"Acousticness\": 0.316, \"Liveness\": 0.25, \"Tempo\": 94.148, \"Duration (ms)\": 176960.0, \"Valence\": 0.581, \"Chord\": \"C\"}, {\"Index\": 588, \"Highest Charting Position\": 73, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Reminds Me Of You\", \"Streams\": 5942551, \"Artist\": \"Juice WRLD, The Kid LAROI\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5YSHygGN9D0mID1NsVd5my\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-12-08\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 75.0, \"Danceability\": 0.613, \"Energy\": 0.631, \"Loudness\": -6.965, \"Speechiness\": 0.12, \"Acousticness\": 0.0663, \"Liveness\": 0.169, \"Tempo\": 149.992, \"Duration (ms)\": 158033.0, \"Valence\": 0.33, \"Chord\": \"E\"}, {\"Index\": 589, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Don't Play\", \"Streams\": 5119828, \"Artist\": \"Anne-Marie, KSI, Digital Farm Animals\", \"Artist Followers\": 8153871.0, \"Song ID\": \"4I5bvu2KDsrCg0EWHIcvul\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-01-15--2021-01-22\", \"Popularity\": 73.0, \"Danceability\": 0.695, \"Energy\": 0.784, \"Loudness\": -6.564, \"Speechiness\": 0.0402, \"Acousticness\": 0.0889, \"Liveness\": 0.0843, \"Tempo\": 128.031, \"Duration (ms)\": 188581.0, \"Valence\": 0.52, \"Chord\": \"F#/Gb\"}, {\"Index\": 590, \"Highest Charting Position\": 108, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"MODO TURBO\", \"Streams\": 4983557, \"Artist\": \"Lu\\u00edsa Sonza, Pabllo Vittar, Anitta\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5217tPOJfhVUY8q9TCKHO1\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-11\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 1.0, \"Danceability\": 0.655, \"Energy\": 0.726, \"Loudness\": -7.628, \"Speechiness\": 0.0796, \"Acousticness\": 0.334, \"Liveness\": 0.232, \"Tempo\": 160.064, \"Duration (ms)\": 150260.0, \"Valence\": 0.766, \"Chord\": \"A#/Bb\"}, {\"Index\": 591, \"Highest Charting Position\": 191, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Buss It\", \"Streams\": 4915403, \"Artist\": \"Erica Banks\", \"Artist Followers\": 41551.0, \"Song ID\": \"25j0Sape7qZbq6ZPLFefTT\", \"Genre\": \"['trap queen']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2021-01-15--2021-01-22\", \"Popularity\": 72.0, \"Danceability\": 0.956, \"Energy\": 0.502, \"Loudness\": -5.995, \"Speechiness\": 0.213, \"Acousticness\": 0.0593, \"Liveness\": 0.238, \"Tempo\": 110.003, \"Duration (ms)\": 187000.0, \"Valence\": 0.795, \"Chord\": \"A\"}, {\"Index\": 592, \"Highest Charting Position\": 41, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Kings & Queens\", \"Streams\": 4855690, \"Artist\": \"Ava Max\", \"Artist Followers\": 3916979.0, \"Song ID\": \"7a53HqqArd4b9NF4XAmlbI\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 82.0, \"Danceability\": 0.637, \"Energy\": 0.69, \"Loudness\": -4.057, \"Speechiness\": 0.0405, \"Acousticness\": 0.00786, \"Liveness\": 0.124, \"Tempo\": 129.857, \"Duration (ms)\": 162399.0, \"Valence\": 0.457, \"Chord\": \"C#/Db\"}, {\"Index\": 593, \"Highest Charting Position\": 6, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Lovesick Girls\", \"Streams\": 4796365, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"4Ws314Ylb27BVsvlZOy30C\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 75.0, \"Danceability\": 0.654, \"Energy\": 0.707, \"Loudness\": -5.661, \"Speechiness\": 0.0664, \"Acousticness\": 0.00559, \"Liveness\": 0.0873, \"Tempo\": 127.97, \"Duration (ms)\": 194765.0, \"Valence\": 0.448, \"Chord\": \"F#/Gb\"}, {\"Index\": 594, \"Highest Charting Position\": 17, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Caramelo\", \"Streams\": 4790233, \"Artist\": \"Ozuna\", \"Artist Followers\": 29238936.0, \"Song ID\": \"3gD4J3RUHy4OUuZ3qAiaiG\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-06-11\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 74.0, \"Danceability\": 0.728, \"Energy\": 0.806, \"Loudness\": -3.766, \"Speechiness\": 0.0623, \"Acousticness\": 0.0531, \"Liveness\": 0.153, \"Tempo\": 168.084, \"Duration (ms)\": 217547.0, \"Valence\": 0.698, \"Chord\": \"F#/Gb\"}, {\"Index\": 595, \"Highest Charting Position\": 67, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Deep End\", \"Streams\": 5622565, \"Artist\": \"Foushe\\u00e9\", \"Artist Followers\": 411262.0, \"Song ID\": \"2AlYncTpVHKwHb55F9lF6O\", \"Genre\": \"['brooklyn drill', 'nyc rap']\", \"Release Date\": \"2020-06-05\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 72.0, \"Danceability\": 0.868, \"Energy\": 0.479, \"Loudness\": -6.687, \"Speechiness\": 0.445, \"Acousticness\": 0.703, \"Liveness\": 0.102, \"Tempo\": 133.928, \"Duration (ms)\": 115200.0, \"Valence\": 0.776, \"Chord\": \"E\"}, {\"Index\": 596, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Sand In My Boots\", \"Streams\": 5446609, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"0uRrG2jRR5tuifsYIJHEao\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\", \"Popularity\": 75.0, \"Danceability\": 0.403, \"Energy\": 0.537, \"Loudness\": -6.628, \"Speechiness\": 0.031, \"Acousticness\": 0.59, \"Liveness\": 0.112, \"Tempo\": 69.877, \"Duration (ms)\": 202133.0, \"Valence\": 0.414, \"Chord\": \"D#/Eb\"}, {\"Index\": 597, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"865\", \"Streams\": 5160123, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"0sKEilrw1GrBlG6qsTCrP4\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\", \"Popularity\": 70.0, \"Danceability\": 0.532, \"Energy\": 0.584, \"Loudness\": -5.254, \"Speechiness\": 0.0248, \"Acousticness\": 0.723, \"Liveness\": 0.101, \"Tempo\": 88.003, \"Duration (ms)\": 190680.0, \"Valence\": 0.367, \"Chord\": \"G#/Ab\"}, {\"Index\": 598, \"Highest Charting Position\": 53, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"7 Summers\", \"Streams\": 5064504, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"4obHzpwGrjoTuZh2DItEMZ\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2020-09-11--2020-09-18\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 73.0, \"Danceability\": 0.466, \"Energy\": 0.786, \"Loudness\": -5.13, \"Speechiness\": 0.0328, \"Acousticness\": 0.417, \"Liveness\": 0.125, \"Tempo\": 203.903, \"Duration (ms)\": 210507.0, \"Valence\": 0.571, \"Chord\": \"C\"}, {\"Index\": 599, \"Highest Charting Position\": 21, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"HACIENDO QUE ME AMAS\", \"Streams\": 4935633, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"26QApq0cuO9brJigr0C0W4\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 78.0, \"Danceability\": 0.584, \"Energy\": 0.411, \"Loudness\": -7.147, \"Speechiness\": 0.0838, \"Acousticness\": 0.869, \"Liveness\": 0.0955, \"Tempo\": 169.934, \"Duration (ms)\": 217769.0, \"Valence\": 0.412, \"Chord\": \"A#/Bb\"}, {\"Index\": 600, \"Highest Charting Position\": 65, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"La Luz\", \"Streams\": 4906324, \"Artist\": \"Sech, J Balvin\", \"Artist Followers\": 8766508.0, \"Song ID\": \"5zj8WNkBrEzlI5FKeYV4ol\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-10-31\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 70.0, \"Danceability\": 0.665, \"Energy\": 0.697, \"Loudness\": -4.819, \"Speechiness\": 0.154, \"Acousticness\": 0.427, \"Liveness\": 0.599, \"Tempo\": 94.053, \"Duration (ms)\": 216747.0, \"Valence\": 0.556, \"Chord\": \"A\"}, {\"Index\": 601, \"Highest Charting Position\": 17, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"The Woo (feat. 50 Cent & Roddy Ricch)\", \"Streams\": 4892682, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"1H7KnK26kc1YyellpbINEn\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 79.0, \"Danceability\": 0.49, \"Energy\": 0.618, \"Loudness\": -5.655, \"Speechiness\": 0.104, \"Acousticness\": 0.0221, \"Liveness\": 0.259, \"Tempo\": 99.7, \"Duration (ms)\": 201600.0, \"Valence\": 0.286, \"Chord\": \"C#/Db\"}, {\"Index\": 602, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"More Than My Hometown\", \"Streams\": 4879971, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"5OELUCYgOHKFAvCERnAvfS\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\", \"Popularity\": 75.0, \"Danceability\": 0.62, \"Energy\": 0.869, \"Loudness\": -5.479, \"Speechiness\": 0.0462, \"Acousticness\": 0.615, \"Liveness\": 0.131, \"Tempo\": 126.019, \"Duration (ms)\": 216573.0, \"Valence\": 0.597, \"Chord\": \"F#/Gb\"}, {\"Index\": 603, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Warning\", \"Streams\": 4860714, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"64SCQtbRtmO28ks1QhS3w5\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\", \"Popularity\": 68.0, \"Danceability\": 0.633, \"Energy\": 0.664, \"Loudness\": -5.037, \"Speechiness\": 0.0294, \"Acousticness\": 0.46, \"Liveness\": 0.108, \"Tempo\": 115.058, \"Duration (ms)\": 156747.0, \"Valence\": 0.268, \"Chord\": \"A#/Bb\"}, {\"Index\": 604, \"Highest Charting Position\": 117, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Recairei - Ao Vivo\", \"Streams\": 4815342, \"Artist\": \"Os Bar\\u00f5es Da Pisadinha\", \"Artist Followers\": 4281787.0, \"Song ID\": \"71FrGl0XcpL3VId65tB5mg\", \"Genre\": \"['forro', 'piseiro']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-27--2020-12-04\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 69.0, \"Danceability\": 0.582, \"Energy\": 0.937, \"Loudness\": -2.118, \"Speechiness\": 0.0858, \"Acousticness\": 0.449, \"Liveness\": 0.684, \"Tempo\": 168.096, \"Duration (ms)\": 166838.0, \"Valence\": 0.939, \"Chord\": \"A#/Bb\"}, {\"Index\": 605, \"Highest Charting Position\": 5, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Ice Cream (with Selena Gomez)\", \"Streams\": 4812765, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"4JUPEh2DVSXFGExu4Uxevz\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 71.0, \"Danceability\": 0.79, \"Energy\": 0.701, \"Loudness\": -4.81, \"Speechiness\": 0.365, \"Acousticness\": 0.0317, \"Liveness\": 0.0311, \"Tempo\": 159.972, \"Duration (ms)\": 177813.0, \"Valence\": 0.91, \"Chord\": \"A\"}, {\"Index\": 606, \"Highest Charting Position\": 22, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Be Kind (with Halsey)\", \"Streams\": 4790427, \"Artist\": \"Marshmello\", \"Artist Followers\": 31552500.0, \"Song ID\": \"3Z8FwOEN59mRMxDCtb8N0A\", \"Genre\": \"['brostep', 'edm', 'pop', 'pop dance', 'progressive electro house']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 80.0, \"Danceability\": 0.63, \"Energy\": 0.633, \"Loudness\": -7.088, \"Speechiness\": 0.0457, \"Acousticness\": 0.00776, \"Liveness\": 0.0541, \"Tempo\": 93.995, \"Duration (ms)\": 172762.0, \"Valence\": 0.452, \"Chord\": \"E\"}, {\"Index\": 607, \"Highest Charting Position\": 76, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Fever\", \"Streams\": 4769618, \"Artist\": \"Dua Lipa, Ang\\u00e8le\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3wJVBz7gvGTwTWVAxFa6ny\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-10-29\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 73.0, \"Danceability\": 0.868, \"Energy\": 0.693, \"Loudness\": -7.052, \"Speechiness\": 0.181, \"Acousticness\": 0.0597, \"Liveness\": 0.106, \"Tempo\": 114.999, \"Duration (ms)\": 156911.0, \"Valence\": 0.396, \"Chord\": \"F#/Gb\"}, {\"Index\": 608, \"Highest Charting Position\": 141, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Angst\", \"Streams\": 5317174, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"5yUzqd3H7cmJ1no6B4uTzu\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2021-01-01\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.599, \"Energy\": 0.79, \"Loudness\": -4.352, \"Speechiness\": 0.386, \"Acousticness\": 0.0213, \"Liveness\": 0.0778, \"Tempo\": 100.119, \"Duration (ms)\": 201501.0, \"Valence\": 0.528, \"Chord\": \"A\"}, {\"Index\": 609, \"Highest Charting Position\": 15, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"no body, no crime (feat. HAIM)\", \"Streams\": 4986214, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3RaT22zZsxVYxxKR7TAaYF\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 68.0, \"Danceability\": 0.546, \"Energy\": 0.613, \"Loudness\": -7.589, \"Speechiness\": 0.0264, \"Acousticness\": 0.418, \"Liveness\": 0.103, \"Tempo\": 79.015, \"Duration (ms)\": 215627.0, \"Valence\": 0.535, \"Chord\": \"G\"}, {\"Index\": 610, \"Highest Charting Position\": 13, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Sunday Best\", \"Streams\": 4858392, \"Artist\": \"Surfaces\", \"Artist Followers\": 724903.0, \"Song ID\": \"1Cv1YLb4q0RzL6pybtaMLo\", \"Genre\": \"['bedroom soul', 'pop']\", \"Release Date\": \"2019-01-06\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 80.0, \"Danceability\": 0.878, \"Energy\": 0.525, \"Loudness\": -6.832, \"Speechiness\": 0.0578, \"Acousticness\": 0.183, \"Liveness\": 0.0714, \"Tempo\": 112.022, \"Duration (ms)\": 158571.0, \"Valence\": 0.694, \"Chord\": \"F\"}, {\"Index\": 611, \"Highest Charting Position\": 171, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Amor ou o Litr\\u00e3o\", \"Streams\": 4848222, \"Artist\": \"Petter Ferraz, Menor Nico\", \"Artist Followers\": 14122.0, \"Song ID\": \"7qmnP8Woc47dLSrMD5MxL1\", \"Genre\": \"[]\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 66.0, \"Danceability\": 0.934, \"Energy\": 0.707, \"Loudness\": -4.214, \"Speechiness\": 0.0646, \"Acousticness\": 0.437, \"Liveness\": 0.0628, \"Tempo\": 138.023, \"Duration (ms)\": 173913.0, \"Valence\": 0.961, \"Chord\": \"A\"}, {\"Index\": 612, \"Highest Charting Position\": 66, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Happier\", \"Streams\": 4655272, \"Artist\": \"Marshmello, Bastille\", \"Artist Followers\": 31552500.0, \"Song ID\": \"2dpaYNEQHiRxtZbfNsse99\", \"Genre\": \"['brostep', 'edm', 'pop', 'pop dance', 'progressive electro house']\", \"Release Date\": \"2018-08-17\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-11-13--2020-11-20\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.687, \"Energy\": 0.792, \"Loudness\": -2.749, \"Speechiness\": 0.0452, \"Acousticness\": 0.191, \"Liveness\": 0.167, \"Tempo\": 100.015, \"Duration (ms)\": 214290.0, \"Valence\": 0.671, \"Chord\": \"F\"}, {\"Index\": 613, \"Highest Charting Position\": 138, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Don't Stop Me Now - Remastered 2011\", \"Streams\": 4630572, \"Artist\": \"Queen\", \"Artist Followers\": 35910149.0, \"Song ID\": \"7hQJA50XrCWABAu5v6QZ4i\", \"Genre\": \"['classic rock', 'glam rock', 'rock']\", \"Release Date\": \"1978-11-10\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-15--2020-05-22\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.563, \"Energy\": 0.865, \"Loudness\": -5.277, \"Speechiness\": 0.16, \"Acousticness\": 0.0472, \"Liveness\": 0.77, \"Tempo\": 156.271, \"Duration (ms)\": 209413.0, \"Valence\": 0.601, \"Chord\": \"F\"}, {\"Index\": 614, \"Highest Charting Position\": 61, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Azul\", \"Streams\": 4606011, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"2lCkncy6bIB0LTMT7kvrD1\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 77.0, \"Danceability\": 0.843, \"Energy\": 0.836, \"Loudness\": -2.474, \"Speechiness\": 0.0695, \"Acousticness\": 0.0816, \"Liveness\": 0.0532, \"Tempo\": 94.018, \"Duration (ms)\": 205933.0, \"Valence\": 0.65, \"Chord\": \"B\"}, {\"Index\": 615, \"Highest Charting Position\": 183, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Basta Voc\\u00ea Me Ligar - Ao Vivo\", \"Streams\": 4580123, \"Artist\": \"Os Bar\\u00f5es Da Pisadinha, Xand Avi\\u00e3o\", \"Artist Followers\": 4281787.0, \"Song ID\": \"3AV1KI22k1jGMz792lDrj1\", \"Genre\": \"['forro', 'piseiro']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 68.0, \"Danceability\": 0.599, \"Energy\": 0.914, \"Loudness\": -2.415, \"Speechiness\": 0.0629, \"Acousticness\": 0.5, \"Liveness\": 0.694, \"Tempo\": 168.008, \"Duration (ms)\": 182977.0, \"Valence\": 0.831, \"Chord\": \"F\"}, {\"Index\": 616, \"Highest Charting Position\": 49, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Tequila Shots\", \"Streams\": 4540781, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"30KctD1WsHKTIYczXjip5a\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 74.0, \"Danceability\": 0.712, \"Energy\": 0.556, \"Loudness\": -7.214, \"Speechiness\": 0.0531, \"Acousticness\": 0.084, \"Liveness\": 0.527, \"Tempo\": 90.494, \"Duration (ms)\": 193293.0, \"Valence\": 0.22, \"Chord\": \"F\"}, {\"Index\": 617, \"Highest Charting Position\": 27, \"Number of Times Charted\": 45, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Lose Control\", \"Streams\": 4516053, \"Artist\": \"MEDUZA, Becky Hill, Goodboys\", \"Artist Followers\": 441714.0, \"Song ID\": \"7CHi4DtfK4heMlQaudCuHK\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop house', 'tropical house']\", \"Release Date\": \"2019-10-11\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.598, \"Energy\": 0.526, \"Loudness\": -8.659, \"Speechiness\": 0.0415, \"Acousticness\": 0.129, \"Liveness\": 0.14, \"Tempo\": 123.935, \"Duration (ms)\": 168387.0, \"Valence\": 0.529, \"Chord\": \"A#/Bb\"}, {\"Index\": 618, \"Highest Charting Position\": 68, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"I CAN'T STOP ME\", \"Streams\": 4504304, \"Artist\": \"TWICE\", \"Artist Followers\": 9998991.0, \"Song ID\": \"37ZtpRBkHcaq6hHy0X98zn\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-26\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 76.0, \"Danceability\": 0.657, \"Energy\": 0.88, \"Loudness\": -3.672, \"Speechiness\": 0.102, \"Acousticness\": 0.121, \"Liveness\": 0.463, \"Tempo\": 150.084, \"Duration (ms)\": 205493.0, \"Valence\": 0.769, \"Chord\": \"A#/Bb\"}, {\"Index\": 619, \"Highest Charting Position\": 158, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"E-GIRLS ARE RUINING MY LIFE!\", \"Streams\": 4488125, \"Artist\": \"CORPSE, Savage Ga$p\", \"Artist Followers\": 1777797.0, \"Song ID\": \"7bCfHiRcfUjG0YVVNUL7Ve\", \"Genre\": \"['dream smp', 'viral rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 77.0, \"Danceability\": 0.614, \"Energy\": 0.937, \"Loudness\": -7.443, \"Speechiness\": 0.115, \"Acousticness\": 0.00161, \"Liveness\": 0.103, \"Tempo\": 84.98, \"Duration (ms)\": 105176.0, \"Valence\": 0.386, \"Chord\": \"C#/Db\"}, {\"Index\": 620, \"Highest Charting Position\": 1, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"All I Want for Christmas Is You\", \"Streams\": 23235257, \"Artist\": \"Mariah Carey\", \"Artist Followers\": 6931357.0, \"Song ID\": \"0bYg9bo50gSsH3LtXe2SQn\", \"Genre\": \"['dance pop', 'pop', 'r&b', 'urban contemporary']\", \"Release Date\": \"1994-11-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2019-12-27--2020-01-03\", \"Popularity\": 65.0, \"Danceability\": 0.336, \"Energy\": 0.627, \"Loudness\": -7.463, \"Speechiness\": 0.0384, \"Acousticness\": 0.164, \"Liveness\": 0.0708, \"Tempo\": 150.273, \"Duration (ms)\": 241107.0, \"Valence\": 0.35, \"Chord\": \"G\"}, {\"Index\": 621, \"Highest Charting Position\": 2, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Last Christmas\", \"Streams\": 20709328, \"Artist\": \"Wham!\", \"Artist Followers\": 1631876.0, \"Song ID\": \"2FRnf9qhLbvw8fu4IBXx78\", \"Genre\": \"['disco', 'europop', 'new romantic', 'new wave', 'new wave pop', 'soft rock', 'synthpop']\", \"Release Date\": \"1984-11-29\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 63.0, \"Danceability\": 0.735, \"Energy\": 0.478, \"Loudness\": -12.472, \"Speechiness\": 0.0293, \"Acousticness\": 0.189, \"Liveness\": 0.355, \"Tempo\": 107.682, \"Duration (ms)\": 262960.0, \"Valence\": 0.947, \"Chord\": \"D\"}, {\"Index\": 622, \"Highest Charting Position\": 3, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Tell Me\", \"Streams\": 16657592, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"0lizgQ7Qw35od7CYaoMBZb\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2014-11-24\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 61.0, \"Danceability\": 0.525, \"Energy\": 0.621, \"Loudness\": -7.364, \"Speechiness\": 0.116, \"Acousticness\": 0.0489, \"Liveness\": 0.294, \"Tempo\": 191.9, \"Duration (ms)\": 204093.0, \"Valence\": 0.591, \"Chord\": \"G\"}, {\"Index\": 623, \"Highest Charting Position\": 5, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Rockin' Around The Christmas Tree\", \"Streams\": 16613649, \"Artist\": \"Brenda Lee\", \"Artist Followers\": 222627.0, \"Song ID\": \"2EjXfH91m7f8HiJN1yQg97\", \"Genre\": \"['adult standards', 'brill building pop', 'easy listening', 'lounge', 'rockabilly', 'vocal jazz']\", \"Release Date\": \"1964-10-19\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 58.0, \"Danceability\": 0.589, \"Energy\": 0.472, \"Loudness\": -8.749, \"Speechiness\": 0.0502, \"Acousticness\": 0.614, \"Liveness\": 0.505, \"Tempo\": 67.196, \"Duration (ms)\": 126267.0, \"Valence\": 0.898, \"Chord\": \"G#/Ab\"}, {\"Index\": 624, \"Highest Charting Position\": 7, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Jingle Bell Rock\", \"Streams\": 16527404, \"Artist\": \"Bobby Helms\", \"Artist Followers\": 20637.0, \"Song ID\": \"7vQbuQcyTflfCIOu3Uzzya\", \"Genre\": \"[]\", \"Release Date\": \"1957-12-02\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 56.0, \"Danceability\": 0.754, \"Energy\": 0.424, \"Loudness\": -8.463, \"Speechiness\": 0.0363, \"Acousticness\": 0.643, \"Liveness\": 0.0652, \"Tempo\": 119.705, \"Duration (ms)\": 130973.0, \"Valence\": 0.806, \"Chord\": \"D\"}, {\"Index\": 625, \"Highest Charting Position\": 6, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"It's Beginning to Look a Lot like Christmas\", \"Streams\": 15424001, \"Artist\": \"Michael Bubl\\u00e9\", \"Artist Followers\": 4702232.0, \"Song ID\": \"5a1iz510sv2W9Dt1MvFd5R\", \"Genre\": \"['adult standards', 'canadian pop', 'jazz pop', 'lounge']\", \"Release Date\": \"2012-11-09\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 55.0, \"Danceability\": 0.339, \"Energy\": 0.214, \"Loudness\": -11.714, \"Speechiness\": 0.0375, \"Acousticness\": 0.908, \"Liveness\": 0.341, \"Tempo\": 94.775, \"Duration (ms)\": 206640.0, \"Valence\": 0.363, \"Chord\": \"E\"}, {\"Index\": 626, \"Highest Charting Position\": 8, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"It's the Most Wonderful Time of the Year\", \"Streams\": 14582001, \"Artist\": \"Andy Williams\", \"Artist Followers\": 369548.0, \"Song ID\": \"5hslUAKq9I9CG2bAulFkHN\", \"Genre\": \"['adult standards', 'brill building pop', 'easy listening', 'lounge', 'mellow gold', 'vocal jazz']\", \"Release Date\": \"1963-11-24\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 55.0, \"Danceability\": 0.24, \"Energy\": 0.598, \"Loudness\": -8.435, \"Speechiness\": 0.0369, \"Acousticness\": 0.766, \"Liveness\": 0.117, \"Tempo\": 201.629, \"Duration (ms)\": 151933.0, \"Valence\": 0.776, \"Chord\": \"G\"}, {\"Index\": 627, \"Highest Charting Position\": 9, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Underneath the Tree\", \"Streams\": 12266990, \"Artist\": \"Kelly Clarkson\", \"Artist Followers\": 7869617.0, \"Song ID\": \"3YZE5qDV7u1ZD1gZc47ZeR\", \"Genre\": \"['dance pop', 'neo mellow', 'pop', 'pop rock', 'post-teen pop', 'talent show']\", \"Release Date\": \"2013-10-29\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 49.0, \"Danceability\": 0.509, \"Energy\": 0.812, \"Loudness\": -5.439, \"Speechiness\": 0.0537, \"Acousticness\": 0.00128, \"Liveness\": 0.214, \"Tempo\": 159.878, \"Duration (ms)\": 229640.0, \"Valence\": 0.689, \"Chord\": \"G#/Ab\"}, {\"Index\": 628, \"Highest Charting Position\": 14, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Feliz Navidad\", \"Streams\": 11664490, \"Artist\": \"Jos\\u00e9 Feliciano\", \"Artist Followers\": 239129.0, \"Song ID\": \"0oPdaY4dXtc3ZsaG17V972\", \"Genre\": \"['latin pop', 'puerto rican pop']\", \"Release Date\": \"2002-09-24\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 49.0, \"Danceability\": 0.513, \"Energy\": 0.831, \"Loudness\": -9.004, \"Speechiness\": 0.0383, \"Acousticness\": 0.55, \"Liveness\": 0.336, \"Tempo\": 148.837, \"Duration (ms)\": 182067.0, \"Valence\": 0.963, \"Chord\": \"D\"}, {\"Index\": 629, \"Highest Charting Position\": 11, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Let It Snow! Let It Snow! Let It Snow!\", \"Streams\": 10884855, \"Artist\": \"Dean Martin\", \"Artist Followers\": 1139096.0, \"Song ID\": \"2uFaJJtFpPDc5Pa95XzTvg\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"1959-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 54.0, \"Danceability\": 0.451, \"Energy\": 0.24, \"Loudness\": -14.014, \"Speechiness\": 0.0351, \"Acousticness\": 0.912, \"Liveness\": 0.175, \"Tempo\": 134.009, \"Duration (ms)\": 117147.0, \"Valence\": 0.701, \"Chord\": \"C#/Db\"}, {\"Index\": 630, \"Highest Charting Position\": 19, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Let It Snow! Let It Snow! Let It Snow! (with The B. Swanson Quartet)\", \"Streams\": 10787165, \"Artist\": \"Frank Sinatra\", \"Artist Followers\": 4953667.0, \"Song ID\": \"4kKdvXD0ez7jp1296JmAts\", \"Genre\": \"['adult standards', 'easy listening', 'lounge']\", \"Release Date\": \"1994-11-08\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 53.0, \"Danceability\": 0.652, \"Energy\": 0.259, \"Loudness\": -13.336, \"Speechiness\": 0.0595, \"Acousticness\": 0.903, \"Liveness\": 0.362, \"Tempo\": 142.169, \"Duration (ms)\": 155453.0, \"Valence\": 0.836, \"Chord\": \"D\"}, {\"Index\": 631, \"Highest Charting Position\": 15, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Mistletoe\", \"Streams\": 10609206, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"7xapw9Oy21WpfEcib2ErSA\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2011-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 59.0, \"Danceability\": 0.657, \"Energy\": 0.56, \"Loudness\": -9.049, \"Speechiness\": 0.0467, \"Acousticness\": 0.498, \"Liveness\": 0.0794, \"Tempo\": 161.993, \"Duration (ms)\": 182947.0, \"Valence\": 0.854, \"Chord\": \"F#/Gb\"}, {\"Index\": 632, \"Highest Charting Position\": 16, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Sleigh Ride\", \"Streams\": 10508459, \"Artist\": \"The Ronettes\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5ASM6Qjiav2xPe7gRkQMsQ\", \"Genre\": \"[]\", \"Release Date\": \"1963\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 50.0, \"Danceability\": 0.529, \"Energy\": 0.772, \"Loudness\": -7.013, \"Speechiness\": 0.0287, \"Acousticness\": 0.403, \"Liveness\": 0.316, \"Tempo\": 91.751, \"Duration (ms)\": 181267.0, \"Valence\": 0.853, \"Chord\": \"D\"}, {\"Index\": 633, \"Highest Charting Position\": 17, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Do They Know It's Christmas? - 1984 Version\", \"Streams\": 10476212, \"Artist\": \"Band Aid\", \"Artist Followers\": 4883.0, \"Song ID\": \"0247StOpd3AkeBQzANX4Zf\", \"Genre\": \"['musical advocacy']\", \"Release Date\": \"2004-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 51.0, \"Danceability\": 0.599, \"Energy\": 0.642, \"Loudness\": -6.936, \"Speechiness\": 0.0363, \"Acousticness\": 0.164, \"Liveness\": 0.0992, \"Tempo\": 115.412, \"Duration (ms)\": 222533.0, \"Valence\": 0.349, \"Chord\": \"C\"}, {\"Index\": 634, \"Highest Charting Position\": 23, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Wonderful Christmastime - Edited Version / Remastered 2011\", \"Streams\": 9882989, \"Artist\": \"Paul McCartney\", \"Artist Followers\": 3609658.0, \"Song ID\": \"1SV1fxF65n9NhRHp3KlBuu\", \"Genre\": \"['album rock', 'art rock', 'beatlesque', 'classic rock', 'mellow gold', 'rock', 'soft rock']\", \"Release Date\": \"1980-05-16\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 51.0, \"Danceability\": 0.774, \"Energy\": 0.511, \"Loudness\": -8.914, \"Speechiness\": 0.0319, \"Acousticness\": 0.322, \"Liveness\": 0.0672, \"Tempo\": 94.736, \"Duration (ms)\": 227653.0, \"Valence\": 0.771, \"Chord\": \"B\"}, {\"Index\": 635, \"Highest Charting Position\": 21, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Holly Jolly Christmas\", \"Streams\": 9852792, \"Artist\": \"Michael Bubl\\u00e9\", \"Artist Followers\": 4702232.0, \"Song ID\": \"5PuKlCjfEVIXl0ZBp5ZW9g\", \"Genre\": \"['adult standards', 'canadian pop', 'jazz pop', 'lounge']\", \"Release Date\": \"2012-11-09\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 48.0, \"Danceability\": 0.647, \"Energy\": 0.465, \"Loudness\": -8.308, \"Speechiness\": 0.0428, \"Acousticness\": 0.865, \"Liveness\": 0.0882, \"Tempo\": 151.251, \"Duration (ms)\": 119787.0, \"Valence\": 0.699, \"Chord\": \"G\"}, {\"Index\": 636, \"Highest Charting Position\": 24, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Happy Xmas (War Is Over) - Remastered 2010\", \"Streams\": 9509781, \"Artist\": \"John Lennon, Yoko Ono\", \"Artist Followers\": 4313100.0, \"Song ID\": \"27RYrbL6S02LNVhDWVl38b\", \"Genre\": \"['album rock', 'art rock', 'beatlesque', 'classic rock', 'folk rock', 'mellow gold', 'rock']\", \"Release Date\": \"2010-10-05\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 53.0, \"Danceability\": 0.321, \"Energy\": 0.64, \"Loudness\": -10.023, \"Speechiness\": 0.0324, \"Acousticness\": 0.28, \"Liveness\": 0.718, \"Tempo\": 146.172, \"Duration (ms)\": 214333.0, \"Valence\": 0.414, \"Chord\": \"D\"}, {\"Index\": 637, \"Highest Charting Position\": 22, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Driving Home for Christmas - 2019 Remaster\", \"Streams\": 8804531, \"Artist\": \"Chris Rea\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 638, \"Highest Charting Position\": 32, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"The Christmas Song (Merry Christmas To You)\", \"Streams\": 8478518, \"Artist\": \"Nat King Cole\", \"Artist Followers\": 1634288.0, \"Song ID\": \"4PS1e8f2LvuTFgUs1Cn3ON\", \"Genre\": \"['adult standards', 'lounge', 'soul', 'vocal jazz']\", \"Release Date\": \"1962\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 53.0, \"Danceability\": 0.319, \"Energy\": 0.21, \"Loudness\": -15.231, \"Speechiness\": 0.0341, \"Acousticness\": 0.92, \"Liveness\": 0.138, \"Tempo\": 78.696, \"Duration (ms)\": 192160.0, \"Valence\": 0.209, \"Chord\": \"C#/Db\"}, {\"Index\": 639, \"Highest Charting Position\": 39, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"White Christmas\", \"Streams\": 7045348, \"Artist\": \"Bing Crosby, Ken Darby Singers, John Scott Trotter & His Orchestra\", \"Artist Followers\": 359973.0, \"Song ID\": \"4so0Wek9Ig1p6CRCHuINwW\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'swing', 'vocal jazz']\", \"Release Date\": \"1942-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 51.0, \"Danceability\": 0.317, \"Energy\": 0.158, \"Loudness\": -16.485, \"Speechiness\": 0.0381, \"Acousticness\": 0.673, \"Liveness\": 0.338, \"Tempo\": 130.503, \"Duration (ms)\": 177480.0, \"Valence\": 0.247, \"Chord\": \"A\"}, {\"Index\": 640, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Slay3r\", \"Streams\": 6912271, \"Artist\": \"Playboi Carti\", \"Artist Followers\": 4958353.0, \"Song ID\": \"1eMNW1HQjF1dbb4GtnmpaX\", \"Genre\": \"['atl hip hop', 'plugg', 'rap', 'trap']\", \"Release Date\": \"2020-12-25\", \"Weeks Charted\": \"2020-12-25--2021-01-01\", \"Popularity\": 63.0, \"Danceability\": 0.885, \"Energy\": 0.661, \"Loudness\": -5.062, \"Speechiness\": 0.141, \"Acousticness\": 0.165, \"Liveness\": 0.334, \"Tempo\": 140.028, \"Duration (ms)\": 164591.0, \"Valence\": 0.436, \"Chord\": \"E\"}, {\"Index\": 641, \"Highest Charting Position\": 42, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"A Holly Jolly Christmas - Single Version\", \"Streams\": 6716353, \"Artist\": \"Burl Ives\", \"Artist Followers\": 58479.0, \"Song ID\": \"77khP2fIVhSW23NwxrRluh\", \"Genre\": \"['adult standards', 'american folk revival']\", \"Release Date\": \"1965-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 49.0, \"Danceability\": 0.683, \"Energy\": 0.375, \"Loudness\": -13.056, \"Speechiness\": 0.0303, \"Acousticness\": 0.579, \"Liveness\": 0.076, \"Tempo\": 140.467, \"Duration (ms)\": 135533.0, \"Valence\": 0.888, \"Chord\": \"C\"}, {\"Index\": 642, \"Highest Charting Position\": 47, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Fairytale of New York (feat. Kirsty MacColl)\", \"Streams\": 6404964, \"Artist\": \"The Pogues\", \"Artist Followers\": 382997.0, \"Song ID\": \"3VTNVsTTu05dmTsVFrmGpK\", \"Genre\": \"['celtic', 'celtic punk', 'celtic rock', 'folk punk', 'irish folk', 'punk']\", \"Release Date\": \"1988-09-05\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 55.0, \"Danceability\": 0.271, \"Energy\": 0.551, \"Loudness\": -7.48, \"Speechiness\": 0.0457, \"Acousticness\": 0.582, \"Liveness\": 0.256, \"Tempo\": 78.111, \"Duration (ms)\": 272467.0, \"Valence\": 0.428, \"Chord\": \"D\"}, {\"Index\": 643, \"Highest Charting Position\": 38, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Merry Christmas Everyone\", \"Streams\": 6052105, \"Artist\": \"Shakin' Stevens\", \"Artist Followers\": 99249.0, \"Song ID\": \"2TE4xW3ImvpltVU0cPcKUn\", \"Genre\": \"['classic uk pop', 'new wave pop', 'rock-and-roll', 'rockabilly', 'soft rock']\", \"Release Date\": \"1991-11-25\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 47.0, \"Danceability\": 0.534, \"Energy\": 0.904, \"Loudness\": -3.315, \"Speechiness\": 0.0369, \"Acousticness\": 0.129, \"Liveness\": 0.128, \"Tempo\": 202.899, \"Duration (ms)\": 220160.0, \"Valence\": 0.96, \"Chord\": \"A\"}, {\"Index\": 644, \"Highest Charting Position\": 62, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Blue Christmas\", \"Streams\": 6007011, \"Artist\": \"Elvis Presley\", \"Artist Followers\": 5698788.0, \"Song ID\": \"3QiAAp20rPC3dcAtKtMaqQ\", \"Genre\": \"['rock-and-roll', 'rockabilly']\", \"Release Date\": \"1957-10-15\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 49.0, \"Danceability\": 0.465, \"Energy\": 0.27, \"Loudness\": -16.661, \"Speechiness\": 0.0425, \"Acousticness\": 0.9, \"Liveness\": 0.145, \"Tempo\": 94.518, \"Duration (ms)\": 129173.0, \"Valence\": 0.58, \"Chord\": \"E\"}, {\"Index\": 645, \"Highest Charting Position\": 65, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Run Rudolph Run - Single Version\", \"Streams\": 5802508, \"Artist\": \"Chuck Berry\", \"Artist Followers\": 1251372.0, \"Song ID\": \"47CIT5hMphuMQkpeyfGQTL\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 0.0, \"Danceability\": 0.647, \"Energy\": 0.876, \"Loudness\": -5.662, \"Speechiness\": 0.185, \"Acousticness\": 0.881, \"Liveness\": 0.26, \"Tempo\": 151.925, \"Duration (ms)\": 162897.0, \"Valence\": 0.949, \"Chord\": \"A#/Bb\"}, {\"Index\": 646, \"Highest Charting Position\": 59, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Claus Is Coming To Town\", \"Streams\": 5801639, \"Artist\": \"The Jackson 5\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5Gz7EYD7JAmItA7FbhKgKb\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 0.0, \"Danceability\": 0.691, \"Energy\": 0.776, \"Loudness\": -4.177, \"Speechiness\": 0.0341, \"Acousticness\": 0.458, \"Liveness\": 0.33, \"Tempo\": 146.861, \"Duration (ms)\": 144080.0, \"Valence\": 0.961, \"Chord\": \"C\"}, {\"Index\": 647, \"Highest Charting Position\": 52, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Baby\", \"Streams\": 5687085, \"Artist\": \"Kylie Minogue\", \"Artist Followers\": 1324920.0, \"Song ID\": \"0cM5URUqqQTpJWonmdzF1J\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'electropop', 'eurodance', 'europop', 'new wave pop', 'pop']\", \"Release Date\": \"2010-11-30\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 42.0, \"Danceability\": 0.685, \"Energy\": 0.391, \"Loudness\": -7.183, \"Speechiness\": 0.0435, \"Acousticness\": 0.744, \"Liveness\": 0.142, \"Tempo\": 87.101, \"Duration (ms)\": 202547.0, \"Valence\": 0.443, \"Chord\": \"C#/Db\"}, {\"Index\": 648, \"Highest Charting Position\": 60, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"It's Beginning to Look a Lot Like Christmas (with Mitchell Ayres & His Orchestra)\", \"Streams\": 5422082, \"Artist\": \"Perry Como, The Fontane Sisters\", \"Artist Followers\": 336373.0, \"Song ID\": \"2pXpURmn6zC5ZYDMms6fwa\", \"Genre\": \"['adult standards', 'brill building pop', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"1999-08-20\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 49.0, \"Danceability\": 0.724, \"Energy\": 0.276, \"Loudness\": -12.25, \"Speechiness\": 0.0599, \"Acousticness\": 0.76, \"Liveness\": 0.116, \"Tempo\": 112.874, \"Duration (ms)\": 155933.0, \"Valence\": 0.718, \"Chord\": \"G\"}, {\"Index\": 649, \"Highest Charting Position\": 69, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas (Baby Please Come Home)\", \"Streams\": 5394054, \"Artist\": \"Darlene Love\", \"Artist Followers\": 1251372.0, \"Song ID\": \"46pF1zFimM582ss1PrMy68\", \"Genre\": \"[]\", \"Release Date\": \"1963\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-12-04--2020-12-11\", \"Popularity\": 45.0, \"Danceability\": 0.325, \"Energy\": 0.759, \"Loudness\": -7.146, \"Speechiness\": 0.053, \"Acousticness\": 0.395, \"Liveness\": 0.0773, \"Tempo\": 126.627, \"Duration (ms)\": 166453.0, \"Valence\": 0.36, \"Chord\": \"G#/Ab\"}, {\"Index\": 650, \"Highest Charting Position\": 66, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Step Into Christmas\", \"Streams\": 5353591, \"Artist\": \"Elton John\", \"Artist Followers\": 7504724.0, \"Song ID\": \"6sBWmE23q6xQHlnEZ8jYPT\", \"Genre\": \"['glam rock', 'mellow gold', 'piano rock']\", \"Release Date\": \"1973-10-05\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 43.0, \"Danceability\": 0.526, \"Energy\": 0.925, \"Loudness\": -5.584, \"Speechiness\": 0.0363, \"Acousticness\": 0.102, \"Liveness\": 0.305, \"Tempo\": 140.308, \"Duration (ms)\": 272394.0, \"Valence\": 0.819, \"Chord\": \"D\"}, {\"Index\": 651, \"Highest Charting Position\": 54, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Show Out (with Skepta & Pop Smoke)\", \"Streams\": 5209372, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"5CFJRZRq6sdKKtRwNPWbYv\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 76.0, \"Danceability\": 0.619, \"Energy\": 0.589, \"Loudness\": -6.531, \"Speechiness\": 0.124, \"Acousticness\": 0.43, \"Liveness\": 0.378, \"Tempo\": 143.896, \"Duration (ms)\": 174960.0, \"Valence\": 0.158, \"Chord\": \"C#/Db\"}, {\"Index\": 652, \"Highest Charting Position\": 166, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Investe Em Mim\", \"Streams\": 5191001, \"Artist\": \"Jonas Esticado\", \"Artist Followers\": 1293055.0, \"Song ID\": \"15k1TDabqSEmyXOwMq9RM7\", \"Genre\": \"['forro', 'sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 72.0, \"Danceability\": 0.632, \"Energy\": 0.953, \"Loudness\": -1.283, \"Speechiness\": 0.0325, \"Acousticness\": 0.317, \"Liveness\": 0.125, \"Tempo\": 160.061, \"Duration (ms)\": 186533.0, \"Valence\": 0.798, \"Chord\": \"A\"}, {\"Index\": 653, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Lance Individual\", \"Streams\": 5152906, \"Artist\": \"Jorge & Mateus\", \"Artist Followers\": 15019109.0, \"Song ID\": \"7GLWWrk1YlkPYqJK3ynIA0\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-12-25--2021-01-01\", \"Popularity\": 72.0, \"Danceability\": 0.752, \"Energy\": 0.62, \"Loudness\": -5.536, \"Speechiness\": 0.0509, \"Acousticness\": 0.309, \"Liveness\": 0.075, \"Tempo\": 117.399, \"Duration (ms)\": 164459.0, \"Valence\": 0.962, \"Chord\": \"F\"}, {\"Index\": 654, \"Highest Charting Position\": 71, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Jingle Bell Rock - Daryl's Version\", \"Streams\": 10522305, \"Artist\": \"Daryl Hall & John Oates\", \"Artist Followers\": 1549216.0, \"Song ID\": \"6pVW5LRWgeLaHudxauOTJU\", \"Genre\": \"['album rock', 'classic rock', 'mellow gold', 'rock', 'soft rock', 'yacht rock']\", \"Release Date\": \"1983-11-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 43.0, \"Danceability\": 0.666, \"Energy\": 0.841, \"Loudness\": -3.592, \"Speechiness\": 0.0312, \"Acousticness\": 0.613, \"Liveness\": 0.113, \"Tempo\": 128.706, \"Duration (ms)\": 126360.0, \"Valence\": 0.84, \"Chord\": \"D\"}, {\"Index\": 655, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Thank God It's Christmas - Non-Album Single\", \"Streams\": 10509961, \"Artist\": \"Queen\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 656, \"Highest Charting Position\": 74, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas Lights\", \"Streams\": 10455065, \"Artist\": \"Coldplay\", \"Artist Followers\": 31161671.0, \"Song ID\": \"4QVdnpSO5JGMFOEl6ys4RQ\", \"Genre\": \"['permanent wave', 'pop']\", \"Release Date\": \"2016-12-16\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 53.0, \"Danceability\": 0.295, \"Energy\": 0.496, \"Loudness\": -9.478, \"Speechiness\": 0.0327, \"Acousticness\": 0.207, \"Liveness\": 0.858, \"Tempo\": 132.062, \"Duration (ms)\": 268521.0, \"Valence\": 0.224, \"Chord\": \"G\"}, {\"Index\": 657, \"Highest Charting Position\": 83, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Have Yourself A Merry Little Christmas\", \"Streams\": 9548924, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"1Qi2wh8fFgDV7tl4Sj3f2K\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2014-12-05\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 46.0, \"Danceability\": 0.438, \"Energy\": 0.178, \"Loudness\": -9.402, \"Speechiness\": 0.0414, \"Acousticness\": 0.957, \"Liveness\": 0.316, \"Tempo\": 75.248, \"Duration (ms)\": 170964.0, \"Valence\": 0.344, \"Chord\": \"F\"}, {\"Index\": 658, \"Highest Charting Position\": 85, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa's Coming for Us\", \"Streams\": 9474711, \"Artist\": \"Sia\", \"Artist Followers\": 20528724.0, \"Song ID\": \"1N1ZpYUJc9fwrqk53FGgWv\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'pop']\", \"Release Date\": \"2018-11-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 49.0, \"Danceability\": 0.547, \"Energy\": 0.814, \"Loudness\": -6.191, \"Speechiness\": 0.12, \"Acousticness\": 0.0215, \"Liveness\": 0.0475, \"Tempo\": 92.986, \"Duration (ms)\": 205267.0, \"Valence\": 0.724, \"Chord\": \"C#/Db\"}, {\"Index\": 659, \"Highest Charting Position\": 86, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"My Only Wish (This Year)\", \"Streams\": 9457199, \"Artist\": \"Britney Spears\", \"Artist Followers\": 9470311.0, \"Song ID\": \"0YWUHZPJVg4iujddsJDwhM\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2000-11-14\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-04--2020-12-11\", \"Popularity\": 43.0, \"Danceability\": 0.669, \"Energy\": 0.843, \"Loudness\": -3.766, \"Speechiness\": 0.0268, \"Acousticness\": 0.169, \"Liveness\": 0.195, \"Tempo\": 147.08, \"Duration (ms)\": 255400.0, \"Valence\": 0.702, \"Chord\": \"C\"}, {\"Index\": 660, \"Highest Charting Position\": 89, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Baby, It's Cold Outside (feat. Meghan Trainor)\", \"Streams\": 9270017, \"Artist\": \"Brett Eldredge\", \"Artist Followers\": 1298537.0, \"Song ID\": \"5Q2P43CJra0uRAogjHyJDK\", \"Genre\": \"['contemporary country', 'country', 'country road', 'modern country rock']\", \"Release Date\": \"2016-10-28\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 44.0, \"Danceability\": 0.583, \"Energy\": 0.572, \"Loudness\": -4.776, \"Speechiness\": 0.0366, \"Acousticness\": 0.738, \"Liveness\": 0.266, \"Tempo\": 113.998, \"Duration (ms)\": 173560.0, \"Valence\": 0.684, \"Chord\": \"C#/Db\"}, {\"Index\": 661, \"Highest Charting Position\": 92, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Like It's Christmas\", \"Streams\": 9167304, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"1OjmlSFuzYflWjSMTCyTJv\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-04--2020-12-11\", \"Popularity\": 47.0, \"Danceability\": 0.725, \"Energy\": 0.571, \"Loudness\": -6.007, \"Speechiness\": 0.102, \"Acousticness\": 0.0183, \"Liveness\": 0.0519, \"Tempo\": 146.035, \"Duration (ms)\": 200880.0, \"Valence\": 0.61, \"Chord\": \"C#/Db\"}, {\"Index\": 662, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas Without You\", \"Streams\": 8813922, \"Artist\": \"Ava Max\", \"Artist Followers\": 3916979.0, \"Song ID\": \"1QLZKzC2pjP4ySf4ALrNhm\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-10-15\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 45.0, \"Danceability\": 0.654, \"Energy\": 0.596, \"Loudness\": -4.68, \"Speechiness\": 0.0458, \"Acousticness\": 0.424, \"Liveness\": 0.11, \"Tempo\": 118.078, \"Duration (ms)\": 169245.0, \"Valence\": 0.382, \"Chord\": \"C#/Db\"}, {\"Index\": 663, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"You Make It Feel Like Christmas (feat. Blake Shelton)\", \"Streams\": 8696354, \"Artist\": \"Gwen Stefani\", \"Artist Followers\": 4805333.0, \"Song ID\": \"2OQ6a4CfUeYskpTTgyawyJ\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'post-teen pop', 'urban contemporary']\", \"Release Date\": \"2017-10-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.635, \"Energy\": 0.87, \"Loudness\": -4.291, \"Speechiness\": 0.04, \"Acousticness\": 0.0156, \"Liveness\": 0.118, \"Tempo\": 93.0, \"Duration (ms)\": 156773.0, \"Valence\": 0.912, \"Chord\": \"D\"}, {\"Index\": 664, \"Highest Charting Position\": 107, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Gnat\", \"Streams\": 8614955, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"6cS9PmLky2NhLOhpIsUlow\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 70.0, \"Danceability\": 0.835, \"Energy\": 0.869, \"Loudness\": -4.582, \"Speechiness\": 0.27, \"Acousticness\": 0.248, \"Liveness\": 0.462, \"Tempo\": 140.945, \"Duration (ms)\": 224656.0, \"Valence\": 0.82, \"Chord\": \"A#/Bb\"}, {\"Index\": 665, \"Highest Charting Position\": 111, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Joy To The World\", \"Streams\": 8387899, \"Artist\": \"Nat King Cole\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5oWFPbd340pwiXKMO1CQRy\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 0.0, \"Danceability\": 0.59, \"Energy\": 0.305, \"Loudness\": -12.955, \"Speechiness\": 0.032, \"Acousticness\": 0.894, \"Liveness\": 0.14, \"Tempo\": 102.103, \"Duration (ms)\": 86760.0, \"Valence\": 0.545, \"Chord\": \"A#/Bb\"}, {\"Index\": 666, \"Highest Charting Position\": 117, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Claus Is Coming to Town\", \"Streams\": 8177832, \"Artist\": \"Michael Bubl\\u00e9\", \"Artist Followers\": 4702232.0, \"Song ID\": \"1RMDXedcRno6rDBCbNHDJf\", \"Genre\": \"['adult standards', 'canadian pop', 'jazz pop', 'lounge']\", \"Release Date\": \"2012-11-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.594, \"Energy\": 0.389, \"Loudness\": -7.109, \"Speechiness\": 0.0517, \"Acousticness\": 0.785, \"Liveness\": 0.0313, \"Tempo\": 122.331, \"Duration (ms)\": 171093.0, \"Valence\": 0.396, \"Chord\": \"A#/Bb\"}, {\"Index\": 667, \"Highest Charting Position\": 119, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Baby It's Cold Outside (duet with Michael Bubl\\u00e9)\", \"Streams\": 8160534, \"Artist\": \"Idina Menzel\", \"Artist Followers\": 353571.0, \"Song ID\": \"0Ie5uiv54KgCr7P4sYDTHl\", \"Genre\": \"['hollywood', 'show tunes']\", \"Release Date\": \"2014-10-10\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 47.0, \"Danceability\": 0.553, \"Energy\": 0.476, \"Loudness\": -8.869, \"Speechiness\": 0.0649, \"Acousticness\": 0.647, \"Liveness\": 0.281, \"Tempo\": 113.401, \"Duration (ms)\": 166147.0, \"Valence\": 0.558, \"Chord\": \"C\"}, {\"Index\": 668, \"Highest Charting Position\": 22, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"\\u2018tis the damn season\", \"Streams\": 8115520, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7dW84mWkdWE5a6lFWxJCBG\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.575, \"Energy\": 0.434, \"Loudness\": -8.193, \"Speechiness\": 0.0312, \"Acousticness\": 0.735, \"Liveness\": 0.105, \"Tempo\": 145.916, \"Duration (ms)\": 229840.0, \"Valence\": 0.348, \"Chord\": \"F\"}, {\"Index\": 669, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"I Saw Mommy Kissing Santa Claus\", \"Streams\": 8064361, \"Artist\": \"The Jackson 5\", \"Artist Followers\": 1151360.0, \"Song ID\": \"15sxLiiChE5dCW3Y756oas\", \"Genre\": \"['motown', 'soul']\", \"Release Date\": \"1970-10-15\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.583, \"Energy\": 0.712, \"Loudness\": -8.222, \"Speechiness\": 0.0538, \"Acousticness\": 0.263, \"Liveness\": 0.817, \"Tempo\": 128.897, \"Duration (ms)\": 181267.0, \"Valence\": 0.614, \"Chord\": \"D#/Eb\"}, {\"Index\": 670, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Baby (with Henri Ren\\u00e9 & His Orchestra)\", \"Streams\": 8022773, \"Artist\": \"Eartha Kitt, Henri Rene & His Orchestra\", \"Artist Followers\": 127251.0, \"Song ID\": \"1foCxQtxBweJtZmdxhEHVO\", \"Genre\": \"['adult standards', 'lounge', 'torch song', 'vocal jazz']\", \"Release Date\": \"2002\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.7, \"Energy\": 0.139, \"Loudness\": -12.346, \"Speechiness\": 0.0607, \"Acousticness\": 0.902, \"Liveness\": 0.185, \"Tempo\": 84.485, \"Duration (ms)\": 206067.0, \"Valence\": 0.49, \"Chord\": \"G#/Ab\"}, {\"Index\": 671, \"Highest Charting Position\": 127, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Carol of the Bells\", \"Streams\": 7993078, \"Artist\": \"Mykola Dmytrovych Leontovych, John Williams\", \"Artist Followers\": 1024868.0, \"Song ID\": \"4tHqQMWSqmL6YjXwsqthDI\", \"Genre\": \"['soundtrack']\", \"Release Date\": \"1990\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 51.0, \"Danceability\": 0.418, \"Energy\": 0.106, \"Loudness\": -22.507, \"Speechiness\": 0.0448, \"Acousticness\": 0.994, \"Liveness\": 0.179, \"Tempo\": 46.718, \"Duration (ms)\": 85267.0, \"Valence\": 0.8, \"Chord\": \"G#/Ab\"}, {\"Index\": 672, \"Highest Charting Position\": 19, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"gold rush\", \"Streams\": 7901968, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5BK0uqwY9DNfZ630STAEaq\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 70.0, \"Danceability\": 0.512, \"Energy\": 0.462, \"Loudness\": -10.491, \"Speechiness\": 0.0408, \"Acousticness\": 0.83, \"Liveness\": 0.121, \"Tempo\": 112.05, \"Duration (ms)\": 185320.0, \"Valence\": 0.353, \"Chord\": \"A\"}, {\"Index\": 673, \"Highest Charting Position\": 133, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"What Christmas Means To Me\", \"Streams\": 7792643, \"Artist\": \"Stevie Wonder\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6Wn9zkkbWdK42uXCcADkRq\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 0.0, \"Danceability\": 0.545, \"Energy\": 0.7, \"Loudness\": -6.961, \"Speechiness\": 0.0323, \"Acousticness\": 0.0982, \"Liveness\": 0.1, \"Tempo\": 83.506, \"Duration (ms)\": 148147.0, \"Valence\": 0.799, \"Chord\": \"F\"}, {\"Index\": 674, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"The Christmas Song (Shawn Mendes & Camila Cabello)\", \"Streams\": 7536851, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 33893352.0, \"Song ID\": \"0fwxmtpxpMmEMphmJbCAEx\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2020-12-07\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 42.0, \"Danceability\": 0.341, \"Energy\": 0.181, \"Loudness\": -12.073, \"Speechiness\": 0.0366, \"Acousticness\": 0.888, \"Liveness\": 0.137, \"Tempo\": 83.608, \"Duration (ms)\": 196254.0, \"Valence\": 0.212, \"Chord\": \"D\"}, {\"Index\": 675, \"Highest Charting Position\": 144, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Baby, It's Cold Outside\", \"Streams\": 7367482, \"Artist\": \"Dean Martin\", \"Artist Followers\": 1139096.0, \"Song ID\": \"4MrfQL4TYQXJBlZYpAHTuE\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"1959-01-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.469, \"Energy\": 0.196, \"Loudness\": -16.093, \"Speechiness\": 0.0571, \"Acousticness\": 0.882, \"Liveness\": 0.0513, \"Tempo\": 130.036, \"Duration (ms)\": 143733.0, \"Valence\": 0.537, \"Chord\": \"C\"}, {\"Index\": 676, \"Highest Charting Position\": 145, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Claus Is Comin' to Town - Live at C.W. Post College, Greenvale, NY - December 1975\", \"Streams\": 7363913, \"Artist\": \"Bruce Springsteen\", \"Artist Followers\": 4224071.0, \"Song ID\": \"6s2wpWPFPAgKg2LXxi1Oee\", \"Genre\": \"['classic rock', 'heartland rock', 'mellow gold', 'permanent wave', 'rock', 'singer-songwriter']\", \"Release Date\": \"1981\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.357, \"Energy\": 0.668, \"Loudness\": -8.444, \"Speechiness\": 0.0479, \"Acousticness\": 0.362, \"Liveness\": 0.727, \"Tempo\": 139.986, \"Duration (ms)\": 267600.0, \"Valence\": 0.407, \"Chord\": \"C\"}, {\"Index\": 677, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"One More Sleep\", \"Streams\": 7350024, \"Artist\": \"Leona Lewis\", \"Artist Followers\": 2877234.0, \"Song ID\": \"78pn8k7RogKo2oxl0DyX6d\", \"Genre\": \"['british soul', 'dance pop', 'europop', 'pop', 'post-teen pop', 'talent show']\", \"Release Date\": \"2013-12-02\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 42.0, \"Danceability\": 0.638, \"Energy\": 0.813, \"Loudness\": -3.849, \"Speechiness\": 0.0362, \"Acousticness\": 0.464, \"Liveness\": 0.344, \"Tempo\": 112.986, \"Duration (ms)\": 239587.0, \"Valence\": 0.754, \"Chord\": \"B\"}, {\"Index\": 678, \"Highest Charting Position\": 149, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Little Saint Nick - 1991 Remix\", \"Streams\": 7301381, \"Artist\": \"The Beach Boys\", \"Artist Followers\": 1251372.0, \"Song ID\": \"63Lk6VuXdj7S58R3wLdv9r\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 0.0, \"Danceability\": 0.602, \"Energy\": 0.553, \"Loudness\": -9.336, \"Speechiness\": 0.0328, \"Acousticness\": 0.108, \"Liveness\": 0.0512, \"Tempo\": 130.594, \"Duration (ms)\": 118840.0, \"Valence\": 0.971, \"Chord\": \"B\"}, {\"Index\": 679, \"Highest Charting Position\": 150, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Naughty List (with Dixie)\", \"Streams\": 7299201, \"Artist\": \"Liam Payne\", \"Artist Followers\": 8037861.0, \"Song ID\": \"2Y0ktCGrGoGcQFXsGztvhi\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 51.0, \"Danceability\": 0.619, \"Energy\": 0.771, \"Loudness\": -2.204, \"Speechiness\": 0.0601, \"Acousticness\": 0.0318, \"Liveness\": 0.114, \"Tempo\": 81.966, \"Duration (ms)\": 154747.0, \"Valence\": 0.704, \"Chord\": \"A\"}, {\"Index\": 680, \"Highest Charting Position\": 152, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"I'll Be Home\", \"Streams\": 7281773, \"Artist\": \"Meghan Trainor\", \"Artist Followers\": 10606572.0, \"Song ID\": \"0lTurWECr2XL607eJAj1A3\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2015-01-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 45.0, \"Danceability\": 0.542, \"Energy\": 0.37, \"Loudness\": -7.779, \"Speechiness\": 0.0257, \"Acousticness\": 0.318, \"Liveness\": 0.108, \"Tempo\": 84.796, \"Duration (ms)\": 219653.0, \"Valence\": 0.289, \"Chord\": \"D\"}, {\"Index\": 681, \"Highest Charting Position\": 156, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Rudolph The Red-Nosed Reindeer\", \"Streams\": 7227612, \"Artist\": \"Dean Martin\", \"Artist Followers\": 1139096.0, \"Song ID\": \"2L9QLAhrvtP4EYg1lY0Tnw\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"1959-01-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.478, \"Energy\": 0.201, \"Loudness\": -16.768, \"Speechiness\": 0.0332, \"Acousticness\": 0.919, \"Liveness\": 0.0854, \"Tempo\": 136.471, \"Duration (ms)\": 135760.0, \"Valence\": 0.857, \"Chord\": \"G\"}, {\"Index\": 682, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Mistletoe And Holly - Remastered 1999\", \"Streams\": 7225080, \"Artist\": \"Frank Sinatra\", \"Artist Followers\": 4953667.0, \"Song ID\": \"7faDzZnZYqTyYThx2sbHVQ\", \"Genre\": \"['adult standards', 'easy listening', 'lounge']\", \"Release Date\": \"1957-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 38.0, \"Danceability\": 0.607, \"Energy\": 0.103, \"Loudness\": -14.405, \"Speechiness\": 0.0404, \"Acousticness\": 0.804, \"Liveness\": 0.076, \"Tempo\": 110.378, \"Duration (ms)\": 136427.0, \"Valence\": 0.341, \"Chord\": \"A\"}, {\"Index\": 683, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Jingle Bells - Remastered 1999\", \"Streams\": 7182262, \"Artist\": \"Frank Sinatra\", \"Artist Followers\": 4953667.0, \"Song ID\": \"4HEOgBHRCExyYVeTyrXsnL\", \"Genre\": \"['adult standards', 'easy listening', 'lounge']\", \"Release Date\": \"1957-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 36.0, \"Danceability\": 0.512, \"Energy\": 0.339, \"Loudness\": -13.119, \"Speechiness\": 0.0498, \"Acousticness\": 0.727, \"Liveness\": 0.0977, \"Tempo\": 174.609, \"Duration (ms)\": 120693.0, \"Valence\": 0.951, \"Chord\": \"G#/Ab\"}, {\"Index\": 684, \"Highest Charting Position\": 160, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Oh Santa! (feat. Ariana Grande & Jennifer Hudson)\", \"Streams\": 7170169, \"Artist\": \"Mariah Carey\", \"Artist Followers\": 6931357.0, \"Song ID\": \"1Ri9P0ZPrqr6h0REDRdJBd\", \"Genre\": \"['dance pop', 'pop', 'r&b', 'urban contemporary']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 47.0, \"Danceability\": 0.648, \"Energy\": 0.938, \"Loudness\": -3.298, \"Speechiness\": 0.115, \"Acousticness\": 0.0339, \"Liveness\": 0.0564, \"Tempo\": 78.496, \"Duration (ms)\": 200467.0, \"Valence\": 0.849, \"Chord\": \"C#/Db\"}, {\"Index\": 685, \"Highest Charting Position\": 161, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Do You Hear What I Hear? - Remastered 2006\", \"Streams\": 7149158, \"Artist\": \"Bing Crosby\", \"Artist Followers\": 359973.0, \"Song ID\": \"5aDoUmxBsbdpS16alksb5Z\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'swing', 'vocal jazz']\", \"Release Date\": \"2006-01-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.566, \"Energy\": 0.246, \"Loudness\": -15.499, \"Speechiness\": 0.0276, \"Acousticness\": 0.813, \"Liveness\": 0.195, \"Tempo\": 101.529, \"Duration (ms)\": 165667.0, \"Valence\": 0.412, \"Chord\": \"A#/Bb\"}, {\"Index\": 686, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Hallelujah\", \"Streams\": 6985392, \"Artist\": \"Pentatonix\", \"Artist Followers\": 3083825.0, \"Song ID\": \"0HZk0QsXPhMNAWNDR3rYE8\", \"Genre\": \"['a cappella']\", \"Release Date\": \"2017-12-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 60.0, \"Danceability\": 0.364, \"Energy\": 0.378, \"Loudness\": -7.381, \"Speechiness\": 0.0331, \"Acousticness\": 0.47, \"Liveness\": 0.339, \"Tempo\": 89.918, \"Duration (ms)\": 268960.0, \"Valence\": 0.366, \"Chord\": \"G\"}, {\"Index\": 687, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"This Christmas\", \"Streams\": 6809438, \"Artist\": \"Donny Hathaway\", \"Artist Followers\": 424935.0, \"Song ID\": \"38xhBO2AKrJnjdjVnhJES6\", \"Genre\": \"['chicago soul', 'classic soul', 'funk', 'motown', 'neo soul', 'quiet storm', 'soul', 'southern soul']\", \"Release Date\": \"1990-04-03\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 42.0, \"Danceability\": 0.634, \"Energy\": 0.645, \"Loudness\": -9.2, \"Speechiness\": 0.0376, \"Acousticness\": 0.292, \"Liveness\": 0.246, \"Tempo\": 93.047, \"Duration (ms)\": 231173.0, \"Valence\": 0.677, \"Chord\": \"F\"}, {\"Index\": 688, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Winter Wonderland\", \"Streams\": 6680928, \"Artist\": \"Tony Bennett\", \"Artist Followers\": 659472.0, \"Song ID\": \"6kkJlaBYdyFcwCg67hW40t\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"2014-12-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 29.0, \"Danceability\": 0.604, \"Energy\": 0.497, \"Loudness\": -6.676, \"Speechiness\": 0.0319, \"Acousticness\": 0.727, \"Liveness\": 0.102, \"Tempo\": 126.011, \"Duration (ms)\": 149307.0, \"Valence\": 0.72, \"Chord\": \"C#/Db\"}, {\"Index\": 689, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas Tree Farm\", \"Streams\": 6657404, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2mvabkN1i2gLnGAPUVdwek\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 52.0, \"Danceability\": 0.598, \"Energy\": 0.68, \"Loudness\": -4.505, \"Speechiness\": 0.0331, \"Acousticness\": 0.06, \"Liveness\": 0.324, \"Tempo\": 134.002, \"Duration (ms)\": 228027.0, \"Valence\": 0.437, \"Chord\": \"G\"}, {\"Index\": 690, \"Highest Charting Position\": 182, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Cozy Little Christmas\", \"Streams\": 6652130, \"Artist\": \"Katy Perry\", \"Artist Followers\": 18936929.0, \"Song ID\": \"02FaKXXL7KUtRc7K0k54tL\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-11-15\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.774, \"Energy\": 0.608, \"Loudness\": -6.264, \"Speechiness\": 0.128, \"Acousticness\": 0.128, \"Liveness\": 0.0895, \"Tempo\": 137.494, \"Duration (ms)\": 182521.0, \"Valence\": 0.56, \"Chord\": \"G\"}, {\"Index\": 691, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Merry Christmas, Happy Holidays\", \"Streams\": 6635128, \"Artist\": \"*NSYNC\", \"Artist Followers\": 1564750.0, \"Song ID\": \"4v9WbaxW8HdjqfUiWYWsII\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"1998-10-30\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.643, \"Energy\": 0.939, \"Loudness\": -3.967, \"Speechiness\": 0.0463, \"Acousticness\": 0.104, \"Liveness\": 0.881, \"Tempo\": 104.999, \"Duration (ms)\": 255307.0, \"Valence\": 0.756, \"Chord\": \"F\"}, {\"Index\": 692, \"Highest Charting Position\": 24, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"tolerate it\", \"Streams\": 6635109, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0PurA4JVJ8YQgSVopY8fn6\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 67.0, \"Danceability\": 0.316, \"Energy\": 0.361, \"Loudness\": -10.381, \"Speechiness\": 0.0488, \"Acousticness\": 0.878, \"Liveness\": 0.0797, \"Tempo\": 74.952, \"Duration (ms)\": 245440.0, \"Valence\": 0.221, \"Chord\": \"A\"}, {\"Index\": 693, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Please Come Home for Christmas - 2013 Remaster\", \"Streams\": 6400108, \"Artist\": \"Eagles\", \"Artist Followers\": 6896776.0, \"Song ID\": \"3QIoEi8Enr9uHffwInGIsC\", \"Genre\": \"['album rock', 'classic rock', 'country rock', 'folk rock', 'heartland rock', 'mellow gold', 'rock', 'soft rock', 'yacht rock']\", \"Release Date\": \"1994\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.612, \"Energy\": 0.289, \"Loudness\": -11.568, \"Speechiness\": 0.0421, \"Acousticness\": 0.599, \"Liveness\": 0.0561, \"Tempo\": 183.18, \"Duration (ms)\": 177440.0, \"Valence\": 0.466, \"Chord\": \"A\"}, {\"Index\": 694, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"My Kind Of Present\", \"Streams\": 6278993, \"Artist\": \"Meghan Trainor\", \"Artist Followers\": 10606572.0, \"Song ID\": \"2rkb8ijsPapKDMEh0cSe8I\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.485, \"Energy\": 0.444, \"Loudness\": -6.232, \"Speechiness\": 0.195, \"Acousticness\": 0.373, \"Liveness\": 0.0969, \"Tempo\": 179.967, \"Duration (ms)\": 161013.0, \"Valence\": 0.777, \"Chord\": \"C#/Db\"}, {\"Index\": 695, \"Highest Charting Position\": 28, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"happiness\", \"Streams\": 16213589, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"73YUReisjb3A9ActdLLjJQ\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 65.0, \"Danceability\": 0.559, \"Energy\": 0.334, \"Loudness\": -10.733, \"Speechiness\": 0.0376, \"Acousticness\": 0.87, \"Liveness\": 0.114, \"Tempo\": 122.079, \"Duration (ms)\": 315147.0, \"Valence\": 0.211, \"Chord\": \"B\"}, {\"Index\": 696, \"Highest Charting Position\": 34, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"ivy\", \"Streams\": 14519547, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"19CSr8rwW05VJL2F91KFNK\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.515, \"Energy\": 0.545, \"Loudness\": -9.277, \"Speechiness\": 0.0353, \"Acousticness\": 0.855, \"Liveness\": 0.0921, \"Tempo\": 88.856, \"Duration (ms)\": 260440.0, \"Valence\": 0.535, \"Chord\": \"D\"}, {\"Index\": 697, \"Highest Charting Position\": 38, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"dorothea\", \"Streams\": 14392788, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"670fUmXf4KQekzbEgaXyPA\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.605, \"Energy\": 0.488, \"Loudness\": -8.322, \"Speechiness\": 0.0264, \"Acousticness\": 0.696, \"Liveness\": 0.129, \"Tempo\": 119.966, \"Duration (ms)\": 225880.0, \"Valence\": 0.354, \"Chord\": \"E\"}, {\"Index\": 698, \"Highest Charting Position\": 39, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"coney island (feat. The National)\", \"Streams\": 14385703, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3k7ne7VmH43ZPWxPdvPUgR\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.537, \"Energy\": 0.537, \"Loudness\": -11.266, \"Speechiness\": 0.0617, \"Acousticness\": 0.819, \"Liveness\": 0.142, \"Tempo\": 107.895, \"Duration (ms)\": 275320.0, \"Valence\": 0.292, \"Chord\": \"G#/Ab\"}, {\"Index\": 699, \"Highest Charting Position\": 43, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"evermore (feat. Bon Iver)\", \"Streams\": 13810722, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3O5osWf1rSoKMwe6E9ZaXP\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.39, \"Energy\": 0.27, \"Loudness\": -10.673, \"Speechiness\": 0.0308, \"Acousticness\": 0.937, \"Liveness\": 0.111, \"Tempo\": 125.177, \"Duration (ms)\": 304107.0, \"Valence\": 0.32, \"Chord\": \"C#/Db\"}, {\"Index\": 700, \"Highest Charting Position\": 45, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"long story short\", \"Streams\": 13583538, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2o2sgVJIgFXk8GQjWTgI6U\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.546, \"Energy\": 0.73, \"Loudness\": -7.704, \"Speechiness\": 0.0417, \"Acousticness\": 0.66, \"Liveness\": 0.0972, \"Tempo\": 157.895, \"Duration (ms)\": 215920.0, \"Valence\": 0.573, \"Chord\": \"C\"}, {\"Index\": 701, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"cowboy like me\", \"Streams\": 12782098, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1XjHRolIXL2M1EEOUsGGR4\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.604, \"Energy\": 0.517, \"Loudness\": -9.014, \"Speechiness\": 0.0347, \"Acousticness\": 0.768, \"Liveness\": 0.123, \"Tempo\": 127.967, \"Duration (ms)\": 275040.0, \"Valence\": 0.511, \"Chord\": \"C\"}, {\"Index\": 702, \"Highest Charting Position\": 57, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"marjorie\", \"Streams\": 12234761, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"12ntTeqEeTg7GAVpe8Mhpl\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.535, \"Energy\": 0.561, \"Loudness\": -11.609, \"Speechiness\": 0.0484, \"Acousticness\": 0.876, \"Liveness\": 0.115, \"Tempo\": 96.103, \"Duration (ms)\": 257773.0, \"Valence\": 0.287, \"Chord\": \"F\"}, {\"Index\": 703, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"closure\", \"Streams\": 11245393, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"35rdVq36LMHQX0Suw9a6tK\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 62.0, \"Danceability\": 0.689, \"Energy\": 0.704, \"Loudness\": -10.813, \"Speechiness\": 0.245, \"Acousticness\": 0.835, \"Liveness\": 0.134, \"Tempo\": 151.884, \"Duration (ms)\": 180653.0, \"Valence\": 0.92, \"Chord\": \"A\"}, {\"Index\": 704, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"She Knows This\", \"Streams\": 10561183, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"1xzUQMiCoY5pdego0pHMeV\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.39, \"Energy\": 0.724, \"Loudness\": -7.607, \"Speechiness\": 0.0889, \"Acousticness\": 0.162, \"Liveness\": 0.393, \"Tempo\": 165.945, \"Duration (ms)\": 216560.0, \"Valence\": 0.312, \"Chord\": \"F#/Gb\"}, {\"Index\": 705, \"Highest Charting Position\": 97, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Another Day\", \"Streams\": 8901697, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"6myUpr3GDR80Dg3zqNTmmG\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 63.0, \"Danceability\": 0.646, \"Energy\": 0.758, \"Loudness\": -7.75, \"Speechiness\": 0.0708, \"Acousticness\": 0.556, \"Liveness\": 0.335, \"Tempo\": 172.995, \"Duration (ms)\": 199787.0, \"Valence\": 0.0642, \"Chord\": \"E\"}, {\"Index\": 706, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Solo Dolo, Pt. III\", \"Streams\": 7655623, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"27oVCAziETRbNuo5A8LNpg\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 61.0, \"Danceability\": 0.589, \"Energy\": 0.727, \"Loudness\": -6.907, \"Speechiness\": 0.0866, \"Acousticness\": 0.239, \"Liveness\": 0.164, \"Tempo\": 152.058, \"Duration (ms)\": 242267.0, \"Valence\": 0.52, \"Chord\": \"A#/Bb\"}, {\"Index\": 707, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Dive\", \"Streams\": 7524738, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"7Hc3YL8oDiAzbiAW32KXrw\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 60.0, \"Danceability\": 0.64, \"Energy\": 0.621, \"Loudness\": -8.269, \"Speechiness\": 0.0679, \"Acousticness\": 0.67, \"Liveness\": 0.36, \"Tempo\": 123.105, \"Duration (ms)\": 148707.0, \"Valence\": 0.332, \"Chord\": \"A\"}, {\"Index\": 708, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Heaven On Earth\", \"Streams\": 7117347, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"2koUj1Fn5TKFEkChSmBPIb\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 59.0, \"Danceability\": 0.786, \"Energy\": 0.61, \"Loudness\": -6.736, \"Speechiness\": 0.0558, \"Acousticness\": 0.379, \"Liveness\": 0.0765, \"Tempo\": 130.036, \"Duration (ms)\": 201093.0, \"Valence\": 0.228, \"Chord\": \"C\"}, {\"Index\": 709, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Sad People\", \"Streams\": 6865689, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"4nuAslShoN77tq12fzwjUq\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 62.0, \"Danceability\": 0.636, \"Energy\": 0.647, \"Loudness\": -6.971, \"Speechiness\": 0.0381, \"Acousticness\": 0.247, \"Liveness\": 0.113, \"Tempo\": 158.073, \"Duration (ms)\": 176027.0, \"Valence\": 0.416, \"Chord\": \"F\"}, {\"Index\": 710, \"Highest Charting Position\": 152, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Damaged\", \"Streams\": 6763705, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"2n7Ao4nyESBa5ti8gcAbBt\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 57.0, \"Danceability\": 0.625, \"Energy\": 0.581, \"Loudness\": -7.1, \"Speechiness\": 0.0316, \"Acousticness\": 0.553, \"Liveness\": 0.254, \"Tempo\": 142.04, \"Duration (ms)\": 150853.0, \"Valence\": 0.267, \"Chord\": \"G#/Ab\"}, {\"Index\": 711, \"Highest Charting Position\": 17, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"YO VISTO AS\\u00cd\", \"Streams\": 6388079, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5fROvzNghPid8mbKNDYvpJ\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 73.0, \"Danceability\": 0.688, \"Energy\": 0.881, \"Loudness\": -4.889, \"Speechiness\": 0.0474, \"Acousticness\": 0.0947, \"Liveness\": 0.0804, \"Tempo\": 123.013, \"Duration (ms)\": 191526.0, \"Valence\": 0.677, \"Chord\": \"G\"}, {\"Index\": 712, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Beautiful Trip\", \"Streams\": 6108393, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"4IIuCotvqijraSdnVLaFnM\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 54.0, \"Danceability\": 0.331, \"Energy\": 0.513, \"Loudness\": -15.392, \"Speechiness\": 0.632, \"Acousticness\": 0.972, \"Liveness\": 0.882, \"Tempo\": 133.971, \"Duration (ms)\": 37013.0, \"Valence\": 0.42, \"Chord\": \"B\"}, {\"Index\": 713, \"Highest Charting Position\": 185, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"The Void\", \"Streams\": 6068816, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"2yg7MXp8nSPaf61HVkhEr3\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 61.0, \"Danceability\": 0.464, \"Energy\": 0.459, \"Loudness\": -8.736, \"Speechiness\": 0.0314, \"Acousticness\": 0.365, \"Liveness\": 0.117, \"Tempo\": 142.017, \"Duration (ms)\": 325413.0, \"Valence\": 0.0786, \"Chord\": \"G\"}, {\"Index\": 714, \"Highest Charting Position\": 1, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"cardigan\", \"Streams\": 5845457, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"4R2kfaDFhslZEMJqAFNpdd\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-12-11--2020-12-18\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 79.0, \"Danceability\": 0.613, \"Energy\": 0.581, \"Loudness\": -8.588, \"Speechiness\": 0.0424, \"Acousticness\": 0.537, \"Liveness\": 0.25, \"Tempo\": 130.033, \"Duration (ms)\": 239560.0, \"Valence\": 0.551, \"Chord\": \"C\"}, {\"Index\": 715, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Real Shit (with benny blanco)\", \"Streams\": 9325928, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"3uVPLtkmDu8pDkYEAVqbgS\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-12-02\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 70.0, \"Danceability\": 0.703, \"Energy\": 0.703, \"Loudness\": -4.672, \"Speechiness\": 0.133, \"Acousticness\": 0.605, \"Liveness\": 0.12, \"Tempo\": 76.017, \"Duration (ms)\": 183783.0, \"Valence\": 0.697, \"Chord\": \"C#/Db\"}, {\"Index\": 716, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Teach Me How To Love\", \"Streams\": 7932101, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 33893352.0, \"Song ID\": \"5LZtB6nxvjIhUoElp3Zqk0\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 68.0, \"Danceability\": 0.592, \"Energy\": 0.885, \"Loudness\": -4.944, \"Speechiness\": 0.0807, \"Acousticness\": 0.0505, \"Liveness\": 0.0843, \"Tempo\": 98.991, \"Duration (ms)\": 202357.0, \"Valence\": 0.731, \"Chord\": \"A\"}, {\"Index\": 717, \"Highest Charting Position\": 138, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Blinding Lights (with ROSAL\\u00cdA) - Remix\", \"Streams\": 6653913, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"7MXgrcOQAJ5VwSNUL0lDd3\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 64.0, \"Danceability\": 0.49, \"Energy\": 0.694, \"Loudness\": -5.793, \"Speechiness\": 0.0618, \"Acousticness\": 0.0133, \"Liveness\": 0.0946, \"Tempo\": 170.903, \"Duration (ms)\": 216123.0, \"Valence\": 0.249, \"Chord\": \"F\"}, {\"Index\": 718, \"Highest Charting Position\": 15, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"WHATS POPPIN (feat. DaBaby, Tory Lanez & Lil Wayne) - Remix\", \"Streams\": 6567755, \"Artist\": \"Tory Lanez, Jack Harlow\", \"Artist Followers\": 3828418.0, \"Song ID\": \"2MbdDtCv5LUVjYy9RuGTgC\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-06-24\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 80.0, \"Danceability\": 0.904, \"Energy\": 0.723, \"Loudness\": -5.224, \"Speechiness\": 0.26, \"Acousticness\": 0.0631, \"Liveness\": 0.185, \"Tempo\": 145.013, \"Duration (ms)\": 227478.0, \"Valence\": 0.835, \"Chord\": \"B\"}, {\"Index\": 719, \"Highest Charting Position\": 29, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"TE DESEO LO MEJOR\", \"Streams\": 6204228, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"23XjN1s3DZC8Q9ZwuorYY4\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.763, \"Energy\": 0.597, \"Loudness\": -5.054, \"Speechiness\": 0.0416, \"Acousticness\": 0.158, \"Liveness\": 0.111, \"Tempo\": 126.054, \"Duration (ms)\": 139576.0, \"Valence\": 0.194, \"Chord\": \"C#/Db\"}, {\"Index\": 720, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Errbody\", \"Streams\": 5929516, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"6eVxH9Kyanzrw636zJRPcw\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-12-03\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 68.0, \"Danceability\": 0.887, \"Energy\": 0.606, \"Loudness\": -6.572, \"Speechiness\": 0.324, \"Acousticness\": 0.000407, \"Liveness\": 0.151, \"Tempo\": 139.995, \"Duration (ms)\": 210699.0, \"Valence\": 0.272, \"Chord\": \"D\"}, {\"Index\": 721, \"Highest Charting Position\": 86, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"Angels Like You\", \"Streams\": 5884221, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"1daDRI9ahBonbWD8YcxOIB\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 77.0, \"Danceability\": 0.672, \"Energy\": 0.642, \"Loudness\": -4.035, \"Speechiness\": 0.0313, \"Acousticness\": 0.0981, \"Liveness\": 0.1, \"Tempo\": 121.981, \"Duration (ms)\": 196453.0, \"Valence\": 0.494, \"Chord\": \"F\"}, {\"Index\": 722, \"Highest Charting Position\": 18, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Blue & Grey\", \"Streams\": 5698275, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"0n2moJpAEWHwaPYYjkzMDl\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 77.0, \"Danceability\": 0.547, \"Energy\": 0.605, \"Loudness\": -6.755, \"Speechiness\": 0.0415, \"Acousticness\": 0.42, \"Liveness\": 0.125, \"Tempo\": 121.953, \"Duration (ms)\": 254950.0, \"Valence\": 0.364, \"Chord\": \"G#/Ab\"}, {\"Index\": 723, \"Highest Charting Position\": 46, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Mad at Disney\", \"Streams\": 5436450, \"Artist\": \"salem ilese\", \"Artist Followers\": 133998.0, \"Song ID\": \"7aGyRfJWtLqgJaZoG9lJhE\", \"Genre\": \"['alt z', 'modern indie pop', 'social media pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 76.0, \"Danceability\": 0.738, \"Energy\": 0.621, \"Loudness\": -7.313, \"Speechiness\": 0.0486, \"Acousticness\": 0.424, \"Liveness\": 0.692, \"Tempo\": 113.968, \"Duration (ms)\": 136839.0, \"Valence\": 0.715, \"Chord\": \"C\"}, {\"Index\": 724, \"Highest Charting Position\": 9, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Safaera\", \"Streams\": 5390363, \"Artist\": \"Bad Bunny, Jowell & Randy, \\u00d1engo Flow\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2DEZmgHKAvm41k4J3R2E9Y\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 79.0, \"Danceability\": 0.607, \"Energy\": 0.829, \"Loudness\": -4.074, \"Speechiness\": 0.379, \"Acousticness\": 0.0103, \"Liveness\": 0.107, \"Tempo\": 96.172, \"Duration (ms)\": 295177.0, \"Valence\": 0.685, \"Chord\": \"D\"}, {\"Index\": 725, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"LA DROGA\", \"Streams\": 5375449, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"67ACYA3UI6QMNtHX6b34wX\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.643, \"Energy\": 0.727, \"Loudness\": -5.506, \"Speechiness\": 0.0389, \"Acousticness\": 0.0439, \"Liveness\": 0.123, \"Tempo\": 90.019, \"Duration (ms)\": 162299.0, \"Valence\": 0.295, \"Chord\": \"C#/Db\"}, {\"Index\": 726, \"Highest Charting Position\": 60, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"GO (feat. Juice WRLD)\", \"Streams\": 5370330, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"2rPHUAeUPbNgTmK18FPTiZ\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-06--2020-11-13\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 78.0, \"Danceability\": 0.487, \"Energy\": 0.74, \"Loudness\": -4.973, \"Speechiness\": 0.0944, \"Acousticness\": 0.157, \"Liveness\": 0.612, \"Tempo\": 73.779, \"Duration (ms)\": 181688.0, \"Valence\": 0.522, \"Chord\": \"F#/Gb\"}, {\"Index\": 727, \"Highest Charting Position\": 180, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"Jenny (I Wanna Ruin Our Friendship)\", \"Streams\": 5364223, \"Artist\": \"Studio Killers\", \"Artist Followers\": 181236.0, \"Song ID\": \"4JLBDUYSaOMPYND0iWeSWQ\", \"Genre\": \"[]\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 72.0, \"Danceability\": 0.668, \"Energy\": 0.798, \"Loudness\": -5.701, \"Speechiness\": 0.0334, \"Acousticness\": 0.00305, \"Liveness\": 0.277, \"Tempo\": 133.928, \"Duration (ms)\": 215280.0, \"Valence\": 0.575, \"Chord\": \"B\"}, {\"Index\": 728, \"Highest Charting Position\": 35, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Mood (Remix) feat. Justin Bieber, J Balvin & iann dior\", \"Streams\": 5314734, \"Artist\": \"24kGoldn\", \"Artist Followers\": 1276406.0, \"Song ID\": \"6FuGJB290AQMAHTfjOYVaK\", \"Genre\": \"['cali rap']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 77.0, \"Danceability\": 0.721, \"Energy\": 0.745, \"Loudness\": -3.508, \"Speechiness\": 0.0366, \"Acousticness\": 0.151, \"Liveness\": 0.372, \"Tempo\": 90.988, \"Duration (ms)\": 192745.0, \"Valence\": 0.699, \"Chord\": \"G\"}, {\"Index\": 729, \"Highest Charting Position\": 41, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"HOY COBR\\u00c9\", \"Streams\": 12914431, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0tjZv2hChdHZCW1zFXpy1J\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.86, \"Energy\": 0.725, \"Loudness\": -6.7, \"Speechiness\": 0.249, \"Acousticness\": 0.0464, \"Liveness\": 0.0994, \"Tempo\": 145.001, \"Duration (ms)\": 162151.0, \"Valence\": 0.375, \"Chord\": \"B\"}, {\"Index\": 730, \"Highest Charting Position\": 44, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"MALDITA POBREZA\", \"Streams\": 12660806, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0Lsis3LB0XAK6XlTHXaJk2\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 67.0, \"Danceability\": 0.762, \"Energy\": 0.861, \"Loudness\": -4.075, \"Speechiness\": 0.0652, \"Acousticness\": 0.139, \"Liveness\": 0.0956, \"Tempo\": 133.037, \"Duration (ms)\": 213609.0, \"Valence\": 0.588, \"Chord\": \"E\"}, {\"Index\": 731, \"Highest Charting Position\": 48, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"EL MUNDO ES M\\u00cdO\", \"Streams\": 12507010, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"36DHxTW2xdr9GG15T9oK9L\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 67.0, \"Danceability\": 0.716, \"Energy\": 0.522, \"Loudness\": -6.834, \"Speechiness\": 0.0582, \"Acousticness\": 0.166, \"Liveness\": 0.113, \"Tempo\": 76.993, \"Duration (ms)\": 165199.0, \"Valence\": 0.224, \"Chord\": \"F\"}, {\"Index\": 732, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"ANTES QUE SE ACABE\", \"Streams\": 11298839, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"7kjEqI6eZ7YlFrGhxixnlN\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 76.0, \"Danceability\": 0.693, \"Energy\": 0.549, \"Loudness\": -6.098, \"Speechiness\": 0.0577, \"Acousticness\": 0.505, \"Liveness\": 0.324, \"Tempo\": 139.988, \"Duration (ms)\": 221187.0, \"Valence\": 0.473, \"Chord\": \"D\"}, {\"Index\": 733, \"Highest Charting Position\": 59, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"SORRY PAPI\", \"Streams\": 11066606, \"Artist\": \"Bad Bunny, ABRA\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5jZ32WOU7sqzDYbzINwMUk\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.612, \"Energy\": 0.561, \"Loudness\": -6.054, \"Speechiness\": 0.0851, \"Acousticness\": 0.0601, \"Liveness\": 0.145, \"Tempo\": 191.911, \"Duration (ms)\": 163053.0, \"Valence\": 0.393, \"Chord\": \"C#/Db\"}, {\"Index\": 734, \"Highest Charting Position\": 63, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"120\", \"Streams\": 10957181, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3KJ3opyV29269SXkPrc19l\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 72.0, \"Danceability\": 0.636, \"Energy\": 0.656, \"Loudness\": -5.542, \"Speechiness\": 0.0676, \"Acousticness\": 0.451, \"Liveness\": 0.287, \"Tempo\": 171.918, \"Duration (ms)\": 151506.0, \"Valence\": 0.439, \"Chord\": \"D\"}, {\"Index\": 735, \"Highest Charting Position\": 66, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"TRELLAS\", \"Streams\": 10733416, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"09WAnxdBuebQopKhJT3oZS\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 66.0, \"Danceability\": 0.43, \"Energy\": 0.412, \"Loudness\": -5.372, \"Speechiness\": 0.0281, \"Acousticness\": 0.2, \"Liveness\": 0.324, \"Tempo\": 90.872, \"Duration (ms)\": 157673.0, \"Valence\": 0.0508, \"Chord\": \"D\"}, {\"Index\": 736, \"Highest Charting Position\": 83, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"Wonderful Christmastime [Edited Version] - Remastered 2011 / Edited Version\", \"Streams\": 9624871, \"Artist\": \"Paul McCartney\", \"Artist Followers\": 3609658.0, \"Song ID\": \"1SV1fxF65n9NhRHp3KlBuu\", \"Genre\": \"['album rock', 'art rock', 'beatlesque', 'classic rock', 'mellow gold', 'rock', 'soft rock']\", \"Release Date\": \"1980-05-16\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 51.0, \"Danceability\": 0.774, \"Energy\": 0.511, \"Loudness\": -8.914, \"Speechiness\": 0.0319, \"Acousticness\": 0.322, \"Liveness\": 0.0672, \"Tempo\": 94.736, \"Duration (ms)\": 227653.0, \"Valence\": 0.771, \"Chord\": \"B\"}, {\"Index\": 737, \"Highest Charting Position\": 16, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Fly To My Room\", \"Streams\": 8413330, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3QH8rQGNFX8VLbCgZ7uPTS\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 76.0, \"Danceability\": 0.764, \"Energy\": 0.526, \"Loudness\": -7.355, \"Speechiness\": 0.212, \"Acousticness\": 0.0484, \"Liveness\": 0.0718, \"Tempo\": 114.91, \"Duration (ms)\": 222243.0, \"Valence\": 0.588, \"Chord\": \"B\"}, {\"Index\": 738, \"Highest Charting Position\": 24, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Telepathy\", \"Streams\": 7703744, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"2FVpOsjT1iquZ3SpCjZ9Ne\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 77.0, \"Danceability\": 0.787, \"Energy\": 0.669, \"Loudness\": -4.333, \"Speechiness\": 0.0428, \"Acousticness\": 0.00782, \"Liveness\": 0.123, \"Tempo\": 104.994, \"Duration (ms)\": 202313.0, \"Valence\": 0.57, \"Chord\": \"F\"}, {\"Index\": 739, \"Highest Charting Position\": 26, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Dis-ease\", \"Streams\": 7165808, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"54DmTIv86D3sYdiawjULQ0\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 75.0, \"Danceability\": 0.731, \"Energy\": 0.845, \"Loudness\": -5.352, \"Speechiness\": 0.132, \"Acousticness\": 0.0132, \"Liveness\": 0.0782, \"Tempo\": 101.085, \"Duration (ms)\": 239722.0, \"Valence\": 0.484, \"Chord\": \"G#/Ab\"}, {\"Index\": 740, \"Highest Charting Position\": 27, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Stay\", \"Streams\": 7010227, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3ndCsZfq8OVwwkz9mmZvUz\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 76.0, \"Danceability\": 0.582, \"Energy\": 0.693, \"Loudness\": -5.048, \"Speechiness\": 0.0465, \"Acousticness\": 0.114, \"Liveness\": 0.13, \"Tempo\": 125.904, \"Duration (ms)\": 204800.0, \"Valence\": 0.341, \"Chord\": \"F#/Gb\"}, {\"Index\": 741, \"Highest Charting Position\": 151, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Heart Of Glass (Live from the iHeart Festival)\", \"Streams\": 6006877, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"5i7ThJfYLAzp2DyZuFpF6j\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-09-29\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 71.0, \"Danceability\": 0.58, \"Energy\": 0.908, \"Loudness\": -5.303, \"Speechiness\": 0.0341, \"Acousticness\": 0.000335, \"Liveness\": 0.087, \"Tempo\": 115.016, \"Duration (ms)\": 213672.0, \"Valence\": 0.427, \"Chord\": \"E\"}, {\"Index\": 742, \"Highest Charting Position\": 171, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"CANTARES DE NAVIDAD\", \"Streams\": 5842320, \"Artist\": \"Trio Vegabaje\\u00f1o\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2Iv6YBslkxslMJQsxshZh5\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 56.0, \"Danceability\": 0.764, \"Energy\": 0.523, \"Loudness\": -7.371, \"Speechiness\": 0.0406, \"Acousticness\": 0.777, \"Liveness\": 0.352, \"Tempo\": 118.671, \"Duration (ms)\": 199720.0, \"Valence\": 0.962, \"Chord\": \"D\"}, {\"Index\": 743, \"Highest Charting Position\": 172, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"Plastic Hearts\", \"Streams\": 5816739, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"6qCsKKS7Ol63SJW3LOIX5R\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 74.0, \"Danceability\": 0.551, \"Energy\": 0.756, \"Loudness\": -4.948, \"Speechiness\": 0.0652, \"Acousticness\": 0.0511, \"Liveness\": 0.0765, \"Tempo\": 175.984, \"Duration (ms)\": 205733.0, \"Valence\": 0.618, \"Chord\": \"D\"}, {\"Index\": 744, \"Highest Charting Position\": 63, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"C\\u00d3MO SE SIENTE - Remix\", \"Streams\": 5463964, \"Artist\": \"Jhay Cortez, Bad Bunny\", \"Artist Followers\": 2435159.0, \"Song ID\": \"2tFwfmceQa1Y6nRPhYbEtC\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-09\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 81.0, \"Danceability\": 0.807, \"Energy\": 0.606, \"Loudness\": -8.871, \"Speechiness\": 0.088, \"Acousticness\": 0.0946, \"Liveness\": 0.119, \"Tempo\": 92.988, \"Duration (ms)\": 227520.0, \"Valence\": 0.304, \"Chord\": \"D#/Eb\"}, {\"Index\": 745, \"Highest Charting Position\": 78, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Skit\", \"Streams\": 8392247, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4GVwjLRT7oSsKby7Vy8EHr\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 60.0, \"Danceability\": 0.703, \"Energy\": 0.321, \"Loudness\": -13.135, \"Speechiness\": 0.884, \"Acousticness\": 0.864, \"Liveness\": 0.908, \"Tempo\": 114.822, \"Duration (ms)\": 179548.0, \"Valence\": 0.544, \"Chord\": \"E\"}, {\"Index\": 746, \"Highest Charting Position\": 105, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Baby (with J Balvin)\", \"Streams\": 7276896, \"Artist\": \"Sfera Ebbasta\", \"Artist Followers\": 4430628.0, \"Song ID\": \"3eblNP3Zd5b5J3JaOckl8Y\", \"Genre\": \"['italian hip hop', 'italian pop', 'trap italiana']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 69.0, \"Danceability\": 0.755, \"Energy\": 0.882, \"Loudness\": -1.957, \"Speechiness\": 0.0532, \"Acousticness\": 0.125, \"Liveness\": 0.103, \"Tempo\": 99.984, \"Duration (ms)\": 193555.0, \"Valence\": 0.606, \"Chord\": \"A#/Bb\"}, {\"Index\": 747, \"Highest Charting Position\": 82, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Tick Tock (feat. 24kGoldn)\", \"Streams\": 6241923, \"Artist\": \"Clean Bandit, Mabel\", \"Artist Followers\": 4431309.0, \"Song ID\": \"27u7t9d7ZQoyjsCROHuZJ3\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk dance', 'uk funky']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 78.0, \"Danceability\": 0.779, \"Energy\": 0.705, \"Loudness\": -3.895, \"Speechiness\": 0.0344, \"Acousticness\": 0.369, \"Liveness\": 0.124, \"Tempo\": 101.022, \"Duration (ms)\": 178374.0, \"Valence\": 0.946, \"Chord\": \"C\"}, {\"Index\": 748, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Dime C\\u00f3mo Quieres\", \"Streams\": 6152821, \"Artist\": \"Christian Nodal, \\u00c1ngela Aguilar\", \"Artist Followers\": 8123757.0, \"Song ID\": \"4jcxBTrNvyqMJdMDyyjdYV\", \"Genre\": \"['mariachi', 'nuevo regional mexicano', 'ranchera', 'regional mexican']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 75.0, \"Danceability\": 0.839, \"Energy\": 0.667, \"Loudness\": -3.961, \"Speechiness\": 0.031, \"Acousticness\": 0.322, \"Liveness\": 0.244, \"Tempo\": 124.889, \"Duration (ms)\": 171360.0, \"Valence\": 0.878, \"Chord\": \"B\"}, {\"Index\": 749, \"Highest Charting Position\": 162, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Tik Tok (feat. Marracash & Gu\\u00e8 Pequeno)\", \"Streams\": 5504912, \"Artist\": \"Sfera Ebbasta\", \"Artist Followers\": 4430628.0, \"Song ID\": \"3tkYK45AZC0PqJ7MSe6IyJ\", \"Genre\": \"['italian hip hop', 'italian pop', 'trap italiana']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 59.0, \"Danceability\": 0.723, \"Energy\": 0.673, \"Loudness\": -7.636, \"Speechiness\": 0.137, \"Acousticness\": 0.0985, \"Liveness\": 0.323, \"Tempo\": 120.046, \"Duration (ms)\": 230389.0, \"Valence\": 0.302, \"Chord\": \"A\"}, {\"Index\": 750, \"Highest Charting Position\": 88, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Jerusalema (feat. Nomcebo Zikode)\", \"Streams\": 5362508, \"Artist\": \"Master KG\", \"Artist Followers\": 247480.0, \"Song ID\": \"2MlOUXmcofMackX3bxfSwi\", \"Genre\": \"['south african house']\", \"Release Date\": \"2020-01-24\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 78.0, \"Danceability\": 0.88, \"Energy\": 0.483, \"Loudness\": -7.012, \"Speechiness\": 0.0505, \"Acousticness\": 0.0185, \"Liveness\": 0.0607, \"Tempo\": 124.009, \"Duration (ms)\": 342613.0, \"Valence\": 0.827, \"Chord\": \"C#/Db\"}, {\"Index\": 751, \"Highest Charting Position\": 19, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Agua (with J Balvin) - Music From \\\"Sponge On The Run\\\" Movie\", \"Streams\": 5358940, \"Artist\": \"Tainy\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 752, \"Highest Charting Position\": 174, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Abracadabra (feat. Future)\", \"Streams\": 5263469, \"Artist\": \"Sfera Ebbasta\", \"Artist Followers\": 4430628.0, \"Song ID\": \"2GuLouaDNgLGxdJoe0vYf6\", \"Genre\": \"['italian hip hop', 'italian pop', 'trap italiana']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 55.0, \"Danceability\": 0.846, \"Energy\": 0.681, \"Loudness\": -7.091, \"Speechiness\": 0.174, \"Acousticness\": 0.0461, \"Liveness\": 0.112, \"Tempo\": 131.988, \"Duration (ms)\": 192965.0, \"Valence\": 0.809, \"Chord\": \"F\"}, {\"Index\": 753, \"Highest Charting Position\": 36, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Djadja (feat. Maluma) - Remix\", \"Streams\": 5203423, \"Artist\": \"Aya Nakamura\", \"Artist Followers\": 2953525.0, \"Song ID\": \"6AzKhCHOms83jvNVLsz0Bt\", \"Genre\": \"['basshall', 'francoton']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 72.0, \"Danceability\": 0.791, \"Energy\": 0.682, \"Loudness\": -7.328, \"Speechiness\": 0.158, \"Acousticness\": 0.175, \"Liveness\": 0.0926, \"Tempo\": 98.031, \"Duration (ms)\": 166851.0, \"Valence\": 0.672, \"Chord\": \"F\"}, {\"Index\": 754, \"Highest Charting Position\": 140, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"ALWAYS DO\", \"Streams\": 5196635, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"3QCU8BT0zDS9LPVfEhRFEE\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 76.0, \"Danceability\": 0.762, \"Energy\": 0.426, \"Loudness\": -6.865, \"Speechiness\": 0.113, \"Acousticness\": 0.0442, \"Liveness\": 0.0858, \"Tempo\": 167.827, \"Duration (ms)\": 151705.0, \"Valence\": 0.582, \"Chord\": \"G#/Ab\"}, {\"Index\": 755, \"Highest Charting Position\": 7, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Smile (with The Weeknd)\", \"Streams\": 5164187, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"6wQlQrTY5mVS8EGaFZVwVF\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 75.0, \"Danceability\": 0.694, \"Energy\": 0.685, \"Loudness\": -6.535, \"Speechiness\": 0.133, \"Acousticness\": 0.224, \"Liveness\": 0.124, \"Tempo\": 158.831, \"Duration (ms)\": 196180.0, \"Valence\": 0.306, \"Chord\": \"F#/Gb\"}, {\"Index\": 756, \"Highest Charting Position\": 22, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Pretty Savage\", \"Streams\": 5039047, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"1XnpzbOGptRwfJhZgLbmSr\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 75.0, \"Danceability\": 0.701, \"Energy\": 0.556, \"Loudness\": -7.42, \"Speechiness\": 0.0414, \"Acousticness\": 0.00886, \"Liveness\": 0.106, \"Tempo\": 152.045, \"Duration (ms)\": 201122.0, \"Valence\": 0.333, \"Chord\": \"A\"}, {\"Index\": 757, \"Highest Charting Position\": 41, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Savage Love (Laxed \\u2013 Siren Beat) [BTS Remix]\", \"Streams\": 4995203, \"Artist\": \"Jawsh 685, Jason Derulo\", \"Artist Followers\": 100635.0, \"Song ID\": \"4TgxFMOn5yoESW6zCidCXL\", \"Genre\": \"['nz pop']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 76.0, \"Danceability\": 0.758, \"Energy\": 0.598, \"Loudness\": -5.695, \"Speechiness\": 0.0868, \"Acousticness\": 0.16, \"Liveness\": 0.295, \"Tempo\": 149.836, \"Duration (ms)\": 184905.0, \"Valence\": 0.658, \"Chord\": \"C\"}, {\"Index\": 758, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Mirrors\", \"Streams\": 4988571, \"Artist\": \"Justin Timberlake\", \"Artist Followers\": 11034144.0, \"Song ID\": \"4rHZZAmHpZrA3iH5zx8frV\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2013-03-15\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 78.0, \"Danceability\": 0.574, \"Energy\": 0.512, \"Loudness\": -6.664, \"Speechiness\": 0.0503, \"Acousticness\": 0.234, \"Liveness\": 0.0946, \"Tempo\": 76.899, \"Duration (ms)\": 484147.0, \"Valence\": 0.512, \"Chord\": \"F\"}, {\"Index\": 759, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Hollywood (feat. Diplo)\", \"Streams\": 4920218, \"Artist\": \"Sfera Ebbasta\", \"Artist Followers\": 4430628.0, \"Song ID\": \"0WXU7I74NEN1DMLIT406Wx\", \"Genre\": \"['italian hip hop', 'italian pop', 'trap italiana']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 63.0, \"Danceability\": 0.848, \"Energy\": 0.708, \"Loudness\": -6.336, \"Speechiness\": 0.0366, \"Acousticness\": 0.153, \"Liveness\": 0.0948, \"Tempo\": 137.973, \"Duration (ms)\": 191869.0, \"Valence\": 0.926, \"Chord\": \"D\"}, {\"Index\": 760, \"Highest Charting Position\": 24, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Runnin\", \"Streams\": 4914682, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"5SWnsxjhdcEDc7LJjq9UHk\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 78.0, \"Danceability\": 0.819, \"Energy\": 0.626, \"Loudness\": -4.574, \"Speechiness\": 0.202, \"Acousticness\": 0.00748, \"Liveness\": 0.167, \"Tempo\": 143.01, \"Duration (ms)\": 195906.0, \"Valence\": 0.415, \"Chord\": \"A#/Bb\"}, {\"Index\": 761, \"Highest Charting Position\": 105, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Are You Bored Yet? (feat. Clairo)\", \"Streams\": 4911995, \"Artist\": \"Wallows\", \"Artist Followers\": 1963296.0, \"Song ID\": \"57RA3JGafJm5zRtKJiKPIm\", \"Genre\": \"['indie pop', 'modern rock', 'pop', 'rock']\", \"Release Date\": \"2019-03-22\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 81.0, \"Danceability\": 0.682, \"Energy\": 0.683, \"Loudness\": -6.444, \"Speechiness\": 0.0287, \"Acousticness\": 0.156, \"Liveness\": 0.273, \"Tempo\": 120.023, \"Duration (ms)\": 178000.0, \"Valence\": 0.64, \"Chord\": \"G#/Ab\"}, {\"Index\": 762, \"Highest Charting Position\": 44, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"10,000 Hours (with Justin Bieber)\", \"Streams\": 4911749, \"Artist\": \"Dan + Shay\", \"Artist Followers\": 2334615.0, \"Song ID\": \"2wrJq5XKLnmhRXHIAf9xBa\", \"Genre\": \"['contemporary country', 'country', 'pop']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.654, \"Energy\": 0.63, \"Loudness\": -4.644, \"Speechiness\": 0.0259, \"Acousticness\": 0.153, \"Liveness\": 0.111, \"Tempo\": 89.991, \"Duration (ms)\": 167693.0, \"Valence\": 0.43, \"Chord\": \"A#/Bb\"}, {\"Index\": 763, \"Highest Charting Position\": 87, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"You Got It\", \"Streams\": 4907925, \"Artist\": \"Vedo\", \"Artist Followers\": 260236.0, \"Song ID\": \"4lsHZ92XCFOQfzJFBTluk8\", \"Genre\": \"['pop r&b', 'r&b']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 79.0, \"Danceability\": 0.762, \"Energy\": 0.433, \"Loudness\": -8.937, \"Speechiness\": 0.187, \"Acousticness\": 0.143, \"Liveness\": 0.118, \"Tempo\": 122.074, \"Duration (ms)\": 203145.0, \"Valence\": 0.394, \"Chord\": \"F\"}, {\"Index\": 764, \"Highest Charting Position\": 129, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Qui\\u00e9reme Mientras Se Pueda\", \"Streams\": 4899440, \"Artist\": \"Manuel Turizo\", \"Artist Followers\": 7909963.0, \"Song ID\": \"34LI7rwi9H8w2S5KTHnv1M\", \"Genre\": \"['colombian pop', 'latin', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 74.0, \"Danceability\": 0.793, \"Energy\": 0.782, \"Loudness\": -3.945, \"Speechiness\": 0.0582, \"Acousticness\": 0.447, \"Liveness\": 0.124, \"Tempo\": 143.86, \"Duration (ms)\": 191945.0, \"Valence\": 0.81, \"Chord\": \"E\"}, {\"Index\": 765, \"Highest Charting Position\": 9, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Party Girl\", \"Streams\": 4878286, \"Artist\": \"StaySolidRocky\", \"Artist Followers\": 150587.0, \"Song ID\": \"5RqR4ZCCKJDcBLIn4sih9l\", \"Genre\": \"['melodic rap']\", \"Release Date\": \"2020-04-21\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 77.0, \"Danceability\": 0.728, \"Energy\": 0.431, \"Loudness\": -9.966, \"Speechiness\": 0.0622, \"Acousticness\": 0.749, \"Liveness\": 0.0996, \"Tempo\": 130.022, \"Duration (ms)\": 147800.0, \"Valence\": 0.629, \"Chord\": \"F#/Gb\"}, {\"Index\": 766, \"Highest Charting Position\": 95, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Drankin N Smokin\", \"Streams\": 7292247, \"Artist\": \"Future, Lil Uzi Vert\", \"Artist Followers\": 10491105.0, \"Song ID\": \"0k7wmahjkn389wAZdz19Cv\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-11-13--2020-11-20\", \"Popularity\": 78.0, \"Danceability\": 0.752, \"Energy\": 0.658, \"Loudness\": -6.297, \"Speechiness\": 0.342, \"Acousticness\": 0.0421, \"Liveness\": 0.0927, \"Tempo\": 151.951, \"Duration (ms)\": 213520.0, \"Valence\": 0.387, \"Chord\": \"C\"}, {\"Index\": 767, \"Highest Charting Position\": 86, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Be Like That - feat. Swae Lee & Khalid\", \"Streams\": 5929062, \"Artist\": \"Kane Brown\", \"Artist Followers\": 3509653.0, \"Song ID\": \"5f1joOtoMeyppIcJGZQvqJ\", \"Genre\": \"['contemporary country', 'country road']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 79.0, \"Danceability\": 0.727, \"Energy\": 0.626, \"Loudness\": -8.415, \"Speechiness\": 0.0726, \"Acousticness\": 0.0469, \"Liveness\": 0.126, \"Tempo\": 86.97, \"Duration (ms)\": 191406.0, \"Valence\": 0.322, \"Chord\": \"G\"}, {\"Index\": 768, \"Highest Charting Position\": 74, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"MORE\", \"Streams\": 5602168, \"Artist\": \"K/DA, Madison Beer, (G)I-DLE, Lexie Liu, Jaira Burns, Seraphine, League of Legends\", \"Artist Followers\": 1245965.0, \"Song ID\": \"6juLaduD4STCUDWT0AYun4\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2020-10-28\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 73.0, \"Danceability\": 0.66, \"Energy\": 0.787, \"Loudness\": -4.592, \"Speechiness\": 0.032, \"Acousticness\": 0.00257, \"Liveness\": 0.323, \"Tempo\": 142.018, \"Duration (ms)\": 217088.0, \"Valence\": 0.199, \"Chord\": \"C#/Db\"}, {\"Index\": 769, \"Highest Charting Position\": 140, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Enchule\", \"Streams\": 5561227, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6096559.0, \"Song ID\": \"3ThrfRAmijYU098H9q9tAs\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 70.0, \"Danceability\": 0.763, \"Energy\": 0.666, \"Loudness\": -3.316, \"Speechiness\": 0.194, \"Acousticness\": 0.153, \"Liveness\": 0.301, \"Tempo\": 90.086, \"Duration (ms)\": 185719.0, \"Valence\": 0.587, \"Chord\": \"G\"}, {\"Index\": 770, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Stripes Like Burberry\", \"Streams\": 5445204, \"Artist\": \"Future, Lil Uzi Vert\", \"Artist Followers\": 10491105.0, \"Song ID\": \"6lt8iodSkYWEV0ifKCSlfg\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-11-13--2020-11-20\", \"Popularity\": 56.0, \"Danceability\": 0.758, \"Energy\": 0.574, \"Loudness\": -7.833, \"Speechiness\": 0.217, \"Acousticness\": 0.216, \"Liveness\": 0.144, \"Tempo\": 144.081, \"Duration (ms)\": 274313.0, \"Valence\": 0.706, \"Chord\": \"A\"}, {\"Index\": 771, \"Highest Charting Position\": 117, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Papi Chulo\", \"Streams\": 5361669, \"Artist\": \"Octavian, Skepta\", \"Artist Followers\": 213344.0, \"Song ID\": \"6Juv5N0dNU1imms9c9u1dA\", \"Genre\": \"['afroswing', 'london rap', 'uk alternative hip hop', 'uk hip hop']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 73.0, \"Danceability\": 0.866, \"Energy\": 0.563, \"Loudness\": -6.964, \"Speechiness\": 0.108, \"Acousticness\": 0.185, \"Liveness\": 0.0889, \"Tempo\": 127.954, \"Duration (ms)\": 161668.0, \"Valence\": 0.307, \"Chord\": \"B\"}, {\"Index\": 772, \"Highest Charting Position\": 20, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"off the table (with The Weeknd)\", \"Streams\": 5308945, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"7E1jVNoWuemqUryI4FxsVD\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 67.0, \"Danceability\": 0.411, \"Energy\": 0.522, \"Loudness\": -7.295, \"Speechiness\": 0.0981, \"Acousticness\": 0.519, \"Liveness\": 0.398, \"Tempo\": 88.332, \"Duration (ms)\": 239949.0, \"Valence\": 0.382, \"Chord\": \"C\"}, {\"Index\": 773, \"Highest Charting Position\": 52, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Spicy (feat. Post Malone)\", \"Streams\": 5303146, \"Artist\": \"Ty Dolla $ign\", \"Artist Followers\": 3866304.0, \"Song ID\": \"5IUtvfNvOyVYZUa6AJFrnP\", \"Genre\": \"['hip hop', 'pop', 'pop rap', 'r&b', 'southern hip hop', 'trap', 'trap soul']\", \"Release Date\": \"2020-10-23\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 80.0, \"Danceability\": 0.782, \"Energy\": 0.51, \"Loudness\": -5.724, \"Speechiness\": 0.0419, \"Acousticness\": 0.143, \"Liveness\": 0.115, \"Tempo\": 99.993, \"Duration (ms)\": 143375.0, \"Valence\": 0.118, \"Chord\": \"E\"}, {\"Index\": 774, \"Highest Charting Position\": 124, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Sweet Melody\", \"Streams\": 5201322, \"Artist\": \"Little Mix\", \"Artist Followers\": 9398941.0, \"Song ID\": \"76Tuo484SLohJakHLnGI3B\", \"Genre\": \"['dance pop', 'girl group', 'pop', 'post-teen pop', 'talent show', 'uk pop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\", \"Popularity\": 73.0, \"Danceability\": 0.448, \"Energy\": 0.824, \"Loudness\": -4.249, \"Speechiness\": 0.057, \"Acousticness\": 0.0739, \"Liveness\": 0.113, \"Tempo\": 119.965, \"Duration (ms)\": 213693.0, \"Valence\": 0.419, \"Chord\": \"F\"}, {\"Index\": 775, \"Highest Charting Position\": 144, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Blueberry Eyes (feat. SUGA of BTS)\", \"Streams\": 5158896, \"Artist\": \"MAX\", \"Artist Followers\": 689627.0, \"Song ID\": \"5dn6QANKbf76pANGjMBida\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'pop rap', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2020-09-15\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 72.0, \"Danceability\": 0.746, \"Energy\": 0.611, \"Loudness\": -7.034, \"Speechiness\": 0.101, \"Acousticness\": 0.454, \"Liveness\": 0.133, \"Tempo\": 149.967, \"Duration (ms)\": 172245.0, \"Valence\": 0.411, \"Chord\": \"C\"}, {\"Index\": 776, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"That\\u2019s It\", \"Streams\": 5151014, \"Artist\": \"Future, Lil Uzi Vert\", \"Artist Followers\": 10491105.0, \"Song ID\": \"5n6gBhdEjCuj3obgCoTEFD\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-11-13--2020-11-20\", \"Popularity\": 64.0, \"Danceability\": 0.94, \"Energy\": 0.532, \"Loudness\": -5.998, \"Speechiness\": 0.358, \"Acousticness\": 0.12, \"Liveness\": 0.0925, \"Tempo\": 123.043, \"Duration (ms)\": 228796.0, \"Valence\": 0.599, \"Chord\": \"B\"}, {\"Index\": 777, \"Highest Charting Position\": 157, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Promiscuous\", \"Streams\": 5083648, \"Artist\": \"Nelly Furtado, Timbaland\", \"Artist Followers\": 2688557.0, \"Song ID\": \"2gam98EZKrF9XuOkU13ApN\", \"Genre\": \"['canadian latin', 'canadian pop', 'dance pop', 'pop', 'pop rap']\", \"Release Date\": \"2006-01-01\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 82.0, \"Danceability\": 0.808, \"Energy\": 0.97, \"Loudness\": -6.098, \"Speechiness\": 0.0506, \"Acousticness\": 0.0569, \"Liveness\": 0.154, \"Tempo\": 114.328, \"Duration (ms)\": 242293.0, \"Valence\": 0.868, \"Chord\": \"A#/Bb\"}, {\"Index\": 778, \"Highest Charting Position\": 22, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"GREECE (feat. Drake)\", \"Streams\": 5043665, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6281829.0, \"Song ID\": \"35RJhm1pEovTBwnNR0zWad\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-07-16\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 77.0, \"Danceability\": 0.695, \"Energy\": 0.343, \"Loudness\": -10.798, \"Speechiness\": 0.0432, \"Acousticness\": 0.0743, \"Liveness\": 0.107, \"Tempo\": 85.84, \"Duration (ms)\": 218902.0, \"Valence\": 0.229, \"Chord\": \"F\"}, {\"Index\": 779, \"Highest Charting Position\": 25, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"just like magic\", \"Streams\": 4980571, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"7Dx9Z6Aon1qPS2N0rHSWTe\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 69.0, \"Danceability\": 0.719, \"Energy\": 0.607, \"Loudness\": -5.156, \"Speechiness\": 0.165, \"Acousticness\": 0.08, \"Liveness\": 0.125, \"Tempo\": 128.006, \"Duration (ms)\": 149900.0, \"Valence\": 0.464, \"Chord\": \"G#/Ab\"}, {\"Index\": 780, \"Highest Charting Position\": 53, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Still Don't Know My Name\", \"Streams\": 4926802, \"Artist\": \"Labrinth\", \"Artist Followers\": 1685215.0, \"Song ID\": \"6N22FZs2ZhPBYi3b9XPajV\", \"Genre\": \"['indie poptimism', 'pop']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 80.0, \"Danceability\": 0.316, \"Energy\": 0.63, \"Loudness\": -5.963, \"Speechiness\": 0.117, \"Acousticness\": 0.471, \"Liveness\": 0.205, \"Tempo\": 89.643, \"Duration (ms)\": 153294.0, \"Valence\": 0.313, \"Chord\": \"F\"}, {\"Index\": 781, \"Highest Charting Position\": 32, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Hasta Que Dios Diga\", \"Streams\": 4899099, \"Artist\": \"Anuel AA, Bad Bunny\", \"Artist Followers\": 18306226.0, \"Song ID\": \"06s3QtMJVXw1AJX3UfvZG1\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 76.0, \"Danceability\": 0.691, \"Energy\": 0.765, \"Loudness\": -4.727, \"Speechiness\": 0.111, \"Acousticness\": 0.464, \"Liveness\": 0.203, \"Tempo\": 174.021, \"Duration (ms)\": 246000.0, \"Valence\": 0.855, \"Chord\": \"G#/Ab\"}, {\"Index\": 782, \"Highest Charting Position\": 102, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Get You The Moon (feat. Sn\\u00f8w)\", \"Streams\": 4872409, \"Artist\": \"Kina\", \"Artist Followers\": 661863.0, \"Song ID\": \"4ZLzoOkj0MPWrTLvooIuaa\", \"Genre\": \"['sad rap']\", \"Release Date\": \"2018-10-08\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.498, \"Energy\": 0.235, \"Loudness\": -16.541, \"Speechiness\": 0.188, \"Acousticness\": 0.72, \"Liveness\": 0.144, \"Tempo\": 118.917, \"Duration (ms)\": 179080.0, \"Valence\": 0.0895, \"Chord\": \"C#/Db\"}, {\"Index\": 783, \"Highest Charting Position\": 162, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Moonwalking in Calabasas (feat. Blueface) - Remix\", \"Streams\": 4863053, \"Artist\": \"DDG\", \"Artist Followers\": 486194.0, \"Song ID\": \"7o4gBbTM6UBLkOYPw9xMCz\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2020-12-02\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 74.0, \"Danceability\": 0.928, \"Energy\": 0.341, \"Loudness\": -10.196, \"Speechiness\": 0.103, \"Acousticness\": 0.0614, \"Liveness\": 0.162, \"Tempo\": 129.966, \"Duration (ms)\": 170233.0, \"Valence\": 0.745, \"Chord\": \"B\"}, {\"Index\": 784, \"Highest Charting Position\": 29, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Forever After All\", \"Streams\": 4746415, \"Artist\": \"Luke Combs\", \"Artist Followers\": 5371000.0, \"Song ID\": \"6IBcOGPsniK3Pso1wHIhew\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2020-10-23\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 80.0, \"Danceability\": 0.487, \"Energy\": 0.65, \"Loudness\": -5.195, \"Speechiness\": 0.0253, \"Acousticness\": 0.191, \"Liveness\": 0.0933, \"Tempo\": 151.964, \"Duration (ms)\": 232533.0, \"Valence\": 0.456, \"Chord\": \"C\"}, {\"Index\": 785, \"Highest Charting Position\": 76, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Lean (feat. Towy, Osquel, Beltito & Sammy & Falsetto)\", \"Streams\": 4739241, \"Artist\": \"Super Yei, Jone Quest\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 786, \"Highest Charting Position\": 156, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"SLOW DANCING IN THE DARK\", \"Streams\": 4732343, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"0rKtyWc8bvkriBthvHKY8d\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2018-10-26\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-05-08--2020-05-15\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.515, \"Energy\": 0.479, \"Loudness\": -7.458, \"Speechiness\": 0.0261, \"Acousticness\": 0.544, \"Liveness\": 0.191, \"Tempo\": 88.964, \"Duration (ms)\": 209274.0, \"Valence\": 0.284, \"Chord\": \"D#/Eb\"}, {\"Index\": 787, \"Highest Charting Position\": 92, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Don Don\", \"Streams\": 4731423, \"Artist\": \"Daddy Yankee, Anuel AA, Kendo Kaponi\", \"Artist Followers\": 23936368.0, \"Song ID\": \"3kml9ZdpT7UYk1ugkjqOzt\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-11\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 69.0, \"Danceability\": 0.838, \"Energy\": 0.819, \"Loudness\": -4.681, \"Speechiness\": 0.211, \"Acousticness\": 0.285, \"Liveness\": 0.224, \"Tempo\": 105.027, \"Duration (ms)\": 275893.0, \"Valence\": 0.656, \"Chord\": \"F\"}, {\"Index\": 788, \"Highest Charting Position\": 5, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"my future\", \"Streams\": 4721082, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"3YUMWmx8EJq0DurfuIwoGh\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-07-30\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 80.0, \"Danceability\": 0.456, \"Energy\": 0.285, \"Loudness\": -10.755, \"Speechiness\": 0.0979, \"Acousticness\": 0.814, \"Liveness\": 0.307, \"Tempo\": 104.89, \"Duration (ms)\": 210005.0, \"Valence\": 0.0809, \"Chord\": \"G#/Ab\"}, {\"Index\": 789, \"Highest Charting Position\": 163, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Nada\", \"Streams\": 4713873, \"Artist\": \"Cali Y El Dandee, Danna Paola\", \"Artist Followers\": 3152313.0, \"Song ID\": \"4K8cyoCDovlc4FvtUr2Hfx\", \"Genre\": \"['champeta', 'colombian pop', 'electro latino', 'latin', 'latin pop', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 76.0, \"Danceability\": 0.684, \"Energy\": 0.808, \"Loudness\": -2.737, \"Speechiness\": 0.061, \"Acousticness\": 0.0518, \"Liveness\": 0.0858, \"Tempo\": 173.905, \"Duration (ms)\": 174027.0, \"Valence\": 0.712, \"Chord\": \"C\"}, {\"Index\": 790, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"safety net (feat. Ty Dolla $ign)\", \"Streams\": 5798744, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"14gkWVFMwdxBMyqBw1wmIg\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 70.0, \"Danceability\": 0.552, \"Energy\": 0.599, \"Loudness\": -5.75, \"Speechiness\": 0.0404, \"Acousticness\": 0.0703, \"Liveness\": 0.0986, \"Tempo\": 161.884, \"Duration (ms)\": 208457.0, \"Valence\": 0.0916, \"Chord\": \"C#/Db\"}, {\"Index\": 791, \"Highest Charting Position\": 31, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"shut up\", \"Streams\": 5282490, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3ko9jEHNt4O5fjKN65ULJp\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 63.0, \"Danceability\": 0.499, \"Energy\": 0.462, \"Loudness\": -5.308, \"Speechiness\": 0.0312, \"Acousticness\": 0.801, \"Liveness\": 0.0946, \"Tempo\": 127.698, \"Duration (ms)\": 157710.0, \"Valence\": 0.599, \"Chord\": \"C\"}, {\"Index\": 792, \"Highest Charting Position\": 42, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"nasty\", \"Streams\": 5249342, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"0sci7ppTZFm4mjcH3nu8yO\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 69.0, \"Danceability\": 0.772, \"Energy\": 0.506, \"Loudness\": -6.558, \"Speechiness\": 0.139, \"Acousticness\": 0.0814, \"Liveness\": 0.182, \"Tempo\": 127.894, \"Duration (ms)\": 200733.0, \"Valence\": 0.456, \"Chord\": \"F#/Gb\"}, {\"Index\": 793, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"TRAGIC (feat. Youngboy Never Broke Again & Internet Money)\", \"Streams\": 5226940, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"13EW51DKru044OJDJ9Bm8o\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-11-06--2020-11-13\", \"Popularity\": 76.0, \"Danceability\": 0.779, \"Energy\": 0.642, \"Loudness\": -6.321, \"Speechiness\": 0.116, \"Acousticness\": 0.0383, \"Liveness\": 0.2, \"Tempo\": 82.363, \"Duration (ms)\": 153147.0, \"Valence\": 0.388, \"Chord\": \"G#/Ab\"}, {\"Index\": 794, \"Highest Charting Position\": 49, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Ayer Me Llam\\u00f3 Mi Ex (feat. Lenny Santos)\", \"Streams\": 5220504, \"Artist\": \"KHEA\", \"Artist Followers\": 3198705.0, \"Song ID\": \"6C6mUonH6MNdSg5pw7kOc9\", \"Genre\": \"['argentine hip hop', 'trap argentino', 'trap latino', 'trap triste']\", \"Release Date\": \"2020-08-20\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 71.0, \"Danceability\": 0.752, \"Energy\": 0.716, \"Loudness\": -5.2, \"Speechiness\": 0.0325, \"Acousticness\": 0.254, \"Liveness\": 0.243, \"Tempo\": 117.007, \"Duration (ms)\": 206760.0, \"Valence\": 0.553, \"Chord\": \"A#/Bb\"}, {\"Index\": 795, \"Highest Charting Position\": 119, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Madrid (feat. Myke Towers)\", \"Streams\": 5064484, \"Artist\": \"Maluma\", \"Artist Followers\": 26784251.0, \"Song ID\": \"19OXtYzrJyCrQvTbfukt4H\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 73.0, \"Danceability\": 0.764, \"Energy\": 0.741, \"Loudness\": -3.617, \"Speechiness\": 0.101, \"Acousticness\": 0.239, \"Liveness\": 0.107, \"Tempo\": 170.081, \"Duration (ms)\": 198570.0, \"Valence\": 0.802, \"Chord\": \"A\"}, {\"Index\": 796, \"Highest Charting Position\": 85, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Caramelo - Remix\", \"Streams\": 5033798, \"Artist\": \"Ozuna, KAROL G, Myke Towers\", \"Artist Followers\": 29238936.0, \"Song ID\": \"2uu2aGqA2UblCg581Q7l1g\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-08-17\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 72.0, \"Danceability\": 0.754, \"Energy\": 0.796, \"Loudness\": -3.743, \"Speechiness\": 0.139, \"Acousticness\": 0.062, \"Liveness\": 0.204, \"Tempo\": 168.045, \"Duration (ms)\": 233160.0, \"Valence\": 0.62, \"Chord\": \"D#/Eb\"}, {\"Index\": 797, \"Highest Charting Position\": 25, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Mr. Right Now (feat. Drake)\", \"Streams\": 4951481, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"4Q34FP1AT7GEl9oLgNtiWj\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 75.0, \"Danceability\": 0.647, \"Energy\": 0.667, \"Loudness\": -5.563, \"Speechiness\": 0.304, \"Acousticness\": 0.231, \"Liveness\": 0.133, \"Tempo\": 172.08, \"Duration (ms)\": 193839.0, \"Valence\": 0.704, \"Chord\": \"F\"}, {\"Index\": 798, \"Highest Charting Position\": 41, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Got It On Me\", \"Streams\": 4924030, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"25zlnOAzbVoOzIeXSvQFf1\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 78.0, \"Danceability\": 0.688, \"Energy\": 0.647, \"Loudness\": -7.258, \"Speechiness\": 0.19, \"Acousticness\": 0.00815, \"Liveness\": 0.095, \"Tempo\": 88.834, \"Duration (ms)\": 164580.0, \"Valence\": 0.195, \"Chord\": \"D\"}, {\"Index\": 799, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"my hair\", \"Streams\": 4896521, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"6u7gmPOz7pzzaeR9xSBpsR\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 66.0, \"Danceability\": 0.686, \"Energy\": 0.526, \"Loudness\": -6.842, \"Speechiness\": 0.0374, \"Acousticness\": 0.0815, \"Liveness\": 0.144, \"Tempo\": 92.013, \"Duration (ms)\": 158436.0, \"Valence\": 0.372, \"Chord\": \"C\"}, {\"Index\": 800, \"Highest Charting Position\": 59, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"obvious\", \"Streams\": 4865084, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"0q85C1JiECyYIQthz1posA\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 65.0, \"Danceability\": 0.624, \"Energy\": 0.672, \"Loudness\": -5.334, \"Speechiness\": 0.106, \"Acousticness\": 0.0967, \"Liveness\": 0.155, \"Tempo\": 159.852, \"Duration (ms)\": 146959.0, \"Valence\": 0.26, \"Chord\": \"C\"}, {\"Index\": 801, \"Highest Charting Position\": 30, \"Number of Times Charted\": 45, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Beautiful People (feat. Khalid)\", \"Streams\": 4813796, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"4evmHXcjt3bTUHD1cvny97\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.64, \"Energy\": 0.648, \"Loudness\": -8.113, \"Speechiness\": 0.187, \"Acousticness\": 0.124, \"Liveness\": 0.0802, \"Tempo\": 92.977, \"Duration (ms)\": 197867.0, \"Valence\": 0.548, \"Chord\": \"F\"}, {\"Index\": 802, \"Highest Charting Position\": 29, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Favorito\", \"Streams\": 4787127, \"Artist\": \"Camilo\", \"Artist Followers\": 10580764.0, \"Song ID\": \"0Snbzbd74RLfL0i4nn1vU5\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-26\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 73.0, \"Danceability\": 0.611, \"Energy\": 0.851, \"Loudness\": -2.982, \"Speechiness\": 0.0598, \"Acousticness\": 0.229, \"Liveness\": 0.232, \"Tempo\": 178.032, \"Duration (ms)\": 211613.0, \"Valence\": 0.823, \"Chord\": \"A\"}, {\"Index\": 803, \"Highest Charting Position\": 42, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"After Party\", \"Streams\": 4784580, \"Artist\": \"Don Toliver\", \"Artist Followers\": 1606884.0, \"Song ID\": \"527k23H0A4Q0UJN3vGs0Da\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 80.0, \"Danceability\": 0.629, \"Energy\": 0.692, \"Loudness\": -8.045, \"Speechiness\": 0.0376, \"Acousticness\": 0.00981, \"Liveness\": 0.603, \"Tempo\": 162.948, \"Duration (ms)\": 167916.0, \"Valence\": 0.453, \"Chord\": \"F\"}, {\"Index\": 804, \"Highest Charting Position\": 14, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Rojo\", \"Streams\": 4773792, \"Artist\": \"J Balvin\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3zR9JVqHsILrkNyCOqA6jM\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 0.0, \"Danceability\": 0.652, \"Energy\": 0.595, \"Loudness\": -4.04, \"Speechiness\": 0.117, \"Acousticness\": 0.15, \"Liveness\": 0.0836, \"Tempo\": 172.277, \"Duration (ms)\": 151147.0, \"Valence\": 0.421, \"Chord\": \"B\"}, {\"Index\": 805, \"Highest Charting Position\": 51, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"six thirty\", \"Streams\": 10941573, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"2IKJtXeR5UsaUjZB46fTOK\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 63.0, \"Danceability\": 0.739, \"Energy\": 0.516, \"Loudness\": -7.154, \"Speechiness\": 0.0539, \"Acousticness\": 0.67, \"Liveness\": 0.151, \"Tempo\": 120.109, \"Duration (ms)\": 183874.0, \"Valence\": 0.434, \"Chord\": \"C\"}, {\"Index\": 806, \"Highest Charting Position\": 65, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"love language\", \"Streams\": 9399230, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"6NYtLvyThMT0oALFdJFdzq\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 62.0, \"Danceability\": 0.688, \"Energy\": 0.573, \"Loudness\": -5.03, \"Speechiness\": 0.208, \"Acousticness\": 0.0686, \"Liveness\": 0.0749, \"Tempo\": 110.034, \"Duration (ms)\": 179861.0, \"Valence\": 0.553, \"Chord\": \"A#/Bb\"}, {\"Index\": 807, \"Highest Charting Position\": 66, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"west side\", \"Streams\": 9397167, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"1whfVLMKWqAX3uk97VXsNN\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 62.0, \"Danceability\": 0.688, \"Energy\": 0.455, \"Loudness\": -8.632, \"Speechiness\": 0.199, \"Acousticness\": 0.186, \"Liveness\": 0.0794, \"Tempo\": 87.865, \"Duration (ms)\": 132279.0, \"Valence\": 0.557, \"Chord\": \"B\"}, {\"Index\": 808, \"Highest Charting Position\": 146, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Thriller\", \"Streams\": 5605234, \"Artist\": \"Michael Jackson\", \"Artist Followers\": 19345579.0, \"Song ID\": \"7azo4rpSUh8nXgtonC6Pkq\", \"Genre\": \"['pop', 'r&b', 'soul']\", \"Release Date\": \"2017-09-27\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 68.0, \"Danceability\": 0.764, \"Energy\": 0.887, \"Loudness\": -3.726, \"Speechiness\": 0.0744, \"Acousticness\": 0.0816, \"Liveness\": 0.847, \"Tempo\": 118.427, \"Duration (ms)\": 358053.0, \"Valence\": 0.72, \"Chord\": \"B\"}, {\"Index\": 809, \"Highest Charting Position\": 105, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Dancing With A Stranger (with Normani)\", \"Streams\": 5229835, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"6Qs4SXO9dwPj5GKvVOv8Ki\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2019-01-11\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.741, \"Energy\": 0.52, \"Loudness\": -7.513, \"Speechiness\": 0.0656, \"Acousticness\": 0.45, \"Liveness\": 0.222, \"Tempo\": 102.998, \"Duration (ms)\": 171030.0, \"Valence\": 0.347, \"Chord\": \"G#/Ab\"}, {\"Index\": 810, \"Highest Charting Position\": 91, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Angeklagt\", \"Streams\": 5226264, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"5eu4Lxm5TlI0tKSTTDWJAT\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-10-29\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 60.0, \"Danceability\": 0.658, \"Energy\": 0.624, \"Loudness\": -9.155, \"Speechiness\": 0.0915, \"Acousticness\": 0.171, \"Liveness\": 0.116, \"Tempo\": 181.942, \"Duration (ms)\": 168991.0, \"Valence\": 0.314, \"Chord\": \"C#/Db\"}, {\"Index\": 811, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Kids Again\", \"Streams\": 5103194, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"1ABS9lKaZ1uXkXCqr9zFO7\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 62.0, \"Danceability\": 0.666, \"Energy\": 0.726, \"Loudness\": -2.998, \"Speechiness\": 0.0262, \"Acousticness\": 0.486, \"Liveness\": 0.0892, \"Tempo\": 128.044, \"Duration (ms)\": 207528.0, \"Valence\": 0.468, \"Chord\": \"B\"}, {\"Index\": 812, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Highway to Hell\", \"Streams\": 5096618, \"Artist\": \"AC/DC\", \"Artist Followers\": 20110171.0, \"Song ID\": \"2zYzyRzz6pRmhPzyfMEC8s\", \"Genre\": \"['australian rock', 'hard rock', 'rock']\", \"Release Date\": \"1979-07-27\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 83.0, \"Danceability\": 0.574, \"Energy\": 0.913, \"Loudness\": -4.793, \"Speechiness\": 0.133, \"Acousticness\": 0.061, \"Liveness\": 0.156, \"Tempo\": 115.728, \"Duration (ms)\": 208400.0, \"Valence\": 0.423, \"Chord\": \"F#/Gb\"}, {\"Index\": 813, \"Highest Charting Position\": 38, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Me Gusta (with Cardi B & Myke Towers)\", \"Streams\": 4914412, \"Artist\": \"Anitta\", \"Artist Followers\": 10741972.0, \"Song ID\": \"7e1VoRlNumuEkXlITMHKLE\", \"Genre\": \"['funk carioca', 'funk pop', 'pagode baiano', 'pop nacional']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 72.0, \"Danceability\": 0.91, \"Energy\": 0.604, \"Loudness\": -4.392, \"Speechiness\": 0.082, \"Acousticness\": 0.448, \"Liveness\": 0.0863, \"Tempo\": 110.075, \"Duration (ms)\": 180788.0, \"Valence\": 0.807, \"Chord\": \"F#/Gb\"}, {\"Index\": 814, \"Highest Charting Position\": 133, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"24 (feat. Lil Baby)\", \"Streams\": 4904772, \"Artist\": \"Money Man\", \"Artist Followers\": 345027.0, \"Song ID\": \"0xUvi7wldroBzaZCengPa5\", \"Genre\": \"['memphis hip hop', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 74.0, \"Danceability\": 0.868, \"Energy\": 0.638, \"Loudness\": -7.746, \"Speechiness\": 0.0736, \"Acousticness\": 0.146, \"Liveness\": 0.0931, \"Tempo\": 126.03, \"Duration (ms)\": 182857.0, \"Valence\": 0.459, \"Chord\": \"D\"}, {\"Index\": 815, \"Highest Charting Position\": 23, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Relaci\\u00f3n\", \"Streams\": 4825749, \"Artist\": \"Sech\", \"Artist Followers\": 8766508.0, \"Song ID\": \"35UUpTmrcFXNIVIN26ujXl\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-04-10--2020-04-17\", \"Popularity\": 80.0, \"Danceability\": 0.793, \"Energy\": 0.771, \"Loudness\": -3.417, \"Speechiness\": 0.0959, \"Acousticness\": 0.0337, \"Liveness\": 0.284, \"Tempo\": 171.943, \"Duration (ms)\": 247308.0, \"Valence\": 0.835, \"Chord\": \"F\"}, {\"Index\": 816, \"Highest Charting Position\": 14, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"FRANCHISE (feat. Young Thug & M.I.A.)\", \"Streams\": 4821213, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"4jVBIpuOiMj1crqd8LoCrJ\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 74.0, \"Danceability\": 0.835, \"Energy\": 0.699, \"Loudness\": -5.405, \"Speechiness\": 0.277, \"Acousticness\": 0.00671, \"Liveness\": 0.195, \"Tempo\": 154.981, \"Duration (ms)\": 202795.0, \"Valence\": 0.547, \"Chord\": \"G#/Ab\"}, {\"Index\": 817, \"Highest Charting Position\": 11, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Bet You Wanna (feat. Cardi B)\", \"Streams\": 6846771, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"7iAgNZdotu40NwtoIWJHFe\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 67.0, \"Danceability\": 0.653, \"Energy\": 0.662, \"Loudness\": -6.168, \"Speechiness\": 0.162, \"Acousticness\": 0.00465, \"Liveness\": 0.0626, \"Tempo\": 111.712, \"Duration (ms)\": 161168.0, \"Valence\": 0.674, \"Chord\": \"G\"}, {\"Index\": 818, \"Highest Charting Position\": 82, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Wolves (feat. Post Malone)\", \"Streams\": 5547002, \"Artist\": \"Big Sean\", \"Artist Followers\": 8673345.0, \"Song ID\": \"33gwZOGJWEZ7dRWPqPxBEZ\", \"Genre\": \"['detroit hip hop', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 79.0, \"Danceability\": 0.724, \"Energy\": 0.675, \"Loudness\": -5.267, \"Speechiness\": 0.0867, \"Acousticness\": 0.0978, \"Liveness\": 0.351, \"Tempo\": 160.048, \"Duration (ms)\": 199758.0, \"Valence\": 0.325, \"Chord\": \"D\"}, {\"Index\": 819, \"Highest Charting Position\": 88, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"thank u, next\", \"Streams\": 5079328, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3e9HZxeyfWwjeyPAMmWSSQ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-02-08\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.717, \"Energy\": 0.653, \"Loudness\": -5.634, \"Speechiness\": 0.0658, \"Acousticness\": 0.229, \"Liveness\": 0.101, \"Tempo\": 106.966, \"Duration (ms)\": 207320.0, \"Valence\": 0.412, \"Chord\": \"C#/Db\"}, {\"Index\": 820, \"Highest Charting Position\": 19, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"MAMACITA\", \"Streams\": 5016343, \"Artist\": \"Black Eyed Peas, Ozuna, J. Rey Soul\", \"Artist Followers\": 5966748.0, \"Song ID\": \"14wf185UxfNbSy8dwt4r4q\", \"Genre\": \"['dance pop', 'pop', 'pop rap']\", \"Release Date\": \"2020-04-10\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 74.0, \"Danceability\": 0.894, \"Energy\": 0.635, \"Loudness\": -6.929, \"Speechiness\": 0.0473, \"Acousticness\": 0.193, \"Liveness\": 0.0823, \"Tempo\": 105.013, \"Duration (ms)\": 249143.0, \"Valence\": 0.428, \"Chord\": \"D\"}, {\"Index\": 821, \"Highest Charting Position\": 137, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Fake\", \"Streams\": 5010179, \"Artist\": \"Lauv, Conan Gray\", \"Artist Followers\": 4442273.0, \"Song ID\": \"4Gt2kh3QbAGU6yquOWn4aW\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-13\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 73.0, \"Danceability\": 0.703, \"Energy\": 0.657, \"Loudness\": -5.363, \"Speechiness\": 0.0783, \"Acousticness\": 0.139, \"Liveness\": 0.093, \"Tempo\": 82.96, \"Duration (ms)\": 146375.0, \"Valence\": 0.455, \"Chord\": \"E\"}, {\"Index\": 822, \"Highest Charting Position\": 56, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"OK Not To Be OK\", \"Streams\": 4980744, \"Artist\": \"Marshmello, Demi Lovato\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6PiO7fUEPKnJfaCQbPrIyg\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 0.0, \"Danceability\": 0.743, \"Energy\": 0.837, \"Loudness\": -5.025, \"Speechiness\": 0.0649, \"Acousticness\": 0.0172, \"Liveness\": 0.0743, \"Tempo\": 103.072, \"Duration (ms)\": 159863.0, \"Valence\": 0.263, \"Chord\": \"C#/Db\"}, {\"Index\": 823, \"Highest Charting Position\": 1, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"THE SCOTTS\", \"Streams\": 4941592, \"Artist\": \"THE SCOTTS, Travis Scott, Kid Cudi\", \"Artist Followers\": 179193.0, \"Song ID\": \"39Yp9wwQiSRIDOvrVg7mbk\", \"Genre\": \"['pop rap']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 79.0, \"Danceability\": 0.716, \"Energy\": 0.537, \"Loudness\": -7.648, \"Speechiness\": 0.0514, \"Acousticness\": 0.233, \"Liveness\": 0.157, \"Tempo\": 129.979, \"Duration (ms)\": 165978.0, \"Valence\": 0.28, \"Chord\": \"C\"}, {\"Index\": 824, \"Highest Charting Position\": 37, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Mamichula - con Nicki Nicole\", \"Streams\": 4817969, \"Artist\": \"Trueno, Bizarrap, Taiu, TATOOL\", \"Artist Followers\": 2172969.0, \"Song ID\": \"0TUW9faHNaBmi89wsYGp9y\", \"Genre\": \"['argentine hip hop', 'trap argentino', 'trap latino']\", \"Release Date\": \"2020-07-23\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 75.0, \"Danceability\": 0.696, \"Energy\": 0.678, \"Loudness\": -5.893, \"Speechiness\": 0.0735, \"Acousticness\": 0.582, \"Liveness\": 0.134, \"Tempo\": 91.985, \"Duration (ms)\": 219202.0, \"Valence\": 0.346, \"Chord\": \"E\"}, {\"Index\": 825, \"Highest Charting Position\": 172, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Let Her Go\", \"Streams\": 4765198, \"Artist\": \"Passenger\", \"Artist Followers\": 2819406.0, \"Song ID\": \"0JmiBCpWc1IAc0et7Xm7FL\", \"Genre\": \"['folk-pop', 'neo mellow', 'pop', 'pop rock']\", \"Release Date\": \"2013-02-17\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 75.0, \"Danceability\": 0.479, \"Energy\": 0.545, \"Loudness\": -7.346, \"Speechiness\": 0.0688, \"Acousticness\": 0.365, \"Liveness\": 0.0963, \"Tempo\": 74.897, \"Duration (ms)\": 252733.0, \"Valence\": 0.243, \"Chord\": \"G\"}, {\"Index\": 826, \"Highest Charting Position\": 26, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Play Date\", \"Streams\": 4745568, \"Artist\": \"Melanie Martinez\", \"Artist Followers\": 10925614.0, \"Song ID\": \"4DpNNXFMMxQEKl7r0ykkWA\", \"Genre\": \"['alt z', 'electropop', 'modern rock', 'pop']\", \"Release Date\": \"2015-08-14\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 80.0, \"Danceability\": 0.68, \"Energy\": 0.729, \"Loudness\": -5.077, \"Speechiness\": 0.0475, \"Acousticness\": 0.612, \"Liveness\": 0.224, \"Tempo\": 123.97, \"Duration (ms)\": 179867.0, \"Valence\": 0.446, \"Chord\": \"F\"}, {\"Index\": 827, \"Highest Charting Position\": 32, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Lose Somebody\", \"Streams\": 4709053, \"Artist\": \"Kygo, OneRepublic\", \"Artist Followers\": 7593792.0, \"Song ID\": \"1sgDyuLooyvEML4oHspNza\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 75.0, \"Danceability\": 0.58, \"Energy\": 0.586, \"Loudness\": -6.883, \"Speechiness\": 0.0357, \"Acousticness\": 0.344, \"Liveness\": 0.0755, \"Tempo\": 147.988, \"Duration (ms)\": 199549.0, \"Valence\": 0.507, \"Chord\": \"C#/Db\"}, {\"Index\": 828, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Someone Like You\", \"Streams\": 4703672, \"Artist\": \"Adele\", \"Artist Followers\": 28335338.0, \"Song ID\": \"1zwMYTA5nlNjZxYrvBB2pV\", \"Genre\": \"['british soul', 'pop', 'pop soul', 'uk pop']\", \"Release Date\": \"2011-01-24\", \"Weeks Charted\": \"2020-10-23--2020-10-30\", \"Popularity\": 77.0, \"Danceability\": 0.556, \"Energy\": 0.319, \"Loudness\": -8.251, \"Speechiness\": 0.0281, \"Acousticness\": 0.893, \"Liveness\": 0.0996, \"Tempo\": 135.187, \"Duration (ms)\": 285240.0, \"Valence\": 0.294, \"Chord\": \"A\"}, {\"Index\": 829, \"Highest Charting Position\": 73, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"It's You\", \"Streams\": 4674658, \"Artist\": \"Ali Gatie\", \"Artist Followers\": 1758300.0, \"Song ID\": \"5DqdesEfbRyOlSS3Tf6c29\", \"Genre\": \"['canadian hip hop', 'pop']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.732, \"Energy\": 0.463, \"Loudness\": -6.972, \"Speechiness\": 0.0287, \"Acousticness\": 0.374, \"Liveness\": 0.194, \"Tempo\": 95.971, \"Duration (ms)\": 212607.0, \"Valence\": 0.397, \"Chord\": \"B\"}, {\"Index\": 830, \"Highest Charting Position\": 68, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Stunnin' (feat. Harm Franklin)\", \"Streams\": 5183246, \"Artist\": \"Curtis Waters\", \"Artist Followers\": 68875.0, \"Song ID\": \"2JSmxLqt8h7ZpJJkfuLJvK\", \"Genre\": \"[]\", \"Release Date\": \"2020-10-09\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 68.0, \"Danceability\": 0.885, \"Energy\": 0.685, \"Loudness\": -6.429, \"Speechiness\": 0.0627, \"Acousticness\": 0.33, \"Liveness\": 0.148, \"Tempo\": 99.954, \"Duration (ms)\": 144000.0, \"Valence\": 0.937, \"Chord\": \"B\"}, {\"Index\": 831, \"Highest Charting Position\": 35, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Love To Hate Me\", \"Streams\": 5125708, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"7iKDsPfLT0d5mu2htfMKBZ\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 69.0, \"Danceability\": 0.686, \"Energy\": 0.64, \"Loudness\": -5.491, \"Speechiness\": 0.159, \"Acousticness\": 0.0334, \"Liveness\": 0.0801, \"Tempo\": 162.225, \"Duration (ms)\": 171798.0, \"Valence\": 0.597, \"Chord\": \"G#/Ab\"}, {\"Index\": 832, \"Highest Charting Position\": 165, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Hate The Way (feat. blackbear)\", \"Streams\": 5116071, \"Artist\": \"G-Eazy\", \"Artist Followers\": 4894656.0, \"Song ID\": \"3QGppKBPd9gHOgHJzRbVIw\", \"Genre\": \"['hip hop', 'indie pop rap', 'oakland hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2020-10-16--2020-10-23\", \"Popularity\": 68.0, \"Danceability\": 0.569, \"Energy\": 0.865, \"Loudness\": -3.844, \"Speechiness\": 0.266, \"Acousticness\": 0.0673, \"Liveness\": 0.312, \"Tempo\": 82.011, \"Duration (ms)\": 214363.0, \"Valence\": 0.361, \"Chord\": \"E\"}, {\"Index\": 833, \"Highest Charting Position\": 89, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Bande organis\\u00e9e\", \"Streams\": 5112572, \"Artist\": \"13 Organis\\u00e9, SCH, Kofs, Jul, Naps, Soso Maness, Elams, Solda, Houari\", \"Artist Followers\": 249910.0, \"Song ID\": \"205HNJ73cgpC0LAOnuQiWT\", \"Genre\": \"['french hip hop', 'pop urbaine', 'rap francais', 'rap marseille']\", \"Release Date\": \"2020-08-15\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 72.0, \"Danceability\": 0.901, \"Energy\": 0.939, \"Loudness\": -2.762, \"Speechiness\": 0.274, \"Acousticness\": 0.117, \"Liveness\": 0.0643, \"Tempo\": 142.948, \"Duration (ms)\": 356347.0, \"Valence\": 0.805, \"Chord\": \"F#/Gb\"}, {\"Index\": 834, \"Highest Charting Position\": 32, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Crazy Over You\", \"Streams\": 5056387, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"7qq0EOPW4RRlqdvMBmdd73\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 68.0, \"Danceability\": 0.804, \"Energy\": 0.633, \"Loudness\": -6.186, \"Speechiness\": 0.0612, \"Acousticness\": 0.0371, \"Liveness\": 0.102, \"Tempo\": 115.002, \"Duration (ms)\": 163946.0, \"Valence\": 0.67, \"Chord\": \"E\"}, {\"Index\": 835, \"Highest Charting Position\": 109, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Baby, I'm Jealous (feat. Doja Cat)\", \"Streams\": 4870203, \"Artist\": \"Bebe Rexha\", \"Artist Followers\": 6569150.0, \"Song ID\": \"2fTdRdN73RgIgcUZN33dvt\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-09\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 69.0, \"Danceability\": 0.737, \"Energy\": 0.867, \"Loudness\": -2.259, \"Speechiness\": 0.0458, \"Acousticness\": 0.0398, \"Liveness\": 0.32, \"Tempo\": 98.05, \"Duration (ms)\": 175873.0, \"Valence\": 0.506, \"Chord\": \"B\"}, {\"Index\": 836, \"Highest Charting Position\": 15, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"TKN (feat. Travis Scott)\", \"Streams\": 4752289, \"Artist\": \"ROSAL\\u00cdA\", \"Artist Followers\": 4769627.0, \"Song ID\": \"4w47S36wQGBhGg073q3nt7\", \"Genre\": \"['r&b en espanol']\", \"Release Date\": \"2020-05-28\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 75.0, \"Danceability\": 0.776, \"Energy\": 0.509, \"Loudness\": -6.266, \"Speechiness\": 0.467, \"Acousticness\": 0.192, \"Liveness\": 0.115, \"Tempo\": 94.634, \"Duration (ms)\": 129371.0, \"Valence\": 0.485, \"Chord\": \"C\"}, {\"Index\": 837, \"Highest Charting Position\": 135, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"El Mismo Aire - con Pablo Albor\\u00e1n\", \"Streams\": 4705484, \"Artist\": \"Camilo\", \"Artist Followers\": 10580764.0, \"Song ID\": \"5EbtodsuLbxrFDH6j5avVS\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-06-10\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 75.0, \"Danceability\": 0.483, \"Energy\": 0.492, \"Loudness\": -6.591, \"Speechiness\": 0.295, \"Acousticness\": 0.603, \"Liveness\": 0.323, \"Tempo\": 144.511, \"Duration (ms)\": 188213.0, \"Valence\": 0.66, \"Chord\": \"C\"}, {\"Index\": 838, \"Highest Charting Position\": 18, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Yo Perreo Sola\", \"Streams\": 4680447, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0SqqAgdovOE24BzxIClpjw\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 78.0, \"Danceability\": 0.86, \"Energy\": 0.758, \"Loudness\": -5.16, \"Speechiness\": 0.0695, \"Acousticness\": 0.021, \"Liveness\": 0.344, \"Tempo\": 97.014, \"Duration (ms)\": 172127.0, \"Valence\": 0.453, \"Chord\": \"B\"}, {\"Index\": 839, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Let Me Love You Like A Woman\", \"Streams\": 4665053, \"Artist\": \"Lana Del Rey\", \"Artist Followers\": 13697048.0, \"Song ID\": \"1gxdWpeOUBpvB908fiZs4D\", \"Genre\": \"['art pop', 'pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2020-10-16--2020-10-23\", \"Popularity\": 67.0, \"Danceability\": 0.303, \"Energy\": 0.249, \"Loudness\": -11.715, \"Speechiness\": 0.111, \"Acousticness\": 0.97, \"Liveness\": 0.117, \"Tempo\": 66.932, \"Duration (ms)\": 200661.0, \"Valence\": 0.131, \"Chord\": \"C\"}, {\"Index\": 840, \"Highest Charting Position\": 69, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"DOLLAZ ON MY HEAD (feat. Young Thug)\", \"Streams\": 4652712, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"3nS9a01VvXHQriLqJYwRqG\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 76.0, \"Danceability\": 0.825, \"Energy\": 0.458, \"Loudness\": -7.47, \"Speechiness\": 0.0577, \"Acousticness\": 0.114, \"Liveness\": 0.102, \"Tempo\": 145.115, \"Duration (ms)\": 197760.0, \"Valence\": 0.161, \"Chord\": \"C\"}, {\"Index\": 841, \"Highest Charting Position\": 54, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Eleg\\u00ed (feat. D\\u00edmelo Flow)\", \"Streams\": 4607003, \"Artist\": \"Rauw Alejandro, Dalex, Lenny Tav\\u00e1rez\", \"Artist Followers\": 6096559.0, \"Song ID\": \"50ZC4PM7hywH27RcCfViau\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-03-26\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 75.0, \"Danceability\": 0.824, \"Energy\": 0.631, \"Loudness\": -2.791, \"Speechiness\": 0.0809, \"Acousticness\": 0.237, \"Liveness\": 0.0531, \"Tempo\": 171.965, \"Duration (ms)\": 197721.0, \"Valence\": 0.678, \"Chord\": \"C\"}, {\"Index\": 842, \"Highest Charting Position\": 77, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"July\", \"Streams\": 4598766, \"Artist\": \"Noah Cyrus\", \"Artist Followers\": 891555.0, \"Song ID\": \"6J2LdBN97cDWn0MLxYh9HB\", \"Genre\": \"['alt z', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.708, \"Energy\": 0.186, \"Loudness\": -8.953, \"Speechiness\": 0.042, \"Acousticness\": 0.868, \"Liveness\": 0.0779, \"Tempo\": 72.541, \"Duration (ms)\": 156106.0, \"Valence\": 0.322, \"Chord\": \"A\"}, {\"Index\": 843, \"Highest Charting Position\": 93, \"Number of Times Charted\": 38, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Bruises\", \"Streams\": 4560503, \"Artist\": \"Lewis Capaldi\", \"Artist Followers\": 8388838.0, \"Song ID\": \"4Of7rzpRpV1mWRbhp5rAqG\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.736, \"Energy\": 0.308, \"Loudness\": -7.83, \"Speechiness\": 0.0677, \"Acousticness\": 0.946, \"Liveness\": 0.186, \"Tempo\": 111.202, \"Duration (ms)\": 220492.0, \"Valence\": 0.361, \"Chord\": \"E\"}, {\"Index\": 844, \"Highest Charting Position\": 46, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"You Never Know\", \"Streams\": 5304382, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"3b7trEcKoglybN5MxGuSaw\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2021-08-03\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 54.0, \"Danceability\": 0.535, \"Energy\": 0.434, \"Loudness\": -5.768, \"Speechiness\": 0.0505, \"Acousticness\": 0.405, \"Liveness\": 0.253, \"Tempo\": 144.497, \"Duration (ms)\": 229236.0, \"Valence\": 0.271, \"Chord\": \"F\"}, {\"Index\": 845, \"Highest Charting Position\": 12, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Supalonely\", \"Streams\": 5089970, \"Artist\": \"BENEE, Gus Dapperton\", \"Artist Followers\": 638337.0, \"Song ID\": \"4nK5YrxbMGZstTLbvj6Gxw\", \"Genre\": \"['alt z', 'nz pop', 'pop']\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 77.0, \"Danceability\": 0.863, \"Energy\": 0.631, \"Loudness\": -4.689, \"Speechiness\": 0.0534, \"Acousticness\": 0.305, \"Liveness\": 0.123, \"Tempo\": 128.977, \"Duration (ms)\": 223480.0, \"Valence\": 0.817, \"Chord\": \"G\"}, {\"Index\": 846, \"Highest Charting Position\": 53, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Glock In My Lap\", \"Streams\": 4947593, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"6pcywuOeGGWeOQzdUyti6k\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 69.0, \"Danceability\": 0.847, \"Energy\": 0.733, \"Loudness\": -6.439, \"Speechiness\": 0.16, \"Acousticness\": 0.00574, \"Liveness\": 0.151, \"Tempo\": 130.029, \"Duration (ms)\": 193591.0, \"Valence\": 0.202, \"Chord\": \"A#/Bb\"}, {\"Index\": 847, \"Highest Charting Position\": 49, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Better\", \"Streams\": 4933462, \"Artist\": \"ZAYN\", \"Artist Followers\": 16655692.0, \"Song ID\": \"1dLXLETYiZohIZWnse4ypG\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-01-03--2020-01-10\", \"Popularity\": 68.0, \"Danceability\": 0.637, \"Energy\": 0.418, \"Loudness\": -7.137, \"Speechiness\": 0.301, \"Acousticness\": 0.353, \"Liveness\": 0.131, \"Tempo\": 84.295, \"Duration (ms)\": 174517.0, \"Valence\": 0.0807, \"Chord\": \"D\"}, {\"Index\": 848, \"Highest Charting Position\": 59, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"forget me too (feat. Halsey)\", \"Streams\": 4751756, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3868320.0, \"Song ID\": \"1VSuFS7PahCN3SWbOcQ98m\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 78.0, \"Danceability\": 0.654, \"Energy\": 0.875, \"Loudness\": -4.845, \"Speechiness\": 0.0744, \"Acousticness\": 0.000417, \"Liveness\": 0.194, \"Tempo\": 99.975, \"Duration (ms)\": 171621.0, \"Valence\": 0.522, \"Chord\": \"C#/Db\"}, {\"Index\": 849, \"Highest Charting Position\": 110, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Oh Juliana\", \"Streams\": 4751064, \"Artist\": \"Niack\", \"Artist Followers\": 352402.0, \"Song ID\": \"4xWzZmX4K1yyrdtRfbUvjt\", \"Genre\": \"['funk carioca']\", \"Release Date\": \"2020-06-30\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 66.0, \"Danceability\": 0.799, \"Energy\": 0.568, \"Loudness\": -3.089, \"Speechiness\": 0.25, \"Acousticness\": 0.387, \"Liveness\": 0.0892, \"Tempo\": 129.63, \"Duration (ms)\": 153078.0, \"Valence\": 0.963, \"Chord\": \"F#/Gb\"}, {\"Index\": 850, \"Highest Charting Position\": 81, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"PORFA Remix ( Feat. Maluma, Nicky Jam, Sech) - Remix\", \"Streams\": 4727923, \"Artist\": \"Feid, J Balvin, Justin Quiles\", \"Artist Followers\": 613348.0, \"Song ID\": \"7lUdbnz7wsv3C9zzf4WHl9\", \"Genre\": \"['colombian pop', 'latin', 'pop reggaeton', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 70.0, \"Danceability\": 0.793, \"Energy\": 0.737, \"Loudness\": -4.731, \"Speechiness\": 0.0785, \"Acousticness\": 0.0765, \"Liveness\": 0.0747, \"Tempo\": 167.969, \"Duration (ms)\": 333800.0, \"Valence\": 0.697, \"Chord\": \"F#/Gb\"}, {\"Index\": 851, \"Highest Charting Position\": 108, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"No Guidance (feat. Drake)\", \"Streams\": 4641393, \"Artist\": \"Chris Brown\", \"Artist Followers\": 14073083.0, \"Song ID\": \"6XHVuErjQ4XNm6nDPVCxVX\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'r&b', 'rap']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.696, \"Energy\": 0.454, \"Loudness\": -6.756, \"Speechiness\": 0.153, \"Acousticness\": 0.123, \"Liveness\": 0.155, \"Tempo\": 92.928, \"Duration (ms)\": 260640.0, \"Valence\": 0.136, \"Chord\": \"C#/Db\"}, {\"Index\": 852, \"Highest Charting Position\": 65, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Rich Nigga Shit (feat. Young Thug)\", \"Streams\": 9129562, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"3ruoIF2UnoXdzK8mR61ebq\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 73.0, \"Danceability\": 0.825, \"Energy\": 0.733, \"Loudness\": -5.625, \"Speechiness\": 0.0969, \"Acousticness\": 0.349, \"Liveness\": 0.112, \"Tempo\": 97.974, \"Duration (ms)\": 190331.0, \"Valence\": 0.62, \"Chord\": \"C#/Db\"}, {\"Index\": 853, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Many Men\", \"Streams\": 8675173, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"3CDVMejYHnB1SkEEx0T1N4\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 65.0, \"Danceability\": 0.635, \"Energy\": 0.793, \"Loudness\": -4.333, \"Speechiness\": 0.0322, \"Acousticness\": 0.000647, \"Liveness\": 0.113, \"Tempo\": 77.594, \"Duration (ms)\": 201856.0, \"Valence\": 0.281, \"Chord\": \"A#/Bb\"}, {\"Index\": 854, \"Highest Charting Position\": 77, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Slidin\", \"Streams\": 8243488, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"7fxSLnklnayJNBIKntXedZ\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 64.0, \"Danceability\": 0.774, \"Energy\": 0.706, \"Loudness\": -6.494, \"Speechiness\": 0.355, \"Acousticness\": 0.00163, \"Liveness\": 0.104, \"Tempo\": 152.891, \"Duration (ms)\": 185037.0, \"Valence\": 0.382, \"Chord\": \"D\"}, {\"Index\": 855, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Outta Time (feat. Drake)\", \"Streams\": 7762934, \"Artist\": \"Bryson Tiller\", \"Artist Followers\": 5019909.0, \"Song ID\": \"4SCnCPOUOUXUmCX2uHb3r7\", \"Genre\": \"['kentucky hip hop', 'pop', 'pop rap', 'r&b', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 68.0, \"Danceability\": 0.714, \"Energy\": 0.582, \"Loudness\": -7.272, \"Speechiness\": 0.0808, \"Acousticness\": 0.0129, \"Liveness\": 0.0774, \"Tempo\": 92.819, \"Duration (ms)\": 198822.0, \"Valence\": 0.338, \"Chord\": \"F\"}, {\"Index\": 856, \"Highest Charting Position\": 131, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"My Dawg\", \"Streams\": 6029118, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"42Tohunwlh34o0mgxYx5iq\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 60.0, \"Danceability\": 0.831, \"Energy\": 0.532, \"Loudness\": -5.319, \"Speechiness\": 0.301, \"Acousticness\": 0.0652, \"Liveness\": 0.464, \"Tempo\": 140.105, \"Duration (ms)\": 181716.0, \"Valence\": 0.364, \"Chord\": \"C\"}, {\"Index\": 857, \"Highest Charting Position\": 138, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Snitches & Rats (feat. Young Nudy)\", \"Streams\": 5846760, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"3WaDoMDQRqDdgtCDLxanpN\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 57.0, \"Danceability\": 0.821, \"Energy\": 0.671, \"Loudness\": -5.893, \"Speechiness\": 0.18, \"Acousticness\": 0.00843, \"Liveness\": 0.0972, \"Tempo\": 145.953, \"Duration (ms)\": 187773.0, \"Valence\": 0.494, \"Chord\": \"A\"}, {\"Index\": 858, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Brand New Draco\", \"Streams\": 5841110, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"4V9ynsDPwHtdItksqjuRu0\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 63.0, \"Danceability\": 0.697, \"Energy\": 0.709, \"Loudness\": -6.642, \"Speechiness\": 0.298, \"Acousticness\": 0.041, \"Liveness\": 0.0886, \"Tempo\": 155.023, \"Duration (ms)\": 202420.0, \"Valence\": 0.439, \"Chord\": \"B\"}, {\"Index\": 859, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Lemonade (Feat. Roddy Ricch & Don Toliver) [Remix]\", \"Streams\": 5550390, \"Artist\": \"Internet Money\", \"Artist Followers\": 412466.0, \"Song ID\": \"5sBplhIrmzA4kQGyIOpmDf\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-09-30\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 69.0, \"Danceability\": 0.832, \"Energy\": 0.549, \"Loudness\": -8.259, \"Speechiness\": 0.0602, \"Acousticness\": 0.168, \"Liveness\": 0.11, \"Tempo\": 140.045, \"Duration (ms)\": 181496.0, \"Valence\": 0.384, \"Chord\": \"C#/Db\"}, {\"Index\": 860, \"Highest Charting Position\": 77, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Your Man\", \"Streams\": 5233336, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"6Vgtvd7I5yopJdBuxqjBd2\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-24\", \"Weeks Charted\": \"2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 68.0, \"Danceability\": 0.785, \"Energy\": 0.818, \"Loudness\": -8.711, \"Speechiness\": 0.099, \"Acousticness\": 0.624, \"Liveness\": 0.149, \"Tempo\": 117.98, \"Duration (ms)\": 163759.0, \"Valence\": 0.0503, \"Chord\": \"G\"}, {\"Index\": 861, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"No Opp Left Behind\", \"Streams\": 5154955, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"50I7FNN2rl2rWiNwGxS146\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 61.0, \"Danceability\": 0.823, \"Energy\": 0.703, \"Loudness\": -2.691, \"Speechiness\": 0.298, \"Acousticness\": 0.0161, \"Liveness\": 0.294, \"Tempo\": 178.043, \"Duration (ms)\": 194214.0, \"Valence\": 0.26, \"Chord\": \"G#/Ab\"}, {\"Index\": 862, \"Highest Charting Position\": 106, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Lets Link\", \"Streams\": 5109038, \"Artist\": \"WhoHeem\", \"Artist Followers\": 25417.0, \"Song ID\": \"6fMzgFFGzWCwiHMzDzNpp5\", \"Genre\": \"['viral rap']\", \"Release Date\": \"2020-08-20\", \"Weeks Charted\": \"2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 61.0, \"Danceability\": 0.839, \"Energy\": 0.683, \"Loudness\": -9.232, \"Speechiness\": 0.165, \"Acousticness\": 0.00667, \"Liveness\": 0.241, \"Tempo\": 120.003, \"Duration (ms)\": 159955.0, \"Valence\": 0.522, \"Chord\": \"A#/Bb\"}, {\"Index\": 863, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"RIP Luv\", \"Streams\": 4915080, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"1wGnp7ejkCuXRsehXx0PNP\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 62.0, \"Danceability\": 0.63, \"Energy\": 0.399, \"Loudness\": -9.869, \"Speechiness\": 0.178, \"Acousticness\": 0.105, \"Liveness\": 0.234, \"Tempo\": 183.016, \"Duration (ms)\": 214192.0, \"Valence\": 0.0657, \"Chord\": \"F\"}, {\"Index\": 864, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Steppin On Niggas\", \"Streams\": 4853661, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"7FtZFla3ZH6PqsAJ9MvVCM\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 57.0, \"Danceability\": 0.849, \"Energy\": 0.635, \"Loudness\": -4.068, \"Speechiness\": 0.254, \"Acousticness\": 0.000608, \"Liveness\": 0.062, \"Tempo\": 89.484, \"Duration (ms)\": 140833.0, \"Valence\": 0.798, \"Chord\": \"G\"}, {\"Index\": 865, \"Highest Charting Position\": 58, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Gimme Love\", \"Streams\": 7471309, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"2hfoyc7ve6xM4ZEiNIiU1B\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-04-16\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 69.0, \"Danceability\": 0.482, \"Energy\": 0.631, \"Loudness\": -6.917, \"Speechiness\": 0.0986, \"Acousticness\": 0.696, \"Liveness\": 0.209, \"Tempo\": 126.576, \"Duration (ms)\": 214558.0, \"Valence\": 0.0743, \"Chord\": \"F\"}, {\"Index\": 866, \"Highest Charting Position\": 97, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Ew\", \"Streams\": 6936305, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"7xcUWyLh6fIMsYjoVI7NnZ\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 67.0, \"Danceability\": 0.48, \"Energy\": 0.373, \"Loudness\": -9.297, \"Speechiness\": 0.0278, \"Acousticness\": 0.804, \"Liveness\": 0.12, \"Tempo\": 114.078, \"Duration (ms)\": 207710.0, \"Valence\": 0.0376, \"Chord\": \"A#/Bb\"}, {\"Index\": 867, \"Highest Charting Position\": 99, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Daylight\", \"Streams\": 6819838, \"Artist\": \"Joji, Diplo\", \"Artist Followers\": 4759367.0, \"Song ID\": \"6Ed1q0X8oSKSm4IIhiQbYg\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-08-06\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-08-07--2020-08-14\", \"Popularity\": 72.0, \"Danceability\": 0.528, \"Energy\": 0.749, \"Loudness\": -7.571, \"Speechiness\": 0.0479, \"Acousticness\": 0.00488, \"Liveness\": 0.0949, \"Tempo\": 163.944, \"Duration (ms)\": 163906.0, \"Valence\": 0.729, \"Chord\": \"G\"}, {\"Index\": 868, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Epidemic\", \"Streams\": 6292620, \"Artist\": \"Polo G\", \"Artist Followers\": 4849204.0, \"Song ID\": \"170DNUSnQRp1tGpppF26pA\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 71.0, \"Danceability\": 0.616, \"Energy\": 0.617, \"Loudness\": -8.431, \"Speechiness\": 0.52, \"Acousticness\": 0.128, \"Liveness\": 0.177, \"Tempo\": 175.929, \"Duration (ms)\": 177273.0, \"Valence\": 0.476, \"Chord\": \"C#/Db\"}, {\"Index\": 869, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"bloody valentine\", \"Streams\": 6032935, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3868320.0, \"Song ID\": \"6mADjHs6FXdroPzEGW6KVJ\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 77.0, \"Danceability\": 0.533, \"Energy\": 0.858, \"Loudness\": -4.212, \"Speechiness\": 0.0766, \"Acousticness\": 0.00021, \"Liveness\": 0.148, \"Tempo\": 160.057, \"Duration (ms)\": 205159.0, \"Valence\": 0.506, \"Chord\": \"D\"}, {\"Index\": 870, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"MODUS\", \"Streams\": 6013371, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"5SjtAe7xzUgHDtNTmt8zS7\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 66.0, \"Danceability\": 0.738, \"Energy\": 0.533, \"Loudness\": -7.617, \"Speechiness\": 0.0492, \"Acousticness\": 0.183, \"Liveness\": 0.115, \"Tempo\": 132.008, \"Duration (ms)\": 207265.0, \"Valence\": 0.262, \"Chord\": \"G\"}, {\"Index\": 871, \"Highest Charting Position\": 145, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Tick Tock\", \"Streams\": 5547939, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"5E7p95xh9Ul4vZp4LEoJwi\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 65.0, \"Danceability\": 0.781, \"Energy\": 0.613, \"Loudness\": -5.582, \"Speechiness\": 0.0524, \"Acousticness\": 0.0399, \"Liveness\": 0.0976, \"Tempo\": 80.53, \"Duration (ms)\": 132215.0, \"Valence\": 0.613, \"Chord\": \"E\"}, {\"Index\": 872, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Sanctuary\", \"Streams\": 5482390, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"3xaugmCyXrVkrDTXbFkMW3\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2019-06-14\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 69.0, \"Danceability\": 0.552, \"Energy\": 0.65, \"Loudness\": -7.199, \"Speechiness\": 0.128, \"Acousticness\": 0.422, \"Liveness\": 0.372, \"Tempo\": 167.788, \"Duration (ms)\": 180019.0, \"Valence\": 0.316, \"Chord\": \"C#/Db\"}, {\"Index\": 873, \"Highest Charting Position\": 112, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"feel something\", \"Streams\": 5463424, \"Artist\": \"Bea Miller\", \"Artist Followers\": 2396662.0, \"Song ID\": \"7JDWhC422Gtk1Bq0mL3OTC\", \"Genre\": \"['alt z', 'dance pop', 'electropop', 'indie cafe pop', 'indie poptimism', 'modern rock', 'pop', 'pop rap', 'post-teen pop', 'talent show']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 75.0, \"Danceability\": 0.74, \"Energy\": 0.415, \"Loudness\": -8.914, \"Speechiness\": 0.0707, \"Acousticness\": 0.242, \"Liveness\": 0.319, \"Tempo\": 136.029, \"Duration (ms)\": 180161.0, \"Valence\": 0.156, \"Chord\": \"C\"}, {\"Index\": 874, \"Highest Charting Position\": 86, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Tap In\", \"Streams\": 5220309, \"Artist\": \"Saweetie\", \"Artist Followers\": 1255573.0, \"Song ID\": \"4Hpib09wXgD84w4uwTPnYD\", \"Genre\": \"['cali rap', 'dance pop', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-06-17\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 73.0, \"Danceability\": 0.954, \"Energy\": 0.696, \"Loudness\": -7.117, \"Speechiness\": 0.204, \"Acousticness\": 0.00576, \"Liveness\": 0.0754, \"Tempo\": 100.036, \"Duration (ms)\": 139413.0, \"Valence\": 0.432, \"Chord\": \"A#/Bb\"}, {\"Index\": 875, \"Highest Charting Position\": 171, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Pretty Boy (feat. Lil Yachty)\", \"Streams\": 5141212, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"0f1G5SHFoFC9lO03gHCGVS\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 66.0, \"Danceability\": 0.656, \"Energy\": 0.776, \"Loudness\": -6.184, \"Speechiness\": 0.0672, \"Acousticness\": 0.16, \"Liveness\": 0.372, \"Tempo\": 156.049, \"Duration (ms)\": 156759.0, \"Valence\": 0.638, \"Chord\": \"F#/Gb\"}, {\"Index\": 876, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Afterthought\", \"Streams\": 4977405, \"Artist\": \"Joji, BENEE\", \"Artist Followers\": 4759367.0, \"Song ID\": \"6zvqq50PL7io0rprbkrYc9\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 67.0, \"Danceability\": 0.668, \"Energy\": 0.547, \"Loudness\": -8.024, \"Speechiness\": 0.0353, \"Acousticness\": 0.398, \"Liveness\": 0.0931, \"Tempo\": 83.5, \"Duration (ms)\": 194871.0, \"Valence\": 0.192, \"Chord\": \"C#/Db\"}, {\"Index\": 877, \"Highest Charting Position\": 164, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"+Linda\", \"Streams\": 4964708, \"Artist\": \"Dalex\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-08-28--2020-09-04\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 878, \"Highest Charting Position\": 24, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Over Now (with The Weeknd)\", \"Streams\": 4867620, \"Artist\": \"Calvin Harris\", \"Artist Followers\": 21946934.0, \"Song ID\": \"58AGoOGbwsQMhBbH0eFLRR\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'house', 'pop', 'progressive house', 'uk dance']\", \"Release Date\": \"2020-08-28\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 72.0, \"Danceability\": 0.612, \"Energy\": 0.884, \"Loudness\": -4.113, \"Speechiness\": 0.0454, \"Acousticness\": 0.0759, \"Liveness\": 0.247, \"Tempo\": 178.043, \"Duration (ms)\": 210795.0, \"Valence\": 0.679, \"Chord\": \"E\"}, {\"Index\": 879, \"Highest Charting Position\": 14, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Hate The Other Side (with Marshmello & The Kid Laroi)\", \"Streams\": 4851997, \"Artist\": \"Juice WRLD, Polo G\", \"Artist Followers\": 19102888.0, \"Song ID\": \"0ada5XsQGLPUVbmTCkAP49\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 78.0, \"Danceability\": 0.701, \"Energy\": 0.65, \"Loudness\": -6.313, \"Speechiness\": 0.104, \"Acousticness\": 0.291, \"Liveness\": 0.112, \"Tempo\": 90.003, \"Duration (ms)\": 160212.0, \"Valence\": 0.647, \"Chord\": \"F#/Gb\"}, {\"Index\": 880, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"drunk face\", \"Streams\": 4834258, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3868320.0, \"Song ID\": \"3k0YJnqMKRZb8swo86vCkq\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 72.0, \"Danceability\": 0.691, \"Energy\": 0.77, \"Loudness\": -4.578, \"Speechiness\": 0.0367, \"Acousticness\": 0.0282, \"Liveness\": 0.497, \"Tempo\": 90.024, \"Duration (ms)\": 143901.0, \"Valence\": 0.344, \"Chord\": \"G\"}, {\"Index\": 881, \"Highest Charting Position\": 76, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Tak Tiki Tak\", \"Streams\": 4761286, \"Artist\": \"Harry Nach\", \"Artist Followers\": 134339.0, \"Song ID\": \"7gwwt1IaAWwmB7af0AcuBM\", \"Genre\": \"['trap chileno', 'trap latino']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\", \"Popularity\": 71.0, \"Danceability\": 0.801, \"Energy\": 0.579, \"Loudness\": -4.78, \"Speechiness\": 0.0813, \"Acousticness\": 0.333, \"Liveness\": 0.172, \"Tempo\": 99.994, \"Duration (ms)\": 212406.0, \"Valence\": 0.231, \"Chord\": \"B\"}, {\"Index\": 882, \"Highest Charting Position\": 26, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"WHATS POPPIN\", \"Streams\": 4745752, \"Artist\": \"Jack Harlow\", \"Artist Followers\": 3828418.0, \"Song ID\": \"2MbdDtCv5LUVjYy9RuGTgC\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-06-24\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 80.0, \"Danceability\": 0.904, \"Energy\": 0.723, \"Loudness\": -5.224, \"Speechiness\": 0.26, \"Acousticness\": 0.0631, \"Liveness\": 0.185, \"Tempo\": 145.013, \"Duration (ms)\": 227478.0, \"Valence\": 0.835, \"Chord\": \"B\"}, {\"Index\": 883, \"Highest Charting Position\": 143, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Money Trees\", \"Streams\": 4632724, \"Artist\": \"Kendrick Lamar, Jay Rock\", \"Artist Followers\": 17931101.0, \"Song ID\": \"2HbKqm4o0w5wEeEFXm2sD4\", \"Genre\": \"['conscious hip hop', 'hip hop', 'rap', 'west coast rap']\", \"Release Date\": \"2012\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 75.0, \"Danceability\": 0.716, \"Energy\": 0.531, \"Loudness\": -7.355, \"Speechiness\": 0.122, \"Acousticness\": 0.0703, \"Liveness\": 0.224, \"Tempo\": 71.994, \"Duration (ms)\": 386907.0, \"Valence\": 0.344, \"Chord\": \"G\"}, {\"Index\": 884, \"Highest Charting Position\": 65, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Blastoff (feat. Juice Wrld & Trippie Redd)\", \"Streams\": 4628159, \"Artist\": \"Internet Money, Diplo\", \"Artist Followers\": 412466.0, \"Song ID\": \"2rFsFjq0D9JAmc0APpCO6P\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-08-29\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 70.0, \"Danceability\": 0.761, \"Energy\": 0.517, \"Loudness\": -6.916, \"Speechiness\": 0.0927, \"Acousticness\": 0.114, \"Liveness\": 0.157, \"Tempo\": 147.912, \"Duration (ms)\": 174730.0, \"Valence\": 0.46, \"Chord\": \"F\"}, {\"Index\": 885, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"September\", \"Streams\": 5329256, \"Artist\": \"Earth, Wind & Fire\", \"Artist Followers\": 3008916.0, \"Song ID\": \"2grjqo0Frpf2okIBiifQKs\", \"Genre\": \"['disco', 'funk', 'jazz funk', 'motown', 'quiet storm', 'soul']\", \"Release Date\": \"1978-11-23\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 80.0, \"Danceability\": 0.697, \"Energy\": 0.832, \"Loudness\": -7.264, \"Speechiness\": 0.0298, \"Acousticness\": 0.168, \"Liveness\": 0.269, \"Tempo\": 125.926, \"Duration (ms)\": 215093.0, \"Valence\": 0.979, \"Chord\": \"A\"}, {\"Index\": 886, \"Highest Charting Position\": 64, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Secrets\", \"Streams\": 5178107, \"Artist\": \"Regard, RAYE\", \"Artist Followers\": 152237.0, \"Song ID\": \"66W1rVTnEv86dIkFhoiElg\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop edm', 'slap house', 'tropical house']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 78.0, \"Danceability\": 0.848, \"Energy\": 0.768, \"Loudness\": -5.386, \"Speechiness\": 0.0373, \"Acousticness\": 0.0412, \"Liveness\": 0.195, \"Tempo\": 118.961, \"Duration (ms)\": 176767.0, \"Valence\": 0.777, \"Chord\": \"F#/Gb\"}, {\"Index\": 887, \"Highest Charting Position\": 150, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"21\", \"Streams\": 5151406, \"Artist\": \"Polo G\", \"Artist Followers\": 4849204.0, \"Song ID\": \"3JKgcAa7r07ocVWcV8bS0H\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 80.0, \"Danceability\": 0.783, \"Energy\": 0.479, \"Loudness\": -10.646, \"Speechiness\": 0.541, \"Acousticness\": 0.149, \"Liveness\": 0.101, \"Tempo\": 176.027, \"Duration (ms)\": 163798.0, \"Valence\": 0.533, \"Chord\": \"G\"}, {\"Index\": 888, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"BXL ZOO\", \"Streams\": 5101640, \"Artist\": \"Damso, Hamza\", \"Artist Followers\": 3071170.0, \"Song ID\": \"1VBt9dPtYfLnVeKaa6CQPr\", \"Genre\": \"['belgian hip hop', 'french hip hop', 'pop urbaine', 'rap belge', 'rap conscient']\", \"Release Date\": \"2021-04-28\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 62.0, \"Danceability\": 0.745, \"Energy\": 0.656, \"Loudness\": -6.829, \"Speechiness\": 0.203, \"Acousticness\": 0.0604, \"Liveness\": 0.11, \"Tempo\": 137.997, \"Duration (ms)\": 201333.0, \"Valence\": 0.405, \"Chord\": \"B\"}, {\"Index\": 889, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"DEUX TOILES DE MER\", \"Streams\": 5094137, \"Artist\": \"Damso\", \"Artist Followers\": 3071170.0, \"Song ID\": \"6vw0mOQ5vm3C5RPm7Rvl2w\", \"Genre\": \"['belgian hip hop', 'french hip hop', 'pop urbaine', 'rap belge', 'rap conscient']\", \"Release Date\": \"2021-04-28\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 62.0, \"Danceability\": 0.521, \"Energy\": 0.39, \"Loudness\": -9.726, \"Speechiness\": 0.128, \"Acousticness\": 0.582, \"Liveness\": 0.112, \"Tempo\": 104.106, \"Duration (ms)\": 315640.0, \"Valence\": 0.157, \"Chord\": \"G#/Ab\"}, {\"Index\": 890, \"Highest Charting Position\": 4, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"exile (feat. Bon Iver)\", \"Streams\": 4924533, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"4pvb0WLRcMtbPGmtejJJ6y\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 77.0, \"Danceability\": 0.298, \"Energy\": 0.38, \"Loudness\": -8.426, \"Speechiness\": 0.0287, \"Acousticness\": 0.778, \"Liveness\": 0.11, \"Tempo\": 75.602, \"Duration (ms)\": 285634.0, \"Valence\": 0.152, \"Chord\": \"F#/Gb\"}, {\"Index\": 891, \"Highest Charting Position\": 10, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Righteous\", \"Streams\": 4819362, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5dOxHHMOFAbG3VH23t0xNm\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 78.0, \"Danceability\": 0.706, \"Energy\": 0.625, \"Loudness\": -7.426, \"Speechiness\": 0.0314, \"Acousticness\": 0.0417, \"Liveness\": 0.129, \"Tempo\": 142.948, \"Duration (ms)\": 242181.0, \"Valence\": 0.225, \"Chord\": \"C\"}, {\"Index\": 892, \"Highest Charting Position\": 9, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Conversations\", \"Streams\": 4805366, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4K06PO78fW4mnBVenxGNob\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 75.0, \"Danceability\": 0.747, \"Energy\": 0.622, \"Loudness\": -5.825, \"Speechiness\": 0.0838, \"Acousticness\": 0.176, \"Liveness\": 0.151, \"Tempo\": 159.93, \"Duration (ms)\": 181661.0, \"Valence\": 0.57, \"Chord\": \"B\"}, {\"Index\": 893, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Dolly (with Lil Uzi Vert)\", \"Streams\": 4800543, \"Artist\": \"Lil Tecca\", \"Artist Followers\": 4022792.0, \"Song ID\": \"77Xwqkw7VrV8E5FCq9JhO8\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 63.0, \"Danceability\": 0.664, \"Energy\": 0.586, \"Loudness\": -7.813, \"Speechiness\": 0.238, \"Acousticness\": 0.212, \"Liveness\": 0.216, \"Tempo\": 88.502, \"Duration (ms)\": 179813.0, \"Valence\": 0.589, \"Chord\": \"G\"}, {\"Index\": 894, \"Highest Charting Position\": 23, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Chicago Freestyle (feat. Giveon)\", \"Streams\": 4799038, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"4wVOKKEHUJxHCFFNUWDn0B\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 80.0, \"Danceability\": 0.735, \"Energy\": 0.449, \"Loudness\": -7.507, \"Speechiness\": 0.347, \"Acousticness\": 0.629, \"Liveness\": 0.113, \"Tempo\": 122.947, \"Duration (ms)\": 220488.0, \"Valence\": 0.0397, \"Chord\": \"A#/Bb\"}, {\"Index\": 895, \"Highest Charting Position\": 4, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"GOOBA\", \"Streams\": 4690955, \"Artist\": \"6ix9ine\", \"Artist Followers\": 6514102.0, \"Song ID\": \"4NhDYoQTYCdWHTvlbGVgwo\", \"Genre\": \"['emo rap', 'rap']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 70.0, \"Danceability\": 0.611, \"Energy\": 0.688, \"Loudness\": -5.688, \"Speechiness\": 0.341, \"Acousticness\": 0.0264, \"Liveness\": 0.251, \"Tempo\": 178.462, \"Duration (ms)\": 132303.0, \"Valence\": 0.393, \"Chord\": \"C#/Db\"}, {\"Index\": 896, \"Highest Charting Position\": 12, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Physical\", \"Streams\": 4599807, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3AzjcOeAmA57TIOr9zF1ZW\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 77.0, \"Danceability\": 0.647, \"Energy\": 0.844, \"Loudness\": -3.756, \"Speechiness\": 0.0457, \"Acousticness\": 0.0137, \"Liveness\": 0.102, \"Tempo\": 146.967, \"Duration (ms)\": 193829.0, \"Valence\": 0.746, \"Chord\": \"C\"}, {\"Index\": 897, \"Highest Charting Position\": 194, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Hot Stuff\", \"Streams\": 4569978, \"Artist\": \"Kygo, Donna Summer\", \"Artist Followers\": 7593792.0, \"Song ID\": \"00ETaeHUQ6lops3oWU1Wrt\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 71.0, \"Danceability\": 0.681, \"Energy\": 0.773, \"Loudness\": -5.749, \"Speechiness\": 0.148, \"Acousticness\": 0.019, \"Liveness\": 0.11, \"Tempo\": 119.961, \"Duration (ms)\": 199008.0, \"Valence\": 0.429, \"Chord\": \"F\"}, {\"Index\": 898, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Who's Laughing Now\", \"Streams\": 4526982, \"Artist\": \"Ava Max\", \"Artist Followers\": 3916979.0, \"Song ID\": \"1Pmp486RrLRkaEkE3HFHXP\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 73.0, \"Danceability\": 0.648, \"Energy\": 0.641, \"Loudness\": -5.521, \"Speechiness\": 0.0389, \"Acousticness\": 0.00565, \"Liveness\": 0.109, \"Tempo\": 184.021, \"Duration (ms)\": 180348.0, \"Valence\": 0.505, \"Chord\": \"G\"}, {\"Index\": 899, \"Highest Charting Position\": 91, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Sweet but Psycho\", \"Streams\": 4502853, \"Artist\": \"Ava Max\", \"Artist Followers\": 3916979.0, \"Song ID\": \"7DnAm9FOTWE3cUvso43HhI\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.72, \"Energy\": 0.706, \"Loudness\": -4.719, \"Speechiness\": 0.0473, \"Acousticness\": 0.0684, \"Liveness\": 0.166, \"Tempo\": 133.002, \"Duration (ms)\": 187436.0, \"Valence\": 0.62, \"Chord\": \"C#/Db\"}, {\"Index\": 900, \"Highest Charting Position\": 83, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Del Mar\", \"Streams\": 5698099, \"Artist\": \"Ozuna, Doja Cat, Sia\", \"Artist Followers\": 29238936.0, \"Song ID\": \"5cpJFiNwYyWwFLH0V6B3N8\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 79.0, \"Danceability\": 0.759, \"Energy\": 0.636, \"Loudness\": -5.585, \"Speechiness\": 0.0369, \"Acousticness\": 0.0224, \"Liveness\": 0.166, \"Tempo\": 109.976, \"Duration (ms)\": 214507.0, \"Valence\": 0.536, \"Chord\": \"F#/Gb\"}, {\"Index\": 901, \"Highest Charting Position\": 72, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Hit Different\", \"Streams\": 5049863, \"Artist\": \"SZA, The Neptunes, Pharrell Williams, Ty Dolla $ign\", \"Artist Followers\": 5888533.0, \"Song ID\": \"7Bar1kLTmsRmH6FCKKMEyU\", \"Genre\": \"['pop', 'pop rap', 'r&b']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 74.0, \"Danceability\": 0.679, \"Energy\": 0.516, \"Loudness\": -6.371, \"Speechiness\": 0.0452, \"Acousticness\": 0.199, \"Liveness\": 0.0965, \"Tempo\": 120.074, \"Duration (ms)\": 202008.0, \"Valence\": 0.716, \"Chord\": \"C\"}, {\"Index\": 902, \"Highest Charting Position\": 65, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Nobody's Love\", \"Streams\": 4957966, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32279979.0, \"Song ID\": \"2ST72jD2KVe7f3fbcGyX1b\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 73.0, \"Danceability\": 0.485, \"Energy\": 0.567, \"Loudness\": -6.456, \"Speechiness\": 0.0388, \"Acousticness\": 0.316, \"Liveness\": 0.0949, \"Tempo\": 93.676, \"Duration (ms)\": 211254.0, \"Valence\": 0.157, \"Chord\": \"C#/Db\"}, {\"Index\": 903, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"M\\u00e1quina do Tempo\", \"Streams\": 4938139, \"Artist\": \"Matu\\u00ea\", \"Artist Followers\": 3263283.0, \"Song ID\": \"5oI9blwsXC8AkTWw6wASY8\", \"Genre\": \"['r&b brasileiro', 'rap cearense', 'trap brasileiro']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-09-11--2020-09-18\", \"Popularity\": 70.0, \"Danceability\": 0.629, \"Energy\": 0.727, \"Loudness\": -4.387, \"Speechiness\": 0.0499, \"Acousticness\": 0.0647, \"Liveness\": 0.138, \"Tempo\": 149.978, \"Duration (ms)\": 230400.0, \"Valence\": 0.132, \"Chord\": \"E\"}, {\"Index\": 904, \"Highest Charting Position\": 112, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Fuckst mich nur ab\", \"Streams\": 4898520, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"0y8mJFmm4ogCHnfe0oTuT6\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 63.0, \"Danceability\": 0.817, \"Energy\": 0.468, \"Loudness\": -10.945, \"Speechiness\": 0.287, \"Acousticness\": 0.233, \"Liveness\": 0.0905, \"Tempo\": 104.875, \"Duration (ms)\": 182931.0, \"Valence\": 0.237, \"Chord\": \"C#/Db\"}, {\"Index\": 905, \"Highest Charting Position\": 122, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Jangueo\", \"Streams\": 4877753, \"Artist\": \"Alex Rose, Rafa Pab\\u00f6n\", \"Artist Followers\": 2168452.0, \"Song ID\": \"1bRpSCFv6P2OUhciByeRYR\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 74.0, \"Danceability\": 0.861, \"Energy\": 0.678, \"Loudness\": -4.157, \"Speechiness\": 0.0536, \"Acousticness\": 0.253, \"Liveness\": 0.106, \"Tempo\": 103.994, \"Duration (ms)\": 259600.0, \"Valence\": 0.723, \"Chord\": \"G#/Ab\"}, {\"Index\": 906, \"Highest Charting Position\": 68, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"We Paid (feat. 42 Dugg)\", \"Streams\": 4776686, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"6gxKUmycQX7uyMwJcweFjp\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 76.0, \"Danceability\": 0.926, \"Energy\": 0.542, \"Loudness\": -5.064, \"Speechiness\": 0.293, \"Acousticness\": 0.135, \"Liveness\": 0.0877, \"Tempo\": 135.14, \"Duration (ms)\": 181929.0, \"Valence\": 0.564, \"Chord\": \"C#/Db\"}, {\"Index\": 907, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Ihr Hobby\", \"Streams\": 4723116, \"Artist\": \"Bonez MC, Maxwell\", \"Artist Followers\": 1683006.0, \"Song ID\": \"4aZfvvgfoSfmSZpfwQYzC0\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-09-11--2020-09-18\", \"Popularity\": 59.0, \"Danceability\": 0.774, \"Energy\": 0.814, \"Loudness\": -6.145, \"Speechiness\": 0.0584, \"Acousticness\": 0.204, \"Liveness\": 0.118, \"Tempo\": 109.019, \"Duration (ms)\": 185330.0, \"Valence\": 0.254, \"Chord\": \"A#/Bb\"}, {\"Index\": 908, \"Highest Charting Position\": 150, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"When I Look At You\", \"Streams\": 4652583, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"7ywzEdEuVG1lsjsRCGJfLy\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2009-01-01\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 63.0, \"Danceability\": 0.459, \"Energy\": 0.545, \"Loudness\": -4.874, \"Speechiness\": 0.0282, \"Acousticness\": 0.142, \"Liveness\": 0.105, \"Tempo\": 137.941, \"Duration (ms)\": 248587.0, \"Valence\": 0.194, \"Chord\": \"F#/Gb\"}, {\"Index\": 909, \"Highest Charting Position\": 21, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Boss Bitch\", \"Streams\": 4620838, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"78qd8dvwea0Gosb6Fe6j3k\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-01-23\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 81.0, \"Danceability\": 0.707, \"Energy\": 0.955, \"Loudness\": -4.593, \"Speechiness\": 0.222, \"Acousticness\": 0.127, \"Liveness\": 0.202, \"Tempo\": 125.989, \"Duration (ms)\": 134240.0, \"Valence\": 0.575, \"Chord\": \"A#/Bb\"}, {\"Index\": 910, \"Highest Charting Position\": 142, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Ain't It Different (feat. AJ Tracey & Stormzy)\", \"Streams\": 4602336, \"Artist\": \"Headie One\", \"Artist Followers\": 328877.0, \"Song ID\": \"6NJfIydBMYrXvlaXsFxmc8\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2020-08-20\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 69.0, \"Danceability\": 0.767, \"Energy\": 0.569, \"Loudness\": -6.805, \"Speechiness\": 0.216, \"Acousticness\": 0.00988, \"Liveness\": 0.109, \"Tempo\": 77.052, \"Duration (ms)\": 196363.0, \"Valence\": 0.524, \"Chord\": \"E\"}, {\"Index\": 911, \"Highest Charting Position\": 75, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Some Say - Felix Jaehn Remix\", \"Streams\": 4598325, \"Artist\": \"Nea\", \"Artist Followers\": 38111.0, \"Song ID\": \"7C1trmcQQ5n5RNy4l6ziCv\", \"Genre\": \"['scandipop', 'swedish pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 77.0, \"Danceability\": 0.682, \"Energy\": 0.7, \"Loudness\": -5.591, \"Speechiness\": 0.0397, \"Acousticness\": 0.406, \"Liveness\": 0.174, \"Tempo\": 120.03, \"Duration (ms)\": 186878.0, \"Valence\": 0.637, \"Chord\": \"F#/Gb\"}, {\"Index\": 912, \"Highest Charting Position\": 13, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Savage Remix (feat. Beyonc\\u00e9)\", \"Streams\": 4568308, \"Artist\": \"Beyonc\\u00e9, Megan Thee Stallion\", \"Artist Followers\": 28335112.0, \"Song ID\": \"5v4GgrXPMghOnBBLmveLac\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'r&b']\", \"Release Date\": \"2020-04-29\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 73.0, \"Danceability\": 0.822, \"Energy\": 0.743, \"Loudness\": -4.772, \"Speechiness\": 0.28, \"Acousticness\": 0.016, \"Liveness\": 0.127, \"Tempo\": 84.459, \"Duration (ms)\": 242001.0, \"Valence\": 0.636, \"Chord\": \"A#/Bb\"}, {\"Index\": 913, \"Highest Charting Position\": 115, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Lithuania (feat. Travis Scott)\", \"Streams\": 5949270, \"Artist\": \"Big Sean\", \"Artist Followers\": 8673345.0, \"Song ID\": \"4VLTxHOyFX5FRtkpsFm5Pc\", \"Genre\": \"['detroit hip hop', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-09-04--2020-09-11\", \"Popularity\": 62.0, \"Danceability\": 0.676, \"Energy\": 0.82, \"Loudness\": -5.217, \"Speechiness\": 0.0554, \"Acousticness\": 0.0493, \"Liveness\": 0.615, \"Tempo\": 152.028, \"Duration (ms)\": 199250.0, \"Valence\": 0.618, \"Chord\": \"G\"}, {\"Index\": 914, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Tap In (feat. Post Malone, DaBaby & Jack Harlow)\", \"Streams\": 5117128, \"Artist\": \"Saweetie\", \"Artist Followers\": 1255573.0, \"Song ID\": \"5woaU1FNkqCwg6WzWiQPW5\", \"Genre\": \"['cali rap', 'dance pop', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-08-28\", \"Weeks Charted\": \"2020-09-04--2020-09-11\", \"Popularity\": 64.0, \"Danceability\": 0.948, \"Energy\": 0.63, \"Loudness\": -7.011, \"Speechiness\": 0.219, \"Acousticness\": 0.00647, \"Liveness\": 0.0737, \"Tempo\": 100.032, \"Duration (ms)\": 253569.0, \"Valence\": 0.425, \"Chord\": \"C#/Db\"}, {\"Index\": 915, \"Highest Charting Position\": 91, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Not Shy\", \"Streams\": 4982232, \"Artist\": \"ITZY\", \"Artist Followers\": 2384076.0, \"Song ID\": \"4ecVWqbtW6phQGpZMAyqIU\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2020-08-17\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 73.0, \"Danceability\": 0.776, \"Energy\": 0.911, \"Loudness\": -3.08, \"Speechiness\": 0.131, \"Acousticness\": 0.155, \"Liveness\": 0.268, \"Tempo\": 101.027, \"Duration (ms)\": 177728.0, \"Valence\": 0.56, \"Chord\": \"D\"}, {\"Index\": 916, \"Highest Charting Position\": 71, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"The Plan - From the Motion Picture \\\"TENET\\\"\", \"Streams\": 4876238, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"551xyaSJsg8hILXFq9JdST\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2020-08-22\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 67.0, \"Danceability\": 0.433, \"Energy\": 0.443, \"Loudness\": -10.568, \"Speechiness\": 0.0361, \"Acousticness\": 0.0922, \"Liveness\": 0.117, \"Tempo\": 79.903, \"Duration (ms)\": 185851.0, \"Valence\": 0.0363, \"Chord\": \"C#/Db\"}, {\"Index\": 917, \"Highest Charting Position\": 152, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"ADMV\", \"Streams\": 4737291, \"Artist\": \"Maluma\", \"Artist Followers\": 26784251.0, \"Song ID\": \"3eJMSq78dDaFb7VvhNFnq6\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-04-23\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 72.0, \"Danceability\": 0.565, \"Energy\": 0.39, \"Loudness\": -4.959, \"Speechiness\": 0.0556, \"Acousticness\": 0.817, \"Liveness\": 0.126, \"Tempo\": 163.781, \"Duration (ms)\": 193700.0, \"Valence\": 0.708, \"Chord\": \"A\"}, {\"Index\": 918, \"Highest Charting Position\": 122, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Alane\", \"Streams\": 4668193, \"Artist\": \"Robin Schulz, Wes\", \"Artist Followers\": 2786366.0, \"Song ID\": \"2u6Jm2klS4yvAlbSHlxUwI\", \"Genre\": \"['dance pop', 'deep euro house', 'deep house', 'edm', 'german dance', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 67.0, \"Danceability\": 0.581, \"Energy\": 0.799, \"Loudness\": -6.66, \"Speechiness\": 0.164, \"Acousticness\": 0.0419, \"Liveness\": 0.11, \"Tempo\": 124.002, \"Duration (ms)\": 175016.0, \"Valence\": 0.662, \"Chord\": \"D#/Eb\"}, {\"Index\": 919, \"Highest Charting Position\": 82, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"THE BADDEST\", \"Streams\": 4642057, \"Artist\": \"K/DA, (G)I-DLE, Wolftyla, Bea Miller, League of Legends\", \"Artist Followers\": 1245965.0, \"Song ID\": \"2V4Fx72svQRxrFvNT1eq5f\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2020-08-27\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 70.0, \"Danceability\": 0.676, \"Energy\": 0.857, \"Loudness\": -4.368, \"Speechiness\": 0.0438, \"Acousticness\": 0.0215, \"Liveness\": 0.254, \"Tempo\": 149.981, \"Duration (ms)\": 162600.0, \"Valence\": 0.717, \"Chord\": \"A#/Bb\"}, {\"Index\": 920, \"Highest Charting Position\": 112, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Desce Pro Play (PA PA PA)\", \"Streams\": 4615520, \"Artist\": \"Mc Zaac, Anitta, Tyga\", \"Artist Followers\": 1555628.0, \"Song ID\": \"4zGtfOglDBfVUypabBwIjQ\", \"Genre\": \"['funk carioca', 'funk pop']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 68.0, \"Danceability\": 0.935, \"Energy\": 0.71, \"Loudness\": -5.085, \"Speechiness\": 0.158, \"Acousticness\": 0.0769, \"Liveness\": 0.173, \"Tempo\": 100.009, \"Duration (ms)\": 168507.0, \"Valence\": 0.635, \"Chord\": \"B\"}, {\"Index\": 921, \"Highest Charting Position\": 103, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Mariposa\", \"Streams\": 4593366, \"Artist\": \"Peach Tree Rascals\", \"Artist Followers\": 177972.0, \"Song ID\": \"4ja2gzrNh9VNigzoXfmbwD\", \"Genre\": \"['alternative r&b', 'chill r&b', 'indie r&b', 'pop']\", \"Release Date\": \"2019-08-28\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 76.0, \"Danceability\": 0.676, \"Energy\": 0.525, \"Loudness\": -5.88, \"Speechiness\": 0.028, \"Acousticness\": 0.617, \"Liveness\": 0.356, \"Tempo\": 112.011, \"Duration (ms)\": 210000.0, \"Valence\": 0.421, \"Chord\": \"A\"}, {\"Index\": 922, \"Highest Charting Position\": 5, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"the 1\", \"Streams\": 4587573, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0Jlcvv8IykzHaSmj49uNW8\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 75.0, \"Danceability\": 0.777, \"Energy\": 0.357, \"Loudness\": -6.942, \"Speechiness\": 0.0522, \"Acousticness\": 0.757, \"Liveness\": 0.108, \"Tempo\": 139.883, \"Duration (ms)\": 210252.0, \"Valence\": 0.172, \"Chord\": \"C\"}, {\"Index\": 923, \"Highest Charting Position\": 11, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"RITMO (Bad Boys For Life)\", \"Streams\": 4585895, \"Artist\": \"Black Eyed Peas, J Balvin\", \"Artist Followers\": 5966748.0, \"Song ID\": \"6cy3ki60hLwimwIje7tALf\", \"Genre\": \"['dance pop', 'pop', 'pop rap']\", \"Release Date\": \"2019-10-12\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.721, \"Energy\": 0.716, \"Loudness\": -7.037, \"Speechiness\": 0.0657, \"Acousticness\": 0.0334, \"Liveness\": 0.237, \"Tempo\": 104.994, \"Duration (ms)\": 221714.0, \"Valence\": 0.667, \"Chord\": \"A#/Bb\"}, {\"Index\": 924, \"Highest Charting Position\": 134, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Unterwegs\", \"Streams\": 4572706, \"Artist\": \"KitschKrieg, Jamule, SFR\", \"Artist Followers\": 166517.0, \"Song ID\": \"7mrWTjhYctgEQb0lJKrVWy\", \"Genre\": \"['german hip hop', 'german pop', 'hamburg hip hop']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 68.0, \"Danceability\": 0.88, \"Energy\": 0.607, \"Loudness\": -7.067, \"Speechiness\": 0.0777, \"Acousticness\": 0.195, \"Liveness\": 0.15, \"Tempo\": 126.039, \"Duration (ms)\": 233905.0, \"Valence\": 0.823, \"Chord\": \"F#/Gb\"}, {\"Index\": 925, \"Highest Charting Position\": 86, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"What's Love Got to Do with It\", \"Streams\": 4538382, \"Artist\": \"Kygo, Tina Turner\", \"Artist Followers\": 7593792.0, \"Song ID\": \"3Be7CLdHZpyzsVijme39cW\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-07-17\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 74.0, \"Danceability\": 0.75, \"Energy\": 0.664, \"Loudness\": -5.908, \"Speechiness\": 0.154, \"Acousticness\": 0.275, \"Liveness\": 0.0632, \"Tempo\": 105.023, \"Duration (ms)\": 208156.0, \"Valence\": 0.617, \"Chord\": \"G#/Ab\"}, {\"Index\": 926, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Cry About It Later\", \"Streams\": 5306994, \"Artist\": \"Katy Perry\", \"Artist Followers\": 18936929.0, \"Song ID\": \"43WYPxyEfIxlIjNlxQGYzc\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2020-08-28--2020-09-04\", \"Popularity\": 67.0, \"Danceability\": 0.676, \"Energy\": 0.794, \"Loudness\": -4.78, \"Speechiness\": 0.0366, \"Acousticness\": 0.0513, \"Liveness\": 0.0723, \"Tempo\": 125.957, \"Duration (ms)\": 159286.0, \"Valence\": 0.161, \"Chord\": \"D\"}, {\"Index\": 927, \"Highest Charting Position\": 71, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Banana (feat. Shaggy) - DJ FLe - Minisiren Remix\", \"Streams\": 4624448, \"Artist\": \"Conkarah\", \"Artist Followers\": 67074.0, \"Song ID\": \"0dZpw3h6KZhcHec61qwevZ\", \"Genre\": \"['jawaiian']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 70.0, \"Danceability\": 0.824, \"Energy\": 0.854, \"Loudness\": -5.312, \"Speechiness\": 0.177, \"Acousticness\": 0.016, \"Liveness\": 0.117, \"Tempo\": 95.114, \"Duration (ms)\": 210329.0, \"Valence\": 0.896, \"Chord\": \"G#/Ab\"}, {\"Index\": 928, \"Highest Charting Position\": 185, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Gifted (feat. Roddy Ricch)\", \"Streams\": 4609169, \"Artist\": \"Cordae\", \"Artist Followers\": 1492551.0, \"Song ID\": \"0mb3uDw5vfFUcZfJYFOMRu\", \"Genre\": \"['dmv rap', 'hip hop', 'pop rap', 'rap', 'trap', 'underground hip hop', 'vapor trap']\", \"Release Date\": \"2020-08-27\", \"Weeks Charted\": \"2020-08-28--2020-09-04\", \"Popularity\": 65.0, \"Danceability\": 0.653, \"Energy\": 0.603, \"Loudness\": -5.697, \"Speechiness\": 0.171, \"Acousticness\": 0.175, \"Liveness\": 0.18, \"Tempo\": 151.016, \"Duration (ms)\": 168477.0, \"Valence\": 0.551, \"Chord\": \"F\"}, {\"Index\": 929, \"Highest Charting Position\": 27, \"Number of Times Charted\": 36, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"OUT WEST (feat. Young Thug)\", \"Streams\": 4597001, \"Artist\": \"JACKBOYS, Travis Scott\", \"Artist Followers\": 437907.0, \"Song ID\": \"6gi6y1xwmVszDWkUqab1qw\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.802, \"Energy\": 0.591, \"Loudness\": -4.895, \"Speechiness\": 0.225, \"Acousticness\": 0.0104, \"Liveness\": 0.196, \"Tempo\": 139.864, \"Duration (ms)\": 157712.0, \"Valence\": 0.309, \"Chord\": \"G#/Ab\"}, {\"Index\": 930, \"Highest Charting Position\": 174, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Anaranjado\", \"Streams\": 4575403, \"Artist\": \"Jowell & Randy, J Balvin\", \"Artist Followers\": 2919696.0, \"Song ID\": \"5iw28wvyHgj4ppOu5AdcEU\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-07-16\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 66.0, \"Danceability\": 0.763, \"Energy\": 0.58, \"Loudness\": -6.196, \"Speechiness\": 0.144, \"Acousticness\": 0.0466, \"Liveness\": 0.154, \"Tempo\": 175.937, \"Duration (ms)\": 212011.0, \"Valence\": 0.608, \"Chord\": \"G#/Ab\"}, {\"Index\": 931, \"Highest Charting Position\": 111, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Reggaetonera\", \"Streams\": 4564331, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"6yVkakCN460KOVol9ZazjH\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-05-29--2020-06-05\", \"Popularity\": 69.0, \"Danceability\": 0.694, \"Energy\": 0.796, \"Loudness\": -4.164, \"Speechiness\": 0.0565, \"Acousticness\": 0.48, \"Liveness\": 0.108, \"Tempo\": 93.064, \"Duration (ms)\": 212312.0, \"Valence\": 0.515, \"Chord\": \"F#/Gb\"}, {\"Index\": 932, \"Highest Charting Position\": 5, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Sour Candy (with BLACKPINK)\", \"Streams\": 4556900, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"6R6ZoHTypt5lt68MWbzZXv\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-28\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 70.0, \"Danceability\": 0.752, \"Energy\": 0.87, \"Loudness\": -3.812, \"Speechiness\": 0.0623, \"Acousticness\": 0.0604, \"Liveness\": 0.489, \"Tempo\": 120.006, \"Duration (ms)\": 157707.0, \"Valence\": 0.784, \"Chord\": \"A\"}, {\"Index\": 933, \"Highest Charting Position\": 113, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Rags2Riches 2 (feat. Lil Baby)\", \"Streams\": 4547965, \"Artist\": \"Rod Wave\", \"Artist Followers\": 2203386.0, \"Song ID\": \"40TPiJpvwGIyvPjJMDTKfy\", \"Genre\": \"['florida rap']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 60.0, \"Danceability\": 0.874, \"Energy\": 0.443, \"Loudness\": -9.628, \"Speechiness\": 0.241, \"Acousticness\": 0.147, \"Liveness\": 0.124, \"Tempo\": 118.004, \"Duration (ms)\": 235988.0, \"Valence\": 0.298, \"Chord\": \"F\"}, {\"Index\": 934, \"Highest Charting Position\": 31, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Bandit (with YoungBoy Never Broke Again)\", \"Streams\": 4514763, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"6Gg1gjgKi2AK4e0qzsR7sd\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.474, \"Energy\": 0.631, \"Loudness\": -5.884, \"Speechiness\": 0.343, \"Acousticness\": 0.0687, \"Liveness\": 0.132, \"Tempo\": 180.051, \"Duration (ms)\": 189323.0, \"Valence\": 0.425, \"Chord\": \"F\"}, {\"Index\": 935, \"Highest Charting Position\": 117, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"PAM\", \"Streams\": 4501441, \"Artist\": \"Justin Quiles, Daddy Yankee, El Alfa\", \"Artist Followers\": 2897862.0, \"Song ID\": \"0eeKDrQxjqNl5bX5VCHDcn\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 73.0, \"Danceability\": 0.889, \"Energy\": 0.863, \"Loudness\": -3.011, \"Speechiness\": 0.0757, \"Acousticness\": 0.289, \"Liveness\": 0.0798, \"Tempo\": 112.953, \"Duration (ms)\": 201000.0, \"Valence\": 0.776, \"Chord\": \"B\"}, {\"Index\": 936, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Lemonade\", \"Streams\": 11373347, \"Artist\": \"Internet Money, Gunna, Don Toliver, NAV\", \"Artist Followers\": 412466.0, \"Song ID\": \"02kDW379Yfd5PzW5A6vuGt\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 82.0, \"Danceability\": 0.799, \"Energy\": 0.66, \"Loudness\": -6.153, \"Speechiness\": 0.079, \"Acousticness\": 0.256, \"Liveness\": 0.111, \"Tempo\": 140.04, \"Duration (ms)\": 195429.0, \"Valence\": 0.471, \"Chord\": \"C#/Db\"}, {\"Index\": 937, \"Highest Charting Position\": 145, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Fr\\u00fchst\\u00fcck in Paris\", \"Streams\": 5440253, \"Artist\": \"Capital Bra, Cro\", \"Artist Followers\": 4093115.0, \"Song ID\": \"1ddbNJwDjjmCYz1GFGYnsw\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-09-17\", \"Weeks Charted\": \"2020-08-21--2020-08-28\", \"Popularity\": 56.0, \"Danceability\": 0.744, \"Energy\": 0.644, \"Loudness\": -5.562, \"Speechiness\": 0.0641, \"Acousticness\": 0.229, \"Liveness\": 0.204, \"Tempo\": 96.852, \"Duration (ms)\": 151360.0, \"Valence\": 0.577, \"Chord\": \"G#/Ab\"}, {\"Index\": 938, \"Highest Charting Position\": 22, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"ON\", \"Streams\": 5391018, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"2QyuXBcV1LJ2rq01KhreMF\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 77.0, \"Danceability\": 0.583, \"Energy\": 0.817, \"Loudness\": -5.146, \"Speechiness\": 0.0987, \"Acousticness\": 0.118, \"Liveness\": 0.338, \"Tempo\": 105.936, \"Duration (ms)\": 246381.0, \"Valence\": 0.438, \"Chord\": \"A\"}, {\"Index\": 939, \"Highest Charting Position\": 106, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"My Oasis (feat. Burna Boy)\", \"Streams\": 4887204, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"2KoHxhRyWxJzA0VafWd5Nk\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-07-30\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 69.0, \"Danceability\": 0.691, \"Energy\": 0.474, \"Loudness\": -8.742, \"Speechiness\": 0.0583, \"Acousticness\": 0.569, \"Liveness\": 0.099, \"Tempo\": 143.783, \"Duration (ms)\": 179917.0, \"Valence\": 0.381, \"Chord\": \"A#/Bb\"}, {\"Index\": 940, \"Highest Charting Position\": 8, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Life's A Mess (feat. Halsey)\", \"Streams\": 4883202, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5wWAwzGp2OaaoIkwcz6wZs\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 74.0, \"Danceability\": 0.63, \"Energy\": 0.446, \"Loudness\": -8.9, \"Speechiness\": 0.0351, \"Acousticness\": 0.337, \"Liveness\": 0.166, \"Tempo\": 143.078, \"Duration (ms)\": 202193.0, \"Valence\": 0.177, \"Chord\": \"C#/Db\"}, {\"Index\": 941, \"Highest Charting Position\": 56, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"PORFA\", \"Streams\": 4702117, \"Artist\": \"Feid, Justin Quiles\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5PwAiSk3ufe0YwOHRFPHEG\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 0.0, \"Danceability\": 0.843, \"Energy\": 0.549, \"Loudness\": -8.018, \"Speechiness\": 0.164, \"Acousticness\": 0.0948, \"Liveness\": 0.155, \"Tempo\": 83.982, \"Duration (ms)\": 233000.0, \"Valence\": 0.542, \"Chord\": \"F#/Gb\"}, {\"Index\": 942, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"2012\", \"Streams\": 4685894, \"Artist\": \"Bausa, Juju\", \"Artist Followers\": 961181.0, \"Song ID\": \"6bM4daGlfZHtKMQp8tEqVz\", \"Genre\": \"['german hip hop', 'german pop']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-08-21--2020-08-28\", \"Popularity\": 62.0, \"Danceability\": 0.805, \"Energy\": 0.619, \"Loudness\": -7.907, \"Speechiness\": 0.0771, \"Acousticness\": 0.218, \"Liveness\": 0.114, \"Tempo\": 98.995, \"Duration (ms)\": 170200.0, \"Valence\": 0.476, \"Chord\": \"F\"}, {\"Index\": 943, \"Highest Charting Position\": 11, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"august\", \"Streams\": 4586236, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3hUxzQpSfdDqwM3ZTFQY0K\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 76.0, \"Danceability\": 0.532, \"Energy\": 0.623, \"Loudness\": -9.208, \"Speechiness\": 0.0331, \"Acousticness\": 0.538, \"Liveness\": 0.0925, \"Tempo\": 89.937, \"Duration (ms)\": 261923.0, \"Valence\": 0.403, \"Chord\": \"F\"}, {\"Index\": 944, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"if i were u (with Lauv)\", \"Streams\": 4561189, \"Artist\": \"blackbear\", \"Artist Followers\": 4272745.0, \"Song ID\": \"0CF1RH8dQKuK2lQPSQw2lZ\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2020-08-19\", \"Weeks Charted\": \"2020-08-21--2020-08-28\", \"Popularity\": 64.0, \"Danceability\": 0.666, \"Energy\": 0.628, \"Loudness\": -5.613, \"Speechiness\": 0.0623, \"Acousticness\": 0.144, \"Liveness\": 0.189, \"Tempo\": 82.992, \"Duration (ms)\": 186468.0, \"Valence\": 0.767, \"Chord\": \"G#/Ab\"}, {\"Index\": 945, \"Highest Charting Position\": 37, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Ballin' (with Roddy Ricch)\", \"Streams\": 4436934, \"Artist\": \"Mustard\", \"Artist Followers\": 881797.0, \"Song ID\": \"3QzAOrNlsabgbMwlZt7TAY\", \"Genre\": \"['cali rap', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.809, \"Energy\": 0.545, \"Loudness\": -6.678, \"Speechiness\": 0.0735, \"Acousticness\": 0.392, \"Liveness\": 0.151, \"Tempo\": 97.008, \"Duration (ms)\": 180435.0, \"Valence\": 0.244, \"Chord\": \"G\"}, {\"Index\": 946, \"Highest Charting Position\": 72, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Stay Gold\", \"Streams\": 4405338, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3Ys2PYl1wyPKQIwyqhP9cQ\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-07-14\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-07-10--2020-07-17\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 73.0, \"Danceability\": 0.723, \"Energy\": 0.634, \"Loudness\": -5.415, \"Speechiness\": 0.0542, \"Acousticness\": 0.0892, \"Liveness\": 0.0787, \"Tempo\": 129.017, \"Duration (ms)\": 243267.0, \"Valence\": 0.582, \"Chord\": \"C#/Db\"}, {\"Index\": 947, \"Highest Charting Position\": 186, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"I'm Yours\", \"Streams\": 4391666, \"Artist\": \"Jason Mraz\", \"Artist Followers\": 6167871.0, \"Song ID\": \"1EzrEOXmMH3G43AXT1y7pA\", \"Genre\": \"['acoustic pop', 'neo mellow', 'pop', 'pop rock']\", \"Release Date\": \"2008-05-12\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\", \"Popularity\": 80.0, \"Danceability\": 0.686, \"Energy\": 0.457, \"Loudness\": -8.322, \"Speechiness\": 0.0468, \"Acousticness\": 0.595, \"Liveness\": 0.105, \"Tempo\": 150.953, \"Duration (ms)\": 242187.0, \"Valence\": 0.718, \"Chord\": \"B\"}, {\"Index\": 948, \"Highest Charting Position\": 136, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Youngblood\", \"Streams\": 4390823, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"2iUXsYOEPhVqEBwsqP70rE\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-06-15\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.596, \"Energy\": 0.854, \"Loudness\": -5.114, \"Speechiness\": 0.463, \"Acousticness\": 0.0169, \"Liveness\": 0.124, \"Tempo\": 120.274, \"Duration (ms)\": 203418.0, \"Valence\": 0.152, \"Chord\": \"G\"}, {\"Index\": 949, \"Highest Charting Position\": 8, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"the last great american dynasty\", \"Streams\": 4389670, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2Eeur20xVqfUoM3Q7EFPFt\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.686, \"Energy\": 0.662, \"Loudness\": -8.505, \"Speechiness\": 0.0413, \"Acousticness\": 0.467, \"Liveness\": 0.109, \"Tempo\": 147.922, \"Duration (ms)\": 230999.0, \"Valence\": 0.706, \"Chord\": \"G\"}, {\"Index\": 950, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Levitating (feat. Madonna and Missy Elliott) [The Blessed Madonna Remix]\", \"Streams\": 5254969, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"0pk1hxhJLBSZZ5RKBhcwOa\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-08-13\", \"Weeks Charted\": \"2020-08-14--2020-08-21\", \"Popularity\": 62.0, \"Danceability\": 0.808, \"Energy\": 0.655, \"Loudness\": -7.34, \"Speechiness\": 0.139, \"Acousticness\": 0.0373, \"Liveness\": 0.208, \"Tempo\": 116.029, \"Duration (ms)\": 250280.0, \"Valence\": 0.56, \"Chord\": \"B\"}, {\"Index\": 951, \"Highest Charting Position\": 10, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"my tears ricochet\", \"Streams\": 5111416, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1MgV7FIyNxIG7WzMRJV5HC\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.456, \"Energy\": 0.263, \"Loudness\": -10.63, \"Speechiness\": 0.0332, \"Acousticness\": 0.806, \"Liveness\": 0.0749, \"Tempo\": 129.86, \"Duration (ms)\": 255894.0, \"Valence\": 0.111, \"Chord\": \"C\"}, {\"Index\": 952, \"Highest Charting Position\": 59, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Rags2Riches (feat. ATR Son Son)\", \"Streams\": 4737306, \"Artist\": \"Rod Wave\", \"Artist Followers\": 2203386.0, \"Song ID\": \"0qg0GJp7HSewRCVPP4fKGk\", \"Genre\": \"['florida rap']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 55.0, \"Danceability\": 0.904, \"Energy\": 0.26, \"Loudness\": -17.57, \"Speechiness\": 0.101, \"Acousticness\": 0.277, \"Liveness\": 0.121, \"Tempo\": 117.967, \"Duration (ms)\": 167147.0, \"Valence\": 0.231, \"Chord\": \"F\"}, {\"Index\": 953, \"Highest Charting Position\": 79, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Flex (feat. Juice WRLD)\", \"Streams\": 4664281, \"Artist\": \"Polo G\", \"Artist Followers\": 4849204.0, \"Song ID\": \"2QqJTIlGKRLJC3onkavYEz\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 76.0, \"Danceability\": 0.752, \"Energy\": 0.673, \"Loudness\": -5.792, \"Speechiness\": 0.153, \"Acousticness\": 0.0538, \"Liveness\": 0.133, \"Tempo\": 164.009, \"Duration (ms)\": 163902.0, \"Valence\": 0.35, \"Chord\": \"A#/Bb\"}, {\"Index\": 954, \"Highest Charting Position\": 77, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Rover (feat. DTG)\", \"Streams\": 4488631, \"Artist\": \"S1mba\", \"Artist Followers\": 46992.0, \"Song ID\": \"4slSrbTK1sNK4I1mDYEthf\", \"Genre\": \"['afroswing', 'social media pop']\", \"Release Date\": \"2020-03-04\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 73.0, \"Danceability\": 0.613, \"Energy\": 0.624, \"Loudness\": -6.66, \"Speechiness\": 0.206, \"Acousticness\": 0.496, \"Liveness\": 0.283, \"Tempo\": 62.948, \"Duration (ms)\": 167917.0, \"Valence\": 0.804, \"Chord\": \"B\"}, {\"Index\": 955, \"Highest Charting Position\": 74, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Only You Freestyle\", \"Streams\": 4480780, \"Artist\": \"Headie One, Drake\", \"Artist Followers\": 328877.0, \"Song ID\": \"4OENnoidV0h8gJV6bhrw7r\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2020-07-20\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 68.0, \"Danceability\": 0.68, \"Energy\": 0.826, \"Loudness\": -2.561, \"Speechiness\": 0.27, \"Acousticness\": 0.562, \"Liveness\": 0.254, \"Tempo\": 146.95, \"Duration (ms)\": 248937.0, \"Valence\": 0.804, \"Chord\": \"F\"}, {\"Index\": 956, \"Highest Charting Position\": 55, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Hallucinate\", \"Streams\": 4472669, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"1nYeVF5vIBxMxfPoL0SIWg\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 72.0, \"Danceability\": 0.627, \"Energy\": 0.69, \"Loudness\": -5.396, \"Speechiness\": 0.139, \"Acousticness\": 0.033, \"Liveness\": 0.0742, \"Tempo\": 122.053, \"Duration (ms)\": 208505.0, \"Valence\": 0.627, \"Chord\": \"A#/Bb\"}, {\"Index\": 957, \"Highest Charting Position\": 100, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"El Efecto\", \"Streams\": 4466143, \"Artist\": \"Rauw Alejandro, Chencho Corleone\", \"Artist Followers\": 6096559.0, \"Song ID\": \"4SJHHpKhcuXwDsCsPqshXj\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2019-03-15\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 76.0, \"Danceability\": 0.849, \"Energy\": 0.781, \"Loudness\": -4.635, \"Speechiness\": 0.159, \"Acousticness\": 0.406, \"Liveness\": 0.0801, \"Tempo\": 84.041, \"Duration (ms)\": 217143.0, \"Valence\": 0.893, \"Chord\": \"C\"}, {\"Index\": 958, \"Highest Charting Position\": 176, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Co\\u00f1o\", \"Streams\": 4462411, \"Artist\": \"Jason Derulo, Puri, Jhorrmountain\", \"Artist Followers\": 9778632.0, \"Song ID\": \"5DV4ZSCqbFv74ui3ZhimXo\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 69.0, \"Danceability\": 0.899, \"Energy\": 0.528, \"Loudness\": -5.442, \"Speechiness\": 0.181, \"Acousticness\": 0.000554, \"Liveness\": 0.105, \"Tempo\": 100.037, \"Duration (ms)\": 111852.0, \"Valence\": 0.456, \"Chord\": \"A\"}, {\"Index\": 959, \"Highest Charting Position\": 126, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Jolie nana\", \"Streams\": 4449437, \"Artist\": \"Aya Nakamura\", \"Artist Followers\": 2953525.0, \"Song ID\": \"65RWVU6N81CeH65nu52K1U\", \"Genre\": \"['basshall', 'francoton']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 69.0, \"Danceability\": 0.813, \"Energy\": 0.64, \"Loudness\": -5.908, \"Speechiness\": 0.272, \"Acousticness\": 0.269, \"Liveness\": 0.131, \"Tempo\": 92.989, \"Duration (ms)\": 147076.0, \"Valence\": 0.488, \"Chord\": \"D\"}, {\"Index\": 960, \"Highest Charting Position\": 189, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Lovefool\", \"Streams\": 4439790, \"Artist\": \"twocolors\", \"Artist Followers\": 36369.0, \"Song ID\": \"51Of5p3lKZeOg6itfs4og4\", \"Genre\": \"['edm', 'pop dance', 'pop edm', 'tropical house']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 79.0, \"Danceability\": 0.677, \"Energy\": 0.766, \"Loudness\": -6.896, \"Speechiness\": 0.0568, \"Acousticness\": 0.0219, \"Liveness\": 0.129, \"Tempo\": 123.062, \"Duration (ms)\": 190488.0, \"Valence\": 0.198, \"Chord\": \"F#/Gb\"}, {\"Index\": 961, \"Highest Charting Position\": 17, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"invisible string\", \"Streams\": 4424118, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6VsvKPJ4xjVNKpI8VVZ3SV\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.653, \"Energy\": 0.452, \"Loudness\": -11.143, \"Speechiness\": 0.055, \"Acousticness\": 0.838, \"Liveness\": 0.108, \"Tempo\": 83.433, \"Duration (ms)\": 252881.0, \"Valence\": 0.45, \"Chord\": \"E\"}, {\"Index\": 962, \"Highest Charting Position\": 118, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Higher Love\", \"Streams\": 4392936, \"Artist\": \"Kygo, Whitney Houston\", \"Artist Followers\": 7593792.0, \"Song ID\": \"6oJ6le65B3SEqPwMRNXWjY\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.693, \"Energy\": 0.678, \"Loudness\": -7.159, \"Speechiness\": 0.0324, \"Acousticness\": 0.0151, \"Liveness\": 0.101, \"Tempo\": 103.952, \"Duration (ms)\": 228267.0, \"Valence\": 0.404, \"Chord\": \"G#/Ab\"}, {\"Index\": 963, \"Highest Charting Position\": 185, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Como Llora\", \"Streams\": 4380308, \"Artist\": \"Juanfran\", \"Artist Followers\": 117894.0, \"Song ID\": \"52zq2a71SGs3f1vJuv59ui\", \"Genre\": \"['dominican pop', 'pop reggaeton', 'urbano espanol']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 67.0, \"Danceability\": 0.827, \"Energy\": 0.629, \"Loudness\": -3.966, \"Speechiness\": 0.185, \"Acousticness\": 0.183, \"Liveness\": 0.084, \"Tempo\": 88.064, \"Duration (ms)\": 187500.0, \"Valence\": 0.486, \"Chord\": \"F#/Gb\"}, {\"Index\": 964, \"Highest Charting Position\": 50, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Walk Em Down (feat. Roddy Ricch)\", \"Streams\": 4371370, \"Artist\": \"NLE Choppa\", \"Artist Followers\": 6608815.0, \"Song ID\": \"4cSSL3YafYjM3yjgFO1vJg\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 74.0, \"Danceability\": 0.867, \"Energy\": 0.744, \"Loudness\": -5.171, \"Speechiness\": 0.227, \"Acousticness\": 0.268, \"Liveness\": 0.0713, \"Tempo\": 84.005, \"Duration (ms)\": 173288.0, \"Valence\": 0.645, \"Chord\": \"D\"}, {\"Index\": 965, \"Highest Charting Position\": 74, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Wow.\", \"Streams\": 4351784, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"7xQAfvXzm3AkraOtGPWIZg\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.829, \"Energy\": 0.539, \"Loudness\": -7.359, \"Speechiness\": 0.208, \"Acousticness\": 0.136, \"Liveness\": 0.103, \"Tempo\": 99.96, \"Duration (ms)\": 149547.0, \"Valence\": 0.388, \"Chord\": \"B\"}, {\"Index\": 966, \"Highest Charting Position\": 13, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"mirrorball\", \"Streams\": 5564072, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0ZNU020wNYvgW84iljPkPP\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.553, \"Energy\": 0.413, \"Loudness\": -10.037, \"Speechiness\": 0.0334, \"Acousticness\": 0.687, \"Liveness\": 0.0594, \"Tempo\": 110.107, \"Duration (ms)\": 208978.0, \"Valence\": 0.379, \"Chord\": \"D\"}, {\"Index\": 967, \"Highest Charting Position\": 15, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"seven\", \"Streams\": 5459423, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6KJqZcs9XDgVck7Lg9QOTC\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 69.0, \"Danceability\": 0.596, \"Energy\": 0.488, \"Loudness\": -10.769, \"Speechiness\": 0.0274, \"Acousticness\": 0.9, \"Liveness\": 0.091, \"Tempo\": 94.926, \"Duration (ms)\": 208907.0, \"Valence\": 0.415, \"Chord\": \"E\"}, {\"Index\": 968, \"Highest Charting Position\": 18, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"this is me trying\", \"Streams\": 5128412, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7kt9e9LFSpN1zQtYEl19o1\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.515, \"Energy\": 0.476, \"Loudness\": -9.843, \"Speechiness\": 0.0328, \"Acousticness\": 0.314, \"Liveness\": 0.171, \"Tempo\": 135.886, \"Duration (ms)\": 195097.0, \"Valence\": 0.412, \"Chord\": \"A\"}, {\"Index\": 969, \"Highest Charting Position\": 24, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"betty\", \"Streams\": 5112180, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5kI4eCXXzyuIUXjQra0Cxi\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.593, \"Energy\": 0.377, \"Loudness\": -8.761, \"Speechiness\": 0.0253, \"Acousticness\": 0.6, \"Liveness\": 0.0976, \"Tempo\": 95.939, \"Duration (ms)\": 294521.0, \"Valence\": 0.502, \"Chord\": \"C\"}, {\"Index\": 970, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"BLIND (feat. Young Thug)\", \"Streams\": 5074613, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"2T5NBwKRySiCR78vVk08vr\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-08-04\", \"Weeks Charted\": \"2020-08-07--2020-08-14\", \"Popularity\": 69.0, \"Danceability\": 0.709, \"Energy\": 0.679, \"Loudness\": -6.503, \"Speechiness\": 0.346, \"Acousticness\": 0.0115, \"Liveness\": 0.0971, \"Tempo\": 162.973, \"Duration (ms)\": 153467.0, \"Valence\": 0.754, \"Chord\": \"B\"}, {\"Index\": 971, \"Highest Charting Position\": 20, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"illicit affairs\", \"Streams\": 5053658, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2NmsngXHeC1GQ9wWrzhOMf\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.559, \"Energy\": 0.31, \"Loudness\": -10.445, \"Speechiness\": 0.0338, \"Acousticness\": 0.881, \"Liveness\": 0.106, \"Tempo\": 119.845, \"Duration (ms)\": 190898.0, \"Valence\": 0.46, \"Chord\": \"A#/Bb\"}, {\"Index\": 972, \"Highest Charting Position\": 170, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Freak\", \"Streams\": 4736059, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"3aA6xB0tOilDDX17fIJ0Bl\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2020-08-07--2020-08-14\", \"Popularity\": 75.0, \"Danceability\": 0.688, \"Energy\": 0.716, \"Loudness\": -5.702, \"Speechiness\": 0.0385, \"Acousticness\": 0.0969, \"Liveness\": 0.0989, \"Tempo\": 116.912, \"Duration (ms)\": 284480.0, \"Valence\": 0.373, \"Chord\": \"G\"}, {\"Index\": 973, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"PUNANI\", \"Streams\": 4625985, \"Artist\": \"6ix9ine\", \"Artist Followers\": 6514102.0, \"Song ID\": \"41xKiK40e7MFu1bqcGSz1d\", \"Genre\": \"['emo rap', 'rap']\", \"Release Date\": \"2020-08-02\", \"Weeks Charted\": \"2020-08-07--2020-08-14\", \"Popularity\": 58.0, \"Danceability\": 0.841, \"Energy\": 0.541, \"Loudness\": -7.121, \"Speechiness\": 0.229, \"Acousticness\": 0.0186, \"Liveness\": 0.123, \"Tempo\": 97.961, \"Duration (ms)\": 115255.0, \"Valence\": 0.42, \"Chord\": \"A\"}, {\"Index\": 974, \"Highest Charting Position\": 50, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Bl\\u00e4ulich\", \"Streams\": 4599408, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"2WRTnY0slmFgWcrmEr8dPj\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 60.0, \"Danceability\": 0.79, \"Energy\": 0.704, \"Loudness\": -7.935, \"Speechiness\": 0.417, \"Acousticness\": 0.069, \"Liveness\": 0.113, \"Tempo\": 154.007, \"Duration (ms)\": 196213.0, \"Valence\": 0.212, \"Chord\": \"A#/Bb\"}, {\"Index\": 975, \"Highest Charting Position\": 170, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Never Let Me Down\", \"Streams\": 4522005, \"Artist\": \"VIZE, Tom Gregory\", \"Artist Followers\": 141016.0, \"Song ID\": \"3bXiWZWR3CoZbhcsqfsMNa\", \"Genre\": \"['dance pop', 'german dance', 'pop dance', 'slap house', 'tropical house']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 61.0, \"Danceability\": 0.758, \"Energy\": 0.848, \"Loudness\": -3.84, \"Speechiness\": 0.0457, \"Acousticness\": 0.21, \"Liveness\": 0.114, \"Tempo\": 127.96, \"Duration (ms)\": 153149.0, \"Valence\": 0.706, \"Chord\": \"A#/Bb\"}, {\"Index\": 976, \"Highest Charting Position\": 16, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Savage\", \"Streams\": 4510218, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"55CHeLEfn5iJ0IIkgaa4si\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 75.0, \"Danceability\": 0.843, \"Energy\": 0.741, \"Loudness\": -5.609, \"Speechiness\": 0.334, \"Acousticness\": 0.0252, \"Liveness\": 0.096, \"Tempo\": 168.983, \"Duration (ms)\": 155497.0, \"Valence\": 0.68, \"Chord\": \"B\"}, {\"Index\": 977, \"Highest Charting Position\": 29, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"mad woman\", \"Streams\": 6796343, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2QDyYdZyhlP2fp79KZX8Bi\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 67.0, \"Danceability\": 0.592, \"Energy\": 0.699, \"Loudness\": -8.995, \"Speechiness\": 0.0471, \"Acousticness\": 0.655, \"Liveness\": 0.114, \"Tempo\": 141.916, \"Duration (ms)\": 237258.0, \"Valence\": 0.506, \"Chord\": \"D#/Eb\"}, {\"Index\": 978, \"Highest Charting Position\": 33, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"epiphany\", \"Streams\": 6085522, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"08fa9LFcFBTcilB3iq2e2A\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 66.0, \"Danceability\": 0.354, \"Energy\": 0.267, \"Loudness\": -13.69, \"Speechiness\": 0.0281, \"Acousticness\": 0.731, \"Liveness\": 0.0858, \"Tempo\": 94.219, \"Duration (ms)\": 289749.0, \"Valence\": 0.113, \"Chord\": \"C#/Db\"}, {\"Index\": 979, \"Highest Charting Position\": 41, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"peace\", \"Streams\": 5943851, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7MbT4I8qGntX4fMdqMQgke\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 67.0, \"Danceability\": 0.647, \"Energy\": 0.272, \"Loudness\": -12.906, \"Speechiness\": 0.0916, \"Acousticness\": 0.918, \"Liveness\": 0.0918, \"Tempo\": 150.044, \"Duration (ms)\": 234000.0, \"Valence\": 0.339, \"Chord\": \"F\"}, {\"Index\": 980, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Move Ya Hips (feat. Nicki Minaj & MadeinTYO)\", \"Streams\": 5768616, \"Artist\": \"A$AP Ferg\", \"Artist Followers\": 3037935.0, \"Song ID\": \"13v5IXnvO2BccWwOx5rb4s\", \"Genre\": \"['hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap', 'underground hip hop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 61.0, \"Danceability\": 0.808, \"Energy\": 0.676, \"Loudness\": -4.902, \"Speechiness\": 0.223, \"Acousticness\": 0.0618, \"Liveness\": 0.11, \"Tempo\": 144.018, \"Duration (ms)\": 144973.0, \"Valence\": 0.0763, \"Chord\": \"E\"}, {\"Index\": 981, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Sie ruft\", \"Streams\": 5752169, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"4CyCHkhRsDXUeP5K4Y3xjU\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 59.0, \"Danceability\": 0.819, \"Energy\": 0.507, \"Loudness\": -7.336, \"Speechiness\": 0.0881, \"Acousticness\": 0.482, \"Liveness\": 0.105, \"Tempo\": 130.009, \"Duration (ms)\": 152013.0, \"Valence\": 0.634, \"Chord\": \"C#/Db\"}, {\"Index\": 982, \"Highest Charting Position\": 144, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Tilidin Weg\", \"Streams\": 5674945, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"7idxewQZ24F0gQy2EWE6Ug\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 60.0, \"Danceability\": 0.882, \"Energy\": 0.526, \"Loudness\": -8.553, \"Speechiness\": 0.237, \"Acousticness\": 0.118, \"Liveness\": 0.0835, \"Tempo\": 109.075, \"Duration (ms)\": 180950.0, \"Valence\": 0.182, \"Chord\": \"A#/Bb\"}, {\"Index\": 983, \"Highest Charting Position\": 149, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Over Your Head\", \"Streams\": 5534361, \"Artist\": \"Future, Lil Uzi Vert\", \"Artist Followers\": 10491105.0, \"Song ID\": \"0Tcw8w9pvPrZoORgxsNASW\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 59.0, \"Danceability\": 0.773, \"Energy\": 0.742, \"Loudness\": -5.453, \"Speechiness\": 0.162, \"Acousticness\": 0.00198, \"Liveness\": 0.558, \"Tempo\": 148.949, \"Duration (ms)\": 186843.0, \"Valence\": 0.35, \"Chord\": \"F\"}, {\"Index\": 984, \"Highest Charting Position\": 47, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"hoax\", \"Streams\": 5375944, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6MWoRt97mnSTXZhu3ggi9C\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 66.0, \"Danceability\": 0.662, \"Energy\": 0.181, \"Loudness\": -15.065, \"Speechiness\": 0.0415, \"Acousticness\": 0.966, \"Liveness\": 0.133, \"Tempo\": 118.819, \"Duration (ms)\": 220043.0, \"Valence\": 0.429, \"Chord\": \"G#/Ab\"}, {\"Index\": 985, \"Highest Charting Position\": 25, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Blood On My Jeans\", \"Streams\": 4978899, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"0fCwrjKfWxF3xQhZrYUw4T\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 73.0, \"Danceability\": 0.868, \"Energy\": 0.55, \"Loudness\": -6.417, \"Speechiness\": 0.226, \"Acousticness\": 0.183, \"Liveness\": 0.109, \"Tempo\": 117.943, \"Duration (ms)\": 154767.0, \"Valence\": 0.464, \"Chord\": \"F#/Gb\"}, {\"Index\": 986, \"Highest Charting Position\": 171, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Narrow Road (feat. Lil Baby)\", \"Streams\": 4828004, \"Artist\": \"NLE Choppa\", \"Artist Followers\": 3372385.0, \"Song ID\": \"3GZd1aDsgKL71Kt3VIp0hc\", \"Genre\": \"['memphis hip hop']\", \"Release Date\": \"2020-07-30\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 64.0, \"Danceability\": 0.614, \"Energy\": 0.553, \"Loudness\": -8.225, \"Speechiness\": 0.169, \"Acousticness\": 0.0306, \"Liveness\": 0.203, \"Tempo\": 159.999, \"Duration (ms)\": 240297.0, \"Valence\": 0.161, \"Chord\": \"G\"}, {\"Index\": 987, \"Highest Charting Position\": 26, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Amarillo\", \"Streams\": 4695091, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"6zEgnpM0qYmHLDnh8WPejL\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 73.0, \"Danceability\": 0.641, \"Energy\": 0.857, \"Loudness\": -5.725, \"Speechiness\": 0.301, \"Acousticness\": 0.013, \"Liveness\": 0.0695, \"Tempo\": 122.728, \"Duration (ms)\": 157733.0, \"Valence\": 0.961, \"Chord\": \"C#/Db\"}, {\"Index\": 988, \"Highest Charting Position\": 179, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Singapur\", \"Streams\": 4661170, \"Artist\": \"El Alfa, Chael Produciendo\", \"Artist Followers\": 1779640.0, \"Song ID\": \"4QfZYDhGZc0T2RDvGiI69E\", \"Genre\": \"['dembow', 'latin', 'rap dominicano', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 69.0, \"Danceability\": 0.853, \"Energy\": 0.909, \"Loudness\": -2.473, \"Speechiness\": 0.229, \"Acousticness\": 0.0522, \"Liveness\": 0.129, \"Tempo\": 112.987, \"Duration (ms)\": 178407.0, \"Valence\": 0.803, \"Chord\": \"G\"}, {\"Index\": 989, \"Highest Charting Position\": 42, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Tattoo\", \"Streams\": 4588064, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6096559.0, \"Song ID\": \"4ZRrLHqzhGRXYj2qcB4s5S\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-07-09\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 78.0, \"Danceability\": 0.848, \"Energy\": 0.637, \"Loudness\": -5.132, \"Speechiness\": 0.156, \"Acousticness\": 0.0413, \"Liveness\": 0.0521, \"Tempo\": 96.988, \"Duration (ms)\": 222680.0, \"Valence\": 0.698, \"Chord\": \"A\"}, {\"Index\": 990, \"Highest Charting Position\": 86, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Ego Death (feat. Kanye West, FKA twigs & Skrillex)\", \"Streams\": 4583475, \"Artist\": \"Ty Dolla $ign\", \"Artist Followers\": 3866304.0, \"Song ID\": \"3Q5cLvkKsHJvYltf8k7HkO\", \"Genre\": \"['hip hop', 'pop', 'pop rap', 'r&b', 'southern hip hop', 'trap', 'trap soul']\", \"Release Date\": \"2020-10-22\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 71.0, \"Danceability\": 0.818, \"Energy\": 0.598, \"Loudness\": -5.948, \"Speechiness\": 0.113, \"Acousticness\": 0.0573, \"Liveness\": 0.634, \"Tempo\": 111.052, \"Duration (ms)\": 231618.0, \"Valence\": 0.331, \"Chord\": \"A#/Bb\"}, {\"Index\": 991, \"Highest Charting Position\": 33, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Morado\", \"Streams\": 4561936, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"3mQ6SLdxxaL52Yte7KF2Ks\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-01-09\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 71.0, \"Danceability\": 0.881, \"Energy\": 0.696, \"Loudness\": -3.838, \"Speechiness\": 0.0797, \"Acousticness\": 0.137, \"Liveness\": 0.0927, \"Tempo\": 97.002, \"Duration (ms)\": 200667.0, \"Valence\": 0.781, \"Chord\": \"B\"}, {\"Index\": 992, \"Highest Charting Position\": 101, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"ocean eyes\", \"Streams\": 4476954, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6pFTDHGJtKOxrQ85xRZ8Ue\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 1.0, \"Danceability\": 0.358, \"Energy\": 0.372, \"Loudness\": -7.664, \"Speechiness\": 0.0464, \"Acousticness\": 0.81, \"Liveness\": 0.0877, \"Tempo\": 144.833, \"Duration (ms)\": 200387.0, \"Valence\": 0.16, \"Chord\": \"E\"}, {\"Index\": 993, \"Highest Charting Position\": 82, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Lion King On Ice\", \"Streams\": 8293983, \"Artist\": \"J. Cole\", \"Artist Followers\": 14103694.0, \"Song ID\": \"1ZvBVbsaNqHEP6ymXaPGlj\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2020-07-22\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 64.0, \"Danceability\": 0.732, \"Energy\": 0.663, \"Loudness\": -7.616, \"Speechiness\": 0.192, \"Acousticness\": 0.0819, \"Liveness\": 0.115, \"Tempo\": 139.964, \"Duration (ms)\": 210587.0, \"Valence\": 0.227, \"Chord\": \"F#/Gb\"}, {\"Index\": 994, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Andere Welt\", \"Streams\": 5600868, \"Artist\": \"Capital Bra, Clueso, KC Rebell\", \"Artist Followers\": 4093115.0, \"Song ID\": \"5PAAUJTKLT0nCmHUlLdPXb\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-07-23\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 60.0, \"Danceability\": 0.692, \"Energy\": 0.764, \"Loudness\": -5.233, \"Speechiness\": 0.113, \"Acousticness\": 0.574, \"Liveness\": 0.106, \"Tempo\": 84.029, \"Duration (ms)\": 189686.0, \"Valence\": 0.564, \"Chord\": \"F\"}, {\"Index\": 995, \"Highest Charting Position\": 163, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"TELL ME WHY\", \"Streams\": 5056986, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"3jlxX3VXPiY3lvBBbppQD3\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.6, \"Energy\": 0.723, \"Loudness\": -4.928, \"Speechiness\": 0.158, \"Acousticness\": 0.109, \"Liveness\": 0.167, \"Tempo\": 149.881, \"Duration (ms)\": 195268.0, \"Valence\": 0.463, \"Chord\": \"F#/Gb\"}, {\"Index\": 996, \"Highest Charting Position\": 37, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Stay High\", \"Streams\": 5047752, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"21CkzgKCBCq5V4XKjiGSIj\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 75.0, \"Danceability\": 0.745, \"Energy\": 0.5, \"Loudness\": -6.184, \"Speechiness\": 0.135, \"Acousticness\": 0.439, \"Liveness\": 0.0943, \"Tempo\": 76.968, \"Duration (ms)\": 168685.0, \"Valence\": 0.433, \"Chord\": \"G#/Ab\"}, {\"Index\": 997, \"Highest Charting Position\": 161, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"What Makes You Beautiful\", \"Streams\": 4966428, \"Artist\": \"One Direction\", \"Artist Followers\": 22536304.0, \"Song ID\": \"4cluDES4hQEUhmXj6TXkSo\", \"Genre\": \"['boy band', 'pop', 'post-teen pop', 'talent show']\", \"Release Date\": \"2012-05-25\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 82.0, \"Danceability\": 0.726, \"Energy\": 0.787, \"Loudness\": -2.494, \"Speechiness\": 0.0737, \"Acousticness\": 0.009, \"Liveness\": 0.0596, \"Tempo\": 124.99, \"Duration (ms)\": 199987.0, \"Valence\": 0.888, \"Chord\": \"E\"}, {\"Index\": 998, \"Highest Charting Position\": 174, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Shit Changed\", \"Streams\": 4823401, \"Artist\": \"Ufo361, Sonus030\", \"Artist Followers\": 1700759.0, \"Song ID\": \"6du77YHyGWoFjbuHCFBHU3\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 52.0, \"Danceability\": 0.824, \"Energy\": 0.528, \"Loudness\": -9.236, \"Speechiness\": 0.175, \"Acousticness\": 0.144, \"Liveness\": 0.104, \"Tempo\": 157.005, \"Duration (ms)\": 183839.0, \"Valence\": 0.32, \"Chord\": \"A\"}, {\"Index\": 999, \"Highest Charting Position\": 35, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Tell Me U Luv Me (with Trippie Redd)\", \"Streams\": 4798078, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5JAYDuLRkODlVt6dgoalKk\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 72.0, \"Danceability\": 0.66, \"Energy\": 0.76, \"Loudness\": -5.726, \"Speechiness\": 0.0787, \"Acousticness\": 0.291, \"Liveness\": 0.632, \"Tempo\": 127.984, \"Duration (ms)\": 180129.0, \"Valence\": 0.394, \"Chord\": \"D\"}, {\"Index\": 1000, \"Highest Charting Position\": 27, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Bad Energy\", \"Streams\": 4761155, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"7d94IqWX2UmSKMGUYSGFJG\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 72.0, \"Danceability\": 0.654, \"Energy\": 0.452, \"Loudness\": -6.36, \"Speechiness\": 0.0439, \"Acousticness\": 0.17, \"Liveness\": 0.114, \"Tempo\": 138.034, \"Duration (ms)\": 186749.0, \"Valence\": 0.532, \"Chord\": \"G\"}, {\"Index\": 1001, \"Highest Charting Position\": 24, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Titanic\", \"Streams\": 4687464, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"1YM6c2sxbf2Jacl9IFgn4I\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 71.0, \"Danceability\": 0.567, \"Energy\": 0.545, \"Loudness\": -6.668, \"Speechiness\": 0.0448, \"Acousticness\": 0.168, \"Liveness\": 0.112, \"Tempo\": 174.146, \"Duration (ms)\": 176650.0, \"Valence\": 0.234, \"Chord\": \"C#/Db\"}, {\"Index\": 1002, \"Highest Charting Position\": 31, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Skechers\", \"Streams\": 4669248, \"Artist\": \"DripReport\", \"Artist Followers\": 92356.0, \"Song ID\": \"2alc8VZAzDgdAsL2QMk3hu\", \"Genre\": \"['viral rap']\", \"Release Date\": \"2020-01-12\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 73.0, \"Danceability\": 0.903, \"Energy\": 0.327, \"Loudness\": -9.727, \"Speechiness\": 0.0877, \"Acousticness\": 0.26, \"Liveness\": 0.108, \"Tempo\": 100.008, \"Duration (ms)\": 106000.0, \"Valence\": 0.274, \"Chord\": \"C#/Db\"}, {\"Index\": 1003, \"Highest Charting Position\": 47, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"The Bigger Picture\", \"Streams\": 4629083, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"44gRhRi2OhEf7moAUj6MD1\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 70.0, \"Danceability\": 0.59, \"Energy\": 0.618, \"Loudness\": -5.756, \"Speechiness\": 0.334, \"Acousticness\": 0.0127, \"Liveness\": 0.244, \"Tempo\": 96.459, \"Duration (ms)\": 252729.0, \"Valence\": 0.153, \"Chord\": \"C#/Db\"}, {\"Index\": 1004, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Story of My Life\", \"Streams\": 4628772, \"Artist\": \"One Direction\", \"Artist Followers\": 22536304.0, \"Song ID\": \"4nVBt6MZDDP6tRVdQTgxJg\", \"Genre\": \"['boy band', 'pop', 'post-teen pop', 'talent show']\", \"Release Date\": \"2013-11-25\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 81.0, \"Danceability\": 0.6, \"Energy\": 0.663, \"Loudness\": -5.802, \"Speechiness\": 0.0477, \"Acousticness\": 0.225, \"Liveness\": 0.119, \"Tempo\": 121.07, \"Duration (ms)\": 245493.0, \"Valence\": 0.286, \"Chord\": \"D#/Eb\"}, {\"Index\": 1005, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Hit My Line\", \"Streams\": 4621205, \"Artist\": \"Logic\", \"Artist Followers\": 5449291.0, \"Song ID\": \"24FR8mXTaiGZPrxnkf1kcP\", \"Genre\": \"['conscious hip hop', 'dmv rap', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 60.0, \"Danceability\": 0.62, \"Energy\": 0.786, \"Loudness\": -5.22, \"Speechiness\": 0.167, \"Acousticness\": 0.143, \"Liveness\": 0.46, \"Tempo\": 164.057, \"Duration (ms)\": 265191.0, \"Valence\": 0.679, \"Chord\": \"A\"}, {\"Index\": 1006, \"Highest Charting Position\": 10, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Party Girl (Remix)\", \"Streams\": 15129295, \"Artist\": \"StaySolidRocky, Lil Uzi Vert\", \"Artist Followers\": 150587.0, \"Song ID\": \"0XkmeG97T4mtYlWRJcrxec\", \"Genre\": \"['melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 62.0, \"Danceability\": 0.752, \"Energy\": 0.375, \"Loudness\": -10.157, \"Speechiness\": 0.204, \"Acousticness\": 0.533, \"Liveness\": 0.175, \"Tempo\": 129.995, \"Duration (ms)\": 147673.0, \"Valence\": 0.591, \"Chord\": \"F#/Gb\"}, {\"Index\": 1007, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Up Up And Away\", \"Streams\": 6229316, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"7pbg3ABlAZv2NiIdKbBBFm\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 72.0, \"Danceability\": 0.661, \"Energy\": 0.665, \"Loudness\": -6.356, \"Speechiness\": 0.053, \"Acousticness\": 0.538, \"Liveness\": 0.0981, \"Tempo\": 75.059, \"Duration (ms)\": 147548.0, \"Valence\": 0.486, \"Chord\": \"E\"}, {\"Index\": 1008, \"Highest Charting Position\": 46, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Man Of The Year\", \"Streams\": 6223001, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"7AvprzMsRJpybaalckaT8c\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 73.0, \"Danceability\": 0.621, \"Energy\": 0.695, \"Loudness\": -5.124, \"Speechiness\": 0.0911, \"Acousticness\": 0.00584, \"Liveness\": 0.086, \"Tempo\": 173.966, \"Duration (ms)\": 136408.0, \"Valence\": 0.298, \"Chord\": \"E\"}, {\"Index\": 1009, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Fighting Demons\", \"Streams\": 5946573, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"0440JCJyIAmINA8KcYgFb5\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 70.0, \"Danceability\": 0.707, \"Energy\": 0.67, \"Loudness\": -6.328, \"Speechiness\": 0.257, \"Acousticness\": 0.0813, \"Liveness\": 0.098, \"Tempo\": 163.099, \"Duration (ms)\": 200629.0, \"Valence\": 0.235, \"Chord\": \"G\"}, {\"Index\": 1010, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Can't Die\", \"Streams\": 5777859, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4PPLJAEYBSOcnzr9TZoqf9\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 71.0, \"Danceability\": 0.652, \"Energy\": 0.671, \"Loudness\": -5.89, \"Speechiness\": 0.0756, \"Acousticness\": 0.0222, \"Liveness\": 0.107, \"Tempo\": 84.008, \"Duration (ms)\": 182922.0, \"Valence\": 0.274, \"Chord\": \"D\"}, {\"Index\": 1011, \"Highest Charting Position\": 44, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Screw Juice\", \"Streams\": 5394197, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4F6YLjakjqWFTgC5qfEwPQ\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 69.0, \"Danceability\": 0.595, \"Energy\": 0.528, \"Loudness\": -7.371, \"Speechiness\": 0.0935, \"Acousticness\": 0.082, \"Liveness\": 0.142, \"Tempo\": 150.075, \"Duration (ms)\": 179464.0, \"Valence\": 0.515, \"Chord\": \"F\"}, {\"Index\": 1012, \"Highest Charting Position\": 129, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Past Life (with Selena Gomez)\", \"Streams\": 5228433, \"Artist\": \"Trevor Daniel\", \"Artist Followers\": 632097.0, \"Song ID\": \"7MN8RYSofZsFROBlEOAzXq\", \"Genre\": \"['alternative r&b', 'melodic rap', 'pop rap']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 47.0, \"Danceability\": 0.575, \"Energy\": 0.543, \"Loudness\": -5.062, \"Speechiness\": 0.0529, \"Acousticness\": 0.102, \"Liveness\": 0.176, \"Tempo\": 159.905, \"Duration (ms)\": 186480.0, \"Valence\": 0.283, \"Chord\": \"D#/Eb\"}, {\"Index\": 1013, \"Highest Charting Position\": 45, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"I Want It\", \"Streams\": 5137482, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"2SVx3uds6jTWALFxevIWMA\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 69.0, \"Danceability\": 0.288, \"Energy\": 0.638, \"Loudness\": -6.935, \"Speechiness\": 0.0779, \"Acousticness\": 0.133, \"Liveness\": 0.14, \"Tempo\": 66.424, \"Duration (ms)\": 173114.0, \"Valence\": 0.147, \"Chord\": \"E\"}, {\"Index\": 1014, \"Highest Charting Position\": 56, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Ransom\", \"Streams\": 5097394, \"Artist\": \"Lil Tecca\", \"Artist Followers\": 4022792.0, \"Song ID\": \"1lOe9qE0vR9zwWQAOk6CoO\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-08-30\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.745, \"Energy\": 0.642, \"Loudness\": -6.257, \"Speechiness\": 0.287, \"Acousticness\": 0.0204, \"Liveness\": 0.0658, \"Tempo\": 179.974, \"Duration (ms)\": 131240.0, \"Valence\": 0.226, \"Chord\": \"G\"}, {\"Index\": 1015, \"Highest Charting Position\": 49, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Diosa\", \"Streams\": 4868180, \"Artist\": \"Myke Towers\", \"Artist Followers\": 6161098.0, \"Song ID\": \"3JHpk0DOTOzyh0777JFAky\", \"Genre\": \"['trap latino']\", \"Release Date\": \"2020-01-24\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 74.0, \"Danceability\": 0.801, \"Energy\": 0.745, \"Loudness\": -3.733, \"Speechiness\": 0.063, \"Acousticness\": 0.398, \"Liveness\": 0.153, \"Tempo\": 104.965, \"Duration (ms)\": 214013.0, \"Valence\": 0.245, \"Chord\": \"F#/Gb\"}, {\"Index\": 1016, \"Highest Charting Position\": 169, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Never Know (feat. SHIRIN DAVID)\", \"Streams\": 4803071, \"Artist\": \"Luciano\", \"Artist Followers\": 942380.0, \"Song ID\": \"5Hkj1XjMJv5QCGc9NwZm6z\", \"Genre\": \"['german drill', 'german hip hop']\", \"Release Date\": \"2020-07-16\", \"Weeks Charted\": \"2020-07-17--2020-07-24\", \"Popularity\": 60.0, \"Danceability\": 0.874, \"Energy\": 0.542, \"Loudness\": -7.064, \"Speechiness\": 0.344, \"Acousticness\": 0.0621, \"Liveness\": 0.181, \"Tempo\": 142.016, \"Duration (ms)\": 196933.0, \"Valence\": 0.481, \"Chord\": \"A#/Bb\"}, {\"Index\": 1017, \"Highest Charting Position\": 5, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"La Dif\\u00edcil\", \"Streams\": 4727554, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"6NfrH0ANGmgBXyxgV2PeXt\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 78.0, \"Danceability\": 0.685, \"Energy\": 0.848, \"Loudness\": -4.561, \"Speechiness\": 0.0858, \"Acousticness\": 0.0861, \"Liveness\": 0.0783, \"Tempo\": 179.87, \"Duration (ms)\": 163084.0, \"Valence\": 0.761, \"Chord\": \"G#/Ab\"}, {\"Index\": 1018, \"Highest Charting Position\": 20, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"TROLLZ (with Nicki Minaj)\", \"Streams\": 4700152, \"Artist\": \"6ix9ine\", \"Artist Followers\": 6514102.0, \"Song ID\": \"3dVvWnj4D8JGkKvo6Hucso\", \"Genre\": \"['emo rap', 'rap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 65.0, \"Danceability\": 0.744, \"Energy\": 0.422, \"Loudness\": -8.946, \"Speechiness\": 0.294, \"Acousticness\": 0.0319, \"Liveness\": 0.11, \"Tempo\": 180.006, \"Duration (ms)\": 202667.0, \"Valence\": 0.493, \"Chord\": \"C#/Db\"}, {\"Index\": 1019, \"Highest Charting Position\": 44, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Old Town Road - Remix\", \"Streams\": 4643817, \"Artist\": \"Lil Nas X, Billy Ray Cyrus\", \"Artist Followers\": 5488666.0, \"Song ID\": \"2YpeDb67231RjR0MgVLzsG\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.878, \"Energy\": 0.619, \"Loudness\": -5.56, \"Speechiness\": 0.102, \"Acousticness\": 0.0533, \"Liveness\": 0.113, \"Tempo\": 136.041, \"Duration (ms)\": 157067.0, \"Valence\": 0.639, \"Chord\": \"F#/Gb\"}, {\"Index\": 1020, \"Highest Charting Position\": 67, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"The Adventures of Moon Man & Slim Shady (with Eminem)\", \"Streams\": 4639929, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"38iBrrbbXyWaSPkmuDNgjZ\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 67.0, \"Danceability\": 0.88, \"Energy\": 0.787, \"Loudness\": -5.189, \"Speechiness\": 0.118, \"Acousticness\": 0.226, \"Liveness\": 0.12, \"Tempo\": 113.018, \"Duration (ms)\": 264834.0, \"Valence\": 0.588, \"Chord\": \"G#/Ab\"}, {\"Index\": 1021, \"Highest Charting Position\": 25, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"China\", \"Streams\": 4627026, \"Artist\": \"Anuel AA, Daddy Yankee, KAROL G, Ozuna, J Balvin\", \"Artist Followers\": 18306226.0, \"Song ID\": \"2ksOAxtIxY8yElEWw8RhgK\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2019-07-19\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.786, \"Energy\": 0.808, \"Loudness\": -3.702, \"Speechiness\": 0.0882, \"Acousticness\": 0.0846, \"Liveness\": 0.0822, \"Tempo\": 105.027, \"Duration (ms)\": 301714.0, \"Valence\": 0.609, \"Chord\": \"G\"}, {\"Index\": 1022, \"Highest Charting Position\": 29, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Hola - Remix\", \"Streams\": 4617726, \"Artist\": \"Dalex, Lenny Tav\\u00e1rez, Chencho Corleone, Juhn, D\\u00edmelo Flow\", \"Artist Followers\": 3600989.0, \"Song ID\": \"5stPVcRqb4qixbafP9e8lt\", \"Genre\": \"['latin', 'r&b en espanol', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-01\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.654, \"Energy\": 0.672, \"Loudness\": -5.98, \"Speechiness\": 0.311, \"Acousticness\": 0.471, \"Liveness\": 0.0781, \"Tempo\": 181.857, \"Duration (ms)\": 249520.0, \"Valence\": 0.343, \"Chord\": \"C\"}, {\"Index\": 1023, \"Highest Charting Position\": 6, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Ignorantes\", \"Streams\": 4613982, \"Artist\": \"Bad Bunny, Sech\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3wYRLYuO1M88d8woWUIxct\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 74.0, \"Danceability\": 0.85, \"Energy\": 0.536, \"Loudness\": -5.161, \"Speechiness\": 0.0599, \"Acousticness\": 0.267, \"Liveness\": 0.0996, \"Tempo\": 96.029, \"Duration (ms)\": 210607.0, \"Valence\": 0.505, \"Chord\": \"C#/Db\"}, {\"Index\": 1024, \"Highest Charting Position\": 2, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Yummy\", \"Streams\": 4599349, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"41L3O37CECZt3N7ziG2z7l\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-03\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 72.0, \"Danceability\": 0.687, \"Energy\": 0.514, \"Loudness\": -6.612, \"Speechiness\": 0.0897, \"Acousticness\": 0.366, \"Liveness\": 0.116, \"Tempo\": 145.921, \"Duration (ms)\": 210427.0, \"Valence\": 0.494, \"Chord\": \"A\"}, {\"Index\": 1025, \"Highest Charting Position\": 29, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"High Fashion (feat. Mustard)\", \"Streams\": 4592772, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6608815.0, \"Song ID\": \"07KXEDMj78x68D884wgVEm\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 77.0, \"Danceability\": 0.831, \"Energy\": 0.499, \"Loudness\": -8.442, \"Speechiness\": 0.114, \"Acousticness\": 0.269, \"Liveness\": 0.3, \"Tempo\": 97.956, \"Duration (ms)\": 220487.0, \"Valence\": 0.511, \"Chord\": \"B\"}, {\"Index\": 1026, \"Highest Charting Position\": 69, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Like That (feat. Gucci Mane)\", \"Streams\": 4565377, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"4EivmOT13NMpNSfTKn9p4s\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 77.0, \"Danceability\": 0.879, \"Energy\": 0.498, \"Loudness\": -6.027, \"Speechiness\": 0.18, \"Acousticness\": 0.239, \"Liveness\": 0.0967, \"Tempo\": 106.044, \"Duration (ms)\": 163173.0, \"Valence\": 0.405, \"Chord\": \"E\"}, {\"Index\": 1027, \"Highest Charting Position\": 132, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Goodbyes (feat. Young Thug)\", \"Streams\": 4527742, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"0t3ZvGKlmYmVsDzBJAXK8C\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 78.0, \"Danceability\": 0.548, \"Energy\": 0.653, \"Loudness\": -3.875, \"Speechiness\": 0.081, \"Acousticness\": 0.456, \"Liveness\": 0.103, \"Tempo\": 150.068, \"Duration (ms)\": 174853.0, \"Valence\": 0.163, \"Chord\": \"F\"}, {\"Index\": 1028, \"Highest Charting Position\": 23, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"BOP\", \"Streams\": 4496450, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"6Ozh9Ok6h4Oi1wUSLtBseN\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.769, \"Energy\": 0.787, \"Loudness\": -3.909, \"Speechiness\": 0.367, \"Acousticness\": 0.189, \"Liveness\": 0.129, \"Tempo\": 126.77, \"Duration (ms)\": 159715.0, \"Valence\": 0.836, \"Chord\": \"B\"}, {\"Index\": 1029, \"Highest Charting Position\": 21, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Sigues Con El\", \"Streams\": 4485060, \"Artist\": \"D\\u00edmelo Flow, Arcangel, Sech\", \"Artist Followers\": 231580.0, \"Song ID\": \"7sQKy5vlPQllr0k9IjYJv3\", \"Genre\": \"['latin', 'perreo', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.883, \"Energy\": 0.668, \"Loudness\": -2.957, \"Speechiness\": 0.113, \"Acousticness\": 0.11, \"Liveness\": 0.0734, \"Tempo\": 87.972, \"Duration (ms)\": 226533.0, \"Valence\": 0.676, \"Chord\": \"A\"}, {\"Index\": 1030, \"Highest Charting Position\": 78, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Anxiety - Intro\", \"Streams\": 8449557, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"02XcRGWPkvomFvzTamEKHg\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 60.0, \"Danceability\": 0.307, \"Energy\": 0.528, \"Loudness\": -11.337, \"Speechiness\": 0.108, \"Acousticness\": 0.972, \"Liveness\": 0.222, \"Tempo\": 174.795, \"Duration (ms)\": 70395.0, \"Valence\": 0.58, \"Chord\": \"B\"}, {\"Index\": 1031, \"Highest Charting Position\": 112, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Juice WRLD Speaks From Heaven - Outro\", \"Streams\": 6682917, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"1OjiYjgPZyxS0AiXiSnuYI\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 59.0, \"Danceability\": 0.392, \"Energy\": 0.373, \"Loudness\": -14.097, \"Speechiness\": 0.0968, \"Acousticness\": 0.991, \"Liveness\": 0.545, \"Tempo\": 121.678, \"Duration (ms)\": 30583.0, \"Valence\": 0.519, \"Chord\": \"C\"}, {\"Index\": 1032, \"Highest Charting Position\": 113, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"The Man, The Myth, The Legend - Interlude\", \"Streams\": 6640728, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4sjdZEEQvR1sXrRNSuBfbA\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 58.0, \"Danceability\": 0.667, \"Energy\": 0.447, \"Loudness\": -14.625, \"Speechiness\": 0.761, \"Acousticness\": 0.916, \"Liveness\": 0.612, \"Tempo\": 83.534, \"Duration (ms)\": 136545.0, \"Valence\": 0.829, \"Chord\": \"D\"}, {\"Index\": 1033, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Tiefschwarz (feat. Samra)\", \"Streams\": 5867111, \"Artist\": \"Kontra K\", \"Artist Followers\": 1818624.0, \"Song ID\": \"7jMMoHhgq6iwVT5ykyxsJt\", \"Genre\": \"['christlicher rap', 'german hip hop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 62.0, \"Danceability\": 0.751, \"Energy\": 0.783, \"Loudness\": -5.926, \"Speechiness\": 0.22, \"Acousticness\": 0.0715, \"Liveness\": 0.114, \"Tempo\": 94.003, \"Duration (ms)\": 189739.0, \"Valence\": 0.379, \"Chord\": \"G\"}, {\"Index\": 1034, \"Highest Charting Position\": 57, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Wash Us In The Blood\", \"Streams\": 5586085, \"Artist\": \"Kanye West, Travis Scott\", \"Artist Followers\": 14624703.0, \"Song ID\": \"7mEUjhl6aTztdHCrxoTgBG\", \"Genre\": \"['chicago rap', 'rap']\", \"Release Date\": \"2020-06-30\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 64.0, \"Danceability\": 0.67, \"Energy\": 0.847, \"Loudness\": -4.85, \"Speechiness\": 0.409, \"Acousticness\": 0.184, \"Liveness\": 0.304, \"Tempo\": 137.22, \"Duration (ms)\": 189827.0, \"Valence\": 0.381, \"Chord\": \"A#/Bb\"}, {\"Index\": 1035, \"Highest Charting Position\": 53, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Gangstas\", \"Streams\": 5104422, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"1hg3RlqFZXJb5YgRoK9qmF\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 71.0, \"Danceability\": 0.548, \"Energy\": 0.506, \"Loudness\": -7.434, \"Speechiness\": 0.102, \"Acousticness\": 0.203, \"Liveness\": 0.0788, \"Tempo\": 119.987, \"Duration (ms)\": 160000.0, \"Valence\": 0.557, \"Chord\": \"E\"}, {\"Index\": 1036, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Monster\", \"Streams\": 5030481, \"Artist\": \"Red Velvet - IRENE & SEULGI\", \"Artist Followers\": 383695.0, \"Song ID\": \"6c1QaQHdDhtFMfUkhueuXK\", \"Genre\": \"['k-pop']\", \"Release Date\": \"2020-07-06\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 70.0, \"Danceability\": 0.631, \"Energy\": 0.748, \"Loudness\": -2.569, \"Speechiness\": 0.0488, \"Acousticness\": 0.212, \"Liveness\": 0.537, \"Tempo\": 115.665, \"Duration (ms)\": 178413.0, \"Valence\": 0.351, \"Chord\": \"E\"}, {\"Index\": 1037, \"Highest Charting Position\": 139, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"YAYA\", \"Streams\": 4729070, \"Artist\": \"6ix9ine\", \"Artist Followers\": 6514102.0, \"Song ID\": \"6EfBMJQwe2xLgldra6DaYp\", \"Genre\": \"['emo rap', 'rap']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 60.0, \"Danceability\": 0.672, \"Energy\": 0.733, \"Loudness\": -5.377, \"Speechiness\": 0.0566, \"Acousticness\": 0.00289, \"Liveness\": 0.199, \"Tempo\": 105.043, \"Duration (ms)\": 149857.0, \"Valence\": 0.354, \"Chord\": \"B\"}, {\"Index\": 1038, \"Highest Charting Position\": 174, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Narcos\", \"Streams\": 4633313, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"7mcdgAXmb35dakBnfDIv3q\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 68.0, \"Danceability\": 0.614, \"Energy\": 0.746, \"Loudness\": -3.527, \"Speechiness\": 0.196, \"Acousticness\": 0.347, \"Liveness\": 0.0874, \"Tempo\": 168.072, \"Duration (ms)\": 259250.0, \"Valence\": 0.601, \"Chord\": \"A#/Bb\"}, {\"Index\": 1039, \"Highest Charting Position\": 105, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"This City\", \"Streams\": 4597406, \"Artist\": \"Sam Fischer\", \"Artist Followers\": 122883.0, \"Song ID\": \"3H3r2nKWa3Yk5gt8xgmsEt\", \"Genre\": \"['alt z', 'australian pop', 'dance pop', 'indie cafe pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2019-12-11\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 80.0, \"Danceability\": 0.605, \"Energy\": 0.377, \"Loudness\": -6.213, \"Speechiness\": 0.0443, \"Acousticness\": 0.733, \"Liveness\": 0.0808, \"Tempo\": 73.877, \"Duration (ms)\": 194853.0, \"Valence\": 0.519, \"Chord\": \"B\"}, {\"Index\": 1040, \"Highest Charting Position\": 64, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Make It Rain (feat. Rowdy Rebel)\", \"Streams\": 4594248, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"71d7LaAgPcNcUopu3OzmP7\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 62.0, \"Danceability\": 0.5, \"Energy\": 0.767, \"Loudness\": -4.105, \"Speechiness\": 0.403, \"Acousticness\": 0.162, \"Liveness\": 0.385, \"Tempo\": 159.477, \"Duration (ms)\": 202443.0, \"Valence\": 0.58, \"Chord\": \"C#/Db\"}, {\"Index\": 1041, \"Highest Charting Position\": 46, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lalala\", \"Streams\": 4541965, \"Artist\": \"Y2K, bbno$\", \"Artist Followers\": 268766.0, \"Song ID\": \"51Fjme0JiitpyXKuyQiCDo\", \"Genre\": \"['pop rap']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.843, \"Energy\": 0.39, \"Loudness\": -7.899, \"Speechiness\": 0.0846, \"Acousticness\": 0.178, \"Liveness\": 0.137, \"Tempo\": 129.972, \"Duration (ms)\": 160627.0, \"Valence\": 0.495, \"Chord\": \"D\"}, {\"Index\": 1042, \"Highest Charting Position\": 79, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Something Special\", \"Streams\": 4535580, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"5kkaSMcf4BFlhRRICCKZb6\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 72.0, \"Danceability\": 0.739, \"Energy\": 0.616, \"Loudness\": -6.963, \"Speechiness\": 0.0338, \"Acousticness\": 0.252, \"Liveness\": 0.101, \"Tempo\": 91.071, \"Duration (ms)\": 158466.0, \"Valence\": 0.654, \"Chord\": \"G\"}, {\"Index\": 1043, \"Highest Charting Position\": 58, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Aim For The Moon (feat. Quavo)\", \"Streams\": 9011502, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"6O7fPYTsb2mY0PiFt2ymDB\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 67.0, \"Danceability\": 0.713, \"Energy\": 0.605, \"Loudness\": -7.487, \"Speechiness\": 0.107, \"Acousticness\": 0.497, \"Liveness\": 0.115, \"Tempo\": 142.025, \"Duration (ms)\": 175756.0, \"Valence\": 0.432, \"Chord\": \"B\"}, {\"Index\": 1044, \"Highest Charting Position\": 63, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"44 BullDog\", \"Streams\": 8443771, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"7sjFIZ1g5QLJLGja3k592K\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 66.0, \"Danceability\": 0.8, \"Energy\": 0.564, \"Loudness\": -5.817, \"Speechiness\": 0.4, \"Acousticness\": 0.0287, \"Liveness\": 0.112, \"Tempo\": 139.989, \"Duration (ms)\": 150857.0, \"Valence\": 0.318, \"Chord\": \"G#/Ab\"}, {\"Index\": 1045, \"Highest Charting Position\": 88, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Creature (feat. Swae Lee)\", \"Streams\": 7308690, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"3eV2WT9YhfzkxbufnBF8wK\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 66.0, \"Danceability\": 0.794, \"Energy\": 0.717, \"Loudness\": -5.73, \"Speechiness\": 0.251, \"Acousticness\": 0.0511, \"Liveness\": 0.195, \"Tempo\": 141.881, \"Duration (ms)\": 202816.0, \"Valence\": 0.372, \"Chord\": \"G\"}, {\"Index\": 1046, \"Highest Charting Position\": 95, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Yea Yea\", \"Streams\": 7112419, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"0bjgQ24UZGwKikldIyEOgf\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 63.0, \"Danceability\": 0.717, \"Energy\": 0.474, \"Loudness\": -8.383, \"Speechiness\": 0.403, \"Acousticness\": 0.0509, \"Liveness\": 0.139, \"Tempo\": 123.906, \"Duration (ms)\": 185804.0, \"Valence\": 0.448, \"Chord\": \"F\"}, {\"Index\": 1047, \"Highest Charting Position\": 100, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Enjoy Yourself (feat. Karol G)\", \"Streams\": 6620040, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"3NWrHCwvyII4fTx05PN3IO\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 70.0, \"Danceability\": 0.764, \"Energy\": 0.676, \"Loudness\": -6.761, \"Speechiness\": 0.0927, \"Acousticness\": 0.389, \"Liveness\": 0.215, \"Tempo\": 97.02, \"Duration (ms)\": 197938.0, \"Valence\": 0.461, \"Chord\": \"B\"}, {\"Index\": 1048, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Bad Bitch From Tokyo (Intro)\", \"Streams\": 6144736, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"4OGIeHtYhRTJ8iW21UUyZW\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 59.0, \"Danceability\": 0.645, \"Energy\": 0.64, \"Loudness\": -6.871, \"Speechiness\": 0.179, \"Acousticness\": 0.395, \"Liveness\": 0.286, \"Tempo\": 140.248, \"Duration (ms)\": 48000.0, \"Valence\": 0.674, \"Chord\": \"A#/Bb\"}, {\"Index\": 1049, \"Highest Charting Position\": 117, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Snitching (feat. Quavo & Future)\", \"Streams\": 6102253, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"2FhEj9lvEIaJihjFprRrGt\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 59.0, \"Danceability\": 0.944, \"Energy\": 0.579, \"Loudness\": -4.961, \"Speechiness\": 0.191, \"Acousticness\": 0.0381, \"Liveness\": 0.253, \"Tempo\": 135.033, \"Duration (ms)\": 259346.0, \"Valence\": 0.769, \"Chord\": \"G#/Ab\"}, {\"Index\": 1050, \"Highest Charting Position\": 121, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"West Coast Shit (feat. Tyga & Quavo)\", \"Streams\": 5931242, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"1JDhNQ0oOT7XpclZn3aQ8F\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 61.0, \"Danceability\": 0.831, \"Energy\": 0.762, \"Loudness\": -5.656, \"Speechiness\": 0.207, \"Acousticness\": 0.0885, \"Liveness\": 0.107, \"Tempo\": 99.999, \"Duration (ms)\": 192000.0, \"Valence\": 0.495, \"Chord\": \"B\"}, {\"Index\": 1051, \"Highest Charting Position\": 72, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Deep End Freestyle\", \"Streams\": 5280810, \"Artist\": \"Sleepy Hallow, Foushe\\u00e9\", \"Artist Followers\": 411262.0, \"Song ID\": \"2AlYncTpVHKwHb55F9lF6O\", \"Genre\": \"['brooklyn drill', 'nyc rap']\", \"Release Date\": \"2020-06-05\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 72.0, \"Danceability\": 0.868, \"Energy\": 0.479, \"Loudness\": -6.687, \"Speechiness\": 0.445, \"Acousticness\": 0.703, \"Liveness\": 0.102, \"Tempo\": 133.928, \"Duration (ms)\": 115200.0, \"Valence\": 0.776, \"Chord\": \"E\"}, {\"Index\": 1052, \"Highest Charting Position\": 56, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Tommy Lee (feat. Post Malone)\", \"Streams\": 5031845, \"Artist\": \"Tyla Yaweh\", \"Artist Followers\": 359133.0, \"Song ID\": \"5QZKcQDp0tCcvMdyqEciBV\", \"Genre\": \"['cali rap', 'melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 73.0, \"Danceability\": 0.457, \"Energy\": 0.621, \"Loudness\": -5.923, \"Speechiness\": 0.138, \"Acousticness\": 0.218, \"Liveness\": 0.0944, \"Tempo\": 85.359, \"Duration (ms)\": 224638.0, \"Valence\": 0.634, \"Chord\": \"A#/Bb\"}, {\"Index\": 1053, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Tunnel Vision (Outro)\", \"Streams\": 4907751, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"2SxR5RitJdsG6wINvJLBSD\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 60.0, \"Danceability\": 0.718, \"Energy\": 0.66, \"Loudness\": -7.39, \"Speechiness\": 0.325, \"Acousticness\": 0.363, \"Liveness\": 0.159, \"Tempo\": 142.879, \"Duration (ms)\": 132587.0, \"Valence\": 0.659, \"Chord\": \"D\"}, {\"Index\": 1054, \"Highest Charting Position\": 7, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Si Veo a Tu Mam\\u00e1\", \"Streams\": 4638728, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"41wtwzCZkXwpnakmwJ239F\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 80.0, \"Danceability\": 0.9, \"Energy\": 0.603, \"Loudness\": -5.313, \"Speechiness\": 0.0646, \"Acousticness\": 0.402, \"Liveness\": 0.134, \"Tempo\": 129.928, \"Duration (ms)\": 170972.0, \"Valence\": 0.824, \"Chord\": \"D\"}, {\"Index\": 1055, \"Highest Charting Position\": 177, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Prospect (ft. Lil Baby)\", \"Streams\": 4571916, \"Artist\": \"iann dior\", \"Artist Followers\": 1276292.0, \"Song ID\": \"4iHSE5R1U8jf84tRn52xRt\", \"Genre\": \"['melodic rap', 'pop rap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 68.0, \"Danceability\": 0.816, \"Energy\": 0.579, \"Loudness\": -6.097, \"Speechiness\": 0.0867, \"Acousticness\": 0.203, \"Liveness\": 0.127, \"Tempo\": 120.078, \"Duration (ms)\": 226314.0, \"Valence\": 0.43, \"Chord\": \"C#/Db\"}, {\"Index\": 1056, \"Highest Charting Position\": 55, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"No Me Conoce - Remix\", \"Streams\": 4501188, \"Artist\": \"Jhay Cortez, J Balvin, Bad Bunny\", \"Artist Followers\": 2435159.0, \"Song ID\": \"4R8BJggjosTswLxtkw8V7P\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-05-24\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.806, \"Energy\": 0.786, \"Loudness\": -3.831, \"Speechiness\": 0.0741, \"Acousticness\": 0.145, \"Liveness\": 0.0935, \"Tempo\": 91.973, \"Duration (ms)\": 309120.0, \"Valence\": 0.58, \"Chord\": \"A#/Bb\"}, {\"Index\": 1057, \"Highest Charting Position\": 189, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"El Manual\", \"Streams\": 4470597, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"7kOf0qHO4Rcwk6QJifZDRJ\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 67.0, \"Danceability\": 0.843, \"Energy\": 0.845, \"Loudness\": -2.344, \"Speechiness\": 0.0503, \"Acousticness\": 0.35, \"Liveness\": 0.0527, \"Tempo\": 126.989, \"Duration (ms)\": 210624.0, \"Valence\": 0.898, \"Chord\": \"C\"}, {\"Index\": 1058, \"Highest Charting Position\": 181, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Thunder\", \"Streams\": 4468668, \"Artist\": \"Imagine Dragons\", \"Artist Followers\": 35299488.0, \"Song ID\": \"1zB4vmk8tFRmM9UULNzbLB\", \"Genre\": \"['modern rock', 'pop', 'rock']\", \"Release Date\": \"2017-06-23\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-05--2020-06-12\\n2020-02-07--2020-02-14\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.605, \"Energy\": 0.822, \"Loudness\": -4.833, \"Speechiness\": 0.0438, \"Acousticness\": 0.00671, \"Liveness\": 0.147, \"Tempo\": 167.997, \"Duration (ms)\": 187147.0, \"Valence\": 0.288, \"Chord\": \"C\"}, {\"Index\": 1059, \"Highest Charting Position\": 158, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"El Efecto - Remix\", \"Streams\": 4433384, \"Artist\": \"Rauw Alejandro, Chencho Corleone, KEVVO, Bryant Myers, Lyanno, Dalex\", \"Artist Followers\": 6096559.0, \"Song ID\": \"74j34STf8L6uADnTN69ohv\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 73.0, \"Danceability\": 0.771, \"Energy\": 0.769, \"Loudness\": -3.504, \"Speechiness\": 0.0694, \"Acousticness\": 0.18, \"Liveness\": 0.345, \"Tempo\": 167.969, \"Duration (ms)\": 289899.0, \"Valence\": 0.931, \"Chord\": \"C\"}, {\"Index\": 1060, \"Highest Charting Position\": 122, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Better Now\", \"Streams\": 4431571, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"7dt6x5M1jzdTEt8oCbisTK\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2018-04-27\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.68, \"Energy\": 0.578, \"Loudness\": -5.804, \"Speechiness\": 0.04, \"Acousticness\": 0.331, \"Liveness\": 0.135, \"Tempo\": 145.038, \"Duration (ms)\": 231267.0, \"Valence\": 0.341, \"Chord\": \"A#/Bb\"}, {\"Index\": 1061, \"Highest Charting Position\": 185, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Don't Stop Believin'\", \"Streams\": 4394985, \"Artist\": \"Journey\", \"Artist Followers\": 3731820.0, \"Song ID\": \"4bHsxqR3GMrXTxEPLuK5ue\", \"Genre\": \"['album rock', 'classic rock', 'hard rock', 'mellow gold', 'rock', 'soft rock']\", \"Release Date\": \"1981\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-19--2020-06-26\", \"Popularity\": 81.0, \"Danceability\": 0.5, \"Energy\": 0.748, \"Loudness\": -9.072, \"Speechiness\": 0.0363, \"Acousticness\": 0.127, \"Liveness\": 0.447, \"Tempo\": 118.852, \"Duration (ms)\": 250987.0, \"Valence\": 0.514, \"Chord\": \"E\"}, {\"Index\": 1062, \"Highest Charting Position\": 90, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"BLACK PARADE\", \"Streams\": 5474807, \"Artist\": \"Beyonc\\u00e9\", \"Artist Followers\": 28335112.0, \"Song ID\": \"2qzUpSVI4NnPyWxbXwumTj\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'r&b']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 61.0, \"Danceability\": 0.824, \"Energy\": 0.555, \"Loudness\": -5.817, \"Speechiness\": 0.05, \"Acousticness\": 0.00337, \"Liveness\": 0.217, \"Tempo\": 120.002, \"Duration (ms)\": 281273.0, \"Valence\": 0.0611, \"Chord\": \"C#/Db\"}, {\"Index\": 1063, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"XXL\", \"Streams\": 5415994, \"Artist\": \"Miksu / Macloud, Summer Cem, Luciano, Jamule\", \"Artist Followers\": 30683.0, \"Song ID\": \"0p3euGPg5LgFeQGC7bBFuR\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 64.0, \"Danceability\": 0.798, \"Energy\": 0.527, \"Loudness\": -7.671, \"Speechiness\": 0.0447, \"Acousticness\": 0.227, \"Liveness\": 0.108, \"Tempo\": 114.008, \"Duration (ms)\": 166173.0, \"Valence\": 0.548, \"Chord\": \"F\"}, {\"Index\": 1064, \"Highest Charting Position\": 70, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Salt\", \"Streams\": 4874960, \"Artist\": \"Ava Max\", \"Artist Followers\": 1251372.0, \"Song ID\": \"2o2p9xH3bkSDLcp6phIF4J\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 1.0, \"Danceability\": 0.693, \"Energy\": 0.835, \"Loudness\": -3.242, \"Speechiness\": 0.0624, \"Acousticness\": 0.131, \"Liveness\": 0.073, \"Tempo\": 128.052, \"Duration (ms)\": 180283.0, \"Valence\": 0.744, \"Chord\": \"F#/Gb\"}, {\"Index\": 1065, \"Highest Charting Position\": 52, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Daisies\", \"Streams\": 4838067, \"Artist\": \"Katy Perry\", \"Artist Followers\": 18936929.0, \"Song ID\": \"4uqh9bualXNHXXwO2wPorc\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 68.0, \"Danceability\": 0.639, \"Energy\": 0.546, \"Loudness\": -5.382, \"Speechiness\": 0.0407, \"Acousticness\": 0.0837, \"Liveness\": 0.122, \"Tempo\": 122.179, \"Duration (ms)\": 173124.0, \"Valence\": 0.149, \"Chord\": \"C#/Db\"}, {\"Index\": 1066, \"Highest Charting Position\": 142, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Emotionally Scarred\", \"Streams\": 4633237, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"7ge7BHazYbVKi8qyZUX1Bm\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 71.0, \"Danceability\": 0.585, \"Energy\": 0.641, \"Loudness\": -4.269, \"Speechiness\": 0.133, \"Acousticness\": 0.0286, \"Liveness\": 0.316, \"Tempo\": 88.284, \"Duration (ms)\": 197530.0, \"Valence\": 0.266, \"Chord\": \"F#/Gb\"}, {\"Index\": 1067, \"Highest Charting Position\": 32, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Myron\", \"Streams\": 4593309, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"56uXDJRCuoS7abX3SkzHKQ\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 76.0, \"Danceability\": 0.771, \"Energy\": 0.654, \"Loudness\": -6.976, \"Speechiness\": 0.298, \"Acousticness\": 0.055, \"Liveness\": 0.214, \"Tempo\": 155.047, \"Duration (ms)\": 224955.0, \"Valence\": 0.573, \"Chord\": \"G#/Ab\"}, {\"Index\": 1068, \"Highest Charting Position\": 67, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"MORE & MORE\", \"Streams\": 4592745, \"Artist\": \"TWICE\", \"Artist Followers\": 9998991.0, \"Song ID\": \"3omvXShuRPM3zbDpWYqf5g\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-06-01\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 70.0, \"Danceability\": 0.739, \"Energy\": 0.841, \"Loudness\": -4.162, \"Speechiness\": 0.06, \"Acousticness\": 0.0312, \"Liveness\": 0.173, \"Tempo\": 106.99, \"Duration (ms)\": 199653.0, \"Valence\": 0.562, \"Chord\": \"F\"}, {\"Index\": 1069, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Girls in the Hood\", \"Streams\": 4577209, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"6WbTTAGKrQtCQvmc5BuYfh\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 72.0, \"Danceability\": 0.821, \"Energy\": 0.863, \"Loudness\": -3.159, \"Speechiness\": 0.353, \"Acousticness\": 0.00824, \"Liveness\": 0.0377, \"Tempo\": 180.013, \"Duration (ms)\": 154324.0, \"Valence\": 0.874, \"Chord\": \"F#/Gb\"}, {\"Index\": 1070, \"Highest Charting Position\": 169, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Parasite Eve\", \"Streams\": 4545883, \"Artist\": \"Bring Me The Horizon\", \"Artist Followers\": 3912138.0, \"Song ID\": \"5OxclJsdFESni44YlpNpkR\", \"Genre\": \"['melodic metalcore', 'metalcore', 'rock', 'uk metalcore']\", \"Release Date\": \"2020-06-25\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 67.0, \"Danceability\": 0.589, \"Energy\": 0.797, \"Loudness\": -5.464, \"Speechiness\": 0.15, \"Acousticness\": 0.0289, \"Liveness\": 0.383, \"Tempo\": 102.489, \"Duration (ms)\": 291813.0, \"Valence\": 0.232, \"Chord\": \"A\"}, {\"Index\": 1071, \"Highest Charting Position\": 78, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Sucker\", \"Streams\": 4543863, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"22vgEDb5hykfaTwLuskFGD\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-06-07\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.842, \"Energy\": 0.734, \"Loudness\": -5.065, \"Speechiness\": 0.0588, \"Acousticness\": 0.0427, \"Liveness\": 0.106, \"Tempo\": 137.958, \"Duration (ms)\": 181027.0, \"Valence\": 0.952, \"Chord\": \"C#/Db\"}, {\"Index\": 1072, \"Highest Charting Position\": 147, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"I Like Me Better\", \"Streams\": 4430642, \"Artist\": \"Lauv\", \"Artist Followers\": 4442273.0, \"Song ID\": \"2P91MQbaiQOfbiz9VqhqKQ\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-05-31\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.752, \"Energy\": 0.505, \"Loudness\": -7.621, \"Speechiness\": 0.253, \"Acousticness\": 0.535, \"Liveness\": 0.104, \"Tempo\": 91.97, \"Duration (ms)\": 197437.0, \"Valence\": 0.419, \"Chord\": \"A\"}, {\"Index\": 1073, \"Highest Charting Position\": 116, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"High Hopes\", \"Streams\": 4426791, \"Artist\": \"Panic! At The Disco\", \"Artist Followers\": 10850424.0, \"Song ID\": \"1rqqCSm0Qe4I9rUvWncaom\", \"Genre\": \"['modern rock']\", \"Release Date\": \"2018-06-22\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.579, \"Energy\": 0.904, \"Loudness\": -2.729, \"Speechiness\": 0.0618, \"Acousticness\": 0.193, \"Liveness\": 0.064, \"Tempo\": 82.014, \"Duration (ms)\": 190947.0, \"Valence\": 0.681, \"Chord\": \"F\"}, {\"Index\": 1074, \"Highest Charting Position\": 88, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Money In The Grave (Drake ft. Rick Ross)\", \"Streams\": 4403348, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5ry2OE6R2zPQFDO85XkgRb\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2019-06-15\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.831, \"Energy\": 0.502, \"Loudness\": -4.045, \"Speechiness\": 0.046, \"Acousticness\": 0.101, \"Liveness\": 0.122, \"Tempo\": 100.541, \"Duration (ms)\": 205427.0, \"Valence\": 0.101, \"Chord\": \"A#/Bb\"}, {\"Index\": 1075, \"Highest Charting Position\": 25, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Say So (feat. Nicki Minaj)\", \"Streams\": 4385148, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"11VApNQCWLJdzxWrlmwzUa\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 69.0, \"Danceability\": 0.856, \"Energy\": 0.641, \"Loudness\": -4.64, \"Speechiness\": 0.204, \"Acousticness\": 0.119, \"Liveness\": 0.427, \"Tempo\": 111.004, \"Duration (ms)\": 206221.0, \"Valence\": 0.745, \"Chord\": \"B\"}, {\"Index\": 1076, \"Highest Charting Position\": 189, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Karaoke\", \"Streams\": 4374448, \"Artist\": \"Boomdabash, Alessandra Amoroso\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3n6TeHSnNhDe991nJS2S90\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-10\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 0.0, \"Danceability\": 0.929, \"Energy\": 0.625, \"Loudness\": -5.728, \"Speechiness\": 0.14, \"Acousticness\": 0.289, \"Liveness\": 0.386, \"Tempo\": 122.03, \"Duration (ms)\": 156493.0, \"Valence\": 0.578, \"Chord\": \"C#/Db\"}, {\"Index\": 1077, \"Highest Charting Position\": 36, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Know Your Worth\", \"Streams\": 4374392, \"Artist\": \"Khalid, Disclosure\", \"Artist Followers\": 14190858.0, \"Song ID\": \"0TrPqhAMoaKUFLR7iYDokf\", \"Genre\": \"['pop']\", \"Release Date\": \"2020-02-04\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 76.0, \"Danceability\": 0.79, \"Energy\": 0.694, \"Loudness\": -7.726, \"Speechiness\": 0.0708, \"Acousticness\": 0.145, \"Liveness\": 0.281, \"Tempo\": 103.007, \"Duration (ms)\": 181436.0, \"Valence\": 0.508, \"Chord\": \"A\"}, {\"Index\": 1078, \"Highest Charting Position\": 26, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"No Idea\", \"Streams\": 4369849, \"Artist\": \"Don Toliver\", \"Artist Followers\": 1606884.0, \"Song ID\": \"7AzlLxHn24DxjgQX73F9fU\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.652, \"Energy\": 0.631, \"Loudness\": -5.718, \"Speechiness\": 0.0893, \"Acousticness\": 0.524, \"Liveness\": 0.165, \"Tempo\": 127.998, \"Duration (ms)\": 154424.0, \"Valence\": 0.35, \"Chord\": \"F#/Gb\"}, {\"Index\": 1079, \"Highest Charting Position\": 145, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Airwaves\", \"Streams\": 4352767, \"Artist\": \"Pashanim\", \"Artist Followers\": 208926.0, \"Song ID\": \"5CqkgDH8QZjSqqI3HmYxDD\", \"Genre\": \"['german alternative rap', 'german drill', 'german hip hop', 'german trap']\", \"Release Date\": \"2020-05-14\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 71.0, \"Danceability\": 0.885, \"Energy\": 0.578, \"Loudness\": -7.416, \"Speechiness\": 0.0783, \"Acousticness\": 0.0739, \"Liveness\": 0.102, \"Tempo\": 131.999, \"Duration (ms)\": 178933.0, \"Valence\": 0.388, \"Chord\": \"F\"}, {\"Index\": 1080, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Kill This Love\", \"Streams\": 4341050, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"6hvczQ05jc1yGlp9zhb95V\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2019-04-05\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 76.0, \"Danceability\": 0.763, \"Energy\": 0.835, \"Loudness\": -5.234, \"Speechiness\": 0.191, \"Acousticness\": 0.323, \"Liveness\": 0.225, \"Tempo\": 131.875, \"Duration (ms)\": 191050.0, \"Valence\": 0.645, \"Chord\": \"D\"}, {\"Index\": 1081, \"Highest Charting Position\": 68, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lights Up\", \"Streams\": 4325411, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16127908.0, \"Song ID\": \"4jAIqgrPjKLTY9Gbez25Qb\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.575, \"Energy\": 0.621, \"Loudness\": -8.165, \"Speechiness\": 0.032, \"Acousticness\": 0.0392, \"Liveness\": 0.141, \"Tempo\": 101.987, \"Duration (ms)\": 172213.0, \"Valence\": 0.27, \"Chord\": \"A#/Bb\"}, {\"Index\": 1082, \"Highest Charting Position\": 14, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Lose You To Love Me\", \"Streams\": 4322088, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4l0Mvzj72xxOpRrp6h8nHi\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.488, \"Energy\": 0.343, \"Loudness\": -8.985, \"Speechiness\": 0.0436, \"Acousticness\": 0.556, \"Liveness\": 0.21, \"Tempo\": 102.819, \"Duration (ms)\": 206459.0, \"Valence\": 0.0978, \"Chord\": \"E\"}, {\"Index\": 1083, \"Highest Charting Position\": 94, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Girls Like You (feat. Cardi B)\", \"Streams\": 4318772, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32279979.0, \"Song ID\": \"6V1bu6o1Yo5ZXnsCJU8Ovk\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2018-06-15\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.851, \"Energy\": 0.541, \"Loudness\": -6.825, \"Speechiness\": 0.0505, \"Acousticness\": 0.568, \"Liveness\": 0.13, \"Tempo\": 124.959, \"Duration (ms)\": 235545.0, \"Valence\": 0.448, \"Chord\": \"C\"}, {\"Index\": 1084, \"Highest Charting Position\": 47, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"PA' ROMPERLA\", \"Streams\": 4312675, \"Artist\": \"Bad Bunny, Don Omar\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5XqCz18k96K8tx6DAYM97i\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 72.0, \"Danceability\": 0.772, \"Energy\": 0.83, \"Loudness\": -5.019, \"Speechiness\": 0.0599, \"Acousticness\": 0.016, \"Liveness\": 0.0843, \"Tempo\": 94.011, \"Duration (ms)\": 194200.0, \"Valence\": 0.697, \"Chord\": \"G\"}, {\"Index\": 1085, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"VACATION\", \"Streams\": 6883487, \"Artist\": \"Tyga\", \"Artist Followers\": 6298789.0, \"Song ID\": \"6q2uIyLqASSpv2SIv2ehWK\", \"Genre\": \"['dance pop', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 51.0, \"Danceability\": 0.821, \"Energy\": 0.61, \"Loudness\": -6.22, \"Speechiness\": 0.0959, \"Acousticness\": 0.0247, \"Liveness\": 0.185, \"Tempo\": 110.973, \"Duration (ms)\": 192936.0, \"Valence\": 0.47, \"Chord\": \"C#/Db\"}, {\"Index\": 1086, \"Highest Charting Position\": 86, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Big Body Benz\", \"Streams\": 6707101, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"2WOJ7D52Ng3myrKlEf4Azj\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-06-18\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 61.0, \"Danceability\": 0.884, \"Energy\": 0.451, \"Loudness\": -8.969, \"Speechiness\": 0.393, \"Acousticness\": 0.0731, \"Liveness\": 0.268, \"Tempo\": 94.024, \"Duration (ms)\": 148284.0, \"Valence\": 0.311, \"Chord\": \"A\"}, {\"Index\": 1087, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Ich wei\\u00df nicht mal wie sie hei\\u00dft\", \"Streams\": 5827600, \"Artist\": \"Capital Bra, Bozza\", \"Artist Followers\": 4093115.0, \"Song ID\": \"4KfL3Ne8bc9bC2PUB8QGwA\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-06-18\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 57.0, \"Danceability\": 0.498, \"Energy\": 0.836, \"Loudness\": -3.905, \"Speechiness\": 0.184, \"Acousticness\": 0.525, \"Liveness\": 0.0994, \"Tempo\": 199.846, \"Duration (ms)\": 168750.0, \"Valence\": 0.609, \"Chord\": \"A#/Bb\"}, {\"Index\": 1088, \"Highest Charting Position\": 101, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"F\\u00fatbol & Rumba (feat. Enrique Iglesias)\", \"Streams\": 5124116, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"2hDe0Ls5mVqs1XJqv7sbcM\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 67.0, \"Danceability\": 0.735, \"Energy\": 0.916, \"Loudness\": -2.082, \"Speechiness\": 0.117, \"Acousticness\": 0.397, \"Liveness\": 0.0918, \"Tempo\": 167.994, \"Duration (ms)\": 221429.0, \"Valence\": 0.691, \"Chord\": \"D\"}, {\"Index\": 1089, \"Highest Charting Position\": 131, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Bleed\", \"Streams\": 5095478, \"Artist\": \"A Boogie Wit da Hoodie\", \"Artist Followers\": 5865895.0, \"Song ID\": \"5XzombolzpiaOSTdj1W0VS\", \"Genre\": \"['melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 61.0, \"Danceability\": 0.698, \"Energy\": 0.572, \"Loudness\": -7.735, \"Speechiness\": 0.198, \"Acousticness\": 0.135, \"Liveness\": 0.154, \"Tempo\": 71.446, \"Duration (ms)\": 176959.0, \"Valence\": 0.391, \"Chord\": \"D\"}, {\"Index\": 1090, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Snow On Tha Bluff\", \"Streams\": 5060764, \"Artist\": \"J. Cole\", \"Artist Followers\": 14103694.0, \"Song ID\": \"1oOEkBNp4zWnkD7nWjJdog\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2020-06-16\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 66.0, \"Danceability\": 0.586, \"Energy\": 0.512, \"Loudness\": -8.819, \"Speechiness\": 0.0668, \"Acousticness\": 0.723, \"Liveness\": 0.119, \"Tempo\": 75.857, \"Duration (ms)\": 235480.0, \"Valence\": 0.235, \"Chord\": \"G#/Ab\"}, {\"Index\": 1091, \"Highest Charting Position\": 113, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Djomb - Bien ou quoi\", \"Streams\": 4924714, \"Artist\": \"Bosh\", \"Artist Followers\": 300500.0, \"Song ID\": \"0KBwGCY9RYD9t2zjeW4h48\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 64.0, \"Danceability\": 0.945, \"Energy\": 0.676, \"Loudness\": -6.6, \"Speechiness\": 0.207, \"Acousticness\": 0.172, \"Liveness\": 0.322, \"Tempo\": 123.109, \"Duration (ms)\": 141893.0, \"Valence\": 0.631, \"Chord\": \"C#/Db\"}, {\"Index\": 1092, \"Highest Charting Position\": 84, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"In Your Eyes (feat. Alida)\", \"Streams\": 4654587, \"Artist\": \"Alida, Robin Schulz\", \"Artist Followers\": 2786366.0, \"Song ID\": \"61ZM92T2zaXIVsqncThQzC\", \"Genre\": \"['dance pop', 'deep euro house', 'deep house', 'edm', 'german dance', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 71.0, \"Danceability\": 0.57, \"Energy\": 0.672, \"Loudness\": -5.888, \"Speechiness\": 0.0716, \"Acousticness\": 0.172, \"Liveness\": 0.0768, \"Tempo\": 120.018, \"Duration (ms)\": 208222.0, \"Valence\": 0.461, \"Chord\": \"G#/Ab\"}, {\"Index\": 1093, \"Highest Charting Position\": 13, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Stupid Love\", \"Streams\": 4609858, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 1251372.0, \"Song ID\": \"1zPwSOUc5MPtPg8EgXAGKU\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-08\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 0.0, \"Danceability\": 0.68, \"Energy\": 0.825, \"Loudness\": -4.296, \"Speechiness\": 0.0702, \"Acousticness\": 0.00173, \"Liveness\": 0.27, \"Tempo\": 117.987, \"Duration (ms)\": 193533.0, \"Valence\": 0.784, \"Chord\": \"G#/Ab\"}, {\"Index\": 1094, \"Highest Charting Position\": 93, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Shotta Flow 5\", \"Streams\": 4513982, \"Artist\": \"NLE Choppa\", \"Artist Followers\": 3372385.0, \"Song ID\": \"1orjH4IkSH9VrWmRCToKV8\", \"Genre\": \"['memphis hip hop']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 62.0, \"Danceability\": 0.806, \"Energy\": 0.749, \"Loudness\": -5.268, \"Speechiness\": 0.328, \"Acousticness\": 0.0838, \"Liveness\": 0.0621, \"Tempo\": 140.032, \"Duration (ms)\": 145167.0, \"Valence\": 0.77, \"Chord\": \"C#/Db\"}, {\"Index\": 1095, \"Highest Charting Position\": 145, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"IDK You Yet\", \"Streams\": 4473413, \"Artist\": \"Alexander 23\", \"Artist Followers\": 207170.0, \"Song ID\": \"0j1Ia2lQWrcXrQZI4AdJlk\", \"Genre\": \"['alt z', 'indie cafe pop', 'pop', 'post-teen pop', 'social media pop']\", \"Release Date\": \"2020-06-23\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 79.0, \"Danceability\": 0.648, \"Energy\": 0.308, \"Loudness\": -11.729, \"Speechiness\": 0.04, \"Acousticness\": 0.886, \"Liveness\": 0.124, \"Tempo\": 76.997, \"Duration (ms)\": 184638.0, \"Valence\": 0.198, \"Chord\": \"C#/Db\"}, {\"Index\": 1096, \"Highest Charting Position\": 75, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Piece Of Your Heart\", \"Streams\": 4422905, \"Artist\": \"MEDUZA, Goodboys\", \"Artist Followers\": 441714.0, \"Song ID\": \"1DFD5Fotzgn6yYXkYsKiGs\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop house', 'tropical house']\", \"Release Date\": \"2019-02-01\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.677, \"Energy\": 0.744, \"Loudness\": -6.806, \"Speechiness\": 0.0295, \"Acousticness\": 0.0404, \"Liveness\": 0.074, \"Tempo\": 124.08, \"Duration (ms)\": 152913.0, \"Valence\": 0.631, \"Chord\": \"A#/Bb\"}, {\"Index\": 1097, \"Highest Charting Position\": 129, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Na Raba Toma Tap\\u00e3o\", \"Streams\": 4396629, \"Artist\": \"Niack\", \"Artist Followers\": 352402.0, \"Song ID\": \"0AGS6ZRgzobrazmCi6pYMe\", \"Genre\": \"['funk carioca']\", \"Release Date\": \"2020-06-06\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 61.0, \"Danceability\": 0.962, \"Energy\": 0.787, \"Loudness\": 1.509, \"Speechiness\": 0.0554, \"Acousticness\": 0.666, \"Liveness\": 0.176, \"Tempo\": 130.003, \"Duration (ms)\": 165231.0, \"Valence\": 0.968, \"Chord\": \"D#/Eb\"}, {\"Index\": 1098, \"Highest Charting Position\": 14, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"La Santa\", \"Streams\": 4384527, \"Artist\": \"Bad Bunny, Daddy Yankee\", \"Artist Followers\": 36177712.0, \"Song ID\": \"69vlMrzHwATKzupwNcUPyK\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 79.0, \"Danceability\": 0.744, \"Energy\": 0.868, \"Loudness\": -4.524, \"Speechiness\": 0.047, \"Acousticness\": 0.0326, \"Liveness\": 0.0822, \"Tempo\": 93.037, \"Duration (ms)\": 206420.0, \"Valence\": 0.586, \"Chord\": \"C#/Db\"}, {\"Index\": 1099, \"Highest Charting Position\": 125, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Make You Mine\", \"Streams\": 4356213, \"Artist\": \"PUBLIC\", \"Artist Followers\": 165504.0, \"Song ID\": \"5iFwAOB2TFkPJk8sMlxP8g\", \"Genre\": \"['indie rockism']\", \"Release Date\": \"2019-08-09\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 77.0, \"Danceability\": 0.606, \"Energy\": 0.799, \"Loudness\": -4.452, \"Speechiness\": 0.0261, \"Acousticness\": 0.0128, \"Liveness\": 0.15, \"Tempo\": 103.014, \"Duration (ms)\": 232907.0, \"Valence\": 0.638, \"Chord\": \"A\"}, {\"Index\": 1100, \"Highest Charting Position\": 76, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"ROCKSTAR (feat. Roddy Ricch) - BLM REMIX\", \"Streams\": 7353153, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"4Aykm3xrOFSHrAnv80KUhh\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 62.0, \"Danceability\": 0.747, \"Energy\": 0.689, \"Loudness\": -7.246, \"Speechiness\": 0.242, \"Acousticness\": 0.197, \"Liveness\": 0.0884, \"Tempo\": 89.901, \"Duration (ms)\": 204547.0, \"Valence\": 0.75, \"Chord\": \"B\"}, {\"Index\": 1101, \"Highest Charting Position\": 97, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Make It Rain\", \"Streams\": 6042929, \"Artist\": \"Pop Smoke, Rowdy Rebel\", \"Artist Followers\": 6852509.0, \"Song ID\": \"4TgHt7vKCimpywaiKfl0uj\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 64.0, \"Danceability\": 0.54, \"Energy\": 0.77, \"Loudness\": -3.981, \"Speechiness\": 0.389, \"Acousticness\": 0.194, \"Liveness\": 0.372, \"Tempo\": 159.494, \"Duration (ms)\": 204000.0, \"Valence\": 0.565, \"Chord\": \"C#/Db\"}, {\"Index\": 1102, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"M' Manc (con Geolier & Sfera Ebbasta)\", \"Streams\": 5171235, \"Artist\": \"Shablo\", \"Artist Followers\": 40045.0, \"Song ID\": \"0MLu1cFYL4ikdRTdasCQT9\", \"Genre\": \"['italian hip hop']\", \"Release Date\": \"2020-06-11\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 66.0, \"Danceability\": 0.703, \"Energy\": 0.704, \"Loudness\": -6.117, \"Speechiness\": 0.0641, \"Acousticness\": 0.048, \"Liveness\": 0.41, \"Tempo\": 139.933, \"Duration (ms)\": 180000.0, \"Valence\": 0.725, \"Chord\": \"F#/Gb\"}, {\"Index\": 1103, \"Highest Charting Position\": 143, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Emotions 2.0\", \"Streams\": 5113459, \"Artist\": \"Ufo361, C\\u00c9LINE\", \"Artist Followers\": 1700759.0, \"Song ID\": \"3yZCjDTxzZxx1kll1sRjGc\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 65.0, \"Danceability\": 0.788, \"Energy\": 0.491, \"Loudness\": -9.884, \"Speechiness\": 0.109, \"Acousticness\": 0.386, \"Liveness\": 0.107, \"Tempo\": 98.543, \"Duration (ms)\": 146028.0, \"Valence\": 0.271, \"Chord\": \"G#/Ab\"}, {\"Index\": 1104, \"Highest Charting Position\": 21, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"P2\", \"Streams\": 4769996, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"3kW4z2pIj5VY5fLjBrMRL5\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 73.0, \"Danceability\": 0.775, \"Energy\": 0.72, \"Loudness\": -5.353, \"Speechiness\": 0.193, \"Acousticness\": 0.0236, \"Liveness\": 0.114, \"Tempo\": 155.086, \"Duration (ms)\": 234627.0, \"Valence\": 0.49, \"Chord\": \"B\"}, {\"Index\": 1105, \"Highest Charting Position\": 79, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Selfish\", \"Streams\": 4754830, \"Artist\": \"Madison Beer\", \"Artist Followers\": 3370013.0, \"Song ID\": \"4PV0uE5pZSh44E3NqNNDEH\", \"Genre\": \"['alt z', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 70.0, \"Danceability\": 0.375, \"Energy\": 0.461, \"Loudness\": -6.202, \"Speechiness\": 0.0279, \"Acousticness\": 0.627, \"Liveness\": 0.386, \"Tempo\": 75.217, \"Duration (ms)\": 223270.0, \"Valence\": 0.233, \"Chord\": \"A\"}, {\"Index\": 1106, \"Highest Charting Position\": 154, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Surrender\", \"Streams\": 4627942, \"Artist\": \"Natalie Taylor\", \"Artist Followers\": 120208.0, \"Song ID\": \"0ecC8p17cDNlxHXkuYqeR6\", \"Genre\": \"[]\", \"Release Date\": \"2019-10-29\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 76.0, \"Danceability\": 0.39, \"Energy\": 0.448, \"Loudness\": -8.57, \"Speechiness\": 0.0276, \"Acousticness\": 0.8, \"Liveness\": 0.107, \"Tempo\": 144.89, \"Duration (ms)\": 183103.0, \"Valence\": 0.077, \"Chord\": \"F\"}, {\"Index\": 1107, \"Highest Charting Position\": 86, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Turks (with Gunna & ft. Travis Scott)\", \"Streams\": 4623279, \"Artist\": \"NAV\", \"Artist Followers\": 2613211.0, \"Song ID\": \"7IMwEtpAiJanqF6vQteZN2\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'hip hop', 'melodic rap', 'pop rap', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 67.0, \"Danceability\": 0.894, \"Energy\": 0.618, \"Loudness\": -4.356, \"Speechiness\": 0.129, \"Acousticness\": 0.0808, \"Liveness\": 0.558, \"Tempo\": 119.1, \"Duration (ms)\": 161320.0, \"Valence\": 0.379, \"Chord\": \"G\"}, {\"Index\": 1108, \"Highest Charting Position\": 48, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"BYE ME FUI\", \"Streams\": 4567732, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0FktnzDqjClqU6iqOZVEs2\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 72.0, \"Danceability\": 0.712, \"Energy\": 0.599, \"Loudness\": -6.342, \"Speechiness\": 0.112, \"Acousticness\": 0.412, \"Liveness\": 0.103, \"Tempo\": 179.788, \"Duration (ms)\": 178000.0, \"Valence\": 0.588, \"Chord\": \"F\"}, {\"Index\": 1109, \"Highest Charting Position\": 15, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Vete\", \"Streams\": 4486408, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5DxXgozhkPLgrbKFY91w0c\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-21\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.886, \"Energy\": 0.672, \"Loudness\": -4.394, \"Speechiness\": 0.188, \"Acousticness\": 0.0363, \"Liveness\": 0.101, \"Tempo\": 91.976, \"Duration (ms)\": 192024.0, \"Valence\": 0.526, \"Chord\": \"C#/Db\"}, {\"Index\": 1110, \"Highest Charting Position\": 43, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Like It Is\", \"Streams\": 4463865, \"Artist\": \"Kygo, Zara Larsson, Tyga\", \"Artist Followers\": 7593792.0, \"Song ID\": \"3frUvGrmGcay91lvFbOgsN\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 68.0, \"Danceability\": 0.794, \"Energy\": 0.728, \"Loudness\": -6.759, \"Speechiness\": 0.114, \"Acousticness\": 0.121, \"Liveness\": 0.227, \"Tempo\": 105.024, \"Duration (ms)\": 183067.0, \"Valence\": 0.36, \"Chord\": \"C#/Db\"}, {\"Index\": 1111, \"Highest Charting Position\": 15, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"My Oh My (feat. DaBaby)\", \"Streams\": 4413457, \"Artist\": \"Camila Cabello\", \"Artist Followers\": 22698747.0, \"Song ID\": \"3yOlyBJuViE2YSGn3nVE1K\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.724, \"Energy\": 0.491, \"Loudness\": -6.024, \"Speechiness\": 0.0296, \"Acousticness\": 0.018, \"Liveness\": 0.0887, \"Tempo\": 105.046, \"Duration (ms)\": 170746.0, \"Valence\": 0.383, \"Chord\": \"G#/Ab\"}, {\"Index\": 1112, \"Highest Charting Position\": 161, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Let Me Down Slowly\", \"Streams\": 4393932, \"Artist\": \"Alec Benjamin\", \"Artist Followers\": 2808285.0, \"Song ID\": \"2qxmye6gAegTMjLKEBoR3d\", \"Genre\": \"['alt z', 'electropop', 'pop']\", \"Release Date\": \"2018-11-16\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.652, \"Energy\": 0.557, \"Loudness\": -5.714, \"Speechiness\": 0.0318, \"Acousticness\": 0.74, \"Liveness\": 0.124, \"Tempo\": 150.073, \"Duration (ms)\": 169354.0, \"Valence\": 0.483, \"Chord\": \"C#/Db\"}, {\"Index\": 1113, \"Highest Charting Position\": 22, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"BELIEVE IT\", \"Streams\": 4361970, \"Artist\": \"PARTYNEXTDOOR, Rihanna\", \"Artist Followers\": 3129968.0, \"Song ID\": \"4HDCLYli2SUdkq9OjmvhSD\", \"Genre\": \"['pop', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap', 'urban contemporary']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 74.0, \"Danceability\": 0.43, \"Energy\": 0.7, \"Loudness\": -5.35, \"Speechiness\": 0.264, \"Acousticness\": 0.0902, \"Liveness\": 0.216, \"Tempo\": 158.373, \"Duration (ms)\": 183219.0, \"Valence\": 0.731, \"Chord\": \"F#/Gb\"}, {\"Index\": 1114, \"Highest Charting Position\": 86, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Boot\", \"Streams\": 6375562, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"12KENAKQY5JvAsRURN7TzB\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2020-06-05--2020-06-12\", \"Popularity\": 54.0, \"Danceability\": 0.534, \"Energy\": 0.565, \"Loudness\": -7.546, \"Speechiness\": 0.307, \"Acousticness\": 0.0627, \"Liveness\": 0.112, \"Tempo\": 194.034, \"Duration (ms)\": 193360.0, \"Valence\": 0.529, \"Chord\": \"G#/Ab\"}, {\"Index\": 1115, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Riot\", \"Streams\": 5163633, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"4aOOExMBUyxKnEYb39SrTg\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2020-06-01\", \"Weeks Charted\": \"2020-06-05--2020-06-12\", \"Popularity\": 70.0, \"Danceability\": 0.509, \"Energy\": 0.542, \"Loudness\": -8.027, \"Speechiness\": 0.442, \"Acousticness\": 0.019, \"Liveness\": 0.23, \"Tempo\": 97.767, \"Duration (ms)\": 78681.0, \"Valence\": 0.151, \"Chord\": \"D#/Eb\"}, {\"Index\": 1116, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"VALLA NEIN (feat. Luciano)\", \"Streams\": 5029858, \"Artist\": \"KC Rebell, Summer Cem\", \"Artist Followers\": 1101597.0, \"Song ID\": \"2rxxXYtTIFKyrhJpofeoIX\", \"Genre\": \"['german drill', 'german hip hop']\", \"Release Date\": \"2020-06-05\", \"Weeks Charted\": \"2020-06-05--2020-06-12\", \"Popularity\": 55.0, \"Danceability\": 0.761, \"Energy\": 0.657, \"Loudness\": -7.246, \"Speechiness\": 0.138, \"Acousticness\": 0.114, \"Liveness\": 0.356, \"Tempo\": 135.909, \"Duration (ms)\": 182040.0, \"Valence\": 0.589, \"Chord\": \"A#/Bb\"}, {\"Index\": 1117, \"Highest Charting Position\": 27, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"I\\u2019m Ready (with Demi Lovato)\", \"Streams\": 4764355, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"1fipvP2zmef6vN2IwXfJhY\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-04-16\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 68.0, \"Danceability\": 0.501, \"Energy\": 0.674, \"Loudness\": -6.363, \"Speechiness\": 0.0408, \"Acousticness\": 0.00346, \"Liveness\": 0.282, \"Tempo\": 155.051, \"Duration (ms)\": 200838.0, \"Valence\": 0.152, \"Chord\": \"F\"}, {\"Index\": 1118, \"Highest Charting Position\": 63, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"This Is America\", \"Streams\": 4727415, \"Artist\": \"Childish Gambino\", \"Artist Followers\": 8099554.0, \"Song ID\": \"0b9oOr2ZgvyQu88wzixux9\", \"Genre\": \"['atl hip hop', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2018-05-06\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 71.0, \"Danceability\": 0.854, \"Energy\": 0.463, \"Loudness\": -6.159, \"Speechiness\": 0.137, \"Acousticness\": 0.117, \"Liveness\": 0.354, \"Tempo\": 120.024, \"Duration (ms)\": 225773.0, \"Valence\": 0.549, \"Chord\": \"F\"}, {\"Index\": 1119, \"Highest Charting Position\": 33, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Fantasias\", \"Streams\": 4432324, \"Artist\": \"Rauw Alejandro, Farruko\", \"Artist Followers\": 6096559.0, \"Song ID\": \"6mAN61JH0dzyZpWslS11jy\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2019-08-29\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.879, \"Energy\": 0.703, \"Loudness\": -4.219, \"Speechiness\": 0.0701, \"Acousticness\": 0.143, \"Liveness\": 0.0569, \"Tempo\": 94.004, \"Duration (ms)\": 199711.0, \"Valence\": 0.788, \"Chord\": \"C#/Db\"}, {\"Index\": 1120, \"Highest Charting Position\": 60, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"BAD CON NICKY\", \"Streams\": 4432210, \"Artist\": \"Bad Bunny, Nicky Jam\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5bmSver2b3ZXyuyLKtgnFI\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 71.0, \"Danceability\": 0.59, \"Energy\": 0.729, \"Loudness\": -4.95, \"Speechiness\": 0.0893, \"Acousticness\": 0.321, \"Liveness\": 0.659, \"Tempo\": 93.094, \"Duration (ms)\": 202240.0, \"Valence\": 0.712, \"Chord\": \"G\"}, {\"Index\": 1121, \"Highest Charting Position\": 145, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"If I Can't Have You\", \"Streams\": 4364166, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 33893352.0, \"Song ID\": \"6LsAAHotRLMOHfCsSfYCsz\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2019-05-03\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.692, \"Energy\": 0.809, \"Loudness\": -4.198, \"Speechiness\": 0.0602, \"Acousticness\": 0.524, \"Liveness\": 0.147, \"Tempo\": 123.911, \"Duration (ms)\": 190800.0, \"Valence\": 0.864, \"Chord\": \"D\"}, {\"Index\": 1122, \"Highest Charting Position\": 27, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"What A Man Gotta Do\", \"Streams\": 4360660, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"4wNIkl5XGiAACjFBlDWuSd\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 77.0, \"Danceability\": 0.852, \"Energy\": 0.698, \"Loudness\": -7.206, \"Speechiness\": 0.0629, \"Acousticness\": 0.00839, \"Liveness\": 0.0773, \"Tempo\": 113.039, \"Duration (ms)\": 180645.0, \"Valence\": 0.324, \"Chord\": \"A\"}, {\"Index\": 1123, \"Highest Charting Position\": 50, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Callaita\", \"Streams\": 4350496, \"Artist\": \"Bad Bunny, Tainy\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2TH65lNHgvLxCKXM3apjxI\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-05-31\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.61, \"Energy\": 0.624, \"Loudness\": -4.773, \"Speechiness\": 0.309, \"Acousticness\": 0.6, \"Liveness\": 0.243, \"Tempo\": 176.169, \"Duration (ms)\": 250534.0, \"Valence\": 0.244, \"Chord\": \"D\"}, {\"Index\": 1124, \"Highest Charting Position\": 51, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Solitaires (feat. Travis Scott)\", \"Streams\": 4334669, \"Artist\": \"Future\", \"Artist Followers\": 10491105.0, \"Song ID\": \"4kfeRwpq5KUaqTkgi4TbDF\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 67.0, \"Danceability\": 0.691, \"Energy\": 0.632, \"Loudness\": -7.598, \"Speechiness\": 0.0513, \"Acousticness\": 0.122, \"Liveness\": 0.0646, \"Tempo\": 169.982, \"Duration (ms)\": 205666.0, \"Valence\": 0.488, \"Chord\": \"C#/Db\"}, {\"Index\": 1125, \"Highest Charting Position\": 137, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"XO Tour Llif3\", \"Streams\": 4314080, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7GX5flRQZVHRAGd6B4TmDO\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2017-08-25\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-08--2020-05-15\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 82.0, \"Danceability\": 0.732, \"Energy\": 0.75, \"Loudness\": -6.366, \"Speechiness\": 0.231, \"Acousticness\": 0.00264, \"Liveness\": 0.109, \"Tempo\": 155.096, \"Duration (ms)\": 182707.0, \"Valence\": 0.401, \"Chord\": \"B\"}, {\"Index\": 1126, \"Highest Charting Position\": 189, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"changes\", \"Streams\": 4299334, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"7AFASza1mXqntmGtbxXprO\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2018-03-16\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 81.0, \"Danceability\": 0.669, \"Energy\": 0.308, \"Loudness\": -10.068, \"Speechiness\": 0.029, \"Acousticness\": 0.883, \"Liveness\": 0.0984, \"Tempo\": 64.934, \"Duration (ms)\": 121887.0, \"Valence\": 0.52, \"Chord\": \"B\"}, {\"Index\": 1127, \"Highest Charting Position\": 66, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Suicidal (Remix) [feat. Juice WRLD]\", \"Streams\": 4296154, \"Artist\": \"YNW Melly\", \"Artist Followers\": 6332535.0, \"Song ID\": \"4S2uhQE8L9V6p7rj7SiauJ\", \"Genre\": \"['melodic rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 76.0, \"Danceability\": 0.655, \"Energy\": 0.441, \"Loudness\": -5.245, \"Speechiness\": 0.0629, \"Acousticness\": 0.474, \"Liveness\": 0.099, \"Tempo\": 139.957, \"Duration (ms)\": 225857.0, \"Valence\": 0.273, \"Chord\": \"A\"}, {\"Index\": 1128, \"Highest Charting Position\": 30, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Level of Concern\", \"Streams\": 4252898, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20829526.0, \"Song ID\": \"6xZ4Q2k2ompmDppyeESIY8\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 72.0, \"Danceability\": 0.754, \"Energy\": 0.583, \"Loudness\": -7.34, \"Speechiness\": 0.0432, \"Acousticness\": 0.32, \"Liveness\": 0.144, \"Tempo\": 122.012, \"Duration (ms)\": 220051.0, \"Valence\": 0.77, \"Chord\": \"E\"}, {\"Index\": 1129, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Alice\", \"Streams\": 10342277, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"41A89rj3GoMG6ktN37L7PG\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 64.0, \"Danceability\": 0.723, \"Energy\": 0.88, \"Loudness\": -4.287, \"Speechiness\": 0.038, \"Acousticness\": 0.00334, \"Liveness\": 0.0632, \"Tempo\": 123.036, \"Duration (ms)\": 177600.0, \"Valence\": 0.323, \"Chord\": \"B\"}, {\"Index\": 1130, \"Highest Charting Position\": 58, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Free Woman\", \"Streams\": 9266945, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"4L6ihclQPu1hqP9r3WNJjQ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 63.0, \"Danceability\": 0.731, \"Energy\": 0.927, \"Loudness\": -3.634, \"Speechiness\": 0.0781, \"Acousticness\": 0.0228, \"Liveness\": 0.187, \"Tempo\": 119.006, \"Duration (ms)\": 191467.0, \"Valence\": 0.478, \"Chord\": \"C\"}, {\"Index\": 1131, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Fun Tonight\", \"Streams\": 7907329, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"6hyQVqfHFvsJDjcmj4qrHf\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.645, \"Energy\": 0.923, \"Loudness\": -4.262, \"Speechiness\": 0.0725, \"Acousticness\": 0.364, \"Liveness\": 0.14, \"Tempo\": 117.945, \"Duration (ms)\": 173427.0, \"Valence\": 0.323, \"Chord\": \"B\"}, {\"Index\": 1132, \"Highest Charting Position\": 75, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Sine From Above (with Elton John)\", \"Streams\": 7734309, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"0zzsyWc45eUcSjw4FNHxeN\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 60.0, \"Danceability\": 0.642, \"Energy\": 0.792, \"Loudness\": -5.746, \"Speechiness\": 0.0488, \"Acousticness\": 0.158, \"Liveness\": 0.68, \"Tempo\": 122.965, \"Duration (ms)\": 244880.0, \"Valence\": 0.0903, \"Chord\": \"C\"}, {\"Index\": 1133, \"Highest Charting Position\": 77, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Enigma\", \"Streams\": 7695566, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"7JDbfYUHjDzQPFSDh5lzGs\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 59.0, \"Danceability\": 0.669, \"Energy\": 0.804, \"Loudness\": -4.035, \"Speechiness\": 0.036, \"Acousticness\": 0.0306, \"Liveness\": 0.694, \"Tempo\": 116.001, \"Duration (ms)\": 179760.0, \"Valence\": 0.184, \"Chord\": \"C\"}, {\"Index\": 1134, \"Highest Charting Position\": 79, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Replay\", \"Streams\": 7479618, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"7sKbyYeJnITO1Eh9xd0lKd\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 63.0, \"Danceability\": 0.658, \"Energy\": 0.878, \"Loudness\": -3.875, \"Speechiness\": 0.123, \"Acousticness\": 0.00792, \"Liveness\": 0.944, \"Tempo\": 122.015, \"Duration (ms)\": 186653.0, \"Valence\": 0.683, \"Chord\": \"C#/Db\"}, {\"Index\": 1135, \"Highest Charting Position\": 80, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Plastic Doll\", \"Streams\": 7451452, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"3CidPLqWXqgesJlwYVJZdy\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.743, \"Energy\": 0.853, \"Loudness\": -4.842, \"Speechiness\": 0.04, \"Acousticness\": 0.0019, \"Liveness\": 0.0872, \"Tempo\": 121.028, \"Duration (ms)\": 221667.0, \"Valence\": 0.422, \"Chord\": \"C\"}, {\"Index\": 1136, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Chromatica II\", \"Streams\": 7136521, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"0oQc0F6KUE7QY7k5TU6bic\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.184, \"Energy\": 0.297, \"Loudness\": -14.534, \"Speechiness\": 0.0359, \"Acousticness\": 0.473, \"Liveness\": 0.527, \"Tempo\": 75.824, \"Duration (ms)\": 41867.0, \"Valence\": 0.113, \"Chord\": \"D\"}, {\"Index\": 1137, \"Highest Charting Position\": 91, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Babylon\", \"Streams\": 6996402, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"5DttNeiizFqWUON9hZBqTY\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 61.0, \"Danceability\": 0.698, \"Energy\": 0.799, \"Loudness\": -4.372, \"Speechiness\": 0.0342, \"Acousticness\": 0.0129, \"Liveness\": 0.215, \"Tempo\": 115.957, \"Duration (ms)\": 161733.0, \"Valence\": 0.351, \"Chord\": \"D\"}, {\"Index\": 1138, \"Highest Charting Position\": 93, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Chromatica I\", \"Streams\": 6630385, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"0oQc0F6KUE7QY7k5TU6bic\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.184, \"Energy\": 0.297, \"Loudness\": -14.534, \"Speechiness\": 0.0359, \"Acousticness\": 0.473, \"Liveness\": 0.527, \"Tempo\": 75.824, \"Duration (ms)\": 41867.0, \"Valence\": 0.113, \"Chord\": \"D\"}, {\"Index\": 1139, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"1000 Doves\", \"Streams\": 6069544, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"62hTXlVQacy3pjBW4ntRPl\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.668, \"Energy\": 0.826, \"Loudness\": -4.466, \"Speechiness\": 0.0383, \"Acousticness\": 0.0236, \"Liveness\": 0.474, \"Tempo\": 122.973, \"Duration (ms)\": 215480.0, \"Valence\": 0.388, \"Chord\": \"A\"}, {\"Index\": 1140, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Broken Glass\", \"Streams\": 5867930, \"Artist\": \"Kygo, Kim Petras\", \"Artist Followers\": 7593792.0, \"Song ID\": \"78ldtCaBRJVp2i91B715L0\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 66.0, \"Danceability\": 0.526, \"Energy\": 0.633, \"Loudness\": -7.002, \"Speechiness\": 0.134, \"Acousticness\": 0.372, \"Liveness\": 0.129, \"Tempo\": 171.044, \"Duration (ms)\": 203947.0, \"Valence\": 0.272, \"Chord\": \"G\"}, {\"Index\": 1141, \"Highest Charting Position\": 131, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"In meinem Benz\", \"Streams\": 5494500, \"Artist\": \"AK AUSSERKONTROLLE, Bonez MC\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 1142, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"FLY\", \"Streams\": 4681054, \"Artist\": \"KC Rebell, Summer Cem\", \"Artist Followers\": 1101597.0, \"Song ID\": \"1WoM4mof0Nl1xPtwf6h6ow\", \"Genre\": \"['german drill', 'german hip hop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 59.0, \"Danceability\": 0.835, \"Energy\": 0.596, \"Loudness\": -6.637, \"Speechiness\": 0.297, \"Acousticness\": 0.137, \"Liveness\": 0.164, \"Tempo\": 100.706, \"Duration (ms)\": 174893.0, \"Valence\": 0.897, \"Chord\": \"F\"}, {\"Index\": 1143, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"SKRR\", \"Streams\": 4629320, \"Artist\": \"KALIM, Ufo361\", \"Artist Followers\": 218931.0, \"Song ID\": \"2J0adlQth373uw9y0yqWAz\", \"Genre\": \"['german hip hop', 'german trap', 'german underground rap', 'hamburg hip hop']\", \"Release Date\": \"2020-09-24\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 60.0, \"Danceability\": 0.803, \"Energy\": 0.649, \"Loudness\": -6.599, \"Speechiness\": 0.132, \"Acousticness\": 0.163, \"Liveness\": 0.152, \"Tempo\": 125.038, \"Duration (ms)\": 119040.0, \"Valence\": 0.584, \"Chord\": \"A#/Bb\"}, {\"Index\": 1144, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"T.D (Lil Yachty & Tierra Whack feat. A$AP Rocky & Tyler, The Creator)\", \"Streams\": 4601709, \"Artist\": \"Lil Yachty\", \"Artist Followers\": 7358720.0, \"Song ID\": \"0gO3E51A3fqp0ypJ26QbVP\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap', 'underground hip hop', 'viral rap']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 66.0, \"Danceability\": 0.784, \"Energy\": 0.632, \"Loudness\": -6.083, \"Speechiness\": 0.347, \"Acousticness\": 0.156, \"Liveness\": 0.605, \"Tempo\": 124.603, \"Duration (ms)\": 232839.0, \"Valence\": 0.746, \"Chord\": \"A#/Bb\"}, {\"Index\": 1145, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Oprah's Bank Account (Lil Yachty & DaBaby feat. Drake)\", \"Streams\": 4598294, \"Artist\": \"Lil Yachty\", \"Artist Followers\": 7358720.0, \"Song ID\": \"7wsmIIm0xWmtP7TmACXkJn\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap', 'underground hip hop', 'viral rap']\", \"Release Date\": \"2020-03-09\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 69.0, \"Danceability\": 0.836, \"Energy\": 0.617, \"Loudness\": -4.363, \"Speechiness\": 0.0534, \"Acousticness\": 0.17, \"Liveness\": 0.319, \"Tempo\": 138.066, \"Duration (ms)\": 206702.0, \"Valence\": 0.866, \"Chord\": \"C\"}, {\"Index\": 1146, \"Highest Charting Position\": 78, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Roadrunner\", \"Streams\": 4596162, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"0atjNG0rNW2m6zPaiK4Co7\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 64.0, \"Danceability\": 0.804, \"Energy\": 0.606, \"Loudness\": -9.045, \"Speechiness\": 0.242, \"Acousticness\": 0.137, \"Liveness\": 0.111, \"Tempo\": 99.024, \"Duration (ms)\": 149028.0, \"Valence\": 0.247, \"Chord\": \"G\"}, {\"Index\": 1147, \"Highest Charting Position\": 99, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Freedom\", \"Streams\": 4573723, \"Artist\": \"Kygo, Zak Abel\", \"Artist Followers\": 7593792.0, \"Song ID\": \"5Gj1wG8b12VQdEd3hUuSwo\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-05-29--2020-06-05\\n2020-04-17--2020-04-24\", \"Popularity\": 72.0, \"Danceability\": 0.715, \"Energy\": 0.635, \"Loudness\": -6.591, \"Speechiness\": 0.0791, \"Acousticness\": 0.127, \"Liveness\": 0.0862, \"Tempo\": 112.887, \"Duration (ms)\": 198635.0, \"Valence\": 0.39, \"Chord\": \"G\"}, {\"Index\": 1148, \"Highest Charting Position\": 45, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Fame\", \"Streams\": 4556947, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"3goH7O78TLkV9RhCAyM4AT\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 62.0, \"Danceability\": 0.811, \"Energy\": 0.645, \"Loudness\": -8.008, \"Speechiness\": 0.104, \"Acousticness\": 0.184, \"Liveness\": 0.103, \"Tempo\": 129.967, \"Duration (ms)\": 173761.0, \"Valence\": 0.474, \"Chord\": \"C#/Db\"}, {\"Index\": 1149, \"Highest Charting Position\": 55, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Daechwita\", \"Streams\": 8908179, \"Artist\": \"Agust D\", \"Artist Followers\": 5564366.0, \"Song ID\": \"0H4ugk6rhnXmTl47ayy9O5\", \"Genre\": \"['k-rap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 77.0, \"Danceability\": 0.65, \"Energy\": 0.827, \"Loudness\": -4.014, \"Speechiness\": 0.0599, \"Acousticness\": 0.0229, \"Liveness\": 0.121, \"Tempo\": 144.995, \"Duration (ms)\": 225668.0, \"Valence\": 0.223, \"Chord\": \"G#/Ab\"}, {\"Index\": 1150, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"COOLER THAN A BITCH (feat. Roddy Ricch)\", \"Streams\": 6642144, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"5LHHKZOwV8XW4LJP2C64mw\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 67.0, \"Danceability\": 0.837, \"Energy\": 0.586, \"Loudness\": -8.521, \"Speechiness\": 0.0807, \"Acousticness\": 0.281, \"Liveness\": 0.134, \"Tempo\": 117.066, \"Duration (ms)\": 197000.0, \"Valence\": 0.618, \"Chord\": \"B\"}, {\"Index\": 1151, \"Highest Charting Position\": 90, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"In Your Eyes (with Doja Cat) - Remix\", \"Streams\": 6511008, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"0UnTaVkntyh3vqvLEvbpQx\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-05-21\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 67.0, \"Danceability\": 0.679, \"Energy\": 0.731, \"Loudness\": -5.522, \"Speechiness\": 0.0319, \"Acousticness\": 0.00518, \"Liveness\": 0.0614, \"Tempo\": 99.984, \"Duration (ms)\": 237912.0, \"Valence\": 0.727, \"Chord\": \"G\"}, {\"Index\": 1152, \"Highest Charting Position\": 92, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"WUNNA\", \"Streams\": 6384306, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"0y7Ao3CVJsyKFmqdjutiIF\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 60.0, \"Danceability\": 0.89, \"Energy\": 0.455, \"Loudness\": -9.0, \"Speechiness\": 0.255, \"Acousticness\": 0.0217, \"Liveness\": 0.11, \"Tempo\": 148.009, \"Duration (ms)\": 158240.0, \"Valence\": 0.313, \"Chord\": \"C\"}, {\"Index\": 1153, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Komm Komm\", \"Streams\": 5552890, \"Artist\": \"Capital Bra\", \"Artist Followers\": 4093115.0, \"Song ID\": \"3US6RbELvvrPw3DcvtJmis\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-05-21\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 53.0, \"Danceability\": 0.485, \"Energy\": 0.793, \"Loudness\": -3.836, \"Speechiness\": 0.426, \"Acousticness\": 0.251, \"Liveness\": 0.146, \"Tempo\": 87.629, \"Duration (ms)\": 160667.0, \"Valence\": 0.371, \"Chord\": \"B\"}, {\"Index\": 1154, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"TOP FLOOR (feat. Travis Scott)\", \"Streams\": 5193309, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"4YhJ3a6kBPGJWX4Ek77sDd\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 63.0, \"Danceability\": 0.823, \"Energy\": 0.504, \"Loudness\": -8.65, \"Speechiness\": 0.16, \"Acousticness\": 0.206, \"Liveness\": 0.417, \"Tempo\": 112.985, \"Duration (ms)\": 169907.0, \"Valence\": 0.481, \"Chord\": \"G#/Ab\"}, {\"Index\": 1155, \"Highest Charting Position\": 54, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Goodbyes (Feat. Young Thug)\", \"Streams\": 5134161, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"0t3ZvGKlmYmVsDzBJAXK8C\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.548, \"Energy\": 0.653, \"Loudness\": -3.875, \"Speechiness\": 0.081, \"Acousticness\": 0.456, \"Liveness\": 0.103, \"Tempo\": 150.068, \"Duration (ms)\": 174853.0, \"Valence\": 0.163, \"Chord\": \"F\"}, {\"Index\": 1156, \"Highest Charting Position\": 59, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"CANCI\\u00d3N CON YANDEL\", \"Streams\": 5132247, \"Artist\": \"Yandel, Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3pm4XtcsRIFFtH2UErk62R\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 76.0, \"Danceability\": 0.75, \"Energy\": 0.741, \"Loudness\": -4.43, \"Speechiness\": 0.402, \"Acousticness\": 0.447, \"Liveness\": 0.121, \"Tempo\": 79.968, \"Duration (ms)\": 209180.0, \"Valence\": 0.495, \"Chord\": \"A\"}, {\"Index\": 1157, \"Highest Charting Position\": 92, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"X (with KAROL G)\", \"Streams\": 5018592, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"77fvnWALKJR0ws1VUx09CY\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 70.0, \"Danceability\": 0.715, \"Energy\": 0.827, \"Loudness\": -5.09, \"Speechiness\": 0.0617, \"Acousticness\": 0.0485, \"Liveness\": 0.321, \"Tempo\": 117.977, \"Duration (ms)\": 185277.0, \"Valence\": 0.75, \"Chord\": \"E\"}, {\"Index\": 1158, \"Highest Charting Position\": 56, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"M\\u00c1S DE UNA CITA\", \"Streams\": 4987116, \"Artist\": \"Bad Bunny, Zion & Lennox\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4EJHKSnHENfjOxXWryyNtL\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 67.0, \"Danceability\": 0.865, \"Energy\": 0.5, \"Loudness\": -10.805, \"Speechiness\": 0.0861, \"Acousticness\": 0.0122, \"Liveness\": 0.098, \"Tempo\": 92.976, \"Duration (ms)\": 183520.0, \"Valence\": 0.317, \"Chord\": \"F\"}, {\"Index\": 1159, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Together\", \"Streams\": 4861870, \"Artist\": \"Sia\", \"Artist Followers\": 20528724.0, \"Song ID\": \"5id3Rqn7SPj1LX4FfY4nGz\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'pop']\", \"Release Date\": \"2020-05-20\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 71.0, \"Danceability\": 0.521, \"Energy\": 0.877, \"Loudness\": -5.444, \"Speechiness\": 0.0683, \"Acousticness\": 0.0132, \"Liveness\": 0.0929, \"Tempo\": 180.007, \"Duration (ms)\": 205208.0, \"Valence\": 0.199, \"Chord\": \"G\"}, {\"Index\": 1160, \"Highest Charting Position\": 62, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"eight(Prod.&Feat. SUGA of BTS)\", \"Streams\": 4764954, \"Artist\": \"IU\", \"Artist Followers\": 4939593.0, \"Song ID\": \"0pYacDCZuRhcrwGUA5nTBe\", \"Genre\": \"['k-pop']\", \"Release Date\": \"2020-05-06\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 75.0, \"Danceability\": 0.676, \"Energy\": 0.869, \"Loudness\": -1.573, \"Speechiness\": 0.0423, \"Acousticness\": 0.115, \"Liveness\": 0.132, \"Tempo\": 120.029, \"Duration (ms)\": 167573.0, \"Valence\": 0.594, \"Chord\": \"C#/Db\"}, {\"Index\": 1161, \"Highest Charting Position\": 16, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"You should be sad\", \"Streams\": 4761908, \"Artist\": \"Halsey\", \"Artist Followers\": 15663384.0, \"Song ID\": \"7lidXGPXPYLNThITAOTlkK\", \"Genre\": \"['dance pop', 'electropop', 'etherpop', 'indie poptimism', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 76.0, \"Danceability\": 0.591, \"Energy\": 0.585, \"Loudness\": -6.35, \"Speechiness\": 0.0277, \"Acousticness\": 0.143, \"Liveness\": 0.109, \"Tempo\": 110.94, \"Duration (ms)\": 205473.0, \"Valence\": 0.324, \"Chord\": \"D\"}, {\"Index\": 1162, \"Highest Charting Position\": 54, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"CITY OF ANGELS\", \"Streams\": 4645541, \"Artist\": \"24kGoldn\", \"Artist Followers\": 1276406.0, \"Song ID\": \"6ap9lSRJ0iLriGLqoJ44cq\", \"Genre\": \"['cali rap']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 76.0, \"Danceability\": 0.686, \"Energy\": 0.541, \"Loudness\": -4.993, \"Speechiness\": 0.0493, \"Acousticness\": 0.042, \"Liveness\": 0.0675, \"Tempo\": 120.082, \"Duration (ms)\": 112493.0, \"Valence\": 0.724, \"Chord\": \"C\"}, {\"Index\": 1163, \"Highest Charting Position\": 98, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Astronomia\", \"Streams\": 4642284, \"Artist\": \"Vicetone, Tony Igy\", \"Artist Followers\": 378114.0, \"Song ID\": \"3hWfKBt3n7j1xqIy6LA5ve\", \"Genre\": \"['edm', 'electro house', 'pop dance', 'pop edm', 'progressive electro house', 'tropical house']\", \"Release Date\": \"2016-09-16\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 71.0, \"Danceability\": 0.653, \"Energy\": 0.945, \"Loudness\": -2.634, \"Speechiness\": 0.096, \"Acousticness\": 0.00561, \"Liveness\": 0.439, \"Tempo\": 126.093, \"Duration (ms)\": 198095.0, \"Valence\": 0.326, \"Chord\": \"F\"}, {\"Index\": 1164, \"Highest Charting Position\": 7, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"After Hours\", \"Streams\": 4559855, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"2p8IUWQDrpjuFltbdgLOag\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 75.0, \"Danceability\": 0.664, \"Energy\": 0.572, \"Loudness\": -6.099, \"Speechiness\": 0.0305, \"Acousticness\": 0.0811, \"Liveness\": 0.121, \"Tempo\": 108.959, \"Duration (ms)\": 361027.0, \"Valence\": 0.143, \"Chord\": \"F\"}, {\"Index\": 1165, \"Highest Charting Position\": 51, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"BUTTERFLY EFFECT\", \"Streams\": 4537762, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"2cYqizR4lgvp4Qu6IQ3qGN\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2018-08-03\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 79.0, \"Danceability\": 0.763, \"Energy\": 0.628, \"Loudness\": -5.85, \"Speechiness\": 0.05, \"Acousticness\": 0.0531, \"Liveness\": 0.114, \"Tempo\": 140.958, \"Duration (ms)\": 190557.0, \"Valence\": 0.193, \"Chord\": \"B\"}, {\"Index\": 1166, \"Highest Charting Position\": 74, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Never Seen the Rain\", \"Streams\": 4473968, \"Artist\": \"Tones And I\", \"Artist Followers\": 1251372.0, \"Song ID\": \"1xUCDewhwnORlcFflAgml0\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.742, \"Energy\": 0.464, \"Loudness\": -5.624, \"Speechiness\": 0.0318, \"Acousticness\": 0.425, \"Liveness\": 0.284, \"Tempo\": 92.107, \"Duration (ms)\": 200742.0, \"Valence\": 0.281, \"Chord\": \"F#/Gb\"}, {\"Index\": 1167, \"Highest Charting Position\": 120, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Sigues Con El - Remix\", \"Streams\": 4440738, \"Artist\": \"Arcangel, Sech, Romeo Santos\", \"Artist Followers\": 6671084.0, \"Song ID\": \"4Pu0a2TuHOYtI4CCE3HEXI\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-04-10\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 69.0, \"Danceability\": 0.747, \"Energy\": 0.693, \"Loudness\": -2.97, \"Speechiness\": 0.298, \"Acousticness\": 0.102, \"Liveness\": 0.0872, \"Tempo\": 175.994, \"Duration (ms)\": 189567.0, \"Valence\": 0.736, \"Chord\": \"C#/Db\"}, {\"Index\": 1168, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"ANGELS & DEMONS\", \"Streams\": 4435538, \"Artist\": \"jxdn\", \"Artist Followers\": 799682.0, \"Song ID\": \"3mkz6eI4Sram8UhO3teU76\", \"Genre\": \"[]\", \"Release Date\": \"2021-07-02\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 72.0, \"Danceability\": 0.554, \"Energy\": 0.8, \"Loudness\": -3.936, \"Speechiness\": 0.0395, \"Acousticness\": 0.119, \"Liveness\": 0.629, \"Tempo\": 115.056, \"Duration (ms)\": 160120.0, \"Valence\": 0.463, \"Chord\": \"G#/Ab\"}, {\"Index\": 1169, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Conf\\u00eda\", \"Streams\": 4419295, \"Artist\": \"Sech, Daddy Yankee\", \"Artist Followers\": 8766508.0, \"Song ID\": \"5kbps8unnGH4raN5WduZuq\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-21\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 62.0, \"Danceability\": 0.722, \"Energy\": 0.757, \"Loudness\": -3.592, \"Speechiness\": 0.0782, \"Acousticness\": 0.17, \"Liveness\": 0.0657, \"Tempo\": 167.987, \"Duration (ms)\": 202308.0, \"Valence\": 0.763, \"Chord\": \"C\"}, {\"Index\": 1170, \"Highest Charting Position\": 44, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Mu\\u00e9velo\", \"Streams\": 4407165, \"Artist\": \"Nicky Jam, Daddy Yankee\", \"Artist Followers\": 14831925.0, \"Song ID\": \"4VgYtXCVJ7IbWAZ5ryfvEQ\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-01-08\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 72.0, \"Danceability\": 0.594, \"Energy\": 0.808, \"Loudness\": -2.409, \"Speechiness\": 0.0489, \"Acousticness\": 0.415, \"Liveness\": 0.565, \"Tempo\": 188.09, \"Duration (ms)\": 194892.0, \"Valence\": 0.919, \"Chord\": \"G\"}, {\"Index\": 1171, \"Highest Charting Position\": 105, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"All Bad (feat. Lil Uzi Vert)\", \"Streams\": 6194224, \"Artist\": \"Future\", \"Artist Followers\": 10491105.0, \"Song ID\": \"021lWIHJrURZrmvYQ1xcM8\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 60.0, \"Danceability\": 0.931, \"Energy\": 0.667, \"Loudness\": -7.043, \"Speechiness\": 0.318, \"Acousticness\": 0.0144, \"Liveness\": 0.15, \"Tempo\": 142.039, \"Duration (ms)\": 207739.0, \"Valence\": 0.667, \"Chord\": \"F#/Gb\"}, {\"Index\": 1172, \"Highest Charting Position\": 12, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Pain 1993 (with Playboi Carti)\", \"Streams\": 6085143, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"6Kj17Afjo1OKJYpf5VzCeo\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 67.0, \"Danceability\": 0.825, \"Energy\": 0.373, \"Loudness\": -5.532, \"Speechiness\": 0.108, \"Acousticness\": 0.163, \"Liveness\": 0.368, \"Tempo\": 77.271, \"Duration (ms)\": 149078.0, \"Valence\": 0.12, \"Chord\": \"F\"}, {\"Index\": 1173, \"Highest Charting Position\": 110, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Trillionaire (feat. Youngboy Never Broke Again)\", \"Streams\": 6057848, \"Artist\": \"Future\", \"Artist Followers\": 10491105.0, \"Song ID\": \"740kQ8xwSGloumdiKR5Cwz\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 61.0, \"Danceability\": 0.768, \"Energy\": 0.526, \"Loudness\": -7.182, \"Speechiness\": 0.209, \"Acousticness\": 0.237, \"Liveness\": 0.139, \"Tempo\": 139.999, \"Duration (ms)\": 167552.0, \"Valence\": 0.473, \"Chord\": \"C\"}, {\"Index\": 1174, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Go Stupid\", \"Streams\": 5464816, \"Artist\": \"Polo G, Stunna 4 Vegas, NLE Choppa, Mike WiLL Made-It\", \"Artist Followers\": 4849204.0, \"Song ID\": \"4PklAHGXT5ityno3IA8SKd\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 74.0, \"Danceability\": 0.92, \"Energy\": 0.833, \"Loudness\": -3.18, \"Speechiness\": 0.253, \"Acousticness\": 0.0277, \"Liveness\": 0.0596, \"Tempo\": 141.034, \"Duration (ms)\": 165726.0, \"Valence\": 0.645, \"Chord\": \"C#/Db\"}, {\"Index\": 1175, \"Highest Charting Position\": 149, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"A Gente Fez Amor - Ao Vivo\", \"Streams\": 5006457, \"Artist\": \"Gusttavo Lima\", \"Artist Followers\": 12981319.0, \"Song ID\": \"3tv697PZNnaQN0Mn2zGhS5\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2019-12-05\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-02-07--2020-02-14\\n2020-01-03--2020-01-10\", \"Popularity\": 66.0, \"Danceability\": 0.794, \"Energy\": 0.937, \"Loudness\": -2.44, \"Speechiness\": 0.0336, \"Acousticness\": 0.366, \"Liveness\": 0.962, \"Tempo\": 134.012, \"Duration (ms)\": 237517.0, \"Valence\": 0.826, \"Chord\": \"G#/Ab\"}, {\"Index\": 1176, \"Highest Charting Position\": 173, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Racks 2 Skinny\", \"Streams\": 4729629, \"Artist\": \"Migos\", \"Artist Followers\": 11692972.0, \"Song ID\": \"568OIKgeHyGRD3uWR44JbO\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-11\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 61.0, \"Danceability\": 0.814, \"Energy\": 0.584, \"Loudness\": -5.425, \"Speechiness\": 0.0819, \"Acousticness\": 0.00839, \"Liveness\": 0.0646, \"Tempo\": 141.016, \"Duration (ms)\": 178025.0, \"Valence\": 0.405, \"Chord\": \"C#/Db\"}, {\"Index\": 1177, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Be Something (feat. Lil Baby)\", \"Streams\": 4687909, \"Artist\": \"Polo G\", \"Artist Followers\": 4849204.0, \"Song ID\": \"65jw6GhwQW3Db55PxlPEpS\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 69.0, \"Danceability\": 0.829, \"Energy\": 0.52, \"Loudness\": -10.34, \"Speechiness\": 0.294, \"Acousticness\": 0.0232, \"Liveness\": 0.134, \"Tempo\": 136.103, \"Duration (ms)\": 194118.0, \"Valence\": 0.248, \"Chord\": \"G#/Ab\"}, {\"Index\": 1178, \"Highest Charting Position\": 82, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"BENDICIONES\", \"Streams\": 4639997, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2CoMYp2uIKsT09nreEZnZn\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 67.0, \"Danceability\": 0.828, \"Energy\": 0.581, \"Loudness\": -9.909, \"Speechiness\": 0.0725, \"Acousticness\": 0.0378, \"Liveness\": 0.103, \"Tempo\": 143.995, \"Duration (ms)\": 155060.0, \"Valence\": 0.843, \"Chord\": \"B\"}, {\"Index\": 1179, \"Highest Charting Position\": 126, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"PTSD\", \"Streams\": 4500903, \"Artist\": \"G Herbo, Juice WRLD, Lil Uzi Vert, Chance the Rapper\", \"Artist Followers\": 1253138.0, \"Song ID\": \"1C8ux1YWLMHCenYJFiIV4Z\", \"Genre\": \"['chicago drill', 'chicago rap', 'drill', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-02-28--2020-03-06\", \"Popularity\": 76.0, \"Danceability\": 0.883, \"Energy\": 0.808, \"Loudness\": -3.158, \"Speechiness\": 0.182, \"Acousticness\": 0.0313, \"Liveness\": 0.207, \"Tempo\": 119.01, \"Duration (ms)\": 232065.0, \"Valence\": 0.806, \"Chord\": \"C#/Db\"}, {\"Index\": 1180, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Excitement\", \"Streams\": 4416484, \"Artist\": \"Trippie Redd, PARTYNEXTDOOR\", \"Artist Followers\": 6434201.0, \"Song ID\": \"7FullO2NDkyvxLuxYVKINa\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 69.0, \"Danceability\": 0.443, \"Energy\": 0.536, \"Loudness\": -8.187, \"Speechiness\": 0.0378, \"Acousticness\": 0.0194, \"Liveness\": 0.1, \"Tempo\": 121.967, \"Duration (ms)\": 283285.0, \"Valence\": 0.0391, \"Chord\": \"E\"}, {\"Index\": 1181, \"Highest Charting Position\": 131, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Can We Kiss Forever?\", \"Streams\": 4397385, \"Artist\": \"Kina, Adriana Proenza\", \"Artist Followers\": 661863.0, \"Song ID\": \"58wyJLv6yH1La9NIZPl3ne\", \"Genre\": \"['sad rap']\", \"Release Date\": \"2018-08-31\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.522, \"Energy\": 0.128, \"Loudness\": -18.717, \"Speechiness\": 0.0357, \"Acousticness\": 0.894, \"Liveness\": 0.0941, \"Tempo\": 109.986, \"Duration (ms)\": 187932.0, \"Valence\": 0.124, \"Chord\": \"E\"}, {\"Index\": 1182, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"SI ELLA SALE\", \"Streams\": 7055918, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"1zaDh3qaGSeSmulNyWlUxm\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 63.0, \"Danceability\": 0.869, \"Energy\": 0.727, \"Loudness\": -7.397, \"Speechiness\": 0.123, \"Acousticness\": 0.0589, \"Liveness\": 0.107, \"Tempo\": 147.967, \"Duration (ms)\": 143240.0, \"Valence\": 0.92, \"Chord\": \"G\"}, {\"Index\": 1183, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"RONCA FREESTYLE\", \"Streams\": 5784075, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3XZeOzJ9tqnu58YP6cqApI\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 64.0, \"Danceability\": 0.856, \"Energy\": 0.656, \"Loudness\": -6.483, \"Speechiness\": 0.131, \"Acousticness\": 0.165, \"Liveness\": 0.0998, \"Tempo\": 90.041, \"Duration (ms)\": 150060.0, \"Valence\": 0.586, \"Chord\": \"F\"}, {\"Index\": 1184, \"Highest Charting Position\": 130, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Zoo York (feat. Fivio Foreign & Pop Smoke)\", \"Streams\": 5368705, \"Artist\": \"Lil Tjay\", \"Artist Followers\": 3559267.0, \"Song ID\": \"3Ddny34bFoYBb8dIGq5lwp\", \"Genre\": \"['brooklyn drill', 'melodic rap', 'nyc rap']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 70.0, \"Danceability\": 0.565, \"Energy\": 0.569, \"Loudness\": -6.084, \"Speechiness\": 0.379, \"Acousticness\": 0.0352, \"Liveness\": 0.106, \"Tempo\": 92.466, \"Duration (ms)\": 214825.0, \"Valence\": 0.303, \"Chord\": \"F#/Gb\"}, {\"Index\": 1185, \"Highest Charting Position\": 131, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"EN CASITA\", \"Streams\": 5364262, \"Artist\": \"Bad Bunny, Gabriela\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2DhNdoHxavs7Qtf5MnhZD0\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 62.0, \"Danceability\": 0.779, \"Energy\": 0.764, \"Loudness\": -8.217, \"Speechiness\": 0.0938, \"Acousticness\": 0.221, \"Liveness\": 0.0909, \"Tempo\": 158.093, \"Duration (ms)\": 176440.0, \"Valence\": 0.675, \"Chord\": \"C\"}, {\"Index\": 1186, \"Highest Charting Position\": 71, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Qu\\u00e9 Maldici\\u00f3n\", \"Streams\": 4971559, \"Artist\": \"Banda MS de Sergio Liz\\u00e1rraga, Snoop Dogg\", \"Artist Followers\": 12140496.0, \"Song ID\": \"2RxC2peY3FtrurYmbbmanr\", \"Genre\": \"['banda', 'corrido', 'norteno', 'regional mexican']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 69.0, \"Danceability\": 0.755, \"Energy\": 0.531, \"Loudness\": -8.051, \"Speechiness\": 0.196, \"Acousticness\": 0.213, \"Liveness\": 0.13, \"Tempo\": 177.951, \"Duration (ms)\": 203360.0, \"Valence\": 0.683, \"Chord\": \"A\"}, {\"Index\": 1187, \"Highest Charting Position\": 69, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Nicht verdient\", \"Streams\": 4912914, \"Artist\": \"Capital Bra, Loredana\", \"Artist Followers\": 4093115.0, \"Song ID\": \"7v8OynJxOxHoeS5C2UA9Y7\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-04-29\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 58.0, \"Danceability\": 0.719, \"Energy\": 0.65, \"Loudness\": -7.274, \"Speechiness\": 0.232, \"Acousticness\": 0.381, \"Liveness\": 0.167, \"Tempo\": 77.981, \"Duration (ms)\": 176953.0, \"Valence\": 0.488, \"Chord\": \"B\"}, {\"Index\": 1188, \"Highest Charting Position\": 52, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"A Tu Merced\", \"Streams\": 4909499, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4r9jkMEnArtWGH2rL2FZl0\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 82.0, \"Danceability\": 0.86, \"Energy\": 0.791, \"Loudness\": -4.784, \"Speechiness\": 0.0568, \"Acousticness\": 0.169, \"Liveness\": 0.106, \"Tempo\": 92.023, \"Duration (ms)\": 175918.0, \"Valence\": 0.887, \"Chord\": \"C\"}, {\"Index\": 1189, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Demons (feat. Fivio Foreign & Sosa Geek)\", \"Streams\": 4766829, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"05aZ9sAU1YXndHv0FMi9iW\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 63.0, \"Danceability\": 0.543, \"Energy\": 0.766, \"Loudness\": -3.387, \"Speechiness\": 0.343, \"Acousticness\": 0.423, \"Liveness\": 0.155, \"Tempo\": 106.869, \"Duration (ms)\": 204805.0, \"Valence\": 0.729, \"Chord\": \"C\"}, {\"Index\": 1190, \"Highest Charting Position\": 42, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Moral of the Story\", \"Streams\": 4609358, \"Artist\": \"Ashe\", \"Artist Followers\": 644479.0, \"Song ID\": \"2nC3QhMI9reBIOWutbU3Tj\", \"Genre\": \"['alt z', 'electropop', 'indie pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-02-14\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 75.0, \"Danceability\": 0.572, \"Energy\": 0.406, \"Loudness\": -8.624, \"Speechiness\": 0.0427, \"Acousticness\": 0.587, \"Liveness\": 0.102, \"Tempo\": 119.812, \"Duration (ms)\": 201084.0, \"Valence\": 0.265, \"Chord\": \"A#/Bb\"}, {\"Index\": 1191, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Can I\", \"Streams\": 4603243, \"Artist\": \"Kehlani\", \"Artist Followers\": 4894562.0, \"Song ID\": \"0uDdI4fAXCuNhQbmxENdsO\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop', 'r&b']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 68.0, \"Danceability\": 0.574, \"Energy\": 0.791, \"Loudness\": -3.752, \"Speechiness\": 0.11, \"Acousticness\": 0.419, \"Liveness\": 0.0982, \"Tempo\": 119.537, \"Duration (ms)\": 167810.0, \"Valence\": 0.612, \"Chord\": \"C#/Db\"}, {\"Index\": 1192, \"Highest Charting Position\": 46, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"STARGAZING\", \"Streams\": 4499820, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"7wBJfHzpfI3032CSD7CE2m\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2018-08-03\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 76.0, \"Danceability\": 0.487, \"Energy\": 0.789, \"Loudness\": -3.69, \"Speechiness\": 0.044, \"Acousticness\": 0.00947, \"Liveness\": 0.189, \"Tempo\": 150.007, \"Duration (ms)\": 270715.0, \"Valence\": 0.0564, \"Chord\": \"G#/Ab\"}, {\"Index\": 1193, \"Highest Charting Position\": 124, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Eastside (with Halsey & Khalid)\", \"Streams\": 4397708, \"Artist\": \"benny blanco\", \"Artist Followers\": 804613.0, \"Song ID\": \"0d2iYfpKoM0QCKvcLCkBao\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2018-07-12\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.56, \"Energy\": 0.68, \"Loudness\": -7.648, \"Speechiness\": 0.321, \"Acousticness\": 0.555, \"Liveness\": 0.116, \"Tempo\": 89.391, \"Duration (ms)\": 173800.0, \"Valence\": 0.319, \"Chord\": \"F#/Gb\"}, {\"Index\": 1194, \"Highest Charting Position\": 23, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Suicidal\", \"Streams\": 4320116, \"Artist\": \"YNW Melly\", \"Artist Followers\": 6332535.0, \"Song ID\": \"4S2uhQE8L9V6p7rj7SiauJ\", \"Genre\": \"['melodic rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.655, \"Energy\": 0.441, \"Loudness\": -5.245, \"Speechiness\": 0.0629, \"Acousticness\": 0.474, \"Liveness\": 0.099, \"Tempo\": 139.957, \"Duration (ms)\": 225857.0, \"Valence\": 0.273, \"Chord\": \"A\"}, {\"Index\": 1195, \"Highest Charting Position\": 39, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"How Do You Sleep?\", \"Streams\": 4313625, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"6b2RcmUt1g9N9mQ3CbjX2Y\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2019-07-19\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.477, \"Energy\": 0.682, \"Loudness\": -4.931, \"Speechiness\": 0.0925, \"Acousticness\": 0.153, \"Liveness\": 0.0763, \"Tempo\": 110.567, \"Duration (ms)\": 202205.0, \"Valence\": 0.345, \"Chord\": \"C#/Db\"}, {\"Index\": 1196, \"Highest Charting Position\": 4, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"No Time To Die\", \"Streams\": 4293009, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"73SpzrcaHk0RQPFP73vqVR\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2020-02-13\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 75.0, \"Danceability\": 0.38, \"Energy\": 0.219, \"Loudness\": -13.273, \"Speechiness\": 0.0358, \"Acousticness\": 0.917, \"Liveness\": 0.0827, \"Tempo\": 73.537, \"Duration (ms)\": 242265.0, \"Valence\": 0.0517, \"Chord\": \"E\"}, {\"Index\": 1197, \"Highest Charting Position\": 46, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"D4L\", \"Streams\": 10537097, \"Artist\": \"Future, Drake, Young Thug\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5fHrHoJKfCgBd35zwIBmUK\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 63.0, \"Danceability\": 0.718, \"Energy\": 0.706, \"Loudness\": -5.709, \"Speechiness\": 0.06, \"Acousticness\": 0.0128, \"Liveness\": 0.352, \"Tempo\": 170.004, \"Duration (ms)\": 189176.0, \"Valence\": 0.815, \"Chord\": \"C#/Db\"}, {\"Index\": 1198, \"Highest Charting Position\": 51, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Time Flies\", \"Streams\": 9904749, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5H4mXWKcicuLKDn4Jy0sK7\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 71.0, \"Danceability\": 0.864, \"Energy\": 0.477, \"Loudness\": -5.786, \"Speechiness\": 0.224, \"Acousticness\": 0.201, \"Liveness\": 0.182, \"Tempo\": 86.46, \"Duration (ms)\": 192932.0, \"Valence\": 0.5, \"Chord\": \"A#/Bb\"}, {\"Index\": 1199, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Desires (with Future)\", \"Streams\": 9628215, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"7eYAHC0RbBF9eaqWzT34Aq\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.812, \"Energy\": 0.506, \"Loudness\": -7.706, \"Speechiness\": 0.116, \"Acousticness\": 0.281, \"Liveness\": 0.325, \"Tempo\": 145.074, \"Duration (ms)\": 237946.0, \"Valence\": 0.554, \"Chord\": \"F\"}, {\"Index\": 1200, \"Highest Charting Position\": 55, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Not You Too (feat. Chris Brown)\", \"Streams\": 9284383, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"3Q4gttWQ6hxqWOa3tHoTNi\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.458, \"Energy\": 0.452, \"Loudness\": -9.299, \"Speechiness\": 0.047, \"Acousticness\": 0.342, \"Liveness\": 0.0703, \"Tempo\": 86.318, \"Duration (ms)\": 269680.0, \"Valence\": 0.316, \"Chord\": \"A\"}, {\"Index\": 1201, \"Highest Charting Position\": 67, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Landed\", \"Streams\": 8355036, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"3KixNgUEaDtrKJVzdqjU5q\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 60.0, \"Danceability\": 0.881, \"Energy\": 0.636, \"Loudness\": -4.629, \"Speechiness\": 0.287, \"Acousticness\": 0.00606, \"Liveness\": 0.111, \"Tempo\": 163.949, \"Duration (ms)\": 152195.0, \"Valence\": 0.715, \"Chord\": \"G\"}, {\"Index\": 1202, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"When To Say When\", \"Streams\": 8304928, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5TCBWmEBrin7etRa4Lswr1\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 60.0, \"Danceability\": 0.41, \"Energy\": 0.82, \"Loudness\": -6.808, \"Speechiness\": 0.533, \"Acousticness\": 0.252, \"Liveness\": 0.538, \"Tempo\": 170.718, \"Duration (ms)\": 223124.0, \"Valence\": 0.526, \"Chord\": \"C#/Db\"}, {\"Index\": 1203, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Deep Pockets\", \"Streams\": 8285754, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"3IvMYBE7A3c7to1aEcfFJk\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 58.0, \"Danceability\": 0.473, \"Energy\": 0.824, \"Loudness\": -3.68, \"Speechiness\": 0.163, \"Acousticness\": 0.482, \"Liveness\": 0.605, \"Tempo\": 77.888, \"Duration (ms)\": 222929.0, \"Valence\": 0.374, \"Chord\": \"G\"}, {\"Index\": 1204, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"War\", \"Streams\": 7821869, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"1I55Ea0zVoSKs6MqW7DQ3i\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.749, \"Energy\": 0.792, \"Loudness\": -4.151, \"Speechiness\": 0.0826, \"Acousticness\": 0.292, \"Liveness\": 0.109, \"Tempo\": 144.064, \"Duration (ms)\": 180000.0, \"Valence\": 0.239, \"Chord\": \"A#/Bb\"}, {\"Index\": 1205, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"From Florida With Love\", \"Streams\": 7216610, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"0YkUwXxnTkeJBvt5upeEtP\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.787, \"Energy\": 0.477, \"Loudness\": -7.837, \"Speechiness\": 0.199, \"Acousticness\": 0.768, \"Liveness\": 0.104, \"Tempo\": 80.506, \"Duration (ms)\": 234783.0, \"Valence\": 0.476, \"Chord\": \"F#/Gb\"}, {\"Index\": 1206, \"Highest Charting Position\": 89, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Losses\", \"Streams\": 6894756, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"6fLVTVaHWaEfVKfEgbkf4D\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 57.0, \"Danceability\": 0.551, \"Energy\": 0.57, \"Loudness\": -7.385, \"Speechiness\": 0.351, \"Acousticness\": 0.28, \"Liveness\": 0.424, \"Tempo\": 85.687, \"Duration (ms)\": 271184.0, \"Valence\": 0.505, \"Chord\": \"C#/Db\"}, {\"Index\": 1207, \"Highest Charting Position\": 25, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Turks (feat. Travis Scott)\", \"Streams\": 5594561, \"Artist\": \"NAV, Gunna\", \"Artist Followers\": 2613211.0, \"Song ID\": \"0lSZh5W0wDeurkGzLYY6hf\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'hip hop', 'melodic rap', 'pop rap', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 70.0, \"Danceability\": 0.893, \"Energy\": 0.618, \"Loudness\": -4.425, \"Speechiness\": 0.112, \"Acousticness\": 0.0827, \"Liveness\": 0.542, \"Tempo\": 119.099, \"Duration (ms)\": 161377.0, \"Valence\": 0.389, \"Chord\": \"G\"}, {\"Index\": 1208, \"Highest Charting Position\": 40, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Boyfriend\", \"Streams\": 5236730, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4QnC1bIaMSfDQvF4XDhV5M\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 62.0, \"Danceability\": 0.811, \"Energy\": 0.512, \"Loudness\": -6.381, \"Speechiness\": 0.17, \"Acousticness\": 0.218, \"Liveness\": 0.0768, \"Tempo\": 92.046, \"Duration (ms)\": 161188.0, \"Valence\": 0.346, \"Chord\": \"D\"}, {\"Index\": 1209, \"Highest Charting Position\": 29, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"What If I Told You That I Love You\", \"Streams\": 5234645, \"Artist\": \"Ali Gatie\", \"Artist Followers\": 1758300.0, \"Song ID\": \"6USdi8uX5GNAPYziFhisHb\", \"Genre\": \"['canadian hip hop', 'pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 69.0, \"Danceability\": 0.596, \"Energy\": 0.366, \"Loudness\": -11.144, \"Speechiness\": 0.115, \"Acousticness\": 0.63, \"Liveness\": 0.0554, \"Tempo\": 84.394, \"Duration (ms)\": 193668.0, \"Valence\": 0.229, \"Chord\": \"G\"}, {\"Index\": 1210, \"Highest Charting Position\": 85, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Emotions\", \"Streams\": 4901960, \"Artist\": \"Ufo361\", \"Artist Followers\": 1700759.0, \"Song ID\": \"3yZCjDTxzZxx1kll1sRjGc\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 65.0, \"Danceability\": 0.788, \"Energy\": 0.491, \"Loudness\": -9.884, \"Speechiness\": 0.109, \"Acousticness\": 0.386, \"Liveness\": 0.107, \"Tempo\": 98.543, \"Duration (ms)\": 146028.0, \"Valence\": 0.271, \"Chord\": \"G#/Ab\"}, {\"Index\": 1211, \"Highest Charting Position\": 32, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"FIND MY WAY\", \"Streams\": 4753495, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"1gVCEnryJhkdQcuC0Kbvor\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 66.0, \"Danceability\": 0.836, \"Energy\": 0.624, \"Loudness\": -6.75, \"Speechiness\": 0.184, \"Acousticness\": 0.187, \"Liveness\": 0.138, \"Tempo\": 103.0, \"Duration (ms)\": 139890.0, \"Valence\": 0.7, \"Chord\": \"E\"}, {\"Index\": 1212, \"Highest Charting Position\": 37, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Keii\", \"Streams\": 4687605, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"5eEQCfq7MXQr6aHLNRUZLs\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 67.0, \"Danceability\": 0.708, \"Energy\": 0.797, \"Loudness\": -3.095, \"Speechiness\": 0.0391, \"Acousticness\": 0.4, \"Liveness\": 0.096, \"Tempo\": 88.015, \"Duration (ms)\": 210000.0, \"Valence\": 0.51, \"Chord\": \"C\"}, {\"Index\": 1213, \"Highest Charting Position\": 130, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"God's Plan\", \"Streams\": 4565400, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"6DCZcSspjsKoFjzjrWoCdn\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2018-06-29\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.754, \"Energy\": 0.449, \"Loudness\": -9.211, \"Speechiness\": 0.109, \"Acousticness\": 0.0332, \"Liveness\": 0.552, \"Tempo\": 77.169, \"Duration (ms)\": 198973.0, \"Valence\": 0.357, \"Chord\": \"G\"}, {\"Index\": 1214, \"Highest Charting Position\": 103, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Por Primera Vez\", \"Streams\": 4478685, \"Artist\": \"Camilo, Evaluna Montaner\", \"Artist Followers\": 10580764.0, \"Song ID\": \"0gWbAFRcUyZKdfUxEOuOiD\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-09\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 70.0, \"Danceability\": 0.716, \"Energy\": 0.588, \"Loudness\": -3.952, \"Speechiness\": 0.116, \"Acousticness\": 0.152, \"Liveness\": 0.0847, \"Tempo\": 165.896, \"Duration (ms)\": 183547.0, \"Valence\": 0.707, \"Chord\": \"C#/Db\"}, {\"Index\": 1215, \"Highest Charting Position\": 32, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"@ MEH\", \"Streams\": 4420187, \"Artist\": \"Playboi Carti\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5rffvRUaCvkPnkwMVcQYgZ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 1.0, \"Danceability\": 0.877, \"Energy\": 0.492, \"Loudness\": -8.11, \"Speechiness\": 0.153, \"Acousticness\": 0.0136, \"Liveness\": 0.0678, \"Tempo\": 151.042, \"Duration (ms)\": 166799.0, \"Valence\": 0.4, \"Chord\": \"B\"}, {\"Index\": 1216, \"Highest Charting Position\": 109, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Broke In A Minute\", \"Streams\": 4402281, \"Artist\": \"Tory Lanez\", \"Artist Followers\": 3828418.0, \"Song ID\": \"4xqIYGwwZTEem9U8A42SPF\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-04-10\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-02-07--2020-02-14\", \"Popularity\": 75.0, \"Danceability\": 0.929, \"Energy\": 0.7, \"Loudness\": -5.595, \"Speechiness\": 0.0906, \"Acousticness\": 0.144, \"Liveness\": 0.349, \"Tempo\": 120.009, \"Duration (ms)\": 132024.0, \"Valence\": 0.802, \"Chord\": \"C\"}, {\"Index\": 1217, \"Highest Charting Position\": 139, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Fantasias - Remix\", \"Streams\": 4401019, \"Artist\": \"Rauw Alejandro, Anuel AA, Natti Natasha, Farruko, Lunay\", \"Artist Followers\": 6096559.0, \"Song ID\": \"0A37XY67wSdGqkGjtfW6aV\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 70.0, \"Danceability\": 0.816, \"Energy\": 0.72, \"Loudness\": -4.454, \"Speechiness\": 0.0684, \"Acousticness\": 0.206, \"Liveness\": 0.277, \"Tempo\": 94.004, \"Duration (ms)\": 267242.0, \"Valence\": 0.78, \"Chord\": \"C#/Db\"}, {\"Index\": 1218, \"Highest Charting Position\": 38, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"SUGAR\", \"Streams\": 4362442, \"Artist\": \"BROCKHAMPTON\", \"Artist Followers\": 1836564.0, \"Song ID\": \"6U0FIYXCQ3TGrk4tFpLrEA\", \"Genre\": \"['boy band', 'hip hop', 'rap']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 75.0, \"Danceability\": 0.453, \"Energy\": 0.538, \"Loudness\": -8.212, \"Speechiness\": 0.0638, \"Acousticness\": 0.449, \"Liveness\": 0.19, \"Tempo\": 122.973, \"Duration (ms)\": 204533.0, \"Valence\": 0.516, \"Chord\": \"C#/Db\"}, {\"Index\": 1219, \"Highest Charting Position\": 112, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"90-60-111\", \"Streams\": 5750861, \"Artist\": \"Shirin David\", \"Artist Followers\": 559215.0, \"Song ID\": \"3ZdDYeaZzeYnrP4crgXzPk\", \"Genre\": \"['frauenrap', 'german hip hop', 'german pop']\", \"Release Date\": \"2020-04-23\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 64.0, \"Danceability\": 0.8, \"Energy\": 0.628, \"Loudness\": -6.615, \"Speechiness\": 0.285, \"Acousticness\": 0.103, \"Liveness\": 0.391, \"Tempo\": 143.979, \"Duration (ms)\": 141387.0, \"Valence\": 0.745, \"Chord\": \"D\"}, {\"Index\": 1220, \"Highest Charting Position\": 115, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"YOSEMITE\", \"Streams\": 5686981, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"7lAK3oHbfEnvUQWosrMMpR\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2018-08-03\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 75.0, \"Danceability\": 0.785, \"Energy\": 0.554, \"Loudness\": -6.571, \"Speechiness\": 0.0409, \"Acousticness\": 0.283, \"Liveness\": 0.116, \"Tempo\": 128.047, \"Duration (ms)\": 150043.0, \"Valence\": 0.144, \"Chord\": \"C\"}, {\"Index\": 1221, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Houdini (feat. Swarmz & Tion Wayne)\", \"Streams\": 4914429, \"Artist\": \"KSI\", \"Artist Followers\": 2010879.0, \"Song ID\": \"3lay6f81Lhy0qp2Uvp4cNJ\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 58.0, \"Danceability\": 0.572, \"Energy\": 0.519, \"Loudness\": -8.054, \"Speechiness\": 0.243, \"Acousticness\": 0.000415, \"Liveness\": 0.129, \"Tempo\": 100.453, \"Duration (ms)\": 169355.0, \"Valence\": 0.704, \"Chord\": \"A#/Bb\"}, {\"Index\": 1222, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Sasuke\", \"Streams\": 4701551, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"0ROE31C8Wu4neZoR9stM9e\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 56.0, \"Danceability\": 0.859, \"Energy\": 0.477, \"Loudness\": -6.116, \"Speechiness\": 0.428, \"Acousticness\": 0.00414, \"Liveness\": 0.0819, \"Tempo\": 145.979, \"Duration (ms)\": 251336.0, \"Valence\": 0.153, \"Chord\": \"C#/Db\"}, {\"Index\": 1223, \"Highest Charting Position\": 47, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Me Gusta\", \"Streams\": 4440661, \"Artist\": \"Shakira, Anuel AA\", \"Artist Followers\": 22136717.0, \"Song ID\": \"5Xhqh4lwJPtMUTsdBztN1a\", \"Genre\": \"['colombian pop', 'dance pop', 'latin', 'latin pop', 'pop']\", \"Release Date\": \"2020-01-13\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 72.0, \"Danceability\": 0.775, \"Energy\": 0.696, \"Loudness\": -5.184, \"Speechiness\": 0.0681, \"Acousticness\": 0.0559, \"Liveness\": 0.157, \"Tempo\": 92.007, \"Duration (ms)\": 190570.0, \"Valence\": 0.775, \"Chord\": \"C#/Db\"}, {\"Index\": 1224, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"If You\\u2019re Too Shy (Let Me Know) - Edit\", \"Streams\": 4429092, \"Artist\": \"The 1975\", \"Artist Followers\": 5044278.0, \"Song ID\": \"3iEqGBZ2wcpVzhiAcwXVC6\", \"Genre\": \"['modern alternative rock', 'modern rock', 'pop', 'rock']\", \"Release Date\": \"2020-04-23\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 59.0, \"Danceability\": 0.651, \"Energy\": 0.806, \"Loudness\": -4.842, \"Speechiness\": 0.0311, \"Acousticness\": 0.00399, \"Liveness\": 0.0927, \"Tempo\": 125.641, \"Duration (ms)\": 239877.0, \"Valence\": 0.386, \"Chord\": \"D\"}, {\"Index\": 1225, \"Highest Charting Position\": 80, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Alone, Pt. II\", \"Streams\": 4395061, \"Artist\": \"Alan Walker, Ava Max\", \"Artist Followers\": 29679430.0, \"Song ID\": \"0bMbDctzMmTyK2j74j3nF3\", \"Genre\": \"['electro house']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.67, \"Energy\": 0.668, \"Loudness\": -4.306, \"Speechiness\": 0.0422, \"Acousticness\": 0.536, \"Liveness\": 0.133, \"Tempo\": 88.033, \"Duration (ms)\": 179053.0, \"Valence\": 0.608, \"Chord\": \"D#/Eb\"}, {\"Index\": 1226, \"Highest Charting Position\": 97, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Tutu\", \"Streams\": 4393037, \"Artist\": \"Camilo, Pedro Cap\\u00f3\", \"Artist Followers\": 10580764.0, \"Song ID\": \"1nocRtwyNPVtGcIJqfgdzZ\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2019-08-09\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.731, \"Energy\": 0.832, \"Loudness\": -2.592, \"Speechiness\": 0.0503, \"Acousticness\": 0.273, \"Liveness\": 0.0665, \"Tempo\": 146.013, \"Duration (ms)\": 178613.0, \"Valence\": 0.94, \"Chord\": \"A\"}, {\"Index\": 1227, \"Highest Charting Position\": 85, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Hate Me (with Juice WRLD)\", \"Streams\": 4367368, \"Artist\": \"Ellie Goulding\", \"Artist Followers\": 9747805.0, \"Song ID\": \"6kls8cSlUyHW2BUOkDJIZE\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'indietronica', 'metropopolis', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2019-06-26\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.657, \"Energy\": 0.768, \"Loudness\": -4.628, \"Speechiness\": 0.0507, \"Acousticness\": 0.108, \"Liveness\": 0.144, \"Tempo\": 75.025, \"Duration (ms)\": 186223.0, \"Valence\": 0.759, \"Chord\": \"G#/Ab\"}, {\"Index\": 1228, \"Highest Charting Position\": 109, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Still Be Friends (feat. Tory Lanez & Tyga)\", \"Streams\": 4299422, \"Artist\": \"G-Eazy\", \"Artist Followers\": 4894656.0, \"Song ID\": \"0JjM9bKm4wrwohMslcm892\", \"Genre\": \"['hip hop', 'indie pop rap', 'oakland hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 76.0, \"Danceability\": 0.803, \"Energy\": 0.759, \"Loudness\": -4.692, \"Speechiness\": 0.0494, \"Acousticness\": 0.00509, \"Liveness\": 0.0921, \"Tempo\": 104.0, \"Duration (ms)\": 213308.0, \"Valence\": 0.284, \"Chord\": \"G\"}, {\"Index\": 1229, \"Highest Charting Position\": 74, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Blanco\", \"Streams\": 4214147, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"2rc7BkzO8qepMFAxHtOrXc\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.87, \"Energy\": 0.706, \"Loudness\": -5.395, \"Speechiness\": 0.126, \"Acousticness\": 0.0253, \"Liveness\": 0.0872, \"Tempo\": 100.013, \"Duration (ms)\": 145800.0, \"Valence\": 0.593, \"Chord\": \"A\"}, {\"Index\": 1230, \"Highest Charting Position\": 78, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"PICK UP (feat. Quavo)\", \"Streams\": 7065060, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"5gNOINI5dXZVom2b36LMOd\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 65.0, \"Danceability\": 0.915, \"Energy\": 0.612, \"Loudness\": -4.535, \"Speechiness\": 0.407, \"Acousticness\": 0.0944, \"Liveness\": 0.115, \"Tempo\": 129.93, \"Duration (ms)\": 118547.0, \"Valence\": 0.758, \"Chord\": \"C#/Db\"}, {\"Index\": 1231, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"JUMP (feat. YoungBoy Never Broke Again)\", \"Streams\": 6033348, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"0oT9ElXYSxvnOOagP9efDq\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 62.0, \"Danceability\": 0.896, \"Energy\": 0.72, \"Loudness\": -6.262, \"Speechiness\": 0.355, \"Acousticness\": 0.169, \"Liveness\": 0.252, \"Tempo\": 140.1, \"Duration (ms)\": 212093.0, \"Valence\": 0.966, \"Chord\": \"C\"}, {\"Index\": 1232, \"Highest Charting Position\": 156, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"LIGHTSKIN SH*T (feat. Future & jetsonmade)\", \"Streams\": 4861875, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"16oi4OiKmkO51l60F5R9kR\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 56.0, \"Danceability\": 0.932, \"Energy\": 0.578, \"Loudness\": -4.478, \"Speechiness\": 0.366, \"Acousticness\": 0.115, \"Liveness\": 0.115, \"Tempo\": 129.991, \"Duration (ms)\": 111173.0, \"Valence\": 0.623, \"Chord\": \"A\"}, {\"Index\": 1233, \"Highest Charting Position\": 16, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"That Way - Bonus Track\", \"Streams\": 4825741, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2ajzBr7vwHTEBeqDzcsNRC\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.712, \"Energy\": 0.598, \"Loudness\": -5.368, \"Speechiness\": 0.0388, \"Acousticness\": 0.0546, \"Liveness\": 0.154, \"Tempo\": 130.007, \"Duration (ms)\": 212354.0, \"Valence\": 0.504, \"Chord\": \"G\"}, {\"Index\": 1234, \"Highest Charting Position\": 162, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"No Me Ame\", \"Streams\": 4822090, \"Artist\": \"Rvssian, Anuel AA, Juice WRLD\", \"Artist Followers\": 1397067.0, \"Song ID\": \"2AuWgceaQyfMoI3EGavwGb\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 64.0, \"Danceability\": 0.68, \"Energy\": 0.766, \"Loudness\": -4.799, \"Speechiness\": 0.0923, \"Acousticness\": 0.0411, \"Liveness\": 0.116, \"Tempo\": 160.095, \"Duration (ms)\": 180000.0, \"Valence\": 0.28, \"Chord\": \"B\"}, {\"Index\": 1235, \"Highest Charting Position\": 80, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"I'll Wait\", \"Streams\": 4674532, \"Artist\": \"Kygo, Sasha Alex Sloan\", \"Artist Followers\": 7593792.0, \"Song ID\": \"6Q3K9gVUZRMZqZKrXovbM2\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 70.0, \"Danceability\": 0.611, \"Energy\": 0.651, \"Loudness\": -6.973, \"Speechiness\": 0.0589, \"Acousticness\": 0.144, \"Liveness\": 0.105, \"Tempo\": 122.983, \"Duration (ms)\": 215361.0, \"Valence\": 0.351, \"Chord\": \"C#/Db\"}, {\"Index\": 1236, \"Highest Charting Position\": 63, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Oprah\\u2019s Bank Account (Lil Yachty & DaBaby feat. Drake)\", \"Streams\": 4618744, \"Artist\": \"Lil Yachty\", \"Artist Followers\": 7358720.0, \"Song ID\": \"7wsmIIm0xWmtP7TmACXkJn\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap', 'underground hip hop', 'viral rap']\", \"Release Date\": \"2020-03-09\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 69.0, \"Danceability\": 0.836, \"Energy\": 0.617, \"Loudness\": -4.363, \"Speechiness\": 0.0534, \"Acousticness\": 0.17, \"Liveness\": 0.319, \"Tempo\": 138.066, \"Duration (ms)\": 206702.0, \"Valence\": 0.866, \"Chord\": \"C\"}, {\"Index\": 1237, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"BLAME IT ON BABY\", \"Streams\": 4616034, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"0jWm0VyD8p3MrSInczpows\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 57.0, \"Danceability\": 0.875, \"Energy\": 0.687, \"Loudness\": -5.734, \"Speechiness\": 0.387, \"Acousticness\": 0.236, \"Liveness\": 0.141, \"Tempo\": 109.791, \"Duration (ms)\": 125907.0, \"Valence\": 0.864, \"Chord\": \"A\"}, {\"Index\": 1238, \"Highest Charting Position\": 128, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Follow\", \"Streams\": 4593449, \"Artist\": \"KAROL G, Anuel AA\", \"Artist Followers\": 17792779.0, \"Song ID\": \"2w1rq80FIrbxeJy9WYURxw\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-04-01\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 63.0, \"Danceability\": 0.735, \"Energy\": 0.787, \"Loudness\": -4.375, \"Speechiness\": 0.16, \"Acousticness\": 0.667, \"Liveness\": 0.0721, \"Tempo\": 168.997, \"Duration (ms)\": 203093.0, \"Valence\": 0.455, \"Chord\": \"G\"}, {\"Index\": 1239, \"Highest Charting Position\": 156, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"3 Nights\", \"Streams\": 4411998, \"Artist\": \"Dominic Fike\", \"Artist Followers\": 554042.0, \"Song ID\": \"1tNJrcVe6gwLEiZCtprs1u\", \"Genre\": \"['alternative pop rock', 'pop']\", \"Release Date\": \"2018-10-16\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.815, \"Energy\": 0.518, \"Loudness\": -6.594, \"Speechiness\": 0.0897, \"Acousticness\": 0.223, \"Liveness\": 0.104, \"Tempo\": 151.891, \"Duration (ms)\": 177667.0, \"Valence\": 0.877, \"Chord\": \"G\"}, {\"Index\": 1240, \"Highest Charting Position\": 163, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"The Take (feat. Chris Brown)\", \"Streams\": 4394195, \"Artist\": \"Tory Lanez\", \"Artist Followers\": 3828418.0, \"Song ID\": \"0Odu228D0yGcFySGuxU4rY\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 73.0, \"Danceability\": 0.464, \"Energy\": 0.547, \"Loudness\": -8.137, \"Speechiness\": 0.339, \"Acousticness\": 0.0511, \"Liveness\": 0.155, \"Tempo\": 67.003, \"Duration (ms)\": 221492.0, \"Valence\": 0.423, \"Chord\": \"G\"}, {\"Index\": 1241, \"Highest Charting Position\": 101, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Stupid Again\", \"Streams\": 5938996, \"Artist\": \"Tory Lanez\", \"Artist Followers\": 3828418.0, \"Song ID\": \"1fPnUpoXCpD2NDI4vPVeLw\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-04-10\", \"Weeks Charted\": \"2020-04-10--2020-04-17\", \"Popularity\": 66.0, \"Danceability\": 0.775, \"Energy\": 0.823, \"Loudness\": -4.941, \"Speechiness\": 0.0635, \"Acousticness\": 0.0881, \"Liveness\": 0.309, \"Tempo\": 120.059, \"Duration (ms)\": 174848.0, \"Valence\": 0.65, \"Chord\": \"F\"}, {\"Index\": 1242, \"Highest Charting Position\": 127, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Shotz Fired\", \"Streams\": 5291167, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"0dy5NFDnx5fuZvE8ZXEX35\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-04-10--2020-04-17\", \"Popularity\": 59.0, \"Danceability\": 0.839, \"Energy\": 0.594, \"Loudness\": -9.087, \"Speechiness\": 0.139, \"Acousticness\": 0.249, \"Liveness\": 0.165, \"Tempo\": 76.007, \"Duration (ms)\": 179844.0, \"Valence\": 0.58, \"Chord\": \"C\"}, {\"Index\": 1243, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"BaeBae\", \"Streams\": 5290730, \"Artist\": \"Samra\", \"Artist Followers\": 1045091.0, \"Song ID\": \"1yYBOIXO2H9LDqEPui42GM\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-04-10--2020-04-17\", \"Popularity\": 57.0, \"Danceability\": 0.628, \"Energy\": 0.712, \"Loudness\": -4.864, \"Speechiness\": 0.156, \"Acousticness\": 0.282, \"Liveness\": 0.156, \"Tempo\": 86.627, \"Duration (ms)\": 167827.0, \"Valence\": 0.45, \"Chord\": \"E\"}, {\"Index\": 1244, \"Highest Charting Position\": 30, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"To Die For\", \"Streams\": 4527835, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"2ZTYlnhhV1UAReg7wIGolx\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 70.0, \"Danceability\": 0.483, \"Energy\": 0.361, \"Loudness\": -7.889, \"Speechiness\": 0.0738, \"Acousticness\": 0.832, \"Liveness\": 0.098, \"Tempo\": 171.649, \"Duration (ms)\": 193795.0, \"Valence\": 0.307, \"Chord\": \"C\"}, {\"Index\": 1245, \"Highest Charting Position\": 86, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"WANNABE\", \"Streams\": 4383521, \"Artist\": \"ITZY\", \"Artist Followers\": 2384076.0, \"Song ID\": \"6tCssnvTUREcperDOUTqvA\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2020-03-09\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 75.0, \"Danceability\": 0.809, \"Energy\": 0.911, \"Loudness\": -4.41, \"Speechiness\": 0.0617, \"Acousticness\": 0.00795, \"Liveness\": 0.181, \"Tempo\": 122.035, \"Duration (ms)\": 191242.0, \"Valence\": 0.64, \"Chord\": \"F#/Gb\"}, {\"Index\": 1246, \"Highest Charting Position\": 152, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Takeaway\", \"Streams\": 4359727, \"Artist\": \"The Chainsmokers, ILLENIUM, Lennon Stella\", \"Artist Followers\": 18195884.0, \"Song ID\": \"3g0mEQx3NTanacLseoP0Gw\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.528, \"Energy\": 0.511, \"Loudness\": -8.144, \"Speechiness\": 0.0324, \"Acousticness\": 0.126, \"Liveness\": 0.101, \"Tempo\": 100.1, \"Duration (ms)\": 209880.0, \"Valence\": 0.351, \"Chord\": \"D#/Eb\"}, {\"Index\": 1247, \"Highest Charting Position\": 190, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Heart On Ice\", \"Streams\": 4324610, \"Artist\": \"Rod Wave\", \"Artist Followers\": 2203386.0, \"Song ID\": \"6fWa5CRgy0z30OeGZyMBvD\", \"Genre\": \"['florida rap']\", \"Release Date\": \"2019-06-14\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 70.0, \"Danceability\": 0.733, \"Energy\": 0.389, \"Loudness\": -8.468, \"Speechiness\": 0.0738, \"Acousticness\": 0.0513, \"Liveness\": 0.141, \"Tempo\": 157.878, \"Duration (ms)\": 159670.0, \"Valence\": 0.244, \"Chord\": \"A#/Bb\"}, {\"Index\": 1248, \"Highest Charting Position\": 194, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"La Cama - Remix\", \"Streams\": 4261965, \"Artist\": \"Lunay, Myke Towers, Ozuna, Chencho Corleone, Rauw Alejandro\", \"Artist Followers\": 4963516.0, \"Song ID\": \"2tGENA8xef0wABdHvyXwv9\", \"Genre\": \"['latin', 'latin pop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 69.0, \"Danceability\": 0.737, \"Energy\": 0.832, \"Loudness\": -2.622, \"Speechiness\": 0.0798, \"Acousticness\": 0.12, \"Liveness\": 0.255, \"Tempo\": 173.986, \"Duration (ms)\": 330240.0, \"Valence\": 0.865, \"Chord\": \"D\"}, {\"Index\": 1249, \"Highest Charting Position\": 105, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Go Stupid (feat. NLE Choppa & Mike WiLL Made-It)\", \"Streams\": 4244510, \"Artist\": \"Polo G, Stunna 4 Vegas\", \"Artist Followers\": 4849204.0, \"Song ID\": \"0L8OsjxbagaGkJI0PezdRg\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 41.0, \"Danceability\": 0.922, \"Energy\": 0.813, \"Loudness\": -3.268, \"Speechiness\": 0.251, \"Acousticness\": 0.0198, \"Liveness\": 0.0539, \"Tempo\": 141.087, \"Duration (ms)\": 165726.0, \"Valence\": 0.724, \"Chord\": \"C#/Db\"}, {\"Index\": 1250, \"Highest Charting Position\": 192, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Cradles\", \"Streams\": 4218201, \"Artist\": \"Sub Urban\", \"Artist Followers\": 908351.0, \"Song ID\": \"1y4jsQt7MjnZhiD1L6qFBC\", \"Genre\": \"['modern indie pop']\", \"Release Date\": \"2019-01-04\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 73.0, \"Danceability\": 0.534, \"Energy\": 0.589, \"Loudness\": -1.865, \"Speechiness\": 0.325, \"Acousticness\": 0.256, \"Liveness\": 0.176, \"Tempo\": 78.616, \"Duration (ms)\": 209829.0, \"Valence\": 0.632, \"Chord\": \"C#/Db\"}, {\"Index\": 1251, \"Highest Charting Position\": 117, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Good as Hell (feat. Ariana Grande)\", \"Streams\": 4176083, \"Artist\": \"Lizzo\", \"Artist Followers\": 3991674.0, \"Song ID\": \"07Oz5StQ7GRoygNLaXs2pd\", \"Genre\": \"['dance pop', 'escape room', 'minnesota hip hop', 'pop', 'pop rap', 'post-teen pop', 'trap queen']\", \"Release Date\": \"2016\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 71.0, \"Danceability\": 0.668, \"Energy\": 0.892, \"Loudness\": -3.001, \"Speechiness\": 0.0645, \"Acousticness\": 0.298, \"Liveness\": 0.735, \"Tempo\": 95.927, \"Duration (ms)\": 159011.0, \"Valence\": 0.478, \"Chord\": \"F\"}, {\"Index\": 1252, \"Highest Charting Position\": 15, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Forever (feat. Post Malone & Clever)\", \"Streams\": 6517807, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2ZlCGeK30BLRNSPC832pNZ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 68.0, \"Danceability\": 0.825, \"Energy\": 0.483, \"Loudness\": -5.746, \"Speechiness\": 0.08, \"Acousticness\": 0.538, \"Liveness\": 0.204, \"Tempo\": 139.98, \"Duration (ms)\": 219933.0, \"Valence\": 0.892, \"Chord\": \"G#/Ab\"}, {\"Index\": 1253, \"Highest Charting Position\": 46, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"I Love Me\", \"Streams\": 5449099, \"Artist\": \"Demi Lovato\", \"Artist Followers\": 20338833.0, \"Song ID\": \"2IHLaN6wwYKQ3S24NsQqpA\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.664, \"Energy\": 0.561, \"Loudness\": -7.031, \"Speechiness\": 0.0495, \"Acousticness\": 0.00261, \"Liveness\": 0.0764, \"Tempo\": 150.093, \"Duration (ms)\": 203672.0, \"Valence\": 0.713, \"Chord\": \"F#/Gb\"}, {\"Index\": 1254, \"Highest Charting Position\": 103, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Old Me\", \"Streams\": 4724056, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"58qO4dGa5SgNdtvqvpewyz\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 67.0, \"Danceability\": 0.722, \"Energy\": 0.62, \"Loudness\": -3.639, \"Speechiness\": 0.0483, \"Acousticness\": 0.313, \"Liveness\": 0.26, \"Tempo\": 127.978, \"Duration (ms)\": 186786.0, \"Valence\": 0.474, \"Chord\": \"C\"}, {\"Index\": 1255, \"Highest Charting Position\": 29, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Pero Ya No\", \"Streams\": 4666658, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"75pQqzwgCjUOSSy5CpmAjy\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 72.0, \"Danceability\": 0.882, \"Energy\": 0.612, \"Loudness\": -6.103, \"Speechiness\": 0.118, \"Acousticness\": 0.0475, \"Liveness\": 0.182, \"Tempo\": 147.982, \"Duration (ms)\": 160638.0, \"Valence\": 0.742, \"Chord\": \"E\"}, {\"Index\": 1256, \"Highest Charting Position\": 24, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Hardest To Love\", \"Streams\": 4553544, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"6kWxIqQDsKFYCJGbU4AjCX\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.467, \"Energy\": 0.608, \"Loudness\": -7.847, \"Speechiness\": 0.0707, \"Acousticness\": 0.0909, \"Liveness\": 0.125, \"Tempo\": 80.957, \"Duration (ms)\": 211400.0, \"Valence\": 0.108, \"Chord\": \"A#/Bb\"}, {\"Index\": 1257, \"Highest Charting Position\": 191, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"BRABA\", \"Streams\": 4452819, \"Artist\": \"Lu\\u00edsa Sonza\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6DEEuFNv0K3aJtFYZag8gv\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-11\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 0.0, \"Danceability\": 0.812, \"Energy\": 0.689, \"Loudness\": -5.113, \"Speechiness\": 0.0619, \"Acousticness\": 0.181, \"Liveness\": 0.0784, \"Tempo\": 144.011, \"Duration (ms)\": 129782.0, \"Valence\": 0.663, \"Chord\": \"C\"}, {\"Index\": 1258, \"Highest Charting Position\": 77, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Woah\", \"Streams\": 4425610, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"598yNsG1JFrGd4n2kMoz7F\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 69.0, \"Danceability\": 0.882, \"Energy\": 0.602, \"Loudness\": -5.554, \"Speechiness\": 0.245, \"Acousticness\": 0.0177, \"Liveness\": 0.178, \"Tempo\": 142.959, \"Duration (ms)\": 183011.0, \"Valence\": 0.43, \"Chord\": \"B\"}, {\"Index\": 1259, \"Highest Charting Position\": 69, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Pretty Please\", \"Streams\": 4305034, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"6DXZiYUbrYgrVIhfX3U9Z2\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 67.0, \"Danceability\": 0.906, \"Energy\": 0.474, \"Loudness\": -6.124, \"Speechiness\": 0.194, \"Acousticness\": 0.0311, \"Liveness\": 0.286, \"Tempo\": 106.976, \"Duration (ms)\": 194607.0, \"Valence\": 0.656, \"Chord\": \"C#/Db\"}, {\"Index\": 1260, \"Highest Charting Position\": 170, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"I.F.L.Y.\", \"Streams\": 4284951, \"Artist\": \"Bazzi\", \"Artist Followers\": 4421378.0, \"Song ID\": \"4a6q8CR2hzLk2plDkSxkfD\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-08-09\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-13--2020-03-20\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 76.0, \"Danceability\": 0.812, \"Energy\": 0.519, \"Loudness\": -4.823, \"Speechiness\": 0.0385, \"Acousticness\": 0.379, \"Liveness\": 0.13, \"Tempo\": 104.954, \"Duration (ms)\": 165714.0, \"Valence\": 0.554, \"Chord\": \"D\"}, {\"Index\": 1261, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Cool\", \"Streams\": 8136247, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"4Ulqu89XempybuL8ApUeqL\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.469, \"Energy\": 0.785, \"Loudness\": -4.015, \"Speechiness\": 0.0664, \"Acousticness\": 0.133, \"Liveness\": 0.0931, \"Tempo\": 89.719, \"Duration (ms)\": 209583.0, \"Valence\": 0.79, \"Chord\": \"F\"}, {\"Index\": 1262, \"Highest Charting Position\": 71, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Future Nostalgia\", \"Streams\": 8091754, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3iYNJX4FTRGlfMQySjlGNr\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.875, \"Energy\": 0.813, \"Loudness\": -4.502, \"Speechiness\": 0.0579, \"Acousticness\": 0.00618, \"Liveness\": 0.321, \"Tempo\": 114.993, \"Duration (ms)\": 184882.0, \"Valence\": 0.859, \"Chord\": \"G\"}, {\"Index\": 1263, \"Highest Charting Position\": 92, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Good In Bed\", \"Streams\": 6802068, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3pyodt4pb554dMz8fCv7oi\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 64.0, \"Danceability\": 0.68, \"Energy\": 0.701, \"Loudness\": -5.001, \"Speechiness\": 0.0917, \"Acousticness\": 0.138, \"Liveness\": 0.168, \"Tempo\": 94.06, \"Duration (ms)\": 218754.0, \"Valence\": 0.649, \"Chord\": \"F\"}, {\"Index\": 1264, \"Highest Charting Position\": 27, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Scared To Live\", \"Streams\": 6566099, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"4BGZF4oLbTL0pWm7C18pbv\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 66.0, \"Danceability\": 0.504, \"Energy\": 0.498, \"Loudness\": -8.24, \"Speechiness\": 0.0499, \"Acousticness\": 0.131, \"Liveness\": 0.0929, \"Tempo\": 87.221, \"Duration (ms)\": 191307.0, \"Valence\": 0.196, \"Chord\": \"C\"}, {\"Index\": 1265, \"Highest Charting Position\": 21, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Alone Again\", \"Streams\": 6055294, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"6b5P51m8xx2XA6U7sdNZ5E\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 66.0, \"Danceability\": 0.218, \"Energy\": 0.652, \"Loudness\": -7.953, \"Speechiness\": 0.0641, \"Acousticness\": 0.033, \"Liveness\": 0.172, \"Tempo\": 65.375, \"Duration (ms)\": 250053.0, \"Valence\": 0.0599, \"Chord\": \"E\"}, {\"Index\": 1266, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Boys Will Be Boys\", \"Streams\": 6015914, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"4szI7zRh7kLApCSqiB6R7b\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 63.0, \"Danceability\": 0.768, \"Energy\": 0.486, \"Loudness\": -5.954, \"Speechiness\": 0.0353, \"Acousticness\": 0.408, \"Liveness\": 0.098, \"Tempo\": 125.021, \"Duration (ms)\": 166266.0, \"Valence\": 0.519, \"Chord\": \"D#/Eb\"}, {\"Index\": 1267, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Auto Blu\", \"Streams\": 5995116, \"Artist\": \"Shiva, Eiffel 65\", \"Artist Followers\": 561372.0, \"Song ID\": \"5swpvba5YLqVDy1nbzUdog\", \"Genre\": \"['italian hip hop', 'trap italiana']\", \"Release Date\": \"2020-03-26\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 56.0, \"Danceability\": 0.82, \"Energy\": 0.783, \"Loudness\": -6.146, \"Speechiness\": 0.0621, \"Acousticness\": 0.0158, \"Liveness\": 0.0938, \"Tempo\": 130.015, \"Duration (ms)\": 166087.0, \"Valence\": 0.653, \"Chord\": \"F\"}, {\"Index\": 1268, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Du bist mein\", \"Streams\": 5878493, \"Artist\": \"Zuna, Loredana, SRNO\", \"Artist Followers\": 900975.0, \"Song ID\": \"719aY5gAzJbx2PHjyalZQu\", \"Genre\": \"['albanian hip hop', 'german hip hop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 54.0, \"Danceability\": 0.761, \"Energy\": 0.556, \"Loudness\": -6.943, \"Speechiness\": 0.364, \"Acousticness\": 0.138, \"Liveness\": 0.0976, \"Tempo\": 187.81, \"Duration (ms)\": 160357.0, \"Valence\": 0.521, \"Chord\": \"C#/Db\"}, {\"Index\": 1269, \"Highest Charting Position\": 28, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Too Late\", \"Streams\": 5867746, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"2K9Ovn1o2bTGqbsABGC6m3\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.638, \"Energy\": 0.863, \"Loudness\": -5.221, \"Speechiness\": 0.132, \"Acousticness\": 0.052, \"Liveness\": 0.685, \"Tempo\": 120.077, \"Duration (ms)\": 239973.0, \"Valence\": 0.226, \"Chord\": \"E\"}, {\"Index\": 1270, \"Highest Charting Position\": 136, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Wildflower\", \"Streams\": 5791343, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"6qlcjGJPTZEwR8nf2nSe9C\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.644, \"Energy\": 0.768, \"Loudness\": -4.316, \"Speechiness\": 0.0455, \"Acousticness\": 0.174, \"Liveness\": 0.469, \"Tempo\": 108.992, \"Duration (ms)\": 220536.0, \"Valence\": 0.598, \"Chord\": \"F#/Gb\"}, {\"Index\": 1271, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Faith\", \"Streams\": 5730081, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"3orEOtd8CPL8GFlpRpKuoE\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.375, \"Energy\": 0.605, \"Loudness\": -7.268, \"Speechiness\": 0.0729, \"Acousticness\": 0.612, \"Liveness\": 0.147, \"Tempo\": 175.946, \"Duration (ms)\": 283227.0, \"Valence\": 0.128, \"Chord\": \"C\"}, {\"Index\": 1272, \"Highest Charting Position\": 35, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Snowchild\", \"Streams\": 5423997, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"3WlbeuhfRSqU7ylK2Ui5U7\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 66.0, \"Danceability\": 0.55, \"Energy\": 0.611, \"Loudness\": -7.475, \"Speechiness\": 0.137, \"Acousticness\": 0.162, \"Liveness\": 0.121, \"Tempo\": 148.062, \"Duration (ms)\": 247187.0, \"Valence\": 0.243, \"Chord\": \"C\"}, {\"Index\": 1273, \"Highest Charting Position\": 37, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Escape From LA\", \"Streams\": 5307288, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"1sOW4PuG5X3Ie3EXUhAopJ\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.404, \"Energy\": 0.524, \"Loudness\": -8.996, \"Speechiness\": 0.0593, \"Acousticness\": 0.0456, \"Liveness\": 0.199, \"Tempo\": 145.74, \"Duration (ms)\": 355960.0, \"Valence\": 0.168, \"Chord\": \"F\"}, {\"Index\": 1274, \"Highest Charting Position\": 161, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Allein sein\", \"Streams\": 5119993, \"Artist\": \"Ufo361\", \"Artist Followers\": 1700759.0, \"Song ID\": \"2TrhpvxwuF6hrboTdRXwnS\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 54.0, \"Danceability\": 0.774, \"Energy\": 0.588, \"Loudness\": -8.529, \"Speechiness\": 0.225, \"Acousticness\": 0.0386, \"Liveness\": 0.258, \"Tempo\": 75.978, \"Duration (ms)\": 147353.0, \"Valence\": 0.392, \"Chord\": \"C#/Db\"}, {\"Index\": 1275, \"Highest Charting Position\": 44, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Bichiyal\", \"Streams\": 4946613, \"Artist\": \"Bad Bunny, Yaviah\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4j4w4CXm6BSr0s25wAWrrX\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 75.0, \"Danceability\": 0.737, \"Energy\": 0.766, \"Loudness\": -4.242, \"Speechiness\": 0.0458, \"Acousticness\": 0.31, \"Liveness\": 0.114, \"Tempo\": 93.956, \"Duration (ms)\": 196500.0, \"Valence\": 0.662, \"Chord\": \"A#/Bb\"}, {\"Index\": 1276, \"Highest Charting Position\": 85, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Medusa\", \"Streams\": 4901559, \"Artist\": \"Jhay Cortez, Anuel AA, J Balvin\", \"Artist Followers\": 2435159.0, \"Song ID\": \"3qM0vBxIe4VUbK0Z0smuVP\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-05\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 70.0, \"Danceability\": 0.886, \"Energy\": 0.604, \"Loudness\": -7.293, \"Speechiness\": 0.208, \"Acousticness\": 0.194, \"Liveness\": 0.107, \"Tempo\": 98.023, \"Duration (ms)\": 305333.0, \"Valence\": 0.383, \"Chord\": \"C\"}, {\"Index\": 1277, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Break Up Song\", \"Streams\": 4593343, \"Artist\": \"Little Mix\", \"Artist Followers\": 9398941.0, \"Song ID\": \"5HArmECc1y0lCHKVKDKXa4\", \"Genre\": \"['dance pop', 'girl group', 'pop', 'post-teen pop', 'talent show', 'uk pop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.631, \"Energy\": 0.75, \"Loudness\": -5.416, \"Speechiness\": 0.0394, \"Acousticness\": 0.00388, \"Liveness\": 0.286, \"Tempo\": 90.019, \"Duration (ms)\": 200293.0, \"Valence\": 0.593, \"Chord\": \"F\"}, {\"Index\": 1278, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Teeth\", \"Streams\": 4571612, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"26wLOs3ZuHJa2Ihhx6QIE6\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 78.0, \"Danceability\": 0.749, \"Energy\": 0.461, \"Loudness\": -2.961, \"Speechiness\": 0.0416, \"Acousticness\": 0.0516, \"Liveness\": 0.0738, \"Tempo\": 139.02, \"Duration (ms)\": 204887.0, \"Valence\": 0.42, \"Chord\": \"A#/Bb\"}, {\"Index\": 1279, \"Highest Charting Position\": 51, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Repeat After Me (Interlude)\", \"Streams\": 10058303, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"40U8d12pC5UHqmHwXjHjjl\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 63.0, \"Danceability\": 0.555, \"Energy\": 0.619, \"Loudness\": -7.918, \"Speechiness\": 0.0314, \"Acousticness\": 0.0323, \"Liveness\": 0.0917, \"Tempo\": 95.032, \"Duration (ms)\": 195813.0, \"Valence\": 0.141, \"Chord\": \"C\"}, {\"Index\": 1280, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Until I Bleed Out\", \"Streams\": 9132077, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"2BcnxwxBuar5wjCaLqm5N3\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 63.0, \"Danceability\": 0.245, \"Energy\": 0.394, \"Loudness\": -9.887, \"Speechiness\": 0.0374, \"Acousticness\": 0.423, \"Liveness\": 0.093, \"Tempo\": 115.233, \"Duration (ms)\": 190173.0, \"Valence\": 0.148, \"Chord\": \"C\"}, {\"Index\": 1281, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Rosa\", \"Streams\": 7564893, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"464uJVLmr0fDJGXOnciaDe\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 64.0, \"Danceability\": 0.651, \"Energy\": 0.561, \"Loudness\": -5.715, \"Speechiness\": 0.25, \"Acousticness\": 0.25, \"Liveness\": 0.435, \"Tempo\": 175.992, \"Duration (ms)\": 189827.0, \"Valence\": 0.369, \"Chord\": \"A\"}, {\"Index\": 1282, \"Highest Charting Position\": 88, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Gris\", \"Streams\": 7514854, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"1syf62zw48zu4FrPwMtDHk\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 65.0, \"Danceability\": 0.849, \"Energy\": 0.709, \"Loudness\": -4.717, \"Speechiness\": 0.0794, \"Acousticness\": 0.229, \"Liveness\": 0.329, \"Tempo\": 93.06, \"Duration (ms)\": 176627.0, \"Valence\": 0.916, \"Chord\": \"F#/Gb\"}, {\"Index\": 1283, \"Highest Charting Position\": 103, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Negro\", \"Streams\": 6651425, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"2hsA9YWuF3C9Gosi4dpjJN\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.795, \"Energy\": 0.911, \"Loudness\": -2.228, \"Speechiness\": 0.0875, \"Acousticness\": 0.0157, \"Liveness\": 0.131, \"Tempo\": 164.081, \"Duration (ms)\": 182093.0, \"Valence\": 0.8, \"Chord\": \"C\"}, {\"Index\": 1284, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Verde\", \"Streams\": 5745393, \"Artist\": \"J Balvin, Sky Rompiendo\", \"Artist Followers\": 29067437.0, \"Song ID\": \"3HTbI3yUJQw3fP0Po8qLcD\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 63.0, \"Danceability\": 0.828, \"Energy\": 0.738, \"Loudness\": -4.295, \"Speechiness\": 0.0516, \"Acousticness\": 0.0381, \"Liveness\": 0.0917, \"Tempo\": 94.995, \"Duration (ms)\": 142547.0, \"Valence\": 0.818, \"Chord\": \"G#/Ab\"}, {\"Index\": 1285, \"Highest Charting Position\": 15, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Baby Pluto\", \"Streams\": 5600261, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7hav1MHURQf5SAoPk0egqh\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 69.0, \"Danceability\": 0.772, \"Energy\": 0.634, \"Loudness\": -6.101, \"Speechiness\": 0.212, \"Acousticness\": 0.135, \"Liveness\": 0.432, \"Tempo\": 160.052, \"Duration (ms)\": 210261.0, \"Valence\": 0.671, \"Chord\": \"A#/Bb\"}, {\"Index\": 1286, \"Highest Charting Position\": 31, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Lo Mein\", \"Streams\": 5231134, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"6CUP2khYzdphXebxVTfPE3\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.855, \"Energy\": 0.676, \"Loudness\": -5.736, \"Speechiness\": 0.325, \"Acousticness\": 0.0888, \"Liveness\": 0.144, \"Tempo\": 133.082, \"Duration (ms)\": 195299.0, \"Valence\": 0.509, \"Chord\": \"C#/Db\"}, {\"Index\": 1287, \"Highest Charting Position\": 113, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"No Judgement\", \"Streams\": 5082563, \"Artist\": \"Niall Horan\", \"Artist Followers\": 7564659.0, \"Song ID\": \"5IUOU5xkzGHsRFOYNu3GSK\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 65.0, \"Danceability\": 0.723, \"Energy\": 0.726, \"Loudness\": -3.835, \"Speechiness\": 0.0472, \"Acousticness\": 0.0564, \"Liveness\": 0.057, \"Tempo\": 100.051, \"Duration (ms)\": 176283.0, \"Valence\": 0.962, \"Chord\": \"C#/Db\"}, {\"Index\": 1288, \"Highest Charting Position\": 57, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Futsal Shuffle 2020 - Bonus Track\", \"Streams\": 5068849, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2fOlBMkWR7lXJfqp5VTbDG\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 63.0, \"Danceability\": 0.879, \"Energy\": 0.448, \"Loudness\": -8.57, \"Speechiness\": 0.222, \"Acousticness\": 0.0346, \"Liveness\": 0.224, \"Tempo\": 136.985, \"Duration (ms)\": 198913.0, \"Valence\": 0.278, \"Chord\": \"G\"}, {\"Index\": 1289, \"Highest Charting Position\": 163, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Arco\\u00edris\", \"Streams\": 5044774, \"Artist\": \"J Balvin, Mr Eazi\", \"Artist Followers\": 29067437.0, \"Song ID\": \"5zzbORcD0GwLY0wQHP1Xs1\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 62.0, \"Danceability\": 0.731, \"Energy\": 0.787, \"Loudness\": -5.26, \"Speechiness\": 0.0721, \"Acousticness\": 0.0853, \"Liveness\": 0.316, \"Tempo\": 92.971, \"Duration (ms)\": 186693.0, \"Valence\": 0.393, \"Chord\": \"E\"}, {\"Index\": 1290, \"Highest Charting Position\": 65, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"TOES (feat. Lil Baby & Moneybagg Yo)\", \"Streams\": 4878903, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"2FvD20Z8aoWIePi7PoN8sG\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 73.0, \"Danceability\": 0.816, \"Energy\": 0.582, \"Loudness\": -4.141, \"Speechiness\": 0.341, \"Acousticness\": 0.0794, \"Liveness\": 0.0916, \"Tempo\": 160.004, \"Duration (ms)\": 136366.0, \"Valence\": 0.542, \"Chord\": \"G#/Ab\"}, {\"Index\": 1291, \"Highest Charting Position\": 42, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Feel Me\", \"Streams\": 4765672, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"6XXYdF6pJR1K3wKvuxmu7n\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 63.0, \"Danceability\": 0.71, \"Energy\": 0.808, \"Loudness\": -6.703, \"Speechiness\": 0.0433, \"Acousticness\": 0.44, \"Liveness\": 0.0734, \"Tempo\": 99.989, \"Duration (ms)\": 226003.0, \"Valence\": 0.392, \"Chord\": \"D\"}, {\"Index\": 1292, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"H <3 T E L\", \"Streams\": 4701388, \"Artist\": \"Dardan, Monet192\", \"Artist Followers\": 861082.0, \"Song ID\": \"3S1NOXjDr2A4xXXsWo8kLr\", \"Genre\": \"['albanian hip hop', 'german hip hop']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 34.0, \"Danceability\": 0.726, \"Energy\": 0.646, \"Loudness\": -6.9, \"Speechiness\": 0.0977, \"Acousticness\": 0.0495, \"Liveness\": 0.112, \"Tempo\": 134.999, \"Duration (ms)\": 163253.0, \"Valence\": 0.58, \"Chord\": \"C#/Db\"}, {\"Index\": 1293, \"Highest Charting Position\": 63, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"25/8\", \"Streams\": 4684378, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4NqQaovM14WR2hNPMFxgjb\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 71.0, \"Danceability\": 0.761, \"Energy\": 0.732, \"Loudness\": -5.469, \"Speechiness\": 0.0549, \"Acousticness\": 0.092, \"Liveness\": 0.0716, \"Tempo\": 151.982, \"Duration (ms)\": 243276.0, \"Valence\": 0.542, \"Chord\": \"E\"}, {\"Index\": 1294, \"Highest Charting Position\": 81, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Se Me Olvid\\u00f3\", \"Streams\": 4591194, \"Artist\": \"Christian Nodal\", \"Artist Followers\": 8123757.0, \"Song ID\": \"7paFC3FEu1WtPVP4Do6VZN\", \"Genre\": \"['mariachi', 'nuevo regional mexicano', 'ranchera', 'regional mexican']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 71.0, \"Danceability\": 0.65, \"Energy\": 0.558, \"Loudness\": -3.082, \"Speechiness\": 0.0309, \"Acousticness\": 0.368, \"Liveness\": 0.303, \"Tempo\": 141.82, \"Duration (ms)\": 159533.0, \"Valence\": 0.725, \"Chord\": \"C\"}, {\"Index\": 1295, \"Highest Charting Position\": 130, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"B.S. (feat. H.E.R.)\", \"Streams\": 4557817, \"Artist\": \"Jhen\\u00e9 Aiko\", \"Artist Followers\": 4720858.0, \"Song ID\": \"63wx9vdskaXbYxyDx4oJCZ\", \"Genre\": \"['alternative r&b', 'dance pop', 'pop', 'pop rap', 'r&b', 'urban contemporary']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 72.0, \"Danceability\": 0.617, \"Energy\": 0.525, \"Loudness\": -10.426, \"Speechiness\": 0.12, \"Acousticness\": 0.554, \"Liveness\": 0.135, \"Tempo\": 135.781, \"Duration (ms)\": 212867.0, \"Valence\": 0.377, \"Chord\": \"G#/Ab\"}, {\"Index\": 1296, \"Highest Charting Position\": 45, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Soli\\u00e1\", \"Streams\": 4516243, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"7sOfmPd18RWp3FoCzpa7Kw\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 72.0, \"Danceability\": 0.71, \"Energy\": 0.81, \"Loudness\": -5.507, \"Speechiness\": 0.0854, \"Acousticness\": 0.117, \"Liveness\": 0.154, \"Tempo\": 92.041, \"Duration (ms)\": 159282.0, \"Valence\": 0.184, \"Chord\": \"D\"}, {\"Index\": 1297, \"Highest Charting Position\": 55, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Est\\u00e1 Cabr\\u00f3n Ser Yo\", \"Streams\": 4438261, \"Artist\": \"Bad Bunny, Anuel AA\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4saHEjXw7O1NXJOzBkUKKG\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.81, \"Energy\": 0.854, \"Loudness\": -3.999, \"Speechiness\": 0.254, \"Acousticness\": 0.0732, \"Liveness\": 0.123, \"Tempo\": 154.083, \"Duration (ms)\": 227939.0, \"Valence\": 0.879, \"Chord\": \"A#/Bb\"}, {\"Index\": 1298, \"Highest Charting Position\": 61, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Bean (Kobe) [feat. Chief Keef]\", \"Streams\": 9039518, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"0IpnZchq8ek2A6pGEP2Qb1\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 67.0, \"Danceability\": 0.733, \"Energy\": 0.567, \"Loudness\": -6.718, \"Speechiness\": 0.319, \"Acousticness\": 0.0129, \"Liveness\": 0.382, \"Tempo\": 75.491, \"Duration (ms)\": 238816.0, \"Valence\": 0.319, \"Chord\": \"C\"}, {\"Index\": 1299, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Yessirskiii\", \"Streams\": 8374259, \"Artist\": \"Lil Uzi Vert, 21 Savage\", \"Artist Followers\": 11821805.0, \"Song ID\": \"59JWp4PjZ9TRM8cmtaDYB1\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 70.0, \"Danceability\": 0.895, \"Energy\": 0.739, \"Loudness\": -6.633, \"Speechiness\": 0.283, \"Acousticness\": 0.0183, \"Liveness\": 0.102, \"Tempo\": 140.007, \"Duration (ms)\": 219340.0, \"Valence\": 0.763, \"Chord\": \"G#/Ab\"}, {\"Index\": 1300, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Cardigan\", \"Streams\": 6586204, \"Artist\": \"Don Toliver\", \"Artist Followers\": 1606884.0, \"Song ID\": \"0Li1OuXXfi7950ilZUFGkF\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 70.0, \"Danceability\": 0.747, \"Energy\": 0.497, \"Loudness\": -6.542, \"Speechiness\": 0.0401, \"Acousticness\": 0.248, \"Liveness\": 0.138, \"Tempo\": 142.046, \"Duration (ms)\": 158709.0, \"Valence\": 0.0663, \"Chord\": \"E\"}, {\"Index\": 1301, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Silly Watch\", \"Streams\": 6442451, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"5egD7A5x9AHdVO2fMo3Wbo\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 65.0, \"Danceability\": 0.903, \"Energy\": 0.535, \"Loudness\": -6.238, \"Speechiness\": 0.286, \"Acousticness\": 0.0298, \"Liveness\": 0.0851, \"Tempo\": 130.117, \"Duration (ms)\": 195692.0, \"Valence\": 0.157, \"Chord\": \"G#/Ab\"}, {\"Index\": 1302, \"Highest Charting Position\": 70, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Hablamos Ma\\u00f1ana\", \"Streams\": 6105711, \"Artist\": \"Bad Bunny, Duki, Pablo Chill-E\", \"Artist Followers\": 36177712.0, \"Song ID\": \"1V8XneTrX6kKeoxYbk4x6h\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.683, \"Energy\": 0.677, \"Loudness\": -4.496, \"Speechiness\": 0.0469, \"Acousticness\": 0.0869, \"Liveness\": 0.0998, \"Tempo\": 156.019, \"Duration (ms)\": 240253.0, \"Valence\": 0.514, \"Chord\": \"C#/Db\"}, {\"Index\": 1303, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Lotus\", \"Streams\": 6017103, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4SnlSaLJJ7reJMCHM5YUuX\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 58.0, \"Danceability\": 0.802, \"Energy\": 0.748, \"Loudness\": -5.708, \"Speechiness\": 0.207, \"Acousticness\": 0.24, \"Liveness\": 0.165, \"Tempo\": 150.063, \"Duration (ms)\": 193861.0, \"Valence\": 0.516, \"Chord\": \"G#/Ab\"}, {\"Index\": 1304, \"Highest Charting Position\": 126, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Lettre \\u00e0 une femme\", \"Streams\": 5895243, \"Artist\": \"Ninho\", \"Artist Followers\": 4764552.0, \"Song ID\": \"10rwyGbKAWZ8JZbL7uHl28\", \"Genre\": \"['french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2020-03-07\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 54.0, \"Danceability\": 0.487, \"Energy\": 0.398, \"Loudness\": -9.901, \"Speechiness\": 0.0697, \"Acousticness\": 0.835, \"Liveness\": 0.12, \"Tempo\": 149.367, \"Duration (ms)\": 157766.0, \"Valence\": 0.905, \"Chord\": \"C#/Db\"}, {\"Index\": 1305, \"Highest Charting Position\": 57, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Que Malo\", \"Streams\": 5544180, \"Artist\": \"Bad Bunny, \\u00d1engo Flow\", \"Artist Followers\": 36177712.0, \"Song ID\": \"53v2u51nq3CxiKUNphRzP1\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.802, \"Energy\": 0.787, \"Loudness\": -6.181, \"Speechiness\": 0.0599, \"Acousticness\": 0.0832, \"Liveness\": 0.153, \"Tempo\": 94.026, \"Duration (ms)\": 167975.0, \"Valence\": 0.446, \"Chord\": \"G\"}, {\"Index\": 1306, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Leaders (feat. NAV)\", \"Streams\": 5496780, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4D7NrSeqkTarBrJ80b2sBc\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 60.0, \"Danceability\": 0.95, \"Energy\": 0.654, \"Loudness\": -5.895, \"Speechiness\": 0.307, \"Acousticness\": 0.0744, \"Liveness\": 0.138, \"Tempo\": 132.936, \"Duration (ms)\": 194844.0, \"Valence\": 0.886, \"Chord\": \"C\"}, {\"Index\": 1307, \"Highest Charting Position\": 149, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Strawberry Peels (feat. Young Thug & Gunna)\", \"Streams\": 5468083, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4lAQfuREAHG8IC0PiiigBt\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 59.0, \"Danceability\": 0.862, \"Energy\": 0.65, \"Loudness\": -6.978, \"Speechiness\": 0.355, \"Acousticness\": 0.0207, \"Liveness\": 0.568, \"Tempo\": 131.194, \"Duration (ms)\": 115350.0, \"Valence\": 0.658, \"Chord\": \"A#/Bb\"}, {\"Index\": 1308, \"Highest Charting Position\": 60, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"La Zona\", \"Streams\": 5440382, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5kqNIqFjijuzvVLhuY9B8j\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.762, \"Energy\": 0.801, \"Loudness\": -3.661, \"Speechiness\": 0.0409, \"Acousticness\": 0.2, \"Liveness\": 0.254, \"Tempo\": 93.992, \"Duration (ms)\": 136893.0, \"Valence\": 0.81, \"Chord\": \"C#/Db\"}, {\"Index\": 1309, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Wassup (feat. Future)\", \"Streams\": 5415044, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"19Ec2gbNtQTE44IizcPjtD\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 57.0, \"Danceability\": 0.762, \"Energy\": 0.622, \"Loudness\": -6.293, \"Speechiness\": 0.223, \"Acousticness\": 0.352, \"Liveness\": 0.145, \"Tempo\": 130.019, \"Duration (ms)\": 193314.0, \"Valence\": 0.626, \"Chord\": \"F\"}, {\"Index\": 1310, \"Highest Charting Position\": 69, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Una Vez\", \"Streams\": 5411302, \"Artist\": \"Bad Bunny, Mora\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5J7teKIJGtqVypgYI6sqXj\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 77.0, \"Danceability\": 0.55, \"Energy\": 0.598, \"Loudness\": -5.402, \"Speechiness\": 0.0831, \"Acousticness\": 0.132, \"Liveness\": 0.0955, \"Tempo\": 83.836, \"Duration (ms)\": 232496.0, \"Valence\": 0.543, \"Chord\": \"B\"}, {\"Index\": 1311, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Moon Relate\", \"Streams\": 5324545, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4sWGHlZGM1XA7TyWdtBAbA\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 58.0, \"Danceability\": 0.867, \"Energy\": 0.768, \"Loudness\": -3.73, \"Speechiness\": 0.0791, \"Acousticness\": 0.18, \"Liveness\": 0.254, \"Tempo\": 102.021, \"Duration (ms)\": 181826.0, \"Valence\": 0.34, \"Chord\": \"G\"}, {\"Index\": 1312, \"Highest Charting Position\": 163, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Black And White\", \"Streams\": 5204120, \"Artist\": \"Niall Horan\", \"Artist Followers\": 7564659.0, \"Song ID\": \"7rpNuuoMbid56XkDsx2FjE\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 75.0, \"Danceability\": 0.443, \"Energy\": 0.582, \"Loudness\": -6.02, \"Speechiness\": 0.0482, \"Acousticness\": 0.0301, \"Liveness\": 0.127, \"Tempo\": 147.589, \"Duration (ms)\": 193090.0, \"Valence\": 0.239, \"Chord\": \"D\"}, {\"Index\": 1313, \"Highest Charting Position\": 81, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"The Other Side (from Trolls World Tour)\", \"Streams\": 5193927, \"Artist\": \"SZA, Justin Timberlake\", \"Artist Followers\": 5888533.0, \"Song ID\": \"463PQggkmk5tTw8ug0ahOX\", \"Genre\": \"['pop', 'pop rap', 'r&b']\", \"Release Date\": \"2020-02-26\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 68.0, \"Danceability\": 0.76, \"Energy\": 0.607, \"Loudness\": -6.274, \"Speechiness\": 0.0964, \"Acousticness\": 0.00277, \"Liveness\": 0.132, \"Tempo\": 105.979, \"Duration (ms)\": 188187.0, \"Valence\": 0.709, \"Chord\": \"G\"}, {\"Index\": 1314, \"Highest Charting Position\": 53, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Whine Up\", \"Streams\": 5130783, \"Artist\": \"Nicky Jam, Anuel AA\", \"Artist Followers\": 14831925.0, \"Song ID\": \"2pWOMNQJW3g2zmGjP0Vkb0\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-01\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.817, \"Energy\": 0.665, \"Loudness\": -6.224, \"Speechiness\": 0.0758, \"Acousticness\": 0.0549, \"Liveness\": 0.103, \"Tempo\": 104.957, \"Duration (ms)\": 215460.0, \"Valence\": 0.662, \"Chord\": \"A\"}, {\"Index\": 1315, \"Highest Charting Position\": 37, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Ayy Macarena\", \"Streams\": 5046905, \"Artist\": \"Tyga\", \"Artist Followers\": 6298789.0, \"Song ID\": \"6LcauUZjF1eXQrgqMUecHX\", \"Genre\": \"['dance pop', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2019-11-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.816, \"Energy\": 0.629, \"Loudness\": -5.568, \"Speechiness\": 0.226, \"Acousticness\": 0.133, \"Liveness\": 0.0692, \"Tempo\": 96.493, \"Duration (ms)\": 131607.0, \"Valence\": 0.714, \"Chord\": \"D\"}, {\"Index\": 1316, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Trap This Way (This Way)\", \"Streams\": 5043990, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7vTspUAmMKFkUpKL9HLZNL\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 59.0, \"Danceability\": 0.71, \"Energy\": 0.586, \"Loudness\": -5.331, \"Speechiness\": 0.381, \"Acousticness\": 0.248, \"Liveness\": 0.193, \"Tempo\": 175.987, \"Duration (ms)\": 185439.0, \"Valence\": 0.207, \"Chord\": \"D\"}, {\"Index\": 1317, \"Highest Charting Position\": 113, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Who (feat. BTS)\", \"Streams\": 5004752, \"Artist\": \"Lauv\", \"Artist Followers\": 4442273.0, \"Song ID\": \"2qG81jL9UIP54uS8gYyP4k\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 74.0, \"Danceability\": 0.632, \"Energy\": 0.345, \"Loudness\": -8.0, \"Speechiness\": 0.0349, \"Acousticness\": 0.551, \"Liveness\": 0.104, \"Tempo\": 141.641, \"Duration (ms)\": 180413.0, \"Valence\": 0.0818, \"Chord\": \"B\"}, {\"Index\": 1318, \"Highest Charting Position\": 51, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Homecoming\", \"Streams\": 4988839, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"6vxU64pcIuQ38O015Zy4qj\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 63.0, \"Danceability\": 0.929, \"Energy\": 0.563, \"Loudness\": -7.428, \"Speechiness\": 0.49, \"Acousticness\": 0.000592, \"Liveness\": 0.244, \"Tempo\": 129.957, \"Duration (ms)\": 213885.0, \"Valence\": 0.353, \"Chord\": \"A\"}, {\"Index\": 1319, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Got The Guap (feat. Young Thug)\", \"Streams\": 4946997, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"1HF6P40Z7nfExGaB1Gk99v\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 58.0, \"Danceability\": 0.837, \"Energy\": 0.601, \"Loudness\": -5.628, \"Speechiness\": 0.198, \"Acousticness\": 0.21, \"Liveness\": 0.0928, \"Tempo\": 142.977, \"Duration (ms)\": 176756.0, \"Valence\": 0.749, \"Chord\": \"G#/Ab\"}, {\"Index\": 1320, \"Highest Charting Position\": 53, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Prices\", \"Streams\": 4898167, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4YcWzLSnGqLjSCycuSMHnn\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 65.0, \"Danceability\": 0.786, \"Energy\": 0.683, \"Loudness\": -5.397, \"Speechiness\": 0.205, \"Acousticness\": 0.173, \"Liveness\": 0.706, \"Tempo\": 126.002, \"Duration (ms)\": 233333.0, \"Valence\": 0.57, \"Chord\": \"G\"}, {\"Index\": 1321, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"I Can Show You\", \"Streams\": 4831405, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"0AhJag7VI8uFf3mJFsTwvf\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 57.0, \"Danceability\": 0.817, \"Energy\": 0.656, \"Loudness\": -7.086, \"Speechiness\": 0.277, \"Acousticness\": 0.051, \"Liveness\": 0.115, \"Tempo\": 139.915, \"Duration (ms)\": 120076.0, \"Valence\": 0.314, \"Chord\": \"A#/Bb\"}, {\"Index\": 1322, \"Highest Charting Position\": 52, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"I'm Sorry\", \"Streams\": 4818039, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"1xcOYJxDa5pObgxY1r0I9c\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 60.0, \"Danceability\": 0.858, \"Energy\": 0.547, \"Loudness\": -5.822, \"Speechiness\": 0.29, \"Acousticness\": 0.213, \"Liveness\": 0.104, \"Tempo\": 128.02, \"Duration (ms)\": 211883.0, \"Valence\": 0.303, \"Chord\": \"C#/Db\"}, {\"Index\": 1323, \"Highest Charting Position\": 19, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Black Swan\", \"Streams\": 4802069, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3bkkMZEAhx7rTVz1C0itRQ\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 70.0, \"Danceability\": 0.719, \"Energy\": 0.758, \"Loudness\": -5.167, \"Speechiness\": 0.0851, \"Acousticness\": 0.137, \"Liveness\": 0.129, \"Tempo\": 147.023, \"Duration (ms)\": 198261.0, \"Valence\": 0.49, \"Chord\": \"D\"}, {\"Index\": 1324, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Bad Child\", \"Streams\": 4787180, \"Artist\": \"Tones And I\", \"Artist Followers\": 1251372.0, \"Song ID\": \"2hBeHlR2d7wFJVLcj2fivL\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 0.0, \"Danceability\": 0.756, \"Energy\": 0.553, \"Loudness\": -4.24, \"Speechiness\": 0.0343, \"Acousticness\": 0.404, \"Liveness\": 0.158, \"Tempo\": 117.992, \"Duration (ms)\": 221467.0, \"Valence\": 0.597, \"Chord\": \"F#/Gb\"}, {\"Index\": 1325, \"Highest Charting Position\": 61, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Adicto (with Anuel AA & Ozuna)\", \"Streams\": 4785720, \"Artist\": \"Tainy\", \"Artist Followers\": 509411.0, \"Song ID\": \"3jbT1Y5MoPwEIpZndDDwVq\", \"Genre\": \"['latin', 'latin hip hop', 'latin pop', 'pop reggaeton', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-08-22\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.734, \"Energy\": 0.836, \"Loudness\": -4.803, \"Speechiness\": 0.0735, \"Acousticness\": 0.017, \"Liveness\": 0.179, \"Tempo\": 80.002, \"Duration (ms)\": 270741.0, \"Valence\": 0.623, \"Chord\": \"A#/Bb\"}, {\"Index\": 1326, \"Highest Charting Position\": 66, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"<3\", \"Streams\": 4755477, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4MZSqgwlE71CWZ6qQ3gkKm\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.631, \"Energy\": 0.665, \"Loudness\": -7.589, \"Speechiness\": 0.229, \"Acousticness\": 0.602, \"Liveness\": 0.152, \"Tempo\": 80.353, \"Duration (ms)\": 157967.0, \"Valence\": 0.634, \"Chord\": \"A#/Bb\"}, {\"Index\": 1327, \"Highest Charting Position\": 198, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Bad Girls, Good Vibes\", \"Streams\": 4752181, \"Artist\": \"Ufo361\", \"Artist Followers\": 1700759.0, \"Song ID\": \"7IxGslFZA5QhgXbUsDmcjf\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 53.0, \"Danceability\": 0.826, \"Energy\": 0.368, \"Loudness\": -12.761, \"Speechiness\": 0.133, \"Acousticness\": 0.516, \"Liveness\": 0.0914, \"Tempo\": 127.977, \"Duration (ms)\": 107446.0, \"Valence\": 0.158, \"Chord\": \"G\"}, {\"Index\": 1328, \"Highest Charting Position\": 120, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Liberdade Provis\\u00f3ria - Ao Vivo\", \"Streams\": 4730891, \"Artist\": \"Henrique & Juliano\", \"Artist Followers\": 13312073.0, \"Song ID\": \"3Ghyp3X5Ua9ypHnBIgOObI\", \"Genre\": \"['sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 58.0, \"Danceability\": 0.668, \"Energy\": 0.684, \"Loudness\": -5.937, \"Speechiness\": 0.0527, \"Acousticness\": 0.627, \"Liveness\": 0.923, \"Tempo\": 108.138, \"Duration (ms)\": 187986.0, \"Valence\": 0.7, \"Chord\": \"C#/Db\"}, {\"Index\": 1329, \"Highest Charting Position\": 60, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"POP\", \"Streams\": 10484727, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"1jDbQz6tr52WgScCTXMnaN\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 58.0, \"Danceability\": 0.741, \"Energy\": 0.599, \"Loudness\": -6.672, \"Speechiness\": 0.419, \"Acousticness\": 0.00961, \"Liveness\": 0.785, \"Tempo\": 139.891, \"Duration (ms)\": 227474.0, \"Valence\": 0.276, \"Chord\": \"C#/Db\"}, {\"Index\": 1330, \"Highest Charting Position\": 61, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Celebration Station\", \"Streams\": 10396969, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"25B5fGr9K0VdZJiRFsnMO4\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 61.0, \"Danceability\": 0.748, \"Energy\": 0.771, \"Loudness\": -4.156, \"Speechiness\": 0.15, \"Acousticness\": 0.101, \"Liveness\": 0.135, \"Tempo\": 142.086, \"Duration (ms)\": 195058.0, \"Valence\": 0.792, \"Chord\": \"F#/Gb\"}, {\"Index\": 1331, \"Highest Charting Position\": 64, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Bigger Than Life\", \"Streams\": 9974143, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2oHDJHNondITqbl8xZ9vPn\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 62.0, \"Danceability\": 0.776, \"Energy\": 0.752, \"Loudness\": -4.711, \"Speechiness\": 0.193, \"Acousticness\": 0.325, \"Liveness\": 0.33, \"Tempo\": 140.013, \"Duration (ms)\": 192705.0, \"Valence\": 0.716, \"Chord\": \"G#/Ab\"}, {\"Index\": 1332, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Venetia\", \"Streams\": 9824605, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"3BYIzNZ3t9lRQCACXSMLrT\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 63.0, \"Danceability\": 0.775, \"Energy\": 0.757, \"Loudness\": -4.139, \"Speechiness\": 0.175, \"Acousticness\": 0.162, \"Liveness\": 0.148, \"Tempo\": 142.933, \"Duration (ms)\": 188800.0, \"Valence\": 0.562, \"Chord\": \"A\"}, {\"Index\": 1333, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"You Better Move\", \"Streams\": 9533898, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"6YAxCn4juTWn5hWl2hzHGw\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 60.0, \"Danceability\": 0.842, \"Energy\": 0.556, \"Loudness\": -6.793, \"Speechiness\": 0.442, \"Acousticness\": 0.159, \"Liveness\": 0.204, \"Tempo\": 118.836, \"Duration (ms)\": 196639.0, \"Valence\": 0.306, \"Chord\": \"G#/Ab\"}, {\"Index\": 1334, \"Highest Charting Position\": 93, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Chrome Heart Tags\", \"Streams\": 8219307, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"46mT9NR7N9Zf5MolcrBgE3\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 57.0, \"Danceability\": 0.702, \"Energy\": 0.768, \"Loudness\": -4.055, \"Speechiness\": 0.0669, \"Acousticness\": 0.541, \"Liveness\": 0.105, \"Tempo\": 70.056, \"Duration (ms)\": 212821.0, \"Valence\": 0.574, \"Chord\": \"C\"}, {\"Index\": 1335, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Bust Me\", \"Streams\": 7828045, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4wBcaYqLPm7EtDVoJQORU4\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 57.0, \"Danceability\": 0.734, \"Energy\": 0.703, \"Loudness\": -6.256, \"Speechiness\": 0.355, \"Acousticness\": 0.237, \"Liveness\": 0.413, \"Tempo\": 151.923, \"Duration (ms)\": 194452.0, \"Valence\": 0.608, \"Chord\": \"B\"}, {\"Index\": 1336, \"Highest Charting Position\": 46, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Ren\\u00e9\", \"Streams\": 7240117, \"Artist\": \"Residente\", \"Artist Followers\": 878491.0, \"Song ID\": \"6gm12xlADJwiBbHIKBXzGW\", \"Genre\": \"['venezuelan hip hop']\", \"Release Date\": \"2020-02-27\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 65.0, \"Danceability\": 0.486, \"Energy\": 0.388, \"Loudness\": -9.326, \"Speechiness\": 0.126, \"Acousticness\": 0.435, \"Liveness\": 0.196, \"Tempo\": 90.471, \"Duration (ms)\": 457592.0, \"Valence\": 0.467, \"Chord\": \"C\"}, {\"Index\": 1337, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Secure The Bag\", \"Streams\": 7053947, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7gHZGXSJzM29WA384suYY2\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 57.0, \"Danceability\": 0.803, \"Energy\": 0.719, \"Loudness\": -4.485, \"Speechiness\": 0.392, \"Acousticness\": 0.344, \"Liveness\": 0.425, \"Tempo\": 129.945, \"Duration (ms)\": 238425.0, \"Valence\": 0.549, \"Chord\": \"C\"}, {\"Index\": 1338, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Urgency (feat. Syd)\", \"Streams\": 6224412, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"5KlPy74NOEAt8jC3FYURnQ\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 53.0, \"Danceability\": 0.619, \"Energy\": 0.784, \"Loudness\": -6.11, \"Speechiness\": 0.123, \"Acousticness\": 0.0326, \"Liveness\": 0.315, \"Tempo\": 156.035, \"Duration (ms)\": 181161.0, \"Valence\": 0.471, \"Chord\": \"C#/Db\"}, {\"Index\": 1339, \"Highest Charting Position\": 34, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"ON (Feat. Sia)\", \"Streams\": 6219276, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3IB5qOeMayvpOdHxYCL5tZ\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 64.0, \"Danceability\": 0.591, \"Energy\": 0.848, \"Loudness\": -4.397, \"Speechiness\": 0.0828, \"Acousticness\": 0.137, \"Liveness\": 0.372, \"Tempo\": 105.922, \"Duration (ms)\": 246816.0, \"Valence\": 0.386, \"Chord\": \"A\"}, {\"Index\": 1340, \"Highest Charting Position\": 99, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"P FKN R\", \"Streams\": 6041127, \"Artist\": \"Bad Bunny, Kendo Kaponi, Arcangel\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0fgsKar6uBO08vzHXkTjWi\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 66.0, \"Danceability\": 0.82, \"Energy\": 0.635, \"Loudness\": -5.749, \"Speechiness\": 0.0772, \"Acousticness\": 0.409, \"Liveness\": 0.244, \"Tempo\": 101.024, \"Duration (ms)\": 258280.0, \"Valence\": 0.528, \"Chord\": \"F\"}, {\"Index\": 1341, \"Highest Charting Position\": 108, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Modern Loneliness\", \"Streams\": 6020508, \"Artist\": \"Lauv\", \"Artist Followers\": 4442273.0, \"Song ID\": \"1eyek0KJEh2v5HQ9uQSybb\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 68.0, \"Danceability\": 0.702, \"Energy\": 0.508, \"Loudness\": -7.105, \"Speechiness\": 0.035, \"Acousticness\": 0.144, \"Liveness\": 0.108, \"Tempo\": 82.008, \"Duration (ms)\": 252337.0, \"Valence\": 0.143, \"Chord\": \"G#/Ab\"}, {\"Index\": 1342, \"Highest Charting Position\": 65, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Heatin Up (feat. Gunna)\", \"Streams\": 6004839, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"7KSSdFCBHCfq4KPzz78ghk\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 66.0, \"Danceability\": 0.788, \"Energy\": 0.436, \"Loudness\": -9.435, \"Speechiness\": 0.364, \"Acousticness\": 0.0611, \"Liveness\": 0.0979, \"Tempo\": 129.847, \"Duration (ms)\": 177314.0, \"Valence\": 0.341, \"Chord\": \"C#/Db\"}, {\"Index\": 1343, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"SKYBOX\", \"Streams\": 5846484, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"7GwYENSg87oERcW0Wacd6m\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 59.0, \"Danceability\": 0.779, \"Energy\": 0.707, \"Loudness\": -6.527, \"Speechiness\": 0.16, \"Acousticness\": 0.0991, \"Liveness\": 0.0934, \"Tempo\": 140.894, \"Duration (ms)\": 178097.0, \"Valence\": 0.343, \"Chord\": \"C#/Db\"}, {\"Index\": 1344, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Young & Alive\", \"Streams\": 5578323, \"Artist\": \"Bazzi\", \"Artist Followers\": 4421378.0, \"Song ID\": \"5RsKelNxucrDxgMbZ3vd3W\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-05\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 71.0, \"Danceability\": 0.716, \"Energy\": 0.563, \"Loudness\": -5.486, \"Speechiness\": 0.0425, \"Acousticness\": 0.326, \"Liveness\": 0.119, \"Tempo\": 86.005, \"Duration (ms)\": 160465.0, \"Valence\": 0.495, \"Chord\": \"D#/Eb\"}, {\"Index\": 1345, \"Highest Charting Position\": 169, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"i'm so tired...\", \"Streams\": 5547770, \"Artist\": \"Lauv, Troye Sivan\", \"Artist Followers\": 4442273.0, \"Song ID\": \"4vjpLMyL3ZO6aphdYr8XYw\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-01-03--2020-01-10\", \"Popularity\": 77.0, \"Danceability\": 0.599, \"Energy\": 0.733, \"Loudness\": -7.058, \"Speechiness\": 0.203, \"Acousticness\": 0.176, \"Liveness\": 0.242, \"Tempo\": 102.211, \"Duration (ms)\": 162583.0, \"Valence\": 0.534, \"Chord\": \"B\"}, {\"Index\": 1346, \"Highest Charting Position\": 53, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Numbers (feat. Roddy Ricch, Gunna and London On Da Track)\", \"Streams\": 5487069, \"Artist\": \"A Boogie Wit da Hoodie\", \"Artist Followers\": 5865895.0, \"Song ID\": \"733c1CWmIGymoQXdp7Us88\", \"Genre\": \"['melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 68.0, \"Danceability\": 0.819, \"Energy\": 0.654, \"Loudness\": -6.665, \"Speechiness\": 0.136, \"Acousticness\": 0.517, \"Liveness\": 0.0996, \"Tempo\": 133.503, \"Duration (ms)\": 188563.0, \"Valence\": 0.455, \"Chord\": \"B\"}, {\"Index\": 1347, \"Highest Charting Position\": 105, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Girl\", \"Streams\": 5434180, \"Artist\": \"Myke Towers\", \"Artist Followers\": 6161098.0, \"Song ID\": \"43NqTeL8pgBxKHPMiJKUP5\", \"Genre\": \"['trap latino']\", \"Release Date\": \"2020-01-24\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 72.0, \"Danceability\": 0.733, \"Energy\": 0.708, \"Loudness\": -4.957, \"Speechiness\": 0.0937, \"Acousticness\": 0.0325, \"Liveness\": 0.324, \"Tempo\": 93.021, \"Duration (ms)\": 186427.0, \"Valence\": 0.694, \"Chord\": \"F#/Gb\"}, {\"Index\": 1348, \"Highest Charting Position\": 104, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Puesto Pa' Guerrial\", \"Streams\": 5359969, \"Artist\": \"Bad Bunny, Myke Towers\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5gCg2qMPzKkW4jS4dBKdDs\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 64.0, \"Danceability\": 0.867, \"Energy\": 0.686, \"Loudness\": -5.342, \"Speechiness\": 0.221, \"Acousticness\": 0.311, \"Liveness\": 0.1, \"Tempo\": 139.968, \"Duration (ms)\": 190207.0, \"Valence\": 0.658, \"Chord\": \"E\"}, {\"Index\": 1349, \"Highest Charting Position\": 114, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Definitivamente\", \"Streams\": 5325447, \"Artist\": \"Daddy Yankee, Sech\", \"Artist Followers\": 23936368.0, \"Song ID\": \"113PlnpZbHd3WIqeYjhZWv\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 66.0, \"Danceability\": 0.813, \"Energy\": 0.764, \"Loudness\": -3.39, \"Speechiness\": 0.105, \"Acousticness\": 0.586, \"Liveness\": 0.253, \"Tempo\": 100.047, \"Duration (ms)\": 217773.0, \"Valence\": 0.429, \"Chord\": \"G#/Ab\"}, {\"Index\": 1350, \"Highest Charting Position\": 41, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"South of the Border (feat. Camila Cabello & Cardi B)\", \"Streams\": 5315827, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"4vUmTMuQqjdnvlZmAH61Qk\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-07-12\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.857, \"Energy\": 0.621, \"Loudness\": -6.376, \"Speechiness\": 0.0825, \"Acousticness\": 0.148, \"Liveness\": 0.0865, \"Tempo\": 97.989, \"Duration (ms)\": 204467.0, \"Valence\": 0.668, \"Chord\": \"A\"}, {\"Index\": 1351, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"I Fall Apart\", \"Streams\": 5251918, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"75ZvA4QfFiZvzhj2xkaWAh\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2016-12-09\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 80.0, \"Danceability\": 0.556, \"Energy\": 0.538, \"Loudness\": -5.408, \"Speechiness\": 0.0382, \"Acousticness\": 0.0689, \"Liveness\": 0.196, \"Tempo\": 143.95, \"Duration (ms)\": 223347.0, \"Valence\": 0.291, \"Chord\": \"G#/Ab\"}, {\"Index\": 1352, \"Highest Charting Position\": 191, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"fuck, i'm lonely (with Anne-Marie)\", \"Streams\": 5226991, \"Artist\": \"Lauv\", \"Artist Followers\": 4442273.0, \"Song ID\": \"09PGubKAMryhOWv1LHpCYz\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 74.0, \"Danceability\": 0.806, \"Energy\": 0.558, \"Loudness\": -6.46, \"Speechiness\": 0.0683, \"Acousticness\": 0.482, \"Liveness\": 0.0618, \"Tempo\": 95.016, \"Duration (ms)\": 198973.0, \"Valence\": 0.678, \"Chord\": \"A\"}, {\"Index\": 1353, \"Highest Charting Position\": 78, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Aventura\", \"Streams\": 5206102, \"Artist\": \"Lunay, Ozuna, Anuel AA\", \"Artist Followers\": 4963516.0, \"Song ID\": \"37zdqI4r1gswIzczSBkRon\", \"Genre\": \"['latin', 'latin pop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-10-25\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.729, \"Energy\": 0.726, \"Loudness\": -3.208, \"Speechiness\": 0.0422, \"Acousticness\": 0.223, \"Liveness\": 0.101, \"Tempo\": 92.025, \"Duration (ms)\": 217130.0, \"Valence\": 0.876, \"Chord\": \"F\"}, {\"Index\": 1354, \"Highest Charting Position\": 12, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Rare\", \"Streams\": 5195842, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"7HMmFQsKsljwTw8bS7lu19\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 68.0, \"Danceability\": 0.838, \"Energy\": 0.545, \"Loudness\": -6.713, \"Speechiness\": 0.0706, \"Acousticness\": 0.208, \"Liveness\": 0.103, \"Tempo\": 114.998, \"Duration (ms)\": 220590.0, \"Valence\": 0.631, \"Chord\": \"F\"}, {\"Index\": 1355, \"Highest Charting Position\": 69, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"VIBEZ\", \"Streams\": 5121486, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"0fySG6A6qLE8IvDpayb5bM\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.768, \"Energy\": 0.652, \"Loudness\": -2.708, \"Speechiness\": 0.307, \"Acousticness\": 0.113, \"Liveness\": 0.107, \"Tempo\": 154.187, \"Duration (ms)\": 144935.0, \"Valence\": 0.777, \"Chord\": \"C#/Db\"}, {\"Index\": 1356, \"Highest Charting Position\": 69, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Mean It\", \"Streams\": 5110064, \"Artist\": \"Lauv, LANY\", \"Artist Followers\": 4442273.0, \"Song ID\": \"3uc8AGNL0KbvISIrjnfRvN\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.746, \"Energy\": 0.45, \"Loudness\": -8.543, \"Speechiness\": 0.0872, \"Acousticness\": 0.0407, \"Liveness\": 0.172, \"Tempo\": 95.998, \"Duration (ms)\": 232853.0, \"Valence\": 0.336, \"Chord\": \"G\"}, {\"Index\": 1357, \"Highest Charting Position\": 49, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"That Way\", \"Streams\": 12059592, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"5raTDhlbxFDnpn89bxArdH\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-01\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 67.0, \"Danceability\": 0.719, \"Energy\": 0.611, \"Loudness\": -5.01, \"Speechiness\": 0.0403, \"Acousticness\": 0.0582, \"Liveness\": 0.155, \"Tempo\": 129.962, \"Duration (ms)\": 212354.0, \"Valence\": 0.489, \"Chord\": \"G\"}, {\"Index\": 1358, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Live Off My Closet (feat. Future)\", \"Streams\": 7410327, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"6AyWdCtEn1DdxjnxPeojR2\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 59.0, \"Danceability\": 0.807, \"Energy\": 0.678, \"Loudness\": -3.244, \"Speechiness\": 0.177, \"Acousticness\": 0.0345, \"Liveness\": 0.0986, \"Tempo\": 147.004, \"Duration (ms)\": 173061.0, \"Valence\": 0.21, \"Chord\": \"F#/Gb\"}, {\"Index\": 1359, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Commercial (feat. Lil Uzi Vert)\", \"Streams\": 6540577, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"3tDqEKKUs6gf8zMvSuLyLA\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 67.0, \"Danceability\": 0.892, \"Energy\": 0.486, \"Loudness\": -8.637, \"Speechiness\": 0.384, \"Acousticness\": 0.048, \"Liveness\": 0.146, \"Tempo\": 120.998, \"Duration (ms)\": 214215.0, \"Valence\": 0.535, \"Chord\": \"B\"}, {\"Index\": 1360, \"Highest Charting Position\": 75, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Sum 2 Prove\", \"Streams\": 6497610, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"2u3EyuCqqV31woqGvO9LBz\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 71.0, \"Danceability\": 0.823, \"Energy\": 0.552, \"Loudness\": -7.57, \"Speechiness\": 0.324, \"Acousticness\": 0.0174, \"Liveness\": 0.122, \"Tempo\": 124.038, \"Duration (ms)\": 205760.0, \"Valence\": 0.418, \"Chord\": \"E\"}, {\"Index\": 1361, \"Highest Charting Position\": 47, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Filter\", \"Streams\": 5913946, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"0ono6UCNVZ1XqOm6j78Blu\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 79.0, \"Danceability\": 0.781, \"Energy\": 0.762, \"Loudness\": -5.188, \"Speechiness\": 0.0626, \"Acousticness\": 0.0222, \"Liveness\": 0.121, \"Tempo\": 110.042, \"Duration (ms)\": 180221.0, \"Valence\": 0.86, \"Chord\": \"A#/Bb\"}, {\"Index\": 1362, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Matrix\", \"Streams\": 5724739, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"7ygVaACDENw4PgLbN1awFE\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-02-24\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 55.0, \"Danceability\": 0.789, \"Energy\": 0.509, \"Loudness\": -8.766, \"Speechiness\": 0.291, \"Acousticness\": 0.768, \"Liveness\": 0.272, \"Tempo\": 114.957, \"Duration (ms)\": 183793.0, \"Valence\": 0.418, \"Chord\": \"A\"}, {\"Index\": 1363, \"Highest Charting Position\": 91, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Bellaquita - Remix\", \"Streams\": 5676621, \"Artist\": \"Dalex, Lenny Tav\\u00e1rez, Anitta, Natti Natasha, Farruko, Justin Quiles\", \"Artist Followers\": 3600989.0, \"Song ID\": \"1Xnn1TPyr5h0hpRAT4B4EA\", \"Genre\": \"['latin', 'r&b en espanol', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.795, \"Energy\": 0.715, \"Loudness\": -3.582, \"Speechiness\": 0.0838, \"Acousticness\": 0.141, \"Liveness\": 0.179, \"Tempo\": 165.941, \"Duration (ms)\": 304733.0, \"Valence\": 0.758, \"Chord\": \"C#/Db\"}, {\"Index\": 1364, \"Highest Charting Position\": 139, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Infeliz\", \"Streams\": 5490386, \"Artist\": \"Arcangel, Bad Bunny\", \"Artist Followers\": 6671084.0, \"Song ID\": \"4z6wo6PJG4Fve45OXK6D9m\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-12-20\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 72.0, \"Danceability\": 0.713, \"Energy\": 0.798, \"Loudness\": -3.147, \"Speechiness\": 0.219, \"Acousticness\": 0.366, \"Liveness\": 0.246, \"Tempo\": 176.073, \"Duration (ms)\": 221103.0, \"Valence\": 0.721, \"Chord\": \"C#/Db\"}, {\"Index\": 1365, \"Highest Charting Position\": 60, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Que Tire Pa Lante\", \"Streams\": 5436773, \"Artist\": \"Daddy Yankee\", \"Artist Followers\": 23936368.0, \"Song ID\": \"6RyaV7owmVU6fzEPE17sF1\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-10-18\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.658, \"Energy\": 0.901, \"Loudness\": -2.814, \"Speechiness\": 0.0357, \"Acousticness\": 0.0478, \"Liveness\": 0.12, \"Tempo\": 93.979, \"Duration (ms)\": 210520.0, \"Valence\": 0.708, \"Chord\": \"G\"}, {\"Index\": 1366, \"Highest Charting Position\": 32, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Futsal Shuffle 2020\", \"Streams\": 5386512, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2Ec33AVlkTTq8BHFgBTdQs\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-12\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.881, \"Energy\": 0.457, \"Loudness\": -8.191, \"Speechiness\": 0.156, \"Acousticness\": 0.0327, \"Liveness\": 0.231, \"Tempo\": 136.97, \"Duration (ms)\": 198913.0, \"Valence\": 0.296, \"Chord\": \"G\"}, {\"Index\": 1367, \"Highest Charting Position\": 123, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"GOODMORNINGTOKYO!\", \"Streams\": 5286044, \"Artist\": \"TOKYO\\u2019S REVENGE\", \"Artist Followers\": 313480.0, \"Song ID\": \"0Q2n5yzl2XRqYbV77tZNYp\", \"Genre\": \"['meme rap', 'sad rap', 'vapor trap', 'viral rap']\", \"Release Date\": \"2019-10-18\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 74.0, \"Danceability\": 0.907, \"Energy\": 0.539, \"Loudness\": -7.782, \"Speechiness\": 0.36, \"Acousticness\": 0.0408, \"Liveness\": 0.253, \"Tempo\": 124.918, \"Duration (ms)\": 150115.0, \"Valence\": 0.664, \"Chord\": \"E\"}, {\"Index\": 1368, \"Highest Charting Position\": 58, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Own It (feat. Ed Sheeran & Burna Boy)\", \"Streams\": 5273046, \"Artist\": \"Stormzy\", \"Artist Followers\": 2317758.0, \"Song ID\": \"4QPEwDdOMhY7rNS05mTyMR\", \"Genre\": \"['grime', 'uk hip hop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.817, \"Energy\": 0.781, \"Loudness\": -4.178, \"Speechiness\": 0.112, \"Acousticness\": 0.00838, \"Liveness\": 0.123, \"Tempo\": 104.0, \"Duration (ms)\": 216707.0, \"Valence\": 0.359, \"Chord\": \"G\"}, {\"Index\": 1369, \"Highest Charting Position\": 128, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Life Is Good (feat. Drake, DaBaby & Lil Baby) - Remix\", \"Streams\": 5260351, \"Artist\": \"Future\", \"Artist Followers\": 10491105.0, \"Song ID\": \"4iiWcajF1fEUpwcUewc464\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-02-15\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 61.0, \"Danceability\": 0.81, \"Energy\": 0.566, \"Loudness\": -8.33, \"Speechiness\": 0.433, \"Acousticness\": 0.107, \"Liveness\": 0.122, \"Tempo\": 142.069, \"Duration (ms)\": 315346.0, \"Valence\": 0.582, \"Chord\": \"F\"}, {\"Index\": 1370, \"Highest Charting Position\": 58, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"My Time\", \"Streams\": 5212053, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4vTgx6h4seHvkuFh84JXYP\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 74.0, \"Danceability\": 0.674, \"Energy\": 0.64, \"Loudness\": -5.139, \"Speechiness\": 0.0339, \"Acousticness\": 0.151, \"Liveness\": 0.0925, \"Tempo\": 99.908, \"Duration (ms)\": 234458.0, \"Valence\": 0.664, \"Chord\": \"C\"}, {\"Index\": 1371, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"100k Cash\", \"Streams\": 5192813, \"Artist\": \"Capital Bra, Samra\", \"Artist Followers\": 4093115.0, \"Song ID\": \"033if6Adj8fwBYsQzHOfQ8\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-02-27\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 52.0, \"Danceability\": 0.701, \"Energy\": 0.714, \"Loudness\": -5.906, \"Speechiness\": 0.524, \"Acousticness\": 0.289, \"Liveness\": 0.0883, \"Tempo\": 86.91, \"Duration (ms)\": 173353.0, \"Valence\": 0.604, \"Chord\": \"A#/Bb\"}, {\"Index\": 1372, \"Highest Charting Position\": 185, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Drown (feat. Clinton Kane)\", \"Streams\": 5186141, \"Artist\": \"Martin Garrix\", \"Artist Followers\": 14921269.0, \"Song ID\": \"4RVtBlHFKj51Ipvpfv5ER4\", \"Genre\": \"['dance pop', 'dutch edm', 'edm', 'pop', 'pop dance', 'progressive house', 'tropical house']\", \"Release Date\": \"2020-02-27\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 74.0, \"Danceability\": 0.573, \"Energy\": 0.739, \"Loudness\": -5.455, \"Speechiness\": 0.0581, \"Acousticness\": 0.212, \"Liveness\": 0.175, \"Tempo\": 120.077, \"Duration (ms)\": 174062.0, \"Valence\": 0.363, \"Chord\": \"A\"}, {\"Index\": 1373, \"Highest Charting Position\": 103, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"me & ur ghost\", \"Streams\": 5184069, \"Artist\": \"blackbear\", \"Artist Followers\": 4272745.0, \"Song ID\": \"38KsRHYE10bG0paU78gL9r\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 71.0, \"Danceability\": 0.742, \"Energy\": 0.679, \"Loudness\": -4.594, \"Speechiness\": 0.0259, \"Acousticness\": 0.0488, \"Liveness\": 0.0754, \"Tempo\": 100.041, \"Duration (ms)\": 201398.0, \"Valence\": 0.856, \"Chord\": \"G\"}, {\"Index\": 1374, \"Highest Charting Position\": 146, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"QUE PRETENDES\", \"Streams\": 5141047, \"Artist\": \"J Balvin, Bad Bunny\", \"Artist Followers\": 29067437.0, \"Song ID\": \"25ZAibhr3bdlMCLmubZDVt\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.639, \"Energy\": 0.791, \"Loudness\": -4.443, \"Speechiness\": 0.253, \"Acousticness\": 0.0275, \"Liveness\": 0.362, \"Tempo\": 92.603, \"Duration (ms)\": 222347.0, \"Valence\": 0.939, \"Chord\": \"A#/Bb\"}, {\"Index\": 1375, \"Highest Charting Position\": 140, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"You Need To Calm Down\", \"Streams\": 5115153, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6RRNNciQGZEXnqk8SQ9yv5\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.771, \"Energy\": 0.671, \"Loudness\": -5.617, \"Speechiness\": 0.0553, \"Acousticness\": 0.00929, \"Liveness\": 0.0637, \"Tempo\": 85.026, \"Duration (ms)\": 171360.0, \"Valence\": 0.714, \"Chord\": \"D\"}, {\"Index\": 1376, \"Highest Charting Position\": 90, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Quizas\", \"Streams\": 5112244, \"Artist\": \"Rich Music LTD, Sech, Dalex, Justin Quiles, Lenny Tav\\u00e1rez, Feid, Wisin, Zion\", \"Artist Followers\": 206225.0, \"Song ID\": \"5Id5B3dxJZhPcV9GzgYZZe\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-10-11\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.727, \"Energy\": 0.815, \"Loudness\": -2.454, \"Speechiness\": 0.153, \"Acousticness\": 0.0258, \"Liveness\": 0.231, \"Tempo\": 176.075, \"Duration (ms)\": 216067.0, \"Valence\": 0.677, \"Chord\": \"D#/Eb\"}, {\"Index\": 1377, \"Highest Charting Position\": 106, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Soltera - Remix\", \"Streams\": 5078459, \"Artist\": \"Lunay, Daddy Yankee, Bad Bunny\", \"Artist Followers\": 4963516.0, \"Song ID\": \"1c0hsvHLELX6y8qymnpLKL\", \"Genre\": \"['latin', 'latin pop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-05-10\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.795, \"Energy\": 0.783, \"Loudness\": -4.271, \"Speechiness\": 0.0432, \"Acousticness\": 0.361, \"Liveness\": 0.437, \"Tempo\": 92.01, \"Duration (ms)\": 266087.0, \"Valence\": 0.799, \"Chord\": \"F\"}, {\"Index\": 1378, \"Highest Charting Position\": 46, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Trampoline (with ZAYN)\", \"Streams\": 5075520, \"Artist\": \"SHAED\", \"Artist Followers\": 139434.0, \"Song ID\": \"1iQDltZqI7BXnHrFy4Qo1k\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-09-26\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 73.0, \"Danceability\": 0.619, \"Energy\": 0.459, \"Loudness\": -5.782, \"Speechiness\": 0.0334, \"Acousticness\": 0.56, \"Liveness\": 0.137, \"Tempo\": 126.803, \"Duration (ms)\": 184280.0, \"Valence\": 0.498, \"Chord\": \"G\"}, {\"Index\": 1379, \"Highest Charting Position\": 82, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Truth Hurts\", \"Streams\": 5024683, \"Artist\": \"Lizzo\", \"Artist Followers\": 3991674.0, \"Song ID\": \"3HWzoMvoF3TQfYg4UPszDq\", \"Genre\": \"['dance pop', 'escape room', 'minnesota hip hop', 'pop', 'pop rap', 'post-teen pop', 'trap queen']\", \"Release Date\": \"2019-04-19\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.715, \"Energy\": 0.624, \"Loudness\": -3.046, \"Speechiness\": 0.114, \"Acousticness\": 0.11, \"Liveness\": 0.123, \"Tempo\": 158.087, \"Duration (ms)\": 173325.0, \"Valence\": 0.412, \"Chord\": \"E\"}, {\"Index\": 1380, \"Highest Charting Position\": 91, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"bury a friend\", \"Streams\": 5020303, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"7p6ZK1vOxKELFwlDfwkJCp\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 1.0, \"Danceability\": 0.887, \"Energy\": 0.388, \"Loudness\": -14.505, \"Speechiness\": 0.349, \"Acousticness\": 0.739, \"Liveness\": 0.106, \"Tempo\": 120.035, \"Duration (ms)\": 193143.0, \"Valence\": 0.205, \"Chord\": \"G#/Ab\"}, {\"Index\": 1381, \"Highest Charting Position\": 54, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Louder than bombs\", \"Streams\": 10016907, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3op7HNwLli54MBjFGzIlZO\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.643, \"Energy\": 0.667, \"Loudness\": -6.993, \"Speechiness\": 0.152, \"Acousticness\": 0.0433, \"Liveness\": 0.0904, \"Tempo\": 145.999, \"Duration (ms)\": 217404.0, \"Valence\": 0.485, \"Chord\": \"C\"}, {\"Index\": 1382, \"Highest Charting Position\": 56, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"UGH!\", \"Streams\": 9991177, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"1aKuG1GG76xPLUkjBbQo3W\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.72, \"Energy\": 0.824, \"Loudness\": -5.086, \"Speechiness\": 0.128, \"Acousticness\": 0.0394, \"Liveness\": 0.0509, \"Tempo\": 165.998, \"Duration (ms)\": 225012.0, \"Valence\": 0.333, \"Chord\": \"A#/Bb\"}, {\"Index\": 1383, \"Highest Charting Position\": 67, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"00:00 (Zero O\\u2019Clock)\", \"Streams\": 9372219, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4AlihYDqxXshKhvh5tnMfP\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.566, \"Energy\": 0.548, \"Loudness\": -6.456, \"Speechiness\": 0.0579, \"Acousticness\": 0.0802, \"Liveness\": 0.11, \"Tempo\": 157.999, \"Duration (ms)\": 250296.0, \"Valence\": 0.196, \"Chord\": \"C#/Db\"}, {\"Index\": 1384, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Friends\", \"Streams\": 8822365, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"7w05lsU2VLSeiT8Nukrv5M\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.55, \"Energy\": 0.747, \"Loudness\": -5.211, \"Speechiness\": 0.0407, \"Acousticness\": 0.0668, \"Liveness\": 0.0536, \"Tempo\": 79.98, \"Duration (ms)\": 199339.0, \"Valence\": 0.648, \"Chord\": \"C#/Db\"}, {\"Index\": 1385, \"Highest Charting Position\": 75, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"We are Bulletproof : the Eternal\", \"Streams\": 8516710, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"44WLOqH7QayQOQdeUHeKUK\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.526, \"Energy\": 0.575, \"Loudness\": -5.215, \"Speechiness\": 0.0309, \"Acousticness\": 0.225, \"Liveness\": 0.108, \"Tempo\": 84.047, \"Duration (ms)\": 261543.0, \"Valence\": 0.19, \"Chord\": \"A\"}, {\"Index\": 1386, \"Highest Charting Position\": 79, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Inner Child\", \"Streams\": 8312399, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4BKOjYosPhw334moS3wlbO\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 71.0, \"Danceability\": 0.589, \"Energy\": 0.696, \"Loudness\": -7.981, \"Speechiness\": 0.0725, \"Acousticness\": 0.017, \"Liveness\": 0.0808, \"Tempo\": 134.953, \"Duration (ms)\": 233266.0, \"Valence\": 0.332, \"Chord\": \"B\"}, {\"Index\": 1387, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Moon\", \"Streams\": 7850129, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"1xfXXujIlLZAx5wpu46Nyk\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.703, \"Energy\": 0.646, \"Loudness\": -6.658, \"Speechiness\": 0.0596, \"Acousticness\": 0.0104, \"Liveness\": 0.191, \"Tempo\": 141.87, \"Duration (ms)\": 208590.0, \"Valence\": 0.64, \"Chord\": \"F#/Gb\"}, {\"Index\": 1388, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Outro : Ego\", \"Streams\": 6857808, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3r9FFjLrAIQjoR8pSHVPC9\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 69.0, \"Danceability\": 0.808, \"Energy\": 0.903, \"Loudness\": -3.106, \"Speechiness\": 0.0958, \"Acousticness\": 0.0121, \"Liveness\": 0.0993, \"Tempo\": 116.988, \"Duration (ms)\": 196199.0, \"Valence\": 0.473, \"Chord\": \"C\"}, {\"Index\": 1389, \"Highest Charting Position\": 109, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Interlude : Shadow\", \"Streams\": 6655856, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"2Nib4r0saYQf2pUV4RFDhl\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 68.0, \"Danceability\": 0.385, \"Energy\": 0.798, \"Loudness\": -6.439, \"Speechiness\": 0.483, \"Acousticness\": 0.115, \"Liveness\": 0.181, \"Tempo\": 149.756, \"Duration (ms)\": 259821.0, \"Valence\": 0.141, \"Chord\": \"A\"}, {\"Index\": 1390, \"Highest Charting Position\": 120, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Respect\", \"Streams\": 6373954, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"37TSJmYKLxXmx8OehFpqMN\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 67.0, \"Danceability\": 0.661, \"Energy\": 0.84, \"Loudness\": -4.805, \"Speechiness\": 0.116, \"Acousticness\": 0.00485, \"Liveness\": 0.287, \"Tempo\": 91.457, \"Duration (ms)\": 237540.0, \"Valence\": 0.524, \"Chord\": \"C\"}, {\"Index\": 1391, \"Highest Charting Position\": 154, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Tudo Ok\", \"Streams\": 5510844, \"Artist\": \"Thiaguinho MT, Mila, JS o M\\u00e3o de Ouro\", \"Artist Followers\": 28017.0, \"Song ID\": \"4HUZBG98TYbxSR9V1V2DWS\", \"Genre\": \"['brega funk', 'funk carioca']\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 57.0, \"Danceability\": 0.814, \"Energy\": 0.755, \"Loudness\": -6.164, \"Speechiness\": 0.0942, \"Acousticness\": 0.239, \"Liveness\": 0.306, \"Tempo\": 79.976, \"Duration (ms)\": 178500.0, \"Valence\": 0.963, \"Chord\": \"B\"}, {\"Index\": 1392, \"Highest Charting Position\": 128, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Perreo en La Luna\", \"Streams\": 5135469, \"Artist\": \"Rich Music LTD, Sech, Dalex, Justin Quiles, Lenny Tav\\u00e1rez, Feid\", \"Artist Followers\": 206225.0, \"Song ID\": \"0RDgqtvOHLwcI6yz9bjsZV\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-10-11\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.711, \"Energy\": 0.757, \"Loudness\": -4.188, \"Speechiness\": 0.29, \"Acousticness\": 0.268, \"Liveness\": 0.367, \"Tempo\": 174.013, \"Duration (ms)\": 218587.0, \"Valence\": 0.724, \"Chord\": \"C#/Db\"}, {\"Index\": 1393, \"Highest Charting Position\": 129, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Lose Yourself - From \\\"8 Mile\\\" Soundtrack\", \"Streams\": 5118004, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5Z01UMMf7V1o0MzF86s6WJ\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2005-12-06\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 75.0, \"Danceability\": 0.692, \"Energy\": 0.744, \"Loudness\": -4.565, \"Speechiness\": 0.257, \"Acousticness\": 0.00868, \"Liveness\": 0.359, \"Tempo\": 171.374, \"Duration (ms)\": 326467.0, \"Valence\": 0.0612, \"Chord\": \"D\"}, {\"Index\": 1394, \"Highest Charting Position\": 118, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"all the good girls go to hell\", \"Streams\": 5074485, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"6IRdLKIyS4p7XNiP8r6rsx\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-03-29\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.726, \"Energy\": 0.444, \"Loudness\": -8.922, \"Speechiness\": 0.372, \"Acousticness\": 0.283, \"Liveness\": 0.177, \"Tempo\": 185.044, \"Duration (ms)\": 168840.0, \"Valence\": 0.569, \"Chord\": \"G#/Ab\"}, {\"Index\": 1395, \"Highest Charting Position\": 155, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"SENTAD\\u00c3O\", \"Streams\": 5013019, \"Artist\": \"PEDRO SAMPAIO, Felipe Original, JS o M\\u00e3o de Ouro\", \"Artist Followers\": 1050520.0, \"Song ID\": \"4lKuzrdZrJuCAedbIslF3A\", \"Genre\": \"['funk carioca']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2019-12-27--2020-01-03\", \"Popularity\": 64.0, \"Danceability\": 0.68, \"Energy\": 0.869, \"Loudness\": -1.94, \"Speechiness\": 0.0589, \"Acousticness\": 0.178, \"Liveness\": 0.223, \"Tempo\": 173.997, \"Duration (ms)\": 143448.0, \"Valence\": 0.924, \"Chord\": \"F#/Gb\"}, {\"Index\": 1396, \"Highest Charting Position\": 182, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Lottery (Renegade)\", \"Streams\": 4994448, \"Artist\": \"K CAMP\", \"Artist Followers\": 1347589.0, \"Song ID\": \"4dZTZbmJBCCofAExHwefda\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'pop r&b', 'pop rap', 'r&b', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 61.0, \"Danceability\": 0.915, \"Energy\": 0.556, \"Loudness\": -8.601, \"Speechiness\": 0.216, \"Acousticness\": 0.0145, \"Liveness\": 0.0733, \"Tempo\": 148.964, \"Duration (ms)\": 170947.0, \"Valence\": 0.67, \"Chord\": \"C#/Db\"}, {\"Index\": 1397, \"Highest Charting Position\": 104, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Si Te Vas\", \"Streams\": 4954292, \"Artist\": \"Sech, Ozuna\", \"Artist Followers\": 8766508.0, \"Song ID\": \"6Y4PDQv4XjYjHLeLmvyOt0\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-09-26\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.73, \"Energy\": 0.644, \"Loudness\": -4.124, \"Speechiness\": 0.132, \"Acousticness\": 0.0933, \"Liveness\": 0.143, \"Tempo\": 174.101, \"Duration (ms)\": 204907.0, \"Valence\": 0.554, \"Chord\": \"C\"}, {\"Index\": 1398, \"Highest Charting Position\": 121, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Que Calor (with J Balvin & El Alfa)\", \"Streams\": 4950254, \"Artist\": \"Major Lazer, Diplo\", \"Artist Followers\": 6223652.0, \"Song ID\": \"3iQGDAAKMrlJarnaYNgnSE\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'moombahton', 'pop', 'pop dance', 'pop rap']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 29.0, \"Danceability\": 0.873, \"Energy\": 0.656, \"Loudness\": -6.043, \"Speechiness\": 0.068, \"Acousticness\": 0.00477, \"Liveness\": 0.0726, \"Tempo\": 125.982, \"Duration (ms)\": 206811.0, \"Valence\": 0.546, \"Chord\": \"G#/Ab\"}, {\"Index\": 1399, \"Highest Charting Position\": 186, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Rich Rich\", \"Streams\": 4938864, \"Artist\": \"Ufo361\", \"Artist Followers\": 1700759.0, \"Song ID\": \"2QfmSvSMwTXcvlIkU0w1Yk\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 50.0, \"Danceability\": 0.548, \"Energy\": 0.648, \"Loudness\": -4.796, \"Speechiness\": 0.292, \"Acousticness\": 0.0842, \"Liveness\": 0.123, \"Tempo\": 141.937, \"Duration (ms)\": 204319.0, \"Valence\": 0.232, \"Chord\": \"E\"}, {\"Index\": 1400, \"Highest Charting Position\": 86, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Indeciso\", \"Streams\": 4897374, \"Artist\": \"Reik, J Balvin, Lalo Ebratt\", \"Artist Followers\": 1251372.0, \"Song ID\": \"0FnPT2g07W4aXuHjniC1of\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.738, \"Energy\": 0.748, \"Loudness\": -4.902, \"Speechiness\": 0.0453, \"Acousticness\": 0.182, \"Liveness\": 0.109, \"Tempo\": 94.949, \"Duration (ms)\": 217253.0, \"Valence\": 0.896, \"Chord\": \"C\"}, {\"Index\": 1401, \"Highest Charting Position\": 148, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"i love you\", \"Streams\": 4863910, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"0np7TYPZSum9xTxe9QTr21\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-03--2020-01-10\", \"Popularity\": 2.0, \"Danceability\": 0.42, \"Energy\": 0.131, \"Loudness\": -18.435, \"Speechiness\": 0.0382, \"Acousticness\": 0.953, \"Liveness\": 0.109, \"Tempo\": 137.421, \"Duration (ms)\": 291796.0, \"Valence\": 0.12, \"Chord\": \"C\"}, {\"Index\": 1402, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Mejor\", \"Streams\": 4851895, \"Artist\": \"Dalex, Sech\", \"Artist Followers\": 3600989.0, \"Song ID\": \"6C1jKbkCUgFws7M0M4oGCB\", \"Genre\": \"['latin', 'r&b en espanol', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 63.0, \"Danceability\": 0.524, \"Energy\": 0.577, \"Loudness\": -4.501, \"Speechiness\": 0.18, \"Acousticness\": 0.185, \"Liveness\": 0.103, \"Tempo\": 175.396, \"Duration (ms)\": 201361.0, \"Valence\": 0.19, \"Chord\": \"D\"}, {\"Index\": 1403, \"Highest Charting Position\": 57, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Give No Fxk\", \"Streams\": 9652399, \"Artist\": \"Migos, Travis Scott, Young Thug\", \"Artist Followers\": 11692972.0, \"Song ID\": \"6ZelF5APDN5r6XnFqcnvWR\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 59.0, \"Danceability\": 0.904, \"Energy\": 0.627, \"Loudness\": -5.608, \"Speechiness\": 0.222, \"Acousticness\": 0.0303, \"Liveness\": 0.0923, \"Tempo\": 145.976, \"Duration (ms)\": 224243.0, \"Valence\": 0.236, \"Chord\": \"C#/Db\"}, {\"Index\": 1404, \"Highest Charting Position\": 61, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Come Around Me\", \"Streams\": 9533583, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2o9LAypwGH4ctV0i9boo6d\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 66.0, \"Danceability\": 0.648, \"Energy\": 0.681, \"Loudness\": -8.389, \"Speechiness\": 0.0378, \"Acousticness\": 0.263, \"Liveness\": 0.0971, \"Tempo\": 157.941, \"Duration (ms)\": 200773.0, \"Valence\": 0.767, \"Chord\": \"D\"}, {\"Index\": 1405, \"Highest Charting Position\": 64, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Habitual\", \"Streams\": 9120086, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"40qyPyljksBEqlNw5sW37T\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 62.0, \"Danceability\": 0.764, \"Energy\": 0.443, \"Loudness\": -6.625, \"Speechiness\": 0.0439, \"Acousticness\": 0.52, \"Liveness\": 0.0749, \"Tempo\": 138.999, \"Duration (ms)\": 168200.0, \"Valence\": 0.63, \"Chord\": \"E\"}, {\"Index\": 1406, \"Highest Charting Position\": 65, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"All Around Me\", \"Streams\": 9010535, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5Py8zRKGkZvgHniVVtvNCN\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 63.0, \"Danceability\": 0.566, \"Energy\": 0.438, \"Loudness\": -7.564, \"Speechiness\": 0.0367, \"Acousticness\": 0.809, \"Liveness\": 0.212, \"Tempo\": 117.127, \"Duration (ms)\": 136907.0, \"Valence\": 0.692, \"Chord\": \"C\"}, {\"Index\": 1407, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Get Me (feat. Kehlani)\", \"Streams\": 8362828, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5VwwpU7KsLhgfbMEecedhJ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 61.0, \"Danceability\": 0.832, \"Energy\": 0.508, \"Loudness\": -6.913, \"Speechiness\": 0.149, \"Acousticness\": 0.0492, \"Liveness\": 0.107, \"Tempo\": 109.352, \"Duration (ms)\": 185427.0, \"Valence\": 0.75, \"Chord\": \"F#/Gb\"}, {\"Index\": 1408, \"Highest Charting Position\": 79, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Second Emotion (feat. Travis Scott)\", \"Streams\": 8109572, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"1PnAx788sAvcI3ZxTlEyX8\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 61.0, \"Danceability\": 0.796, \"Energy\": 0.777, \"Loudness\": -6.112, \"Speechiness\": 0.0567, \"Acousticness\": 0.0276, \"Liveness\": 0.095, \"Tempo\": 141.97, \"Duration (ms)\": 202720.0, \"Valence\": 0.96, \"Chord\": \"B\"}, {\"Index\": 1409, \"Highest Charting Position\": 85, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Running Over (feat. Lil Dicky)\", \"Streams\": 7493188, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"75nKBP8jQu681pTNCtrEnn\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.774, \"Energy\": 0.603, \"Loudness\": -7.319, \"Speechiness\": 0.0591, \"Acousticness\": 0.438, \"Liveness\": 0.0869, \"Tempo\": 149.982, \"Duration (ms)\": 179627.0, \"Valence\": 0.977, \"Chord\": \"B\"}, {\"Index\": 1410, \"Highest Charting Position\": 86, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Available\", \"Streams\": 7473249, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"1b6tPXXCV2fSNtR3SKWUQA\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.702, \"Energy\": 0.608, \"Loudness\": -6.843, \"Speechiness\": 0.0359, \"Acousticness\": 0.0736, \"Liveness\": 0.129, \"Tempo\": 75.012, \"Duration (ms)\": 195333.0, \"Valence\": 0.597, \"Chord\": \"D#/Eb\"}, {\"Index\": 1411, \"Highest Charting Position\": 96, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Breathe Deeper\", \"Streams\": 7142364, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"3LbZIhU0smEU5SUnxod4j4\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 66.0, \"Danceability\": 0.664, \"Energy\": 0.848, \"Loudness\": -4.51, \"Speechiness\": 0.0322, \"Acousticness\": 0.0245, \"Liveness\": 0.172, \"Tempo\": 104.998, \"Duration (ms)\": 372867.0, \"Valence\": 0.502, \"Chord\": \"B\"}, {\"Index\": 1412, \"Highest Charting Position\": 103, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Changes\", \"Streams\": 6865229, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"521Os1SMlxmsoevsqyjNmJ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 62.0, \"Danceability\": 0.485, \"Energy\": 0.412, \"Loudness\": -7.766, \"Speechiness\": 0.042, \"Acousticness\": 0.738, \"Liveness\": 0.12, \"Tempo\": 64.062, \"Duration (ms)\": 135493.0, \"Valence\": 0.612, \"Chord\": \"A\"}, {\"Index\": 1413, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Confirmation\", \"Streams\": 6520106, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"60brXKLTC15vK0av5gIldm\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.438, \"Energy\": 0.315, \"Loudness\": -8.186, \"Speechiness\": 0.0375, \"Acousticness\": 0.608, \"Liveness\": 0.151, \"Tempo\": 190.064, \"Duration (ms)\": 170587.0, \"Valence\": 0.449, \"Chord\": \"G#/Ab\"}, {\"Index\": 1414, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Mios mit Bars\", \"Streams\": 6341141, \"Artist\": \"Luciano\", \"Artist Followers\": 942380.0, \"Song ID\": \"7Ek9e3eIuktIFjpDRQfmHE\", \"Genre\": \"['german drill', 'german hip hop']\", \"Release Date\": \"2020-02-13\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 57.0, \"Danceability\": 0.677, \"Energy\": 0.633, \"Loudness\": -7.353, \"Speechiness\": 0.0467, \"Acousticness\": 0.111, \"Liveness\": 0.217, \"Tempo\": 145.012, \"Duration (ms)\": 232147.0, \"Valence\": 0.404, \"Chord\": \"A\"}, {\"Index\": 1415, \"Highest Charting Position\": 135, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"E.T.A.\", \"Streams\": 6008945, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6PzOPrXx8tJEqace76yrv2\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.465, \"Energy\": 0.494, \"Loudness\": -7.595, \"Speechiness\": 0.066, \"Acousticness\": 0.49, \"Liveness\": 0.127, \"Tempo\": 127.298, \"Duration (ms)\": 176733.0, \"Valence\": 0.457, \"Chord\": \"E\"}, {\"Index\": 1416, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Borderline\", \"Streams\": 5921044, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"5hM5arv9KDbCHS0k9uqwjr\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 77.0, \"Danceability\": 0.621, \"Energy\": 0.873, \"Loudness\": -3.067, \"Speechiness\": 0.0369, \"Acousticness\": 0.0406, \"Liveness\": 0.0824, \"Tempo\": 97.96, \"Duration (ms)\": 237800.0, \"Valence\": 0.873, \"Chord\": \"F\"}, {\"Index\": 1417, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Take It Out On Me\", \"Streams\": 5858768, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"39nTNk5MfyiiRupTwn1iyC\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 54.0, \"Danceability\": 0.772, \"Energy\": 0.616, \"Loudness\": -4.673, \"Speechiness\": 0.102, \"Acousticness\": 0.00337, \"Liveness\": 0.104, \"Tempo\": 129.967, \"Duration (ms)\": 178013.0, \"Valence\": 0.279, \"Chord\": \"G\"}, {\"Index\": 1418, \"Highest Charting Position\": 67, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"No Shame\", \"Streams\": 5835260, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"5EbidH3lGB30WuDsoR4km6\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 62.0, \"Danceability\": 0.576, \"Energy\": 0.807, \"Loudness\": -3.019, \"Speechiness\": 0.0374, \"Acousticness\": 0.0185, \"Liveness\": 0.0963, \"Tempo\": 90.932, \"Duration (ms)\": 192737.0, \"Valence\": 0.479, \"Chord\": \"G\"}, {\"Index\": 1419, \"Highest Charting Position\": 160, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Might Not Give Up (feat. Young Thug)\", \"Streams\": 5503902, \"Artist\": \"A Boogie Wit da Hoodie\", \"Artist Followers\": 5865895.0, \"Song ID\": \"4l2rsMfr20dj6nf6i6F3Y8\", \"Genre\": \"['melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 57.0, \"Danceability\": 0.687, \"Energy\": 0.592, \"Loudness\": -6.378, \"Speechiness\": 0.224, \"Acousticness\": 0.203, \"Liveness\": 0.279, \"Tempo\": 178.83, \"Duration (ms)\": 225266.0, \"Valence\": 0.246, \"Chord\": \"D\"}, {\"Index\": 1420, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"That's What Love Is\", \"Streams\": 5440037, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2hLu8L8SNfCN4yKyPdX0h3\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 59.0, \"Danceability\": 0.639, \"Energy\": 0.437, \"Loudness\": -6.959, \"Speechiness\": 0.0355, \"Acousticness\": 0.692, \"Liveness\": 0.12, \"Tempo\": 147.575, \"Duration (ms)\": 165120.0, \"Valence\": 0.751, \"Chord\": \"A\"}, {\"Index\": 1421, \"Highest Charting Position\": 80, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Forever Yours - Avicii Tribute\", \"Streams\": 5421905, \"Artist\": \"Kygo, Sandro Cavazza\", \"Artist Followers\": 1251372.0, \"Song ID\": \"418ohXmKnlngIosIn6gG0H\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-10\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 15.0, \"Danceability\": 0.53, \"Energy\": 0.612, \"Loudness\": -8.794, \"Speechiness\": 0.0518, \"Acousticness\": 0.253, \"Liveness\": 0.246, \"Tempo\": 119.255, \"Duration (ms)\": 193847.0, \"Valence\": 0.433, \"Chord\": \"A#/Bb\"}, {\"Index\": 1422, \"Highest Charting Position\": 68, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Baby\", \"Streams\": 5376451, \"Artist\": \"Joker Bra, VIZE\", \"Artist Followers\": 191521.0, \"Song ID\": \"1V7JaMp11LKGwKiVmSetf0\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-01-30\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 63.0, \"Danceability\": 0.771, \"Energy\": 0.921, \"Loudness\": -4.228, \"Speechiness\": 0.109, \"Acousticness\": 0.166, \"Liveness\": 0.119, \"Tempo\": 128.021, \"Duration (ms)\": 148125.0, \"Valence\": 0.56, \"Chord\": \"C#/Db\"}, {\"Index\": 1423, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"One More Year\", \"Streams\": 5279739, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"5ozqshq2dtU7SYCpCBu0NE\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 56.0, \"Danceability\": 0.602, \"Energy\": 0.88, \"Loudness\": -5.414, \"Speechiness\": 0.0354, \"Acousticness\": 0.057, \"Liveness\": 0.284, \"Tempo\": 114.009, \"Duration (ms)\": 324013.0, \"Valence\": 0.493, \"Chord\": \"C#/Db\"}, {\"Index\": 1424, \"Highest Charting Position\": 14, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Good News\", \"Streams\": 5210780, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"1DWZUa5Mzf2BwzpHtgbHPY\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 75.0, \"Danceability\": 0.794, \"Energy\": 0.32, \"Loudness\": -12.92, \"Speechiness\": 0.173, \"Acousticness\": 0.853, \"Liveness\": 0.112, \"Tempo\": 174.088, \"Duration (ms)\": 342040.0, \"Valence\": 0.241, \"Chord\": \"C#/Db\"}, {\"Index\": 1425, \"Highest Charting Position\": 141, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"wish you were gay\", \"Streams\": 5187997, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"3Fj47GNK2kUF0uaEDgXLaD\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-03-29\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.853, \"Energy\": 0.351, \"Loudness\": -10.198, \"Speechiness\": 0.241, \"Acousticness\": 0.39, \"Liveness\": 0.752, \"Tempo\": 118.028, \"Duration (ms)\": 221543.0, \"Valence\": 0.282, \"Chord\": \"G\"}, {\"Index\": 1426, \"Highest Charting Position\": 61, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Only The Young - Featured in Miss Americana\", \"Streams\": 5111068, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2slqvGLwzZZYsT4K4Y1GBC\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 63.0, \"Danceability\": 0.56, \"Energy\": 0.78, \"Loudness\": -4.895, \"Speechiness\": 0.0517, \"Acousticness\": 0.00244, \"Liveness\": 0.0714, \"Tempo\": 93.516, \"Duration (ms)\": 157507.0, \"Valence\": 0.602, \"Chord\": \"F\"}, {\"Index\": 1427, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Lost In Yesterday\", \"Streams\": 5096624, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"5JWPUEov2wlX7c0jhYZpeB\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 69.0, \"Danceability\": 0.569, \"Energy\": 0.84, \"Loudness\": -4.123, \"Speechiness\": 0.118, \"Acousticness\": 0.0295, \"Liveness\": 0.0995, \"Tempo\": 183.059, \"Duration (ms)\": 249587.0, \"Valence\": 0.749, \"Chord\": \"C#/Db\"}, {\"Index\": 1428, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"At Least For Now\", \"Streams\": 5033764, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6VLkgf5YmLixsabdqiCVGU\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 54.0, \"Danceability\": 0.375, \"Energy\": 0.304, \"Loudness\": -9.897, \"Speechiness\": 0.0325, \"Acousticness\": 0.683, \"Liveness\": 0.196, \"Tempo\": 83.832, \"Duration (ms)\": 149653.0, \"Valence\": 0.295, \"Chord\": \"A\"}, {\"Index\": 1429, \"Highest Charting Position\": 167, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"you should see me in a crown\", \"Streams\": 4988054, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6WbvBhwCaUuYHcHGEuVgqo\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 0.0, \"Danceability\": 0.683, \"Energy\": 0.534, \"Loudness\": -10.348, \"Speechiness\": 0.189, \"Acousticness\": 0.519, \"Liveness\": 0.148, \"Tempo\": 150.469, \"Duration (ms)\": 180567.0, \"Valence\": 0.284, \"Chord\": \"E\"}, {\"Index\": 1430, \"Highest Charting Position\": 186, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Too Good At Goodbyes\", \"Streams\": 4984764, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"3VlbOrM6nYPprVvzBZllE5\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2017-11-03\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 72.0, \"Danceability\": 0.681, \"Energy\": 0.372, \"Loudness\": -8.237, \"Speechiness\": 0.0432, \"Acousticness\": 0.64, \"Liveness\": 0.169, \"Tempo\": 91.873, \"Duration (ms)\": 201000.0, \"Valence\": 0.476, \"Chord\": \"F\"}, {\"Index\": 1431, \"Highest Charting Position\": 7, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Intentions\", \"Streams\": 28509534, \"Artist\": \"Justin Bieber, Quavo\", \"Artist Followers\": 48544923.0, \"Song ID\": \"4umIPjkehX1r7uhmGvXiSV\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-07--2020-02-14\", \"Popularity\": 77.0, \"Danceability\": 0.806, \"Energy\": 0.546, \"Loudness\": -6.637, \"Speechiness\": 0.0575, \"Acousticness\": 0.3, \"Liveness\": 0.102, \"Tempo\": 147.986, \"Duration (ms)\": 212867.0, \"Valence\": 0.874, \"Chord\": \"A\"}, {\"Index\": 1432, \"Highest Charting Position\": 105, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Yikes\", \"Streams\": 6561188, \"Artist\": \"Nicki Minaj\", \"Artist Followers\": 22170982.0, \"Song ID\": \"75dLEqanQTupF3dtP9exT5\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'pop rap', 'post-teen pop', 'queens hip hop']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-02-07--2020-02-14\", \"Popularity\": 70.0, \"Danceability\": 0.911, \"Energy\": 0.637, \"Loudness\": -8.381, \"Speechiness\": 0.447, \"Acousticness\": 0.0409, \"Liveness\": 0.238, \"Tempo\": 149.996, \"Duration (ms)\": 156882.0, \"Valence\": 0.66, \"Chord\": \"G#/Ab\"}, {\"Index\": 1433, \"Highest Charting Position\": 66, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Yellow Hearts\", \"Streams\": 6554824, \"Artist\": \"Ant Saunders\", \"Artist Followers\": 82522.0, \"Song ID\": \"2W4yABdLc4Jnds67Poi5Nl\", \"Genre\": \"['chill r&b', 'pop']\", \"Release Date\": \"2019-06-18\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.866, \"Energy\": 0.438, \"Loudness\": -8.943, \"Speechiness\": 0.0719, \"Acousticness\": 0.177, \"Liveness\": 0.0743, \"Tempo\": 129.039, \"Duration (ms)\": 223258.0, \"Valence\": 0.695, \"Chord\": \"G\"}, {\"Index\": 1434, \"Highest Charting Position\": 120, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Birthday\", \"Streams\": 6207326, \"Artist\": \"Anne-Marie\", \"Artist Followers\": 8153871.0, \"Song ID\": \"5hff5RQeE84pznOt8WEWeO\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-02-07--2020-02-14\", \"Popularity\": 65.0, \"Danceability\": 0.609, \"Energy\": 0.785, \"Loudness\": -3.32, \"Speechiness\": 0.0891, \"Acousticness\": 0.0502, \"Liveness\": 0.171, \"Tempo\": 151.995, \"Duration (ms)\": 181467.0, \"Valence\": 0.756, \"Chord\": \"B\"}, {\"Index\": 1435, \"Highest Charting Position\": 16, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"HIGHEST IN THE ROOM (feat. ROSAL\\u00cdA & Lil Baby) - REMIX\", \"Streams\": 6107499, \"Artist\": \"Travis Scott\", \"Artist Followers\": 437907.0, \"Song ID\": \"7h0d2h0fUmzbs7zeFigJPn\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.559, \"Energy\": 0.491, \"Loudness\": -6.406, \"Speechiness\": 0.0346, \"Acousticness\": 0.0567, \"Liveness\": 0.0992, \"Tempo\": 153.131, \"Duration (ms)\": 244874.0, \"Valence\": 0.114, \"Chord\": \"D\"}, {\"Index\": 1436, \"Highest Charting Position\": 65, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Good as Hell (feat. Ariana Grande) - Remix\", \"Streams\": 6066001, \"Artist\": \"Lizzo\", \"Artist Followers\": 3991674.0, \"Song ID\": \"07Oz5StQ7GRoygNLaXs2pd\", \"Genre\": \"['dance pop', 'escape room', 'minnesota hip hop', 'pop', 'pop rap', 'post-teen pop', 'trap queen']\", \"Release Date\": \"2016\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.668, \"Energy\": 0.892, \"Loudness\": -3.001, \"Speechiness\": 0.0645, \"Acousticness\": 0.298, \"Liveness\": 0.735, \"Tempo\": 95.927, \"Duration (ms)\": 159011.0, \"Valence\": 0.478, \"Chord\": \"F\"}, {\"Index\": 1437, \"Highest Charting Position\": 70, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"I Do It (ft. Big Sean, Lil Baby)\", \"Streams\": 5561205, \"Artist\": \"Lil Wayne\", \"Artist Followers\": 10710088.0, \"Song ID\": \"1bRO28yzxgO3y3UmNR29TZ\", \"Genre\": \"['hip hop', 'new orleans rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 60.0, \"Danceability\": 0.804, \"Energy\": 0.528, \"Loudness\": -3.231, \"Speechiness\": 0.378, \"Acousticness\": 0.125, \"Liveness\": 0.41, \"Tempo\": 138.005, \"Duration (ms)\": 184440.0, \"Valence\": 0.321, \"Chord\": \"C#/Db\"}, {\"Index\": 1438, \"Highest Charting Position\": 45, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Get Me\", \"Streams\": 5236560, \"Artist\": \"Justin Bieber, Kehlani\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5VwwpU7KsLhgfbMEecedhJ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 61.0, \"Danceability\": 0.832, \"Energy\": 0.508, \"Loudness\": -6.913, \"Speechiness\": 0.149, \"Acousticness\": 0.0492, \"Liveness\": 0.107, \"Tempo\": 109.352, \"Duration (ms)\": 185427.0, \"Valence\": 0.75, \"Chord\": \"F#/Gb\"}, {\"Index\": 1439, \"Highest Charting Position\": 95, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Yo x Ti, Tu x Mi\", \"Streams\": 5202210, \"Artist\": \"ROSAL\\u00cdA, Ozuna\", \"Artist Followers\": 4769627.0, \"Song ID\": \"7BlBVFwvbWvcwNcUarQmjk\", \"Genre\": \"['r&b en espanol']\", \"Release Date\": \"2019-08-15\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.78, \"Energy\": 0.759, \"Loudness\": -3.292, \"Speechiness\": 0.225, \"Acousticness\": 0.462, \"Liveness\": 0.143, \"Tempo\": 91.952, \"Duration (ms)\": 201040.0, \"Valence\": 0.579, \"Chord\": \"C#/Db\"}, {\"Index\": 1440, \"Highest Charting Position\": 161, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"DJ No Pare (feat. Zion, Dalex, Lenny Tav\\u00e1rez) - Remix\", \"Streams\": 5148516, \"Artist\": \"Justin Quiles, Natti Natasha, Farruko\", \"Artist Followers\": 2897862.0, \"Song ID\": \"1ndyl3wJCFs872XZ3ztPk6\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.743, \"Energy\": 0.709, \"Loudness\": -3.922, \"Speechiness\": 0.0879, \"Acousticness\": 0.0451, \"Liveness\": 0.0809, \"Tempo\": 170.001, \"Duration (ms)\": 258600.0, \"Valence\": 0.831, \"Chord\": \"D#/Eb\"}, {\"Index\": 1441, \"Highest Charting Position\": 160, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"EARFQUAKE\", \"Streams\": 5079657, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6782693.0, \"Song ID\": \"5hVghJ4KaYES3BFUATCYn0\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 79.0, \"Danceability\": 0.554, \"Energy\": 0.498, \"Loudness\": -8.866, \"Speechiness\": 0.0685, \"Acousticness\": 0.23, \"Liveness\": 0.795, \"Tempo\": 79.635, \"Duration (ms)\": 190067.0, \"Valence\": 0.413, \"Chord\": \"A\"}, {\"Index\": 1442, \"Highest Charting Position\": 157, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Pa' Olvidarme De Ella\", \"Streams\": 5066711, \"Artist\": \"Piso 21, Christian Nodal\", \"Artist Followers\": 7226268.0, \"Song ID\": \"1cVlW9WQiGlFdWUXFdFZGh\", \"Genre\": \"['colombian pop', 'latin', 'latin pop', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.728, \"Energy\": 0.542, \"Loudness\": -5.195, \"Speechiness\": 0.0514, \"Acousticness\": 0.259, \"Liveness\": 0.136, \"Tempo\": 90.016, \"Duration (ms)\": 227234.0, \"Valence\": 0.637, \"Chord\": \"C\"}, {\"Index\": 1443, \"Highest Charting Position\": 89, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Loco Contigo (feat. J. Balvin & Tyga)\", \"Streams\": 5013732, \"Artist\": \"DJ Snake, J Balvin\", \"Artist Followers\": 7408249.0, \"Song ID\": \"6osaMSJh9NguagEDQcZaKx\", \"Genre\": \"['dance pop', 'edm', 'electronic trap', 'pop', 'pop dance']\", \"Release Date\": \"2019-07-25\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.694, \"Energy\": 0.758, \"Loudness\": -2.986, \"Speechiness\": 0.218, \"Acousticness\": 0.278, \"Liveness\": 0.102, \"Tempo\": 192.091, \"Duration (ms)\": 185195.0, \"Valence\": 0.371, \"Chord\": \"B\"}, {\"Index\": 1444, \"Highest Charting Position\": 54, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Psycho\", \"Streams\": 4991751, \"Artist\": \"Red Velvet\", \"Artist Followers\": 5688315.0, \"Song ID\": \"3CYH422oy1cZNoo0GTG1TK\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2019-12-23\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.664, \"Energy\": 0.666, \"Loudness\": -2.203, \"Speechiness\": 0.0446, \"Acousticness\": 0.193, \"Liveness\": 0.0854, \"Tempo\": 139.987, \"Duration (ms)\": 210560.0, \"Valence\": 0.405, \"Chord\": \"G#/Ab\"}, {\"Index\": 1445, \"Highest Charting Position\": 113, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Suge\", \"Streams\": 4986299, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"2gwkD6igEhQbDQegRCcdoB\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-03-01\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.876, \"Energy\": 0.662, \"Loudness\": -6.482, \"Speechiness\": 0.426, \"Acousticness\": 0.0608, \"Liveness\": 0.127, \"Tempo\": 75.445, \"Duration (ms)\": 163320.0, \"Valence\": 0.844, \"Chord\": \"D\"}, {\"Index\": 1446, \"Highest Charting Position\": 101, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Con Altura\", \"Streams\": 4961249, \"Artist\": \"ROSAL\\u00cdA, J Balvin, El Guincho\", \"Artist Followers\": 4769627.0, \"Song ID\": \"2qG5sZ7Si6sdK74qLxedYM\", \"Genre\": \"['r&b en espanol']\", \"Release Date\": \"2019-03-28\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.882, \"Energy\": 0.689, \"Loudness\": -4.027, \"Speechiness\": 0.124, \"Acousticness\": 0.39, \"Liveness\": 0.0501, \"Tempo\": 97.963, \"Duration (ms)\": 161627.0, \"Valence\": 0.746, \"Chord\": \"F#/Gb\"}, {\"Index\": 1447, \"Highest Charting Position\": 140, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Only Human\", \"Streams\": 4953866, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"0DiDStADDVh3SvAsoJAFMk\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-06-07\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.795, \"Energy\": 0.496, \"Loudness\": -5.883, \"Speechiness\": 0.0722, \"Acousticness\": 0.108, \"Liveness\": 0.0645, \"Tempo\": 94.01, \"Duration (ms)\": 183000.0, \"Valence\": 0.874, \"Chord\": \"C\"}, {\"Index\": 1448, \"Highest Charting Position\": 51, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Eleven\", \"Streams\": 4947780, \"Artist\": \"Khalid\", \"Artist Followers\": 14190858.0, \"Song ID\": \"18O00Y7yrkJ0pRXm1n21Og\", \"Genre\": \"['pop']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 68.0, \"Danceability\": 0.679, \"Energy\": 0.408, \"Loudness\": -9.754, \"Speechiness\": 0.0882, \"Acousticness\": 0.133, \"Liveness\": 0.23, \"Tempo\": 129.079, \"Duration (ms)\": 206080.0, \"Valence\": 0.151, \"Chord\": \"E\"}, {\"Index\": 1449, \"Highest Charting Position\": 135, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Talk (feat. Disclosure)\", \"Streams\": 4940984, \"Artist\": \"Khalid\", \"Artist Followers\": 14190858.0, \"Song ID\": \"6TqXcAFInzjp0bODyvrWEq\", \"Genre\": \"['pop']\", \"Release Date\": \"2019-04-05\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.9, \"Energy\": 0.4, \"Loudness\": -8.575, \"Speechiness\": 0.127, \"Acousticness\": 0.0516, \"Liveness\": 0.0599, \"Tempo\": 135.984, \"Duration (ms)\": 197573.0, \"Valence\": 0.346, \"Chord\": \"C\"}, {\"Index\": 1450, \"Highest Charting Position\": 117, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Hot (Remix) [feat. Gunna and Travis Scott]\", \"Streams\": 4905155, \"Artist\": \"Travis Scott, Young Thug\", \"Artist Followers\": 3337982.0, \"Song ID\": \"56AMYGJzxBO6p8v0wEe9de\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-11-01\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.845, \"Energy\": 0.631, \"Loudness\": -8.206, \"Speechiness\": 0.216, \"Acousticness\": 0.188, \"Liveness\": 0.0806, \"Tempo\": 111.983, \"Duration (ms)\": 279907.0, \"Valence\": 0.545, \"Chord\": \"G\"}, {\"Index\": 1451, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Weiss\", \"Streams\": 4872077, \"Artist\": \"Samra\", \"Artist Followers\": 1045091.0, \"Song ID\": \"38YP1STiBe3AZevFFJILf4\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-02-07--2020-02-14\", \"Popularity\": 56.0, \"Danceability\": 0.6, \"Energy\": 0.525, \"Loudness\": -6.585, \"Speechiness\": 0.423, \"Acousticness\": 0.393, \"Liveness\": 0.111, \"Tempo\": 96.989, \"Duration (ms)\": 162702.0, \"Valence\": 0.436, \"Chord\": \"D\"}, {\"Index\": 1452, \"Highest Charting Position\": 105, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Con Calma\", \"Streams\": 4861378, \"Artist\": \"Daddy Yankee, Snow\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3GIhMWNecxw8GyCFwviF6v\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 3.0, \"Danceability\": 0.737, \"Energy\": 0.86, \"Loudness\": -2.652, \"Speechiness\": 0.0594, \"Acousticness\": 0.11, \"Liveness\": 0.0574, \"Tempo\": 93.989, \"Duration (ms)\": 193227.0, \"Valence\": 0.656, \"Chord\": \"G#/Ab\"}, {\"Index\": 1453, \"Highest Charting Position\": 148, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"MIDDLE CHILD\", \"Streams\": 4836113, \"Artist\": \"J. Cole\", \"Artist Followers\": 14103694.0, \"Song ID\": \"2JvzF1RMd7lE3KmFlsyZD8\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2019-01-23\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.837, \"Energy\": 0.364, \"Loudness\": -11.713, \"Speechiness\": 0.276, \"Acousticness\": 0.149, \"Liveness\": 0.271, \"Tempo\": 123.984, \"Duration (ms)\": 213594.0, \"Valence\": 0.463, \"Chord\": \"G#/Ab\"}, {\"Index\": 1454, \"Highest Charting Position\": 136, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Otro Trago - Remix\", \"Streams\": 4803294, \"Artist\": \"Sech, Ozuna, Anuel AA, Darell, Nicky Jam\", \"Artist Followers\": 8766508.0, \"Song ID\": \"4bTZeO72FwMa6wKOiqoynL\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-07-26\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.725, \"Energy\": 0.79, \"Loudness\": -2.331, \"Speechiness\": 0.197, \"Acousticness\": 0.0711, \"Liveness\": 0.0602, \"Tempo\": 175.988, \"Duration (ms)\": 287773.0, \"Valence\": 0.763, \"Chord\": \"C\"}, {\"Index\": 1455, \"Highest Charting Position\": 113, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"FML\", \"Streams\": 6350496, \"Artist\": \"Arizona Zervas\", \"Artist Followers\": 621200.0, \"Song ID\": \"6lruHh1jF7ezgbLv72xYmf\", \"Genre\": \"['pop rap', 'rhode island rap']\", \"Release Date\": \"2018-06-03\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 74.0, \"Danceability\": 0.822, \"Energy\": 0.575, \"Loudness\": -5.95, \"Speechiness\": 0.0934, \"Acousticness\": 0.113, \"Liveness\": 0.106, \"Tempo\": 100.087, \"Duration (ms)\": 223000.0, \"Valence\": 0.616, \"Chord\": \"F\"}, {\"Index\": 1456, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"King Of My City\", \"Streams\": 5922748, \"Artist\": \"A Boogie Wit da Hoodie\", \"Artist Followers\": 1251372.0, \"Song ID\": \"4JEz0Iz8PnzHe5B0CkYSjP\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 0.0, \"Danceability\": 0.679, \"Energy\": 0.679, \"Loudness\": -6.747, \"Speechiness\": 0.167, \"Acousticness\": 0.443, \"Liveness\": 0.153, \"Tempo\": 119.921, \"Duration (ms)\": 148676.0, \"Valence\": 0.245, \"Chord\": \"E\"}, {\"Index\": 1457, \"Highest Charting Position\": 22, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Those Kinda Nights (feat. Ed Sheeran)\", \"Streams\": 5823422, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"0VSzREd1OjEWJ9tXoFHRQH\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 66.0, \"Danceability\": 0.794, \"Energy\": 0.637, \"Loudness\": -6.29, \"Speechiness\": 0.339, \"Acousticness\": 0.028, \"Liveness\": 0.0919, \"Tempo\": 103.868, \"Duration (ms)\": 177693.0, \"Valence\": 0.393, \"Chord\": \"E\"}, {\"Index\": 1458, \"Highest Charting Position\": 136, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Mon Ami\", \"Streams\": 5774770, \"Artist\": \"Samra\", \"Artist Followers\": 1045091.0, \"Song ID\": \"1R4xkZXQUQ8QJtAdwHkSgC\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-01-29\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 53.0, \"Danceability\": 0.801, \"Energy\": 0.731, \"Loudness\": -3.723, \"Speechiness\": 0.383, \"Acousticness\": 0.188, \"Liveness\": 0.111, \"Tempo\": 105.666, \"Duration (ms)\": 138409.0, \"Valence\": 0.537, \"Chord\": \"G#/Ab\"}, {\"Index\": 1459, \"Highest Charting Position\": 120, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Break My Stride\", \"Streams\": 5312936, \"Artist\": \"Matthew Wilder\", \"Artist Followers\": 30386.0, \"Song ID\": \"1mCsF9Tw4AkIZOjvZbZZdT\", \"Genre\": \"['new wave pop']\", \"Release Date\": \"1983-03-19\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 73.0, \"Danceability\": 0.917, \"Energy\": 0.588, \"Loudness\": -11.047, \"Speechiness\": 0.0607, \"Acousticness\": 0.195, \"Liveness\": 0.0914, \"Tempo\": 110.077, \"Duration (ms)\": 184480.0, \"Valence\": 0.828, \"Chord\": \"A#/Bb\"}, {\"Index\": 1460, \"Highest Charting Position\": 76, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Kein Wort\", \"Streams\": 5208651, \"Artist\": \"Juju, Loredana, Miksu / Macloud\", \"Artist Followers\": 486474.0, \"Song ID\": \"1hoLUVBx0ixX3kn0EX0P5n\", \"Genre\": \"['frauenrap', 'german hip hop', 'german pop']\", \"Release Date\": \"2020-01-16\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.746, \"Energy\": 0.592, \"Loudness\": -6.861, \"Speechiness\": 0.0914, \"Acousticness\": 0.462, \"Liveness\": 0.187, \"Tempo\": 160.065, \"Duration (ms)\": 162094.0, \"Valence\": 0.629, \"Chord\": \"F#/Gb\"}, {\"Index\": 1461, \"Highest Charting Position\": 86, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Graveyard\", \"Streams\": 5044853, \"Artist\": \"Halsey\", \"Artist Followers\": 15663384.0, \"Song ID\": \"2ufmtcIFdFpuUYBPXK5f67\", \"Genre\": \"['dance pop', 'electropop', 'etherpop', 'indie poptimism', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.667, \"Energy\": 0.583, \"Loudness\": -5.127, \"Speechiness\": 0.0747, \"Acousticness\": 0.231, \"Liveness\": 0.181, \"Tempo\": 92.043, \"Duration (ms)\": 181806.0, \"Valence\": 0.187, \"Chord\": \"B\"}, {\"Index\": 1462, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Wake Up Call (feat. Trippie Redd)\", \"Streams\": 5029979, \"Artist\": \"KSI\", \"Artist Followers\": 2010879.0, \"Song ID\": \"5MYzajZVxBaPT2JUSRa99L\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2020-01-27\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 56.0, \"Danceability\": 0.642, \"Energy\": 0.669, \"Loudness\": -5.774, \"Speechiness\": 0.0486, \"Acousticness\": 0.318, \"Liveness\": 0.119, \"Tempo\": 156.084, \"Duration (ms)\": 175067.0, \"Valence\": 0.227, \"Chord\": \"F#/Gb\"}, {\"Index\": 1463, \"Highest Charting Position\": 131, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Turn Me On (feat. Vula)\", \"Streams\": 4925843, \"Artist\": \"Riton, Oliver Heldens\", \"Artist Followers\": 83743.0, \"Song ID\": \"0qaWEvPkts34WF68r8Dzx9\", \"Genre\": \"['dance pop', 'house', 'pop dance', 'tropical house', 'uk dance']\", \"Release Date\": \"2019-09-13\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.737, \"Energy\": 0.828, \"Loudness\": -4.711, \"Speechiness\": 0.0396, \"Acousticness\": 0.0149, \"Liveness\": 0.0862, \"Tempo\": 124.051, \"Duration (ms)\": 208474.0, \"Valence\": 0.517, \"Chord\": \"B\"}, {\"Index\": 1464, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Hips Don't Lie (feat. Wyclef Jean)\", \"Streams\": 4918636, \"Artist\": \"Shakira\", \"Artist Followers\": 22136717.0, \"Song ID\": \"3ZFTkvIE7kyPt6Nu3PEa7V\", \"Genre\": \"['colombian pop', 'dance pop', 'latin', 'latin pop', 'pop']\", \"Release Date\": \"2005-11-28\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 83.0, \"Danceability\": 0.778, \"Energy\": 0.824, \"Loudness\": -5.892, \"Speechiness\": 0.0707, \"Acousticness\": 0.284, \"Liveness\": 0.405, \"Tempo\": 100.024, \"Duration (ms)\": 218093.0, \"Valence\": 0.758, \"Chord\": \"A#/Bb\"}, {\"Index\": 1465, \"Highest Charting Position\": 106, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Liar\", \"Streams\": 4896939, \"Artist\": \"Camila Cabello\", \"Artist Followers\": 22698747.0, \"Song ID\": \"7LzouaWGFCy4tkXDOOnEyM\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-09-04\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 69.0, \"Danceability\": 0.74, \"Energy\": 0.498, \"Loudness\": -6.684, \"Speechiness\": 0.0456, \"Acousticness\": 0.0169, \"Liveness\": 0.319, \"Tempo\": 98.016, \"Duration (ms)\": 207039.0, \"Valence\": 0.652, \"Chord\": \"B\"}, {\"Index\": 1466, \"Highest Charting Position\": 191, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Going Bad (feat. Drake)\", \"Streams\": 4889500, \"Artist\": \"Meek Mill\", \"Artist Followers\": 5241145.0, \"Song ID\": \"2IRZnDFmlqMuOrYOLnZZyc\", \"Genre\": \"['hip hop', 'philly rap', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2018-11-30\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.889, \"Energy\": 0.496, \"Loudness\": -6.365, \"Speechiness\": 0.0905, \"Acousticness\": 0.259, \"Liveness\": 0.252, \"Tempo\": 86.003, \"Duration (ms)\": 180522.0, \"Valence\": 0.544, \"Chord\": \"E\"}, {\"Index\": 1467, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"ME! (feat. Brendon Urie of Panic! At The Disco)\", \"Streams\": 4884909, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2Rk4JlNc2TPmZe2af99d45\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 77.0, \"Danceability\": 0.61, \"Energy\": 0.83, \"Loudness\": -4.105, \"Speechiness\": 0.0571, \"Acousticness\": 0.033, \"Liveness\": 0.118, \"Tempo\": 182.162, \"Duration (ms)\": 193000.0, \"Valence\": 0.728, \"Chord\": \"C\"}, {\"Index\": 1468, \"Highest Charting Position\": 134, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Panini\", \"Streams\": 4867723, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5488666.0, \"Song ID\": \"1000nHvUdawXuUHgBod4Wv\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2019-09-13\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.703, \"Energy\": 0.594, \"Loudness\": -6.146, \"Speechiness\": 0.0752, \"Acousticness\": 0.342, \"Liveness\": 0.123, \"Tempo\": 153.848, \"Duration (ms)\": 114893.0, \"Valence\": 0.475, \"Chord\": \"F\"}, {\"Index\": 1469, \"Highest Charting Position\": 191, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"idontwannabeyouanymore\", \"Streams\": 4824483, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"41zXlQxzTi6cGAjpOXyLYH\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2017-12-22\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 78.0, \"Danceability\": 0.483, \"Energy\": 0.412, \"Loudness\": -8.461, \"Speechiness\": 0.0402, \"Acousticness\": 0.737, \"Liveness\": 0.116, \"Tempo\": 170.163, \"Duration (ms)\": 203569.0, \"Valence\": 0.247, \"Chord\": \"G\"}, {\"Index\": 1470, \"Highest Charting Position\": 158, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"The London (feat. J. Cole & Travis Scott)\", \"Streams\": 4791732, \"Artist\": \"J. Cole, Young Thug\", \"Artist Followers\": 6383275.0, \"Song ID\": \"7DcvwMAiqKJQD1rrdfxSDx\", \"Genre\": \"['atl hip hop', 'atl trap', 'gangster rap', 'hip hop', 'melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2019-05-23\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.796, \"Energy\": 0.586, \"Loudness\": -6.946, \"Speechiness\": 0.147, \"Acousticness\": 0.0247, \"Liveness\": 0.132, \"Tempo\": 97.981, \"Duration (ms)\": 200107.0, \"Valence\": 0.179, \"Chord\": \"E\"}, {\"Index\": 1471, \"Highest Charting Position\": 123, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"223's (feat. 9lokknine)\", \"Streams\": 4781697, \"Artist\": \"YNW Melly\", \"Artist Followers\": 6332535.0, \"Song ID\": \"4sjiIpEv617LDXaidKioOI\", \"Genre\": \"['melodic rap', 'trap']\", \"Release Date\": \"2019-08-09\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.932, \"Energy\": 0.547, \"Loudness\": -7.787, \"Speechiness\": 0.333, \"Acousticness\": 0.0388, \"Liveness\": 0.0924, \"Tempo\": 94.998, \"Duration (ms)\": 176640.0, \"Valence\": 0.695, \"Chord\": \"C\"}, {\"Index\": 1472, \"Highest Charting Position\": 26, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Darkness\", \"Streams\": 7618955, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5SiZJoLXp3WOl3J4C8IK0d\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 65.0, \"Danceability\": 0.671, \"Energy\": 0.623, \"Loudness\": -7.161, \"Speechiness\": 0.308, \"Acousticness\": 0.00998, \"Liveness\": 0.643, \"Tempo\": 75.055, \"Duration (ms)\": 337147.0, \"Valence\": 0.195, \"Chord\": \"D\"}, {\"Index\": 1473, \"Highest Charting Position\": 30, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"You Gon\\u2019 Learn (feat. Royce Da 5'9\\\" & White Gold)\", \"Streams\": 7157402, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"0GQ5bFTVFFKpwNPc7KwQnB\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 66.0, \"Danceability\": 0.68, \"Energy\": 0.82, \"Loudness\": -4.197, \"Speechiness\": 0.151, \"Acousticness\": 0.0614, \"Liveness\": 0.597, \"Tempo\": 140.033, \"Duration (ms)\": 234653.0, \"Valence\": 0.243, \"Chord\": \"E\"}, {\"Index\": 1474, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Blue World\", \"Streams\": 7060589, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"2hwOoMtWPtTSSn6WHV7Vp5\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 75.0, \"Danceability\": 0.742, \"Energy\": 0.553, \"Loudness\": -8.98, \"Speechiness\": 0.419, \"Acousticness\": 0.389, \"Liveness\": 0.0694, \"Tempo\": 84.931, \"Duration (ms)\": 209440.0, \"Valence\": 0.508, \"Chord\": \"G#/Ab\"}, {\"Index\": 1475, \"Highest Charting Position\": 99, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Liberdade Provis\\u00f3ria\", \"Streams\": 6442626, \"Artist\": \"Henrique & Juliano\", \"Artist Followers\": 13312073.0, \"Song ID\": \"1vG3YuKRYqPwTmNmYgqkpg\", \"Genre\": \"['sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.668, \"Energy\": 0.684, \"Loudness\": -5.937, \"Speechiness\": 0.0527, \"Acousticness\": 0.627, \"Liveness\": 0.923, \"Tempo\": 108.138, \"Duration (ms)\": 187986.0, \"Valence\": 0.7, \"Chord\": \"C#/Db\"}, {\"Index\": 1476, \"Highest Charting Position\": 32, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Unaccommodating (feat. Young M.A)\", \"Streams\": 6374807, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"0q2vG0UVuy6ajjcpkQHdZM\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 65.0, \"Danceability\": 0.852, \"Energy\": 0.752, \"Loudness\": -5.793, \"Speechiness\": 0.0597, \"Acousticness\": 0.0169, \"Liveness\": 0.394, \"Tempo\": 89.95, \"Duration (ms)\": 216600.0, \"Valence\": 0.389, \"Chord\": \"C#/Db\"}, {\"Index\": 1477, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Donuts\", \"Streams\": 6113037, \"Artist\": \"Gzuz\", \"Artist Followers\": 1140383.0, \"Song ID\": \"5XVPNr0CAoUn1jD033Ucoo\", \"Genre\": \"['deep german hip hop', 'german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-02-13\", \"Weeks Charted\": \"2020-01-24--2020-01-31\", \"Popularity\": 62.0, \"Danceability\": 0.784, \"Energy\": 0.703, \"Loudness\": -7.491, \"Speechiness\": 0.236, \"Acousticness\": 0.0973, \"Liveness\": 0.0754, \"Tempo\": 141.035, \"Duration (ms)\": 162938.0, \"Valence\": 0.556, \"Chord\": \"B\"}, {\"Index\": 1478, \"Highest Charting Position\": 44, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Leaving Heaven (feat. Skylar Grey)\", \"Streams\": 5466161, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5CpsIb7SMFHjmAG8RvIWfq\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.661, \"Energy\": 0.748, \"Loudness\": -4.809, \"Speechiness\": 0.206, \"Acousticness\": 0.175, \"Liveness\": 0.254, \"Tempo\": 171.983, \"Duration (ms)\": 265947.0, \"Valence\": 0.509, \"Chord\": \"D\"}, {\"Index\": 1479, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Zu Ende\", \"Streams\": 5297101, \"Artist\": \"Samra, ELIF\", \"Artist Followers\": 1045091.0, \"Song ID\": \"0Vl4eICpXMjtiK0RhdaWov\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-01-23\", \"Weeks Charted\": \"2020-01-24--2020-01-31\", \"Popularity\": 57.0, \"Danceability\": 0.707, \"Energy\": 0.747, \"Loudness\": -5.212, \"Speechiness\": 0.279, \"Acousticness\": 0.307, \"Liveness\": 0.183, \"Tempo\": 80.025, \"Duration (ms)\": 197861.0, \"Valence\": 0.491, \"Chord\": \"G#/Ab\"}, {\"Index\": 1480, \"Highest Charting Position\": 171, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"B.I.T.C.H.\", \"Streams\": 5215211, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"06scTb0zbkxYNgpAB3J9fN\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-01-24\", \"Weeks Charted\": \"2020-01-24--2020-01-31\", \"Popularity\": 59.0, \"Danceability\": 0.742, \"Energy\": 0.731, \"Loudness\": -4.362, \"Speechiness\": 0.306, \"Acousticness\": 0.0851, \"Liveness\": 0.131, \"Tempo\": 174.019, \"Duration (ms)\": 183143.0, \"Valence\": 0.547, \"Chord\": \"B\"}, {\"Index\": 1481, \"Highest Charting Position\": 56, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Look At Her Now\", \"Streams\": 5066377, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 1251372.0, \"Song ID\": \"2XUPkAie1nz9SYIhbdIVWb\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.753, \"Energy\": 0.564, \"Loudness\": -7.908, \"Speechiness\": 0.251, \"Acousticness\": 0.114, \"Liveness\": 0.359, \"Tempo\": 77.341, \"Duration (ms)\": 162596.0, \"Valence\": 0.55, \"Chord\": \"A#/Bb\"}, {\"Index\": 1482, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Bi Sonraki Hayat\\u0131mda Gel\", \"Streams\": 5037967, \"Artist\": \"Murda, Ezhel\", \"Artist Followers\": 862965.0, \"Song ID\": \"5SYkeNpjhJPFUMOP5TK8iw\", \"Genre\": \"['basshall', 'turkish trap']\", \"Release Date\": \"2020-08-28\", \"Weeks Charted\": \"2020-01-24--2020-01-31\", \"Popularity\": 57.0, \"Danceability\": 0.933, \"Energy\": 0.448, \"Loudness\": -4.491, \"Speechiness\": 0.136, \"Acousticness\": 0.0253, \"Liveness\": 0.104, \"Tempo\": 103.981, \"Duration (ms)\": 167350.0, \"Valence\": 0.737, \"Chord\": \"G#/Ab\"}, {\"Index\": 1483, \"Highest Charting Position\": 126, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Legends\", \"Streams\": 4922369, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"1Knctxx9vGZxpZfF66BIEa\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2018-06-22\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.594, \"Energy\": 0.798, \"Loudness\": -5.244, \"Speechiness\": 0.0844, \"Acousticness\": 0.115, \"Liveness\": 0.143, \"Tempo\": 142.049, \"Duration (ms)\": 191840.0, \"Valence\": 0.381, \"Chord\": \"E\"}, {\"Index\": 1484, \"Highest Charting Position\": 157, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"11 PM\", \"Streams\": 4891989, \"Artist\": \"Maluma\", \"Artist Followers\": 26784251.0, \"Song ID\": \"7KbF6AdprOXEEHlsq11Z6d\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.777, \"Energy\": 0.712, \"Loudness\": -4.84, \"Speechiness\": 0.277, \"Acousticness\": 0.217, \"Liveness\": 0.091, \"Tempo\": 95.692, \"Duration (ms)\": 175733.0, \"Valence\": 0.68, \"Chord\": \"A#/Bb\"}, {\"Index\": 1485, \"Highest Charting Position\": 182, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Post Malone (feat. RANI)\", \"Streams\": 4855270, \"Artist\": \"Sam Feldt\", \"Artist Followers\": 639516.0, \"Song ID\": \"0qc4QlcCxVTGyShurEv1UU\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'pop', 'pop dance', 'pop edm', 'tropical house']\", \"Release Date\": \"2019-05-24\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.59, \"Energy\": 0.642, \"Loudness\": -3.87, \"Speechiness\": 0.122, \"Acousticness\": 0.0771, \"Liveness\": 0.105, \"Tempo\": 107.356, \"Duration (ms)\": 174444.0, \"Valence\": 0.651, \"Chord\": \"G\"}, {\"Index\": 1486, \"Highest Charting Position\": 52, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"In Too Deep\", \"Streams\": 4824037, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"7Dj2wqPYXfSRFwa6qyOztr\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.72, \"Energy\": 0.767, \"Loudness\": -5.839, \"Speechiness\": 0.214, \"Acousticness\": 0.0387, \"Liveness\": 0.202, \"Tempo\": 88.966, \"Duration (ms)\": 194707.0, \"Valence\": 0.595, \"Chord\": \"A#/Bb\"}, {\"Index\": 1487, \"Highest Charting Position\": 57, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Premonition - Intro\", \"Streams\": 10830400, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"7ccTcabbJlCJiIqtrSSwBk\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.847, \"Energy\": 0.637, \"Loudness\": -5.193, \"Speechiness\": 0.367, \"Acousticness\": 0.0258, \"Liveness\": 0.382, \"Tempo\": 165.979, \"Duration (ms)\": 173893.0, \"Valence\": 0.511, \"Chord\": \"C#/Db\"}, {\"Index\": 1488, \"Highest Charting Position\": 62, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"I Can See\", \"Streams\": 10086930, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"3R8CyhJfVjvgIROd5RSGhQ\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.699, \"Energy\": 0.503, \"Loudness\": -9.922, \"Speechiness\": 0.0882, \"Acousticness\": 0.391, \"Liveness\": 0.0996, \"Tempo\": 114.86, \"Duration (ms)\": 220853.0, \"Valence\": 0.0546, \"Chord\": \"F\"}, {\"Index\": 1489, \"Highest Charting Position\": 69, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Hand Me Downs\", \"Streams\": 9521654, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"2Yv2mHzr5AQavVdwQjEokV\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.677, \"Energy\": 0.33, \"Loudness\": -11.198, \"Speechiness\": 0.149, \"Acousticness\": 0.474, \"Liveness\": 0.064, \"Tempo\": 68.985, \"Duration (ms)\": 298440.0, \"Valence\": 0.336, \"Chord\": \"D\"}, {\"Index\": 1490, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"No Regrets (feat. Don Toliver)\", \"Streams\": 9493884, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"1lO9CZo6eDrOy0S7khgryG\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 63.0, \"Danceability\": 0.756, \"Energy\": 0.747, \"Loudness\": -5.407, \"Speechiness\": 0.046, \"Acousticness\": 0.0048, \"Liveness\": 0.588, \"Tempo\": 134.935, \"Duration (ms)\": 200947.0, \"Valence\": 0.0687, \"Chord\": \"A\"}, {\"Index\": 1491, \"Highest Charting Position\": 71, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Complicated\", \"Streams\": 9443725, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"3WfSNAoj2D8C9noPSGZZFM\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.831, \"Energy\": 0.36, \"Loudness\": -8.073, \"Speechiness\": 0.052, \"Acousticness\": 0.136, \"Liveness\": 0.0703, \"Tempo\": 75.014, \"Duration (ms)\": 232212.0, \"Valence\": 0.601, \"Chord\": \"C\"}, {\"Index\": 1492, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Lock It Up (feat. Anderson .Paak)\", \"Streams\": 9328951, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"1qwMkkRiD5jqLeUUjfgblh\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.848, \"Energy\": 0.745, \"Loudness\": -3.052, \"Speechiness\": 0.221, \"Acousticness\": 0.0949, \"Liveness\": 0.0796, \"Tempo\": 137.024, \"Duration (ms)\": 170227.0, \"Valence\": 0.516, \"Chord\": \"F#/Gb\"}, {\"Index\": 1493, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Marsh\", \"Streams\": 9260007, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"34d7sGX6WUqq8f04e7CSNF\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.871, \"Energy\": 0.493, \"Loudness\": -6.356, \"Speechiness\": 0.205, \"Acousticness\": 0.0134, \"Liveness\": 0.385, \"Tempo\": 144.989, \"Duration (ms)\": 200573.0, \"Valence\": 0.0495, \"Chord\": \"C#/Db\"}, {\"Index\": 1494, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Stepdad\", \"Streams\": 9159901, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"3QVHSV8YKYq4L8tI5rnFgj\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 61.0, \"Danceability\": 0.779, \"Energy\": 0.805, \"Loudness\": -3.121, \"Speechiness\": 0.178, \"Acousticness\": 0.018, \"Liveness\": 0.321, \"Tempo\": 145.68, \"Duration (ms)\": 213413.0, \"Valence\": 0.557, \"Chord\": \"C#/Db\"}, {\"Index\": 1495, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Yah Yah (feat. Royce Da 5'9\\\", Black Thought, Q-Tip & Denaun)\", \"Streams\": 8695060, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5mZXWEH2eh8zMZGCxT5aW0\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.458, \"Energy\": 0.966, \"Loudness\": -2.107, \"Speechiness\": 0.384, \"Acousticness\": 0.14, \"Liveness\": 0.11, \"Tempo\": 183.586, \"Duration (ms)\": 286960.0, \"Valence\": 0.356, \"Chord\": \"C#/Db\"}, {\"Index\": 1496, \"Highest Charting Position\": 90, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Never Love Again\", \"Streams\": 8335790, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"40YbWniIEmqy6s58fYXLUh\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.747, \"Energy\": 0.899, \"Loudness\": -5.125, \"Speechiness\": 0.246, \"Acousticness\": 0.1, \"Liveness\": 0.486, \"Tempo\": 92.029, \"Duration (ms)\": 177547.0, \"Valence\": 0.581, \"Chord\": \"F\"}, {\"Index\": 1497, \"Highest Charting Position\": 91, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Woods\", \"Streams\": 8329349, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"3Qa944OTMZkg8DHjET8JQv\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.779, \"Energy\": 0.362, \"Loudness\": -10.847, \"Speechiness\": 0.0474, \"Acousticness\": 0.135, \"Liveness\": 0.111, \"Tempo\": 85.011, \"Duration (ms)\": 286387.0, \"Valence\": 0.46, \"Chord\": \"C\"}, {\"Index\": 1498, \"Highest Charting Position\": 94, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Farewell\", \"Streams\": 8277608, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"74gykWHknHDrg4eMdcmdRq\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 61.0, \"Danceability\": 0.89, \"Energy\": 0.664, \"Loudness\": -6.625, \"Speechiness\": 0.106, \"Acousticness\": 0.00487, \"Liveness\": 0.257, \"Tempo\": 93.007, \"Duration (ms)\": 247733.0, \"Valence\": 0.467, \"Chord\": \"E\"}, {\"Index\": 1499, \"Highest Charting Position\": 98, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Everybody\", \"Streams\": 8172098, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"1OuN92HcVG6NVpWbeESNB3\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.875, \"Energy\": 0.599, \"Loudness\": -9.077, \"Speechiness\": 0.138, \"Acousticness\": 0.0333, \"Liveness\": 0.113, \"Tempo\": 152.061, \"Duration (ms)\": 256507.0, \"Valence\": 0.112, \"Chord\": \"A\"}, {\"Index\": 1500, \"Highest Charting Position\": 100, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Alfred - Interlude\", \"Streams\": 8030151, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"4EmunTy7kNBYQivOa8F6b8\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 57.0, \"Danceability\": 0.429, \"Energy\": 0.231, \"Loudness\": -20.43, \"Speechiness\": 0.402, \"Acousticness\": 0.878, \"Liveness\": 0.279, \"Tempo\": 74.545, \"Duration (ms)\": 30133.0, \"Valence\": 0.914, \"Chord\": \"F\"}, {\"Index\": 1501, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Little Engine\", \"Streams\": 7913461, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"4qNWEOMyexn7b8Icyk29t9\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.769, \"Energy\": 0.811, \"Loudness\": -4.162, \"Speechiness\": 0.228, \"Acousticness\": 0.0234, \"Liveness\": 0.0451, \"Tempo\": 155.081, \"Duration (ms)\": 177293.0, \"Valence\": 0.76, \"Chord\": \"A#/Bb\"}, {\"Index\": 1502, \"Highest Charting Position\": 113, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"I Will (feat. KXNG Crooked, Royce Da 5'9\\\" & Joell Ortiz)\", \"Streams\": 7115414, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"3CJbxqRQ0JNCqboWDNUUeX\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.635, \"Energy\": 0.543, \"Loudness\": -5.941, \"Speechiness\": 0.067, \"Acousticness\": 0.0454, \"Liveness\": 0.272, \"Tempo\": 98.743, \"Duration (ms)\": 303000.0, \"Valence\": 0.036, \"Chord\": \"G#/Ab\"}, {\"Index\": 1503, \"Highest Charting Position\": 115, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Still Learning\", \"Streams\": 7050815, \"Artist\": \"Halsey\", \"Artist Followers\": 15663384.0, \"Song ID\": \"2Mfv5HaqnI18Q9JRv9hqnn\", \"Genre\": \"['dance pop', 'electropop', 'etherpop', 'indie poptimism', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 59.0, \"Danceability\": 0.708, \"Energy\": 0.661, \"Loudness\": -6.543, \"Speechiness\": 0.0546, \"Acousticness\": 0.0396, \"Liveness\": 0.113, \"Tempo\": 102.046, \"Duration (ms)\": 211784.0, \"Valence\": 0.317, \"Chord\": \"C\"}, {\"Index\": 1504, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Surf\", \"Streams\": 6960699, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"1kwnxJNVl7cwcU98RvMBaR\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 67.0, \"Danceability\": 0.828, \"Energy\": 0.182, \"Loudness\": -13.066, \"Speechiness\": 0.166, \"Acousticness\": 0.754, \"Liveness\": 0.15, \"Tempo\": 147.279, \"Duration (ms)\": 330507.0, \"Valence\": 0.231, \"Chord\": \"C#/Db\"}, {\"Index\": 1505, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"That's On Me\", \"Streams\": 6462701, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"0udOCZp7yk0Ml92C0k8H8D\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.583, \"Energy\": 0.499, \"Loudness\": -10.086, \"Speechiness\": 0.0261, \"Acousticness\": 0.591, \"Liveness\": 0.33, \"Tempo\": 155.199, \"Duration (ms)\": 217868.0, \"Valence\": 0.342, \"Chord\": \"A#/Bb\"}, {\"Index\": 1506, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Once A Day\", \"Streams\": 6159873, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"26G5nmIx7Yvq79bIIluyZV\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 61.0, \"Danceability\": 0.762, \"Energy\": 0.054, \"Loudness\": -16.735, \"Speechiness\": 0.0503, \"Acousticness\": 0.947, \"Liveness\": 0.124, \"Tempo\": 96.838, \"Duration (ms)\": 160267.0, \"Valence\": 0.339, \"Chord\": \"D\"}, {\"Index\": 1507, \"Highest Charting Position\": 155, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Big Drip\", \"Streams\": 6010373, \"Artist\": \"Ufo361, Future\", \"Artist Followers\": 1700759.0, \"Song ID\": \"7HZoWhGQaKg97OsqG7HLOS\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 48.0, \"Danceability\": 0.791, \"Energy\": 0.535, \"Loudness\": -6.753, \"Speechiness\": 0.311, \"Acousticness\": 0.0448, \"Liveness\": 0.129, \"Tempo\": 158.922, \"Duration (ms)\": 173785.0, \"Valence\": 0.443, \"Chord\": \"C\"}, {\"Index\": 1508, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Hands\", \"Streams\": 5934464, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"6CrnvqCxBKVWahSiQwOesM\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 58.0, \"Danceability\": 0.739, \"Energy\": 0.627, \"Loudness\": -8.608, \"Speechiness\": 0.171, \"Acousticness\": 0.0459, \"Liveness\": 0.159, \"Tempo\": 74.962, \"Duration (ms)\": 199981.0, \"Valence\": 0.542, \"Chord\": \"C\"}, {\"Index\": 1509, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Dans l'espace (feat. Heuss l'Enfoir\\u00e9)\", \"Streams\": 5678754, \"Artist\": \"Gambi\", \"Artist Followers\": 951798.0, \"Song ID\": \"2KAkkba3PaYFegfmYpUITv\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 59.0, \"Danceability\": 0.916, \"Energy\": 0.57, \"Loudness\": -6.278, \"Speechiness\": 0.18, \"Acousticness\": 0.0286, \"Liveness\": 0.0851, \"Tempo\": 110.05, \"Duration (ms)\": 169702.0, \"Valence\": 0.7, \"Chord\": \"C#/Db\"}, {\"Index\": 1510, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Blanche\", \"Streams\": 5656775, \"Artist\": \"Maes, Booba\", \"Artist Followers\": 1603670.0, \"Song ID\": \"5GyyPRvEwdI4wJSUbzxHQv\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2020-01-16\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 65.0, \"Danceability\": 0.776, \"Energy\": 0.713, \"Loudness\": -6.121, \"Speechiness\": 0.143, \"Acousticness\": 0.525, \"Liveness\": 0.306, \"Tempo\": 127.987, \"Duration (ms)\": 193453.0, \"Valence\": 0.551, \"Chord\": \"E\"}, {\"Index\": 1511, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Vulnerable\", \"Streams\": 7531094, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"11OwAR3GlBj9E35Cznf7Lj\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 55.0, \"Danceability\": 0.695, \"Energy\": 0.573, \"Loudness\": -8.882, \"Speechiness\": 0.167, \"Acousticness\": 0.132, \"Liveness\": 0.156, \"Tempo\": 100.031, \"Duration (ms)\": 192172.0, \"Valence\": 0.38, \"Chord\": \"A#/Bb\"}, {\"Index\": 1512, \"Highest Charting Position\": 90, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Dance Again\", \"Streams\": 7394604, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"5sK3o66yupTNIK6gWgzGjf\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 56.0, \"Danceability\": 0.784, \"Energy\": 0.552, \"Loudness\": -7.261, \"Speechiness\": 0.0871, \"Acousticness\": 0.0447, \"Liveness\": 0.192, \"Tempo\": 111.984, \"Duration (ms)\": 170498.0, \"Valence\": 0.465, \"Chord\": \"C#/Db\"}, {\"Index\": 1513, \"Highest Charting Position\": 107, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Ring\", \"Streams\": 6693229, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"11Ey4yJVeWEsA73KjACkVY\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 55.0, \"Danceability\": 0.873, \"Energy\": 0.51, \"Loudness\": -5.35, \"Speechiness\": 0.0661, \"Acousticness\": 0.565, \"Liveness\": 0.0738, \"Tempo\": 110.953, \"Duration (ms)\": 148776.0, \"Valence\": 0.871, \"Chord\": \"D#/Eb\"}, {\"Index\": 1514, \"Highest Charting Position\": 111, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Crowded Room (feat. 6LACK)\", \"Streams\": 6483001, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"2C0hTkdEoikhKzDCJl32QZ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 55.0, \"Danceability\": 0.724, \"Energy\": 0.415, \"Loudness\": -8.408, \"Speechiness\": 0.0518, \"Acousticness\": 0.764, \"Liveness\": 0.103, \"Tempo\": 89.999, \"Duration (ms)\": 186459.0, \"Valence\": 0.328, \"Chord\": \"G\"}, {\"Index\": 1515, \"Highest Charting Position\": 119, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"People You Know\", \"Streams\": 6255954, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"63mdJr3NMY3wReOkNE6c6W\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 54.0, \"Danceability\": 0.695, \"Energy\": 0.62, \"Loudness\": -8.082, \"Speechiness\": 0.0521, \"Acousticness\": 0.0881, \"Liveness\": 0.111, \"Tempo\": 150.032, \"Duration (ms)\": 194900.0, \"Valence\": 0.62, \"Chord\": \"G#/Ab\"}, {\"Index\": 1516, \"Highest Charting Position\": 83, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Up All Night\", \"Streams\": 5834918, \"Artist\": \"Khalid\", \"Artist Followers\": 14190858.0, \"Song ID\": \"1mpD5Q8IM32I4bF6eCpU74\", \"Genre\": \"['pop']\", \"Release Date\": \"2019-11-14\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 69.0, \"Danceability\": 0.665, \"Energy\": 0.712, \"Loudness\": -7.536, \"Speechiness\": 0.0527, \"Acousticness\": 0.00103, \"Liveness\": 0.102, \"Tempo\": 93.992, \"Duration (ms)\": 157220.0, \"Valence\": 0.669, \"Chord\": \"C#/Db\"}, {\"Index\": 1517, \"Highest Charting Position\": 111, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Nice To Meet Ya\", \"Streams\": 5730427, \"Artist\": \"Niall Horan\", \"Artist Followers\": 7564659.0, \"Song ID\": \"3cphb8kdsjElYR7r5icK3H\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.591, \"Energy\": 0.841, \"Loudness\": -4.351, \"Speechiness\": 0.0304, \"Acousticness\": 0.0119, \"Liveness\": 0.395, \"Tempo\": 109.034, \"Duration (ms)\": 158805.0, \"Valence\": 0.392, \"Chord\": \"E\"}, {\"Index\": 1518, \"Highest Charting Position\": 102, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Into the Unknown\", \"Streams\": 5705999, \"Artist\": \"Idina Menzel, AURORA\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3Z0oQ8r78OUaHvGPiDBR3W\", \"Genre\": \"[]\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.323, \"Energy\": 0.405, \"Loudness\": -8.533, \"Speechiness\": 0.0413, \"Acousticness\": 0.849, \"Liveness\": 0.138, \"Tempo\": 145.104, \"Duration (ms)\": 194848.0, \"Valence\": 0.274, \"Chord\": \"A#/Bb\"}, {\"Index\": 1519, \"Highest Charting Position\": 161, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Let Me Get Me\", \"Streams\": 5356671, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"0uFForNKQPvgSCnxlZIhQy\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 51.0, \"Danceability\": 0.826, \"Energy\": 0.571, \"Loudness\": -9.263, \"Speechiness\": 0.0426, \"Acousticness\": 0.249, \"Liveness\": 0.215, \"Tempo\": 121.06, \"Duration (ms)\": 189145.0, \"Valence\": 0.475, \"Chord\": \"D\"}, {\"Index\": 1520, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"A Sweeter Place (feat. Kid Cudi)\", \"Streams\": 5291134, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4bb94wZVF1cX66vQjNeJTX\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 52.0, \"Danceability\": 0.583, \"Energy\": 0.777, \"Loudness\": -6.991, \"Speechiness\": 0.185, \"Acousticness\": 0.109, \"Liveness\": 0.108, \"Tempo\": 190.054, \"Duration (ms)\": 263306.0, \"Valence\": 0.31, \"Chord\": \"A#/Bb\"}, {\"Index\": 1521, \"Highest Charting Position\": 131, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Stuck In A Dream (feat. Gunna)\", \"Streams\": 5258047, \"Artist\": \"Lil Mosey\", \"Artist Followers\": 3818503.0, \"Song ID\": \"7iHHxY2NLlJRAmlAmC4ahQ\", \"Genre\": \"['melodic rap', 'rap', 'rap conscient', 'trap', 'vapor trap']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.748, \"Energy\": 0.648, \"Loudness\": -6.445, \"Speechiness\": 0.0816, \"Acousticness\": 0.484, \"Liveness\": 0.126, \"Tempo\": 139.952, \"Duration (ms)\": 123560.0, \"Valence\": 0.726, \"Chord\": \"A#/Bb\"}, {\"Index\": 1522, \"Highest Charting Position\": 138, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Take What You Want (feat. Ozzy Osbourne & Travis Scott)\", \"Streams\": 5199618, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"7CZyCXKG6d5ALeq41sLzbw\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.499, \"Energy\": 0.8, \"Loudness\": -2.665, \"Speechiness\": 0.0502, \"Acousticness\": 0.0906, \"Liveness\": 0.147, \"Tempo\": 139.919, \"Duration (ms)\": 229573.0, \"Valence\": 0.272, \"Chord\": \"C#/Db\"}, {\"Index\": 1523, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Tip Toe (feat. A Boogie Wit da Hoodie)\", \"Streams\": 5150724, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6608815.0, \"Song ID\": \"6ztvsy3C6hPjVg9j4x1XKJ\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 63.0, \"Danceability\": 0.757, \"Energy\": 0.673, \"Loudness\": -8.513, \"Speechiness\": 0.141, \"Acousticness\": 0.095, \"Liveness\": 0.338, \"Tempo\": 92.958, \"Duration (ms)\": 185806.0, \"Valence\": 0.574, \"Chord\": \"C#/Db\"}, {\"Index\": 1524, \"Highest Charting Position\": 182, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Start Wit Me (feat. Gunna)\", \"Streams\": 5085706, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6608815.0, \"Song ID\": \"7A20WnLkjtZU2d7hIB6Ziu\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 68.0, \"Danceability\": 0.886, \"Energy\": 0.479, \"Loudness\": -8.054, \"Speechiness\": 0.334, \"Acousticness\": 0.077, \"Liveness\": 0.135, \"Tempo\": 130.029, \"Duration (ms)\": 158692.0, \"Valence\": 0.408, \"Chord\": \"E\"}, {\"Index\": 1525, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Diamonds (with Normani)\", \"Streams\": 4981484, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"0PQsrLxPbOBBwwmXCnGvcF\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 58.0, \"Danceability\": 0.785, \"Energy\": 0.753, \"Loudness\": -3.841, \"Speechiness\": 0.0873, \"Acousticness\": 0.188, \"Liveness\": 0.265, \"Tempo\": 94.012, \"Duration (ms)\": 199301.0, \"Valence\": 0.488, \"Chord\": \"C#/Db\"}, {\"Index\": 1526, \"Highest Charting Position\": 140, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Don't Call Me Up\", \"Streams\": 4931458, \"Artist\": \"Mabel\", \"Artist Followers\": 1374784.0, \"Song ID\": \"5WHTFyqSii0lmT9R21abT8\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2019-01-18\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.674, \"Energy\": 0.881, \"Loudness\": -2.853, \"Speechiness\": 0.147, \"Acousticness\": 0.296, \"Liveness\": 0.0793, \"Tempo\": 98.994, \"Duration (ms)\": 178480.0, \"Valence\": 0.234, \"Chord\": \"A\"}, {\"Index\": 1527, \"Highest Charting Position\": 177, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Death\", \"Streams\": 4929396, \"Artist\": \"Trippie Redd, DaBaby\", \"Artist Followers\": 6434201.0, \"Song ID\": \"3Kd6Wp3lG5HXMB2dlvuy7y\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 65.0, \"Danceability\": 0.802, \"Energy\": 0.82, \"Loudness\": -5.969, \"Speechiness\": 0.146, \"Acousticness\": 0.0579, \"Liveness\": 0.149, \"Tempo\": 164.005, \"Duration (ms)\": 172196.0, \"Valence\": 0.613, \"Chord\": \"A#/Bb\"}, {\"Index\": 1528, \"Highest Charting Position\": 133, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Calma - Remix\", \"Streams\": 4879713, \"Artist\": \"Pedro Cap\\u00f3, Farruko\", \"Artist Followers\": 1353049.0, \"Song ID\": \"5iwz1NiezX7WWjnCgY5TH4\", \"Genre\": \"['latin', 'latin pop', 'puerto rican pop']\", \"Release Date\": \"2018-10-05\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.826, \"Energy\": 0.773, \"Loudness\": -4.218, \"Speechiness\": 0.0524, \"Acousticness\": 0.323, \"Liveness\": 0.143, \"Tempo\": 126.899, \"Duration (ms)\": 238200.0, \"Valence\": 0.761, \"Chord\": \"B\"}, {\"Index\": 1529, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Cut You Off\", \"Streams\": 4874380, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4OtHGdb0KqEbaWb6edUnR9\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 51.0, \"Danceability\": 0.855, \"Energy\": 0.294, \"Loudness\": -8.676, \"Speechiness\": 0.286, \"Acousticness\": 0.3, \"Liveness\": 0.091, \"Tempo\": 139.745, \"Duration (ms)\": 182017.0, \"Valence\": 0.842, \"Chord\": \"F\"}, {\"Index\": 1530, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Kinda Crazy\", \"Streams\": 4866777, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"59iGOjPSOcPLGl3vqEStUp\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 49.0, \"Danceability\": 0.691, \"Energy\": 0.446, \"Loudness\": -10.304, \"Speechiness\": 0.0472, \"Acousticness\": 0.484, \"Liveness\": 0.183, \"Tempo\": 93.03, \"Duration (ms)\": 212436.0, \"Valence\": 0.534, \"Chord\": \"B\"}, {\"Index\": 1531, \"Highest Charting Position\": 179, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"2002\", \"Streams\": 4831644, \"Artist\": \"Anne-Marie\", \"Artist Followers\": 8153871.0, \"Song ID\": \"2BgEsaKNfHUdlh97KmvFyo\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2018-04-27\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.697, \"Energy\": 0.683, \"Loudness\": -2.881, \"Speechiness\": 0.117, \"Acousticness\": 0.0372, \"Liveness\": 0.137, \"Tempo\": 96.133, \"Duration (ms)\": 186987.0, \"Valence\": 0.603, \"Chord\": \"C#/Db\"}, {\"Index\": 1532, \"Highest Charting Position\": 153, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Taki Taki (feat. Selena Gomez, Ozuna & Cardi B)\", \"Streams\": 4816702, \"Artist\": \"DJ Snake\", \"Artist Followers\": 7408249.0, \"Song ID\": \"0KoiMHhqKLoL4xM54rcWYY\", \"Genre\": \"['dance pop', 'edm', 'electronic trap', 'pop', 'pop dance']\", \"Release Date\": \"2019-07-25\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.842, \"Energy\": 0.801, \"Loudness\": -4.167, \"Speechiness\": 0.228, \"Acousticness\": 0.157, \"Liveness\": 0.0642, \"Tempo\": 95.881, \"Duration (ms)\": 212500.0, \"Valence\": 0.617, \"Chord\": \"G#/Ab\"}, {\"Index\": 1533, \"Highest Charting Position\": 107, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Family\", \"Streams\": 6145132, \"Artist\": \"The Chainsmokers, Kygo\", \"Artist Followers\": 18195884.0, \"Song ID\": \"3TKpJrY9q49Mj1JOsM9zGL\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.584, \"Energy\": 0.607, \"Loudness\": -6.605, \"Speechiness\": 0.0356, \"Acousticness\": 0.426, \"Liveness\": 0.101, \"Tempo\": 117.817, \"Duration (ms)\": 194827.0, \"Valence\": 0.374, \"Chord\": \"B\"}, {\"Index\": 1534, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"GANG GANG\", \"Streams\": 5898484, \"Artist\": \"JACKBOYS, Sheck Wes\", \"Artist Followers\": 437907.0, \"Song ID\": \"6uJONCdr2rC65BNmCnTBWK\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 69.0, \"Danceability\": 0.859, \"Energy\": 0.6, \"Loudness\": -4.63, \"Speechiness\": 0.301, \"Acousticness\": 0.071, \"Liveness\": 0.353, \"Tempo\": 123.017, \"Duration (ms)\": 244761.0, \"Valence\": 0.568, \"Chord\": \"G\"}, {\"Index\": 1535, \"Highest Charting Position\": 39, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Had Enough (feat. Quavo & Offset)\", \"Streams\": 5748010, \"Artist\": \"Don Toliver\", \"Artist Followers\": 437907.0, \"Song ID\": \"7LGWmZaoS7jZJ5tEi9EcDi\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.75, \"Energy\": 0.789, \"Loudness\": -4.578, \"Speechiness\": 0.108, \"Acousticness\": 0.253, \"Liveness\": 0.129, \"Tempo\": 147.957, \"Duration (ms)\": 157133.0, \"Valence\": 0.673, \"Chord\": \"D\"}, {\"Index\": 1536, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"WHAT TO DO? (feat. Don Toliver)\", \"Streams\": 5586351, \"Artist\": \"JACKBOYS, Travis Scott\", \"Artist Followers\": 437907.0, \"Song ID\": \"4AO1XhrgJczQ9bNVxdfKQe\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.643, \"Energy\": 0.594, \"Loudness\": -5.191, \"Speechiness\": 0.0312, \"Acousticness\": 0.0695, \"Liveness\": 0.115, \"Tempo\": 118.037, \"Duration (ms)\": 250142.0, \"Valence\": 0.195, \"Chord\": \"A\"}, {\"Index\": 1537, \"Highest Charting Position\": 125, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Writing on the Wall (feat. Post Malone, Cardi B & Rvssian)\", \"Streams\": 5229616, \"Artist\": \"French Montana\", \"Artist Followers\": 4039037.0, \"Song ID\": \"7x9nXsowok1JszkVztI5NI\", \"Genre\": \"['gangster rap', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 59.0, \"Danceability\": 0.773, \"Energy\": 0.836, \"Loudness\": -2.326, \"Speechiness\": 0.153, \"Acousticness\": 0.283, \"Liveness\": 0.0828, \"Tempo\": 112.01, \"Duration (ms)\": 201271.0, \"Valence\": 0.497, \"Chord\": \"A\"}, {\"Index\": 1538, \"Highest Charting Position\": 169, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"VALENTINO\", \"Streams\": 4935492, \"Artist\": \"24kGoldn\", \"Artist Followers\": 1276406.0, \"Song ID\": \"6piAUJJQFD8oHDUr0b7l7q\", \"Genre\": \"['cali rap']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.746, \"Energy\": 0.717, \"Loudness\": -4.841, \"Speechiness\": 0.179, \"Acousticness\": 0.199, \"Liveness\": 0.132, \"Tempo\": 150.964, \"Duration (ms)\": 179133.0, \"Valence\": 0.523, \"Chord\": \"A\"}, {\"Index\": 1539, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"fuck, i'm lonely (with Anne-Marie) - from \\u201c13 Reasons Why: Season 3\\u201d\", \"Streams\": 4856458, \"Artist\": \"Lauv\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-01-03--2020-01-10\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 1540, \"Highest Charting Position\": 150, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Roller\", \"Streams\": 4732292, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"6hw1Sy9wZ8UCxYGdpKrU6M\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2019-10-25\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.941, \"Energy\": 0.758, \"Loudness\": -6.47, \"Speechiness\": 0.17, \"Acousticness\": 0.0256, \"Liveness\": 0.193, \"Tempo\": 128.017, \"Duration (ms)\": 157093.0, \"Valence\": 0.683, \"Chord\": \"A#/Bb\"}, {\"Index\": 1541, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Never Really Over\", \"Streams\": 4679948, \"Artist\": \"Katy Perry\", \"Artist Followers\": 18936929.0, \"Song ID\": \"5PYQUBXc7NYeI1obMKSJK0\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-05-31\", \"Weeks Charted\": \"2020-01-03--2020-01-10\", \"Popularity\": 74.0, \"Danceability\": 0.77, \"Energy\": 0.882, \"Loudness\": -4.792, \"Speechiness\": 0.0602, \"Acousticness\": 0.194, \"Liveness\": 0.316, \"Tempo\": 99.991, \"Duration (ms)\": 223523.0, \"Valence\": 0.385, \"Chord\": \"G#/Ab\"}, {\"Index\": 1542, \"Highest Charting Position\": 145, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"One Kiss (with Dua Lipa)\", \"Streams\": 4594157, \"Artist\": \"Calvin Harris\", \"Artist Followers\": 21946934.0, \"Song ID\": \"7ef4DlsgrMEH11cDZd32M6\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'house', 'pop', 'progressive house', 'uk dance']\", \"Release Date\": \"2018-04-06\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.791, \"Energy\": 0.862, \"Loudness\": -3.24, \"Speechiness\": 0.11, \"Acousticness\": 0.037, \"Liveness\": 0.0814, \"Tempo\": 123.994, \"Duration (ms)\": 214847.0, \"Valence\": 0.592, \"Chord\": \"A\"}, {\"Index\": 1543, \"Highest Charting Position\": 192, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Fantas\\u00eda\", \"Streams\": 4543012, \"Artist\": \"Ozuna\", \"Artist Followers\": 29238936.0, \"Song ID\": \"40rXWke6SnXiGkSmaT8ZUr\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-29\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 59.0, \"Danceability\": 0.695, \"Energy\": 0.719, \"Loudness\": -5.938, \"Speechiness\": 0.0903, \"Acousticness\": 0.227, \"Liveness\": 0.0884, \"Tempo\": 180.074, \"Duration (ms)\": 175187.0, \"Valence\": 0.781, \"Chord\": \"D\"}, {\"Index\": 1544, \"Highest Charting Position\": 59, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Trampoline\", \"Streams\": 8896030, \"Artist\": \"SHAED, ZAYN\", \"Artist Followers\": 139434.0, \"Song ID\": \"1iQDltZqI7BXnHrFy4Qo1k\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-09-26\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.619, \"Energy\": 0.459, \"Loudness\": -5.782, \"Speechiness\": 0.0334, \"Acousticness\": 0.56, \"Liveness\": 0.137, \"Tempo\": 126.803, \"Duration (ms)\": 184280.0, \"Valence\": 0.498, \"Chord\": \"G\"}, {\"Index\": 1545, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"GATTI\", \"Streams\": 7685470, \"Artist\": \"JACKBOYS, Pop Smoke, Travis Scott\", \"Artist Followers\": 437907.0, \"Song ID\": \"40mjsnRjCpycdUw3xhS20g\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.594, \"Energy\": 0.676, \"Loudness\": -5.808, \"Speechiness\": 0.344, \"Acousticness\": 0.135, \"Liveness\": 0.163, \"Tempo\": 143.477, \"Duration (ms)\": 181145.0, \"Valence\": 0.472, \"Chord\": \"D\"}, {\"Index\": 1546, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Candy\", \"Streams\": 5632102, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"1VJwtWR6z7SpZRwipI12be\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2018-03-30\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.689, \"Energy\": 0.516, \"Loudness\": -5.857, \"Speechiness\": 0.0444, \"Acousticness\": 0.513, \"Liveness\": 0.163, \"Tempo\": 124.876, \"Duration (ms)\": 190920.0, \"Valence\": 0.209, \"Chord\": \"G#/Ab\"}, {\"Index\": 1547, \"Highest Charting Position\": 143, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"JACKBOYS\", \"Streams\": 5363493, \"Artist\": \"JACKBOYS\", \"Artist Followers\": 437907.0, \"Song ID\": \"62zKJrpbLxz6InR3tGyr7o\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 56.0, \"Danceability\": 0.413, \"Energy\": 0.13, \"Loudness\": -25.166, \"Speechiness\": 0.0336, \"Acousticness\": 0.9, \"Liveness\": 0.111, \"Tempo\": 123.342, \"Duration (ms)\": 46837.0, \"Valence\": 0.0676, \"Chord\": \"C\"}, {\"Index\": 1548, \"Highest Charting Position\": 156, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Combatchy (feat. MC Rebecca)\", \"Streams\": 5149797, \"Artist\": \"Anitta, Lexa, Lu\\u00edsa Sonza\", \"Artist Followers\": 10741972.0, \"Song ID\": \"2bPtwnrpFNEe8N7Q85kLHw\", \"Genre\": \"['funk carioca', 'funk pop', 'pagode baiano', 'pop nacional']\", \"Release Date\": \"2019-11-20\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 64.0, \"Danceability\": 0.826, \"Energy\": 0.73, \"Loudness\": -3.032, \"Speechiness\": 0.0809, \"Acousticness\": 0.383, \"Liveness\": 0.0197, \"Tempo\": 150.134, \"Duration (ms)\": 157600.0, \"Valence\": 0.605, \"Chord\": \"C#/Db\"}, {\"Index\": 1549, \"Highest Charting Position\": 178, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Old Town Road\", \"Streams\": 4852004, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5488666.0, \"Song ID\": \"2YpeDb67231RjR0MgVLzsG\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.878, \"Energy\": 0.619, \"Loudness\": -5.56, \"Speechiness\": 0.102, \"Acousticness\": 0.0533, \"Liveness\": 0.113, \"Tempo\": 136.041, \"Duration (ms)\": 157067.0, \"Valence\": 0.639, \"Chord\": \"F#/Gb\"}, {\"Index\": 1550, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Let Me Know (I Wonder Why Freestyle)\", \"Streams\": 4701532, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"3wwo0bJvDSorOpNfzEkfXx\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2019-12-07\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.635, \"Energy\": 0.537, \"Loudness\": -7.895, \"Speechiness\": 0.0832, \"Acousticness\": 0.172, \"Liveness\": 0.418, \"Tempo\": 125.028, \"Duration (ms)\": 215381.0, \"Valence\": 0.383, \"Chord\": \"G\"}, {\"Index\": 1551, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Ne reviens pas\", \"Streams\": 4676857, \"Artist\": \"Gradur, Heuss L'enfoir\\u00e9\", \"Artist Followers\": 1390813.0, \"Song ID\": \"4TnFANpjVwVKWzkxNzIyFH\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2019-11-29\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 62.0, \"Danceability\": 0.932, \"Energy\": 0.778, \"Loudness\": -3.384, \"Speechiness\": 0.0638, \"Acousticness\": 0.212, \"Liveness\": 0.168, \"Tempo\": 124.996, \"Duration (ms)\": 188613.0, \"Valence\": 0.933, \"Chord\": \"A#/Bb\"}, {\"Index\": 1552, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"New Rules\", \"Streams\": 4630675, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"2ekn2ttSfGqwhhate0LSR0\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2017-06-02\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.762, \"Energy\": 0.7, \"Loudness\": -6.021, \"Speechiness\": 0.0694, \"Acousticness\": 0.00261, \"Liveness\": 0.153, \"Tempo\": 116.073, \"Duration (ms)\": 209320.0, \"Valence\": 0.608, \"Chord\": \"A\"}, {\"Index\": 1553, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Cheirosa - Ao Vivo\", \"Streams\": 4623030, \"Artist\": \"Jorge & Mateus\", \"Artist Followers\": 15019109.0, \"Song ID\": \"2PWjKmjyTZeDpmOUa3a5da\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2019-10-11\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.528, \"Energy\": 0.87, \"Loudness\": -3.123, \"Speechiness\": 0.0851, \"Acousticness\": 0.24, \"Liveness\": 0.333, \"Tempo\": 152.37, \"Duration (ms)\": 181930.0, \"Valence\": 0.714, \"Chord\": \"B\"}, {\"Index\": 1554, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Havana (feat. Young Thug)\", \"Streams\": 4620876, \"Artist\": \"Camila Cabello\", \"Artist Followers\": 22698747.0, \"Song ID\": \"1rfofaqEpACxVEHIZBJe6W\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-01-12\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.765, \"Energy\": 0.523, \"Loudness\": -4.333, \"Speechiness\": 0.03, \"Acousticness\": 0.184, \"Liveness\": 0.132, \"Tempo\": 104.988, \"Duration (ms)\": 217307.0, \"Valence\": 0.394, \"Chord\": \"D\"}, {\"Index\": 1555, \"Highest Charting Position\": 198, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Surtada - Remix Brega Funk\", \"Streams\": 4607385, \"Artist\": \"Dad\\u00e1 Bolad\\u00e3o, Tati Zaqui, OIK\", \"Artist Followers\": 208630.0, \"Song ID\": \"5F8ffc8KWKNawllr5WsW0r\", \"Genre\": \"['brega funk', 'funk carioca']\", \"Release Date\": \"2019-09-25\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 60.0, \"Danceability\": 0.832, \"Energy\": 0.55, \"Loudness\": -7.026, \"Speechiness\": 0.0587, \"Acousticness\": 0.249, \"Liveness\": 0.182, \"Tempo\": 154.064, \"Duration (ms)\": 152784.0, \"Valence\": 0.881, \"Chord\": \"F\"}, {\"Index\": 1556, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lover (Remix) [feat. Shawn Mendes]\", \"Streams\": 4595450, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3i9UVldZOE0aD0JnyfAZZ0\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-11-13\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.448, \"Energy\": 0.603, \"Loudness\": -7.176, \"Speechiness\": 0.064, \"Acousticness\": 0.433, \"Liveness\": 0.0862, \"Tempo\": 205.272, \"Duration (ms)\": 221307.0, \"Valence\": 0.422, \"Chord\": \"G\"}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 18,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "alt.Chart(df).mark_circle().encode(\n",
    "    x = \"Energy\",\n",
    "    y = \"Loudness\",\n",
    "    color = 'Acousticness',\n",
    "    tooltip = [\"Artist\",\"Song Name\",\"Release Date\",\"Chord\"]\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "f594666f",
   "metadata": {},
   "source": [
    "One of my favorite customizations in Altair is to use a more interesting color scheme.  Here is an example using the color scheme \"goldred\".  You can find more color options in the [Vega documentation](https://vega.github.io/vega/docs/schemes/)."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 19,
   "id": "ce82ee84",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-10cc4cb27c7943668d4b952430b5fa60\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-10cc4cb27c7943668d4b952430b5fa60\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-10cc4cb27c7943668d4b952430b5fa60\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-67c9fb159873386c9c7303ca2ad81ad2\"}, \"mark\": \"circle\", \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"Acousticness\", \"scale\": {\"scheme\": \"goldred\"}}, \"tooltip\": [{\"type\": \"nominal\", \"field\": \"Artist\"}, {\"type\": \"nominal\", \"field\": \"Song Name\"}, {\"type\": \"nominal\", \"field\": \"Release Date\"}, {\"type\": \"nominal\", \"field\": \"Chord\"}], \"x\": {\"type\": \"quantitative\", \"field\": \"Energy\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"Loudness\"}}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-67c9fb159873386c9c7303ca2ad81ad2\": [{\"Index\": 1, \"Highest Charting Position\": 1, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Beggin'\", \"Streams\": 48633449, \"Artist\": \"M\\u00e5neskin\", \"Artist Followers\": 3377762.0, \"Song ID\": \"3Wrjm47oTz2sjIgck11l5e\", \"Genre\": \"['indie rock italiano', 'italian pop']\", \"Release Date\": \"2017-12-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 100.0, \"Danceability\": 0.714, \"Energy\": 0.8, \"Loudness\": -4.808, \"Speechiness\": 0.0504, \"Acousticness\": 0.127, \"Liveness\": 0.359, \"Tempo\": 134.002, \"Duration (ms)\": 211560.0, \"Valence\": 0.589, \"Chord\": \"B\"}, {\"Index\": 2, \"Highest Charting Position\": 2, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"STAY (with Justin Bieber)\", \"Streams\": 47248719, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2230022.0, \"Song ID\": \"5HCyWlXZPP0y6Gqq8TgA20\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 99.0, \"Danceability\": 0.591, \"Energy\": 0.764, \"Loudness\": -5.484, \"Speechiness\": 0.0483, \"Acousticness\": 0.0383, \"Liveness\": 0.103, \"Tempo\": 169.928, \"Duration (ms)\": 141806.0, \"Valence\": 0.478, \"Chord\": \"C#/Db\"}, {\"Index\": 3, \"Highest Charting Position\": 1, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"good 4 u\", \"Streams\": 40162559, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"4ZtFanR9U6ndgddUvNcjcG\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 99.0, \"Danceability\": 0.563, \"Energy\": 0.664, \"Loudness\": -5.044, \"Speechiness\": 0.154, \"Acousticness\": 0.335, \"Liveness\": 0.0849, \"Tempo\": 166.928, \"Duration (ms)\": 178147.0, \"Valence\": 0.688, \"Chord\": \"A\"}, {\"Index\": 4, \"Highest Charting Position\": 3, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Bad Habits\", \"Streams\": 37799456, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83293380.0, \"Song ID\": \"6PQ88X9TkUIAUIZJHW2upE\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 98.0, \"Danceability\": 0.808, \"Energy\": 0.897, \"Loudness\": -3.712, \"Speechiness\": 0.0348, \"Acousticness\": 0.0469, \"Liveness\": 0.364, \"Tempo\": 126.026, \"Duration (ms)\": 231041.0, \"Valence\": 0.591, \"Chord\": \"B\"}, {\"Index\": 5, \"Highest Charting Position\": 5, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"INDUSTRY BABY (feat. Jack Harlow)\", \"Streams\": 33948454, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5473565.0, \"Song ID\": \"27NovPIUIRrOZoCHxABJwK\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2021-07-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 96.0, \"Danceability\": 0.736, \"Energy\": 0.704, \"Loudness\": -7.409, \"Speechiness\": 0.0615, \"Acousticness\": 0.0203, \"Liveness\": 0.0501, \"Tempo\": 149.995, \"Duration (ms)\": 212000.0, \"Valence\": 0.894, \"Chord\": \"D#/Eb\"}, {\"Index\": 6, \"Highest Charting Position\": 1, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"MONTERO (Call Me By Your Name)\", \"Streams\": 30071134, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5473565.0, \"Song ID\": \"67BtfxlNbhBmCDR2L2l8qd\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2021-03-31\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 97.0, \"Danceability\": 0.61, \"Energy\": 0.508, \"Loudness\": -6.682, \"Speechiness\": 0.152, \"Acousticness\": 0.297, \"Liveness\": 0.384, \"Tempo\": 178.818, \"Duration (ms)\": 137876.0, \"Valence\": 0.758, \"Chord\": \"G#/Ab\"}, {\"Index\": 7, \"Highest Charting Position\": 3, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Kiss Me More (feat. SZA)\", \"Streams\": 29356736, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"748mdHapucXQri7IAO8yFK\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 94.0, \"Danceability\": 0.762, \"Energy\": 0.701, \"Loudness\": -3.541, \"Speechiness\": 0.0286, \"Acousticness\": 0.235, \"Liveness\": 0.123, \"Tempo\": 110.968, \"Duration (ms)\": 208867.0, \"Valence\": 0.742, \"Chord\": \"G#/Ab\"}, {\"Index\": 8, \"Highest Charting Position\": 2, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Todo De Ti\", \"Streams\": 26951613, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6080597.0, \"Song ID\": \"4fSIb4hdOQ151TILNsSEaF\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2021-05-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 95.0, \"Danceability\": 0.78, \"Energy\": 0.718, \"Loudness\": -3.605, \"Speechiness\": 0.0506, \"Acousticness\": 0.31, \"Liveness\": 0.0932, \"Tempo\": 127.949, \"Duration (ms)\": 199604.0, \"Valence\": 0.342, \"Chord\": \"D#/Eb\"}, {\"Index\": 9, \"Highest Charting Position\": 3, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Yonaguni\", \"Streams\": 25030128, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36142273.0, \"Song ID\": \"2JPLbjOn0wPCngEot2STUS\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 96.0, \"Danceability\": 0.644, \"Energy\": 0.648, \"Loudness\": -4.601, \"Speechiness\": 0.118, \"Acousticness\": 0.276, \"Liveness\": 0.135, \"Tempo\": 179.951, \"Duration (ms)\": 206710.0, \"Valence\": 0.44, \"Chord\": \"C#/Db\"}, {\"Index\": 10, \"Highest Charting Position\": 8, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"I WANNA BE YOUR SLAVE\", \"Streams\": 24551591, \"Artist\": \"M\\u00e5neskin\", \"Artist Followers\": 3377762.0, \"Song ID\": \"4pt5fDVTg5GhEvEtlz9dKk\", \"Genre\": \"['indie rock italiano', 'italian pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 95.0, \"Danceability\": 0.75, \"Energy\": 0.608, \"Loudness\": -4.008, \"Speechiness\": 0.0387, \"Acousticness\": 0.00165, \"Liveness\": 0.178, \"Tempo\": 132.507, \"Duration (ms)\": 173347.0, \"Valence\": 0.958, \"Chord\": \"C#/Db\"}, {\"Index\": 11, \"Highest Charting Position\": 4, \"Number of Times Charted\": 43, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Levitating (feat. DaBaby)\", \"Streams\": 23518010, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"463CkQjx2Zk1yXoBuierM9\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-10-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 89.0, \"Danceability\": 0.702, \"Energy\": 0.825, \"Loudness\": -3.787, \"Speechiness\": 0.0601, \"Acousticness\": 0.00883, \"Liveness\": 0.0674, \"Tempo\": 102.977, \"Duration (ms)\": 203064.0, \"Valence\": 0.915, \"Chord\": \"F#/Gb\"}, {\"Index\": 12, \"Highest Charting Position\": 9, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Qu\\u00e9 M\\u00e1s Pues?\", \"Streams\": 22405111, \"Artist\": \"J Balvin, Maria Becerra\", \"Artist Followers\": 29051363.0, \"Song ID\": \"6hf0RpxTbOprT5nnwzkk8e\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\", \"Popularity\": 95.0, \"Danceability\": 0.891, \"Energy\": 0.819, \"Loudness\": -3.964, \"Speechiness\": 0.106, \"Acousticness\": 0.0261, \"Liveness\": 0.173, \"Tempo\": 101.968, \"Duration (ms)\": 217773.0, \"Valence\": 0.768, \"Chord\": \"G#/Ab\"}, {\"Index\": 13, \"Highest Charting Position\": 5, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Permission to Dance\", \"Streams\": 22062812, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"0LThjFY2iTtNdd4wviwVV2\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 95.0, \"Danceability\": 0.702, \"Energy\": 0.741, \"Loudness\": -5.33, \"Speechiness\": 0.0427, \"Acousticness\": 0.00544, \"Liveness\": 0.337, \"Tempo\": 124.925, \"Duration (ms)\": 187585.0, \"Valence\": 0.646, \"Chord\": \"A\"}, {\"Index\": 14, \"Highest Charting Position\": 1, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Peaches (feat. Daniel Caesar & Giveon)\", \"Streams\": 20294457, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48504126.0, \"Song ID\": \"4iJyoBOLtHqaGxP12qzhQI\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 94.0, \"Danceability\": 0.677, \"Energy\": 0.696, \"Loudness\": -6.181, \"Speechiness\": 0.119, \"Acousticness\": 0.321, \"Liveness\": 0.42, \"Tempo\": 90.03, \"Duration (ms)\": 198082.0, \"Valence\": 0.464, \"Chord\": \"C\"}, {\"Index\": 15, \"Highest Charting Position\": 2, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Butter\", \"Streams\": 19985713, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"2bgTY4UwhfBYhGT4HUYStN\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 95.0, \"Danceability\": 0.759, \"Energy\": 0.459, \"Loudness\": -5.187, \"Speechiness\": 0.0948, \"Acousticness\": 0.00323, \"Liveness\": 0.0906, \"Tempo\": 109.997, \"Duration (ms)\": 164442.0, \"Valence\": 0.695, \"Chord\": \"G#/Ab\"}, {\"Index\": 16, \"Highest Charting Position\": 7, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"traitor\", \"Streams\": 19480679, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"5CZ40GBx1sQ9agT82CLQCT\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 94.0, \"Danceability\": 0.38, \"Energy\": 0.339, \"Loudness\": -7.885, \"Speechiness\": 0.0338, \"Acousticness\": 0.691, \"Liveness\": 0.12, \"Tempo\": 100.607, \"Duration (ms)\": 229227.0, \"Valence\": 0.0849, \"Chord\": \"D#/Eb\"}, {\"Index\": 17, \"Highest Charting Position\": 3, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"deja vu\", \"Streams\": 18571755, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"6HU7h9RYOaPRFeh0R3UeAr\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 93.0, \"Danceability\": 0.442, \"Energy\": 0.612, \"Loudness\": -7.222, \"Speechiness\": 0.112, \"Acousticness\": 0.584, \"Liveness\": 0.37, \"Tempo\": 180.917, \"Duration (ms)\": 215507.0, \"Valence\": 0.178, \"Chord\": \"D\"}, {\"Index\": 18, \"Highest Charting Position\": 5, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Save Your Tears (with Ariana Grande) (Remix)\", \"Streams\": 18053141, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"37BZB0z9T8Xu7U3e65qxFy\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 94.0, \"Danceability\": 0.65, \"Energy\": 0.825, \"Loudness\": -4.645, \"Speechiness\": 0.0325, \"Acousticness\": 0.0215, \"Liveness\": 0.0936, \"Tempo\": 118.091, \"Duration (ms)\": 191014.0, \"Valence\": 0.593, \"Chord\": \"C\"}, {\"Index\": 19, \"Highest Charting Position\": 14, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"AM Remix\", \"Streams\": 17617965, \"Artist\": \"Nio Garcia, J Balvin, Bad Bunny\", \"Artist Followers\": 2123734.0, \"Song ID\": \"05bfbizlM5AX6Mf1RRyMho\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-24\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 93.0, \"Danceability\": 0.743, \"Energy\": 0.655, \"Loudness\": -5.015, \"Speechiness\": 0.159, \"Acousticness\": 0.114, \"Liveness\": 0.0764, \"Tempo\": 172.031, \"Duration (ms)\": 261335.0, \"Valence\": 0.785, \"Chord\": \"F#/Gb\"}, {\"Index\": 20, \"Highest Charting Position\": 20, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Need To Know\", \"Streams\": 16908917, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"3Vi5XqYrmQgOYBajMWSvCi\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 90.0, \"Danceability\": 0.664, \"Energy\": 0.609, \"Loudness\": -6.509, \"Speechiness\": 0.0707, \"Acousticness\": 0.304, \"Liveness\": 0.0926, \"Tempo\": 130.041, \"Duration (ms)\": 210560.0, \"Valence\": 0.194, \"Chord\": \"C#/Db\"}, {\"Index\": 21, \"Highest Charting Position\": 19, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Volando - Remix\", \"Streams\": 16606925, \"Artist\": \"Mora, Bad Bunny, Sech\", \"Artist Followers\": 151486.0, \"Song ID\": \"0G2zPzWqVjR68iNPmx2TBe\", \"Genre\": \"['reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 91.0, \"Danceability\": 0.659, \"Energy\": 0.688, \"Loudness\": -4.649, \"Speechiness\": 0.0673, \"Acousticness\": 0.207, \"Liveness\": 0.113, \"Tempo\": 153.979, \"Duration (ms)\": 273474.0, \"Valence\": 0.632, \"Chord\": \"F#/Gb\"}, {\"Index\": 22, \"Highest Charting Position\": 22, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Ain't Shit\", \"Streams\": 16126897, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"5lAnYvAIkSDNXqfo7DyFUm\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 90.0, \"Danceability\": 0.855, \"Energy\": 0.488, \"Loudness\": -4.601, \"Speechiness\": 0.208, \"Acousticness\": 0.506, \"Liveness\": 0.347, \"Tempo\": 124.097, \"Duration (ms)\": 174253.0, \"Valence\": 0.619, \"Chord\": \"D#/Eb\"}, {\"Index\": 23, \"Highest Charting Position\": 1, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"drivers license\", \"Streams\": 15684978, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"5wANPM4fQCJwkGd4rN57mH\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 92.0, \"Danceability\": 0.561, \"Energy\": 0.431, \"Loudness\": -8.81, \"Speechiness\": 0.0578, \"Acousticness\": 0.768, \"Liveness\": 0.106, \"Tempo\": 143.875, \"Duration (ms)\": 242013.0, \"Valence\": 0.137, \"Chord\": \"A#/Bb\"}, {\"Index\": 24, \"Highest Charting Position\": 24, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Heat Waves\", \"Streams\": 15089184, \"Artist\": \"Glass Animals\", \"Artist Followers\": 1890510.0, \"Song ID\": \"3USxtqRwSYz57Ewm6wWRMp\", \"Genre\": \"['gauze pop', 'indietronica', 'shiver pop']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 85.0, \"Danceability\": 0.761, \"Energy\": 0.525, \"Loudness\": -6.9, \"Speechiness\": 0.0944, \"Acousticness\": 0.44, \"Liveness\": 0.0921, \"Tempo\": 80.87, \"Duration (ms)\": 238805.0, \"Valence\": 0.531, \"Chord\": \"B\"}, {\"Index\": 25, \"Highest Charting Position\": 1, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Blinding Lights\", \"Streams\": 15011809, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"0VjIjW4GlUZAMYd2vXMi3b\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 92.0, \"Danceability\": 0.514, \"Energy\": 0.73, \"Loudness\": -5.934, \"Speechiness\": 0.0598, \"Acousticness\": 0.00146, \"Liveness\": 0.0897, \"Tempo\": 171.005, \"Duration (ms)\": 200040.0, \"Valence\": 0.334, \"Chord\": \"C#/Db\"}, {\"Index\": 26, \"Highest Charting Position\": 12, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"happier\", \"Streams\": 14849078, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"2tGvwE8GcFKwNdAXMnlbfl\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 92.0, \"Danceability\": 0.395, \"Energy\": 0.443, \"Loudness\": -9.72, \"Speechiness\": 0.133, \"Acousticness\": 0.765, \"Liveness\": 0.0839, \"Tempo\": 168.924, \"Duration (ms)\": 175933.0, \"Valence\": 0.338, \"Chord\": \"F#/Gb\"}, {\"Index\": 27, \"Highest Charting Position\": 27, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Pepas\", \"Streams\": 14809458, \"Artist\": \"Farruko\", \"Artist Followers\": 10502148.0, \"Song ID\": \"5fwSHlTEWpluwOM0Sxnh5k\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-24\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 92.0, \"Danceability\": 0.762, \"Energy\": 0.766, \"Loudness\": -3.955, \"Speechiness\": 0.0343, \"Acousticness\": 0.00776, \"Liveness\": 0.128, \"Tempo\": 130.001, \"Duration (ms)\": 287120.0, \"Valence\": 0.442, \"Chord\": \"G\"}, {\"Index\": 28, \"Highest Charting Position\": 18, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Motley Crew\", \"Streams\": 14329162, \"Artist\": \"Post Malone\", \"Artist Followers\": 33651775.0, \"Song ID\": \"40uMIn2zJLAQhNXghRjBed\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 90.0, \"Danceability\": 0.797, \"Energy\": 0.631, \"Loudness\": -3.818, \"Speechiness\": 0.0786, \"Acousticness\": 0.0904, \"Liveness\": 0.0998, \"Tempo\": 129.915, \"Duration (ms)\": 184213.0, \"Valence\": 0.288, \"Chord\": \"D#/Eb\"}, {\"Index\": 29, \"Highest Charting Position\": 15, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Friday (feat. Mufasa & Hypeman) - Dopamine Re-Edit\", \"Streams\": 14273637, \"Artist\": \"Riton, Nightcrawlers\", \"Artist Followers\": 83689.0, \"Song ID\": \"4cG7HUWYHBV6R6tHn1gxrl\", \"Genre\": \"['dance pop', 'house', 'pop dance', 'tropical house', 'uk dance']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 92.0, \"Danceability\": 0.824, \"Energy\": 0.862, \"Loudness\": -3.424, \"Speechiness\": 0.126, \"Acousticness\": 0.0076, \"Liveness\": 0.303, \"Tempo\": 122.98, \"Duration (ms)\": 169153.0, \"Valence\": 0.801, \"Chord\": \"D\"}, {\"Index\": 30, \"Highest Charting Position\": 3, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Astronaut In The Ocean\", \"Streams\": 14174752, \"Artist\": \"Masked Wolf\", \"Artist Followers\": 365975.0, \"Song ID\": \"3Ofmpyhv5UAQ70mENzB277\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2021-01-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 89.0, \"Danceability\": 0.778, \"Energy\": 0.695, \"Loudness\": -6.865, \"Speechiness\": 0.0913, \"Acousticness\": 0.175, \"Liveness\": 0.15, \"Tempo\": 149.996, \"Duration (ms)\": 132780.0, \"Valence\": 0.472, \"Chord\": \"E\"}, {\"Index\": 31, \"Highest Charting Position\": 5, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Leave The Door Open\", \"Streams\": 13963568, \"Artist\": \"Bruno Mars, Anderson .Paak, Silk Sonic\", \"Artist Followers\": 32574754.0, \"Song ID\": \"7MAibcTli4IisCtbHKrGMh\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 92.0, \"Danceability\": 0.586, \"Energy\": 0.616, \"Loudness\": -7.964, \"Speechiness\": 0.0324, \"Acousticness\": 0.182, \"Liveness\": 0.0927, \"Tempo\": 148.088, \"Duration (ms)\": 242096.0, \"Valence\": 0.719, \"Chord\": \"F\"}, {\"Index\": 32, \"Highest Charting Position\": 32, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Don't Go Yet\", \"Streams\": 13205250, \"Artist\": \"Camila Cabello\", \"Artist Followers\": 22683756.0, \"Song ID\": \"1058fW9H3fZA6QjYCdOBad\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-07-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 88.0, \"Danceability\": 0.666, \"Energy\": 0.796, \"Loudness\": -6.967, \"Speechiness\": 0.103, \"Acousticness\": 0.0492, \"Liveness\": 0.0442, \"Tempo\": 110.108, \"Duration (ms)\": 164842.0, \"Valence\": 0.61, \"Chord\": \"A#/Bb\"}, {\"Index\": 33, \"Highest Charting Position\": 11, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"favorite crime\", \"Streams\": 12818935, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"5JCoSi02qi3jJeHdZXMmR8\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 91.0, \"Danceability\": 0.369, \"Energy\": 0.272, \"Loudness\": -10.497, \"Speechiness\": 0.0364, \"Acousticness\": 0.866, \"Liveness\": 0.147, \"Tempo\": 172.929, \"Duration (ms)\": 152667.0, \"Valence\": 0.218, \"Chord\": \"A\"}, {\"Index\": 34, \"Highest Charting Position\": 10, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Pareja Del A\\u00f1o\", \"Streams\": 12572307, \"Artist\": \"Sebastian Yatra, Myke Towers\", \"Artist Followers\": 16216789.0, \"Song ID\": \"2rCbl9naJYhaxjLsfx88uM\", \"Genre\": \"['colombian pop', 'latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 91.0, \"Danceability\": 0.715, \"Energy\": 0.622, \"Loudness\": -5.102, \"Speechiness\": 0.046, \"Acousticness\": 0.163, \"Liveness\": 0.0948, \"Tempo\": 80.015, \"Duration (ms)\": 195053.0, \"Valence\": 0.808, \"Chord\": \"E\"}, {\"Index\": 35, \"Highest Charting Position\": 4, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Watermelon Sugar\", \"Streams\": 11996689, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16112621.0, \"Song ID\": \"6UelLqGlWMcVH1E5c4H7lY\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 90.0, \"Danceability\": 0.548, \"Energy\": 0.816, \"Loudness\": -4.209, \"Speechiness\": 0.0465, \"Acousticness\": 0.122, \"Liveness\": 0.335, \"Tempo\": 95.39, \"Duration (ms)\": 174000.0, \"Valence\": 0.557, \"Chord\": \"C\"}, {\"Index\": 36, \"Highest Charting Position\": 36, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"NOT SOBER (feat. Polo G & Stunna Gambino)\", \"Streams\": 11869336, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 37, \"Highest Charting Position\": 3, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"RAPSTAR\", \"Streams\": 11683383, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"43PGPuHIlVOc04jrZVh9L6\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 89.0, \"Danceability\": 0.789, \"Energy\": 0.536, \"Loudness\": -6.862, \"Speechiness\": 0.242, \"Acousticness\": 0.41, \"Liveness\": 0.129, \"Tempo\": 81.039, \"Duration (ms)\": 165926.0, \"Valence\": 0.437, \"Chord\": \"F#/Gb\"}, {\"Index\": 38, \"Highest Charting Position\": 15, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"You Right\", \"Streams\": 11629418, \"Artist\": \"Doja Cat, The Weeknd\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0k4d5YPDr1r7FX77VdqWez\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 89.0, \"Danceability\": 0.828, \"Energy\": 0.621, \"Loudness\": -6.414, \"Speechiness\": 0.0565, \"Acousticness\": 0.0164, \"Liveness\": 0.0845, \"Tempo\": 128.986, \"Duration (ms)\": 186173.0, \"Valence\": 0.436, \"Chord\": \"G#/Ab\"}, {\"Index\": 39, \"Highest Charting Position\": 39, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"911 - Remix\", \"Streams\": 11553846, \"Artist\": \"Sech, Jhay Cortez\", \"Artist Followers\": 8758283.0, \"Song ID\": \"27RSJHEA99Y0Vsow7nA37A\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 89.0, \"Danceability\": 0.816, \"Energy\": 0.71, \"Loudness\": -3.728, \"Speechiness\": 0.0398, \"Acousticness\": 0.165, \"Liveness\": 0.292, \"Tempo\": 93.02, \"Duration (ms)\": 208631.0, \"Valence\": 0.784, \"Chord\": \"G\"}, {\"Index\": 40, \"Highest Charting Position\": 1, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"D\\u00c1KITI\", \"Streams\": 11524288, \"Artist\": \"Bad Bunny, Jhay Cortez\", \"Artist Followers\": 36142273.0, \"Song ID\": \"4MzXwWMhyBbmu6hOcLVD49\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 86.0, \"Danceability\": 0.731, \"Energy\": 0.573, \"Loudness\": -10.059, \"Speechiness\": 0.0544, \"Acousticness\": 0.401, \"Liveness\": 0.113, \"Tempo\": 109.928, \"Duration (ms)\": 205090.0, \"Valence\": 0.145, \"Chord\": \"E\"}, {\"Index\": 41, \"Highest Charting Position\": 41, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Mi\\u00e9nteme\", \"Streams\": 11477024, \"Artist\": \"TINI, Maria Becerra\", \"Artist Followers\": 2936204.0, \"Song ID\": \"0cOa970mzTWAxKtltpkpLc\", \"Genre\": \"['latin pop', 'pop argentino']\", \"Release Date\": \"2021-04-29\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 90.0, \"Danceability\": 0.85, \"Energy\": 0.541, \"Loudness\": -4.522, \"Speechiness\": 0.0674, \"Acousticness\": 0.161, \"Liveness\": 0.286, \"Tempo\": 92.003, \"Duration (ms)\": 165275.0, \"Valence\": 0.916, \"Chord\": \"D\"}, {\"Index\": 42, \"Highest Charting Position\": 17, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"jealousy, jealousy\", \"Streams\": 11287301, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"0MMyJUC3WNnFS1lit5pTjk\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 90.0, \"Danceability\": 0.695, \"Energy\": 0.575, \"Loudness\": -6.334, \"Speechiness\": 0.116, \"Acousticness\": 0.198, \"Liveness\": 0.0614, \"Tempo\": 163.929, \"Duration (ms)\": 173160.0, \"Valence\": 0.699, \"Chord\": \"A#/Bb\"}, {\"Index\": 43, \"Highest Charting Position\": 33, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Poblado - Remix\", \"Streams\": 11283626, \"Artist\": \"J Balvin, KAROL G, Nicky Jam, Crissin, Totoy El Frio, Natan & Shander\", \"Artist Followers\": 29051363.0, \"Song ID\": \"1WedZeiezCmCEOzLwhx0hV\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 89.0, \"Danceability\": 0.813, \"Energy\": 0.809, \"Loudness\": -5.382, \"Speechiness\": 0.0846, \"Acousticness\": 0.102, \"Liveness\": 0.377, \"Tempo\": 93.005, \"Duration (ms)\": 393280.0, \"Valence\": 0.646, \"Chord\": \"D#/Eb\"}, {\"Index\": 44, \"Highest Charting Position\": 2, \"Number of Times Charted\": 49, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Dynamite\", \"Streams\": 11196819, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"4saklk6nie3yiGePpBwUoc\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 89.0, \"Danceability\": 0.746, \"Energy\": 0.765, \"Loudness\": -4.41, \"Speechiness\": 0.0993, \"Acousticness\": 0.0112, \"Liveness\": 0.0936, \"Tempo\": 114.044, \"Duration (ms)\": 199054.0, \"Valence\": 0.737, \"Chord\": \"F#/Gb\"}, {\"Index\": 45, \"Highest Charting Position\": 9, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"The Business\", \"Streams\": 10739770, \"Artist\": \"Ti\\u00ebsto\", \"Artist Followers\": 5785065.0, \"Song ID\": \"6f3Slt0GbA2bPZlz0aIFXN\", \"Genre\": \"['big room', 'brostep', 'dance pop', 'dutch edm', 'edm', 'electro house', 'house', 'pop dance', 'slap house', 'trance', 'tropical house']\", \"Release Date\": \"2020-09-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 90.0, \"Danceability\": 0.798, \"Energy\": 0.62, \"Loudness\": -7.079, \"Speechiness\": 0.232, \"Acousticness\": 0.414, \"Liveness\": 0.112, \"Tempo\": 120.031, \"Duration (ms)\": 164000.0, \"Valence\": 0.235, \"Chord\": \"G#/Ab\"}, {\"Index\": 46, \"Highest Charting Position\": 46, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Heartbreak Anthem (with David Guetta & Little Mix)\", \"Streams\": 10315460, \"Artist\": \"Galantis\", \"Artist Followers\": 3120157.0, \"Song ID\": \"5K6Ssv4Z3zRvxt0P6EKUAP\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2021-05-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 89.0, \"Danceability\": 0.595, \"Energy\": 0.784, \"Loudness\": -4.878, \"Speechiness\": 0.102, \"Acousticness\": 0.216, \"Liveness\": 0.0608, \"Tempo\": 124.111, \"Duration (ms)\": 183726.0, \"Valence\": 0.479, \"Chord\": \"C#/Db\"}, {\"Index\": 47, \"Highest Charting Position\": 1, \"Number of Times Charted\": 51, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Mood (feat. iann dior)\", \"Streams\": 10222056, \"Artist\": \"24kGoldn\", \"Artist Followers\": 1274433.0, \"Song ID\": \"4jPy3l0RUwlUI9T5XHBW2m\", \"Genre\": \"['cali rap']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 89.0, \"Danceability\": 0.701, \"Energy\": 0.716, \"Loudness\": -3.671, \"Speechiness\": 0.0361, \"Acousticness\": 0.174, \"Liveness\": 0.324, \"Tempo\": 91.007, \"Duration (ms)\": 140533.0, \"Valence\": 0.732, \"Chord\": \"G\"}, {\"Index\": 48, \"Highest Charting Position\": 48, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Entre Nosotros\", \"Streams\": 10215216, \"Artist\": \"Tiago PZK, LIT killah\", \"Artist Followers\": 375865.0, \"Song ID\": \"6w8yBI2vthyN9UnwO4UBWb\", \"Genre\": \"['trap argentino']\", \"Release Date\": \"2021-07-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 89.0, \"Danceability\": 0.729, \"Energy\": 0.513, \"Loudness\": -6.345, \"Speechiness\": 0.0455, \"Acousticness\": 0.494, \"Liveness\": 0.137, \"Tempo\": 170.064, \"Duration (ms)\": 192353.0, \"Valence\": 0.789, \"Chord\": \"F\"}, {\"Index\": 49, \"Highest Charting Position\": 29, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Fiel - Remix\", \"Streams\": 10032746, \"Artist\": \"Wisin, Jhay Cortez, Anuel AA, Los Legendarios, Myke Towers\", \"Artist Followers\": 6929075.0, \"Song ID\": \"43qcs9NpJhDxtG91zxFkj7\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 89.0, \"Danceability\": 0.839, \"Energy\": 0.711, \"Loudness\": -4.733, \"Speechiness\": 0.0473, \"Acousticness\": 0.398, \"Liveness\": 0.118, \"Tempo\": 97.99, \"Duration (ms)\": 349547.0, \"Valence\": 0.573, \"Chord\": \"F#/Gb\"}, {\"Index\": 50, \"Highest Charting Position\": 20, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Build a Bitch\", \"Streams\": 9841998, \"Artist\": \"Bella Poarch\", \"Artist Followers\": 389076.0, \"Song ID\": \"7BoobGhD4x5K96Me0hqC8Q\", \"Genre\": \"[]\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 89.0, \"Danceability\": 0.855, \"Energy\": 0.463, \"Loudness\": -7.454, \"Speechiness\": 0.0367, \"Acousticness\": 0.217, \"Liveness\": 0.347, \"Tempo\": 102.931, \"Duration (ms)\": 122773.0, \"Valence\": 0.866, \"Chord\": \"D#/Eb\"}, {\"Index\": 51, \"Highest Charting Position\": 19, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Nicky Jam: Bzrp Music Sessions, Vol. 41\", \"Streams\": 9799701, \"Artist\": \"Bizarrap, Nicky Jam\", \"Artist Followers\": 3126961.0, \"Song ID\": \"03LfOYi0icz4souspZVVhq\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2021-06-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 88.0, \"Danceability\": 0.627, \"Energy\": 0.849, \"Loudness\": -3.167, \"Speechiness\": 0.153, \"Acousticness\": 0.0913, \"Liveness\": 0.145, \"Tempo\": 89.907, \"Duration (ms)\": 158087.0, \"Valence\": 0.818, \"Chord\": \"C#/Db\"}, {\"Index\": 52, \"Highest Charting Position\": 52, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Tiroteo - Remix\", \"Streams\": 9781153, \"Artist\": \"Marc Segu\\u00ed, Rauw Alejandro, Pol Granch\", \"Artist Followers\": 45362.0, \"Song ID\": \"4OwhwvKESFtuu06dTgct7i\", \"Genre\": \"[]\", \"Release Date\": \"2021-04-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 88.0, \"Danceability\": 0.75, \"Energy\": 0.522, \"Loudness\": -7.018, \"Speechiness\": 0.0293, \"Acousticness\": 0.282, \"Liveness\": 0.0743, \"Tempo\": 110.427, \"Duration (ms)\": 321556.0, \"Valence\": 0.601, \"Chord\": \"A\"}, {\"Index\": 53, \"Highest Charting Position\": 19, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"NDA\", \"Streams\": 9635619, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47014200.0, \"Song ID\": \"38GBNKZUhfBkk3oNlWzRYd\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-07-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 84.0, \"Danceability\": 0.765, \"Energy\": 0.373, \"Loudness\": -9.921, \"Speechiness\": 0.0713, \"Acousticness\": 0.341, \"Liveness\": 0.112, \"Tempo\": 85.016, \"Duration (ms)\": 195777.0, \"Valence\": 0.554, \"Chord\": \"G#/Ab\"}, {\"Index\": 54, \"Highest Charting Position\": 40, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Rasputin\", \"Streams\": 9600707, \"Artist\": \"Majestic, Boney M.\", \"Artist Followers\": 32178.0, \"Song ID\": \"6FO4K7MrMoYkc5BlpX5LNV\", \"Genre\": \"['house', 'pop dance', 'uk dance']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 49.0, \"Danceability\": 0.83, \"Energy\": 0.839, \"Loudness\": -6.985, \"Speechiness\": 0.0699, \"Acousticness\": 0.00201, \"Liveness\": 0.0353, \"Tempo\": 128.012, \"Duration (ms)\": 345543.0, \"Valence\": 0.59, \"Chord\": \"F#/Gb\"}, {\"Index\": 55, \"Highest Charting Position\": 52, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Leave Before You Love Me (with Jonas Brothers)\", \"Streams\": 9428494, \"Artist\": \"Marshmello\", \"Artist Followers\": 31541310.0, \"Song ID\": \"4qu63nuBpdn0qHUHuObEj1\", \"Genre\": \"['brostep', 'edm', 'pop', 'pop dance', 'progressive electro house']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\", \"Popularity\": 89.0, \"Danceability\": 0.721, \"Energy\": 0.738, \"Loudness\": -4.77, \"Speechiness\": 0.0403, \"Acousticness\": 0.00226, \"Liveness\": 0.118, \"Tempo\": 119.976, \"Duration (ms)\": 154983.0, \"Valence\": 0.637, \"Chord\": \"G\"}, {\"Index\": 56, \"Highest Charting Position\": 56, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Freaks\", \"Streams\": 9319465, \"Artist\": \"Surf Curse\", \"Artist Followers\": 495226.0, \"Song ID\": \"7EkWXAI1wn8Ii883ecd9xr\", \"Genre\": \"['dreamo', 'indie surf', 'surf punk', 'vegas indie']\", \"Release Date\": \"2021-05-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 89.0, \"Danceability\": 0.345, \"Energy\": 0.941, \"Loudness\": -9.918, \"Speechiness\": 0.0466, \"Acousticness\": 3.84e-05, \"Liveness\": 0.0511, \"Tempo\": 179.626, \"Duration (ms)\": 147062.0, \"Valence\": 0.407, \"Chord\": \"A\"}, {\"Index\": 57, \"Highest Charting Position\": 57, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Meu Peda\\u00e7o de Pecado\", \"Streams\": 9206366, \"Artist\": \"Jo\\u00e3o Gomes\", \"Artist Followers\": 409173.0, \"Song ID\": \"2kJRlOyrxsy7Ot3c5TZ8Q6\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 83.0, \"Danceability\": 0.668, \"Energy\": 0.887, \"Loudness\": -4.404, \"Speechiness\": 0.0564, \"Acousticness\": 0.369, \"Liveness\": 0.257, \"Tempo\": 151.92, \"Duration (ms)\": 157176.0, \"Valence\": 0.907, \"Chord\": \"B\"}, {\"Index\": 58, \"Highest Charting Position\": 31, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"2/Catorce\", \"Streams\": 9086979, \"Artist\": \"Rauw Alejandro, Mr. Naisgai\", \"Artist Followers\": 6080597.0, \"Song ID\": \"71R8HJxQk5qMiRstrlXN9t\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2021-02-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 87.0, \"Danceability\": 0.54, \"Energy\": 0.455, \"Loudness\": -5.988, \"Speechiness\": 0.224, \"Acousticness\": 0.675, \"Liveness\": 0.12, \"Tempo\": 83.876, \"Duration (ms)\": 212032.0, \"Valence\": 0.432, \"Chord\": \"D#/Eb\"}, {\"Index\": 59, \"Highest Charting Position\": 34, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Beautiful Mistakes (feat. Megan Thee Stallion)\", \"Streams\": 9048966, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32262679.0, \"Song ID\": \"5zFglKYiknIxks8geR8rcL\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 88.0, \"Danceability\": 0.713, \"Energy\": 0.676, \"Loudness\": -5.483, \"Speechiness\": 0.027, \"Acousticness\": 0.0377, \"Liveness\": 0.154, \"Tempo\": 99.048, \"Duration (ms)\": 227395.0, \"Valence\": 0.721, \"Chord\": \"A#/Bb\"}, {\"Index\": 60, \"Highest Charting Position\": 31, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Run\", \"Streams\": 9017356, \"Artist\": \"OneRepublic\", \"Artist Followers\": 12169108.0, \"Song ID\": \"2UbVnbE5FH6008mAm6Mmgw\", \"Genre\": \"['dance pop', 'piano rock', 'pop', 'pop rock']\", \"Release Date\": \"2021-05-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2020-09-25--2020-10-02\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 88.0, \"Danceability\": 0.682, \"Energy\": 0.72, \"Loudness\": -8.173, \"Speechiness\": 0.0381, \"Acousticness\": 0.326, \"Liveness\": 0.148, \"Tempo\": 117.003, \"Duration (ms)\": 169011.0, \"Valence\": 0.673, \"Chord\": \"B\"}, {\"Index\": 61, \"Highest Charting Position\": 46, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Thot Shit\", \"Streams\": 8977336, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4787261.0, \"Song ID\": \"5zNW5ARjYhJQJz1AChP33n\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 88.0, \"Danceability\": 0.95, \"Energy\": 0.693, \"Loudness\": -3.424, \"Speechiness\": 0.0898, \"Acousticness\": 0.0133, \"Liveness\": 0.173, \"Tempo\": 130.02, \"Duration (ms)\": 184635.0, \"Valence\": 0.891, \"Chord\": \"A\"}, {\"Index\": 62, \"Highest Charting Position\": 26, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Your Love (9PM)\", \"Streams\": 8935418, \"Artist\": \"ATB, Topic, A7S\", \"Artist Followers\": 291777.0, \"Song ID\": \"5YaskwnGDZFDRipaqzbwQx\", \"Genre\": \"['german dance', 'german techno', 'german trance', 'trance']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 88.0, \"Danceability\": 0.669, \"Energy\": 0.784, \"Loudness\": -5.603, \"Speechiness\": 0.112, \"Acousticness\": 0.194, \"Liveness\": 0.115, \"Tempo\": 125.993, \"Duration (ms)\": 150053.0, \"Valence\": 0.517, \"Chord\": \"G\"}, {\"Index\": 63, \"Highest Charting Position\": 9, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"brutal\", \"Streams\": 8881356, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"6SRsiMl7w1USE4mFqrOhHC\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 89.0, \"Danceability\": 0.672, \"Energy\": 0.526, \"Loudness\": -6.446, \"Speechiness\": 0.0599, \"Acousticness\": 0.0311, \"Liveness\": 0.28, \"Tempo\": 123.999, \"Duration (ms)\": 143747.0, \"Valence\": 0.28, \"Chord\": \"E\"}, {\"Index\": 64, \"Highest Charting Position\": 2, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Save Your Tears\", \"Streams\": 8843110, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"37BZB0z9T8Xu7U3e65qxFy\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 94.0, \"Danceability\": 0.65, \"Energy\": 0.825, \"Loudness\": -4.645, \"Speechiness\": 0.0325, \"Acousticness\": 0.0215, \"Liveness\": 0.0936, \"Tempo\": 118.091, \"Duration (ms)\": 191014.0, \"Valence\": 0.593, \"Chord\": \"C\"}, {\"Index\": 65, \"Highest Charting Position\": 8, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Heartbreak Anniversary\", \"Streams\": 8832945, \"Artist\": \"Giveon\", \"Artist Followers\": 1398563.0, \"Song ID\": \"3FAJ6O0NOHQV8Mc5Ri6ENp\", \"Genre\": \"['pop', 'r&b']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 87.0, \"Danceability\": 0.449, \"Energy\": 0.465, \"Loudness\": -8.964, \"Speechiness\": 0.0791, \"Acousticness\": 0.524, \"Liveness\": 0.303, \"Tempo\": 89.087, \"Duration (ms)\": 198371.0, \"Valence\": 0.543, \"Chord\": \"C\"}, {\"Index\": 66, \"Highest Charting Position\": 2, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Don't Start Now\", \"Streams\": 8821971, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 1250353.0, \"Song ID\": \"7njGslFmqBmOSSOpTyZCs9\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.793, \"Energy\": 0.793, \"Loudness\": -4.521, \"Speechiness\": 0.083, \"Acousticness\": 0.0123, \"Liveness\": 0.0951, \"Tempo\": 123.95, \"Duration (ms)\": 183290.0, \"Valence\": 0.679, \"Chord\": \"B\"}, {\"Index\": 67, \"Highest Charting Position\": 33, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Dinero\", \"Streams\": 8564775, \"Artist\": \"Trinidad Cardona\", \"Artist Followers\": 116817.0, \"Song ID\": \"3ggtU1ZOKO8ZNiqPNyXGcm\", \"Genre\": \"[]\", \"Release Date\": \"2018-02-02\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 87.0, \"Danceability\": 0.708, \"Energy\": 0.782, \"Loudness\": -4.687, \"Speechiness\": 0.0674, \"Acousticness\": 0.00772, \"Liveness\": 0.107, \"Tempo\": 119.997, \"Duration (ms)\": 160880.0, \"Valence\": 0.484, \"Chord\": \"D\"}, {\"Index\": 68, \"Highest Charting Position\": 35, \"Number of Times Charted\": 48, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Sweater Weather\", \"Streams\": 8564017, \"Artist\": \"The Neighbourhood\", \"Artist Followers\": 6662605.0, \"Song ID\": \"2QjOHCTQ1Jl3zawyYOpxh6\", \"Genre\": \"['modern alternative rock', 'modern rock', 'pop']\", \"Release Date\": \"2013-04-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 87.0, \"Danceability\": 0.612, \"Energy\": 0.807, \"Loudness\": -2.81, \"Speechiness\": 0.0336, \"Acousticness\": 0.0495, \"Liveness\": 0.101, \"Tempo\": 124.053, \"Duration (ms)\": 240400.0, \"Valence\": 0.398, \"Chord\": \"A#/Bb\"}, {\"Index\": 69, \"Highest Charting Position\": 69, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Sobrio\", \"Streams\": 8514480, \"Artist\": \"Maluma\", \"Artist Followers\": 26769304.0, \"Song ID\": \"4HzqWEdAbzcVFDv0pvxV4w\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-07-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 87.0, \"Danceability\": 0.762, \"Energy\": 0.77, \"Loudness\": -2.758, \"Speechiness\": 0.223, \"Acousticness\": 0.138, \"Liveness\": 0.15, \"Tempo\": 177.998, \"Duration (ms)\": 201181.0, \"Valence\": 0.631, \"Chord\": \"F\"}, {\"Index\": 70, \"Highest Charting Position\": 12, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Someone You Loved\", \"Streams\": 8490162, \"Artist\": \"Lewis Capaldi\", \"Artist Followers\": 8384096.0, \"Song ID\": \"7qEHsqek33rTcFNT9PFqLf\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.501, \"Energy\": 0.405, \"Loudness\": -5.679, \"Speechiness\": 0.0319, \"Acousticness\": 0.751, \"Liveness\": 0.105, \"Tempo\": 109.891, \"Duration (ms)\": 182161.0, \"Valence\": 0.446, \"Chord\": \"C#/Db\"}, {\"Index\": 71, \"Highest Charting Position\": 71, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Over The Top (feat. Drake)\", \"Streams\": 8269753, \"Artist\": \"Smiley\", \"Artist Followers\": 26131.0, \"Song ID\": \"3yaYgjEFkRw3PVjW9mV1TO\", \"Genre\": \"['canadian hip hop', 'toronto rap']\", \"Release Date\": \"2021-07-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 83.0, \"Danceability\": 0.833, \"Energy\": 0.498, \"Loudness\": -5.196, \"Speechiness\": 0.117, \"Acousticness\": 0.0493, \"Liveness\": 0.119, \"Tempo\": 139.928, \"Duration (ms)\": 153406.0, \"Valence\": 0.259, \"Chord\": \"A#/Bb\"}, {\"Index\": 72, \"Highest Charting Position\": 72, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"2055\", \"Streams\": 8133401, \"Artist\": \"Sleepy Hallow\", \"Artist Followers\": 408696.0, \"Song ID\": \"4XvcHTUfIlWfyJTRG0aqlo\", \"Genre\": \"['brooklyn drill', 'nyc rap']\", \"Release Date\": \"2021-06-02\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 85.0, \"Danceability\": 0.829, \"Energy\": 0.512, \"Loudness\": -5.865, \"Speechiness\": 0.187, \"Acousticness\": 0.492, \"Liveness\": 0.12, \"Tempo\": 80.511, \"Duration (ms)\": 123987.0, \"Valence\": 0.638, \"Chord\": \"F#/Gb\"}, {\"Index\": 73, \"Highest Charting Position\": 33, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"EL MAKINON\", \"Streams\": 8102107, \"Artist\": \"KAROL G, Mariah Angeliq\", \"Artist Followers\": 17775316.0, \"Song ID\": \"2FSGUA0gFgGeQdprjtGM2M\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 87.0, \"Danceability\": 0.635, \"Energy\": 0.706, \"Loudness\": -3.224, \"Speechiness\": 0.125, \"Acousticness\": 0.256, \"Liveness\": 0.108, \"Tempo\": 88.863, \"Duration (ms)\": 209160.0, \"Valence\": 0.443, \"Chord\": \"F\"}, {\"Index\": 74, \"Highest Charting Position\": 74, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Loco\", \"Streams\": 8093413, \"Artist\": \"Justin Quiles, Chimbala, Zion & Lennox\", \"Artist Followers\": 2895789.0, \"Song ID\": \"6PDlkWmrq2ZKiUuFt2aQsH\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 87.0, \"Danceability\": 0.77, \"Energy\": 0.899, \"Loudness\": -2.981, \"Speechiness\": 0.0494, \"Acousticness\": 0.222, \"Liveness\": 0.0894, \"Tempo\": 128.05, \"Duration (ms)\": 231604.0, \"Valence\": 0.851, \"Chord\": \"G#/Ab\"}, {\"Index\": 75, \"Highest Charting Position\": 75, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Love Tonight - Edit\", \"Streams\": 8006336, \"Artist\": \"Shouse\", \"Artist Followers\": 27116.0, \"Song ID\": \"6OufwUcCqo81guU2jAlDVP\", \"Genre\": \"['aussietronica']\", \"Release Date\": \"2017-12-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 87.0, \"Danceability\": 0.727, \"Energy\": 0.681, \"Loudness\": -7.114, \"Speechiness\": 0.0265, \"Acousticness\": 0.00214, \"Liveness\": 0.0861, \"Tempo\": 123.028, \"Duration (ms)\": 241970.0, \"Valence\": 0.448, \"Chord\": \"F\"}, {\"Index\": 76, \"Highest Charting Position\": 12, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"ZITTI E BUONI\", \"Streams\": 7975148, \"Artist\": \"M\\u00e5neskin\", \"Artist Followers\": 3377762.0, \"Song ID\": \"776AftMmFFAWUIEAb3lHhw\", \"Genre\": \"['indie rock italiano', 'italian pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-03-05--2021-03-12\", \"Popularity\": 86.0, \"Danceability\": 0.625, \"Energy\": 0.939, \"Loudness\": -3.115, \"Speechiness\": 0.0669, \"Acousticness\": 0.00138, \"Liveness\": 0.424, \"Tempo\": 102.999, \"Duration (ms)\": 194787.0, \"Valence\": 0.644, \"Chord\": \"E\"}, {\"Index\": 77, \"Highest Charting Position\": 2, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"telepat\\u00eda\", \"Streams\": 7912399, \"Artist\": \"Kali Uchis\", \"Artist Followers\": 1999954.0, \"Song ID\": \"6tDDoYIxWvMLTdKpjFkc1B\", \"Genre\": \"['colombian pop', 'pop']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 88.0, \"Danceability\": 0.653, \"Energy\": 0.524, \"Loudness\": -9.016, \"Speechiness\": 0.0502, \"Acousticness\": 0.112, \"Liveness\": 0.203, \"Tempo\": 83.97, \"Duration (ms)\": 160191.0, \"Valence\": 0.553, \"Chord\": \"B\"}, {\"Index\": 78, \"Highest Charting Position\": 9, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Botella Tras Botella\", \"Streams\": 7735223, \"Artist\": \"Gera MX, Christian Nodal\", \"Artist Followers\": 2043294.0, \"Song ID\": \"2MnLkFqY9Rpg9s3Zv6ZJdK\", \"Genre\": \"['mexican hip hop', 'rap conciencia']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 87.0, \"Danceability\": 0.727, \"Energy\": 0.546, \"Loudness\": -4.572, \"Speechiness\": 0.0437, \"Acousticness\": 0.656, \"Liveness\": 0.122, \"Tempo\": 106.891, \"Duration (ms)\": 197333.0, \"Valence\": 0.69, \"Chord\": \"C\"}, {\"Index\": 79, \"Highest Charting Position\": 7, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Fiel\", \"Streams\": 7717211, \"Artist\": \"Los Legendarios, Wisin, Jhay Cortez\", \"Artist Followers\": 31488.0, \"Song ID\": \"7Bk0uXKk1uPT0XuQbpFzvs\", \"Genre\": \"['reggaeton', 'trap latino']\", \"Release Date\": \"2021-02-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 88.0, \"Danceability\": 0.849, \"Energy\": 0.701, \"Loudness\": -4.407, \"Speechiness\": 0.06, \"Acousticness\": 0.407, \"Liveness\": 0.112, \"Tempo\": 98.005, \"Duration (ms)\": 261667.0, \"Valence\": 0.505, \"Chord\": \"F#/Gb\"}, {\"Index\": 80, \"Highest Charting Position\": 1, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Dance Monkey\", \"Streams\": 7687058, \"Artist\": \"Tones And I\", \"Artist Followers\": 2819593.0, \"Song ID\": \"2XU0oxnq2qxCpomAAuJY8K\", \"Genre\": \"['australian pop', 'pop']\", \"Release Date\": \"2019-10-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.824, \"Energy\": 0.588, \"Loudness\": -6.4, \"Speechiness\": 0.0924, \"Acousticness\": 0.692, \"Liveness\": 0.149, \"Tempo\": 98.027, \"Duration (ms)\": 209438.0, \"Valence\": 0.513, \"Chord\": \"F#/Gb\"}, {\"Index\": 81, \"Highest Charting Position\": 7, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"WITHOUT YOU\", \"Streams\": 7642130, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2230022.0, \"Song ID\": \"27OeeYzk6klgBh83TSvGMA\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 87.0, \"Danceability\": 0.662, \"Energy\": 0.413, \"Loudness\": -7.357, \"Speechiness\": 0.0299, \"Acousticness\": 0.213, \"Liveness\": 0.134, \"Tempo\": 93.005, \"Duration (ms)\": 161385.0, \"Valence\": 0.467, \"Chord\": \"C\"}, {\"Index\": 82, \"Highest Charting Position\": 6, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Wants and Needs (feat. Lil Baby)\", \"Streams\": 7637626, \"Artist\": \"Drake\", \"Artist Followers\": 56308172.0, \"Song ID\": \"65OVbaJR5O1RmwOQx0875b\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 87.0, \"Danceability\": 0.578, \"Energy\": 0.449, \"Loudness\": -6.349, \"Speechiness\": 0.286, \"Acousticness\": 0.0618, \"Liveness\": 0.119, \"Tempo\": 136.006, \"Duration (ms)\": 192956.0, \"Valence\": 0.1, \"Chord\": \"C#/Db\"}, {\"Index\": 83, \"Highest Charting Position\": 83, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Bezos I\", \"Streams\": 7516291, \"Artist\": \"Bo Burnham\", \"Artist Followers\": 1042079.0, \"Song ID\": \"0Kdj7nwaYQmvhxnqZaIQuW\", \"Genre\": \"['comic']\", \"Release Date\": \"2021-06-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 84.0, \"Danceability\": 0.694, \"Energy\": 0.948, \"Loudness\": -5.307, \"Speechiness\": 0.0361, \"Acousticness\": 0.00936, \"Liveness\": 0.139, \"Tempo\": 115.044, \"Duration (ms)\": 58149.0, \"Valence\": 0.705, \"Chord\": \"D\"}, {\"Index\": 84, \"Highest Charting Position\": 76, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Love Again\", \"Streams\": 7465445, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 1250353.0, \"Song ID\": \"2sN1pMv6d2t5GlvN6IBMlK\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2020-03-27--2020-04-03\", \"Popularity\": 0.0, \"Danceability\": 0.659, \"Energy\": 0.667, \"Loudness\": -4.668, \"Speechiness\": 0.0339, \"Acousticness\": 0.00173, \"Liveness\": 0.1, \"Tempo\": 115.982, \"Duration (ms)\": 258004.0, \"Valence\": 0.468, \"Chord\": \"B\"}, {\"Index\": 85, \"Highest Charting Position\": 32, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Goosebumps - Remix\", \"Streams\": 7452633, \"Artist\": \"Travis Scott, HVME\", \"Artist Followers\": 17719446.0, \"Song ID\": \"5uEYRdEIh9Bo4fpjDd4Na9\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 87.0, \"Danceability\": 0.841, \"Energy\": 0.593, \"Loudness\": -7.846, \"Speechiness\": 0.0379, \"Acousticness\": 0.418, \"Liveness\": 0.124, \"Tempo\": 124.917, \"Duration (ms)\": 162803.0, \"Valence\": 0.808, \"Chord\": \"C#/Db\"}, {\"Index\": 86, \"Highest Charting Position\": 11, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Head & Heart (feat. MNEK)\", \"Streams\": 7434252, \"Artist\": \"Joel Corry\", \"Artist Followers\": 207547.0, \"Song ID\": \"6cx06DFPPHchuUAcTxznu9\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance', 'tropical house', 'uk dance']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 87.0, \"Danceability\": 0.734, \"Energy\": 0.874, \"Loudness\": -3.158, \"Speechiness\": 0.0662, \"Acousticness\": 0.168, \"Liveness\": 0.0489, \"Tempo\": 122.953, \"Duration (ms)\": 166028.0, \"Valence\": 0.905, \"Chord\": \"G#/Ab\"}, {\"Index\": 87, \"Highest Charting Position\": 42, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"BED\", \"Streams\": 7383369, \"Artist\": \"Joel Corry, RAYE, David Guetta\", \"Artist Followers\": 207547.0, \"Song ID\": \"0siYMEsGrzzzlWLXK5zJfS\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance', 'tropical house', 'uk dance']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 87.0, \"Danceability\": 0.671, \"Energy\": 0.782, \"Loudness\": -4.593, \"Speechiness\": 0.0341, \"Acousticness\": 0.0142, \"Liveness\": 0.333, \"Tempo\": 123.989, \"Duration (ms)\": 178088.0, \"Valence\": 0.618, \"Chord\": \"F#/Gb\"}, {\"Index\": 88, \"Highest Charting Position\": 78, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Iko Iko (My Bestie)\", \"Streams\": 7381585, \"Artist\": \"Justin Wellington, Small Jam\", \"Artist Followers\": 18228.0, \"Song ID\": \"7MC4XR9M9amdmKQr2iDF7i\", \"Genre\": \"['melanesian pop', 'pacific islands pop', 'png pop']\", \"Release Date\": \"2019-06-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 87.0, \"Danceability\": 0.862, \"Energy\": 0.753, \"Loudness\": -5.356, \"Speechiness\": 0.0625, \"Acousticness\": 0.131, \"Liveness\": 0.077, \"Tempo\": 105.039, \"Duration (ms)\": 182857.0, \"Valence\": 0.827, \"Chord\": \"F\"}, {\"Index\": 89, \"Highest Charting Position\": 89, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Better Believe\", \"Streams\": 7365053, \"Artist\": \"Belly, The Weeknd, Young Thug\", \"Artist Followers\": 203972.0, \"Song ID\": \"3zs87EV3EZSh2UpiXxT52Y\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'pop rap', 'rap', 'southern hip hop', 'trap', 'trap soul', 'underground hip hop']\", \"Release Date\": \"2021-07-22\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 80.0, \"Danceability\": 0.797, \"Energy\": 0.573, \"Loudness\": -7.85, \"Speechiness\": 0.319, \"Acousticness\": 0.159, \"Liveness\": 0.144, \"Tempo\": 124.995, \"Duration (ms)\": 206629.0, \"Valence\": 0.445, \"Chord\": \"C\"}, {\"Index\": 90, \"Highest Charting Position\": 23, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Arcade\", \"Streams\": 7353795, \"Artist\": \"Duncan Laurence\", \"Artist Followers\": 287361.0, \"Song ID\": \"1Xi84slp6FryDSCbzq4UCD\", \"Genre\": \"['dutch pop']\", \"Release Date\": \"2019-03-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 84.0, \"Danceability\": 0.45, \"Energy\": 0.329, \"Loudness\": -12.603, \"Speechiness\": 0.0441, \"Acousticness\": 0.818, \"Liveness\": 0.135, \"Tempo\": 71.884, \"Duration (ms)\": 183624.0, \"Valence\": 0.266, \"Chord\": \"A\"}, {\"Index\": 91, \"Highest Charting Position\": 55, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"512\", \"Streams\": 7336542, \"Artist\": \"Mora, Jhay Cortez\", \"Artist Followers\": 151486.0, \"Song ID\": \"5jzEwSyyymBlf1fa1o39T2\", \"Genre\": \"['reggaeton', 'trap latino']\", \"Release Date\": \"2021-02-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 87.0, \"Danceability\": 0.818, \"Energy\": 0.673, \"Loudness\": -7.542, \"Speechiness\": 0.148, \"Acousticness\": 0.348, \"Liveness\": 0.172, \"Tempo\": 87.961, \"Duration (ms)\": 193636.0, \"Valence\": 0.695, \"Chord\": \"E\"}, {\"Index\": 92, \"Highest Charting Position\": 1, \"Number of Times Charted\": 40, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"positions\", \"Streams\": 7244853, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67158068.0, \"Song ID\": \"35mvY5S1H3J2QZyna3TFe0\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 86.0, \"Danceability\": 0.737, \"Energy\": 0.802, \"Loudness\": -4.771, \"Speechiness\": 0.0878, \"Acousticness\": 0.468, \"Liveness\": 0.0931, \"Tempo\": 144.015, \"Duration (ms)\": 172325.0, \"Valence\": 0.682, \"Chord\": \"C\"}, {\"Index\": 93, \"Highest Charting Position\": 6, \"Number of Times Charted\": 84, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Circles\", \"Streams\": 7156162, \"Artist\": \"Post Malone\", \"Artist Followers\": 33651775.0, \"Song ID\": \"21jGcNKet2qwijlDFuPiPb\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 87.0, \"Danceability\": 0.695, \"Energy\": 0.762, \"Loudness\": -3.497, \"Speechiness\": 0.0395, \"Acousticness\": 0.192, \"Liveness\": 0.0863, \"Tempo\": 120.042, \"Duration (ms)\": 215280.0, \"Valence\": 0.553, \"Chord\": \"C\"}, {\"Index\": 94, \"Highest Charting Position\": 94, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Blaues Licht\", \"Streams\": 7084292, \"Artist\": \"RAF Camora, Bonez MC\", \"Artist Followers\": 1329531.0, \"Song ID\": \"08EPQiLMyGB8GJX2EiVoCM\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 78.0, \"Danceability\": 0.819, \"Energy\": 0.835, \"Loudness\": -4.899, \"Speechiness\": 0.102, \"Acousticness\": 0.398, \"Liveness\": 0.252, \"Tempo\": 144.955, \"Duration (ms)\": 144264.0, \"Valence\": 0.703, \"Chord\": \"G#/Ab\"}, {\"Index\": 95, \"Highest Charting Position\": 75, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Ram Pam Pam\", \"Streams\": 7064003, \"Artist\": \"Natti Natasha, Becky G\", \"Artist Followers\": 6341942.0, \"Song ID\": \"4DHDIdeayp8xvlyg22wREO\", \"Genre\": \"['latin', 'latin pop', 'rap latina', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-04-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 86.0, \"Danceability\": 0.908, \"Energy\": 0.813, \"Loudness\": -2.749, \"Speechiness\": 0.0777, \"Acousticness\": 0.305, \"Liveness\": 0.278, \"Tempo\": 97.018, \"Duration (ms)\": 200785.0, \"Valence\": 0.924, \"Chord\": \"F\"}, {\"Index\": 96, \"Highest Charting Position\": 96, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"In Da Getto\", \"Streams\": 6984262, \"Artist\": \"J Balvin, Skrillex\", \"Artist Followers\": 1250353.0, \"Song ID\": \"5lGtPshEJlsJgmqKLi41LY\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 2.0, \"Danceability\": 0.915, \"Energy\": 0.72, \"Loudness\": -3.126, \"Speechiness\": 0.0459, \"Acousticness\": 0.025, \"Liveness\": 0.0942, \"Tempo\": 126.986, \"Duration (ms)\": 131067.0, \"Valence\": 0.631, \"Chord\": \"G#/Ab\"}, {\"Index\": 97, \"Highest Charting Position\": 97, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Woman\", \"Streams\": 6858466, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"6Uj1ctrBOjOas8xZXGqKk4\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-06-25--2021-07-02\", \"Popularity\": 86.0, \"Danceability\": 0.824, \"Energy\": 0.764, \"Loudness\": -4.175, \"Speechiness\": 0.0854, \"Acousticness\": 0.0888, \"Liveness\": 0.117, \"Tempo\": 107.998, \"Duration (ms)\": 172627.0, \"Valence\": 0.881, \"Chord\": \"F\"}, {\"Index\": 98, \"Highest Charting Position\": 60, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"t r a n s p a r e n t s o u l feat. Travis Barker\", \"Streams\": 6853994, \"Artist\": \"WILLOW\", \"Artist Followers\": 1521837.0, \"Song ID\": \"1QL7nSDZCwZMnbisV4KOXt\", \"Genre\": \"['afrofuturism', 'dance pop', 'electropop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2021-04-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 85.0, \"Danceability\": 0.39, \"Energy\": 0.83, \"Loudness\": -5.201, \"Speechiness\": 0.0563, \"Acousticness\": 0.0021, \"Liveness\": 0.156, \"Tempo\": 90.021, \"Duration (ms)\": 168030.0, \"Valence\": 0.191, \"Chord\": \"B\"}, {\"Index\": 99, \"Highest Charting Position\": 99, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Clash (feat. Stormzy)\", \"Streams\": 6825463, \"Artist\": \"Dave\", \"Artist Followers\": 1427540.0, \"Song ID\": \"2oUwMN5VfdGX10XeQJLBBi\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2021-07-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-09--2021-07-16\", \"Popularity\": 79.0, \"Danceability\": 0.871, \"Energy\": 0.519, \"Loudness\": -6.549, \"Speechiness\": 0.258, \"Acousticness\": 0.313, \"Liveness\": 0.0869, \"Tempo\": 140.013, \"Duration (ms)\": 251733.0, \"Valence\": 0.532, \"Chord\": \"D\"}, {\"Index\": 100, \"Highest Charting Position\": 22, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Before You Go\", \"Streams\": 6813800, \"Artist\": \"Lewis Capaldi\", \"Artist Followers\": 8384096.0, \"Song ID\": \"2gMXnyrvIjhVBUZwvLZDMP\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.459, \"Energy\": 0.575, \"Loudness\": -4.858, \"Speechiness\": 0.0573, \"Acousticness\": 0.604, \"Liveness\": 0.0885, \"Tempo\": 111.881, \"Duration (ms)\": 215107.0, \"Valence\": 0.183, \"Chord\": \"D#/Eb\"}, {\"Index\": 101, \"Highest Charting Position\": 52, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Levitating\", \"Streams\": 6799831, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"463CkQjx2Zk1yXoBuierM9\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-10-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 89.0, \"Danceability\": 0.702, \"Energy\": 0.825, \"Loudness\": -3.787, \"Speechiness\": 0.0601, \"Acousticness\": 0.00883, \"Liveness\": 0.0674, \"Tempo\": 102.977, \"Duration (ms)\": 203064.0, \"Valence\": 0.915, \"Chord\": \"F#/Gb\"}, {\"Index\": 102, \"Highest Charting Position\": 85, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Reckless\", \"Streams\": 6711375, \"Artist\": \"Madison Beer\", \"Artist Followers\": 3363988.0, \"Song ID\": \"5ajjAnNRh8bxFvaVHzpPjh\", \"Genre\": \"['alt z', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 86.0, \"Danceability\": 0.386, \"Energy\": 0.426, \"Loudness\": -6.642, \"Speechiness\": 0.0363, \"Acousticness\": 0.807, \"Liveness\": 0.14, \"Tempo\": 180.104, \"Duration (ms)\": 203385.0, \"Valence\": 0.261, \"Chord\": \"D#/Eb\"}, {\"Index\": 103, \"Highest Charting Position\": 103, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"No Me Conocen (Remix) [con DUKI, Rei & Tiago PZK]\", \"Streams\": 6709106, \"Artist\": \"BANDIDO\", \"Artist Followers\": 16074.0, \"Song ID\": \"7COGuXyTr12KvdaYXMqheC\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 85.0, \"Danceability\": 0.769, \"Energy\": 0.812, \"Loudness\": -2.088, \"Speechiness\": 0.0825, \"Acousticness\": 0.281, \"Liveness\": 0.0781, \"Tempo\": 180.003, \"Duration (ms)\": 280274.0, \"Valence\": 0.926, \"Chord\": \"C#/Db\"}, {\"Index\": 104, \"Highest Charting Position\": 88, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Believer\", \"Streams\": 6699895, \"Artist\": \"Imagine Dragons\", \"Artist Followers\": 35285425.0, \"Song ID\": \"0pqnGHJpmpxLKifKRmU6WP\", \"Genre\": \"['modern rock', 'pop', 'rock']\", \"Release Date\": \"2017-06-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.776, \"Energy\": 0.78, \"Loudness\": -4.374, \"Speechiness\": 0.128, \"Acousticness\": 0.0622, \"Liveness\": 0.081, \"Tempo\": 124.949, \"Duration (ms)\": 204347.0, \"Valence\": 0.666, \"Chord\": \"A#/Bb\"}, {\"Index\": 105, \"Highest Charting Position\": 2, \"Number of Times Charted\": 48, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Lemonade (feat. Gunna, Don Toliver & NAV)\", \"Streams\": 6697067, \"Artist\": \"Internet Money\", \"Artist Followers\": 411579.0, \"Song ID\": \"02kDW379Yfd5PzW5A6vuGt\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 82.0, \"Danceability\": 0.799, \"Energy\": 0.66, \"Loudness\": -6.153, \"Speechiness\": 0.079, \"Acousticness\": 0.256, \"Liveness\": 0.111, \"Tempo\": 140.04, \"Duration (ms)\": 195429.0, \"Valence\": 0.471, \"Chord\": \"C#/Db\"}, {\"Index\": 106, \"Highest Charting Position\": 45, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Talking to the Moon\", \"Streams\": 6660319, \"Artist\": \"Bruno Mars\", \"Artist Followers\": 32574754.0, \"Song ID\": \"161DnLWsx1i3u1JT05lzqU\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2010-10-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 83.0, \"Danceability\": 0.523, \"Energy\": 0.606, \"Loudness\": -4.754, \"Speechiness\": 0.0301, \"Acousticness\": 0.512, \"Liveness\": 0.106, \"Tempo\": 145.837, \"Duration (ms)\": 217867.0, \"Valence\": 0.065, \"Chord\": \"C#/Db\"}, {\"Index\": 107, \"Highest Charting Position\": 3, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Roses - Imanbek Remix\", \"Streams\": 6653690, \"Artist\": \"SAINt JHN\", \"Artist Followers\": 742692.0, \"Song ID\": \"0zLCBJZSiELJf02ucPP9wb\", \"Genre\": \"['melodic rap', 'pop rap', 'rap', 'slap house', 'trap']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.769, \"Energy\": 0.719, \"Loudness\": -5.472, \"Speechiness\": 0.0474, \"Acousticness\": 0.0143, \"Liveness\": 0.359, \"Tempo\": 121.955, \"Duration (ms)\": 176867.0, \"Valence\": 0.863, \"Chord\": \"G#/Ab\"}, {\"Index\": 108, \"Highest Charting Position\": 59, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Sal y Perrea\", \"Streams\": 6635076, \"Artist\": \"Sech\", \"Artist Followers\": 8758283.0, \"Song ID\": \"5u7twkeask1VIyDeNTElSU\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-04-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 86.0, \"Danceability\": 0.786, \"Energy\": 0.899, \"Loudness\": -0.515, \"Speechiness\": 0.127, \"Acousticness\": 0.192, \"Liveness\": 0.299, \"Tempo\": 90.025, \"Duration (ms)\": 216510.0, \"Valence\": 0.813, \"Chord\": \"A#/Bb\"}, {\"Index\": 109, \"Highest Charting Position\": 109, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Fulanito\", \"Streams\": 6614072, \"Artist\": \"Becky G, El Alfa\", \"Artist Followers\": 10356559.0, \"Song ID\": \"59L8x0xy8njj75vzVCPMqg\", \"Genre\": \"['dance pop', 'latin', 'latin pop', 'latin viral pop', 'pop', 'rap latina', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 86.0, \"Danceability\": 0.93, \"Energy\": 0.837, \"Loudness\": -4.632, \"Speechiness\": 0.187, \"Acousticness\": 0.256, \"Liveness\": 0.239, \"Tempo\": 111.898, \"Duration (ms)\": 158532.0, \"Valence\": 0.821, \"Chord\": \"G\"}, {\"Index\": 110, \"Highest Charting Position\": 110, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Par\\u00eds\", \"Streams\": 6584896, \"Artist\": \"Ingratax\", \"Artist Followers\": 56699.0, \"Song ID\": \"4bF2y8rR7GUjrd5LNEvej3\", \"Genre\": \"[]\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 86.0, \"Danceability\": 0.57, \"Energy\": 0.455, \"Loudness\": -5.748, \"Speechiness\": 0.0996, \"Acousticness\": 0.441, \"Liveness\": 0.0654, \"Tempo\": 167.933, \"Duration (ms)\": 151429.0, \"Valence\": 0.399, \"Chord\": \"C#/Db\"}, {\"Index\": 111, \"Highest Charting Position\": 46, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"lovely (with Khalid)\", \"Streams\": 6569547, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47014200.0, \"Song ID\": \"0u2P5u6lvoDfwTYjAADbn4\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2018-04-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.351, \"Energy\": 0.296, \"Loudness\": -10.109, \"Speechiness\": 0.0333, \"Acousticness\": 0.934, \"Liveness\": 0.095, \"Tempo\": 115.284, \"Duration (ms)\": 200186.0, \"Valence\": 0.12, \"Chord\": \"E\"}, {\"Index\": 112, \"Highest Charting Position\": 24, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Sunflower - Spider-Man: Into the Spider-Verse\", \"Streams\": 6546948, \"Artist\": \"Post Malone, Swae Lee\", \"Artist Followers\": 1250353.0, \"Song ID\": \"3KkXRkHbMCARz0aVfEt68P\", \"Genre\": \"[]\", \"Release Date\": \"2018-12-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.76, \"Energy\": 0.479, \"Loudness\": -5.574, \"Speechiness\": 0.0466, \"Acousticness\": 0.556, \"Liveness\": 0.0703, \"Tempo\": 89.911, \"Duration (ms)\": 158040.0, \"Valence\": 0.913, \"Chord\": \"D\"}, {\"Index\": 113, \"Highest Charting Position\": 113, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"double take\", \"Streams\": 6539852, \"Artist\": \"dhruv\", \"Artist Followers\": 73211.0, \"Song ID\": \"2CVChktEKBsM6v4IfdFU5k\", \"Genre\": \"['chill r&b', 'nyc pop']\", \"Release Date\": \"2019-05-24\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 86.0, \"Danceability\": 0.663, \"Energy\": 0.434, \"Loudness\": -11.177, \"Speechiness\": 0.0648, \"Acousticness\": 0.828, \"Liveness\": 0.249, \"Tempo\": 109.075, \"Duration (ms)\": 171743.0, \"Valence\": 0.225, \"Chord\": \"G#/Ab\"}, {\"Index\": 114, \"Highest Charting Position\": 9, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Streets\", \"Streams\": 6502302, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"60ynsPSSKe6O3sfwRnIBRf\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 86.0, \"Danceability\": 0.749, \"Energy\": 0.463, \"Loudness\": -8.433, \"Speechiness\": 0.0842, \"Acousticness\": 0.21, \"Liveness\": 0.338, \"Tempo\": 90.035, \"Duration (ms)\": 226987.0, \"Valence\": 0.189, \"Chord\": \"B\"}, {\"Index\": 115, \"Highest Charting Position\": 80, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"By Your Side (feat. Tom Grennan)\", \"Streams\": 6488622, \"Artist\": \"Calvin Harris\", \"Artist Followers\": 21942793.0, \"Song ID\": \"0vR2rIVORmgeKiGIgNT0fV\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'house', 'pop', 'progressive house', 'uk dance']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 85.0, \"Danceability\": 0.733, \"Energy\": 0.96, \"Loudness\": -3.597, \"Speechiness\": 0.0295, \"Acousticness\": 0.0514, \"Liveness\": 0.287, \"Tempo\": 124.01, \"Duration (ms)\": 189672.0, \"Valence\": 0.811, \"Chord\": \"G\"}, {\"Index\": 116, \"Highest Charting Position\": 116, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"MORENA\", \"Streams\": 6469500, \"Artist\": \"Luan Santana\", \"Artist Followers\": 5420471.0, \"Song ID\": \"4PQdrXMDHDPl1RczrrlADd\", \"Genre\": \"['sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2021-06-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 85.0, \"Danceability\": 0.526, \"Energy\": 0.731, \"Loudness\": -4.662, \"Speechiness\": 0.0887, \"Acousticness\": 0.18, \"Liveness\": 0.0891, \"Tempo\": 86.959, \"Duration (ms)\": 193221.0, \"Valence\": 0.476, \"Chord\": \"B\"}, {\"Index\": 117, \"Highest Charting Position\": 80, \"Number of Times Charted\": 80, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Shape of You\", \"Streams\": 6452492, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83293380.0, \"Song ID\": \"7qiZfU4dY1lWllzX7mPBI3\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2017-03-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.825, \"Energy\": 0.652, \"Loudness\": -3.183, \"Speechiness\": 0.0802, \"Acousticness\": 0.581, \"Liveness\": 0.0931, \"Tempo\": 95.977, \"Duration (ms)\": 233713.0, \"Valence\": 0.931, \"Chord\": \"C#/Db\"}, {\"Index\": 118, \"Highest Charting Position\": 9, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Se\\u00f1orita\", \"Streams\": 6317487, \"Artist\": \"Shawn Mendes, Camila Cabello\", \"Artist Followers\": 33879560.0, \"Song ID\": \"0TK2YIli7K1leLovkQiNik\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.759, \"Energy\": 0.54, \"Loudness\": -6.039, \"Speechiness\": 0.0287, \"Acousticness\": 0.037, \"Liveness\": 0.0945, \"Tempo\": 116.947, \"Duration (ms)\": 190960.0, \"Valence\": 0.75, \"Chord\": \"A\"}, {\"Index\": 119, \"Highest Charting Position\": 5, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Hold On\", \"Streams\": 6300416, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 1250353.0, \"Song ID\": \"49xx65gvlD7xXjDTavFqaJ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 0.0, \"Danceability\": 0.658, \"Energy\": 0.634, \"Loudness\": -5.797, \"Speechiness\": 0.0413, \"Acousticness\": 0.0106, \"Liveness\": 0.132, \"Tempo\": 139.98, \"Duration (ms)\": 170813.0, \"Valence\": 0.29, \"Chord\": \"C#/Db\"}, {\"Index\": 120, \"Highest Charting Position\": 99, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Perfect\", \"Streams\": 6278765, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83293380.0, \"Song ID\": \"0tgVpDi06FyKpA1z0VMD4v\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2017-03-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.599, \"Energy\": 0.448, \"Loudness\": -6.312, \"Speechiness\": 0.0232, \"Acousticness\": 0.163, \"Liveness\": 0.106, \"Tempo\": 95.05, \"Duration (ms)\": 263400.0, \"Valence\": 0.168, \"Chord\": \"G#/Ab\"}, {\"Index\": 121, \"Highest Charting Position\": 80, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"2:50 Remix\", \"Streams\": 6244011, \"Artist\": \"MYA, TINI, Duki\", \"Artist Followers\": 282045.0, \"Song ID\": \"74znaWw1hmQBusGPSOuTFy\", \"Genre\": \"['latin pop']\", \"Release Date\": \"2021-06-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 85.0, \"Danceability\": 0.818, \"Energy\": 0.812, \"Loudness\": -4.425, \"Speechiness\": 0.0475, \"Acousticness\": 0.112, \"Liveness\": 0.234, \"Tempo\": 139.966, \"Duration (ms)\": 231708.0, \"Valence\": 0.844, \"Chord\": \"A\"}, {\"Index\": 122, \"Highest Charting Position\": 2, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"LA NOCHE DE ANOCHE\", \"Streams\": 6242863, \"Artist\": \"Bad Bunny, ROSAL\\u00cdA\", \"Artist Followers\": 36142273.0, \"Song ID\": \"2XIc1pqjXV3Cr2BQUGNBck\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 86.0, \"Danceability\": 0.856, \"Energy\": 0.618, \"Loudness\": -4.892, \"Speechiness\": 0.286, \"Acousticness\": 0.0303, \"Liveness\": 0.0866, \"Tempo\": 81.993, \"Duration (ms)\": 203201.0, \"Valence\": 0.391, \"Chord\": \"G\"}, {\"Index\": 123, \"Highest Charting Position\": 1, \"Number of Times Charted\": 67, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"ROCKSTAR (feat. Roddy Ricch)\", \"Streams\": 6180056, \"Artist\": \"DaBaby\", \"Artist Followers\": 7593046.0, \"Song ID\": \"7ytR5pFWmSjzHJIeQkgog4\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 86.0, \"Danceability\": 0.746, \"Energy\": 0.69, \"Loudness\": -7.956, \"Speechiness\": 0.164, \"Acousticness\": 0.247, \"Liveness\": 0.101, \"Tempo\": 89.977, \"Duration (ms)\": 181733.0, \"Valence\": 0.497, \"Chord\": \"B\"}, {\"Index\": 124, \"Highest Charting Position\": 12, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Heather\", \"Streams\": 6164795, \"Artist\": \"Conan Gray\", \"Artist Followers\": 3794081.0, \"Song ID\": \"4xqrdfXkTW4T0RauPLv3WA\", \"Genre\": \"['alt z', 'bedroom pop', 'electropop', 'indie pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 86.0, \"Danceability\": 0.357, \"Energy\": 0.425, \"Loudness\": -7.301, \"Speechiness\": 0.0333, \"Acousticness\": 0.584, \"Liveness\": 0.322, \"Tempo\": 102.078, \"Duration (ms)\": 198040.0, \"Valence\": 0.27, \"Chord\": \"F\"}, {\"Index\": 125, \"Highest Charting Position\": 13, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"you broke me first\", \"Streams\": 6152121, \"Artist\": \"Tate McRae\", \"Artist Followers\": 1647262.0, \"Song ID\": \"45bE4HXI0AwGZXfZtMp8JR\", \"Genre\": \"['alt z', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 86.0, \"Danceability\": 0.667, \"Energy\": 0.373, \"Loudness\": -9.389, \"Speechiness\": 0.05, \"Acousticness\": 0.785, \"Liveness\": 0.0906, \"Tempo\": 124.148, \"Duration (ms)\": 169266.0, \"Valence\": 0.0823, \"Chord\": \"E\"}, {\"Index\": 126, \"Highest Charting Position\": 126, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"The Nights\", \"Streams\": 6136340, \"Artist\": \"Avicii\", \"Artist Followers\": 20270895.0, \"Song ID\": \"0ct6r3EGTcMLPtrXHDvVjc\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance']\", \"Release Date\": \"2014-01-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 85.0, \"Danceability\": 0.527, \"Energy\": 0.835, \"Loudness\": -5.298, \"Speechiness\": 0.0433, \"Acousticness\": 0.0166, \"Liveness\": 0.249, \"Tempo\": 125.983, \"Duration (ms)\": 176658.0, \"Valence\": 0.654, \"Chord\": \"F#/Gb\"}, {\"Index\": 127, \"Highest Charting Position\": 122, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Riptide\", \"Streams\": 6089242, \"Artist\": \"Vance Joy\", \"Artist Followers\": 2421254.0, \"Song ID\": \"3JvrhDOgAt6p7K8mDyZwRd\", \"Genre\": \"['folk-pop', 'modern rock', 'pop', 'pop rock']\", \"Release Date\": \"2014-09-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 78.0, \"Danceability\": 0.484, \"Energy\": 0.731, \"Loudness\": -6.694, \"Speechiness\": 0.0379, \"Acousticness\": 0.431, \"Liveness\": 0.151, \"Tempo\": 101.654, \"Duration (ms)\": 204280.0, \"Valence\": 0.51, \"Chord\": \"C#/Db\"}, {\"Index\": 128, \"Highest Charting Position\": 128, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Smells Like Teen Spirit\", \"Streams\": 6065267, \"Artist\": \"Nirvana\", \"Artist Followers\": 13261089.0, \"Song ID\": \"5ghIJDpPoe3CfHMGu71E6T\", \"Genre\": \"['grunge', 'permanent wave', 'rock']\", \"Release Date\": \"1991-09-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\", \"Popularity\": 77.0, \"Danceability\": 0.502, \"Energy\": 0.912, \"Loudness\": -4.556, \"Speechiness\": 0.0564, \"Acousticness\": 2.55e-05, \"Liveness\": 0.106, \"Tempo\": 116.761, \"Duration (ms)\": 301920.0, \"Valence\": 0.72, \"Chord\": \"C#/Db\"}, {\"Index\": 129, \"Highest Charting Position\": 11, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"enough for you\", \"Streams\": 6040918, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"2TOzTqQXNmR2zDJXihjZ2e\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 86.0, \"Danceability\": 0.638, \"Energy\": 0.259, \"Loudness\": -10.706, \"Speechiness\": 0.0898, \"Acousticness\": 0.753, \"Liveness\": 0.219, \"Tempo\": 88.485, \"Duration (ms)\": 202827.0, \"Valence\": 0.269, \"Chord\": \"G\"}, {\"Index\": 130, \"Highest Charting Position\": 99, \"Number of Times Charted\": 42, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Daddy Issues\", \"Streams\": 6014443, \"Artist\": \"The Neighbourhood\", \"Artist Followers\": 6662605.0, \"Song ID\": \"5E30LdtzQTGqRvNd7l6kG5\", \"Genre\": \"['modern alternative rock', 'modern rock', 'pop']\", \"Release Date\": \"2015-10-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 85.0, \"Danceability\": 0.588, \"Energy\": 0.521, \"Loudness\": -9.461, \"Speechiness\": 0.0329, \"Acousticness\": 0.0678, \"Liveness\": 0.123, \"Tempo\": 85.012, \"Duration (ms)\": 260173.0, \"Valence\": 0.337, \"Chord\": \"A#/Bb\"}, {\"Index\": 131, \"Highest Charting Position\": 131, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Aquelas Coisas\", \"Streams\": 6012839, \"Artist\": \"Jo\\u00e3o Gomes\", \"Artist Followers\": 409173.0, \"Song ID\": \"0FqVtQxRD3HsPltldG5v5M\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 84.0, \"Danceability\": 0.682, \"Energy\": 0.873, \"Loudness\": -4.163, \"Speechiness\": 0.0449, \"Acousticness\": 0.402, \"Liveness\": 0.0946, \"Tempo\": 150.006, \"Duration (ms)\": 147072.0, \"Valence\": 0.964, \"Chord\": \"F#/Gb\"}, {\"Index\": 132, \"Highest Charting Position\": 19, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Miss The Rage (feat. Playboi Carti)\", \"Streams\": 5952490, \"Artist\": \"Trippie Redd\", \"Artist Followers\": 6430522.0, \"Song ID\": \"2BITQ360Knh6qNAOqR7Dyq\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2021-05-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 85.0, \"Danceability\": 0.584, \"Energy\": 0.859, \"Loudness\": -5.616, \"Speechiness\": 0.121, \"Acousticness\": 0.0144, \"Liveness\": 0.847, \"Tempo\": 77.005, \"Duration (ms)\": 236883.0, \"Valence\": 0.369, \"Chord\": \"G#/Ab\"}, {\"Index\": 133, \"Highest Charting Position\": 4, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Memories\", \"Streams\": 5928329, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32262679.0, \"Song ID\": \"4cktbXiXOapiLBMprHFErI\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.775, \"Energy\": 0.327, \"Loudness\": -7.241, \"Speechiness\": 0.0557, \"Acousticness\": 0.841, \"Liveness\": 0.0821, \"Tempo\": 91.05, \"Duration (ms)\": 189486.0, \"Valence\": 0.595, \"Chord\": \"B\"}, {\"Index\": 134, \"Highest Charting Position\": 76, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Another Love\", \"Streams\": 5914661, \"Artist\": \"Tom Odell\", \"Artist Followers\": 1838616.0, \"Song ID\": \"7otCGmgp9h4CsR2LhwB6gt\", \"Genre\": \"['pop']\", \"Release Date\": \"2013-09-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 67.0, \"Danceability\": 0.445, \"Energy\": 0.537, \"Loudness\": -8.532, \"Speechiness\": 0.04, \"Acousticness\": 0.695, \"Liveness\": 0.0941, \"Tempo\": 122.764, \"Duration (ms)\": 244360.0, \"Valence\": 0.131, \"Chord\": \"E\"}, {\"Index\": 135, \"Highest Charting Position\": 135, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Here's Your Perfect\", \"Streams\": 5912784, \"Artist\": \"Jamie Miller\", \"Artist Followers\": 64288.0, \"Song ID\": \"2aTKrdenCq5qBOoJPFdn4P\", \"Genre\": \"['pop soul']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 85.0, \"Danceability\": 0.558, \"Energy\": 0.454, \"Loudness\": -5.335, \"Speechiness\": 0.0551, \"Acousticness\": 0.499, \"Liveness\": 0.146, \"Tempo\": 113.12, \"Duration (ms)\": 158594.0, \"Valence\": 0.424, \"Chord\": \"F#/Gb\"}, {\"Index\": 136, \"Highest Charting Position\": 108, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Take Me To Church\", \"Streams\": 5907750, \"Artist\": \"Hozier\", \"Artist Followers\": 4781906.0, \"Song ID\": \"1CS7Sd1u5tWkstBhpssyjP\", \"Genre\": \"['irish singer-songwriter', 'modern rock', 'pop']\", \"Release Date\": \"2014-09-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 74.0, \"Danceability\": 0.566, \"Energy\": 0.664, \"Loudness\": -5.303, \"Speechiness\": 0.0464, \"Acousticness\": 0.634, \"Liveness\": 0.116, \"Tempo\": 128.945, \"Duration (ms)\": 241693.0, \"Valence\": 0.437, \"Chord\": \"E\"}, {\"Index\": 137, \"Highest Charting Position\": 110, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Little Bit of Love\", \"Streams\": 5848466, \"Artist\": \"Tom Grennan\", \"Artist Followers\": 261225.0, \"Song ID\": \"2sX7lJXsOYGP1Us6CqM9t1\", \"Genre\": \"['modern rock', 'uk pop']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 80.0, \"Danceability\": 0.689, \"Energy\": 0.706, \"Loudness\": -4.48, \"Speechiness\": 0.0312, \"Acousticness\": 0.0833, \"Liveness\": 0.105, \"Tempo\": 106.52, \"Duration (ms)\": 226268.0, \"Valence\": 0.623, \"Chord\": \"C#/Db\"}, {\"Index\": 138, \"Highest Charting Position\": 138, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Ficha Limpa\", \"Streams\": 5847975, \"Artist\": \"Gusttavo Lima\", \"Artist Followers\": 12969190.0, \"Song ID\": \"5SwyN9hzmWjBsINlif8li8\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2021-06-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 85.0, \"Danceability\": 0.774, \"Energy\": 0.732, \"Loudness\": -4.227, \"Speechiness\": 0.0308, \"Acousticness\": 0.108, \"Liveness\": 0.243, \"Tempo\": 135.005, \"Duration (ms)\": 192725.0, \"Valence\": 0.734, \"Chord\": \"A\"}, {\"Index\": 139, \"Highest Charting Position\": 14, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Up\", \"Streams\": 5845156, \"Artist\": \"Cardi B\", \"Artist Followers\": 17353707.0, \"Song ID\": \"1XXimziG1uhM0eDNCZCrUl\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'rap']\", \"Release Date\": \"2021-02-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 83.0, \"Danceability\": 0.868, \"Energy\": 0.795, \"Loudness\": -6.044, \"Speechiness\": 0.269, \"Acousticness\": 0.0012, \"Liveness\": 0.0461, \"Tempo\": 166.0, \"Duration (ms)\": 156945.0, \"Valence\": 0.819, \"Chord\": \"B\"}, {\"Index\": 140, \"Highest Charting Position\": 2, \"Number of Times Charted\": 52, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Haw\\u00e1i\", \"Streams\": 5769714, \"Artist\": \"Maluma\", \"Artist Followers\": 26769304.0, \"Song ID\": \"0GzuHFG4Ql6DoyxFRnIk3F\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-11-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 77.0, \"Danceability\": 0.766, \"Energy\": 0.788, \"Loudness\": -3.128, \"Speechiness\": 0.312, \"Acousticness\": 0.105, \"Liveness\": 0.142, \"Tempo\": 179.984, \"Duration (ms)\": 200482.0, \"Valence\": 0.609, \"Chord\": \"F#/Gb\"}, {\"Index\": 141, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"New Normal\", \"Streams\": 5768653, \"Artist\": \"Khalid\", \"Artist Followers\": 14187747.0, \"Song ID\": \"2CIYemjFXdmCWpJnfbtrD6\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-07-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 79.0, \"Danceability\": 0.39, \"Energy\": 0.534, \"Loudness\": -9.575, \"Speechiness\": 0.0709, \"Acousticness\": 0.0807, \"Liveness\": 0.184, \"Tempo\": 92.047, \"Duration (ms)\": 198765.0, \"Valence\": 0.244, \"Chord\": \"C\"}, {\"Index\": 142, \"Highest Charting Position\": 81, \"Number of Times Charted\": 81, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Bohemian Rhapsody - Remastered 2011\", \"Streams\": 5756583, \"Artist\": \"Queen\", \"Artist Followers\": 35888760.0, \"Song ID\": \"7tFiyTwD0nx5a1eklYtX2J\", \"Genre\": \"['classic rock', 'glam rock', 'rock']\", \"Release Date\": \"1975-11-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.392, \"Energy\": 0.402, \"Loudness\": -9.961, \"Speechiness\": 0.0536, \"Acousticness\": 0.288, \"Liveness\": 0.243, \"Tempo\": 143.883, \"Duration (ms)\": 354320.0, \"Valence\": 0.228, \"Chord\": \"C\"}, {\"Index\": 143, \"Highest Charting Position\": 5, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Bandido\", \"Streams\": 5734402, \"Artist\": \"Myke Towers, Juhn\", \"Artist Followers\": 6150675.0, \"Song ID\": \"1xK1Gg9SxG8fy2Ya373oqb\", \"Genre\": \"['trap latino']\", \"Release Date\": \"2020-12-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\", \"Popularity\": 85.0, \"Danceability\": 0.713, \"Energy\": 0.617, \"Loudness\": -4.637, \"Speechiness\": 0.0887, \"Acousticness\": 0.122, \"Liveness\": 0.0962, \"Tempo\": 168.021, \"Duration (ms)\": 232853.0, \"Valence\": 0.682, \"Chord\": \"G#/Ab\"}, {\"Index\": 144, \"Highest Charting Position\": 25, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Paradise (feat. Dermot Kennedy)\", \"Streams\": 5693848, \"Artist\": \"MEDUZA\", \"Artist Followers\": 441674.0, \"Song ID\": \"6ft4hAq6yde8jPZY2i5zLr\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop house', 'tropical house']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 85.0, \"Danceability\": 0.632, \"Energy\": 0.595, \"Loudness\": -7.644, \"Speechiness\": 0.0401, \"Acousticness\": 0.0689, \"Liveness\": 0.209, \"Tempo\": 124.114, \"Duration (ms)\": 167903.0, \"Valence\": 0.435, \"Chord\": \"G#/Ab\"}, {\"Index\": 145, \"Highest Charting Position\": 13, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"goosebumps\", \"Streams\": 5691540, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17719446.0, \"Song ID\": \"5uEYRdEIh9Bo4fpjDd4Na9\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 87.0, \"Danceability\": 0.841, \"Energy\": 0.593, \"Loudness\": -7.846, \"Speechiness\": 0.0379, \"Acousticness\": 0.418, \"Liveness\": 0.124, \"Tempo\": 124.917, \"Duration (ms)\": 162803.0, \"Valence\": 0.808, \"Chord\": \"C#/Db\"}, {\"Index\": 146, \"Highest Charting Position\": 90, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Wasted Love (feat. Lagique)\", \"Streams\": 5690260, \"Artist\": \"Ofenbach\", \"Artist Followers\": 432581.0, \"Song ID\": \"2pPO9YecZimmuVQfIzfV6U\", \"Genre\": \"['edm', 'new french touch', 'pop dance', 'tropical house']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 85.0, \"Danceability\": 0.734, \"Energy\": 0.855, \"Loudness\": -4.578, \"Speechiness\": 0.135, \"Acousticness\": 0.0821, \"Liveness\": 0.0901, \"Tempo\": 121.955, \"Duration (ms)\": 139563.0, \"Valence\": 0.54, \"Chord\": \"F#/Gb\"}, {\"Index\": 147, \"Highest Charting Position\": 100, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"KESI - Remix\", \"Streams\": 5682062, \"Artist\": \"Camilo, Shawn Mendes\", \"Artist Followers\": 10561047.0, \"Song ID\": \"0IqCoZ168iRc9LqfrYgpZy\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2021-07-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 83.0, \"Danceability\": 0.871, \"Energy\": 0.815, \"Loudness\": -4.439, \"Speechiness\": 0.0477, \"Acousticness\": 0.127, \"Liveness\": 0.094, \"Tempo\": 122.959, \"Duration (ms)\": 176575.0, \"Valence\": 0.823, \"Chord\": \"E\"}, {\"Index\": 148, \"Highest Charting Position\": 59, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Shallow\", \"Streams\": 5672480, \"Artist\": \"Lady Gaga, Bradley Cooper\", \"Artist Followers\": 18572085.0, \"Song ID\": \"2VxeLyX666F8uXCJ0dZF8B\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-10-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.572, \"Energy\": 0.385, \"Loudness\": -6.362, \"Speechiness\": 0.0308, \"Acousticness\": 0.371, \"Liveness\": 0.231, \"Tempo\": 95.799, \"Duration (ms)\": 215733.0, \"Valence\": 0.323, \"Chord\": \"G\"}, {\"Index\": 149, \"Highest Charting Position\": 110, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Tell Em\", \"Streams\": 5668576, \"Artist\": \"Cochise, $NOT\", \"Artist Followers\": 159647.0, \"Song ID\": \"7nc7mlSdWYeFom84zZ8Wr8\", \"Genre\": \"['plugg', 'vapor trap', 'viral rap']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\", \"Popularity\": 85.0, \"Danceability\": 0.672, \"Energy\": 0.717, \"Loudness\": -7.476, \"Speechiness\": 0.226, \"Acousticness\": 0.103, \"Liveness\": 0.398, \"Tempo\": 157.905, \"Duration (ms)\": 180380.0, \"Valence\": 0.473, \"Chord\": \"F\"}, {\"Index\": 150, \"Highest Charting Position\": 103, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"N\\u00e3o, N\\u00e3o Vou\", \"Streams\": 5652272, \"Artist\": \"Mari Fernandez\", \"Artist Followers\": 15889.0, \"Song ID\": \"0xBQvhJAm6f7J142ympKOn\", \"Genre\": \"[]\", \"Release Date\": \"2021-04-29\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.631, \"Energy\": 0.861, \"Loudness\": -1.891, \"Speechiness\": 0.0424, \"Acousticness\": 0.427, \"Liveness\": 0.215, \"Tempo\": 149.95, \"Duration (ms)\": 173038.0, \"Valence\": 0.822, \"Chord\": \"B\"}, {\"Index\": 151, \"Highest Charting Position\": 147, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Counting Stars\", \"Streams\": 5647568, \"Artist\": \"OneRepublic\", \"Artist Followers\": 12169108.0, \"Song ID\": \"6sy3LkhNFjJWlaeSMNwQ62\", \"Genre\": \"['dance pop', 'piano rock', 'pop', 'pop rock']\", \"Release Date\": \"2014-01-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 74.0, \"Danceability\": 0.664, \"Energy\": 0.705, \"Loudness\": -4.972, \"Speechiness\": 0.0382, \"Acousticness\": 0.0654, \"Liveness\": 0.115, \"Tempo\": 122.017, \"Duration (ms)\": 257840.0, \"Valence\": 0.477, \"Chord\": \"C#/Db\"}, {\"Index\": 152, \"Highest Charting Position\": 121, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Yellow\", \"Streams\": 5628703, \"Artist\": \"Coldplay\", \"Artist Followers\": 31151294.0, \"Song ID\": \"3AJwUDP919kvQ9QcozQPxg\", \"Genre\": \"['permanent wave', 'pop']\", \"Release Date\": \"2000-07-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 85.0, \"Danceability\": 0.429, \"Energy\": 0.661, \"Loudness\": -7.227, \"Speechiness\": 0.0281, \"Acousticness\": 0.00239, \"Liveness\": 0.234, \"Tempo\": 173.372, \"Duration (ms)\": 266773.0, \"Valence\": 0.285, \"Chord\": \"B\"}, {\"Index\": 153, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Como Si No Importara\", \"Streams\": 5627257, \"Artist\": \"Emilia, Duki\", \"Artist Followers\": 205590.0, \"Song ID\": \"1GYJpuLq41vEVKXiHGEY9j\", \"Genre\": \"[]\", \"Release Date\": \"2021-07-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 83.0, \"Danceability\": 0.843, \"Energy\": 0.534, \"Loudness\": -6.658, \"Speechiness\": 0.142, \"Acousticness\": 0.467, \"Liveness\": 0.0984, \"Tempo\": 94.984, \"Duration (ms)\": 173053.0, \"Valence\": 0.528, \"Chord\": \"C#/Db\"}, {\"Index\": 154, \"Highest Charting Position\": 154, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Se For Amor\", \"Streams\": 5618268, \"Artist\": \"Jo\\u00e3o Gomes, Vitor Fernandes\", \"Artist Followers\": 409173.0, \"Song ID\": \"5F2xRvRFkxDvqdFtUNAEyw\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 81.0, \"Danceability\": 0.667, \"Energy\": 0.899, \"Loudness\": -4.402, \"Speechiness\": 0.0322, \"Acousticness\": 0.423, \"Liveness\": 0.332, \"Tempo\": 147.962, \"Duration (ms)\": 239928.0, \"Valence\": 0.835, \"Chord\": \"B\"}, {\"Index\": 155, \"Highest Charting Position\": 142, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Wake Me Up\", \"Streams\": 5607285, \"Artist\": \"Avicii\", \"Artist Followers\": 20270895.0, \"Song ID\": \"0nrRP2bk19rLc0orkWPQk2\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance']\", \"Release Date\": \"2013-01-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-01--2021-01-08\\n2020-08-07--2020-08-14\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.532, \"Energy\": 0.783, \"Loudness\": -5.697, \"Speechiness\": 0.0523, \"Acousticness\": 0.0038, \"Liveness\": 0.161, \"Tempo\": 124.08, \"Duration (ms)\": 247427.0, \"Valence\": 0.643, \"Chord\": \"D\"}, {\"Index\": 156, \"Highest Charting Position\": 128, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Baby Me Atende\", \"Streams\": 5594505, \"Artist\": \"Matheus Fernandes, Dilsinho\", \"Artist Followers\": 77034.0, \"Song ID\": \"5R9KPXQVeyqsHZoPLMgfNy\", \"Genre\": \"['forro', 'sertanejo pop']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 83.0, \"Danceability\": 0.65, \"Energy\": 0.792, \"Loudness\": -3.825, \"Speechiness\": 0.0393, \"Acousticness\": 0.607, \"Liveness\": 0.92, \"Tempo\": 154.027, \"Duration (ms)\": 225672.0, \"Valence\": 0.872, \"Chord\": \"F#/Gb\"}, {\"Index\": 157, \"Highest Charting Position\": 68, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Ramenez la coupe \\u00e0 la maison\", \"Streams\": 5576844, \"Artist\": \"Vegedream\", \"Artist Followers\": 1250353.0, \"Song ID\": \"0dqVP9CnGjaYNjya3gYbYy\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 0.0, \"Danceability\": 0.808, \"Energy\": 0.66, \"Loudness\": -6.237, \"Speechiness\": 0.0395, \"Acousticness\": 0.0358, \"Liveness\": 0.138, \"Tempo\": 107.994, \"Duration (ms)\": 235556.0, \"Valence\": 0.804, \"Chord\": \"C\"}, {\"Index\": 158, \"Highest Charting Position\": 6, \"Number of Times Charted\": 47, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"What You Know Bout Love\", \"Streams\": 5570735, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"1tkg4EHVoqnhR6iFEXb60y\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-07-03--2020-07-10\", \"Popularity\": 85.0, \"Danceability\": 0.709, \"Energy\": 0.548, \"Loudness\": -8.493, \"Speechiness\": 0.353, \"Acousticness\": 0.65, \"Liveness\": 0.133, \"Tempo\": 83.995, \"Duration (ms)\": 160000.0, \"Valence\": 0.543, \"Chord\": \"A#/Bb\"}, {\"Index\": 159, \"Highest Charting Position\": 19, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Runaway\", \"Streams\": 5566150, \"Artist\": \"AURORA\", \"Artist Followers\": 1687399.0, \"Song ID\": \"0TCmhnbMpw5zwPsTvlXTJi\", \"Genre\": \"['art pop', 'norwegian pop']\", \"Release Date\": \"2014\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 77.0, \"Danceability\": 0.521, \"Energy\": 0.277, \"Loudness\": -10.34, \"Speechiness\": 0.0356, \"Acousticness\": 0.634, \"Liveness\": 0.103, \"Tempo\": 115.01, \"Duration (ms)\": 248827.0, \"Valence\": 0.13, \"Chord\": \"B\"}, {\"Index\": 160, \"Highest Charting Position\": 121, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Red Light Green Light\", \"Streams\": 5493760, \"Artist\": \"DaBaby\", \"Artist Followers\": 7593046.0, \"Song ID\": \"1YDebgap5OFwXEBG18NJvy\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.933, \"Energy\": 0.656, \"Loudness\": -5.85, \"Speechiness\": 0.322, \"Acousticness\": 0.129, \"Liveness\": 0.161, \"Tempo\": 119.987, \"Duration (ms)\": 159083.0, \"Valence\": 0.934, \"Chord\": \"D\"}, {\"Index\": 161, \"Highest Charting Position\": 120, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Ball If I Want To\", \"Streams\": 5478055, \"Artist\": \"DaBaby\", \"Artist Followers\": 7593046.0, \"Song ID\": \"0cu0rhnlCnJ7JIeHRiLpj3\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\", \"Popularity\": 84.0, \"Danceability\": 0.902, \"Energy\": 0.669, \"Loudness\": -5.049, \"Speechiness\": 0.457, \"Acousticness\": 0.161, \"Liveness\": 0.0728, \"Tempo\": 139.949, \"Duration (ms)\": 112547.0, \"Valence\": 0.628, \"Chord\": \"C#/Db\"}, {\"Index\": 162, \"Highest Charting Position\": 31, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lucid Dreams\", \"Streams\": 5477563, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"285pBltuF7vW8TeWk8hdRR\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2018-12-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.511, \"Energy\": 0.566, \"Loudness\": -7.23, \"Speechiness\": 0.2, \"Acousticness\": 0.349, \"Liveness\": 0.34, \"Tempo\": 83.903, \"Duration (ms)\": 239836.0, \"Valence\": 0.218, \"Chord\": \"F#/Gb\"}, {\"Index\": 163, \"Highest Charting Position\": 4, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Calling My Phone\", \"Streams\": 5467753, \"Artist\": \"Lil Tjay, 6LACK\", \"Artist Followers\": 3553442.0, \"Song ID\": \"3J8EOeKLTLXORtWPpOU5bE\", \"Genre\": \"['brooklyn drill', 'melodic rap', 'nyc rap']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 85.0, \"Danceability\": 0.907, \"Energy\": 0.393, \"Loudness\": -7.636, \"Speechiness\": 0.0539, \"Acousticness\": 0.451, \"Liveness\": 0.135, \"Tempo\": 104.949, \"Duration (ms)\": 205458.0, \"Valence\": 0.202, \"Chord\": \"E\"}, {\"Index\": 164, \"Highest Charting Position\": 5, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"34+35\", \"Streams\": 5453159, \"Artist\": \"Ariana Grande\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 165, \"Highest Charting Position\": 13, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"bad guy\", \"Streams\": 5436286, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"1hewNsVmijBqjKvFRQfk4m\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.701, \"Energy\": 0.425, \"Loudness\": -10.965, \"Speechiness\": 0.375, \"Acousticness\": 0.328, \"Liveness\": 0.1, \"Tempo\": 135.128, \"Duration (ms)\": 194088.0, \"Valence\": 0.562, \"Chord\": \"G\"}, {\"Index\": 166, \"Highest Charting Position\": 59, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Cover Me In Sunshine\", \"Streams\": 5434073, \"Artist\": \"P!nk, Willow Sage Hart\", \"Artist Followers\": 11477164.0, \"Song ID\": \"6Tio0ZoDeSQnI7EBAqWer2\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-02-12\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 83.0, \"Danceability\": 0.476, \"Energy\": 0.594, \"Loudness\": -6.879, \"Speechiness\": 0.135, \"Acousticness\": 0.0599, \"Liveness\": 0.0785, \"Tempo\": 159.702, \"Duration (ms)\": 141050.0, \"Valence\": 0.314, \"Chord\": \"F\"}, {\"Index\": 167, \"Highest Charting Position\": 7, \"Number of Times Charted\": 56, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"For The Night (feat. Lil Baby & DaBaby)\", \"Streams\": 5431375, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"0PvFJmanyNQMseIFrU708S\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 84.0, \"Danceability\": 0.823, \"Energy\": 0.586, \"Loudness\": -6.606, \"Speechiness\": 0.2, \"Acousticness\": 0.114, \"Liveness\": 0.193, \"Tempo\": 125.971, \"Duration (ms)\": 190476.0, \"Valence\": 0.347, \"Chord\": \"F#/Gb\"}, {\"Index\": 168, \"Highest Charting Position\": 13, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"1 step forward, 3 steps back\", \"Streams\": 5420003, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"4wcBRRpIfesgcyUtis7PEg\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 85.0, \"Danceability\": 0.473, \"Energy\": 0.203, \"Loudness\": -12.627, \"Speechiness\": 0.102, \"Acousticness\": 0.941, \"Liveness\": 0.126, \"Tempo\": 168.884, \"Duration (ms)\": 163587.0, \"Valence\": 0.419, \"Chord\": \"D\"}, {\"Index\": 169, \"Highest Charting Position\": 1, \"Number of Times Charted\": 51, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"WAP (feat. Megan Thee Stallion)\", \"Streams\": 5386268, \"Artist\": \"Cardi B\", \"Artist Followers\": 17353707.0, \"Song ID\": \"4Oun2ylbjFKMPTiaSbbCih\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'rap']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 84.0, \"Danceability\": 0.935, \"Energy\": 0.454, \"Loudness\": -7.509, \"Speechiness\": 0.375, \"Acousticness\": 0.0194, \"Liveness\": 0.0824, \"Tempo\": 133.073, \"Duration (ms)\": 187541.0, \"Valence\": 0.357, \"Chord\": \"C#/Db\"}, {\"Index\": 170, \"Highest Charting Position\": 155, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Mr. Brightside\", \"Streams\": 5382191, \"Artist\": \"The Killers\", \"Artist Followers\": 6118063.0, \"Song ID\": \"7oK9VyNzrYvRFo7nQEYkWN\", \"Genre\": \"['dance rock', 'modern rock', 'permanent wave', 'rock']\", \"Release Date\": \"2004-06-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-12--2021-03-19\\n2021-02-26--2021-03-05\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 75.0, \"Danceability\": 0.356, \"Energy\": 0.924, \"Loudness\": -3.74, \"Speechiness\": 0.0808, \"Acousticness\": 0.00101, \"Liveness\": 0.0953, \"Tempo\": 148.017, \"Duration (ms)\": 222587.0, \"Valence\": 0.232, \"Chord\": \"C#/Db\"}, {\"Index\": 171, \"Highest Charting Position\": 144, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Every Breath You Take\", \"Streams\": 5379704, \"Artist\": \"The Police\", \"Artist Followers\": 4339245.0, \"Song ID\": \"1JSTJqkT5qHq8MDJnJbRE1\", \"Genre\": \"['album rock', 'art rock', 'classic rock', 'mellow gold', 'new wave', 'permanent wave', 'rock', 'soft rock']\", \"Release Date\": \"1983-06-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-01-01--2021-01-08\\n2020-06-19--2020-06-26\\n2020-06-05--2020-06-12\", \"Popularity\": 83.0, \"Danceability\": 0.82, \"Energy\": 0.452, \"Loudness\": -9.796, \"Speechiness\": 0.0348, \"Acousticness\": 0.543, \"Liveness\": 0.0714, \"Tempo\": 117.401, \"Duration (ms)\": 253920.0, \"Valence\": 0.74, \"Chord\": \"C#/Db\"}, {\"Index\": 172, \"Highest Charting Position\": 20, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Dreams - 2004 Remaster\", \"Streams\": 5378971, \"Artist\": \"Fleetwood Mac\", \"Artist Followers\": 6930669.0, \"Song ID\": \"0ofHAoxe9vBkTCp2UQIavz\", \"Genre\": \"['album rock', 'classic rock', 'mellow gold', 'rock', 'soft rock', 'yacht rock']\", \"Release Date\": \"1977-02-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 84.0, \"Danceability\": 0.828, \"Energy\": 0.492, \"Loudness\": -9.744, \"Speechiness\": 0.0276, \"Acousticness\": 0.0644, \"Liveness\": 0.128, \"Tempo\": 120.151, \"Duration (ms)\": 257800.0, \"Valence\": 0.789, \"Chord\": \"C\"}, {\"Index\": 173, \"Highest Charting Position\": 94, \"Number of Times Charted\": 82, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Say You Won't Let Go\", \"Streams\": 5375426, \"Artist\": \"James Arthur\", \"Artist Followers\": 8441598.0, \"Song ID\": \"5uCax9HTNlzGybIStD3vDh\", \"Genre\": \"['pop', 'post-teen pop', 'talent show', 'uk pop']\", \"Release Date\": \"2016-10-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.358, \"Energy\": 0.557, \"Loudness\": -7.398, \"Speechiness\": 0.059, \"Acousticness\": 0.695, \"Liveness\": 0.0902, \"Tempo\": 85.043, \"Duration (ms)\": 211467.0, \"Valence\": 0.494, \"Chord\": \"A#/Bb\"}, {\"Index\": 174, \"Highest Charting Position\": 110, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Wild Side (feat. Cardi B)\", \"Streams\": 5366242, \"Artist\": \"Normani\", \"Artist Followers\": 1304510.0, \"Song ID\": \"2vXgyN14LX2zl7JEASw242\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop', 'r&b', 'urban contemporary']\", \"Release Date\": \"2021-07-22\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 75.0, \"Danceability\": 0.74, \"Energy\": 0.576, \"Loudness\": -6.744, \"Speechiness\": 0.146, \"Acousticness\": 0.0249, \"Liveness\": 0.104, \"Tempo\": 110.095, \"Duration (ms)\": 209476.0, \"Valence\": 0.315, \"Chord\": \"F#/Gb\"}, {\"Index\": 175, \"Highest Charting Position\": 65, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Bout A Million (feat. 42 Dugg & 21 Savage)\", \"Streams\": 5315734, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"4LaGu95Ui2s4vprSQYWUAZ\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 81.0, \"Danceability\": 0.716, \"Energy\": 0.67, \"Loudness\": -6.995, \"Speechiness\": 0.101, \"Acousticness\": 0.526, \"Liveness\": 0.13, \"Tempo\": 145.043, \"Duration (ms)\": 203586.0, \"Valence\": 0.411, \"Chord\": \"C\"}, {\"Index\": 176, \"Highest Charting Position\": 72, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Demeanor (feat. Dua Lipa)\", \"Streams\": 5245618, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"3DMs7bahbQTnoxCjgP7qoK\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 81.0, \"Danceability\": 0.675, \"Energy\": 0.608, \"Loudness\": -6.934, \"Speechiness\": 0.103, \"Acousticness\": 0.336, \"Liveness\": 0.11, \"Tempo\": 99.865, \"Duration (ms)\": 184800.0, \"Valence\": 0.728, \"Chord\": \"D#/Eb\"}, {\"Index\": 177, \"Highest Charting Position\": 4, \"Number of Times Charted\": 76, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"death bed (coffee for your head)\", \"Streams\": 5238547, \"Artist\": \"Powfu, beabadoobee\", \"Artist Followers\": 924083.0, \"Song ID\": \"7eJMfftS33KTjuF7lTsMCx\", \"Genre\": \"['sad rap']\", \"Release Date\": \"2020-02-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 85.0, \"Danceability\": 0.726, \"Energy\": 0.431, \"Loudness\": -8.765, \"Speechiness\": 0.135, \"Acousticness\": 0.731, \"Liveness\": 0.696, \"Tempo\": 144.026, \"Duration (ms)\": 173333.0, \"Valence\": 0.348, \"Chord\": \"G#/Ab\"}, {\"Index\": 178, \"Highest Charting Position\": 100, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Our Song\", \"Streams\": 5235335, \"Artist\": \"Anne-Marie, Niall Horan\", \"Artist Followers\": 8148393.0, \"Song ID\": \"5zqObw7wjBgL9TDiAymxPn\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 83.0, \"Danceability\": 0.595, \"Energy\": 0.759, \"Loudness\": -4.245, \"Speechiness\": 0.0423, \"Acousticness\": 0.141, \"Liveness\": 0.172, \"Tempo\": 80.953, \"Duration (ms)\": 163733.0, \"Valence\": 0.515, \"Chord\": \"B\"}, {\"Index\": 179, \"Highest Charting Position\": 138, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Another One Bites The Dust - Remastered 2011\", \"Streams\": 5204983, \"Artist\": \"Queen\", \"Artist Followers\": 35888760.0, \"Song ID\": \"57JVGBtBLCfHw2muk5416J\", \"Genre\": \"['classic rock', 'glam rock', 'rock']\", \"Release Date\": \"1980-06-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.933, \"Energy\": 0.528, \"Loudness\": -6.472, \"Speechiness\": 0.162, \"Acousticness\": 0.112, \"Liveness\": 0.163, \"Tempo\": 109.975, \"Duration (ms)\": 214653.0, \"Valence\": 0.756, \"Chord\": \"F\"}, {\"Index\": 180, \"Highest Charting Position\": 149, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"One Dance\", \"Streams\": 5178490, \"Artist\": \"Drake, WizKid, Kyla\", \"Artist Followers\": 56308172.0, \"Song ID\": \"1zi7xx7UVEFkmKfv06H8x0\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2016-05-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 84.0, \"Danceability\": 0.792, \"Energy\": 0.625, \"Loudness\": -5.609, \"Speechiness\": 0.0536, \"Acousticness\": 0.00776, \"Liveness\": 0.329, \"Tempo\": 103.967, \"Duration (ms)\": 173987.0, \"Valence\": 0.37, \"Chord\": \"C#/Db\"}, {\"Index\": 181, \"Highest Charting Position\": 15, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Adore You\", \"Streams\": 5166847, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16112621.0, \"Song ID\": \"3jjujdWJ72nww5eGnfs2E7\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.676, \"Energy\": 0.771, \"Loudness\": -3.675, \"Speechiness\": 0.0483, \"Acousticness\": 0.0237, \"Liveness\": 0.102, \"Tempo\": 99.048, \"Duration (ms)\": 207133.0, \"Valence\": 0.569, \"Chord\": \"G#/Ab\"}, {\"Index\": 182, \"Highest Charting Position\": 181, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"As the World Caves In\", \"Streams\": 5145493, \"Artist\": \"Sarah Cothran\", \"Artist Followers\": 180723.0, \"Song ID\": \"2xXNLutYAOELYVObYb1C1S\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-04--2021-06-11\", \"Popularity\": 71.0, \"Danceability\": 0.422, \"Energy\": 0.25, \"Loudness\": -6.836, \"Speechiness\": 0.0351, \"Acousticness\": 0.441, \"Liveness\": 0.35, \"Tempo\": 124.026, \"Duration (ms)\": 161613.0, \"Valence\": 0.246, \"Chord\": \"C\"}, {\"Index\": 183, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Fancy Like\", \"Streams\": 5145432, \"Artist\": \"Walker Hayes\", \"Artist Followers\": 304995.0, \"Song ID\": \"3ZozFqJJlDBNIm4xqxn2ZD\", \"Genre\": \"['contemporary country', 'country', 'country road', 'modern country rock']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 83.0, \"Danceability\": 0.649, \"Energy\": 0.76, \"Loudness\": -6.487, \"Speechiness\": 0.0574, \"Acousticness\": 0.114, \"Liveness\": 0.317, \"Tempo\": 80.018, \"Duration (ms)\": 161853.0, \"Valence\": 0.843, \"Chord\": \"C#/Db\"}, {\"Index\": 184, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"C\\u00farame\", \"Streams\": 5104206, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6080597.0, \"Song ID\": \"3PwRuzdphgedcWVUOVYJ7I\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 85.0, \"Danceability\": 0.765, \"Energy\": 0.625, \"Loudness\": -3.599, \"Speechiness\": 0.0548, \"Acousticness\": 0.584, \"Liveness\": 0.112, \"Tempo\": 102.101, \"Duration (ms)\": 164706.0, \"Valence\": 0.262, \"Chord\": \"A\"}, {\"Index\": 185, \"Highest Charting Position\": 110, \"Number of Times Charted\": 78, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"All of Me\", \"Streams\": 5103014, \"Artist\": \"John Legend\", \"Artist Followers\": 5799137.0, \"Song ID\": \"3U4isOIWM3VvDubwSI3y7a\", \"Genre\": \"['neo soul', 'pop', 'pop soul', 'r&b', 'urban contemporary']\", \"Release Date\": \"2013-08-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.422, \"Energy\": 0.264, \"Loudness\": -7.064, \"Speechiness\": 0.0322, \"Acousticness\": 0.922, \"Liveness\": 0.132, \"Tempo\": 119.93, \"Duration (ms)\": 269560.0, \"Valence\": 0.331, \"Chord\": \"G#/Ab\"}, {\"Index\": 186, \"Highest Charting Position\": 80, \"Number of Times Charted\": 41, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Martin & Gina\", \"Streams\": 5098609, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"1VLtjHwRWOVJiE5Py7JxoQ\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 85.0, \"Danceability\": 0.832, \"Energy\": 0.534, \"Loudness\": -7.813, \"Speechiness\": 0.253, \"Acousticness\": 0.345, \"Liveness\": 0.165, \"Tempo\": 93.924, \"Duration (ms)\": 132833.0, \"Valence\": 0.116, \"Chord\": \"C#/Db\"}, {\"Index\": 187, \"Highest Charting Position\": 40, \"Number of Times Charted\": 65, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Dior\", \"Streams\": 5092354, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"79s5XnCN4TJKTVMSmOx8Ep\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2019-07-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-06-18--2021-06-25\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 83.0, \"Danceability\": 0.548, \"Energy\": 0.805, \"Loudness\": -5.732, \"Speechiness\": 0.351, \"Acousticness\": 0.212, \"Liveness\": 0.408, \"Tempo\": 142.094, \"Duration (ms)\": 216387.0, \"Valence\": 0.648, \"Chord\": \"G\"}, {\"Index\": 188, \"Highest Charting Position\": 45, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Best Friend (feat. Doja Cat)\", \"Streams\": 5090062, \"Artist\": \"Saweetie\", \"Artist Followers\": 1254432.0, \"Song ID\": \"2etHQJxIbV0soyPhelVs9Y\", \"Genre\": \"['cali rap', 'dance pop', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2021-01-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 83.0, \"Danceability\": 0.84, \"Energy\": 0.766, \"Loudness\": -4.12, \"Speechiness\": 0.136, \"Acousticness\": 0.00302, \"Liveness\": 0.0684, \"Tempo\": 94.018, \"Duration (ms)\": 155884.0, \"Valence\": 0.402, \"Chord\": \"E\"}, {\"Index\": 189, \"Highest Charting Position\": 52, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"The Hills\", \"Streams\": 5068864, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"7fBv7CLKzipRk6EC6TWHOB\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2015-08-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 84.0, \"Danceability\": 0.585, \"Energy\": 0.564, \"Loudness\": -7.063, \"Speechiness\": 0.0515, \"Acousticness\": 0.0671, \"Liveness\": 0.135, \"Tempo\": 113.003, \"Duration (ms)\": 242253.0, \"Valence\": 0.137, \"Chord\": \"C\"}, {\"Index\": 190, \"Highest Charting Position\": 5, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Good Days\", \"Streams\": 5065132, \"Artist\": \"SZA\", \"Artist Followers\": 5881963.0, \"Song ID\": \"3YJJjQPAbDT7mGpX3WtQ9A\", \"Genre\": \"['pop', 'pop rap', 'r&b']\", \"Release Date\": \"2020-12-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 84.0, \"Danceability\": 0.436, \"Energy\": 0.655, \"Loudness\": -8.37, \"Speechiness\": 0.0583, \"Acousticness\": 0.499, \"Liveness\": 0.688, \"Tempo\": 121.002, \"Duration (ms)\": 279204.0, \"Valence\": 0.412, \"Chord\": \"C#/Db\"}, {\"Index\": 191, \"Highest Charting Position\": 191, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Kiss My (Uh Oh)\", \"Streams\": 5063181, \"Artist\": \"Anne-Marie, Little Mix\", \"Artist Followers\": 8148393.0, \"Song ID\": \"0MWiSBKm8Avs8iDIxcertp\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2021-07-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 78.0, \"Danceability\": 0.638, \"Energy\": 0.878, \"Loudness\": -3.639, \"Speechiness\": 0.0484, \"Acousticness\": 0.0151, \"Liveness\": 0.308, \"Tempo\": 103.948, \"Duration (ms)\": 176800.0, \"Valence\": 0.481, \"Chord\": \"F\"}, {\"Index\": 192, \"Highest Charting Position\": 64, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"De Museo\", \"Streams\": 5016125, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36142273.0, \"Song ID\": \"267NGliXM8YLVZiKAD9Otm\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 83.0, \"Danceability\": 0.592, \"Energy\": 0.494, \"Loudness\": -10.618, \"Speechiness\": 0.0747, \"Acousticness\": 0.237, \"Liveness\": 0.13, \"Tempo\": 132.037, \"Duration (ms)\": 209771.0, \"Valence\": 0.231, \"Chord\": \"E\"}, {\"Index\": 193, \"Highest Charting Position\": 41, \"Number of Times Charted\": 81, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"7 rings\", \"Streams\": 5002227, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67158068.0, \"Song ID\": \"6ocbgoVGwYJhOv1GgI9NsF\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-02-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.778, \"Energy\": 0.317, \"Loudness\": -10.732, \"Speechiness\": 0.334, \"Acousticness\": 0.592, \"Liveness\": 0.0881, \"Tempo\": 140.048, \"Duration (ms)\": 178627.0, \"Valence\": 0.327, \"Chord\": \"C#/Db\"}, {\"Index\": 194, \"Highest Charting Position\": 194, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Chosen (feat. Ty Dolla $ign)\", \"Streams\": 4992405, \"Artist\": \"Blxst, Tyga\", \"Artist Followers\": 167628.0, \"Song ID\": \"1dIWPXMX4kRHj6Dt2DStUQ\", \"Genre\": \"[]\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 84.0, \"Danceability\": 0.571, \"Energy\": 0.767, \"Loudness\": -5.16, \"Speechiness\": 0.287, \"Acousticness\": 0.336, \"Liveness\": 0.0809, \"Tempo\": 93.421, \"Duration (ms)\": 161684.0, \"Valence\": 0.605, \"Chord\": \"D\"}, {\"Index\": 195, \"Highest Charting Position\": 149, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"N\\u00e3o Nasceu pra Namorar\", \"Streams\": 4978559, \"Artist\": \"MC Zaquin, MC Rick\", \"Artist Followers\": 130627.0, \"Song ID\": \"6pQKUKBpwr6GhfhcFFFozo\", \"Genre\": \"['funk bh', 'funk carioca']\", \"Release Date\": \"2021-02-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.525, \"Energy\": 0.448, \"Loudness\": -4.075, \"Speechiness\": 0.0443, \"Acousticness\": 0.14, \"Liveness\": 0.0922, \"Tempo\": 83.406, \"Duration (ms)\": 140308.0, \"Valence\": 0.527, \"Chord\": \"C#/Db\"}, {\"Index\": 196, \"Highest Charting Position\": 8, \"Number of Times Charted\": 71, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Breaking Me\", \"Streams\": 4977498, \"Artist\": \"Topic, A7S\", \"Artist Followers\": 151832.0, \"Song ID\": \"3H7ihDc1dqLriiWXwsc2po\", \"Genre\": \"['dance pop', 'edm', 'german dance', 'pop dance', 'pop edm', 'tropical house']\", \"Release Date\": \"2019-12-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 84.0, \"Danceability\": 0.789, \"Energy\": 0.72, \"Loudness\": -5.652, \"Speechiness\": 0.218, \"Acousticness\": 0.223, \"Liveness\": 0.129, \"Tempo\": 122.031, \"Duration (ms)\": 166794.0, \"Valence\": 0.664, \"Chord\": \"G#/Ab\"}, {\"Index\": 197, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"penhasco.\", \"Streams\": 4973937, \"Artist\": \"Lu\\u00edsa Sonza\", \"Artist Followers\": 1909059.0, \"Song ID\": \"5VTqW8raQYnj2avZ27nO2a\", \"Genre\": \"['funk carioca', 'pop nacional']\", \"Release Date\": \"2021-07-18\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 80.0, \"Danceability\": 0.43, \"Energy\": 0.467, \"Loudness\": -8.56, \"Speechiness\": 0.051, \"Acousticness\": 0.775, \"Liveness\": 0.0933, \"Tempo\": 77.249, \"Duration (ms)\": 186121.0, \"Valence\": 0.382, \"Chord\": \"G#/Ab\"}, {\"Index\": 198, \"Highest Charting Position\": 58, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Late At Night\", \"Streams\": 4954899, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6603627.0, \"Song ID\": \"1fxYz1s15pyZLsJT0Hdh1m\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 84.0, \"Danceability\": 0.643, \"Energy\": 0.403, \"Loudness\": -11.254, \"Speechiness\": 0.41, \"Acousticness\": 0.343, \"Liveness\": 0.138, \"Tempo\": 98.54, \"Duration (ms)\": 174682.0, \"Valence\": 0.111, \"Chord\": \"C#/Db\"}, {\"Index\": 199, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Verdansk\", \"Streams\": 4950275, \"Artist\": \"Dave\", \"Artist Followers\": 1427540.0, \"Song ID\": \"7IPKXYU2rTMnrLW5IZ7ZI5\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2021-07-22\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 77.0, \"Danceability\": 0.961, \"Energy\": 0.502, \"Loudness\": -8.605, \"Speechiness\": 0.312, \"Acousticness\": 0.28, \"Liveness\": 0.145, \"Tempo\": 117.078, \"Duration (ms)\": 182285.0, \"Valence\": 0.536, \"Chord\": \"D\"}, {\"Index\": 200, \"Highest Charting Position\": 172, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"The Real Slim Shady\", \"Streams\": 4948965, \"Artist\": \"Eminem\", \"Artist Followers\": 46785561.0, \"Song ID\": \"3yfqSUWxFvZELEM4PmlwIR\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2000-05-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 84.0, \"Danceability\": 0.949, \"Energy\": 0.661, \"Loudness\": -4.244, \"Speechiness\": 0.0572, \"Acousticness\": 0.0302, \"Liveness\": 0.0454, \"Tempo\": 104.504, \"Duration (ms)\": 284200.0, \"Valence\": 0.76, \"Chord\": \"F\"}, {\"Index\": 201, \"Highest Charting Position\": 66, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Tell The Vision (feat. Kanye West & Pusha T)\", \"Streams\": 8859168, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"1Eu51GaXEehPMrDMh5QghA\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 57.0, \"Danceability\": 0.662, \"Energy\": 0.686, \"Loudness\": -8.302, \"Speechiness\": 0.332, \"Acousticness\": 0.251, \"Liveness\": 0.349, \"Tempo\": 143.971, \"Duration (ms)\": 215000.0, \"Valence\": 0.678, \"Chord\": \"G\"}, {\"Index\": 202, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Woo Baby (feat. Chris Brown)\", \"Streams\": 7371935, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"6bsqes8Zg9gUULzuCkMUs0\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 56.0, \"Danceability\": 0.563, \"Energy\": 0.672, \"Loudness\": -7.226, \"Speechiness\": 0.0765, \"Acousticness\": 0.359, \"Liveness\": 0.0972, \"Tempo\": 99.772, \"Duration (ms)\": 156000.0, \"Valence\": 0.284, \"Chord\": \"A\"}, {\"Index\": 203, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Holy Smokes\", \"Streams\": 6464206, \"Artist\": \"Trippie Redd, Lil Uzi Vert\", \"Artist Followers\": 6430522.0, \"Song ID\": \"3EpF150nXMSNjiH0bbmXIL\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 79.0, \"Danceability\": 0.437, \"Energy\": 0.527, \"Loudness\": -6.967, \"Speechiness\": 0.465, \"Acousticness\": 0.185, \"Liveness\": 0.153, \"Tempo\": 187.815, \"Duration (ms)\": 181714.0, \"Valence\": 0.701, \"Chord\": \"F#/Gb\"}, {\"Index\": 204, \"Highest Charting Position\": 127, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"More Time\", \"Streams\": 6238351, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"7wAnRqccDr2tzcSKLR4jKl\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 55.0, \"Danceability\": 0.628, \"Energy\": 0.581, \"Loudness\": -8.377, \"Speechiness\": 0.188, \"Acousticness\": 0.46, \"Liveness\": 0.152, \"Tempo\": 145.396, \"Duration (ms)\": 120828.0, \"Valence\": 0.259, \"Chord\": \"D\"}, {\"Index\": 205, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Coupe\", \"Streams\": 6161664, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"7LB3ilSpX1mSMKKztNTnu2\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 54.0, \"Danceability\": 0.912, \"Energy\": 0.589, \"Loudness\": -7.476, \"Speechiness\": 0.2, \"Acousticness\": 0.0332, \"Liveness\": 0.0795, \"Tempo\": 135.921, \"Duration (ms)\": 123549.0, \"Valence\": 0.486, \"Chord\": \"G#/Ab\"}, {\"Index\": 206, \"Highest Charting Position\": 76, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Holiday\", \"Streams\": 5883145, \"Artist\": \"KSI\", \"Artist Followers\": 2008516.0, \"Song ID\": \"6nV2dFZXpv1JlqDWBeTXRl\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 81.0, \"Danceability\": 0.356, \"Energy\": 0.684, \"Loudness\": -7.347, \"Speechiness\": 0.0878, \"Acousticness\": 0.152, \"Liveness\": 0.101, \"Tempo\": 87.188, \"Duration (ms)\": 193733.0, \"Valence\": 0.347, \"Chord\": \"G#/Ab\"}, {\"Index\": 207, \"Highest Charting Position\": 150, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Manslaughter (feat. Rick Ross & The-Dream)\", \"Streams\": 5822266, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"4byRwLo7EmkCNBU6S8G6u0\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 55.0, \"Danceability\": 0.441, \"Energy\": 0.623, \"Loudness\": -7.331, \"Speechiness\": 0.0414, \"Acousticness\": 0.135, \"Liveness\": 0.14, \"Tempo\": 78.082, \"Duration (ms)\": 249231.0, \"Valence\": 0.285, \"Chord\": \"C#/Db\"}, {\"Index\": 208, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Genius (feat. Lil Tjay & Swae Lee)\", \"Streams\": 5702636, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"2mmRtchzDVpCj9LSyexgjS\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 53.0, \"Danceability\": 0.723, \"Energy\": 0.667, \"Loudness\": -7.524, \"Speechiness\": 0.351, \"Acousticness\": 0.256, \"Liveness\": 0.261, \"Tempo\": 143.044, \"Duration (ms)\": 208112.0, \"Valence\": 0.396, \"Chord\": \"D\"}, {\"Index\": 209, \"Highest Charting Position\": 22, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"WUSYANAME (feat. Youngboy Never Broke Again & Ty Dolla $ign)\", \"Streams\": 5696113, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"5B0kgjHULYJhAQkK5XsMoC\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.493, \"Energy\": 0.653, \"Loudness\": -5.666, \"Speechiness\": 0.0466, \"Acousticness\": 0.269, \"Liveness\": 0.511, \"Tempo\": 142.347, \"Duration (ms)\": 121573.0, \"Valence\": 0.852, \"Chord\": \"C\"}, {\"Index\": 210, \"Highest Charting Position\": 105, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Sommergewitter\", \"Streams\": 5627519, \"Artist\": \"Pashanim\", \"Artist Followers\": 208554.0, \"Song ID\": \"2H7jZg2HliuQhZjfBblLrZ\", \"Genre\": \"['german alternative rap', 'german drill', 'german hip hop', 'german trap']\", \"Release Date\": \"2021-06-24\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.787, \"Energy\": 0.531, \"Loudness\": -10.569, \"Speechiness\": 0.101, \"Acousticness\": 0.132, \"Liveness\": 0.112, \"Tempo\": 91.996, \"Duration (ms)\": 138533.0, \"Valence\": 0.721, \"Chord\": \"B\"}, {\"Index\": 211, \"Highest Charting Position\": 17, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Body (Remix) [feat. ArrDee, E1 (3x3), ZT (3x3), Bugzy Malone, Buni, Fivio Foreign & Darkoo]\", \"Streams\": 5383125, \"Artist\": \"Tion Wayne, Russ Millions\", \"Artist Followers\": 323203.0, \"Song ID\": \"6uvMKqNlrSvcC4NaKnrwjZ\", \"Genre\": \"['london rap']\", \"Release Date\": \"2021-04-22\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 84.0, \"Danceability\": 0.883, \"Energy\": 0.674, \"Loudness\": -8.043, \"Speechiness\": 0.357, \"Acousticness\": 0.21, \"Liveness\": 0.0678, \"Tempo\": 141.02, \"Duration (ms)\": 278085.0, \"Valence\": 0.73, \"Chord\": \"B\"}, {\"Index\": 212, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Brush Em (feat. Rah Swish)\", \"Streams\": 5335271, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"58aW6yZGFl7rVM7SLfLnLL\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 54.0, \"Danceability\": 0.654, \"Energy\": 0.724, \"Loudness\": -6.59, \"Speechiness\": 0.355, \"Acousticness\": 0.106, \"Liveness\": 0.655, \"Tempo\": 71.696, \"Duration (ms)\": 150449.0, \"Valence\": 0.717, \"Chord\": \"D#/Eb\"}, {\"Index\": 213, \"Highest Charting Position\": 13, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"AM\", \"Streams\": 5288927, \"Artist\": \"Nio Garcia, Flow La Movie\", \"Artist Followers\": 2123734.0, \"Song ID\": \"2dNhNlpZAtV4lwAFW45LIv\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-01-28\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 85.0, \"Danceability\": 0.83, \"Energy\": 0.517, \"Loudness\": -6.416, \"Speechiness\": 0.333, \"Acousticness\": 0.399, \"Liveness\": 0.0916, \"Tempo\": 171.959, \"Duration (ms)\": 182496.0, \"Valence\": 0.616, \"Chord\": \"F#/Gb\"}, {\"Index\": 214, \"Highest Charting Position\": 175, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"MI FAI IMPAZZIRE\", \"Streams\": 5242097, \"Artist\": \"BLANCO, Sfera Ebbasta\", \"Artist Followers\": 127364.0, \"Song ID\": \"1x3Qb8np6S1UvpSLthwEJN\", \"Genre\": \"['italian hip hop', 'italian pop']\", \"Release Date\": \"2021-06-17\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\", \"Popularity\": 83.0, \"Danceability\": 0.477, \"Energy\": 0.844, \"Loudness\": -4.87, \"Speechiness\": 0.0458, \"Acousticness\": 0.00273, \"Liveness\": 0.137, \"Tempo\": 169.941, \"Duration (ms)\": 220235.0, \"Valence\": 0.203, \"Chord\": \"B\"}, {\"Index\": 215, \"Highest Charting Position\": 20, \"Number of Times Charted\": 82, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Ride It\", \"Streams\": 5235088, \"Artist\": \"Regard\", \"Artist Followers\": 152226.0, \"Song ID\": \"2tnVG71enUj33Ic2nFN6kZ\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop edm', 'slap house', 'tropical house']\", \"Release Date\": \"2019-07-26\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.88, \"Energy\": 0.751, \"Loudness\": -4.258, \"Speechiness\": 0.0874, \"Acousticness\": 0.177, \"Liveness\": 0.106, \"Tempo\": 117.948, \"Duration (ms)\": 157606.0, \"Valence\": 0.884, \"Chord\": \"G\"}, {\"Index\": 216, \"Highest Charting Position\": 15, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Lost Cause\", \"Streams\": 5203319, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"36fhyo5QlxBW7DrDHIOn1G\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 0.0, \"Danceability\": 0.671, \"Energy\": 0.336, \"Loudness\": -8.494, \"Speechiness\": 0.241, \"Acousticness\": 0.705, \"Liveness\": 0.0577, \"Tempo\": 75.051, \"Duration (ms)\": 212496.0, \"Valence\": 0.518, \"Chord\": \"A#/Bb\"}, {\"Index\": 217, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Shot in the Dark\", \"Streams\": 5173308, \"Artist\": \"John Mayer\", \"Artist Followers\": 5178156.0, \"Song ID\": \"239yM7BAQ2CkNc61ogPGXo\", \"Genre\": \"['neo mellow', 'pop rock', 'singer-songwriter']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 76.0, \"Danceability\": 0.741, \"Energy\": 0.556, \"Loudness\": -9.184, \"Speechiness\": 0.0266, \"Acousticness\": 0.0629, \"Liveness\": 0.103, \"Tempo\": 122.008, \"Duration (ms)\": 249080.0, \"Valence\": 0.587, \"Chord\": \"D\"}, {\"Index\": 218, \"Highest Charting Position\": 71, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Wrecked\", \"Streams\": 5150909, \"Artist\": \"Imagine Dragons\", \"Artist Followers\": 35285425.0, \"Song ID\": \"2d1MywHy6FwKdzxFuSJnwl\", \"Genre\": \"['modern rock', 'pop', 'rock']\", \"Release Date\": \"2021-07-02\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 83.0, \"Danceability\": 0.626, \"Energy\": 0.56, \"Loudness\": -5.82, \"Speechiness\": 0.0288, \"Acousticness\": 0.148, \"Liveness\": 0.109, \"Tempo\": 93.989, \"Duration (ms)\": 244005.0, \"Valence\": 0.229, \"Chord\": \"C\"}, {\"Index\": 219, \"Highest Charting Position\": 79, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Bipolar\", \"Streams\": 5116589, \"Artist\": \"Mc Davi, Mc Pedrinho, Mc Don Juan\", \"Artist Followers\": 2586114.0, \"Song ID\": \"0qxLQ6opocOGyFnlXqJ53x\", \"Genre\": \"['funk carioca', 'funk ostentacao', 'funk paulista']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 84.0, \"Danceability\": 0.601, \"Energy\": 0.36, \"Loudness\": -7.791, \"Speechiness\": 0.0877, \"Acousticness\": 0.586, \"Liveness\": 0.0882, \"Tempo\": 124.993, \"Duration (ms)\": 276480.0, \"Valence\": 0.335, \"Chord\": \"A\"}, {\"Index\": 220, \"Highest Charting Position\": 122, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"His & Hers (feat. Don Toliver, Lil Uzi Vert & Gunna)\", \"Streams\": 5110475, \"Artist\": \"Internet Money\", \"Artist Followers\": 411579.0, \"Song ID\": \"2IePEfMAtqWS6rLXXFZIgI\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-05-14--2021-05-21\", \"Popularity\": 84.0, \"Danceability\": 0.792, \"Energy\": 0.707, \"Loudness\": -5.218, \"Speechiness\": 0.0623, \"Acousticness\": 0.116, \"Liveness\": 0.12, \"Tempo\": 134.997, \"Duration (ms)\": 224042.0, \"Valence\": 0.408, \"Chord\": \"G\"}, {\"Index\": 221, \"Highest Charting Position\": 75, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Follow You\", \"Streams\": 5097187, \"Artist\": \"Imagine Dragons\", \"Artist Followers\": 35285425.0, \"Song ID\": \"7FdUvDkaE24o3FPIWTvzv2\", \"Genre\": \"['modern rock', 'pop', 'rock']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 84.0, \"Danceability\": 0.542, \"Energy\": 0.732, \"Loudness\": -5.956, \"Speechiness\": 0.0521, \"Acousticness\": 0.00209, \"Liveness\": 0.496, \"Tempo\": 124.912, \"Duration (ms)\": 175644.0, \"Valence\": 0.489, \"Chord\": \"A\"}, {\"Index\": 222, \"Highest Charting Position\": 22, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"We're Good\", \"Streams\": 6318660, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"1diS6nkxMQc3wwC4G1j0bh\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 83.0, \"Danceability\": 0.722, \"Energy\": 0.588, \"Loudness\": -5.932, \"Speechiness\": 0.0544, \"Acousticness\": 0.0319, \"Liveness\": 0.183, \"Tempo\": 134.01, \"Duration (ms)\": 165507.0, \"Valence\": 0.59, \"Chord\": \"F#/Gb\"}, {\"Index\": 223, \"Highest Charting Position\": 4, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Life Goes On\", \"Streams\": 6142975, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"249gnXrbfmV8NG6jTEMSwD\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 84.0, \"Danceability\": 0.566, \"Energy\": 0.716, \"Loudness\": -5.733, \"Speechiness\": 0.0424, \"Acousticness\": 0.00691, \"Liveness\": 0.37, \"Tempo\": 81.068, \"Duration (ms)\": 207481.0, \"Valence\": 0.45, \"Chord\": \"C#/Db\"}, {\"Index\": 224, \"Highest Charting Position\": 28, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"911\", \"Streams\": 6111108, \"Artist\": \"Sech\", \"Artist Followers\": 8758283.0, \"Song ID\": \"27RSJHEA99Y0Vsow7nA37A\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2020-05-29--2020-06-05\", \"Popularity\": 89.0, \"Danceability\": 0.816, \"Energy\": 0.71, \"Loudness\": -3.728, \"Speechiness\": 0.0398, \"Acousticness\": 0.165, \"Liveness\": 0.292, \"Tempo\": 93.02, \"Duration (ms)\": 208631.0, \"Valence\": 0.784, \"Chord\": \"G\"}, {\"Index\": 225, \"Highest Charting Position\": 17, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Baila Conmigo (with Rauw Alejandro)\", \"Streams\": 5588217, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28909504.0, \"Song ID\": \"079Ey5uxL04AKPQgVQwx5h\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 84.0, \"Danceability\": 0.823, \"Energy\": 0.544, \"Loudness\": -7.132, \"Speechiness\": 0.0715, \"Acousticness\": 0.0215, \"Liveness\": 0.0966, \"Tempo\": 149.903, \"Duration (ms)\": 186088.0, \"Valence\": 0.664, \"Chord\": \"F\"}, {\"Index\": 226, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"The Jackie (with J. Cole & Lil Tjay)\", \"Streams\": 5454994, \"Artist\": \"Bas\", \"Artist Followers\": 386757.0, \"Song ID\": \"15qKrPi4Kg0z7g9HlwWyeb\", \"Genre\": \"['hip hop', 'pop rap', 'queens hip hop', 'rap', 'sudanese pop', 'underground hip hop']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-09--2021-07-16\", \"Popularity\": 76.0, \"Danceability\": 0.784, \"Energy\": 0.474, \"Loudness\": -6.139, \"Speechiness\": 0.0524, \"Acousticness\": 0.333, \"Liveness\": 0.278, \"Tempo\": 128.012, \"Duration (ms)\": 204434.0, \"Valence\": 0.64, \"Chord\": \"G#/Ab\"}, {\"Index\": 227, \"Highest Charting Position\": 22, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"hope ur ok\", \"Streams\": 5435614, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"1zejeOnykpCoyVSit6Bwp3\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 84.0, \"Danceability\": 0.443, \"Energy\": 0.298, \"Loudness\": -12.181, \"Speechiness\": 0.0644, \"Acousticness\": 0.388, \"Liveness\": 0.103, \"Tempo\": 77.253, \"Duration (ms)\": 209560.0, \"Valence\": 0.172, \"Chord\": \"C\"}, {\"Index\": 228, \"Highest Charting Position\": 169, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Faz Amor Comigo S\\u00f3 Hoje - Ao Vivo\", \"Streams\": 5269757, \"Artist\": \"Israel & Rodolffo, Wesley Safad\\u00e3o\", \"Artist Followers\": 1097789.0, \"Song ID\": \"7Kba4OaxQFQ1zlknQUpNqN\", \"Genre\": \"['sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2021-05-26\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 82.0, \"Danceability\": 0.624, \"Energy\": 0.922, \"Loudness\": -4.628, \"Speechiness\": 0.0439, \"Acousticness\": 0.3, \"Liveness\": 0.112, \"Tempo\": 164.819, \"Duration (ms)\": 148228.0, \"Valence\": 0.884, \"Chord\": \"C#/Db\"}, {\"Index\": 229, \"Highest Charting Position\": 80, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Alcohol-Free\", \"Streams\": 5259503, \"Artist\": \"TWICE\", \"Artist Followers\": 9987114.0, \"Song ID\": \"0BTaaKT4RMbs5M73tOHX5Y\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 82.0, \"Danceability\": 0.688, \"Energy\": 0.909, \"Loudness\": -1.992, \"Speechiness\": 0.0624, \"Acousticness\": 0.0474, \"Liveness\": 0.0674, \"Tempo\": 97.097, \"Duration (ms)\": 210573.0, \"Valence\": 0.702, \"Chord\": \"G#/Ab\"}, {\"Index\": 230, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"WHOLE LOTTA MONEY (feat. Nicki Minaj) - Remix\", \"Streams\": 5186354, \"Artist\": \"BIA\", \"Artist Followers\": 151870.0, \"Song ID\": \"67G6iaOw8DZqp1z8STR89R\", \"Genre\": \"['escape room', 'r&b', 'rap latina', 'trap queen']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-09--2021-07-16\", \"Popularity\": 80.0, \"Danceability\": 0.893, \"Energy\": 0.463, \"Loudness\": -5.301, \"Speechiness\": 0.36, \"Acousticness\": 0.199, \"Liveness\": 0.318, \"Tempo\": 81.026, \"Duration (ms)\": 229601.0, \"Valence\": 0.591, \"Chord\": \"C#/Db\"}, {\"Index\": 231, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Memory\", \"Streams\": 5173178, \"Artist\": \"Kane Brown, blackbear\", \"Artist Followers\": 3507622.0, \"Song ID\": \"34chhNX59Wo9HMFCsI3K8Y\", \"Genre\": \"['contemporary country', 'country road']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-09--2021-07-16\", \"Popularity\": 80.0, \"Danceability\": 0.434, \"Energy\": 0.889, \"Loudness\": -5.684, \"Speechiness\": 0.0509, \"Acousticness\": 0.395, \"Liveness\": 0.273, \"Tempo\": 113.326, \"Duration (ms)\": 153338.0, \"Valence\": 0.845, \"Chord\": \"A\"}, {\"Index\": 232, \"Highest Charting Position\": 183, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Me Fije\", \"Streams\": 5068677, \"Artist\": \"Alex Rose, Rauw Alejandro\", \"Artist Followers\": 2166191.0, \"Song ID\": \"6Et5KimMg3IXwD6lJPGmQw\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2021-03-18\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-05-07--2021-05-14\", \"Popularity\": 83.0, \"Danceability\": 0.76, \"Energy\": 0.674, \"Loudness\": -4.039, \"Speechiness\": 0.0636, \"Acousticness\": 0.396, \"Liveness\": 0.0977, \"Tempo\": 172.024, \"Duration (ms)\": 202307.0, \"Valence\": 0.735, \"Chord\": \"G\"}, {\"Index\": 233, \"Highest Charting Position\": 71, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Volta Beb\\u00ea, Volta Nen\\u00e9m\", \"Streams\": 5041120, \"Artist\": \"Dj Guuga, DJ Ivis\", \"Artist Followers\": 608109.0, \"Song ID\": \"4wQUopWk9Ed7Ng5qpKN5qd\", \"Genre\": \"['funk carioca', 'funk paulista', 'rave funk']\", \"Release Date\": \"2021-03-27\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 79.0, \"Danceability\": 0.583, \"Energy\": 0.918, \"Loudness\": -3.612, \"Speechiness\": 0.0518, \"Acousticness\": 0.288, \"Liveness\": 0.0701, \"Tempo\": 164.081, \"Duration (ms)\": 172973.0, \"Valence\": 0.836, \"Chord\": \"F#/Gb\"}, {\"Index\": 234, \"Highest Charting Position\": 95, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Aloha\", \"Streams\": 5036030, \"Artist\": \"Maluma, Be\\u00e9le, Rauw Alejandro, Mambo Kingz, DJ Luian, Darell\", \"Artist Followers\": 26769304.0, \"Song ID\": \"5RAIMjdrCEjpjaR5tBATXU\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 84.0, \"Danceability\": 0.807, \"Energy\": 0.712, \"Loudness\": -5.757, \"Speechiness\": 0.1, \"Acousticness\": 0.532, \"Liveness\": 0.163, \"Tempo\": 100.004, \"Duration (ms)\": 241659.0, \"Valence\": 0.792, \"Chord\": \"C#/Db\"}, {\"Index\": 235, \"Highest Charting Position\": 184, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Sexo Virtual\", \"Streams\": 4975786, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6080597.0, \"Song ID\": \"0giiXonRhODYy4J1iy4Lb3\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 82.0, \"Danceability\": 0.704, \"Energy\": 0.739, \"Loudness\": -3.286, \"Speechiness\": 0.112, \"Acousticness\": 0.328, \"Liveness\": 0.0856, \"Tempo\": 179.879, \"Duration (ms)\": 208292.0, \"Valence\": 0.425, \"Chord\": \"G#/Ab\"}, {\"Index\": 236, \"Highest Charting Position\": 141, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Closer\", \"Streams\": 4954679, \"Artist\": \"The Chainsmokers, Halsey\", \"Artist Followers\": 18191658.0, \"Song ID\": \"7BKLCZ1jbUBVqRi2FVlTVw\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2016-07-29\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-01--2021-01-08\\n2020-08-14--2020-08-21\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.748, \"Energy\": 0.524, \"Loudness\": -5.599, \"Speechiness\": 0.0338, \"Acousticness\": 0.414, \"Liveness\": 0.111, \"Tempo\": 95.01, \"Duration (ms)\": 244960.0, \"Valence\": 0.661, \"Chord\": \"G#/Ab\"}, {\"Index\": 237, \"Highest Charting Position\": 194, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Wonderwall - Remastered\", \"Streams\": 4938180, \"Artist\": \"Oasis\", \"Artist Followers\": 6475631.0, \"Song ID\": \"7ygpwy2qP3NbrxVkHvUhXY\", \"Genre\": \"['beatlesque', 'britpop', 'madchester', 'permanent wave', 'rock']\", \"Release Date\": \"1995\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-05-28--2021-06-04\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 78.0, \"Danceability\": 0.375, \"Energy\": 0.893, \"Loudness\": -4.097, \"Speechiness\": 0.0406, \"Acousticness\": 0.000509, \"Liveness\": 0.187, \"Tempo\": 174.323, \"Duration (ms)\": 258773.0, \"Valence\": 0.434, \"Chord\": \"D\"}, {\"Index\": 238, \"Highest Charting Position\": 101, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Wasting Time ( feat. Drake )\", \"Streams\": 6731106, \"Artist\": \"Brent Faiyaz\", \"Artist Followers\": 1724414.0, \"Song ID\": \"48WidxP9CqyYtk97pwGZ3c\", \"Genre\": \"['dmv rap', 'pop', 'r&b', 'rap']\", \"Release Date\": \"2021-07-01\", \"Weeks Charted\": \"2021-07-02--2021-07-09\", \"Popularity\": 78.0, \"Danceability\": 0.652, \"Energy\": 0.717, \"Loudness\": -3.751, \"Speechiness\": 0.0581, \"Acousticness\": 0.0694, \"Liveness\": 0.0906, \"Tempo\": 89.982, \"Duration (ms)\": 301304.0, \"Valence\": 0.377, \"Chord\": \"G\"}, {\"Index\": 239, \"Highest Charting Position\": 55, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"I Don't Do Drugs (feat. Ariana Grande)\", \"Streams\": 5912293, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0FFsgUoFibYISzMxuGS61W\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 80.0, \"Danceability\": 0.683, \"Energy\": 0.615, \"Loudness\": -5.737, \"Speechiness\": 0.0966, \"Acousticness\": 0.222, \"Liveness\": 0.154, \"Tempo\": 77.014, \"Duration (ms)\": 188893.0, \"Valence\": 0.45, \"Chord\": \"F\"}, {\"Index\": 240, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Renegade (feat. Taylor Swift)\", \"Streams\": 5876058, \"Artist\": \"Big Red Machine\", \"Artist Followers\": 98503.0, \"Song ID\": \"1aU1wpYBSpP0M6IiihY5Ue\", \"Genre\": \"['eau claire indie', 'folktronica']\", \"Release Date\": \"2021-07-02\", \"Weeks Charted\": \"2021-07-02--2021-07-09\", \"Popularity\": 77.0, \"Danceability\": 0.532, \"Energy\": 0.708, \"Loudness\": -8.121, \"Speechiness\": 0.0505, \"Acousticness\": 0.435, \"Liveness\": 0.107, \"Tempo\": 167.977, \"Duration (ms)\": 254467.0, \"Valence\": 0.586, \"Chord\": \"C\"}, {\"Index\": 241, \"Highest Charting Position\": 40, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"JUGGERNAUT (feat. Lil Uzi Vert & Pharrell Williams)\", \"Streams\": 5392334, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"7z4xW9WY86uH3gd1V9pfCM\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 80.0, \"Danceability\": 0.827, \"Energy\": 0.571, \"Loudness\": -7.949, \"Speechiness\": 0.366, \"Acousticness\": 0.0195, \"Liveness\": 0.166, \"Tempo\": 142.034, \"Duration (ms)\": 146419.0, \"Valence\": 0.62, \"Chord\": \"B\"}, {\"Index\": 242, \"Highest Charting Position\": 152, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"All Eyes On Me\", \"Streams\": 5347263, \"Artist\": \"Bo Burnham\", \"Artist Followers\": 1042079.0, \"Song ID\": \"3rV5y8rcQrwRt9fWGLmjOQ\", \"Genre\": \"['comic']\", \"Release Date\": \"2021-06-10\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 81.0, \"Danceability\": 0.352, \"Energy\": 0.424, \"Loudness\": -10.131, \"Speechiness\": 0.0394, \"Acousticness\": 0.733, \"Liveness\": 0.0664, \"Tempo\": 127.047, \"Duration (ms)\": 302951.0, \"Valence\": 0.141, \"Chord\": \"F#/Gb\"}, {\"Index\": 243, \"Highest Charting Position\": 101, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"EVERY CHANCE I GET (feat. Lil Baby & Lil Durk)\", \"Streams\": 5321544, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6278835.0, \"Song ID\": \"1EJIcDYXwSqipW5dFe4uJz\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 83.0, \"Danceability\": 0.477, \"Energy\": 0.727, \"Loudness\": -4.053, \"Speechiness\": 0.286, \"Acousticness\": 0.000866, \"Liveness\": 0.108, \"Tempo\": 150.062, \"Duration (ms)\": 236524.0, \"Valence\": 0.227, \"Chord\": \"D\"}, {\"Index\": 244, \"Highest Charting Position\": 72, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Dick (feat. Doja Cat)\", \"Streams\": 5258628, \"Artist\": \"StarBoi3\", \"Artist Followers\": 17202.0, \"Song ID\": \"3nY8AqaMNNHHLYV4380ol0\", \"Genre\": \"[]\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 83.0, \"Danceability\": 0.647, \"Energy\": 0.608, \"Loudness\": -6.831, \"Speechiness\": 0.42, \"Acousticness\": 0.13, \"Liveness\": 0.0584, \"Tempo\": 125.994, \"Duration (ms)\": 175238.0, \"Valence\": 0.474, \"Chord\": \"A\"}, {\"Index\": 245, \"Highest Charting Position\": 25, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Solar Power\", \"Streams\": 5234112, \"Artist\": \"Lorde\", \"Artist Followers\": 8083566.0, \"Song ID\": \"3KdoeNlEN0BoAKWzaRLNZa\", \"Genre\": \"['art pop', 'dance pop', 'electropop', 'metropopolis', 'nz pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-06-10\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 81.0, \"Danceability\": 0.735, \"Energy\": 0.47, \"Loudness\": -9.405, \"Speechiness\": 0.1, \"Acousticness\": 0.266, \"Liveness\": 0.32, \"Tempo\": 87.971, \"Duration (ms)\": 192621.0, \"Valence\": 0.897, \"Chord\": \"E\"}, {\"Index\": 246, \"Highest Charting Position\": 4, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Your Power\", \"Streams\": 5135380, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47014200.0, \"Song ID\": \"042Sl6Mn83JHyLEqdK7uI0\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-07-30\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 81.0, \"Danceability\": 0.632, \"Energy\": 0.284, \"Loudness\": -14.025, \"Speechiness\": 0.0801, \"Acousticness\": 0.932, \"Liveness\": 0.233, \"Tempo\": 129.642, \"Duration (ms)\": 245897.0, \"Valence\": 0.208, \"Chord\": \"A\"}, {\"Index\": 247, \"Highest Charting Position\": 189, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Lieben wir\", \"Streams\": 5029898, \"Artist\": \"Shirin David\", \"Artist Followers\": 558345.0, \"Song ID\": \"49gzU1IS1B6P3GATSZ5eCE\", \"Genre\": \"['frauenrap', 'german hip hop', 'german pop']\", \"Release Date\": \"2021-07-01\", \"Weeks Charted\": \"2021-07-02--2021-07-09\", \"Popularity\": 77.0, \"Danceability\": 0.871, \"Energy\": 0.669, \"Loudness\": -7.62, \"Speechiness\": 0.329, \"Acousticness\": 0.0113, \"Liveness\": 0.0795, \"Tempo\": 95.939, \"Duration (ms)\": 155363.0, \"Valence\": 0.806, \"Chord\": \"A#/Bb\"}, {\"Index\": 248, \"Highest Charting Position\": 8, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Whoopty\", \"Streams\": 5013017, \"Artist\": \"CJ\", \"Artist Followers\": 180454.0, \"Song ID\": \"5vGLcdRuSbUhD8ScwsGSdA\", \"Genre\": \"['nyc rap']\", \"Release Date\": \"2020-08-20\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 81.0, \"Danceability\": 0.719, \"Energy\": 0.648, \"Loudness\": -7.6, \"Speechiness\": 0.125, \"Acousticness\": 0.2, \"Liveness\": 0.127, \"Tempo\": 140.201, \"Duration (ms)\": 123263.0, \"Valence\": 0.66, \"Chord\": \"D#/Eb\"}, {\"Index\": 249, \"Highest Charting Position\": 55, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Batom de Cereja - Ao Vivo\", \"Streams\": 5011753, \"Artist\": \"Israel & Rodolffo\", \"Artist Followers\": 1097789.0, \"Song ID\": \"2MZQAvsA7aZDssppBLRxYp\", \"Genre\": \"['sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2021-01-29\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 83.0, \"Danceability\": 0.606, \"Energy\": 0.908, \"Loudness\": -6.201, \"Speechiness\": 0.0565, \"Acousticness\": 0.556, \"Liveness\": 0.19, \"Tempo\": 171.966, \"Duration (ms)\": 140942.0, \"Valence\": 0.798, \"Chord\": \"F#/Gb\"}, {\"Index\": 250, \"Highest Charting Position\": 11, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Prisoner (feat. Dua Lipa)\", \"Streams\": 5005018, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15770302.0, \"Song ID\": \"5JqZ3oqF00jkT81foAFvqg\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 79.0, \"Danceability\": 0.781, \"Energy\": 0.67, \"Loudness\": -3.912, \"Speechiness\": 0.0452, \"Acousticness\": 0.0103, \"Liveness\": 0.0761, \"Tempo\": 127.99, \"Duration (ms)\": 169333.0, \"Valence\": 0.595, \"Chord\": \"D#/Eb\"}, {\"Index\": 251, \"Highest Charting Position\": 136, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Stereo Hearts (feat. Adam Levine)\", \"Streams\": 4992345, \"Artist\": \"Gym Class Heroes\", \"Artist Followers\": 1275345.0, \"Song ID\": \"0qOnSQQF0yzuPWsXrQ9paz\", \"Genre\": \"['dance pop', 'pop rap']\", \"Release Date\": \"2011-11-11\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 82.0, \"Danceability\": 0.646, \"Energy\": 0.795, \"Loudness\": -3.293, \"Speechiness\": 0.0976, \"Acousticness\": 0.0319, \"Liveness\": 0.267, \"Tempo\": 89.99, \"Duration (ms)\": 210960.0, \"Valence\": 0.796, \"Chord\": \"A\"}, {\"Index\": 252, \"Highest Charting Position\": 32, \"Number of Times Charted\": 36, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Reloj\", \"Streams\": 4980155, \"Artist\": \"Rauw Alejandro, Anuel AA\", \"Artist Followers\": 6080597.0, \"Song ID\": \"7r9ZhitdQBONTFOiJW5mr8\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-10-22\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 79.0, \"Danceability\": 0.823, \"Energy\": 0.537, \"Loudness\": -2.639, \"Speechiness\": 0.209, \"Acousticness\": 0.176, \"Liveness\": 0.123, \"Tempo\": 175.946, \"Duration (ms)\": 231595.0, \"Valence\": 0.615, \"Chord\": \"G#/Ab\"}, {\"Index\": 253, \"Highest Charting Position\": 81, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"malibu\", \"Streams\": 4973063, \"Artist\": \"sangiovanni\", \"Artist Followers\": 384097.0, \"Song ID\": \"01hEpx8jnOG4q7nDK14Rhi\", \"Genre\": \"[]\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.733, \"Energy\": 0.736, \"Loudness\": -5.123, \"Speechiness\": 0.111, \"Acousticness\": 0.028, \"Liveness\": 0.131, \"Tempo\": 147.897, \"Duration (ms)\": 166216.0, \"Valence\": 0.669, \"Chord\": \"G\"}, {\"Index\": 254, \"Highest Charting Position\": 101, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Eladio Carrion: Bzrp Music Sessions, Vol. 40\", \"Streams\": 4965913, \"Artist\": \"Bizarrap, Eladio Carrion\", \"Artist Followers\": 3126961.0, \"Song ID\": \"1VauUM5CBX7nkLcgafQL2B\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2021-06-09\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 81.0, \"Danceability\": 0.783, \"Energy\": 0.524, \"Loudness\": -6.455, \"Speechiness\": 0.0554, \"Acousticness\": 0.241, \"Liveness\": 0.271, \"Tempo\": 117.496, \"Duration (ms)\": 164896.0, \"Valence\": 0.839, \"Chord\": \"F\"}, {\"Index\": 255, \"Highest Charting Position\": 117, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Do I Wanna Know?\", \"Streams\": 4938586, \"Artist\": \"Arctic Monkeys\", \"Artist Followers\": 12369079.0, \"Song ID\": \"5FVd6KXrgO9B3JPmC8OPst\", \"Genre\": \"['garage rock', 'permanent wave', 'rock', 'sheffield indie']\", \"Release Date\": \"2013-09-09\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 84.0, \"Danceability\": 0.548, \"Energy\": 0.532, \"Loudness\": -7.596, \"Speechiness\": 0.0323, \"Acousticness\": 0.186, \"Liveness\": 0.217, \"Tempo\": 85.03, \"Duration (ms)\": 272394.0, \"Valence\": 0.405, \"Chord\": \"F\"}, {\"Index\": 256, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"LUMBERJACK\", \"Streams\": 11756283, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"0BiK5BbYNFLb88CCOxBFJe\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 76.0, \"Danceability\": 0.386, \"Energy\": 0.762, \"Loudness\": -6.341, \"Speechiness\": 0.564, \"Acousticness\": 0.122, \"Liveness\": 0.527, \"Tempo\": 170.691, \"Duration (ms)\": 138312.0, \"Valence\": 0.433, \"Chord\": \"A\"}, {\"Index\": 257, \"Highest Charting Position\": 47, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"LEMONHEAD (feat. 42 Dugg)\", \"Streams\": 11380679, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"5fbHRCsGpFIOLRtlhCRFDR\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 78.0, \"Danceability\": 0.62, \"Energy\": 0.586, \"Loudness\": -6.612, \"Speechiness\": 0.212, \"Acousticness\": 0.155, \"Liveness\": 0.535, \"Tempo\": 137.131, \"Duration (ms)\": 130980.0, \"Valence\": 0.487, \"Chord\": \"C#/Db\"}, {\"Index\": 258, \"Highest Charting Position\": 59, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"HOT WIND BLOWS (feat. Lil Wayne)\", \"Streams\": 9889197, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"3JJL91ilRV6fXhKqu0FGXs\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 77.0, \"Danceability\": 0.371, \"Energy\": 0.75, \"Loudness\": -5.382, \"Speechiness\": 0.402, \"Acousticness\": 0.601, \"Liveness\": 0.482, \"Tempo\": 173.456, \"Duration (ms)\": 155293.0, \"Valence\": 0.729, \"Chord\": \"G\"}, {\"Index\": 259, \"Highest Charting Position\": 63, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"CORSO\", \"Streams\": 9503981, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"46oHvXwpEZOFX518we1nJD\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 77.0, \"Danceability\": 0.703, \"Energy\": 0.845, \"Loudness\": -4.851, \"Speechiness\": 0.337, \"Acousticness\": 0.169, \"Liveness\": 0.122, \"Tempo\": 97.672, \"Duration (ms)\": 146482.0, \"Valence\": 0.745, \"Chord\": \"A#/Bb\"}, {\"Index\": 260, \"Highest Charting Position\": 69, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"SWEET / I THOUGHT YOU WANTED TO DANCE (feat. Brent Faiyaz & Fana Hues)\", \"Streams\": 9142721, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"3EG9FJ0ToLfgnc1IG2Z1wz\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 79.0, \"Danceability\": 0.468, \"Energy\": 0.652, \"Loudness\": -4.912, \"Speechiness\": 0.0722, \"Acousticness\": 0.333, \"Liveness\": 0.55, \"Tempo\": 140.223, \"Duration (ms)\": 588139.0, \"Valence\": 0.39, \"Chord\": \"C\"}, {\"Index\": 261, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"SIR BAUDELAIRE (feat. DJ Drama)\", \"Streams\": 8884283, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"4ydmav4vl7hebadtfZtMrg\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 75.0, \"Danceability\": 0.467, \"Energy\": 0.635, \"Loudness\": -6.115, \"Speechiness\": 0.154, \"Acousticness\": 0.314, \"Liveness\": 0.844, \"Tempo\": 127.596, \"Duration (ms)\": 88625.0, \"Valence\": 0.51, \"Chord\": \"G\"}, {\"Index\": 262, \"Highest Charting Position\": 82, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"MASSA\", \"Streams\": 8218423, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"2goHCrsDJaflEwQ930ef0o\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 74.0, \"Danceability\": 0.685, \"Energy\": 0.855, \"Loudness\": -6.724, \"Speechiness\": 0.438, \"Acousticness\": 0.329, \"Liveness\": 0.301, \"Tempo\": 157.181, \"Duration (ms)\": 223719.0, \"Valence\": 0.46, \"Chord\": \"C#/Db\"}, {\"Index\": 263, \"Highest Charting Position\": 85, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"RUNITUP (feat. Teezo Touchdown)\", \"Streams\": 7917707, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"13HsOwrwTA5HgLuoaDHncP\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 75.0, \"Danceability\": 0.665, \"Energy\": 0.469, \"Loudness\": -7.778, \"Speechiness\": 0.13, \"Acousticness\": 0.565, \"Liveness\": 0.219, \"Tempo\": 115.852, \"Duration (ms)\": 229565.0, \"Valence\": 0.142, \"Chord\": \"A#/Bb\"}, {\"Index\": 264, \"Highest Charting Position\": 108, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"MANIFESTO (feat. Domo Genesis)\", \"Streams\": 6988886, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"6qouBO0wJtYc3k7DfKRUBx\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.454, \"Energy\": 0.866, \"Loudness\": -5.348, \"Speechiness\": 0.391, \"Acousticness\": 0.121, \"Liveness\": 0.167, \"Tempo\": 92.463, \"Duration (ms)\": 175123.0, \"Valence\": 0.518, \"Chord\": \"D\"}, {\"Index\": 265, \"Highest Charting Position\": 121, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Get Into It (Yuh)\", \"Streams\": 6503281, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0W6I02J9xcqK8MtSeosEXb\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 80.0, \"Danceability\": 0.912, \"Energy\": 0.655, \"Loudness\": -6.029, \"Speechiness\": 0.162, \"Acousticness\": 0.315, \"Liveness\": 0.0894, \"Tempo\": 91.942, \"Duration (ms)\": 138293.0, \"Valence\": 0.793, \"Chord\": \"G#/Ab\"}, {\"Index\": 266, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"WILSHIRE\", \"Streams\": 6268542, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"1pbbsI2KGPOMu0HmuGccBu\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.555, \"Energy\": 0.712, \"Loudness\": -7.446, \"Speechiness\": 0.323, \"Acousticness\": 0.0451, \"Liveness\": 0.182, \"Tempo\": 78.958, \"Duration (ms)\": 515865.0, \"Valence\": 0.555, \"Chord\": \"C#/Db\"}, {\"Index\": 267, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"RISE! (feat. DAISY WORLD)\", \"Streams\": 6034281, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"4Hta7Oy5W9HD0UgT1P8PPV\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.766, \"Energy\": 0.814, \"Loudness\": -3.367, \"Speechiness\": 0.0733, \"Acousticness\": 0.044, \"Liveness\": 0.195, \"Tempo\": 108.07, \"Duration (ms)\": 203588.0, \"Valence\": 0.481, \"Chord\": \"D\"}, {\"Index\": 268, \"Highest Charting Position\": 165, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Naked\", \"Streams\": 5527865, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0CsR9Y9SnC6ZWmekmVqSHz\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 75.0, \"Danceability\": 0.733, \"Energy\": 0.862, \"Loudness\": -5.736, \"Speechiness\": 0.197, \"Acousticness\": 0.374, \"Liveness\": 0.131, \"Tempo\": 111.076, \"Duration (ms)\": 223560.0, \"Valence\": 0.536, \"Chord\": \"G\"}, {\"Index\": 269, \"Highest Charting Position\": 50, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Having Our Way (feat. Drake)\", \"Streams\": 5424579, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"2NM0qHzx4Ohy8iXHEEgwlO\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 79.0, \"Danceability\": 0.927, \"Energy\": 0.538, \"Loudness\": -3.917, \"Speechiness\": 0.116, \"Acousticness\": 0.0312, \"Liveness\": 0.0945, \"Tempo\": 125.983, \"Duration (ms)\": 278191.0, \"Valence\": 0.221, \"Chord\": \"C#/Db\"}, {\"Index\": 270, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Payday (feat. Young Thug)\", \"Streams\": 5393789, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"2HolBGR6tpiWI80MXoV1dJ\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.619, \"Energy\": 0.707, \"Loudness\": -5.791, \"Speechiness\": 0.0499, \"Acousticness\": 0.0366, \"Liveness\": 0.13, \"Tempo\": 168.995, \"Duration (ms)\": 212947.0, \"Valence\": 0.558, \"Chord\": \"C#/Db\"}, {\"Index\": 271, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Been Like This\", \"Streams\": 5362817, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"7y3xU9vEC1s8DSuuoSYKih\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 74.0, \"Danceability\": 0.678, \"Energy\": 0.531, \"Loudness\": -5.029, \"Speechiness\": 0.0374, \"Acousticness\": 0.126, \"Liveness\": 0.377, \"Tempo\": 99.008, \"Duration (ms)\": 177373.0, \"Valence\": 0.176, \"Chord\": \"A#/Bb\"}, {\"Index\": 272, \"Highest Charting Position\": 138, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"MILLE (feat. Orietta Berti)\", \"Streams\": 5341887, \"Artist\": \"Fedez, Achille Lauro\", \"Artist Followers\": 1650683.0, \"Song ID\": \"6qdMhG7pRFi0csRlFGvLE4\", \"Genre\": \"['italian adult pop', 'italian pop']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 82.0, \"Danceability\": 0.527, \"Energy\": 0.764, \"Loudness\": -4.297, \"Speechiness\": 0.322, \"Acousticness\": 0.016, \"Liveness\": 0.0273, \"Tempo\": 184.339, \"Duration (ms)\": 175924.0, \"Valence\": 0.829, \"Chord\": \"D\"}, {\"Index\": 273, \"Highest Charting Position\": 10, \"Number of Times Charted\": 49, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"UN DIA (ONE DAY) (Feat. Tainy)\", \"Streams\": 5203364, \"Artist\": \"J Balvin, Dua Lipa, Bad Bunny\", \"Artist Followers\": 29051363.0, \"Song ID\": \"0EhpEsp4L0oRGM0vmeaN5e\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 83.0, \"Danceability\": 0.571, \"Energy\": 0.693, \"Loudness\": -8.234, \"Speechiness\": 0.0545, \"Acousticness\": 0.00536, \"Liveness\": 0.173, \"Tempo\": 168.169, \"Duration (ms)\": 232253.0, \"Valence\": 0.393, \"Chord\": \"F#/Gb\"}, {\"Index\": 274, \"Highest Charting Position\": 1, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Savage Love (Laxed - Siren Beat)\", \"Streams\": 5108950, \"Artist\": \"Jawsh 685, Jason Derulo\", \"Artist Followers\": 100604.0, \"Song ID\": \"1xQ6trAsedVPCdbtDAmk0c\", \"Genre\": \"['nz pop']\", \"Release Date\": \"2020-06-11\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 82.0, \"Danceability\": 0.767, \"Energy\": 0.481, \"Loudness\": -8.52, \"Speechiness\": 0.0803, \"Acousticness\": 0.234, \"Liveness\": 0.269, \"Tempo\": 150.076, \"Duration (ms)\": 171375.0, \"Valence\": 0.761, \"Chord\": \"C\"}, {\"Index\": 275, \"Highest Charting Position\": 59, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Poblado\", \"Streams\": 6893939, \"Artist\": \"Crissin, Totoy El Frio, Natan & Shander\", \"Artist Followers\": 29051363.0, \"Song ID\": \"1WedZeiezCmCEOzLwhx0hV\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 89.0, \"Danceability\": 0.813, \"Energy\": 0.809, \"Loudness\": -5.382, \"Speechiness\": 0.0846, \"Acousticness\": 0.102, \"Liveness\": 0.377, \"Tempo\": 93.005, \"Duration (ms)\": 393280.0, \"Valence\": 0.646, \"Chord\": \"D#/Eb\"}, {\"Index\": 276, \"Highest Charting Position\": 17, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Hecha Pa' Mi\", \"Streams\": 6308369, \"Artist\": \"Boza\", \"Artist Followers\": 278679.0, \"Song ID\": \"3VvA1wSxukMLsvXoXtlwWx\", \"Genre\": \"['reggaeton']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 83.0, \"Danceability\": 0.725, \"Energy\": 0.756, \"Loudness\": -5.013, \"Speechiness\": 0.0572, \"Acousticness\": 0.362, \"Liveness\": 0.103, \"Tempo\": 100.07, \"Duration (ms)\": 186133.0, \"Valence\": 0.828, \"Chord\": \"E\"}, {\"Index\": 277, \"Highest Charting Position\": 146, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"working\", \"Streams\": 5666770, \"Artist\": \"Tate McRae, Khalid\", \"Artist Followers\": 1647262.0, \"Song ID\": \"31sSFHIe4NaxltVFOEIcTa\", \"Genre\": \"['alt z', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-06-17\", \"Weeks Charted\": \"2021-06-18--2021-06-25\", \"Popularity\": 80.0, \"Danceability\": 0.783, \"Energy\": 0.435, \"Loudness\": -7.78, \"Speechiness\": 0.0588, \"Acousticness\": 0.282, \"Liveness\": 0.0833, \"Tempo\": 106.974, \"Duration (ms)\": 210220.0, \"Valence\": 0.512, \"Chord\": \"G\"}, {\"Index\": 278, \"Highest Charting Position\": 112, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Petrouchka (feat. PLK)\", \"Streams\": 5511544, \"Artist\": \"Soso Maness\", \"Artist Followers\": 289437.0, \"Song ID\": \"03y045SZqaC94yfXl1cU4E\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais', 'rap marseille']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 79.0, \"Danceability\": 0.624, \"Energy\": 0.802, \"Loudness\": -4.818, \"Speechiness\": 0.311, \"Acousticness\": 0.0597, \"Liveness\": 0.252, \"Tempo\": 133.888, \"Duration (ms)\": 189933.0, \"Valence\": 0.818, \"Chord\": \"F#/Gb\"}, {\"Index\": 279, \"Highest Charting Position\": 11, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"p r i d e . i s . t h e . d e v i l (with Lil Baby)\", \"Streams\": 5430260, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5W8jRrZ6tWrTrqnKRtIQBf\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.861, \"Energy\": 0.656, \"Loudness\": -7.867, \"Speechiness\": 0.425, \"Acousticness\": 0.104, \"Liveness\": 0.0986, \"Tempo\": 88.967, \"Duration (ms)\": 218210.0, \"Valence\": 0.331, \"Chord\": \"E\"}, {\"Index\": 280, \"Highest Charting Position\": 6, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"m y . l i f e (with 21 Savage & Morray)\", \"Streams\": 5246577, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"1D3z6HTiQsNmZxjl7F7eoG\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.597, \"Energy\": 0.587, \"Loudness\": -7.026, \"Speechiness\": 0.137, \"Acousticness\": 0.0622, \"Liveness\": 0.214, \"Tempo\": 140.021, \"Duration (ms)\": 218802.0, \"Valence\": 0.0753, \"Chord\": \"G\"}, {\"Index\": 281, \"Highest Charting Position\": 96, \"Number of Times Charted\": 77, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Jocelyn Flores\", \"Streams\": 5220422, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29539807.0, \"Song ID\": \"7m9OqQk4RVRkw9JJdeAw96\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2017-08-25\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.872, \"Energy\": 0.391, \"Loudness\": -9.144, \"Speechiness\": 0.242, \"Acousticness\": 0.469, \"Liveness\": 0.297, \"Tempo\": 134.021, \"Duration (ms)\": 119133.0, \"Valence\": 0.437, \"Chord\": \"C\"}, {\"Index\": 282, \"Highest Charting Position\": 66, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"No Return (with The Kid LAROI & Lil Durk)\", \"Streams\": 5189427, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"23OYT3SFtoJqhiAUqktbc1\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 80.0, \"Danceability\": 0.479, \"Energy\": 0.645, \"Loudness\": -7.336, \"Speechiness\": 0.302, \"Acousticness\": 0.135, \"Liveness\": 0.0825, \"Tempo\": 155.057, \"Duration (ms)\": 168729.0, \"Valence\": 0.381, \"Chord\": \"F\"}, {\"Index\": 283, \"Highest Charting Position\": 1, \"Number of Times Charted\": 78, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"The Box\", \"Streams\": 5145099, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6603627.0, \"Song ID\": \"0nbXyq5TXYPCO7pr3N8S4I\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.896, \"Energy\": 0.586, \"Loudness\": -6.687, \"Speechiness\": 0.0559, \"Acousticness\": 0.104, \"Liveness\": 0.79, \"Tempo\": 116.971, \"Duration (ms)\": 196653.0, \"Valence\": 0.642, \"Chord\": \"A#/Bb\"}, {\"Index\": 284, \"Highest Charting Position\": 31, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Wellerman - Sea Shanty / 220 KID x Billen Ted Remix\", \"Streams\": 5124606, \"Artist\": \"Nathan Evans\", \"Artist Followers\": 140812.0, \"Song ID\": \"3iw6V4LH7yPj1ESORX9RIN\", \"Genre\": \"[]\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 83.0, \"Danceability\": 0.722, \"Energy\": 0.893, \"Loudness\": -3.255, \"Speechiness\": 0.0475, \"Acousticness\": 0.0441, \"Liveness\": 0.0673, \"Tempo\": 119.932, \"Duration (ms)\": 116750.0, \"Valence\": 0.439, \"Chord\": \"C\"}, {\"Index\": 285, \"Highest Charting Position\": 170, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Can't Hold Us - feat. Ray Dalton\", \"Streams\": 5085147, \"Artist\": \"Macklemore & Ryan Lewis\", \"Artist Followers\": 2562082.0, \"Song ID\": \"3bidbhpOYeV4knp8AIu8Xn\", \"Genre\": \"['modern rock', 'pop rap', 'seattle hip hop']\", \"Release Date\": \"2012-10-09\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.641, \"Energy\": 0.922, \"Loudness\": -4.457, \"Speechiness\": 0.0786, \"Acousticness\": 0.0291, \"Liveness\": 0.0862, \"Tempo\": 146.078, \"Duration (ms)\": 258343.0, \"Valence\": 0.847, \"Chord\": \"D\"}, {\"Index\": 286, \"Highest Charting Position\": 6, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Anyone\", \"Streams\": 5079587, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 1250353.0, \"Song ID\": \"2RwMwWo43LapkA4raptxaB\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-01-31--2020-02-07\", \"Popularity\": 0.0, \"Danceability\": 0.686, \"Energy\": 0.538, \"Loudness\": -8.026, \"Speechiness\": 0.0345, \"Acousticness\": 0.181, \"Liveness\": 0.113, \"Tempo\": 115.884, \"Duration (ms)\": 190779.0, \"Valence\": 0.584, \"Chord\": \"D\"}, {\"Index\": 287, \"Highest Charting Position\": 39, \"Number of Times Charted\": 45, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"my ex's best friend (with blackbear)\", \"Streams\": 5048079, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3864419.0, \"Song ID\": \"7kDUspsoYfLkWnZR7qwHZl\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 83.0, \"Danceability\": 0.731, \"Energy\": 0.675, \"Loudness\": -5.134, \"Speechiness\": 0.0434, \"Acousticness\": 0.00473, \"Liveness\": 0.141, \"Tempo\": 124.939, \"Duration (ms)\": 139461.0, \"Valence\": 0.298, \"Chord\": \"F\"}, {\"Index\": 288, \"Highest Charting Position\": 133, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Just the Way You Are\", \"Streams\": 5043647, \"Artist\": \"Bruno Mars\", \"Artist Followers\": 32574754.0, \"Song ID\": \"7BqBn9nzAq8spo5e7cZ0dJ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2010-10-05\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 80.0, \"Danceability\": 0.637, \"Energy\": 0.843, \"Loudness\": -5.413, \"Speechiness\": 0.0432, \"Acousticness\": 0.0151, \"Liveness\": 0.0876, \"Tempo\": 109.012, \"Duration (ms)\": 220733.0, \"Valence\": 0.434, \"Chord\": \"F\"}, {\"Index\": 289, \"Highest Charting Position\": 17, \"Number of Times Charted\": 78, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"HIGHEST IN THE ROOM\", \"Streams\": 4975720, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17719446.0, \"Song ID\": \"3eekarcy7kvN4yt5ZFzltW\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.598, \"Energy\": 0.427, \"Loudness\": -8.764, \"Speechiness\": 0.0317, \"Acousticness\": 0.0546, \"Liveness\": 0.21, \"Tempo\": 76.469, \"Duration (ms)\": 175721.0, \"Valence\": 0.0605, \"Chord\": \"G\"}, {\"Index\": 290, \"Highest Charting Position\": 7, \"Number of Times Charted\": 65, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Break My Heart\", \"Streams\": 4971176, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"017PF4Q3l4DBUiWoXk4OWT\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 80.0, \"Danceability\": 0.73, \"Energy\": 0.729, \"Loudness\": -3.434, \"Speechiness\": 0.0884, \"Acousticness\": 0.167, \"Liveness\": 0.349, \"Tempo\": 113.011, \"Duration (ms)\": 221820.0, \"Valence\": 0.467, \"Chord\": \"E\"}, {\"Index\": 291, \"Highest Charting Position\": 2, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Laugh Now Cry Later (feat. Lil Durk)\", \"Streams\": 4916860, \"Artist\": \"Drake\", \"Artist Followers\": 56308172.0, \"Song ID\": \"2SAqBLGA283SUiwJ3xOUVI\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 83.0, \"Danceability\": 0.761, \"Energy\": 0.518, \"Loudness\": -8.871, \"Speechiness\": 0.134, \"Acousticness\": 0.244, \"Liveness\": 0.107, \"Tempo\": 133.976, \"Duration (ms)\": 261493.0, \"Valence\": 0.522, \"Chord\": \"C\"}, {\"Index\": 292, \"Highest Charting Position\": 175, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"We Are The People (feat. Bono & The Edge) - Official UEFA EURO 2020 Song\", \"Streams\": 4912036, \"Artist\": \"Martin Garrix\", \"Artist Followers\": 14917926.0, \"Song ID\": \"2iL0W5qi0ivZ9WRXbZ74cS\", \"Genre\": \"['dance pop', 'dutch edm', 'edm', 'pop', 'pop dance', 'progressive house', 'tropical house']\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.66, \"Energy\": 0.733, \"Loudness\": -4.619, \"Speechiness\": 0.0359, \"Acousticness\": 0.248, \"Liveness\": 0.17, \"Tempo\": 119.933, \"Duration (ms)\": 217000.0, \"Valence\": 0.304, \"Chord\": \"C\"}, {\"Index\": 293, \"Highest Charting Position\": 23, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Ella No Es Tuya - Remix\", \"Streams\": 4911162, \"Artist\": \"Rochy RD, Myke Towers, Nicki Nicole\", \"Artist Followers\": 319192.0, \"Song ID\": \"5YYW3yRktprLRr47WK219Y\", \"Genre\": \"['dembow', 'dominican pop', 'rap dominicano', 'trap latino']\", \"Release Date\": \"2021-02-03\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 82.0, \"Danceability\": 0.585, \"Energy\": 0.611, \"Loudness\": -4.132, \"Speechiness\": 0.288, \"Acousticness\": 0.39, \"Liveness\": 0.649, \"Tempo\": 97.041, \"Duration (ms)\": 218107.0, \"Valence\": 0.962, \"Chord\": \"F#/Gb\"}, {\"Index\": 294, \"Highest Charting Position\": 176, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"In the End\", \"Streams\": 4910070, \"Artist\": \"Linkin Park\", \"Artist Followers\": 19584111.0, \"Song ID\": \"60a0Rd6pjrkxjPbaKzXjfq\", \"Genre\": \"['alternative metal', 'nu metal', 'post-grunge', 'rap metal']\", \"Release Date\": \"2000-10-24\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-03-19--2021-03-26\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 83.0, \"Danceability\": 0.556, \"Energy\": 0.864, \"Loudness\": -5.87, \"Speechiness\": 0.0584, \"Acousticness\": 0.00958, \"Liveness\": 0.209, \"Tempo\": 105.143, \"Duration (ms)\": 216880.0, \"Valence\": 0.4, \"Chord\": \"D#/Eb\"}, {\"Index\": 295, \"Highest Charting Position\": 119, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"No Role Modelz\", \"Streams\": 4904401, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"62vpWI1CHwFy7tMIcSStl8\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2014-12-09\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 84.0, \"Danceability\": 0.692, \"Energy\": 0.521, \"Loudness\": -8.465, \"Speechiness\": 0.33, \"Acousticness\": 0.301, \"Liveness\": 0.0565, \"Tempo\": 100.45, \"Duration (ms)\": 292987.0, \"Valence\": 0.463, \"Chord\": \"A#/Bb\"}, {\"Index\": 296, \"Highest Charting Position\": 7, \"Number of Times Charted\": 74, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"SICKO MODE\", \"Streams\": 4898977, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17719446.0, \"Song ID\": \"2xLMifQCjDGFmkHkpNLD9h\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2018-08-03\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.834, \"Energy\": 0.73, \"Loudness\": -3.714, \"Speechiness\": 0.222, \"Acousticness\": 0.00513, \"Liveness\": 0.124, \"Tempo\": 155.008, \"Duration (ms)\": 312820.0, \"Valence\": 0.446, \"Chord\": \"G#/Ab\"}, {\"Index\": 297, \"Highest Charting Position\": 161, \"Number of Times Charted\": 41, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Something Just Like This\", \"Streams\": 4862683, \"Artist\": \"The Chainsmokers, Coldplay\", \"Artist Followers\": 18191658.0, \"Song ID\": \"6RUKPb4LETWmmr3iAEQktW\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2017-04-07\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-02-26--2021-03-05\\n2021-01-01--2021-01-08\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.617, \"Energy\": 0.635, \"Loudness\": -6.769, \"Speechiness\": 0.0317, \"Acousticness\": 0.0498, \"Liveness\": 0.164, \"Tempo\": 103.019, \"Duration (ms)\": 247160.0, \"Valence\": 0.446, \"Chord\": \"B\"}, {\"Index\": 298, \"Highest Charting Position\": 84, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"You\", \"Streams\": 4846549, \"Artist\": \"Regard, Troye Sivan, Tate McRae\", \"Artist Followers\": 152226.0, \"Song ID\": \"2cc8Sw1OnCuA5bV8nqWqpE\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop edm', 'slap house', 'tropical house']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 83.0, \"Danceability\": 0.691, \"Energy\": 0.695, \"Loudness\": -5.6, \"Speechiness\": 0.0367, \"Acousticness\": 0.0592, \"Liveness\": 0.0647, \"Tempo\": 106.064, \"Duration (ms)\": 233386.0, \"Valence\": 0.514, \"Chord\": \"C\"}, {\"Index\": 299, \"Highest Charting Position\": 84, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Straightenin\", \"Streams\": 7615531, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"3X2r2CnHOJeV5YekPTgBnK\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 77.0, \"Danceability\": 0.847, \"Energy\": 0.629, \"Loudness\": -5.81, \"Speechiness\": 0.102, \"Acousticness\": 0.0318, \"Liveness\": 0.152, \"Tempo\": 135.976, \"Duration (ms)\": 255532.0, \"Valence\": 0.109, \"Chord\": \"A\"}, {\"Index\": 300, \"Highest Charting Position\": 71, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"GANG GANG (with Lil Wayne)\", \"Streams\": 7506580, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"4VW44pawoOHPUjlN7DX5vk\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 78.0, \"Danceability\": 0.752, \"Energy\": 0.563, \"Loudness\": -8.066, \"Speechiness\": 0.209, \"Acousticness\": 0.146, \"Liveness\": 0.103, \"Tempo\": 145.05, \"Duration (ms)\": 178776.0, \"Valence\": 0.551, \"Chord\": \"D#/Eb\"}, {\"Index\": 301, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Black Hearted\", \"Streams\": 6989528, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"25qk9xa71F1POdI4vj7rbi\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 75.0, \"Danceability\": 0.506, \"Energy\": 0.563, \"Loudness\": -7.664, \"Speechiness\": 0.411, \"Acousticness\": 0.0326, \"Liveness\": 0.0856, \"Tempo\": 168.146, \"Duration (ms)\": 190509.0, \"Valence\": 0.153, \"Chord\": \"C#/Db\"}, {\"Index\": 302, \"Highest Charting Position\": 124, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Lost\", \"Streams\": 6410263, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32262679.0, \"Song ID\": \"18XlJEroUwFo0tLZxscgXE\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 79.0, \"Danceability\": 0.766, \"Energy\": 0.706, \"Loudness\": -6.553, \"Speechiness\": 0.16, \"Acousticness\": 0.223, \"Liveness\": 0.064, \"Tempo\": 142.989, \"Duration (ms)\": 172598.0, \"Valence\": 0.766, \"Chord\": \"G\"}, {\"Index\": 303, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Avalanche\", \"Streams\": 6323268, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"4KD0lLJ4OGonZhBeKtct9I\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 71.0, \"Danceability\": 0.917, \"Energy\": 0.623, \"Loudness\": -8.231, \"Speechiness\": 0.135, \"Acousticness\": 0.0985, \"Liveness\": 0.0833, \"Tempo\": 126.063, \"Duration (ms)\": 206272.0, \"Valence\": 0.687, \"Chord\": \"C#/Db\"}, {\"Index\": 304, \"Highest Charting Position\": 59, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"My Head & My Heart\", \"Streams\": 5470147, \"Artist\": \"Ava Max\", \"Artist Followers\": 3911473.0, \"Song ID\": \"1KixkQVDUHggZMU9dUobgm\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 83.0, \"Danceability\": 0.614, \"Energy\": 0.934, \"Loudness\": -3.709, \"Speechiness\": 0.07, \"Acousticness\": 0.0697, \"Liveness\": 0.121, \"Tempo\": 116.001, \"Duration (ms)\": 174760.0, \"Valence\": 0.436, \"Chord\": \"A\"}, {\"Index\": 305, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Malibu (feat. Polo G)\", \"Streams\": 5456648, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"3v1zVVdzNVNt7vmI9VG2gq\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 72.0, \"Danceability\": 0.831, \"Energy\": 0.719, \"Loudness\": -6.836, \"Speechiness\": 0.235, \"Acousticness\": 0.514, \"Liveness\": 0.0675, \"Tempo\": 155.038, \"Duration (ms)\": 248652.0, \"Valence\": 0.859, \"Chord\": \"A#/Bb\"}, {\"Index\": 306, \"Highest Charting Position\": 36, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"GIRL LIKE ME\", \"Streams\": 5395181, \"Artist\": \"Black Eyed Peas, Shakira\", \"Artist Followers\": 5963840.0, \"Song ID\": \"1zLBsSVxETQOfINOLYvT5m\", \"Genre\": \"['dance pop', 'pop', 'pop rap']\", \"Release Date\": \"2020-11-02\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\", \"Popularity\": 82.0, \"Danceability\": 0.965, \"Energy\": 0.485, \"Loudness\": -8.784, \"Speechiness\": 0.191, \"Acousticness\": 0.0206, \"Liveness\": 0.0655, \"Tempo\": 124.025, \"Duration (ms)\": 222523.0, \"Valence\": 0.312, \"Chord\": \"D\"}, {\"Index\": 307, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Clueless (with Pop Smoke & Fivio Foreign)\", \"Streams\": 5335308, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"4CPcZHzSvIBM8AKhdHUwnL\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 74.0, \"Danceability\": 0.734, \"Energy\": 0.712, \"Loudness\": -6.217, \"Speechiness\": 0.201, \"Acousticness\": 0.391, \"Liveness\": 0.103, \"Tempo\": 140.369, \"Duration (ms)\": 165405.0, \"Valence\": 0.674, \"Chord\": \"F#/Gb\"}, {\"Index\": 308, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Modern Day\", \"Streams\": 5322745, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"2Igem6Q4sfvXGJ3JkG7Baw\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 78.0, \"Danceability\": 0.87, \"Energy\": 0.629, \"Loudness\": -7.598, \"Speechiness\": 0.279, \"Acousticness\": 0.173, \"Liveness\": 0.101, \"Tempo\": 134.944, \"Duration (ms)\": 241790.0, \"Valence\": 0.512, \"Chord\": \"B\"}, {\"Index\": 309, \"Highest Charting Position\": 2, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Therefore I Am\", \"Streams\": 5265630, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"0aACcc1jEv2C6VSmmJbllJ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 0.0, \"Danceability\": 0.889, \"Energy\": 0.34, \"Loudness\": -7.773, \"Speechiness\": 0.0697, \"Acousticness\": 0.218, \"Liveness\": 0.055, \"Tempo\": 94.009, \"Duration (ms)\": 174321.0, \"Valence\": 0.716, \"Chord\": \"B\"}, {\"Index\": 310, \"Highest Charting Position\": 12, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"TE MUDASTE\", \"Streams\": 5242347, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36142273.0, \"Song ID\": \"5RubKOuDoPn5Kj5TLVxSxY\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 82.0, \"Danceability\": 0.811, \"Energy\": 0.637, \"Loudness\": -4.835, \"Speechiness\": 0.0591, \"Acousticness\": 0.234, \"Liveness\": 0.118, \"Tempo\": 92.025, \"Duration (ms)\": 130014.0, \"Valence\": 0.471, \"Chord\": \"A#/Bb\"}, {\"Index\": 311, \"Highest Charting Position\": 108, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Tipo Gin - Ao Vivo\", \"Streams\": 5155238, \"Artist\": \"MC Kevin o Chris\", \"Artist Followers\": 2753929.0, \"Song ID\": \"4llr8mcoauwrHBtjGb7F9S\", \"Genre\": \"['funk 150 bpm', 'funk carioca']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 81.0, \"Danceability\": 0.75, \"Energy\": 0.668, \"Loudness\": -4.49, \"Speechiness\": 0.061, \"Acousticness\": 0.78, \"Liveness\": 0.338, \"Tempo\": 94.998, \"Duration (ms)\": 159147.0, \"Valence\": 0.786, \"Chord\": \"C\"}, {\"Index\": 312, \"Highest Charting Position\": 39, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Higher Power\", \"Streams\": 5142982, \"Artist\": \"Coldplay\", \"Artist Followers\": 1250353.0, \"Song ID\": \"4rOEoKL0fHrxBMhVljpbGW\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 0.0, \"Danceability\": 0.507, \"Energy\": 0.828, \"Loudness\": -6.023, \"Speechiness\": 0.0449, \"Acousticness\": 0.00711, \"Liveness\": 0.261, \"Tempo\": 178.032, \"Duration (ms)\": 211295.0, \"Valence\": 0.489, \"Chord\": \"A#/Bb\"}, {\"Index\": 313, \"Highest Charting Position\": 54, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"SUN GOES DOWN\", \"Streams\": 5125477, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5473565.0, \"Song ID\": \"34eF4BoV8FPk0uhAAoqU7h\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 80.0, \"Danceability\": 0.551, \"Energy\": 0.636, \"Loudness\": -6.798, \"Speechiness\": 0.054, \"Acousticness\": 0.0837, \"Liveness\": 0.112, \"Tempo\": 174.065, \"Duration (ms)\": 168276.0, \"Valence\": 0.148, \"Chord\": \"D\"}, {\"Index\": 314, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Painting Pictures\", \"Streams\": 5119845, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"25uBGaikHi0DhMiGMfuXYE\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 72.0, \"Danceability\": 0.522, \"Energy\": 0.466, \"Loudness\": -8.05, \"Speechiness\": 0.458, \"Acousticness\": 0.331, \"Liveness\": 0.11, \"Tempo\": 78.43, \"Duration (ms)\": 137692.0, \"Valence\": 0.459, \"Chord\": \"D#/Eb\"}, {\"Index\": 315, \"Highest Charting Position\": 1, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Rain On Me (with Ariana Grande)\", \"Streams\": 5041656, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18572085.0, \"Song ID\": \"24ySl2hOPGCDcxBxFIqWBu\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 79.0, \"Danceability\": 0.672, \"Energy\": 0.855, \"Loudness\": -3.764, \"Speechiness\": 0.0397, \"Acousticness\": 0.021, \"Liveness\": 0.323, \"Tempo\": 123.056, \"Duration (ms)\": 182200.0, \"Valence\": 0.646, \"Chord\": \"A\"}, {\"Index\": 316, \"Highest Charting Position\": 97, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Hats Off (feat. Travis Scott)\", \"Streams\": 7324233, \"Artist\": \"Lil Baby, Lil Durk\", \"Artist Followers\": 7805880.0, \"Song ID\": \"4lUmnwRybYH7mMzf16xB0y\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-06-04--2021-06-11\", \"Popularity\": 81.0, \"Danceability\": 0.596, \"Energy\": 0.65, \"Loudness\": -5.167, \"Speechiness\": 0.337, \"Acousticness\": 0.138, \"Liveness\": 0.14, \"Tempo\": 133.997, \"Duration (ms)\": 257428.0, \"Valence\": 0.188, \"Chord\": \"A\"}, {\"Index\": 317, \"Highest Charting Position\": 117, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Last Train Home\", \"Streams\": 6439718, \"Artist\": \"John Mayer\", \"Artist Followers\": 5178156.0, \"Song ID\": \"0tgBtQ0ISnMQOKorrN9HLX\", \"Genre\": \"['neo mellow', 'pop rock', 'singer-songwriter']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-06-04--2021-06-11\", \"Popularity\": 75.0, \"Danceability\": 0.591, \"Energy\": 0.831, \"Loudness\": -6.612, \"Speechiness\": 0.0355, \"Acousticness\": 0.235, \"Liveness\": 0.0571, \"Tempo\": 93.007, \"Duration (ms)\": 187307.0, \"Valence\": 0.678, \"Chord\": \"E\"}, {\"Index\": 318, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Voice of the Heroes\", \"Streams\": 6249801, \"Artist\": \"Lil Baby, Lil Durk\", \"Artist Followers\": 7805880.0, \"Song ID\": \"4lUmnwRybYH7mMzf16xB0y\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-06-04--2021-06-11\", \"Popularity\": 81.0, \"Danceability\": 0.596, \"Energy\": 0.65, \"Loudness\": -5.167, \"Speechiness\": 0.337, \"Acousticness\": 0.138, \"Liveness\": 0.14, \"Tempo\": 133.997, \"Duration (ms)\": 257428.0, \"Valence\": 0.188, \"Chord\": \"A\"}, {\"Index\": 319, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"0X1=LOVESONG (I Know I Love you)\", \"Streams\": 6040553, \"Artist\": \"TOMORROW X TOGETHER, Seori\", \"Artist Followers\": 4136553.0, \"Song ID\": \"1Z8TPHiKeCUyClxV6WTTIf\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-05-31\", \"Weeks Charted\": \"2021-06-04--2021-06-11\", \"Popularity\": 81.0, \"Danceability\": 0.584, \"Energy\": 0.836, \"Loudness\": -4.925, \"Speechiness\": 0.079, \"Acousticness\": 0.0558, \"Liveness\": 0.0663, \"Tempo\": 104.973, \"Duration (ms)\": 202204.0, \"Valence\": 0.484, \"Chord\": \"C\"}, {\"Index\": 320, \"Highest Charting Position\": 10, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"a m a r i\", \"Streams\": 5645966, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"2cnKST6T9qUo2i907lm8zX\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 79.0, \"Danceability\": 0.725, \"Energy\": 0.713, \"Loudness\": -6.173, \"Speechiness\": 0.187, \"Acousticness\": 0.127, \"Liveness\": 0.617, \"Tempo\": 65.988, \"Duration (ms)\": 148421.0, \"Valence\": 0.207, \"Chord\": \"E\"}, {\"Index\": 321, \"Highest Charting Position\": 72, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"NEVER LEFT\", \"Streams\": 5552212, \"Artist\": \"Lil Tecca\", \"Artist Followers\": 4016497.0, \"Song ID\": \"21UkXrc9kD48rNpTMI2ecz\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2021-05-06\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 82.0, \"Danceability\": 0.807, \"Energy\": 0.659, \"Loudness\": -6.92, \"Speechiness\": 0.332, \"Acousticness\": 0.0224, \"Liveness\": 0.309, \"Tempo\": 82.465, \"Duration (ms)\": 168727.0, \"Valence\": 0.438, \"Chord\": \"B\"}, {\"Index\": 322, \"Highest Charting Position\": 27, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Solid (feat. Drake)\", \"Streams\": 5347781, \"Artist\": \"Young Stoner Life, Young Thug, Gunna\", \"Artist Followers\": 61930.0, \"Song ID\": \"6rTInqW3YECMkQsBEHw4sd\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 82.0, \"Danceability\": 0.887, \"Energy\": 0.485, \"Loudness\": -9.358, \"Speechiness\": 0.2, \"Acousticness\": 0.0392, \"Liveness\": 0.141, \"Tempo\": 125.987, \"Duration (ms)\": 215693.0, \"Valence\": 0.328, \"Chord\": \"B\"}, {\"Index\": 323, \"Highest Charting Position\": 21, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"La Nota\", \"Streams\": 5300884, \"Artist\": \"Manuel Turizo, Rauw Alejandro, Myke Towers\", \"Artist Followers\": 7904381.0, \"Song ID\": \"7ndTONDDRFGiPnnhOzOXxq\", \"Genre\": \"['colombian pop', 'latin', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2020-10-08\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 79.0, \"Danceability\": 0.736, \"Energy\": 0.632, \"Loudness\": -4.939, \"Speechiness\": 0.0648, \"Acousticness\": 0.18, \"Liveness\": 0.349, \"Tempo\": 92.03, \"Duration (ms)\": 216107.0, \"Valence\": 0.503, \"Chord\": \"B\"}, {\"Index\": 324, \"Highest Charting Position\": 47, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Golden\", \"Streams\": 5298893, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16112621.0, \"Song ID\": \"45S5WTQEGOB1VHr1Q4FuPl\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 83.0, \"Danceability\": 0.448, \"Energy\": 0.838, \"Loudness\": -5.257, \"Speechiness\": 0.0557, \"Acousticness\": 0.21, \"Liveness\": 0.131, \"Tempo\": 139.863, \"Duration (ms)\": 208907.0, \"Valence\": 0.254, \"Chord\": \"E\"}, {\"Index\": 325, \"Highest Charting Position\": 127, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"CORALINE\", \"Streams\": 5241813, \"Artist\": \"M\\u00e5neskin\", \"Artist Followers\": 3377762.0, \"Song ID\": \"7HMz8o0m7ASQ3ImFPfhWTY\", \"Genre\": \"['indie rock italiano', 'italian pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\", \"Popularity\": 81.0, \"Danceability\": 0.363, \"Energy\": 0.678, \"Loudness\": -4.939, \"Speechiness\": 0.0995, \"Acousticness\": 0.0299, \"Liveness\": 0.324, \"Tempo\": 162.124, \"Duration (ms)\": 300413.0, \"Valence\": 0.321, \"Chord\": \"D\"}, {\"Index\": 326, \"Highest Charting Position\": 3, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"BICHOTA\", \"Streams\": 5201714, \"Artist\": \"KAROL G\", \"Artist Followers\": 1250353.0, \"Song ID\": \"4nYLZSNXJyPq8Jj3cEdykP\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 0.0, \"Danceability\": 0.863, \"Energy\": 0.666, \"Loudness\": -4.158, \"Speechiness\": 0.152, \"Acousticness\": 0.212, \"Liveness\": 0.103, \"Tempo\": 163.908, \"Duration (ms)\": 178947.0, \"Valence\": 0.838, \"Chord\": \"C#/Db\"}, {\"Index\": 327, \"Highest Charting Position\": 96, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Slumber Party (feat. Princess Nokia)\", \"Streams\": 5113574, \"Artist\": \"Ashnikko\", \"Artist Followers\": 1246335.0, \"Song ID\": \"11ZulcYY4lowvcQm4oe3VJ\", \"Genre\": \"['electropop', 'escape room', 'pop']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 82.0, \"Danceability\": 0.964, \"Energy\": 0.398, \"Loudness\": -8.981, \"Speechiness\": 0.0795, \"Acousticness\": 0.00151, \"Liveness\": 0.101, \"Tempo\": 105.012, \"Duration (ms)\": 178405.0, \"Valence\": 0.563, \"Chord\": \"B\"}, {\"Index\": 328, \"Highest Charting Position\": 170, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Killer (feat. Jack Harlow & Cordae) - Remix\", \"Streams\": 5404939, \"Artist\": \"Eminem\", \"Artist Followers\": 46785561.0, \"Song ID\": \"7zl7kehxesNEo2pYkKXTSe\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-05-28--2021-06-04\", \"Popularity\": 76.0, \"Danceability\": 0.924, \"Energy\": 0.73, \"Loudness\": -6.125, \"Speechiness\": 0.274, \"Acousticness\": 0.0525, \"Liveness\": 0.113, \"Tempo\": 99.01, \"Duration (ms)\": 236666.0, \"Valence\": 0.848, \"Chord\": \"B\"}, {\"Index\": 329, \"Highest Charting Position\": 105, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Liberdade (Quando o Grave Bate Forte)\", \"Streams\": 5378350, \"Artist\": \"Alok, Mc Don Juan, Dj GBR\", \"Artist Followers\": 10334543.0, \"Song ID\": \"2QLbRVzixE282JSQjBz2DG\", \"Genre\": \"['electro house', 'pop nacional', 'slap house']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 80.0, \"Danceability\": 0.81, \"Energy\": 0.789, \"Loudness\": -4.032, \"Speechiness\": 0.0498, \"Acousticness\": 0.0254, \"Liveness\": 0.104, \"Tempo\": 129.988, \"Duration (ms)\": 150462.0, \"Valence\": 0.432, \"Chord\": \"F#/Gb\"}, {\"Index\": 330, \"Highest Charting Position\": 108, \"Number of Times Charted\": 51, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"All Girls Are The Same\", \"Streams\": 5372180, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"4VXIryQMWpIdGgYR4TrjT1\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2018-12-10\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-08--2020-05-15\\n2020-04-24--2020-05-01\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.671, \"Energy\": 0.529, \"Loudness\": -7.226, \"Speechiness\": 0.307, \"Acousticness\": 0.0769, \"Liveness\": 0.0856, \"Tempo\": 161.989, \"Duration (ms)\": 165820.0, \"Valence\": 0.203, \"Chord\": \"C\"}, {\"Index\": 331, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"734\", \"Streams\": 5368759, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"6vB8bdQCCTDDIH8fhRfuXA\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-05-28--2021-06-04\", \"Popularity\": 75.0, \"Danceability\": 0.663, \"Energy\": 0.545, \"Loudness\": -3.93, \"Speechiness\": 0.036, \"Acousticness\": 0.123, \"Liveness\": 0.106, \"Tempo\": 78.452, \"Duration (ms)\": 196147.0, \"Valence\": 0.344, \"Chord\": \"D\"}, {\"Index\": 332, \"Highest Charting Position\": 85, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Boy With Luv (feat. Halsey)\", \"Streams\": 5266625, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"5KawlOMHjWeUjQtnuRs22c\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2019-04-12\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2020-11-20--2020-11-27\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-01-17--2020-01-24\", \"Popularity\": 82.0, \"Danceability\": 0.645, \"Energy\": 0.862, \"Loudness\": -4.757, \"Speechiness\": 0.0965, \"Acousticness\": 0.0923, \"Liveness\": 0.192, \"Tempo\": 119.991, \"Duration (ms)\": 229773.0, \"Valence\": 0.798, \"Chord\": \"B\"}, {\"Index\": 333, \"Highest Charting Position\": 82, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Disco Arranhado - Funk Remix\", \"Streams\": 5207186, \"Artist\": \"Malu, DJ Lucas Beat\", \"Artist Followers\": 74814.0, \"Song ID\": \"2Gjt4rUHBUH0rMKpBg0hF4\", \"Genre\": \"[]\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 80.0, \"Danceability\": 0.747, \"Energy\": 0.725, \"Loudness\": -2.564, \"Speechiness\": 0.363, \"Acousticness\": 0.551, \"Liveness\": 0.0626, \"Tempo\": 129.96, \"Duration (ms)\": 125558.0, \"Valence\": 0.904, \"Chord\": \"D\"}, {\"Index\": 334, \"Highest Charting Position\": 4, \"Number of Times Charted\": 70, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Godzilla (feat. Juice WRLD)\", \"Streams\": 5143522, \"Artist\": \"Eminem\", \"Artist Followers\": 46785561.0, \"Song ID\": \"7FIWs0pqAYbP91WWM0vlTQ\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 83.0, \"Danceability\": 0.808, \"Energy\": 0.745, \"Loudness\": -5.26, \"Speechiness\": 0.342, \"Acousticness\": 0.145, \"Liveness\": 0.292, \"Tempo\": 165.995, \"Duration (ms)\": 210800.0, \"Valence\": 0.829, \"Chord\": \"A#/Bb\"}, {\"Index\": 335, \"Highest Charting Position\": 8, \"Number of Times Charted\": 68, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Blueberry Faygo\", \"Streams\": 5085511, \"Artist\": \"Lil Mosey\", \"Artist Followers\": 3816446.0, \"Song ID\": \"6wJYhPfqk3KGhHRG76WzOh\", \"Genre\": \"['melodic rap', 'rap', 'rap conscient', 'trap', 'vapor trap']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 79.0, \"Danceability\": 0.774, \"Energy\": 0.554, \"Loudness\": -7.909, \"Speechiness\": 0.0383, \"Acousticness\": 0.207, \"Liveness\": 0.132, \"Tempo\": 99.034, \"Duration (ms)\": 162547.0, \"Valence\": 0.349, \"Chord\": \"C\"}, {\"Index\": 336, \"Highest Charting Position\": 129, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Somebody That I Used To Know\", \"Streams\": 5068972, \"Artist\": \"Gotye, Kimbra\", \"Artist Followers\": 2263960.0, \"Song ID\": \"4wCmqSrbyCgxEXROQE6vtV\", \"Genre\": \"['australian pop']\", \"Release Date\": \"2011-01-01\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 76.0, \"Danceability\": 0.864, \"Energy\": 0.495, \"Loudness\": -7.036, \"Speechiness\": 0.037, \"Acousticness\": 0.591, \"Liveness\": 0.0992, \"Tempo\": 129.062, \"Duration (ms)\": 244973.0, \"Valence\": 0.72, \"Chord\": \"C\"}, {\"Index\": 337, \"Highest Charting Position\": 4, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Holy (feat. Chance The Rapper)\", \"Streams\": 5063015, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48504126.0, \"Song ID\": \"5u1n1kITHCxxp8twBcZxWy\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 81.0, \"Danceability\": 0.673, \"Energy\": 0.704, \"Loudness\": -8.056, \"Speechiness\": 0.36, \"Acousticness\": 0.196, \"Liveness\": 0.0898, \"Tempo\": 86.919, \"Duration (ms)\": 212093.0, \"Valence\": 0.372, \"Chord\": \"F#/Gb\"}, {\"Index\": 338, \"Highest Charting Position\": 200, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Vida Louca\", \"Streams\": 5051514, \"Artist\": \"Mc Poze do Rodo, Neo Beats, Mainstreet\", \"Artist Followers\": 448447.0, \"Song ID\": \"7IG7laqVpcvIIULrwWP5SA\", \"Genre\": \"['funk carioca', 'funk ostentacao']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-05-28--2021-06-04\", \"Popularity\": 82.0, \"Danceability\": 0.852, \"Energy\": 0.62, \"Loudness\": -5.79, \"Speechiness\": 0.227, \"Acousticness\": 0.359, \"Liveness\": 0.101, \"Tempo\": 92.464, \"Duration (ms)\": 155676.0, \"Valence\": 0.744, \"Chord\": \"F#/Gb\"}, {\"Index\": 339, \"Highest Charting Position\": 15, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"i n t e r l u d e\", \"Streams\": 7880155, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"08LwMWf5Tcfsd752EPzFV0\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 76.0, \"Danceability\": 0.77, \"Energy\": 0.574, \"Loudness\": -5.525, \"Speechiness\": 0.106, \"Acousticness\": 0.0617, \"Liveness\": 0.104, \"Tempo\": 98.962, \"Duration (ms)\": 133022.0, \"Valence\": 0.104, \"Chord\": \"C#/Db\"}, {\"Index\": 340, \"Highest Charting Position\": 95, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Butter (Instrumental)\", \"Streams\": 7450126, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"2Ol2sv6gePRdJrZC1hDVNY\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 70.0, \"Danceability\": 0.429, \"Energy\": 0.387, \"Loudness\": -7.486, \"Speechiness\": 0.0753, \"Acousticness\": 0.000178, \"Liveness\": 0.142, \"Tempo\": 109.893, \"Duration (ms)\": 162147.0, \"Valence\": 0.41, \"Chord\": \"C#/Db\"}, {\"Index\": 341, \"Highest Charting Position\": 25, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Film out\", \"Streams\": 7198095, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"3UHPGOkUcE4hE7sqBF4Snt\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-04-01\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 81.0, \"Danceability\": 0.499, \"Energy\": 0.709, \"Loudness\": -6.404, \"Speechiness\": 0.134, \"Acousticness\": 0.296, \"Liveness\": 0.331, \"Tempo\": 164.032, \"Duration (ms)\": 214621.0, \"Valence\": 0.314, \"Chord\": \"A#/Bb\"}, {\"Index\": 342, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Voil\\u00e0\", \"Streams\": 6935400, \"Artist\": \"Barbara Pravi\", \"Artist Followers\": 75496.0, \"Song ID\": \"1uAOCTevGnyKIDbgZdOCnE\", \"Genre\": \"['eurovision', 'nouvelle chanson francaise']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 72.0, \"Danceability\": 0.447, \"Energy\": 0.337, \"Loudness\": -8.665, \"Speechiness\": 0.0631, \"Acousticness\": 0.773, \"Liveness\": 0.298, \"Tempo\": 135.379, \"Duration (ms)\": 176816.0, \"Valence\": 0.603, \"Chord\": \"D\"}, {\"Index\": 343, \"Highest Charting Position\": 53, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Shy Away\", \"Streams\": 6634722, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20823062.0, \"Song ID\": \"2nG54Y4a3sH9YpfxMolOyi\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 77.0, \"Danceability\": 0.588, \"Energy\": 0.856, \"Loudness\": -5.242, \"Speechiness\": 0.0316, \"Acousticness\": 0.000818, \"Liveness\": 0.238, \"Tempo\": 96.966, \"Duration (ms)\": 175044.0, \"Valence\": 0.635, \"Chord\": \"A\"}, {\"Index\": 344, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Saturday\", \"Streams\": 6628638, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20823062.0, \"Song ID\": \"60dwJ8dnqZ4WrIdiu7LkNR\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 75.0, \"Danceability\": 0.687, \"Energy\": 0.89, \"Loudness\": -5.99, \"Speechiness\": 0.0344, \"Acousticness\": 0.00396, \"Liveness\": 0.0436, \"Tempo\": 113.06, \"Duration (ms)\": 172232.0, \"Valence\": 0.854, \"Chord\": \"G#/Ab\"}, {\"Index\": 345, \"Highest Charting Position\": 18, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"9 5 . s o u t h\", \"Streams\": 6333126, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5R691ipUYRDYW6ehapjoj6\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 75.0, \"Danceability\": 0.713, \"Energy\": 0.793, \"Loudness\": -5.277, \"Speechiness\": 0.397, \"Acousticness\": 0.271, \"Liveness\": 0.727, \"Tempo\": 71.724, \"Duration (ms)\": 196946.0, \"Valence\": 0.203, \"Chord\": \"D\"}, {\"Index\": 346, \"Highest Charting Position\": 67, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Seeing Green (with Drake & Lil Wayne)\", \"Streams\": 6299936, \"Artist\": \"Nicki Minaj\", \"Artist Followers\": 22161310.0, \"Song ID\": \"1TZv3bujNaYz646eezRE91\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'pop rap', 'post-teen pop', 'queens hip hop']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 77.0, \"Danceability\": 0.573, \"Energy\": 0.867, \"Loudness\": -2.876, \"Speechiness\": 0.168, \"Acousticness\": 0.0853, \"Liveness\": 0.38, \"Tempo\": 74.861, \"Duration (ms)\": 339506.0, \"Valence\": 0.231, \"Chord\": \"F\"}, {\"Index\": 347, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Dark Side\", \"Streams\": 6277641, \"Artist\": \"Blind Channel\", \"Artist Followers\": 121225.0, \"Song ID\": \"1ovFnZv6mUe0LzAbfVqOmh\", \"Genre\": \"['eurovision', 'oulu metal', 'trancecore']\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 72.0, \"Danceability\": 0.571, \"Energy\": 0.955, \"Loudness\": -3.795, \"Speechiness\": 0.105, \"Acousticness\": 0.00254, \"Liveness\": 0.274, \"Tempo\": 98.01, \"Duration (ms)\": 177790.0, \"Valence\": 0.437, \"Chord\": \"G\"}, {\"Index\": 348, \"Highest Charting Position\": 137, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"SHUM\", \"Streams\": 6237019, \"Artist\": \"Go_A\", \"Artist Followers\": 107553.0, \"Song ID\": \"7mEDVrAHDnQJStDo8jKJJm\", \"Genre\": \"['eurovision']\", \"Release Date\": \"2021-03-10\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 75.0, \"Danceability\": 0.527, \"Energy\": 0.737, \"Loudness\": -5.34, \"Speechiness\": 0.0642, \"Acousticness\": 0.05, \"Liveness\": 0.105, \"Tempo\": 116.431, \"Duration (ms)\": 172675.0, \"Valence\": 0.499, \"Chord\": \"E\"}, {\"Index\": 349, \"Highest Charting Position\": 69, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"In the morning\", \"Streams\": 5738325, \"Artist\": \"ITZY\", \"Artist Followers\": 2379448.0, \"Song ID\": \"2QdH0rKlV3d9Y6lWzcnlBH\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 79.0, \"Danceability\": 0.847, \"Energy\": 0.814, \"Loudness\": -4.668, \"Speechiness\": 0.152, \"Acousticness\": 0.0825, \"Liveness\": 0.0948, \"Tempo\": 140.057, \"Duration (ms)\": 172359.0, \"Valence\": 0.711, \"Chord\": \"B\"}, {\"Index\": 350, \"Highest Charting Position\": 27, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"l e t . g o . m y . h a n d (with Bas & 6LACK)\", \"Streams\": 5393643, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"0GAyuCo975IHGxxiLKDufB\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 73.0, \"Danceability\": 0.583, \"Energy\": 0.625, \"Loudness\": -8.011, \"Speechiness\": 0.277, \"Acousticness\": 0.506, \"Liveness\": 0.196, \"Tempo\": 89.812, \"Duration (ms)\": 266291.0, \"Valence\": 0.516, \"Chord\": \"C#/Db\"}, {\"Index\": 351, \"Highest Charting Position\": 2, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"What\\u2019s Next\", \"Streams\": 5335112, \"Artist\": \"Drake\", \"Artist Followers\": 56308172.0, \"Song ID\": \"3aQem4jVGdhtg116TmJnHz\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 81.0, \"Danceability\": 0.781, \"Energy\": 0.594, \"Loudness\": -6.959, \"Speechiness\": 0.0485, \"Acousticness\": 0.0136, \"Liveness\": 0.162, \"Tempo\": 129.895, \"Duration (ms)\": 178154.0, \"Valence\": 0.0628, \"Chord\": \"C\"}, {\"Index\": 352, \"Highest Charting Position\": 154, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Ramen & OJ\", \"Streams\": 5282702, \"Artist\": \"Joyner Lucas, Lil Baby\", \"Artist Followers\": 1725025.0, \"Song ID\": \"4TIqzdAssasqx3DAe6cG9J\", \"Genre\": \"['boston hip hop', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 81.0, \"Danceability\": 0.597, \"Energy\": 0.571, \"Loudness\": -6.205, \"Speechiness\": 0.293, \"Acousticness\": 0.492, \"Liveness\": 0.093, \"Tempo\": 106.196, \"Duration (ms)\": 218448.0, \"Valence\": 0.165, \"Chord\": \"C#/Db\"}, {\"Index\": 353, \"Highest Charting Position\": 91, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Cloud 9\", \"Streams\": 5252767, \"Artist\": \"Beach Bunny\", \"Artist Followers\": 618444.0, \"Song ID\": \"6vFsBXYczYsP0H3lgunZOm\", \"Genre\": \"['bubblegrunge', 'chicago indie', 'indie pop', 'pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 81.0, \"Danceability\": 0.637, \"Energy\": 0.929, \"Loudness\": -3.593, \"Speechiness\": 0.0491, \"Acousticness\": 0.00167, \"Liveness\": 0.344, \"Tempo\": 80.974, \"Duration (ms)\": 147351.0, \"Valence\": 0.902, \"Chord\": \"E\"}, {\"Index\": 354, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Tout l'univers\", \"Streams\": 5174437, \"Artist\": \"Gjon's Tears\", \"Artist Followers\": 32257.0, \"Song ID\": \"3MvY2XbGYFi6p2dgmdcOYG\", \"Genre\": \"[]\", \"Release Date\": \"2021-03-10\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 69.0, \"Danceability\": 0.534, \"Energy\": 0.365, \"Loudness\": -9.187, \"Speechiness\": 0.033, \"Acousticness\": 0.81, \"Liveness\": 0.158, \"Tempo\": 123.466, \"Duration (ms)\": 183707.0, \"Valence\": 0.237, \"Chord\": \"A\"}, {\"Index\": 355, \"Highest Charting Position\": 64, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Headshot (feat. Polo G & Fivio Foreign)\", \"Streams\": 5174298, \"Artist\": \"Lil Tjay\", \"Artist Followers\": 3553442.0, \"Song ID\": \"4eNOLmx8r2IJAVKvBBL1jv\", \"Genre\": \"['brooklyn drill', 'melodic rap', 'nyc rap']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 81.0, \"Danceability\": 0.808, \"Energy\": 0.639, \"Loudness\": -7.266, \"Speechiness\": 0.279, \"Acousticness\": 0.0802, \"Liveness\": 0.15, \"Tempo\": 118.0, \"Duration (ms)\": 144349.0, \"Valence\": 0.395, \"Chord\": \"C#/Db\"}, {\"Index\": 356, \"Highest Charting Position\": 198, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Mask\", \"Streams\": 5156496, \"Artist\": \"Dream\", \"Artist Followers\": 727731.0, \"Song ID\": \"3IxMaULfjq4IT2IN6v54PB\", \"Genre\": \"['dream smp']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 76.0, \"Danceability\": 0.636, \"Energy\": 0.749, \"Loudness\": -4.197, \"Speechiness\": 0.0631, \"Acousticness\": 0.195, \"Liveness\": 0.107, \"Tempo\": 117.904, \"Duration (ms)\": 174936.0, \"Valence\": 0.653, \"Chord\": \"C#/Db\"}, {\"Index\": 357, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"10 Years\", \"Streams\": 5152139, \"Artist\": \"Da\\u00f0i Freyr\", \"Artist Followers\": 169137.0, \"Song ID\": \"4O0LQKVT6hGmVGNwizmydg\", \"Genre\": \"['icelandic pop', 'sunnlensk tonlist']\", \"Release Date\": \"2021-03-13\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 70.0, \"Danceability\": 0.798, \"Energy\": 0.621, \"Loudness\": -6.916, \"Speechiness\": 0.0391, \"Acousticness\": 0.0141, \"Liveness\": 0.0926, \"Tempo\": 123.038, \"Duration (ms)\": 166000.0, \"Valence\": 0.443, \"Chord\": \"D\"}, {\"Index\": 358, \"Highest Charting Position\": 127, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Choker\", \"Streams\": 5150176, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20823062.0, \"Song ID\": \"732E6ibFkQR5lNIPEeiEnx\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-04-30--2021-05-07\", \"Popularity\": 72.0, \"Danceability\": 0.7, \"Energy\": 0.664, \"Loudness\": -8.211, \"Speechiness\": 0.0394, \"Acousticness\": 0.306, \"Liveness\": 0.249, \"Tempo\": 142.009, \"Duration (ms)\": 223066.0, \"Valence\": 0.585, \"Chord\": \"G\"}, {\"Index\": 359, \"Highest Charting Position\": 25, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"a p p l y i n g . p r e s s u r e\", \"Streams\": 15967986, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"1d7q712nXjG98HiwHk7HFS\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 71.0, \"Danceability\": 0.699, \"Energy\": 0.759, \"Loudness\": -5.302, \"Speechiness\": 0.311, \"Acousticness\": 0.0814, \"Liveness\": 0.312, \"Tempo\": 83.092, \"Duration (ms)\": 177337.0, \"Valence\": 0.404, \"Chord\": \"C#/Db\"}, {\"Index\": 360, \"Highest Charting Position\": 30, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"1 0 0 . m i l \\u2018 (with Bas)\", \"Streams\": 15171655, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"4n6NDfYake476trCjJRNl0\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 72.0, \"Danceability\": 0.711, \"Energy\": 0.647, \"Loudness\": -5.667, \"Speechiness\": 0.0822, \"Acousticness\": 0.334, \"Liveness\": 0.312, \"Tempo\": 125.092, \"Duration (ms)\": 163302.0, \"Valence\": 0.227, \"Chord\": \"D\"}, {\"Index\": 361, \"Highest Charting Position\": 32, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"p u n c h i n \\u2018 . t h e . c l o c k\", \"Streams\": 14051831, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"57ZUX6TNyKLBydAdVVd02x\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 70.0, \"Danceability\": 0.769, \"Energy\": 0.74, \"Loudness\": -6.579, \"Speechiness\": 0.378, \"Acousticness\": 0.197, \"Liveness\": 0.171, \"Tempo\": 94.104, \"Duration (ms)\": 112579.0, \"Valence\": 0.692, \"Chord\": \"B\"}, {\"Index\": 362, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"t h e . c l i m b . b a c k\", \"Streams\": 12648655, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5lLNBIyjp72btcnrjBG751\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.618, \"Energy\": 0.632, \"Loudness\": -6.973, \"Speechiness\": 0.346, \"Acousticness\": 0.0526, \"Liveness\": 0.353, \"Tempo\": 81.446, \"Duration (ms)\": 306257.0, \"Valence\": 0.319, \"Chord\": \"B\"}, {\"Index\": 363, \"Highest Charting Position\": 48, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"h u n g e r . o n . h i l l s i d e (with Bas)\", \"Streams\": 11647489, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5BwQjRasNcdRPuVWKcHto2\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 71.0, \"Danceability\": 0.563, \"Energy\": 0.703, \"Loudness\": -5.756, \"Speechiness\": 0.0702, \"Acousticness\": 0.126, \"Liveness\": 0.213, \"Tempo\": 94.983, \"Duration (ms)\": 238972.0, \"Valence\": 0.294, \"Chord\": \"D\"}, {\"Index\": 364, \"Highest Charting Position\": 55, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"c l o s e\", \"Streams\": 10712648, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"1D3z6HTiQsNmZxjl7F7eoG\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.597, \"Energy\": 0.587, \"Loudness\": -7.026, \"Speechiness\": 0.137, \"Acousticness\": 0.0622, \"Liveness\": 0.214, \"Tempo\": 140.021, \"Duration (ms)\": 218802.0, \"Valence\": 0.0753, \"Chord\": \"G\"}, {\"Index\": 365, \"Highest Charting Position\": 34, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"WITHOUT YOU (with Miley Cyrus)\", \"Streams\": 6081034, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2230022.0, \"Song ID\": \"1EHUQesfVKwbthtNcpBi9g\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 81.0, \"Danceability\": 0.655, \"Energy\": 0.469, \"Loudness\": -6.257, \"Speechiness\": 0.0292, \"Acousticness\": 0.173, \"Liveness\": 0.0956, \"Tempo\": 92.56, \"Duration (ms)\": 161385.0, \"Valence\": 0.467, \"Chord\": \"C\"}, {\"Index\": 366, \"Highest Charting Position\": 92, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Snow Tha Product: Bzrp Music Sessions, Vol. 39\", \"Streams\": 5595839, \"Artist\": \"Bizarrap, Snow Tha Product\", \"Artist Followers\": 3126961.0, \"Song ID\": \"3ke6it1vTmHtz2ApcIVUz5\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2021-04-28\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 78.0, \"Danceability\": 0.83, \"Energy\": 0.748, \"Loudness\": -5.362, \"Speechiness\": 0.162, \"Acousticness\": 0.354, \"Liveness\": 0.0992, \"Tempo\": 133.028, \"Duration (ms)\": 177443.0, \"Valence\": 0.523, \"Chord\": \"C#/Db\"}, {\"Index\": 367, \"Highest Charting Position\": 87, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Travesuras - Remix\", \"Streams\": 5518444, \"Artist\": \"Nio Garcia, Casper Magico, Ozuna, Wisin & Yandel, Myke Towers, Flow La Movie\", \"Artist Followers\": 2123734.0, \"Song ID\": \"0VWLId2RwPCno9s1cJm2Vy\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-03-11\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 81.0, \"Danceability\": 0.739, \"Energy\": 0.788, \"Loudness\": -5.198, \"Speechiness\": 0.0731, \"Acousticness\": 0.0513, \"Liveness\": 0.282, \"Tempo\": 175.996, \"Duration (ms)\": 324426.0, \"Valence\": 0.473, \"Chord\": \"C#/Db\"}, {\"Index\": 368, \"Highest Charting Position\": 148, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Bubblegum Bitch\", \"Streams\": 5375782, \"Artist\": \"MARINA\", \"Artist Followers\": 2918229.0, \"Song ID\": \"0ZFBKLOZLIM16RAUb5eomN\", \"Genre\": \"['dance pop', 'electropop', 'metropopolis', 'pop', 'post-teen pop', 'uk alternative pop']\", \"Release Date\": \"2012-04-30\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 73.0, \"Danceability\": 0.495, \"Energy\": 0.856, \"Loudness\": -5.123, \"Speechiness\": 0.0311, \"Acousticness\": 0.000219, \"Liveness\": 0.103, \"Tempo\": 158.024, \"Duration (ms)\": 154667.0, \"Valence\": 0.609, \"Chord\": \"C\"}, {\"Index\": 369, \"Highest Charting Position\": 5, \"Number of Times Charted\": 142, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Falling\", \"Streams\": 5294368, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16112621.0, \"Song ID\": \"1ZMiCix7XSAbfAJlEZWMCp\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.567, \"Energy\": 0.267, \"Loudness\": -6.502, \"Speechiness\": 0.0299, \"Acousticness\": 0.839, \"Liveness\": 0.089, \"Tempo\": 110.011, \"Duration (ms)\": 240133.0, \"Valence\": 0.0592, \"Chord\": \"E\"}, {\"Index\": 370, \"Highest Charting Position\": 182, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Expl\\u00edcito\", \"Streams\": 5278449, \"Artist\": \"Myke Towers\", \"Artist Followers\": 6150675.0, \"Song ID\": \"6qraVL4IJaIj0IuEexYJNa\", \"Genre\": \"['trap latino']\", \"Release Date\": \"2020-12-15\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-03-26--2021-04-02\", \"Popularity\": 81.0, \"Danceability\": 0.828, \"Energy\": 0.83, \"Loudness\": -3.371, \"Speechiness\": 0.047, \"Acousticness\": 0.348, \"Liveness\": 0.0613, \"Tempo\": 95.007, \"Duration (ms)\": 195066.0, \"Valence\": 0.422, \"Chord\": \"D\"}, {\"Index\": 371, \"Highest Charting Position\": 58, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"No Te Enamores - Remix\", \"Streams\": 5218146, \"Artist\": \"Milly, Farruko, Nio Garcia, Jay Wheeler, Amenazzy\", \"Artist Followers\": 22718.0, \"Song ID\": \"2mM3gZ0BbPwPPMelbA8vgt\", \"Genre\": \"['reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 79.0, \"Danceability\": 0.824, \"Energy\": 0.837, \"Loudness\": -4.603, \"Speechiness\": 0.107, \"Acousticness\": 0.573, \"Liveness\": 0.271, \"Tempo\": 100.021, \"Duration (ms)\": 289933.0, \"Valence\": 0.58, \"Chord\": \"F\"}, {\"Index\": 372, \"Highest Charting Position\": 110, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"PROBLEMA\", \"Streams\": 5215973, \"Artist\": \"Daddy Yankee\", \"Artist Followers\": 1250353.0, \"Song ID\": \"7vzPjsX8UzlPKKtV47qGPn\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 0.0, \"Danceability\": 0.773, \"Energy\": 0.8, \"Loudness\": -3.17, \"Speechiness\": 0.0987, \"Acousticness\": 0.0613, \"Liveness\": 0.0327, \"Tempo\": 89.988, \"Duration (ms)\": 184507.0, \"Valence\": 0.842, \"Chord\": \"A#/Bb\"}, {\"Index\": 373, \"Highest Charting Position\": 5, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Lonely (with benny blanco)\", \"Streams\": 5191697, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48504126.0, \"Song ID\": \"4y4spB9m0Q6026KfkAvy9Q\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 80.0, \"Danceability\": 0.631, \"Energy\": 0.239, \"Loudness\": -7.071, \"Speechiness\": 0.0398, \"Acousticness\": 0.864, \"Liveness\": 0.116, \"Tempo\": 79.859, \"Duration (ms)\": 149297.0, \"Valence\": 0.0927, \"Chord\": \"B\"}, {\"Index\": 374, \"Highest Charting Position\": 77, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Cupid's Chokehold / Breakfast in America\", \"Streams\": 5165035, \"Artist\": \"Gym Class Heroes\", \"Artist Followers\": 1275345.0, \"Song ID\": \"2Lhdl74nwwVGOE2Gv35QuK\", \"Genre\": \"['dance pop', 'pop rap']\", \"Release Date\": \"2005-02-22\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 81.0, \"Danceability\": 0.72, \"Energy\": 0.744, \"Loudness\": -6.938, \"Speechiness\": 0.12, \"Acousticness\": 0.237, \"Liveness\": 0.255, \"Tempo\": 78.953, \"Duration (ms)\": 243773.0, \"Valence\": 0.619, \"Chord\": \"C#/Db\"}, {\"Index\": 375, \"Highest Charting Position\": 38, \"Number of Times Charted\": 72, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"If the World Was Ending - feat. Julia Michaels\", \"Streams\": 5127736, \"Artist\": \"JP Saxe\", \"Artist Followers\": 280585.0, \"Song ID\": \"2kJwzbxV2ppxnQoYw4GLBZ\", \"Genre\": \"['alt z', 'canadian contemporary r&b', 'indie cafe pop', 'pop', 'pop rock', 'post-teen pop']\", \"Release Date\": \"2019-10-17\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.464, \"Energy\": 0.473, \"Loudness\": -10.086, \"Speechiness\": 0.129, \"Acousticness\": 0.866, \"Liveness\": 0.109, \"Tempo\": 75.801, \"Duration (ms)\": 208687.0, \"Valence\": 0.604, \"Chord\": \"C#/Db\"}, {\"Index\": 376, \"Highest Charting Position\": 47, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"I DID IT (feat. Post Malone, Megan Thee Stallion, Lil Baby & DaBaby)\", \"Streams\": 7347891, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6278835.0, \"Song ID\": \"20GrahbI4AzAOWxpYfDKkf\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 76.0, \"Danceability\": 0.757, \"Energy\": 0.721, \"Loudness\": -2.906, \"Speechiness\": 0.0691, \"Acousticness\": 0.00196, \"Liveness\": 0.647, \"Tempo\": 124.036, \"Duration (ms)\": 165366.0, \"Valence\": 0.364, \"Chord\": \"E\"}, {\"Index\": 377, \"Highest Charting Position\": 61, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Body\", \"Streams\": 5831357, \"Artist\": \"Russ Millions, Tion Wayne\", \"Artist Followers\": 323203.0, \"Song ID\": \"6uvMKqNlrSvcC4NaKnrwjZ\", \"Genre\": \"['london rap']\", \"Release Date\": \"2021-04-22\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 84.0, \"Danceability\": 0.883, \"Energy\": 0.674, \"Loudness\": -8.043, \"Speechiness\": 0.357, \"Acousticness\": 0.21, \"Liveness\": 0.0678, \"Tempo\": 141.02, \"Duration (ms)\": 278085.0, \"Valence\": 0.73, \"Chord\": \"B\"}, {\"Index\": 378, \"Highest Charting Position\": 10, \"Number of Times Charted\": 69, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"everything i wanted\", \"Streams\": 5448680, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"1OC8hMoqAuWmTWJ4heJNlO\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.704, \"Energy\": 0.225, \"Loudness\": -14.454, \"Speechiness\": 0.0994, \"Acousticness\": 0.901, \"Liveness\": 0.106, \"Tempo\": 120.006, \"Duration (ms)\": 245426.0, \"Valence\": 0.243, \"Chord\": \"F#/Gb\"}, {\"Index\": 379, \"Highest Charting Position\": 169, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"What You Need\", \"Streams\": 5346005, \"Artist\": \"Don Toliver\", \"Artist Followers\": 1605329.0, \"Song ID\": \"6LcX2hBbXaJcK4AuefE936\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2021-05-04\", \"Weeks Charted\": \"2021-05-07--2021-05-14\", \"Popularity\": 76.0, \"Danceability\": 0.664, \"Energy\": 0.655, \"Loudness\": -7.327, \"Speechiness\": 0.0461, \"Acousticness\": 0.059, \"Liveness\": 0.17, \"Tempo\": 129.987, \"Duration (ms)\": 217609.0, \"Valence\": 0.13, \"Chord\": \"A#/Bb\"}, {\"Index\": 380, \"Highest Charting Position\": 115, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"L-Gante: Bzrp Music Sessions, Vol.38\", \"Streams\": 5290877, \"Artist\": \"Bizarrap, L-Gante\", \"Artist Followers\": 3126961.0, \"Song ID\": \"1Crj1zkRMpsEjb9NOR6Zof\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2021-03-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 80.0, \"Danceability\": 0.553, \"Energy\": 0.819, \"Loudness\": -3.083, \"Speechiness\": 0.257, \"Acousticness\": 0.368, \"Liveness\": 0.0915, \"Tempo\": 87.913, \"Duration (ms)\": 192348.0, \"Valence\": 0.761, \"Chord\": \"D\"}, {\"Index\": 381, \"Highest Charting Position\": 19, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"HOLIDAY\", \"Streams\": 5264232, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5473565.0, \"Song ID\": \"6zFMeegAMYQo0mt8rXtrli\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 83.0, \"Danceability\": 0.81, \"Energy\": 0.511, \"Loudness\": -6.924, \"Speechiness\": 0.164, \"Acousticness\": 0.12, \"Liveness\": 0.0832, \"Tempo\": 151.947, \"Duration (ms)\": 154998.0, \"Valence\": 0.837, \"Chord\": \"F\"}, {\"Index\": 382, \"Highest Charting Position\": 71, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"At My Worst\", \"Streams\": 5258000, \"Artist\": \"Pink Sweat$\", \"Artist Followers\": 942628.0, \"Song ID\": \"0ri0Han4IRJhzvERHOZTMr\", \"Genre\": \"['bedroom soul', 'pop']\", \"Release Date\": \"2020-07-17\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 79.0, \"Danceability\": 0.813, \"Energy\": 0.415, \"Loudness\": -5.926, \"Speechiness\": 0.0349, \"Acousticness\": 0.777, \"Liveness\": 0.131, \"Tempo\": 91.921, \"Duration (ms)\": 170345.0, \"Valence\": 0.667, \"Chord\": \"C\"}, {\"Index\": 383, \"Highest Charting Position\": 3, \"Number of Times Charted\": 70, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Life Is Good (feat. Drake)\", \"Streams\": 5241227, \"Artist\": \"Future\", \"Artist Followers\": 10488292.0, \"Song ID\": \"5yY9lUy8nbvjM1Uyo1Uqoc\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 81.0, \"Danceability\": 0.676, \"Energy\": 0.609, \"Loudness\": -5.831, \"Speechiness\": 0.481, \"Acousticness\": 0.0706, \"Liveness\": 0.152, \"Tempo\": 142.037, \"Duration (ms)\": 237735.0, \"Valence\": 0.508, \"Chord\": \"D\"}, {\"Index\": 384, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Extasy\", \"Streams\": 5203700, \"Artist\": \"187 Strassenbande, Bonez MC, Frauenarzt\", \"Artist Followers\": 1223734.0, \"Song ID\": \"79lc69ZXfL4WmJIzVSDmWT\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-05-07--2021-05-14\", \"Popularity\": 67.0, \"Danceability\": 0.863, \"Energy\": 0.739, \"Loudness\": -5.879, \"Speechiness\": 0.153, \"Acousticness\": 0.0289, \"Liveness\": 0.0931, \"Tempo\": 129.964, \"Duration (ms)\": 174021.0, \"Valence\": 0.547, \"Chord\": \"A\"}, {\"Index\": 385, \"Highest Charting Position\": 7, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Wishing Well\", \"Streams\": 5125706, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"2U5WueTLIK5WJLD7mvDODv\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 83.0, \"Danceability\": 0.65, \"Energy\": 0.613, \"Loudness\": -6.13, \"Speechiness\": 0.128, \"Acousticness\": 0.00336, \"Liveness\": 0.267, \"Tempo\": 149.972, \"Duration (ms)\": 194621.0, \"Valence\": 0.0804, \"Chord\": \"A\"}, {\"Index\": 386, \"Highest Charting Position\": 164, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Fan de Tus Fotos\", \"Streams\": 5103863, \"Artist\": \"Nicky Jam, Romeo Santos\", \"Artist Followers\": 14826679.0, \"Song ID\": \"1mauYRwbpoGQX6itP2FAJC\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-02-08\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\", \"Popularity\": 79.0, \"Danceability\": 0.728, \"Energy\": 0.689, \"Loudness\": -5.718, \"Speechiness\": 0.0725, \"Acousticness\": 0.293, \"Liveness\": 0.109, \"Tempo\": 170.089, \"Duration (ms)\": 197647.0, \"Valence\": 0.431, \"Chord\": \"G\"}, {\"Index\": 387, \"Highest Charting Position\": 82, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Tap\\u00e3o Na Raba\", \"Streams\": 5088848, \"Artist\": \"Ra\\u00ed Saia Rodada\", \"Artist Followers\": 1260752.0, \"Song ID\": \"58pgi1RpcU2fVJsxhm7BIr\", \"Genre\": \"['forro']\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 80.0, \"Danceability\": 0.808, \"Energy\": 0.796, \"Loudness\": -3.169, \"Speechiness\": 0.0305, \"Acousticness\": 0.462, \"Liveness\": 0.155, \"Tempo\": 128.048, \"Duration (ms)\": 175047.0, \"Valence\": 0.799, \"Chord\": \"C#/Db\"}, {\"Index\": 388, \"Highest Charting Position\": 66, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Machu Picchu\", \"Streams\": 5062404, \"Artist\": \"Camilo, Evaluna Montaner\", \"Artist Followers\": 10561047.0, \"Song ID\": \"1LXb70u8SLsvBAPWHMCTMe\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2021-03-01\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 76.0, \"Danceability\": 0.788, \"Energy\": 0.789, \"Loudness\": -2.39, \"Speechiness\": 0.124, \"Acousticness\": 0.397, \"Liveness\": 0.226, \"Tempo\": 167.897, \"Duration (ms)\": 179005.0, \"Valence\": 0.867, \"Chord\": \"C\"}, {\"Index\": 389, \"Highest Charting Position\": 4, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Come & Go (with Marshmello)\", \"Streams\": 5037124, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"2Y0wPrPQBrGhoLn14xRYCG\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 83.0, \"Danceability\": 0.625, \"Energy\": 0.814, \"Loudness\": -5.181, \"Speechiness\": 0.0657, \"Acousticness\": 0.0172, \"Liveness\": 0.158, \"Tempo\": 144.991, \"Duration (ms)\": 205485.0, \"Valence\": 0.535, \"Chord\": \"C\"}, {\"Index\": 390, \"Highest Charting Position\": 71, \"Number of Times Charted\": 72, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Robbery\", \"Streams\": 5024884, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"6Hj9jySrnFppAI0sEMCZpJ\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2019-03-08\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.685, \"Energy\": 0.692, \"Loudness\": -5.122, \"Speechiness\": 0.0457, \"Acousticness\": 0.328, \"Liveness\": 0.153, \"Tempo\": 159.966, \"Duration (ms)\": 240051.0, \"Valence\": 0.578, \"Chord\": \"D\"}, {\"Index\": 391, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Paradigmas\", \"Streams\": 5018076, \"Artist\": \"Jorge & Mateus\", \"Artist Followers\": 15013645.0, \"Song ID\": \"17UfXrL7Run3GyZJW4uRjC\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2021-04-22\", \"Weeks Charted\": \"2021-05-07--2021-05-14\", \"Popularity\": 72.0, \"Danceability\": 0.686, \"Energy\": 0.789, \"Loudness\": -4.103, \"Speechiness\": 0.126, \"Acousticness\": 0.322, \"Liveness\": 0.4, \"Tempo\": 157.932, \"Duration (ms)\": 157355.0, \"Valence\": 0.822, \"Chord\": \"C#/Db\"}, {\"Index\": 392, \"Highest Charting Position\": 53, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"SugarCrash!\", \"Streams\": 5018005, \"Artist\": \"ElyOtto\", \"Artist Followers\": 85617.0, \"Song ID\": \"2ePtv8MlBO9nuuXABqAfEX\", \"Genre\": \"['weirdcore']\", \"Release Date\": \"2020-08-25\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 80.0, \"Danceability\": 0.748, \"Energy\": 0.734, \"Loudness\": -6.499, \"Speechiness\": 0.124, \"Acousticness\": 0.524, \"Liveness\": 0.0975, \"Tempo\": 97.753, \"Duration (ms)\": 80081.0, \"Valence\": 0.368, \"Chord\": \"C\"}, {\"Index\": 393, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"durag activity (with Travis Scott)\", \"Streams\": 7939784, \"Artist\": \"Baby Keem\", \"Artist Followers\": 279741.0, \"Song ID\": \"4JJcP0Rv9AgyPD6ZGaC8EE\", \"Genre\": \"['hip hop', 'rap', 'trap', 'underground hip hop']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-04-30--2021-05-07\", \"Popularity\": 75.0, \"Danceability\": 0.89, \"Energy\": 0.701, \"Loudness\": -5.712, \"Speechiness\": 0.342, \"Acousticness\": 0.00306, \"Liveness\": 0.0895, \"Tempo\": 80.462, \"Duration (ms)\": 225020.0, \"Valence\": 0.505, \"Chord\": \"C\"}, {\"Index\": 394, \"Highest Charting Position\": 113, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"love race (feat. Kellin Quinn)\", \"Streams\": 6325080, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3864419.0, \"Song ID\": \"1F9kEuwT29fgqlovIclu81\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2021-04-29\", \"Weeks Charted\": \"2021-04-30--2021-05-07\", \"Popularity\": 76.0, \"Danceability\": 0.517, \"Energy\": 0.848, \"Loudness\": -4.054, \"Speechiness\": 0.0521, \"Acousticness\": 0.00581, \"Liveness\": 0.214, \"Tempo\": 95.906, \"Duration (ms)\": 188779.0, \"Valence\": 0.429, \"Chord\": \"A#/Bb\"}, {\"Index\": 395, \"Highest Charting Position\": 7, \"Number of Times Charted\": 40, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"POPSTAR (feat. Drake)\", \"Streams\": 6127103, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6278835.0, \"Song ID\": \"6EDO9iiTtwNv6waLwa1UUq\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-07-17\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 80.0, \"Danceability\": 0.8, \"Energy\": 0.56, \"Loudness\": -4.818, \"Speechiness\": 0.261, \"Acousticness\": 0.057, \"Liveness\": 0.134, \"Tempo\": 163.071, \"Duration (ms)\": 200221.0, \"Valence\": 0.45, \"Chord\": \"F\"}, {\"Index\": 396, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"LET IT GO (feat. Justin Bieber & 21 Savage)\", \"Streams\": 6083338, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6278835.0, \"Song ID\": \"1cEhrSF6EylAEqdhUGuNpX\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-04-30--2021-05-07\", \"Popularity\": 75.0, \"Danceability\": 0.877, \"Energy\": 0.444, \"Loudness\": -7.547, \"Speechiness\": 0.172, \"Acousticness\": 0.24, \"Liveness\": 0.169, \"Tempo\": 129.06, \"Duration (ms)\": 165527.0, \"Valence\": 0.658, \"Chord\": \"G#/Ab\"}, {\"Index\": 397, \"Highest Charting Position\": 137, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Girl From Rio\", \"Streams\": 5768836, \"Artist\": \"Anitta\", \"Artist Followers\": 10740222.0, \"Song ID\": \"6CF085Ol0cVda1WqelybEQ\", \"Genre\": \"['funk carioca', 'funk pop', 'pagode baiano', 'pop nacional']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-04-30--2021-05-07\", \"Popularity\": 69.0, \"Danceability\": 0.732, \"Energy\": 0.604, \"Loudness\": -7.472, \"Speechiness\": 0.0443, \"Acousticness\": 0.0112, \"Liveness\": 0.219, \"Tempo\": 139.982, \"Duration (ms)\": 195429.0, \"Valence\": 0.732, \"Chord\": \"C\"}, {\"Index\": 398, \"Highest Charting Position\": 10, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"On The Ground\", \"Streams\": 5655879, \"Artist\": \"ROS\\u00c9\", \"Artist Followers\": 1094731.0, \"Song ID\": \"2pn8dNVSpYnAtlKFC8Q0DJ\", \"Genre\": \"[]\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 74.0, \"Danceability\": 0.311, \"Energy\": 0.607, \"Loudness\": -6.578, \"Speechiness\": 0.11, \"Acousticness\": 0.0174, \"Liveness\": 0.131, \"Tempo\": 188.7, \"Duration (ms)\": 168086.0, \"Valence\": 0.286, \"Chord\": \"C#/Db\"}, {\"Index\": 399, \"Highest Charting Position\": 20, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Mr. Perfectly Fine (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5480722, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2CYVETnhM9aytqrazYYwrK\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 74.0, \"Danceability\": 0.66, \"Energy\": 0.817, \"Loudness\": -6.269, \"Speechiness\": 0.0521, \"Acousticness\": 0.162, \"Liveness\": 0.0667, \"Tempo\": 135.942, \"Duration (ms)\": 277592.0, \"Valence\": 0.714, \"Chord\": \"B\"}, {\"Index\": 400, \"Highest Charting Position\": 42, \"Number of Times Charted\": 60, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"when the party's over\", \"Streams\": 5467596, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"5KWwUzVxubgSPmLIUAQhYt\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.484, \"Energy\": 0.103, \"Loudness\": -14.075, \"Speechiness\": 0.0627, \"Acousticness\": 0.979, \"Liveness\": 0.0895, \"Tempo\": 124.011, \"Duration (ms)\": 199931.0, \"Valence\": 0.194, \"Chord\": \"C#/Db\"}, {\"Index\": 401, \"Highest Charting Position\": 63, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Otra Noche Sin Ti\", \"Streams\": 5377794, \"Artist\": \"J Balvin, Khalid\", \"Artist Followers\": 29051363.0, \"Song ID\": \"2CdTLdDjwZdVcm0bresVWx\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 80.0, \"Danceability\": 0.503, \"Energy\": 0.548, \"Loudness\": -7.564, \"Speechiness\": 0.164, \"Acousticness\": 0.0751, \"Liveness\": 0.145, \"Tempo\": 94.036, \"Duration (ms)\": 228920.0, \"Valence\": 0.441, \"Chord\": \"C\"}, {\"Index\": 402, \"Highest Charting Position\": 33, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Met Him Last Night (feat. Ariana Grande)\", \"Streams\": 5200695, \"Artist\": \"Demi Lovato\", \"Artist Followers\": 20331923.0, \"Song ID\": \"0BI0hfbmqybnd3TezrDME3\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 72.0, \"Danceability\": 0.538, \"Energy\": 0.512, \"Loudness\": -4.548, \"Speechiness\": 0.0262, \"Acousticness\": 0.22, \"Liveness\": 0.101, \"Tempo\": 144.978, \"Duration (ms)\": 204632.0, \"Valence\": 0.12, \"Chord\": \"E\"}, {\"Index\": 403, \"Highest Charting Position\": 100, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Back In Blood (feat. Lil Durk)\", \"Streams\": 5198209, \"Artist\": \"Pooh Shiesty\", \"Artist Followers\": 423237.0, \"Song ID\": \"7JuHVG3qQKQKxC4doneXVW\", \"Genre\": \"['memphis hip hop', 'rap', 'southern hip hop', 'tennessee hip hop', 'trap']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 75.0, \"Danceability\": 0.759, \"Energy\": 0.538, \"Loudness\": -8.256, \"Speechiness\": 0.384, \"Acousticness\": 0.151, \"Liveness\": 0.126, \"Tempo\": 146.933, \"Duration (ms)\": 184490.0, \"Valence\": 0.831, \"Chord\": \"G#/Ab\"}, {\"Index\": 404, \"Highest Charting Position\": 94, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Run It Up (feat. Offset & Moneybagg Yo)\", \"Streams\": 5107084, \"Artist\": \"Lil Tjay\", \"Artist Followers\": 3553442.0, \"Song ID\": \"1dg3qy5DjoJodawfOCgrTP\", \"Genre\": \"['brooklyn drill', 'melodic rap', 'nyc rap']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 81.0, \"Danceability\": 0.88, \"Energy\": 0.575, \"Loudness\": -6.091, \"Speechiness\": 0.163, \"Acousticness\": 0.415, \"Liveness\": 0.109, \"Tempo\": 120.031, \"Duration (ms)\": 232048.0, \"Valence\": 0.671, \"Chord\": \"F#/Gb\"}, {\"Index\": 405, \"Highest Charting Position\": 37, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Mi Ni\\u00f1a\", \"Streams\": 5026961, \"Artist\": \"Wisin, Myke Towers, Los Legendarios\", \"Artist Followers\": 6929075.0, \"Song ID\": \"2bgcUk2A3jjKbCJ7KPquTi\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-23\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 79.0, \"Danceability\": 0.823, \"Energy\": 0.821, \"Loudness\": -3.402, \"Speechiness\": 0.166, \"Acousticness\": 0.31, \"Liveness\": 0.143, \"Tempo\": 99.999, \"Duration (ms)\": 213314.0, \"Valence\": 0.791, \"Chord\": \"G#/Ab\"}, {\"Index\": 406, \"Highest Charting Position\": 9, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"As I Am (feat. Khalid)\", \"Streams\": 5896065, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6F2r4HgpJnvKDmkN6JEN6J\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 72.0, \"Danceability\": 0.595, \"Energy\": 0.543, \"Loudness\": -8.149, \"Speechiness\": 0.038, \"Acousticness\": 0.127, \"Liveness\": 0.0975, \"Tempo\": 99.928, \"Duration (ms)\": 174406.0, \"Valence\": 0.109, \"Chord\": \"B\"}, {\"Index\": 407, \"Highest Charting Position\": 150, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Come Through (feat. Chris Brown)\", \"Streams\": 5531998, \"Artist\": \"H.E.R.\", \"Artist Followers\": 4138951.0, \"Song ID\": \"3krZxyBsWEHfEfJegYaWTd\", \"Genre\": \"['alternative r&b', 'dance pop', 'pop', 'r&b']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-04-23--2021-04-30\", \"Popularity\": 74.0, \"Danceability\": 0.615, \"Energy\": 0.422, \"Loudness\": -8.019, \"Speechiness\": 0.0504, \"Acousticness\": 0.604, \"Liveness\": 0.112, \"Tempo\": 135.859, \"Duration (ms)\": 214094.0, \"Valence\": 0.185, \"Chord\": \"F\"}, {\"Index\": 408, \"Highest Charting Position\": 33, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Goosebumps\", \"Streams\": 5496962, \"Artist\": \"HVME\", \"Artist Followers\": 17719446.0, \"Song ID\": \"5uEYRdEIh9Bo4fpjDd4Na9\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 87.0, \"Danceability\": 0.841, \"Energy\": 0.593, \"Loudness\": -7.846, \"Speechiness\": 0.0379, \"Acousticness\": 0.418, \"Liveness\": 0.124, \"Tempo\": 124.917, \"Duration (ms)\": 162803.0, \"Valence\": 0.808, \"Chord\": \"C#/Db\"}, {\"Index\": 409, \"Highest Charting Position\": 18, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Put Your Records On\", \"Streams\": 5181180, \"Artist\": \"Ritt Momney\", \"Artist Followers\": 100463.0, \"Song ID\": \"6AGOKlMZWLCaEJGnaROtF9\", \"Genre\": \"['bedroom pop']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 81.0, \"Danceability\": 0.399, \"Energy\": 0.491, \"Loudness\": -10.778, \"Speechiness\": 0.0538, \"Acousticness\": 0.0563, \"Liveness\": 0.11, \"Tempo\": 91.066, \"Duration (ms)\": 210463.0, \"Valence\": 0.151, \"Chord\": \"F#/Gb\"}, {\"Index\": 410, \"Highest Charting Position\": 137, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Facas - Ao Vivo\", \"Streams\": 5141640, \"Artist\": \"Diego & Victor Hugo, Bruno & Marrone\", \"Artist Followers\": 1585593.0, \"Song ID\": \"1ere9b9vDw2N3m9d4uiXxa\", \"Genre\": \"['sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2020-10-15\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 79.0, \"Danceability\": 0.443, \"Energy\": 0.509, \"Loudness\": -5.995, \"Speechiness\": 0.0536, \"Acousticness\": 0.615, \"Liveness\": 0.472, \"Tempo\": 160.984, \"Duration (ms)\": 196380.0, \"Valence\": 0.69, \"Chord\": \"D\"}, {\"Index\": 411, \"Highest Charting Position\": 62, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Train Wreck\", \"Streams\": 5081800, \"Artist\": \"James Arthur\", \"Artist Followers\": 8446147.0, \"Song ID\": \"55Am8neGJkdj2ADaM3aw5H\", \"Genre\": \"['pop', 'post-teen pop', 'talent show', 'uk pop']\", \"Release Date\": \"2016-10-28\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 82.0, \"Danceability\": 0.311, \"Energy\": 0.485, \"Loudness\": -5.726, \"Speechiness\": 0.0365, \"Acousticness\": 0.701, \"Liveness\": 0.0726, \"Tempo\": 77.355, \"Duration (ms)\": 208827.0, \"Valence\": 0.225, \"Chord\": \"F#/Gb\"}, {\"Index\": 412, \"Highest Charting Position\": 7, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Monster (Shawn Mendes & Justin Bieber)\", \"Streams\": 5069268, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 33893352.0, \"Song ID\": \"2Z8yfpFX0ZMavHkcIeHiO1\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 79.0, \"Danceability\": 0.652, \"Energy\": 0.383, \"Loudness\": -7.076, \"Speechiness\": 0.0516, \"Acousticness\": 0.0676, \"Liveness\": 0.0828, \"Tempo\": 145.765, \"Duration (ms)\": 178994.0, \"Valence\": 0.549, \"Chord\": \"D\"}, {\"Index\": 413, \"Highest Charting Position\": 6, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"In Your Eyes\", \"Streams\": 5054319, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"7szuecWAPwGoV1e5vGu8tl\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 81.0, \"Danceability\": 0.667, \"Energy\": 0.719, \"Loudness\": -5.371, \"Speechiness\": 0.0346, \"Acousticness\": 0.00285, \"Liveness\": 0.0736, \"Tempo\": 100.021, \"Duration (ms)\": 237520.0, \"Valence\": 0.717, \"Chord\": \"G\"}, {\"Index\": 414, \"Highest Charting Position\": 101, \"Number of Times Charted\": 68, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"SAD!\", \"Streams\": 5051338, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"3ee8Jmje8o58CHK66QrVC2\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2018-03-16\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.74, \"Energy\": 0.613, \"Loudness\": -4.88, \"Speechiness\": 0.145, \"Acousticness\": 0.258, \"Liveness\": 0.123, \"Tempo\": 75.023, \"Duration (ms)\": 166606.0, \"Valence\": 0.473, \"Chord\": \"G#/Ab\"}, {\"Index\": 415, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Good Without\", \"Streams\": 4998044, \"Artist\": \"Mimi Webb\", \"Artist Followers\": 130801.0, \"Song ID\": \"15OCqNPYoLziEAsbVnqRj5\", \"Genre\": \"['alt z', 'indie cafe pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-04-23--2021-04-30\", \"Popularity\": 81.0, \"Danceability\": 0.616, \"Energy\": 0.576, \"Loudness\": -5.495, \"Speechiness\": 0.0532, \"Acousticness\": 0.0723, \"Liveness\": 0.375, \"Tempo\": 89.962, \"Duration (ms)\": 182121.0, \"Valence\": 0.269, \"Chord\": \"B\"}, {\"Index\": 416, \"Highest Charting Position\": 19, \"Number of Times Charted\": 66, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"hot girl bummer\", \"Streams\": 4992396, \"Artist\": \"blackbear\", \"Artist Followers\": 4270131.0, \"Song ID\": \"2mt1IqcFyY1zmYZT8Q3xw9\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.782, \"Energy\": 0.559, \"Loudness\": -7.106, \"Speechiness\": 0.0767, \"Acousticness\": 0.125, \"Liveness\": 0.385, \"Tempo\": 129.992, \"Duration (ms)\": 188344.0, \"Valence\": 0.685, \"Chord\": \"F#/Gb\"}, {\"Index\": 417, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"When I Was Your Man\", \"Streams\": 4945935, \"Artist\": \"Bruno Mars\", \"Artist Followers\": 32603394.0, \"Song ID\": \"0nJW01T7XtvILxQgC5J7Wh\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2012-12-07\", \"Weeks Charted\": \"2021-04-23--2021-04-30\", \"Popularity\": 82.0, \"Danceability\": 0.612, \"Energy\": 0.28, \"Loudness\": -8.648, \"Speechiness\": 0.0434, \"Acousticness\": 0.932, \"Liveness\": 0.088, \"Tempo\": 72.795, \"Duration (ms)\": 213827.0, \"Valence\": 0.387, \"Chord\": \"C\"}, {\"Index\": 418, \"Highest Charting Position\": 73, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"LOCATION\", \"Streams\": 4940701, \"Artist\": \"KAROL G, Anuel AA, J Balvin\", \"Artist Followers\": 1250353.0, \"Song ID\": \"1aH3EQY5LTXjRZQLpl1Gby\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 0.0, \"Danceability\": 0.772, \"Energy\": 0.758, \"Loudness\": -3.891, \"Speechiness\": 0.0482, \"Acousticness\": 0.0433, \"Liveness\": 0.295, \"Tempo\": 115.977, \"Duration (ms)\": 265240.0, \"Valence\": 0.654, \"Chord\": \"A\"}, {\"Index\": 419, \"Highest Charting Position\": 177, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Stressed Out\", \"Streams\": 4913147, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20823062.0, \"Song ID\": \"3CRDbSIZ4r5MsZ0YwxuEkn\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2015-05-15\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 83.0, \"Danceability\": 0.734, \"Energy\": 0.637, \"Loudness\": -5.677, \"Speechiness\": 0.141, \"Acousticness\": 0.0462, \"Liveness\": 0.0602, \"Tempo\": 169.977, \"Duration (ms)\": 202333.0, \"Valence\": 0.648, \"Chord\": \"E\"}, {\"Index\": 420, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Ski\", \"Streams\": 7753784, \"Artist\": \"Young Stoner Life, Young Thug, Gunna\", \"Artist Followers\": 61930.0, \"Song ID\": \"6755DFiZ7CWe2WMdTGW5C1\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-04-16--2021-04-23\", \"Popularity\": 78.0, \"Danceability\": 0.953, \"Energy\": 0.621, \"Loudness\": -7.638, \"Speechiness\": 0.221, \"Acousticness\": 0.017, \"Liveness\": 0.0398, \"Tempo\": 123.016, \"Duration (ms)\": 152333.0, \"Valence\": 0.883, \"Chord\": \"G#/Ab\"}, {\"Index\": 421, \"Highest Charting Position\": 75, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Diamonds Dancing (feat. Travis Scott)\", \"Streams\": 7515766, \"Artist\": \"Young Stoner Life, Young Thug, Gunna\", \"Artist Followers\": 61930.0, \"Song ID\": \"7uZqvqXzzYMKrexKxdcGmd\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-04-16--2021-04-23\", \"Popularity\": 69.0, \"Danceability\": 0.851, \"Energy\": 0.703, \"Loudness\": -7.351, \"Speechiness\": 0.303, \"Acousticness\": 0.00949, \"Liveness\": 0.0895, \"Tempo\": 74.017, \"Duration (ms)\": 242600.0, \"Valence\": 0.596, \"Chord\": \"E\"}, {\"Index\": 422, \"Highest Charting Position\": 8, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Love Story (Taylor\\u2019s Version)\", \"Streams\": 6202933, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6YvqWjhGD8mB5QXcbcUKtx\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 73.0, \"Danceability\": 0.627, \"Energy\": 0.792, \"Loudness\": -4.311, \"Speechiness\": 0.031, \"Acousticness\": 0.13, \"Liveness\": 0.0845, \"Tempo\": 119.054, \"Duration (ms)\": 235767.0, \"Valence\": 0.415, \"Chord\": \"D\"}, {\"Index\": 423, \"Highest Charting Position\": 107, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Ele \\u00c9 Ele, Eu Sou Eu\", \"Streams\": 5380517, \"Artist\": \"Wesley Safad\\u00e3o, Os Bar\\u00f5es Da Pisadinha\", \"Artist Followers\": 9907270.0, \"Song ID\": \"7EWXP47VlXKO3r7mNxuWHw\", \"Genre\": \"['forro']\", \"Release Date\": \"2020-11-12\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 73.0, \"Danceability\": 0.758, \"Energy\": 0.763, \"Loudness\": -8.754, \"Speechiness\": 0.0768, \"Acousticness\": 0.23, \"Liveness\": 0.0703, \"Tempo\": 163.946, \"Duration (ms)\": 155210.0, \"Valence\": 0.854, \"Chord\": \"C#/Db\"}, {\"Index\": 424, \"Highest Charting Position\": 186, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Quero Ver \\u00e9 Me Esquecer (feat. Jorge) - Ao Vivo\", \"Streams\": 5159208, \"Artist\": \"Os Bar\\u00f5es Da Pisadinha\", \"Artist Followers\": 4271775.0, \"Song ID\": \"2SUPbyD77tJuOUbqbxct6l\", \"Genre\": \"['forro', 'piseiro']\", \"Release Date\": \"2021-02-19\", \"Weeks Charted\": \"2021-04-16--2021-04-23\", \"Popularity\": 80.0, \"Danceability\": 0.593, \"Energy\": 0.932, \"Loudness\": -2.324, \"Speechiness\": 0.0526, \"Acousticness\": 0.302, \"Liveness\": 0.133, \"Tempo\": 171.977, \"Duration (ms)\": 147876.0, \"Valence\": 0.913, \"Chord\": \"G#/Ab\"}, {\"Index\": 425, \"Highest Charting Position\": 3, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"willow\", \"Streams\": 5016865, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0lx2cLdOt3piJbcaXIV74f\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 79.0, \"Danceability\": 0.392, \"Energy\": 0.574, \"Loudness\": -9.195, \"Speechiness\": 0.17, \"Acousticness\": 0.833, \"Liveness\": 0.145, \"Tempo\": 81.112, \"Duration (ms)\": 214707.0, \"Valence\": 0.529, \"Chord\": \"G\"}, {\"Index\": 426, \"Highest Charting Position\": 104, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Why'd You Only Call Me When You're High?\", \"Streams\": 4976405, \"Artist\": \"Arctic Monkeys\", \"Artist Followers\": 12375514.0, \"Song ID\": \"086myS9r57YsLbJpU0TgK9\", \"Genre\": \"['garage rock', 'permanent wave', 'rock', 'sheffield indie']\", \"Release Date\": \"2013-09-09\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 82.0, \"Danceability\": 0.691, \"Energy\": 0.631, \"Loudness\": -6.478, \"Speechiness\": 0.0368, \"Acousticness\": 0.0483, \"Liveness\": 0.104, \"Tempo\": 92.004, \"Duration (ms)\": 161124.0, \"Valence\": 0.8, \"Chord\": \"D\"}, {\"Index\": 427, \"Highest Charting Position\": 18, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Afterglow\", \"Streams\": 4965330, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 1250353.0, \"Song ID\": \"5dA45onYgYACRp8C5xEOS9\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\", \"Popularity\": 0.0, \"Danceability\": 0.641, \"Energy\": 0.324, \"Loudness\": -5.851, \"Speechiness\": 0.0299, \"Acousticness\": 0.698, \"Liveness\": 0.328, \"Tempo\": 110.184, \"Duration (ms)\": 185487.0, \"Valence\": 0.273, \"Chord\": \"B\"}, {\"Index\": 428, \"Highest Charting Position\": 43, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"LA CANCI\\u00d3N\", \"Streams\": 4959754, \"Artist\": \"J Balvin, Bad Bunny\", \"Artist Followers\": 29051363.0, \"Song ID\": \"0fea68AdmYNygeTGI4RC18\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.754, \"Energy\": 0.646, \"Loudness\": -5.795, \"Speechiness\": 0.317, \"Acousticness\": 0.152, \"Liveness\": 0.108, \"Tempo\": 176.089, \"Duration (ms)\": 242573.0, \"Valence\": 0.429, \"Chord\": \"G\"}, {\"Index\": 429, \"Highest Charting Position\": 52, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"You Belong With Me (Taylor\\u2019s Version)\", \"Streams\": 9872084, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1qrpoAMXodY6895hGKoUpA\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 73.0, \"Danceability\": 0.632, \"Energy\": 0.773, \"Loudness\": -4.856, \"Speechiness\": 0.0346, \"Acousticness\": 0.0623, \"Liveness\": 0.0885, \"Tempo\": 130.033, \"Duration (ms)\": 231124.0, \"Valence\": 0.474, \"Chord\": \"F#/Gb\"}, {\"Index\": 430, \"Highest Charting Position\": 54, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Fearless (Taylor\\u2019s Version)\", \"Streams\": 9676024, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"77sMIMlNaSURUAXq5coCxE\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 69.0, \"Danceability\": 0.569, \"Energy\": 0.741, \"Loudness\": -4.963, \"Speechiness\": 0.0282, \"Acousticness\": 0.0122, \"Liveness\": 0.333, \"Tempo\": 100.118, \"Duration (ms)\": 241592.0, \"Valence\": 0.43, \"Chord\": \"F\"}, {\"Index\": 431, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"X Gon' Give It To Ya\", \"Streams\": 8638360, \"Artist\": \"DMX\", \"Artist Followers\": 2815928.0, \"Song ID\": \"1zzxoZVylsna2BQB65Ppcb\", \"Genre\": \"['east coast hip hop', 'gangster rap', 'hardcore hip hop', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2007-06-12\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 73.0, \"Danceability\": 0.761, \"Energy\": 0.899, \"Loudness\": -3.09, \"Speechiness\": 0.183, \"Acousticness\": 0.0135, \"Liveness\": 0.0719, \"Tempo\": 95.027, \"Duration (ms)\": 217587.0, \"Valence\": 0.673, \"Chord\": \"A#/Bb\"}, {\"Index\": 432, \"Highest Charting Position\": 80, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Fifteen (Taylor\\u2019s Version)\", \"Streams\": 7852063, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2nqio0SfWg6gh2eCtfuMa5\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 66.0, \"Danceability\": 0.559, \"Energy\": 0.646, \"Loudness\": -4.61, \"Speechiness\": 0.0272, \"Acousticness\": 0.116, \"Liveness\": 0.32, \"Tempo\": 95.466, \"Duration (ms)\": 294419.0, \"Valence\": 0.289, \"Chord\": \"G\"}, {\"Index\": 433, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"The Way I Loved You (Taylor\\u2019s Version)\", \"Streams\": 7736262, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"22bPsP2jCgbLUvh82U0Z3M\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 72.0, \"Danceability\": 0.402, \"Energy\": 0.732, \"Loudness\": -4.665, \"Speechiness\": 0.0484, \"Acousticness\": 0.0033, \"Liveness\": 0.108, \"Tempo\": 161.032, \"Duration (ms)\": 243137.0, \"Valence\": 0.472, \"Chord\": \"F\"}, {\"Index\": 434, \"Highest Charting Position\": 51, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"You All Over Me (feat. Maren Morris) (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 7712896, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5pcjystBtalYeqaiXCcgEY\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 65.0, \"Danceability\": 0.589, \"Energy\": 0.496, \"Loudness\": -7.606, \"Speechiness\": 0.0377, \"Acousticness\": 0.818, \"Liveness\": 0.101, \"Tempo\": 142.731, \"Duration (ms)\": 220839.0, \"Valence\": 0.44, \"Chord\": \"D\"}, {\"Index\": 435, \"Highest Charting Position\": 93, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Hey Stephen (Taylor\\u2019s Version)\", \"Streams\": 7385864, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"550erGcdD9n6PnwxrvYqZT\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 66.0, \"Danceability\": 0.788, \"Energy\": 0.571, \"Loudness\": -6.135, \"Speechiness\": 0.0296, \"Acousticness\": 0.106, \"Liveness\": 0.0934, \"Tempo\": 115.99, \"Duration (ms)\": 254255.0, \"Valence\": 0.797, \"Chord\": \"F#/Gb\"}, {\"Index\": 436, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"White Horse (Taylor\\u2019s Version)\", \"Streams\": 7039222, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5YL553x8sHderRBDlm3NM3\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 65.0, \"Danceability\": 0.423, \"Energy\": 0.517, \"Loudness\": -7.377, \"Speechiness\": 0.0486, \"Acousticness\": 0.369, \"Liveness\": 0.177, \"Tempo\": 185.262, \"Duration (ms)\": 234516.0, \"Valence\": 0.366, \"Chord\": \"C\"}, {\"Index\": 437, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Forever & Always (Taylor\\u2019s Version)\", \"Streams\": 6566059, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1msEuwSBneBKpVCZQcFTsU\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 66.0, \"Danceability\": 0.598, \"Energy\": 0.821, \"Loudness\": -4.433, \"Speechiness\": 0.0447, \"Acousticness\": 0.0231, \"Liveness\": 0.143, \"Tempo\": 128.03, \"Duration (ms)\": 225328.0, \"Valence\": 0.673, \"Chord\": \"A#/Bb\"}, {\"Index\": 438, \"Highest Charting Position\": 119, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Breathe (feat. Colbie Caillat) (Taylor\\u2019s Version)\", \"Streams\": 6508683, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7HC7R2D8WjXVcUHJyEGjRs\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 64.0, \"Danceability\": 0.506, \"Energy\": 0.626, \"Loudness\": -6.066, \"Speechiness\": 0.0287, \"Acousticness\": 0.156, \"Liveness\": 0.228, \"Tempo\": 148.035, \"Duration (ms)\": 263377.0, \"Valence\": 0.321, \"Chord\": \"C#/Db\"}, {\"Index\": 439, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Ruff Ryders' Anthem\", \"Streams\": 5988511, \"Artist\": \"DMX\", \"Artist Followers\": 2815928.0, \"Song ID\": \"1BKT2I9x4RGKaKqW4up34s\", \"Genre\": \"['east coast hip hop', 'gangster rap', 'hardcore hip hop', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"1998-05-01\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 72.0, \"Danceability\": 0.88, \"Energy\": 0.577, \"Loudness\": -8.093, \"Speechiness\": 0.302, \"Acousticness\": 0.0564, \"Liveness\": 0.201, \"Tempo\": 90.991, \"Duration (ms)\": 214440.0, \"Valence\": 0.74, \"Chord\": \"A#/Bb\"}, {\"Index\": 440, \"Highest Charting Position\": 146, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"That\\u2019s When (feat. Keith Urban) (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5889939, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7eResoqEJJAVTkQYSqvO3P\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 67.0, \"Danceability\": 0.588, \"Energy\": 0.608, \"Loudness\": -7.062, \"Speechiness\": 0.0365, \"Acousticness\": 0.225, \"Liveness\": 0.092, \"Tempo\": 90.201, \"Duration (ms)\": 189496.0, \"Valence\": 0.508, \"Chord\": \"F\"}, {\"Index\": 441, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Tell Me Why (Taylor\\u2019s Version)\", \"Streams\": 5885151, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0k0vFacOHNuArLWMiH60p7\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 63.0, \"Danceability\": 0.578, \"Energy\": 0.909, \"Loudness\": -3.669, \"Speechiness\": 0.0628, \"Acousticness\": 0.0222, \"Liveness\": 0.333, \"Tempo\": 100.023, \"Duration (ms)\": 200576.0, \"Valence\": 0.541, \"Chord\": \"G\"}, {\"Index\": 442, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"You\\u2019re Not Sorry (Taylor\\u2019s Version)\", \"Streams\": 5860405, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6iiAfo4wTA2CVC3Uwx9uh8\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 64.0, \"Danceability\": 0.506, \"Energy\": 0.444, \"Loudness\": -4.99, \"Speechiness\": 0.0285, \"Acousticness\": 0.0538, \"Liveness\": 0.123, \"Tempo\": 133.873, \"Duration (ms)\": 261843.0, \"Valence\": 0.241, \"Chord\": \"F#/Gb\"}, {\"Index\": 443, \"Highest Charting Position\": 40, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Chica Ideal\", \"Streams\": 5217052, \"Artist\": \"Sebastian Yatra, Guaynaa\", \"Artist Followers\": 1250353.0, \"Song ID\": \"6M3Bdl5UtQtmjnYDW69LZQ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 0.0, \"Danceability\": 0.574, \"Energy\": 0.891, \"Loudness\": -3.665, \"Speechiness\": 0.157, \"Acousticness\": 0.0847, \"Liveness\": 0.16, \"Tempo\": 100.978, \"Duration (ms)\": 183240.0, \"Valence\": 0.707, \"Chord\": \"C\"}, {\"Index\": 444, \"Highest Charting Position\": 15, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Relaci\\u00f3n - Remix\", \"Streams\": 5206614, \"Artist\": \"Sech, Daddy Yankee, J Balvin, ROSAL\\u00cdA, Farruko\", \"Artist Followers\": 8758283.0, \"Song ID\": \"35UUpTmrcFXNIVIN26ujXl\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 80.0, \"Danceability\": 0.793, \"Energy\": 0.771, \"Loudness\": -3.417, \"Speechiness\": 0.0959, \"Acousticness\": 0.0337, \"Liveness\": 0.284, \"Tempo\": 171.943, \"Duration (ms)\": 247308.0, \"Valence\": 0.835, \"Chord\": \"F\"}, {\"Index\": 445, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Don\\u2019t You (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5197564, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"4uuEGH5SVuzkkSFjo2DEiY\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 65.0, \"Danceability\": 0.563, \"Energy\": 0.473, \"Loudness\": -11.548, \"Speechiness\": 0.0503, \"Acousticness\": 0.514, \"Liveness\": 0.109, \"Tempo\": 101.934, \"Duration (ms)\": 208609.0, \"Valence\": 0.405, \"Chord\": \"D#/Eb\"}, {\"Index\": 446, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"We Were Happy (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5189423, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"34V9RiEPe8MNdU32qJsJa1\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 64.0, \"Danceability\": 0.609, \"Energy\": 0.373, \"Loudness\": -8.819, \"Speechiness\": 0.0263, \"Acousticness\": 0.849, \"Liveness\": 0.0779, \"Tempo\": 106.007, \"Duration (ms)\": 244237.0, \"Valence\": 0.13, \"Chord\": \"C\"}, {\"Index\": 447, \"Highest Charting Position\": 153, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"WACHA\", \"Streams\": 5172999, \"Artist\": \"KHEA, Duki\", \"Artist Followers\": 3198705.0, \"Song ID\": \"5RmSunLqeDqNWww8LWhAiK\", \"Genre\": \"['argentine hip hop', 'trap argentino', 'trap latino', 'trap triste']\", \"Release Date\": \"2021-04-01\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 75.0, \"Danceability\": 0.737, \"Energy\": 0.634, \"Loudness\": -4.25, \"Speechiness\": 0.0424, \"Acousticness\": 0.345, \"Liveness\": 0.111, \"Tempo\": 94.927, \"Duration (ms)\": 206360.0, \"Valence\": 0.528, \"Chord\": \"D#/Eb\"}, {\"Index\": 448, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Dancing With The Devil\", \"Streams\": 5836326, \"Artist\": \"Demi Lovato\", \"Artist Followers\": 20338833.0, \"Song ID\": \"2kONpeXXK70YEs7c0UQbmq\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-04-02--2021-04-09\", \"Popularity\": 66.0, \"Danceability\": 0.413, \"Energy\": 0.64, \"Loudness\": -5.811, \"Speechiness\": 0.0427, \"Acousticness\": 0.273, \"Liveness\": 0.11, \"Tempo\": 75.245, \"Duration (ms)\": 243992.0, \"Valence\": 0.149, \"Chord\": \"G#/Ab\"}, {\"Index\": 449, \"Highest Charting Position\": 26, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Gone\", \"Streams\": 5427638, \"Artist\": \"ROS\\u00c9\", \"Artist Followers\": 1099480.0, \"Song ID\": \"2dHoVW9AxJVSRebPRyV2aA\", \"Genre\": \"[]\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 71.0, \"Danceability\": 0.647, \"Energy\": 0.377, \"Loudness\": -6.003, \"Speechiness\": 0.0375, \"Acousticness\": 0.594, \"Liveness\": 0.0768, \"Tempo\": 79.936, \"Duration (ms)\": 207164.0, \"Valence\": 0.653, \"Chord\": \"F#/Gb\"}, {\"Index\": 450, \"Highest Charting Position\": 160, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"What Other People Say\", \"Streams\": 5413003, \"Artist\": \"Sam Fischer, Demi Lovato\", \"Artist Followers\": 122746.0, \"Song ID\": \"2h9TDNEXRhcDIV3fsoEVq9\", \"Genre\": \"['alt z', 'australian pop', 'dance pop', 'indie cafe pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2021-02-04\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\", \"Popularity\": 77.0, \"Danceability\": 0.652, \"Energy\": 0.472, \"Loudness\": -8.084, \"Speechiness\": 0.0399, \"Acousticness\": 0.158, \"Liveness\": 0.121, \"Tempo\": 126.904, \"Duration (ms)\": 194890.0, \"Valence\": 0.24, \"Chord\": \"G\"}, {\"Index\": 451, \"Highest Charting Position\": 88, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Hello (feat. A Boogie Wit da Hoodie)\", \"Streams\": 5323062, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"2r6OAV3WsYtXuXjvJ1lIDi\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-20\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 82.0, \"Danceability\": 0.905, \"Energy\": 0.647, \"Loudness\": -5.065, \"Speechiness\": 0.107, \"Acousticness\": 0.0187, \"Liveness\": 0.282, \"Tempo\": 130.97, \"Duration (ms)\": 190534.0, \"Valence\": 0.367, \"Chord\": \"A#/Bb\"}, {\"Index\": 452, \"Highest Charting Position\": 91, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Hasta Abajo\", \"Streams\": 5269163, \"Artist\": \"Kevin Roldan, Bryant Myers, Lyanno\", \"Artist Followers\": 4026643.0, \"Song ID\": \"4PEfJZpVjdclfzZ9XO8uDw\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'reggaeton colombiano', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 77.0, \"Danceability\": 0.714, \"Energy\": 0.671, \"Loudness\": -5.119, \"Speechiness\": 0.362, \"Acousticness\": 0.289, \"Liveness\": 0.325, \"Tempo\": 169.732, \"Duration (ms)\": 229827.0, \"Valence\": 0.641, \"Chord\": \"F\"}, {\"Index\": 453, \"Highest Charting Position\": 30, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Take You Dancing\", \"Streams\": 5176493, \"Artist\": \"Jason Derulo\", \"Artist Followers\": 9778632.0, \"Song ID\": \"59qrUpoplZxbIZxk6X0Bm3\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2020-07-22\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 82.0, \"Danceability\": 0.789, \"Energy\": 0.711, \"Loudness\": -4.248, \"Speechiness\": 0.041, \"Acousticness\": 0.0332, \"Liveness\": 0.0876, \"Tempo\": 112.985, \"Duration (ms)\": 190306.0, \"Valence\": 0.753, \"Chord\": \"D\"}, {\"Index\": 454, \"Highest Charting Position\": 28, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Unstable (feat. The Kid LAROI)\", \"Streams\": 5137645, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"137mSruegm1u6x9NvwiagR\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 74.0, \"Danceability\": 0.495, \"Energy\": 0.333, \"Loudness\": -10.109, \"Speechiness\": 0.0288, \"Acousticness\": 0.737, \"Liveness\": 0.112, \"Tempo\": 99.757, \"Duration (ms)\": 158324.0, \"Valence\": 0.37, \"Chord\": \"E\"}, {\"Index\": 455, \"Highest Charting Position\": 2, \"Number of Times Charted\": 48, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Stuck with U (with Justin Bieber)\", \"Streams\": 5094660, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"4HBZA5flZLE435QTztThqH\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 84.0, \"Danceability\": 0.597, \"Energy\": 0.45, \"Loudness\": -6.658, \"Speechiness\": 0.0418, \"Acousticness\": 0.223, \"Liveness\": 0.382, \"Tempo\": 178.765, \"Duration (ms)\": 228482.0, \"Valence\": 0.537, \"Chord\": \"G#/Ab\"}, {\"Index\": 456, \"Highest Charting Position\": 120, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Hayloft\", \"Streams\": 5086382, \"Artist\": \"Mother Mother\", \"Artist Followers\": 2110870.0, \"Song ID\": \"2kS6td1yvmpNgZTt1q5pQq\", \"Genre\": \"['indie pop', 'vancouver indie']\", \"Release Date\": \"2008-09-23\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 81.0, \"Danceability\": 0.527, \"Energy\": 0.922, \"Loudness\": -2.666, \"Speechiness\": 0.0728, \"Acousticness\": 0.00475, \"Liveness\": 0.422, \"Tempo\": 95.975, \"Duration (ms)\": 181680.0, \"Valence\": 0.49, \"Chord\": \"A\"}, {\"Index\": 457, \"Highest Charting Position\": 191, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Esquema Preferido (feat. Tarc\\u00edsio do Acordeon)\", \"Streams\": 5078174, \"Artist\": \"DJ Ivis\", \"Artist Followers\": 342930.0, \"Song ID\": \"0e6NlGJxYlHvAN8SKxad7N\", \"Genre\": \"['piseiro']\", \"Release Date\": \"2020-11-26\", \"Weeks Charted\": \"2021-04-02--2021-04-09\", \"Popularity\": 73.0, \"Danceability\": 0.676, \"Energy\": 0.823, \"Loudness\": -4.386, \"Speechiness\": 0.102, \"Acousticness\": 0.242, \"Liveness\": 0.0773, \"Tempo\": 160.013, \"Duration (ms)\": 190680.0, \"Valence\": 0.907, \"Chord\": \"F\"}, {\"Index\": 458, \"Highest Charting Position\": 75, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Adem\\u00e1s de M\\u00ed - Remix\", \"Streams\": 5060336, \"Artist\": \"Rusherking, KHEA, Duki, Maria Becerra, LIT killah, Tiago PZK\", \"Artist Followers\": 301217.0, \"Song ID\": \"7I8L3vYCLThw2FDrE6LuzE\", \"Genre\": \"['trap argentino', 'trap latino', 'trap triste']\", \"Release Date\": \"2021-03-04\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 78.0, \"Danceability\": 0.397, \"Energy\": 0.613, \"Loudness\": -5.077, \"Speechiness\": 0.0549, \"Acousticness\": 0.0396, \"Liveness\": 0.192, \"Tempo\": 78.4, \"Duration (ms)\": 330040.0, \"Valence\": 0.405, \"Chord\": \"F#/Gb\"}, {\"Index\": 459, \"Highest Charting Position\": 193, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Payphone\", \"Streams\": 5052717, \"Artist\": \"Maroon 5, Wiz Khalifa\", \"Artist Followers\": 32279979.0, \"Song ID\": \"1LmN9SSHISbtp9LoaR5ZVJ\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2012-01-01\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 74.0, \"Danceability\": 0.739, \"Energy\": 0.756, \"Loudness\": -4.828, \"Speechiness\": 0.0394, \"Acousticness\": 0.0136, \"Liveness\": 0.37, \"Tempo\": 110.028, \"Duration (ms)\": 231387.0, \"Valence\": 0.523, \"Chord\": \"E\"}, {\"Index\": 460, \"Highest Charting Position\": 50, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Ghost\", \"Streams\": 5013450, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6I3mqTwhRpn34SLVafSH7G\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 71.0, \"Danceability\": 0.601, \"Energy\": 0.741, \"Loudness\": -5.569, \"Speechiness\": 0.0478, \"Acousticness\": 0.185, \"Liveness\": 0.415, \"Tempo\": 153.96, \"Duration (ms)\": 153190.0, \"Valence\": 0.441, \"Chord\": \"D\"}, {\"Index\": 461, \"Highest Charting Position\": 37, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Off My Face\", \"Streams\": 5004111, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"3T03rPwlL8NVk1yIaxeD8U\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 75.0, \"Danceability\": 0.509, \"Energy\": 0.228, \"Loudness\": -8.68, \"Speechiness\": 0.0332, \"Acousticness\": 0.92, \"Liveness\": 0.104, \"Tempo\": 90.674, \"Duration (ms)\": 156468.0, \"Valence\": 0.586, \"Chord\": \"E\"}, {\"Index\": 462, \"Highest Charting Position\": 140, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Whats Poppin (feat. DaBaby, Tory Lanez & Lil Wayne) [Remix] - Bonus Track\", \"Streams\": 4972518, \"Artist\": \"Jack Harlow\", \"Artist Followers\": 1053324.0, \"Song ID\": \"0ZLuW8uOXdFNWcI40C0OC2\", \"Genre\": \"['deep underground hip hop', 'kentucky hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\", \"Popularity\": 73.0, \"Danceability\": 0.904, \"Energy\": 0.723, \"Loudness\": -5.224, \"Speechiness\": 0.26, \"Acousticness\": 0.0631, \"Liveness\": 0.185, \"Tempo\": 145.013, \"Duration (ms)\": 227478.0, \"Valence\": 0.835, \"Chord\": \"B\"}, {\"Index\": 463, \"Highest Charting Position\": 188, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Take on Me\", \"Streams\": 4969662, \"Artist\": \"a-ha\", \"Artist Followers\": 1560784.0, \"Song ID\": \"2WfaOiMkCvy7F5fcp2zZ8L\", \"Genre\": \"['new romantic', 'new wave', 'new wave pop', 'permanent wave', 'soft rock', 'synthpop']\", \"Release Date\": \"1985-06-01\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 84.0, \"Danceability\": 0.573, \"Energy\": 0.902, \"Loudness\": -7.638, \"Speechiness\": 0.054, \"Acousticness\": 0.018, \"Liveness\": 0.0928, \"Tempo\": 84.412, \"Duration (ms)\": 225280.0, \"Valence\": 0.876, \"Chord\": \"F#/Gb\"}, {\"Index\": 464, \"Highest Charting Position\": 45, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"BEB\\u00c9\", \"Streams\": 4967348, \"Artist\": \"Camilo, El Alfa\", \"Artist Followers\": 10580764.0, \"Song ID\": \"7D7EH7MGyNHWSkqrszerI1\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-11-25\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 78.0, \"Danceability\": 0.862, \"Energy\": 0.72, \"Loudness\": -4.048, \"Speechiness\": 0.0379, \"Acousticness\": 0.487, \"Liveness\": 0.0604, \"Tempo\": 129.972, \"Duration (ms)\": 198707.0, \"Valence\": 0.965, \"Chord\": \"E\"}, {\"Index\": 465, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Richer (feat. Polo G)\", \"Streams\": 6292362, \"Artist\": \"Rod Wave\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-03-26--2021-04-02\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 466, \"Highest Charting Position\": 128, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Tu Veneno\", \"Streams\": 6007541, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"5KFHrrBMyGj5MhVbZMM3ts\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 76.0, \"Danceability\": 0.664, \"Energy\": 0.659, \"Loudness\": -4.232, \"Speechiness\": 0.0873, \"Acousticness\": 0.0625, \"Liveness\": 0.0874, \"Tempo\": 175.826, \"Duration (ms)\": 157320.0, \"Valence\": 0.797, \"Chord\": \"A#/Bb\"}, {\"Index\": 467, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Deserve You\", \"Streams\": 5837372, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5NU40QTlXrDUJzDBdv79bg\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 69.0, \"Danceability\": 0.677, \"Energy\": 0.633, \"Loudness\": -7.831, \"Speechiness\": 0.0771, \"Acousticness\": 0.0314, \"Liveness\": 0.112, \"Tempo\": 89.934, \"Duration (ms)\": 187239.0, \"Valence\": 0.409, \"Chord\": \"G\"}, {\"Index\": 468, \"Highest Charting Position\": 44, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"2 Much\", \"Streams\": 5794583, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"0oaY19dUwZimIgzn3ZZLZO\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 70.0, \"Danceability\": 0.583, \"Energy\": 0.444, \"Loudness\": -8.601, \"Speechiness\": 0.0456, \"Acousticness\": 0.593, \"Liveness\": 0.353, \"Tempo\": 119.59, \"Duration (ms)\": 152796.0, \"Valence\": 0.167, \"Chord\": \"A\"}, {\"Index\": 469, \"Highest Charting Position\": 3, \"Number of Times Charted\": 66, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Tusa\", \"Streams\": 5510113, \"Artist\": \"KAROL G, Nicki Minaj\", \"Artist Followers\": 17792779.0, \"Song ID\": \"7k4t7uLgtOxPwTpFmtJNTY\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.803, \"Energy\": 0.715, \"Loudness\": -3.28, \"Speechiness\": 0.298, \"Acousticness\": 0.295, \"Liveness\": 0.0574, \"Tempo\": 101.085, \"Duration (ms)\": 200960.0, \"Valence\": 0.574, \"Chord\": \"D\"}, {\"Index\": 470, \"Highest Charting Position\": 34, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Una Locura\", \"Streams\": 5466954, \"Artist\": \"Ozuna, J Balvin, Chencho Corleone\", \"Artist Followers\": 29238936.0, \"Song ID\": \"5y7DaS3jAc9eZzcSOoUIwU\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 81.0, \"Danceability\": 0.714, \"Energy\": 0.761, \"Loudness\": -4.596, \"Speechiness\": 0.0427, \"Acousticness\": 0.139, \"Liveness\": 0.241, \"Tempo\": 168.022, \"Duration (ms)\": 230693.0, \"Valence\": 0.906, \"Chord\": \"F\"}, {\"Index\": 471, \"Highest Charting Position\": 61, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Loved By You (feat. Burna Boy)\", \"Streams\": 5419040, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2tB9OFgAHjAds3cqquLlvp\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 69.0, \"Danceability\": 0.79, \"Energy\": 0.724, \"Loudness\": -6.972, \"Speechiness\": 0.0852, \"Acousticness\": 0.0696, \"Liveness\": 0.113, \"Tempo\": 101.04, \"Duration (ms)\": 159250.0, \"Valence\": 0.642, \"Chord\": \"C#/Db\"}, {\"Index\": 472, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Girls Like Us\", \"Streams\": 5410730, \"Artist\": \"Zoe Wees\", \"Artist Followers\": 203555.0, \"Song ID\": \"5SFXOMJJ334Wn2PwBHeRZN\", \"Genre\": \"['german pop']\", \"Release Date\": \"2021-01-12\", \"Weeks Charted\": \"2021-03-26--2021-04-02\", \"Popularity\": 78.0, \"Danceability\": 0.444, \"Energy\": 0.648, \"Loudness\": -4.955, \"Speechiness\": 0.0476, \"Acousticness\": 0.288, \"Liveness\": 0.059, \"Tempo\": 125.706, \"Duration (ms)\": 189000.0, \"Valence\": 0.171, \"Chord\": \"C#/Db\"}, {\"Index\": 473, \"Highest Charting Position\": 17, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Lemon Pepper Freestyle (feat. Rick Ross)\", \"Streams\": 5365747, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"4FRW5Nza1Ym91BGV4nFWXI\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 76.0, \"Danceability\": 0.77, \"Energy\": 0.637, \"Loudness\": -5.53, \"Speechiness\": 0.345, \"Acousticness\": 0.103, \"Liveness\": 0.171, \"Tempo\": 94.966, \"Duration (ms)\": 383037.0, \"Valence\": 0.431, \"Chord\": \"C#/Db\"}, {\"Index\": 474, \"Highest Charting Position\": 97, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Esquema Preferido\", \"Streams\": 5356696, \"Artist\": \"DJ Ivis, Tarc\\u00edsio do Acordeon\", \"Artist Followers\": 342930.0, \"Song ID\": \"0e6NlGJxYlHvAN8SKxad7N\", \"Genre\": \"['piseiro']\", \"Release Date\": \"2020-11-26\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 73.0, \"Danceability\": 0.676, \"Energy\": 0.823, \"Loudness\": -4.386, \"Speechiness\": 0.102, \"Acousticness\": 0.242, \"Liveness\": 0.0773, \"Tempo\": 160.013, \"Duration (ms)\": 190680.0, \"Valence\": 0.907, \"Chord\": \"F\"}, {\"Index\": 475, \"Highest Charting Position\": 105, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Love Not War (The Tampa Beat)\", \"Streams\": 5326719, \"Artist\": \"Jason Derulo, Nuka\", \"Artist Followers\": 9778632.0, \"Song ID\": \"4Lt6GXGzYsa1tgkv3nGSTm\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 79.0, \"Danceability\": 0.738, \"Energy\": 0.85, \"Loudness\": -3.049, \"Speechiness\": 0.0642, \"Acousticness\": 0.105, \"Liveness\": 0.23, \"Tempo\": 98.013, \"Duration (ms)\": 192921.0, \"Valence\": 0.865, \"Chord\": \"G#/Ab\"}, {\"Index\": 476, \"Highest Charting Position\": 57, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Die For You (feat. Dominic Fike)\", \"Streams\": 5323412, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"7aely3H8kMj9o0gt6vXHE1\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 67.0, \"Danceability\": 0.728, \"Energy\": 0.629, \"Loudness\": -6.629, \"Speechiness\": 0.0318, \"Acousticness\": 0.00196, \"Liveness\": 0.0847, \"Tempo\": 135.031, \"Duration (ms)\": 198426.0, \"Valence\": 0.71, \"Chord\": \"C#/Db\"}, {\"Index\": 477, \"Highest Charting Position\": 64, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Starboy\", \"Streams\": 5302285, \"Artist\": \"The Weeknd, Daft Punk\", \"Artist Followers\": 35340069.0, \"Song ID\": \"7MXVkk9YMctZqd1Srtv4MB\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2016-11-25\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 83.0, \"Danceability\": 0.679, \"Energy\": 0.587, \"Loudness\": -7.015, \"Speechiness\": 0.276, \"Acousticness\": 0.141, \"Liveness\": 0.137, \"Tempo\": 186.003, \"Duration (ms)\": 230453.0, \"Valence\": 0.486, \"Chord\": \"G\"}, {\"Index\": 478, \"Highest Charting Position\": 22, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"La T\\u00f3xica\", \"Streams\": 5255393, \"Artist\": \"Farruko\", \"Artist Followers\": 10510156.0, \"Song ID\": \"15OjBeqNX3bShsGYQbteRv\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 78.0, \"Danceability\": 0.659, \"Energy\": 0.701, \"Loudness\": -4.107, \"Speechiness\": 0.164, \"Acousticness\": 0.0882, \"Liveness\": 0.0866, \"Tempo\": 91.97, \"Duration (ms)\": 180520.0, \"Valence\": 0.623, \"Chord\": \"A\"}, {\"Index\": 479, \"Highest Charting Position\": 181, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Cora\\u00e7\\u00e3o Na Cama - Ao Vivo\", \"Streams\": 5211351, \"Artist\": \"Hugo & Guilherme\", \"Artist Followers\": 435936.0, \"Song ID\": \"2nZj5YymF54qhAu7RneVP6\", \"Genre\": \"['sertanejo pop']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 77.0, \"Danceability\": 0.764, \"Energy\": 0.794, \"Loudness\": -4.096, \"Speechiness\": 0.0589, \"Acousticness\": 0.663, \"Liveness\": 0.34, \"Tempo\": 110.013, \"Duration (ms)\": 173227.0, \"Valence\": 0.721, \"Chord\": \"G#/Ab\"}, {\"Index\": 480, \"Highest Charting Position\": 60, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Love You Different (feat. BEAM)\", \"Streams\": 10024729, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"27UcQ6dAvQrgH9C880rCM3\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-19--2021-03-26\", \"Popularity\": 66.0, \"Danceability\": 0.759, \"Energy\": 0.584, \"Loudness\": -6.655, \"Speechiness\": 0.06, \"Acousticness\": 0.0652, \"Liveness\": 0.16, \"Tempo\": 127.138, \"Duration (ms)\": 186696.0, \"Valence\": 0.374, \"Chord\": \"G#/Ab\"}, {\"Index\": 481, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Somebody\", \"Streams\": 8912458, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"3rLIv187BhjyweFe89SgLn\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2010-01-01\", \"Weeks Charted\": \"2021-03-19--2021-03-26\", \"Popularity\": 67.0, \"Danceability\": 0.714, \"Energy\": 0.833, \"Loudness\": -5.239, \"Speechiness\": 0.0259, \"Acousticness\": 0.00249, \"Liveness\": 0.298, \"Tempo\": 129.964, \"Duration (ms)\": 220920.0, \"Valence\": 0.663, \"Chord\": \"F\"}, {\"Index\": 482, \"Highest Charting Position\": 152, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"White Dress\", \"Streams\": 5796978, \"Artist\": \"Lana Del Rey\", \"Artist Followers\": 13697048.0, \"Song ID\": \"4Hl9rOqYomojCmxYfr25im\", \"Genre\": \"['art pop', 'pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-19--2021-03-26\", \"Popularity\": 65.0, \"Danceability\": 0.493, \"Energy\": 0.263, \"Loudness\": -12.805, \"Speechiness\": 0.0351, \"Acousticness\": 0.926, \"Liveness\": 0.0879, \"Tempo\": 122.792, \"Duration (ms)\": 333710.0, \"Valence\": 0.158, \"Chord\": \"C\"}, {\"Index\": 483, \"Highest Charting Position\": 82, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Polvo\", \"Streams\": 5528508, \"Artist\": \"Nicky Jam, Myke Towers\", \"Artist Followers\": 14831925.0, \"Song ID\": \"68mrW6gXHgupgSiDHgaDi5\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 76.0, \"Danceability\": 0.763, \"Energy\": 0.621, \"Loudness\": -6.169, \"Speechiness\": 0.066, \"Acousticness\": 0.0105, \"Liveness\": 0.106, \"Tempo\": 82.042, \"Duration (ms)\": 211130.0, \"Valence\": 0.582, \"Chord\": \"B\"}, {\"Index\": 484, \"Highest Charting Position\": 138, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Chemtrails Over The Country Club\", \"Streams\": 5418816, \"Artist\": \"Lana Del Rey\", \"Artist Followers\": 13697048.0, \"Song ID\": \"7bPWdJgx8vek7S5i5yAtvG\", \"Genre\": \"['art pop', 'pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-01-15--2021-01-22\", \"Popularity\": 73.0, \"Danceability\": 0.334, \"Energy\": 0.276, \"Loudness\": -13.125, \"Speechiness\": 0.0643, \"Acousticness\": 0.877, \"Liveness\": 0.113, \"Tempo\": 201.025, \"Duration (ms)\": 271177.0, \"Valence\": 0.429, \"Chord\": \"E\"}, {\"Index\": 485, \"Highest Charting Position\": 37, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Parce (feat. Justin Quiles)\", \"Streams\": 5312876, \"Artist\": \"Maluma, Lenny Tav\\u00e1rez\", \"Artist Followers\": 26769304.0, \"Song ID\": \"4RJz8NfIe09gpKMiRUWKhJ\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 78.0, \"Danceability\": 0.691, \"Energy\": 0.739, \"Loudness\": -3.09, \"Speechiness\": 0.229, \"Acousticness\": 0.422, \"Liveness\": 0.11, \"Tempo\": 83.897, \"Duration (ms)\": 248345.0, \"Valence\": 0.884, \"Chord\": \"F\"}, {\"Index\": 486, \"Highest Charting Position\": 40, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Ropa Cara\", \"Streams\": 5249427, \"Artist\": \"Camilo\", \"Artist Followers\": 10580764.0, \"Song ID\": \"7BIy3EGQhg98CsRdKYHnJC\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2021-01-18\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 73.0, \"Danceability\": 0.813, \"Energy\": 0.526, \"Loudness\": -4.787, \"Speechiness\": 0.125, \"Acousticness\": 0.105, \"Liveness\": 0.11, \"Tempo\": 170.002, \"Duration (ms)\": 163320.0, \"Valence\": 0.608, \"Chord\": \"E\"}, {\"Index\": 487, \"Highest Charting Position\": 25, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Vida de Rico\", \"Streams\": 5189822, \"Artist\": \"Camilo\", \"Artist Followers\": 10580764.0, \"Song ID\": \"73nAK3HgQK8dak83Y2WQ8F\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-09-21\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 79.0, \"Danceability\": 0.824, \"Energy\": 0.457, \"Loudness\": -5.428, \"Speechiness\": 0.0543, \"Acousticness\": 0.167, \"Liveness\": 0.041, \"Tempo\": 87.977, \"Duration (ms)\": 187427.0, \"Valence\": 0.95, \"Chord\": \"F#/Gb\"}, {\"Index\": 488, \"Highest Charting Position\": 182, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Devil Eyes\", \"Streams\": 5098581, \"Artist\": \"Hippie Sabotage\", \"Artist Followers\": 713486.0, \"Song ID\": \"7MiZjKawmXTsTNePyTfPyL\", \"Genre\": \"['edm', 'electronic trap']\", \"Release Date\": \"2016-02-05\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 80.0, \"Danceability\": 0.391, \"Energy\": 0.396, \"Loudness\": -8.621, \"Speechiness\": 0.189, \"Acousticness\": 0.702, \"Liveness\": 0.315, \"Tempo\": 99.112, \"Duration (ms)\": 131272.0, \"Valence\": 0.199, \"Chord\": \"C#/Db\"}, {\"Index\": 489, \"Highest Charting Position\": 141, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Ponte Pa' Mi\", \"Streams\": 5082870, \"Artist\": \"Justin Quiles\", \"Artist Followers\": 2897862.0, \"Song ID\": \"4C6BlqqMwjFzOXzqpTeoWR\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 76.0, \"Danceability\": 0.878, \"Energy\": 0.713, \"Loudness\": -4.566, \"Speechiness\": 0.0948, \"Acousticness\": 0.0581, \"Liveness\": 0.0822, \"Tempo\": 92.028, \"Duration (ms)\": 202373.0, \"Valence\": 0.615, \"Chord\": \"F\"}, {\"Index\": 490, \"Highest Charting Position\": 109, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"D\\u00e1melo To\\u2019 (feat. Myke Towers)\", \"Streams\": 6426522, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"36CiGk9oRdwTnBDMgKEfjl\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 64.0, \"Danceability\": 0.787, \"Energy\": 0.641, \"Loudness\": -7.376, \"Speechiness\": 0.315, \"Acousticness\": 0.101, \"Liveness\": 0.07, \"Tempo\": 182.003, \"Duration (ms)\": 184134.0, \"Valence\": 0.437, \"Chord\": \"G#/Ab\"}, {\"Index\": 491, \"Highest Charting Position\": 121, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Patience (feat. YUNGBLUD & Polo G)\", \"Streams\": 6155698, \"Artist\": \"KSI\", \"Artist Followers\": 2010879.0, \"Song ID\": \"5J5CpT6bgE6KYKk23jgp9W\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 71.0, \"Danceability\": 0.616, \"Energy\": 0.741, \"Loudness\": -4.272, \"Speechiness\": 0.0426, \"Acousticness\": 0.00251, \"Liveness\": 0.307, \"Tempo\": 122.012, \"Duration (ms)\": 181720.0, \"Valence\": 0.431, \"Chord\": \"G\"}, {\"Index\": 492, \"Highest Charting Position\": 56, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Selfish Love (with Selena Gomez)\", \"Streams\": 6020785, \"Artist\": \"DJ Snake\", \"Artist Followers\": 7408249.0, \"Song ID\": \"3XoflnowYPFRPOh3uFvHcm\", \"Genre\": \"['dance pop', 'edm', 'electronic trap', 'pop', 'pop dance']\", \"Release Date\": \"2021-03-04\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 74.0, \"Danceability\": 0.723, \"Energy\": 0.646, \"Loudness\": -7.973, \"Speechiness\": 0.102, \"Acousticness\": 0.0206, \"Liveness\": 0.0994, \"Tempo\": 110.971, \"Duration (ms)\": 168649.0, \"Valence\": 0.443, \"Chord\": \"F\"}, {\"Index\": 493, \"Highest Charting Position\": 12, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Snowman\", \"Streams\": 5454807, \"Artist\": \"Sia\", \"Artist Followers\": 20528724.0, \"Song ID\": \"7uoFMmxln0GPXQ0AcCBXRq\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'pop']\", \"Release Date\": \"2018-11-01\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 77.0, \"Danceability\": 0.716, \"Energy\": 0.512, \"Loudness\": -6.257, \"Speechiness\": 0.0331, \"Acousticness\": 0.483, \"Liveness\": 0.0928, \"Tempo\": 104.957, \"Duration (ms)\": 165907.0, \"Valence\": 0.326, \"Chord\": \"C#/Db\"}, {\"Index\": 494, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"DAYWALKER! (feat. CORPSE)\", \"Streams\": 5439646, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3868320.0, \"Song ID\": \"2NnJpRXIlx35Vij3bPZO0h\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 74.0, \"Danceability\": 0.632, \"Energy\": 0.922, \"Loudness\": -2.173, \"Speechiness\": 0.0794, \"Acousticness\": 0.00558, \"Liveness\": 0.0927, \"Tempo\": 88.972, \"Duration (ms)\": 137747.0, \"Valence\": 0.497, \"Chord\": \"G\"}, {\"Index\": 495, \"Highest Charting Position\": 19, \"Number of Times Charted\": 38, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"La Curiosidad\", \"Streams\": 5198514, \"Artist\": \"Jay Wheeler, DJ Nelson, Myke Towers\", \"Artist Followers\": 1650912.0, \"Song ID\": \"4HYDUMY0xSpeBr0AMY9cUz\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 82.0, \"Danceability\": 0.845, \"Energy\": 0.677, \"Loudness\": -4.798, \"Speechiness\": 0.136, \"Acousticness\": 0.269, \"Liveness\": 0.108, \"Tempo\": 90.013, \"Duration (ms)\": 219048.0, \"Valence\": 0.68, \"Chord\": \"B\"}, {\"Index\": 496, \"Highest Charting Position\": 86, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"All We Got (feat. KIDDO)\", \"Streams\": 5156937, \"Artist\": \"Robin Schulz\", \"Artist Followers\": 2786366.0, \"Song ID\": \"1FP9s72rDYty6mfoOEYKnE\", \"Genre\": \"['dance pop', 'deep euro house', 'deep house', 'edm', 'german dance', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 74.0, \"Danceability\": 0.504, \"Energy\": 0.76, \"Loudness\": -4.246, \"Speechiness\": 0.0426, \"Acousticness\": 0.286, \"Liveness\": 0.151, \"Tempo\": 183.933, \"Duration (ms)\": 190218.0, \"Valence\": 0.64, \"Chord\": \"E\"}, {\"Index\": 497, \"Highest Charting Position\": 6, \"Number of Times Charted\": 60, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Say So\", \"Streams\": 5103528, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"3Dv1eDb0MEgF93GpLXlucZ\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-02-26--2021-03-05\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.787, \"Energy\": 0.673, \"Loudness\": -4.583, \"Speechiness\": 0.159, \"Acousticness\": 0.264, \"Liveness\": 0.0904, \"Tempo\": 110.962, \"Duration (ms)\": 237893.0, \"Valence\": 0.779, \"Chord\": \"B\"}, {\"Index\": 498, \"Highest Charting Position\": 157, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Hope\", \"Streams\": 5085527, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"2ZRo7axmMPeSVUvDbGkJah\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2018-03-16\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 84.0, \"Danceability\": 0.592, \"Energy\": 0.457, \"Loudness\": -6.081, \"Speechiness\": 0.0603, \"Acousticness\": 0.661, \"Liveness\": 0.146, \"Tempo\": 146.04, \"Duration (ms)\": 110886.0, \"Valence\": 0.225, \"Chord\": \"A\"}, {\"Index\": 499, \"Highest Charting Position\": 149, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"The Less I Know The Better\", \"Streams\": 5084635, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"6K4t31amVTZDgR3sKmwUJJ\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2015-07-17\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-01-03--2020-01-10\", \"Popularity\": 84.0, \"Danceability\": 0.64, \"Energy\": 0.74, \"Loudness\": -4.083, \"Speechiness\": 0.0284, \"Acousticness\": 0.0115, \"Liveness\": 0.167, \"Tempo\": 116.879, \"Duration (ms)\": 216320.0, \"Valence\": 0.785, \"Chord\": \"E\"}, {\"Index\": 500, \"Highest Charting Position\": 109, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"I Feel It Coming\", \"Streams\": 5079857, \"Artist\": \"The Weeknd, Daft Punk\", \"Artist Followers\": 35340069.0, \"Song ID\": \"3dhjNA0jGA8vHBQ1VdD6vV\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2016-11-25\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 80.0, \"Danceability\": 0.773, \"Energy\": 0.819, \"Loudness\": -5.946, \"Speechiness\": 0.118, \"Acousticness\": 0.428, \"Liveness\": 0.0679, \"Tempo\": 92.987, \"Duration (ms)\": 269187.0, \"Valence\": 0.585, \"Chord\": \"C\"}, {\"Index\": 501, \"Highest Charting Position\": 12, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Mood Swings (feat. Lil Tjay)\", \"Streams\": 5068349, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"5rZlwNFl01HqLWBQGryKSm\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 82.0, \"Danceability\": 0.48, \"Energy\": 0.602, \"Loudness\": -6.335, \"Speechiness\": 0.368, \"Acousticness\": 0.487, \"Liveness\": 0.0848, \"Tempo\": 179.798, \"Duration (ms)\": 213333.0, \"Valence\": 0.269, \"Chord\": \"A#/Bb\"}, {\"Index\": 502, \"Highest Charting Position\": 123, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Someone To You\", \"Streams\": 5054881, \"Artist\": \"BANNERS\", \"Artist Followers\": 419151.0, \"Song ID\": \"2f0pn9DkEJwAzXApnFh5cr\", \"Genre\": \"['indie cafe pop', 'indie poptimism', 'modern rock', 'pop', 'pop rock']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 79.0, \"Danceability\": 0.52, \"Energy\": 0.903, \"Loudness\": -5.497, \"Speechiness\": 0.042, \"Acousticness\": 0.00517, \"Liveness\": 0.254, \"Tempo\": 74.988, \"Duration (ms)\": 219801.0, \"Valence\": 0.652, \"Chord\": \"D\"}, {\"Index\": 503, \"Highest Charting Position\": 198, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"To the Bone\", \"Streams\": 5052557, \"Artist\": \"Pamungkas\", \"Artist Followers\": 1643882.0, \"Song ID\": \"3pCt2wRdBDa2kCisIdHWgF\", \"Genre\": \"['indonesian pop']\", \"Release Date\": \"2019-06-14\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 81.0, \"Danceability\": 0.668, \"Energy\": 0.727, \"Loudness\": -6.55, \"Speechiness\": 0.027, \"Acousticness\": 0.514, \"Liveness\": 0.1, \"Tempo\": 139.991, \"Duration (ms)\": 344571.0, \"Valence\": 0.939, \"Chord\": \"G\"}, {\"Index\": 504, \"Highest Charting Position\": 4, \"Number of Times Charted\": 38, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"How You Like That\", \"Streams\": 5023592, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"4SFknyjLcyTLJFPKD2m96o\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 79.0, \"Danceability\": 0.812, \"Energy\": 0.761, \"Loudness\": -5.222, \"Speechiness\": 0.0812, \"Acousticness\": 0.0465, \"Liveness\": 0.0601, \"Tempo\": 130.032, \"Duration (ms)\": 182956.0, \"Valence\": 0.344, \"Chord\": \"B\"}, {\"Index\": 505, \"Highest Charting Position\": 200, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"LOST\", \"Streams\": 5013851, \"Artist\": \"NF, Hopsin\", \"Artist Followers\": 5831194.0, \"Song ID\": \"2MZrOmrVxRmmOoFW6dhenG\", \"Genre\": \"['hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2021-03-11\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 66.0, \"Danceability\": 0.637, \"Energy\": 0.912, \"Loudness\": -3.123, \"Speechiness\": 0.308, \"Acousticness\": 0.352, \"Liveness\": 0.0657, \"Tempo\": 116.919, \"Duration (ms)\": 234852.0, \"Valence\": 0.451, \"Chord\": \"F\"}, {\"Index\": 506, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"VOCE\", \"Streams\": 5510906, \"Artist\": \"Madame\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6CAVxdHTkls5loqUmfM52V\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 0.0, \"Danceability\": 0.615, \"Energy\": 0.834, \"Loudness\": -5.471, \"Speechiness\": 0.0667, \"Acousticness\": 0.105, \"Liveness\": 0.157, \"Tempo\": 112.602, \"Duration (ms)\": 211411.0, \"Valence\": 0.341, \"Chord\": \"G#/Ab\"}, {\"Index\": 507, \"Highest Charting Position\": 64, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"AP - Music from the film Boogie\", \"Streams\": 5462333, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"17vGPZ5EsdvtgAOCD4FLWI\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\", \"Popularity\": 75.0, \"Danceability\": 0.751, \"Energy\": 0.744, \"Loudness\": -6.859, \"Speechiness\": 0.177, \"Acousticness\": 0.152, \"Liveness\": 0.252, \"Tempo\": 148.014, \"Duration (ms)\": 171892.0, \"Valence\": 0.634, \"Chord\": \"C#/Db\"}, {\"Index\": 508, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Life's A Mess II (with Clever & Post Malone)\", \"Streams\": 5393459, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4O3RwH1TFG1EjPezLIYehI\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 72.0, \"Danceability\": 0.53, \"Energy\": 0.37, \"Loudness\": -9.989, \"Speechiness\": 0.0279, \"Acousticness\": 0.806, \"Liveness\": 0.112, \"Tempo\": 140.061, \"Duration (ms)\": 206734.0, \"Valence\": 0.701, \"Chord\": \"F#/Gb\"}, {\"Index\": 509, \"Highest Charting Position\": 170, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"CHIAMAMI PER NOME\", \"Streams\": 5321946, \"Artist\": \"Francesca Michielin, Fedez\", \"Artist Followers\": 568711.0, \"Song ID\": \"0ZqHo6eTBHUcOVjZzPvftT\", \"Genre\": \"['italian adult pop', 'italian indie pop', 'italian pop', 'italian pop rock']\", \"Release Date\": \"2021-03-03\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 67.0, \"Danceability\": 0.641, \"Energy\": 0.636, \"Loudness\": -4.318, \"Speechiness\": 0.0414, \"Acousticness\": 0.289, \"Liveness\": 0.125, \"Tempo\": 89.826, \"Duration (ms)\": 222667.0, \"Valence\": 0.285, \"Chord\": \"A#/Bb\"}, {\"Index\": 510, \"Highest Charting Position\": 54, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Antes\", \"Streams\": 5232377, \"Artist\": \"Anuel AA, Ozuna\", \"Artist Followers\": 18306226.0, \"Song ID\": \"73O30uMI7n6DuzBmbtO7kC\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 73.0, \"Danceability\": 0.817, \"Energy\": 0.737, \"Loudness\": -5.453, \"Speechiness\": 0.102, \"Acousticness\": 0.046, \"Liveness\": 0.092, \"Tempo\": 93.985, \"Duration (ms)\": 206587.0, \"Valence\": 0.67, \"Chord\": \"F#/Gb\"}, {\"Index\": 511, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Mona Lisa\", \"Streams\": 5208787, \"Artist\": \"Booba, JSX\", \"Artist Followers\": 2161609.0, \"Song ID\": \"5LYRIyhmlrDAQsYdHEvP0f\", \"Genre\": \"['french hip hop', 'old school rap francais', 'pop urbaine', 'rap conscient']\", \"Release Date\": \"2021-03-04\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 72.0, \"Danceability\": 0.784, \"Energy\": 0.529, \"Loudness\": -7.681, \"Speechiness\": 0.0742, \"Acousticness\": 0.683, \"Liveness\": 0.118, \"Tempo\": 134.041, \"Duration (ms)\": 187362.0, \"Valence\": 0.246, \"Chord\": \"B\"}, {\"Index\": 512, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Real As It Gets (feat. EST Gee)\", \"Streams\": 5170861, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"7eX3um6NpOQKWJMGCi97XD\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2021-03-04\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 74.0, \"Danceability\": 0.779, \"Energy\": 0.705, \"Loudness\": -5.891, \"Speechiness\": 0.163, \"Acousticness\": 0.00471, \"Liveness\": 0.0971, \"Tempo\": 140.005, \"Duration (ms)\": 192804.0, \"Valence\": 0.196, \"Chord\": \"F#/Gb\"}, {\"Index\": 513, \"Highest Charting Position\": 24, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Se Te Nota (with Guaynaa)\", \"Streams\": 5168240, \"Artist\": \"Lele Pons\", \"Artist Followers\": 786461.0, \"Song ID\": \"11EnQRgRMJwMAesfkB5pnu\", \"Genre\": \"['latin pop', 'viral pop']\", \"Release Date\": \"2020-09-02\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 77.0, \"Danceability\": 0.905, \"Energy\": 0.686, \"Loudness\": -3.152, \"Speechiness\": 0.0664, \"Acousticness\": 0.0907, \"Liveness\": 0.266, \"Tempo\": 103.013, \"Duration (ms)\": 155825.0, \"Valence\": 0.963, \"Chord\": \"C\"}, {\"Index\": 514, \"Highest Charting Position\": 91, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Head Shoulders Knees & Toes (feat. Norma Jean Martine)\", \"Streams\": 5093408, \"Artist\": \"Ofenbach, Quarterhead\", \"Artist Followers\": 432511.0, \"Song ID\": \"6i7zAdNhzUN2k1HcrBxPHG\", \"Genre\": \"['edm', 'new french touch', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 79.0, \"Danceability\": 0.798, \"Energy\": 0.828, \"Loudness\": -5.36, \"Speechiness\": 0.193, \"Acousticness\": 0.0247, \"Liveness\": 0.121, \"Tempo\": 124.962, \"Duration (ms)\": 156960.0, \"Valence\": 0.6, \"Chord\": \"D\"}, {\"Index\": 515, \"Highest Charting Position\": 152, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Star Shopping\", \"Streams\": 5073657, \"Artist\": \"Lil Peep\", \"Artist Followers\": 7535054.0, \"Song ID\": \"30bqVoKjX479ab90a8Pafp\", \"Genre\": \"['emo rap', 'lgbtq+ hip hop']\", \"Release Date\": \"2015\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 82.0, \"Danceability\": 0.585, \"Energy\": 0.471, \"Loudness\": -9.934, \"Speechiness\": 0.0616, \"Acousticness\": 0.0967, \"Liveness\": 0.115, \"Tempo\": 93.099, \"Duration (ms)\": 142000.0, \"Valence\": 0.323, \"Chord\": \"E\"}, {\"Index\": 516, \"Highest Charting Position\": 61, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Electric Love\", \"Streams\": 5060903, \"Artist\": \"B\\u00d8RNS\", \"Artist Followers\": 1027085.0, \"Song ID\": \"2GiJYvgVaD2HtM8GqD9EgQ\", \"Genre\": \"['modern alternative rock', 'modern rock', 'pop']\", \"Release Date\": \"2015-10-16\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 83.0, \"Danceability\": 0.611, \"Energy\": 0.797, \"Loudness\": -7.627, \"Speechiness\": 0.0533, \"Acousticness\": 0.00543, \"Liveness\": 0.26, \"Tempo\": 120.041, \"Duration (ms)\": 218107.0, \"Valence\": 0.518, \"Chord\": \"F#/Gb\"}, {\"Index\": 517, \"Highest Charting Position\": 112, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Maniac\", \"Streams\": 5044929, \"Artist\": \"Conan Gray\", \"Artist Followers\": 3799104.0, \"Song ID\": \"6KfoDhO4XUWSbnyKjNp9c4\", \"Genre\": \"['alt z', 'bedroom pop', 'electropop', 'indie pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.628, \"Energy\": 0.639, \"Loudness\": -5.46, \"Speechiness\": 0.0435, \"Acousticness\": 0.00162, \"Liveness\": 0.354, \"Tempo\": 108.045, \"Duration (ms)\": 185773.0, \"Valence\": 0.493, \"Chord\": \"G#/Ab\"}, {\"Index\": 518, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Only Wanna Be With You - Pok\\u00e9mon 25 Version\", \"Streams\": 7464020, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"3SawmGBjjq8EOYZJV11cJm\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2021-02-25\", \"Weeks Charted\": \"2021-02-26--2021-03-05\", \"Popularity\": 72.0, \"Danceability\": 0.47, \"Energy\": 0.709, \"Loudness\": -4.563, \"Speechiness\": 0.0299, \"Acousticness\": 0.00124, \"Liveness\": 0.302, \"Tempo\": 98.036, \"Duration (ms)\": 241360.0, \"Valence\": 0.247, \"Chord\": \"G\"}, {\"Index\": 519, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"test drive\", \"Streams\": 6591829, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3eZYOQO4UzKrUDYDghtnFw\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-02-19\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 71.0, \"Danceability\": 0.698, \"Energy\": 0.708, \"Loudness\": -4.943, \"Speechiness\": 0.0454, \"Acousticness\": 0.0251, \"Liveness\": 0.124, \"Tempo\": 115.036, \"Duration (ms)\": 122174.0, \"Valence\": 0.322, \"Chord\": \"A\"}, {\"Index\": 520, \"Highest Charting Position\": 42, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"T\\u00fa Me Dejaste De Querer\", \"Streams\": 5874460, \"Artist\": \"C. Tangana, Ni\\u00f1o de Elche, La H\\u00fangara\", \"Artist Followers\": 1453875.0, \"Song ID\": \"5ddFjrPG8NgQQ6xlOQIVd2\", \"Genre\": \"['urbano espanol']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 75.0, \"Danceability\": 0.823, \"Energy\": 0.723, \"Loudness\": -4.778, \"Speechiness\": 0.229, \"Acousticness\": 0.311, \"Liveness\": 0.0998, \"Tempo\": 83.97, \"Duration (ms)\": 198493.0, \"Valence\": 0.505, \"Chord\": \"E\"}, {\"Index\": 521, \"Highest Charting Position\": 46, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"SO DONE\", \"Streams\": 5440707, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"5psEZhQu6lukjhavJo4AbC\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-10-23\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 74.0, \"Danceability\": 0.719, \"Energy\": 0.598, \"Loudness\": -6.254, \"Speechiness\": 0.077, \"Acousticness\": 0.232, \"Liveness\": 0.115, \"Tempo\": 142.592, \"Duration (ms)\": 126521.0, \"Valence\": 0.303, \"Chord\": \"A\"}, {\"Index\": 522, \"Highest Charting Position\": 35, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Jeans\", \"Streams\": 5145966, \"Artist\": \"Justin Quiles\", \"Artist Followers\": 2897862.0, \"Song ID\": \"3GtnId3Cm1Xa6joCj08nzW\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 75.0, \"Danceability\": 0.807, \"Energy\": 0.656, \"Loudness\": -4.395, \"Speechiness\": 0.105, \"Acousticness\": 0.0165, \"Liveness\": 0.0693, \"Tempo\": 83.943, \"Duration (ms)\": 185840.0, \"Valence\": 0.89, \"Chord\": \"D#/Eb\"}, {\"Index\": 523, \"Highest Charting Position\": 2, \"Number of Times Charted\": 61, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"ROXANNE\", \"Streams\": 5124742, \"Artist\": \"Arizona Zervas\", \"Artist Followers\": 621200.0, \"Song ID\": \"696DnlkuDOXcMAnKlTgXXK\", \"Genre\": \"['pop rap', 'rhode island rap']\", \"Release Date\": \"2019-10-10\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.621, \"Energy\": 0.601, \"Loudness\": -5.616, \"Speechiness\": 0.148, \"Acousticness\": 0.0522, \"Liveness\": 0.46, \"Tempo\": 116.735, \"Duration (ms)\": 163636.0, \"Valence\": 0.457, \"Chord\": \"F#/Gb\"}, {\"Index\": 524, \"Highest Charting Position\": 83, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"rockstar (feat. 21 Savage)\", \"Streams\": 5115990, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"0e7ipj03S05BNilyu5bRzt\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2018-04-27\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-01-29--2021-02-05\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.585, \"Energy\": 0.52, \"Loudness\": -6.136, \"Speechiness\": 0.0712, \"Acousticness\": 0.124, \"Liveness\": 0.131, \"Tempo\": 159.801, \"Duration (ms)\": 218147.0, \"Valence\": 0.129, \"Chord\": \"F\"}, {\"Index\": 525, \"Highest Charting Position\": 185, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"P\\u00e1rteme La Cara\", \"Streams\": 5079580, \"Artist\": \"C. Tangana, Ed Maverick\", \"Artist Followers\": 1453875.0, \"Song ID\": \"5gEUDNQvoQjdjklrwPdGwD\", \"Genre\": \"['urbano espanol']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-02-26--2021-03-05\", \"Popularity\": 70.0, \"Danceability\": 0.761, \"Energy\": 0.296, \"Loudness\": -10.22, \"Speechiness\": 0.0484, \"Acousticness\": 0.551, \"Liveness\": 0.134, \"Tempo\": 127.938, \"Duration (ms)\": 167867.0, \"Valence\": 0.579, \"Chord\": \"C\"}, {\"Index\": 526, \"Highest Charting Position\": 80, \"Number of Times Charted\": 57, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Without Me\", \"Streams\": 5016283, \"Artist\": \"Halsey\", \"Artist Followers\": 15663384.0, \"Song ID\": \"5p7ujcrUXASCNwRaWNHR1C\", \"Genre\": \"['dance pop', 'electropop', 'etherpop', 'indie poptimism', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-10-04\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.752, \"Energy\": 0.488, \"Loudness\": -7.05, \"Speechiness\": 0.0705, \"Acousticness\": 0.297, \"Liveness\": 0.0936, \"Tempo\": 136.041, \"Duration (ms)\": 201661.0, \"Valence\": 0.533, \"Chord\": \"F#/Gb\"}, {\"Index\": 527, \"Highest Charting Position\": 33, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"BOOKER T\", \"Streams\": 4995965, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"26w9NTiE9NGjW1ZvIOd1So\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 77.0, \"Danceability\": 0.883, \"Energy\": 0.6, \"Loudness\": -7.188, \"Speechiness\": 0.37, \"Acousticness\": 0.114, \"Liveness\": 0.0931, \"Tempo\": 113.903, \"Duration (ms)\": 156430.0, \"Valence\": 0.691, \"Chord\": \"G\"}, {\"Index\": 528, \"Highest Charting Position\": 5, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Intentions (feat. Quavo)\", \"Streams\": 4994138, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"4umIPjkehX1r7uhmGvXiSV\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 77.0, \"Danceability\": 0.806, \"Energy\": 0.546, \"Loudness\": -6.637, \"Speechiness\": 0.0575, \"Acousticness\": 0.3, \"Liveness\": 0.102, \"Tempo\": 147.986, \"Duration (ms)\": 212867.0, \"Valence\": 0.874, \"Chord\": \"A\"}, {\"Index\": 529, \"Highest Charting Position\": 49, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Sofia\", \"Streams\": 4982892, \"Artist\": \"Clairo\", \"Artist Followers\": 2722638.0, \"Song ID\": \"7B3z0ySL9Rr0XvZEAjWZzM\", \"Genre\": \"['bedroom pop', 'indie pop', 'pop']\", \"Release Date\": \"2019-08-02\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 81.0, \"Danceability\": 0.744, \"Energy\": 0.619, \"Loudness\": -9.805, \"Speechiness\": 0.039, \"Acousticness\": 0.598, \"Liveness\": 0.231, \"Tempo\": 112.997, \"Duration (ms)\": 188387.0, \"Valence\": 0.641, \"Chord\": \"C\"}, {\"Index\": 530, \"Highest Charting Position\": 176, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Photograph\", \"Streams\": 4974880, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"1HNkqx9Ahdgi1Ixy2xkKkL\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2014-06-21\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-02-07--2020-02-14\\n2020-01-03--2020-01-10\", \"Popularity\": 83.0, \"Danceability\": 0.614, \"Energy\": 0.379, \"Loudness\": -10.48, \"Speechiness\": 0.0476, \"Acousticness\": 0.607, \"Liveness\": 0.0986, \"Tempo\": 107.989, \"Duration (ms)\": 258987.0, \"Valence\": 0.201, \"Chord\": \"E\"}, {\"Index\": 531, \"Highest Charting Position\": 20, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"34+35 Remix (feat. Doja Cat, Megan Thee Stallion) - Remix\", \"Streams\": 6162453, \"Artist\": \"Ariana Grande\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 532, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"Madonna\", \"Streams\": 5936752, \"Artist\": \"Bausa, Apache 207\", \"Artist Followers\": 961181.0, \"Song ID\": \"6a3kNt1UlUOapDKmEr3JzZ\", \"Genre\": \"['german hip hop', 'german pop']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-02-19--2021-02-26\", \"Popularity\": 68.0, \"Danceability\": 0.806, \"Energy\": 0.565, \"Loudness\": -8.96, \"Speechiness\": 0.113, \"Acousticness\": 0.47, \"Liveness\": 0.0824, \"Tempo\": 116.963, \"Duration (ms)\": 195734.0, \"Valence\": 0.311, \"Chord\": \"B\"}, {\"Index\": 533, \"Highest Charting Position\": 144, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"CLOUDS\", \"Streams\": 5897983, \"Artist\": \"NF\", \"Artist Followers\": 5831194.0, \"Song ID\": \"5UMMPHPp6vRP6ghPpSUOzp\", \"Genre\": \"['hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2021-02-18\", \"Weeks Charted\": \"2021-02-19--2021-02-26\", \"Popularity\": 69.0, \"Danceability\": 0.793, \"Energy\": 0.65, \"Loudness\": -3.944, \"Speechiness\": 0.397, \"Acousticness\": 0.371, \"Liveness\": 0.854, \"Tempo\": 128.111, \"Duration (ms)\": 243750.0, \"Valence\": 0.809, \"Chord\": \"C#/Db\"}, {\"Index\": 534, \"Highest Charting Position\": 12, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Wonder\", \"Streams\": 5535339, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 1251372.0, \"Song ID\": \"7jjS2fSD9zuzbEHeVEFJ2w\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 0.0, \"Danceability\": 0.333, \"Energy\": 0.637, \"Loudness\": -4.904, \"Speechiness\": 0.0581, \"Acousticness\": 0.131, \"Liveness\": 0.149, \"Tempo\": 139.898, \"Duration (ms)\": 172693.0, \"Valence\": 0.132, \"Chord\": \"C#/Db\"}, {\"Index\": 535, \"Highest Charting Position\": 50, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Skin\", \"Streams\": 5497942, \"Artist\": \"Sabrina Carpenter\", \"Artist Followers\": 3689546.0, \"Song ID\": \"03B2SfXuvDh1m9F4tqrX07\", \"Genre\": \"['alt z', 'dance pop', 'electropop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 76.0, \"Danceability\": 0.557, \"Energy\": 0.457, \"Loudness\": -5.372, \"Speechiness\": 0.0335, \"Acousticness\": 0.428, \"Liveness\": 0.0567, \"Tempo\": 105.918, \"Duration (ms)\": 177500.0, \"Valence\": 0.328, \"Chord\": \"G\"}, {\"Index\": 536, \"Highest Charting Position\": 62, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Tyler Herro\", \"Streams\": 5168107, \"Artist\": \"Jack Harlow\", \"Artist Followers\": 1053324.0, \"Song ID\": \"4DuUwzP4ALMqpquHU0ltAB\", \"Genre\": \"['deep underground hip hop', 'kentucky hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-10-22\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 76.0, \"Danceability\": 0.794, \"Energy\": 0.756, \"Loudness\": -7.16, \"Speechiness\": 0.136, \"Acousticness\": 0.11, \"Liveness\": 0.247, \"Tempo\": 123.066, \"Duration (ms)\": 156498.0, \"Valence\": 0.775, \"Chord\": \"F\"}, {\"Index\": 537, \"Highest Charting Position\": 173, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Remember That Night?\", \"Streams\": 5116325, \"Artist\": \"Sara Kays\", \"Artist Followers\": 251549.0, \"Song ID\": \"1nYzjrdVQ8RpF93M0jPFW7\", \"Genre\": \"['alt z', 'indie cafe pop', 'modern indie pop', 'pop', 'social media pop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 78.0, \"Danceability\": 0.679, \"Energy\": 0.61, \"Loudness\": -10.936, \"Speechiness\": 0.0305, \"Acousticness\": 0.585, \"Liveness\": 0.156, \"Tempo\": 123.978, \"Duration (ms)\": 227186.0, \"Valence\": 0.554, \"Chord\": \"G\"}, {\"Index\": 538, \"Highest Charting Position\": 128, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Lifestyle (feat. Adam Levine)\", \"Streams\": 5059891, \"Artist\": \"Jason Derulo, Maroon 5\", \"Artist Followers\": 9778632.0, \"Song ID\": \"0osvOdeD3YXZiWkT8MKolJ\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 78.0, \"Danceability\": 0.749, \"Energy\": 0.674, \"Loudness\": -5.128, \"Speechiness\": 0.0366, \"Acousticness\": 0.0209, \"Liveness\": 0.169, \"Tempo\": 123.055, \"Duration (ms)\": 153865.0, \"Valence\": 0.711, \"Chord\": \"A#/Bb\"}, {\"Index\": 539, \"Highest Charting Position\": 177, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Fly Away\", \"Streams\": 5053713, \"Artist\": \"Tones And I\", \"Artist Followers\": 2820477.0, \"Song ID\": \"5ri4zqtWhG07hIuNNDWP76\", \"Genre\": \"['australian pop', 'pop']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 79.0, \"Danceability\": 0.806, \"Energy\": 0.513, \"Loudness\": -6.208, \"Speechiness\": 0.0685, \"Acousticness\": 0.217, \"Liveness\": 0.217, \"Tempo\": 124.988, \"Duration (ms)\": 178157.0, \"Valence\": 0.503, \"Chord\": \"E\"}, {\"Index\": 540, \"Highest Charting Position\": 37, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Despeinada\", \"Streams\": 5004462, \"Artist\": \"Ozuna, Camilo\", \"Artist Followers\": 29238936.0, \"Song ID\": \"0JAZWvvqttGFm4UMDsPQXC\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 75.0, \"Danceability\": 0.734, \"Energy\": 0.775, \"Loudness\": -3.855, \"Speechiness\": 0.0614, \"Acousticness\": 0.186, \"Liveness\": 0.123, \"Tempo\": 166.039, \"Duration (ms)\": 224187.0, \"Valence\": 0.72, \"Chord\": \"G#/Ab\"}, {\"Index\": 541, \"Highest Charting Position\": 14, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"motive (with Doja Cat)\", \"Streams\": 4986037, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"5GkQIP5mWPi4KZLLXeuFTT\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 80.0, \"Danceability\": 0.789, \"Energy\": 0.742, \"Loudness\": -5.664, \"Speechiness\": 0.0652, \"Acousticness\": 0.0681, \"Liveness\": 0.166, \"Tempo\": 116.965, \"Duration (ms)\": 167990.0, \"Valence\": 0.661, \"Chord\": \"A#/Bb\"}, {\"Index\": 542, \"Highest Charting Position\": 28, \"Number of Times Charted\": 57, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"I Don't Care (with Justin Bieber)\", \"Streams\": 4984399, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"3HVWdVOQ0ZA45FuZGSfvns\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-05-10\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.798, \"Energy\": 0.675, \"Loudness\": -5.041, \"Speechiness\": 0.0442, \"Acousticness\": 0.0912, \"Liveness\": 0.0894, \"Tempo\": 101.956, \"Duration (ms)\": 219947.0, \"Valence\": 0.842, \"Chord\": \"F#/Gb\"}, {\"Index\": 543, \"Highest Charting Position\": 14, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Ay, DiOs M\\u00edo!\", \"Streams\": 5344862, \"Artist\": \"KAROL G\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3PF1mUoD0NgK4ykdt5sk3g\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 0.0, \"Danceability\": 0.715, \"Energy\": 0.706, \"Loudness\": -4.423, \"Speechiness\": 0.195, \"Acousticness\": 0.496, \"Liveness\": 0.106, \"Tempo\": 179.997, \"Duration (ms)\": 189840.0, \"Valence\": 0.522, \"Chord\": \"B\"}, {\"Index\": 544, \"Highest Charting Position\": 83, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Nathy Peluso: Bzrp Music Sessions, Vol. 36\", \"Streams\": 5232509, \"Artist\": \"Bizarrap, Nathy Peluso\", \"Artist Followers\": 3134041.0, \"Song ID\": \"78SeXVRJ7KCqVmOwTiFjnI\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 77.0, \"Danceability\": 0.65, \"Energy\": 0.655, \"Loudness\": -3.71, \"Speechiness\": 0.405, \"Acousticness\": 0.25, \"Liveness\": 0.0691, \"Tempo\": 94.059, \"Duration (ms)\": 171215.0, \"Valence\": 0.735, \"Chord\": \"C#/Db\"}, {\"Index\": 545, \"Highest Charting Position\": 17, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Haw\\u00e1i - Remix\", \"Streams\": 5163323, \"Artist\": \"Maluma, The Weeknd\", \"Artist Followers\": 26784251.0, \"Song ID\": \"0GzuHFG4Ql6DoyxFRnIk3F\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-11-05\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 77.0, \"Danceability\": 0.766, \"Energy\": 0.788, \"Loudness\": -3.128, \"Speechiness\": 0.312, \"Acousticness\": 0.105, \"Liveness\": 0.142, \"Tempo\": 179.984, \"Duration (ms)\": 200482.0, \"Valence\": 0.609, \"Chord\": \"F#/Gb\"}, {\"Index\": 546, \"Highest Charting Position\": 22, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Tattoo - Remix with Camilo\", \"Streams\": 5120753, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6096559.0, \"Song ID\": \"4ZRrLHqzhGRXYj2qcB4s5S\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-07-09\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 78.0, \"Danceability\": 0.848, \"Energy\": 0.637, \"Loudness\": -5.132, \"Speechiness\": 0.156, \"Acousticness\": 0.0413, \"Liveness\": 0.0521, \"Tempo\": 96.988, \"Duration (ms)\": 222680.0, \"Valence\": 0.698, \"Chord\": \"A\"}, {\"Index\": 547, \"Highest Charting Position\": 151, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Meia Noite (Voc\\u00ea tem meu Whatsapp)\", \"Streams\": 5044252, \"Artist\": \"Tarc\\u00edsio do Acordeon\", \"Artist Followers\": 1200248.0, \"Song ID\": \"6sPBi0qLI6KM3yXX56NxsA\", \"Genre\": \"[]\", \"Release Date\": \"2020-12-17\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 67.0, \"Danceability\": 0.709, \"Energy\": 0.816, \"Loudness\": -4.787, \"Speechiness\": 0.0346, \"Acousticness\": 0.685, \"Liveness\": 0.146, \"Tempo\": 150.06, \"Duration (ms)\": 237900.0, \"Valence\": 0.921, \"Chord\": \"B\"}, {\"Index\": 548, \"Highest Charting Position\": 143, \"Number of Times Charted\": 42, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Moonlight\", \"Streams\": 5003825, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"0JP9xo3adEtGSdUEISiszL\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2018-03-16\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2020-09-18--2020-09-25\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.921, \"Energy\": 0.537, \"Loudness\": -5.723, \"Speechiness\": 0.0804, \"Acousticness\": 0.556, \"Liveness\": 0.102, \"Tempo\": 128.009, \"Duration (ms)\": 135090.0, \"Valence\": 0.711, \"Chord\": \"A\"}, {\"Index\": 549, \"Highest Charting Position\": 182, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Thinking out Loud\", \"Streams\": 4995623, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"34gCuhDGsG4bRPIf9bb02f\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2014-06-21\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 82.0, \"Danceability\": 0.781, \"Energy\": 0.445, \"Loudness\": -6.061, \"Speechiness\": 0.0295, \"Acousticness\": 0.474, \"Liveness\": 0.184, \"Tempo\": 78.998, \"Duration (ms)\": 281560.0, \"Valence\": 0.591, \"Chord\": \"D\"}, {\"Index\": 550, \"Highest Charting Position\": 2, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Toosie Slide\", \"Streams\": 4966878, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"127QTOFJsJQp5LbJbu3A1y\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 78.0, \"Danceability\": 0.834, \"Energy\": 0.454, \"Loudness\": -9.75, \"Speechiness\": 0.201, \"Acousticness\": 0.321, \"Liveness\": 0.114, \"Tempo\": 81.618, \"Duration (ms)\": 247059.0, \"Valence\": 0.837, \"Chord\": \"C#/Db\"}, {\"Index\": 551, \"Highest Charting Position\": 167, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Earned It (Fifty Shades Of Grey)\", \"Streams\": 4929647, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"4frLb7nWtsz2ymBE6k2GRP\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2015-08-28\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 69.0, \"Danceability\": 0.659, \"Energy\": 0.291, \"Loudness\": -8.275, \"Speechiness\": 0.0348, \"Acousticness\": 0.405, \"Liveness\": 0.0771, \"Tempo\": 119.829, \"Duration (ms)\": 277680.0, \"Valence\": 0.406, \"Chord\": \"D\"}, {\"Index\": 552, \"Highest Charting Position\": 9, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"ily (i love you baby) (feat. Emilee)\", \"Streams\": 4908929, \"Artist\": \"Surf Mesa\", \"Artist Followers\": 132855.0, \"Song ID\": \"62aP9fBQKYKxi7PDXwcUAS\", \"Genre\": \"['tropical house']\", \"Release Date\": \"2019-11-26\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 81.0, \"Danceability\": 0.674, \"Energy\": 0.774, \"Loudness\": -7.567, \"Speechiness\": 0.0892, \"Acousticness\": 0.0686, \"Liveness\": 0.393, \"Tempo\": 112.05, \"Duration (ms)\": 176547.0, \"Valence\": 0.33, \"Chord\": \"B\"}, {\"Index\": 553, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Wonderwall\", \"Streams\": 4902737, \"Artist\": \"Oasis\", \"Artist Followers\": 6478565.0, \"Song ID\": \"7ygpwy2qP3NbrxVkHvUhXY\", \"Genre\": \"['beatlesque', 'britpop', 'madchester', 'permanent wave', 'rock']\", \"Release Date\": \"1995\", \"Weeks Charted\": \"2021-02-12--2021-02-19\", \"Popularity\": 78.0, \"Danceability\": 0.375, \"Energy\": 0.893, \"Loudness\": -4.097, \"Speechiness\": 0.0406, \"Acousticness\": 0.000509, \"Liveness\": 0.187, \"Tempo\": 174.323, \"Duration (ms)\": 258773.0, \"Valence\": 0.434, \"Chord\": \"D\"}, {\"Index\": 554, \"Highest Charting Position\": 181, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Everybody Dies In Their Nightmares\", \"Streams\": 4847224, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"3GVkPk8mqxz0itaAriG1L7\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2017-08-25\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\", \"Popularity\": 83.0, \"Danceability\": 0.734, \"Energy\": 0.57, \"Loudness\": -7.066, \"Speechiness\": 0.133, \"Acousticness\": 0.847, \"Liveness\": 0.112, \"Tempo\": 129.953, \"Duration (ms)\": 95467.0, \"Valence\": 0.689, \"Chord\": \"G\"}, {\"Index\": 555, \"Highest Charting Position\": 27, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Bad Boy (with Young Thug)\", \"Streams\": 6011642, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"43CIWpJaJHRcI4mUSjqgc2\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 76.0, \"Danceability\": 0.697, \"Energy\": 0.674, \"Loudness\": -6.326, \"Speechiness\": 0.0533, \"Acousticness\": 0.00215, \"Liveness\": 0.138, \"Tempo\": 81.535, \"Duration (ms)\": 157355.0, \"Valence\": 0.198, \"Chord\": \"C#/Db\"}, {\"Index\": 556, \"Highest Charting Position\": 19, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Lo Vas A Olvidar (with ROSAL\\u00cdA)\", \"Streams\": 5963380, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"0psS4i5YooJrXfDnGvWRLi\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 68.0, \"Danceability\": 0.343, \"Energy\": 0.243, \"Loudness\": -14.66, \"Speechiness\": 0.0777, \"Acousticness\": 0.721, \"Liveness\": 0.0668, \"Tempo\": 135.154, \"Duration (ms)\": 203464.0, \"Valence\": 0.032, \"Chord\": \"E\"}, {\"Index\": 557, \"Highest Charting Position\": 152, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Floating Through Space\", \"Streams\": 5579697, \"Artist\": \"Sia, David Guetta\", \"Artist Followers\": 20528724.0, \"Song ID\": \"2AceGjiX9isUbXmMZa0Dl1\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'pop']\", \"Release Date\": \"2021-02-04\", \"Weeks Charted\": \"2021-02-05--2021-02-12\", \"Popularity\": 78.0, \"Danceability\": 0.575, \"Energy\": 0.844, \"Loudness\": -4.89, \"Speechiness\": 0.072, \"Acousticness\": 0.00172, \"Liveness\": 0.114, \"Tempo\": 104.914, \"Duration (ms)\": 177801.0, \"Valence\": 0.277, \"Chord\": \"F#/Gb\"}, {\"Index\": 558, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Can't Feel My Face\", \"Streams\": 5479407, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"22VdIZQfgXJea34mQxlt81\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2015-08-28\", \"Weeks Charted\": \"2021-02-05--2021-02-12\", \"Popularity\": 80.0, \"Danceability\": 0.705, \"Energy\": 0.769, \"Loudness\": -5.526, \"Speechiness\": 0.0425, \"Acousticness\": 0.113, \"Liveness\": 0.105, \"Tempo\": 107.949, \"Duration (ms)\": 213520.0, \"Valence\": 0.583, \"Chord\": \"A\"}, {\"Index\": 559, \"Highest Charting Position\": 89, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"You (with Marshmello & Vance Joy)\", \"Streams\": 5342938, \"Artist\": \"benny blanco\", \"Artist Followers\": 804613.0, \"Song ID\": \"1GkHyypTFkUf0QQKwYoXH4\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2021-01-29\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 73.0, \"Danceability\": 0.668, \"Energy\": 0.563, \"Loudness\": -6.433, \"Speechiness\": 0.0522, \"Acousticness\": 0.0493, \"Liveness\": 0.119, \"Tempo\": 103.116, \"Duration (ms)\": 169632.0, \"Valence\": 0.305, \"Chord\": \"B\"}, {\"Index\": 560, \"Highest Charting Position\": 168, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Call Out My Name\", \"Streams\": 5233359, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"09mEdoA6zrmBPgTEN5qXmN\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2018-03-30\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\", \"Popularity\": 80.0, \"Danceability\": 0.461, \"Energy\": 0.593, \"Loudness\": -4.954, \"Speechiness\": 0.0356, \"Acousticness\": 0.17, \"Liveness\": 0.307, \"Tempo\": 134.17, \"Duration (ms)\": 228373.0, \"Valence\": 0.175, \"Chord\": \"C#/Db\"}, {\"Index\": 561, \"Highest Charting Position\": 14, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Midnight Sky\", \"Streams\": 5208100, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"27ycaQnQAxaPiyeg3nr2aB\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 76.0, \"Danceability\": 0.705, \"Energy\": 0.814, \"Loudness\": -5.466, \"Speechiness\": 0.0346, \"Acousticness\": 0.00115, \"Liveness\": 0.203, \"Tempo\": 110.0, \"Duration (ms)\": 223279.0, \"Valence\": 0.259, \"Chord\": \"E\"}, {\"Index\": 562, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Pressure (feat. Tove Lo)\", \"Streams\": 5197587, \"Artist\": \"Martin Garrix\", \"Artist Followers\": 14921269.0, \"Song ID\": \"4ga4WvRNhMsIL38pkBbnIN\", \"Genre\": \"['dance pop', 'dutch edm', 'edm', 'pop', 'pop dance', 'progressive house', 'tropical house']\", \"Release Date\": \"2021-02-05\", \"Weeks Charted\": \"2021-02-05--2021-02-12\", \"Popularity\": 76.0, \"Danceability\": 0.859, \"Energy\": 0.558, \"Loudness\": -8.991, \"Speechiness\": 0.0902, \"Acousticness\": 0.659, \"Liveness\": 0.124, \"Tempo\": 114.978, \"Duration (ms)\": 144391.0, \"Valence\": 0.357, \"Chord\": \"G\"}, {\"Index\": 563, \"Highest Charting Position\": 140, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Can You Feel My Heart\", \"Streams\": 5092250, \"Artist\": \"Bring Me The Horizon\", \"Artist Followers\": 3912138.0, \"Song ID\": \"0WSa1sucoNRcEeULlZVQXj\", \"Genre\": \"['melodic metalcore', 'metalcore', 'rock', 'uk metalcore']\", \"Release Date\": \"2013-04-01\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 77.0, \"Danceability\": 0.15, \"Energy\": 0.859, \"Loudness\": -2.827, \"Speechiness\": 0.0595, \"Acousticness\": 0.00201, \"Liveness\": 0.387, \"Tempo\": 170.527, \"Duration (ms)\": 228147.0, \"Valence\": 0.354, \"Chord\": \"E\"}, {\"Index\": 564, \"Highest Charting Position\": 167, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Agua de Jamaica\", \"Streams\": 5072462, \"Artist\": \"Maluma\", \"Artist Followers\": 26784251.0, \"Song ID\": \"41BzKiCrKpUQHS3TP0jmdr\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-01-28\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 75.0, \"Danceability\": 0.664, \"Energy\": 0.665, \"Loudness\": -3.616, \"Speechiness\": 0.0879, \"Acousticness\": 0.123, \"Liveness\": 0.411, \"Tempo\": 173.961, \"Duration (ms)\": 176970.0, \"Valence\": 0.726, \"Chord\": \"A#/Bb\"}, {\"Index\": 565, \"Highest Charting Position\": 162, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Mds\", \"Streams\": 5046418, \"Artist\": \"Kawe, Mc Lele JP\", \"Artist Followers\": 444736.0, \"Song ID\": \"0QglpM23kl9ldvVdoYNZwF\", \"Genre\": \"['brazilian hip hop', 'funk ostentacao']\", \"Release Date\": \"2020-05-19\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 72.0, \"Danceability\": 0.885, \"Energy\": 0.561, \"Loudness\": -5.331, \"Speechiness\": 0.249, \"Acousticness\": 0.261, \"Liveness\": 0.121, \"Tempo\": 140.02, \"Duration (ms)\": 125143.0, \"Valence\": 0.644, \"Chord\": \"F#/Gb\"}, {\"Index\": 566, \"Highest Charting Position\": 18, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Heartless\", \"Streams\": 4995578, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"6bnF93Rx87YqUBLSgjiMU8\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.537, \"Energy\": 0.746, \"Loudness\": -5.507, \"Speechiness\": 0.15, \"Acousticness\": 0.0236, \"Liveness\": 0.156, \"Tempo\": 170.062, \"Duration (ms)\": 198267.0, \"Valence\": 0.252, \"Chord\": \"A#/Bb\"}, {\"Index\": 567, \"Highest Charting Position\": 20, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"pov\", \"Streams\": 4906738, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3UoULw70kMsiVXxW0L3A33\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 79.0, \"Danceability\": 0.487, \"Energy\": 0.534, \"Loudness\": -5.664, \"Speechiness\": 0.0555, \"Acousticness\": 0.36, \"Liveness\": 0.1, \"Tempo\": 131.798, \"Duration (ms)\": 201882.0, \"Valence\": 0.173, \"Chord\": \"C\"}, {\"Index\": 568, \"Highest Charting Position\": 138, \"Number of Times Charted\": 49, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Be Alright\", \"Streams\": 4900492, \"Artist\": \"Dean Lewis\", \"Artist Followers\": 1692635.0, \"Song ID\": \"3EPXxR3ImUwfayaurPi3cm\", \"Genre\": \"['australian pop', 'indie cafe pop', 'pop', 'pop rock', 'post-teen pop']\", \"Release Date\": \"2018-06-29\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.553, \"Energy\": 0.586, \"Loudness\": -6.319, \"Speechiness\": 0.0362, \"Acousticness\": 0.697, \"Liveness\": 0.0813, \"Tempo\": 126.684, \"Duration (ms)\": 196373.0, \"Valence\": 0.443, \"Chord\": \"B\"}, {\"Index\": 569, \"Highest Charting Position\": 174, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Cry Baby (feat. DaBaby)\", \"Streams\": 4884711, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"4aarlAfLKVCTxUDNgbwhjH\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 76.0, \"Danceability\": 0.957, \"Energy\": 0.437, \"Loudness\": -7.882, \"Speechiness\": 0.359, \"Acousticness\": 0.00402, \"Liveness\": 0.219, \"Tempo\": 130.058, \"Duration (ms)\": 137984.0, \"Valence\": 0.616, \"Chord\": \"B\"}, {\"Index\": 570, \"Highest Charting Position\": 47, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Mi Cuarto\", \"Streams\": 4873380, \"Artist\": \"Jerry Di\", \"Artist Followers\": 149682.0, \"Song ID\": \"6fmQjRuo7XvRFCK2qex5hQ\", \"Genre\": \"['cubaton', 'dominican pop', 'pop venezolano', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 76.0, \"Danceability\": 0.854, \"Energy\": 0.525, \"Loudness\": -4.426, \"Speechiness\": 0.214, \"Acousticness\": 0.819, \"Liveness\": 0.146, \"Tempo\": 97.054, \"Duration (ms)\": 197587.0, \"Valence\": 0.63, \"Chord\": \"C#/Db\"}, {\"Index\": 571, \"Highest Charting Position\": 99, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Ohne Dich\", \"Streams\": 5487774, \"Artist\": \"KASIMIR1441, badm\\u00f3mzjay, WILDBWOYS\", \"Artist Followers\": 197320.0, \"Song ID\": \"4hSJUp6k7QeHLxU32MrLIU\", \"Genre\": \"['german alternative rap', 'german hip hop', 'german trap', 'tekk']\", \"Release Date\": \"2021-01-14\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 70.0, \"Danceability\": 0.807, \"Energy\": 0.535, \"Loudness\": -6.519, \"Speechiness\": 0.349, \"Acousticness\": 0.191, \"Liveness\": 0.125, \"Tempo\": 156.013, \"Duration (ms)\": 125720.0, \"Valence\": 0.925, \"Chord\": \"B\"}, {\"Index\": 572, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Gravity (feat. Tyler, The Creator)\", \"Streams\": 5136895, \"Artist\": \"Brent Faiyaz, DJ Dahi\", \"Artist Followers\": 1726216.0, \"Song ID\": \"6u3CPnFMKANYgfdiifFOiJ\", \"Genre\": \"['dmv rap', 'pop', 'r&b', 'rap']\", \"Release Date\": \"2021-01-29\", \"Weeks Charted\": \"2021-01-29--2021-02-05\", \"Popularity\": 76.0, \"Danceability\": 0.539, \"Energy\": 0.615, \"Loudness\": -8.746, \"Speechiness\": 0.252, \"Acousticness\": 0.173, \"Liveness\": 0.144, \"Tempo\": 163.924, \"Duration (ms)\": 214693.0, \"Valence\": 0.493, \"Chord\": \"C#/Db\"}, {\"Index\": 573, \"Highest Charting Position\": 55, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Vibez\", \"Streams\": 5071718, \"Artist\": \"ZAYN\", \"Artist Followers\": 16655692.0, \"Song ID\": \"709F3MwiVvLD0LQXeKs5Cz\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 69.0, \"Danceability\": 0.635, \"Energy\": 0.659, \"Loudness\": -7.499, \"Speechiness\": 0.116, \"Acousticness\": 0.242, \"Liveness\": 0.105, \"Tempo\": 96.855, \"Duration (ms)\": 163127.0, \"Valence\": 0.34, \"Chord\": \"G\"}, {\"Index\": 574, \"Highest Charting Position\": 103, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"All I Want - From \\\"High School Musical: The Musical: The Series\\\"\", \"Streams\": 5052801, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6313514.0, \"Song ID\": \"4Yxc55NX3tAXC2mHRAhtcW\", \"Genre\": \"['pop']\", \"Release Date\": \"2019-11-27\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 76.0, \"Danceability\": 0.376, \"Energy\": 0.43, \"Loudness\": -6.585, \"Speechiness\": 0.0328, \"Acousticness\": 0.0902, \"Liveness\": 0.0912, \"Tempo\": 77.599, \"Duration (ms)\": 177323.0, \"Valence\": 0.129, \"Chord\": \"C\"}, {\"Index\": 575, \"Highest Charting Position\": 45, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Daisy\", \"Streams\": 5030670, \"Artist\": \"Ashnikko\", \"Artist Followers\": 1248499.0, \"Song ID\": \"0AUvWawuP0ibk4SQ3sIZjk\", \"Genre\": \"['electropop', 'escape room', 'pop']\", \"Release Date\": \"2020-07-09\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 76.0, \"Danceability\": 0.834, \"Energy\": 0.663, \"Loudness\": -6.143, \"Speechiness\": 0.133, \"Acousticness\": 0.235, \"Liveness\": 0.372, \"Tempo\": 121.876, \"Duration (ms)\": 146523.0, \"Valence\": 0.774, \"Chord\": \"G#/Ab\"}, {\"Index\": 576, \"Highest Charting Position\": 83, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Wasted On You\", \"Streams\": 4948563, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"3cBsEDNhFI9E82vPj3kvi3\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 76.0, \"Danceability\": 0.505, \"Energy\": 0.657, \"Loudness\": -5.24, \"Speechiness\": 0.0318, \"Acousticness\": 0.373, \"Liveness\": 0.126, \"Tempo\": 196.0, \"Duration (ms)\": 178520.0, \"Valence\": 0.252, \"Chord\": \"B\"}, {\"Index\": 577, \"Highest Charting Position\": 13, \"Number of Times Charted\": 38, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"La Jeepeta - Remix\", \"Streams\": 4942545, \"Artist\": \"Nio Garcia, Anuel AA, Myke Towers, Brray, Juanka\", \"Artist Followers\": 2127531.0, \"Song ID\": \"1mohfLaTJtB2RplHLQVM70\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 75.0, \"Danceability\": 0.815, \"Energy\": 0.715, \"Loudness\": -4.65, \"Speechiness\": 0.207, \"Acousticness\": 0.3, \"Liveness\": 0.091, \"Tempo\": 176.007, \"Duration (ms)\": 345241.0, \"Valence\": 0.786, \"Chord\": \"E\"}, {\"Index\": 578, \"Highest Charting Position\": 137, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Los Dioses\", \"Streams\": 5929507, \"Artist\": \"Anuel AA, Ozuna\", \"Artist Followers\": 18306226.0, \"Song ID\": \"73O30uMI7n6DuzBmbtO7kC\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-01-22--2021-01-29\", \"Popularity\": 73.0, \"Danceability\": 0.817, \"Energy\": 0.737, \"Loudness\": -5.453, \"Speechiness\": 0.102, \"Acousticness\": 0.046, \"Liveness\": 0.092, \"Tempo\": 93.985, \"Duration (ms)\": 206587.0, \"Valence\": 0.67, \"Chord\": \"F#/Gb\"}, {\"Index\": 579, \"Highest Charting Position\": 132, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Si Me Tomo Una Cerveza\", \"Streams\": 5427534, \"Artist\": \"Migrantes, Alico\", \"Artist Followers\": 114348.0, \"Song ID\": \"3lCbsHaN1wCxyDzcNN2x4N\", \"Genre\": \"['cumbia pop']\", \"Release Date\": \"2020-11-07\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 74.0, \"Danceability\": 0.72, \"Energy\": 0.613, \"Loudness\": -6.899, \"Speechiness\": 0.0572, \"Acousticness\": 0.185, \"Liveness\": 0.155, \"Tempo\": 84.974, \"Duration (ms)\": 182199.0, \"Valence\": 0.857, \"Chord\": \"C#/Db\"}, {\"Index\": 580, \"Highest Charting Position\": 90, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Somebody\\u2019s Problem\", \"Streams\": 5332437, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"0SErdEdRcVX1uJCf1eTGYH\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2020-11-20--2020-11-27\", \"Popularity\": 70.0, \"Danceability\": 0.657, \"Energy\": 0.54, \"Loudness\": -7.675, \"Speechiness\": 0.0287, \"Acousticness\": 0.662, \"Liveness\": 0.123, \"Tempo\": 136.97, \"Duration (ms)\": 161773.0, \"Valence\": 0.625, \"Chord\": \"F\"}, {\"Index\": 581, \"Highest Charting Position\": 66, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"De Una Vez\", \"Streams\": 5186567, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"1v3lhrZEsOcazqR2QIyyRu\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 70.0, \"Danceability\": 0.659, \"Energy\": 0.479, \"Loudness\": -6.79, \"Speechiness\": 0.2, \"Acousticness\": 0.152, \"Liveness\": 0.268, \"Tempo\": 163.882, \"Duration (ms)\": 155956.0, \"Valence\": 0.0395, \"Chord\": \"B\"}, {\"Index\": 582, \"Highest Charting Position\": 121, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Way Out (feat. Big Sean)\", \"Streams\": 4962949, \"Artist\": \"Jack Harlow\", \"Artist Followers\": 1053324.0, \"Song ID\": \"6rLi6PyWXu1rPlShuIZpj6\", \"Genre\": \"['deep underground hip hop', 'kentucky hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-09\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 72.0, \"Danceability\": 0.945, \"Energy\": 0.582, \"Loudness\": -8.357, \"Speechiness\": 0.0719, \"Acousticness\": 0.114, \"Liveness\": 0.103, \"Tempo\": 108.025, \"Duration (ms)\": 168906.0, \"Valence\": 0.907, \"Chord\": \"B\"}, {\"Index\": 583, \"Highest Charting Position\": 42, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Diamonds\", \"Streams\": 4931163, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"5hvwx5i67IwnCkjl9VHkNv\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-09-17\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 77.0, \"Danceability\": 0.653, \"Energy\": 0.667, \"Loudness\": -6.764, \"Speechiness\": 0.0423, \"Acousticness\": 0.154, \"Liveness\": 0.107, \"Tempo\": 104.181, \"Duration (ms)\": 213869.0, \"Valence\": 0.556, \"Chord\": \"A#/Bb\"}, {\"Index\": 584, \"Highest Charting Position\": 190, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Dancing in My Room\", \"Streams\": 4914093, \"Artist\": \"347aidan\", \"Artist Followers\": 211500.0, \"Song ID\": \"6Pgmqg15yVexuOgtzuxwoX\", \"Genre\": \"['sad rap']\", \"Release Date\": \"2020-10-26\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\", \"Popularity\": 79.0, \"Danceability\": 0.98, \"Energy\": 0.413, \"Loudness\": -11.052, \"Speechiness\": 0.101, \"Acousticness\": 0.671, \"Liveness\": 0.17, \"Tempo\": 119.993, \"Duration (ms)\": 180139.0, \"Valence\": 0.764, \"Chord\": \"G#/Ab\"}, {\"Index\": 585, \"Highest Charting Position\": 116, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"De Cora <3\", \"Streams\": 4864544, \"Artist\": \"Rauw Alejandro, J Balvin\", \"Artist Followers\": 6096559.0, \"Song ID\": \"22Sh5dlwbERqJAq1fZk5b2\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 73.0, \"Danceability\": 0.811, \"Energy\": 0.683, \"Loudness\": -2.028, \"Speechiness\": 0.241, \"Acousticness\": 0.46, \"Liveness\": 0.128, \"Tempo\": 176.037, \"Duration (ms)\": 190101.0, \"Valence\": 0.571, \"Chord\": \"B\"}, {\"Index\": 586, \"Highest Charting Position\": 10, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"champagne problems\", \"Streams\": 4848954, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0sY6ZUTh4yoctD8VIXz339\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 75.0, \"Danceability\": 0.462, \"Energy\": 0.24, \"Loudness\": -12.077, \"Speechiness\": 0.0377, \"Acousticness\": 0.92, \"Liveness\": 0.113, \"Tempo\": 171.319, \"Duration (ms)\": 244000.0, \"Valence\": 0.32, \"Chord\": \"C\"}, {\"Index\": 587, \"Highest Charting Position\": 37, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Go Crazy\", \"Streams\": 4833081, \"Artist\": \"Chris Brown, Young Thug\", \"Artist Followers\": 14073083.0, \"Song ID\": \"1IIKrJVP1C9N7iPtG6eOsK\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'r&b', 'rap']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 80.0, \"Danceability\": 0.755, \"Energy\": 0.578, \"Loudness\": -8.932, \"Speechiness\": 0.145, \"Acousticness\": 0.316, \"Liveness\": 0.25, \"Tempo\": 94.148, \"Duration (ms)\": 176960.0, \"Valence\": 0.581, \"Chord\": \"C\"}, {\"Index\": 588, \"Highest Charting Position\": 73, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Reminds Me Of You\", \"Streams\": 5942551, \"Artist\": \"Juice WRLD, The Kid LAROI\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5YSHygGN9D0mID1NsVd5my\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-12-08\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 75.0, \"Danceability\": 0.613, \"Energy\": 0.631, \"Loudness\": -6.965, \"Speechiness\": 0.12, \"Acousticness\": 0.0663, \"Liveness\": 0.169, \"Tempo\": 149.992, \"Duration (ms)\": 158033.0, \"Valence\": 0.33, \"Chord\": \"E\"}, {\"Index\": 589, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Don't Play\", \"Streams\": 5119828, \"Artist\": \"Anne-Marie, KSI, Digital Farm Animals\", \"Artist Followers\": 8153871.0, \"Song ID\": \"4I5bvu2KDsrCg0EWHIcvul\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-01-15--2021-01-22\", \"Popularity\": 73.0, \"Danceability\": 0.695, \"Energy\": 0.784, \"Loudness\": -6.564, \"Speechiness\": 0.0402, \"Acousticness\": 0.0889, \"Liveness\": 0.0843, \"Tempo\": 128.031, \"Duration (ms)\": 188581.0, \"Valence\": 0.52, \"Chord\": \"F#/Gb\"}, {\"Index\": 590, \"Highest Charting Position\": 108, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"MODO TURBO\", \"Streams\": 4983557, \"Artist\": \"Lu\\u00edsa Sonza, Pabllo Vittar, Anitta\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5217tPOJfhVUY8q9TCKHO1\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-11\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 1.0, \"Danceability\": 0.655, \"Energy\": 0.726, \"Loudness\": -7.628, \"Speechiness\": 0.0796, \"Acousticness\": 0.334, \"Liveness\": 0.232, \"Tempo\": 160.064, \"Duration (ms)\": 150260.0, \"Valence\": 0.766, \"Chord\": \"A#/Bb\"}, {\"Index\": 591, \"Highest Charting Position\": 191, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Buss It\", \"Streams\": 4915403, \"Artist\": \"Erica Banks\", \"Artist Followers\": 41551.0, \"Song ID\": \"25j0Sape7qZbq6ZPLFefTT\", \"Genre\": \"['trap queen']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2021-01-15--2021-01-22\", \"Popularity\": 72.0, \"Danceability\": 0.956, \"Energy\": 0.502, \"Loudness\": -5.995, \"Speechiness\": 0.213, \"Acousticness\": 0.0593, \"Liveness\": 0.238, \"Tempo\": 110.003, \"Duration (ms)\": 187000.0, \"Valence\": 0.795, \"Chord\": \"A\"}, {\"Index\": 592, \"Highest Charting Position\": 41, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Kings & Queens\", \"Streams\": 4855690, \"Artist\": \"Ava Max\", \"Artist Followers\": 3916979.0, \"Song ID\": \"7a53HqqArd4b9NF4XAmlbI\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 82.0, \"Danceability\": 0.637, \"Energy\": 0.69, \"Loudness\": -4.057, \"Speechiness\": 0.0405, \"Acousticness\": 0.00786, \"Liveness\": 0.124, \"Tempo\": 129.857, \"Duration (ms)\": 162399.0, \"Valence\": 0.457, \"Chord\": \"C#/Db\"}, {\"Index\": 593, \"Highest Charting Position\": 6, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Lovesick Girls\", \"Streams\": 4796365, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"4Ws314Ylb27BVsvlZOy30C\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 75.0, \"Danceability\": 0.654, \"Energy\": 0.707, \"Loudness\": -5.661, \"Speechiness\": 0.0664, \"Acousticness\": 0.00559, \"Liveness\": 0.0873, \"Tempo\": 127.97, \"Duration (ms)\": 194765.0, \"Valence\": 0.448, \"Chord\": \"F#/Gb\"}, {\"Index\": 594, \"Highest Charting Position\": 17, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Caramelo\", \"Streams\": 4790233, \"Artist\": \"Ozuna\", \"Artist Followers\": 29238936.0, \"Song ID\": \"3gD4J3RUHy4OUuZ3qAiaiG\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-06-11\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 74.0, \"Danceability\": 0.728, \"Energy\": 0.806, \"Loudness\": -3.766, \"Speechiness\": 0.0623, \"Acousticness\": 0.0531, \"Liveness\": 0.153, \"Tempo\": 168.084, \"Duration (ms)\": 217547.0, \"Valence\": 0.698, \"Chord\": \"F#/Gb\"}, {\"Index\": 595, \"Highest Charting Position\": 67, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Deep End\", \"Streams\": 5622565, \"Artist\": \"Foushe\\u00e9\", \"Artist Followers\": 411262.0, \"Song ID\": \"2AlYncTpVHKwHb55F9lF6O\", \"Genre\": \"['brooklyn drill', 'nyc rap']\", \"Release Date\": \"2020-06-05\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 72.0, \"Danceability\": 0.868, \"Energy\": 0.479, \"Loudness\": -6.687, \"Speechiness\": 0.445, \"Acousticness\": 0.703, \"Liveness\": 0.102, \"Tempo\": 133.928, \"Duration (ms)\": 115200.0, \"Valence\": 0.776, \"Chord\": \"E\"}, {\"Index\": 596, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Sand In My Boots\", \"Streams\": 5446609, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"0uRrG2jRR5tuifsYIJHEao\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\", \"Popularity\": 75.0, \"Danceability\": 0.403, \"Energy\": 0.537, \"Loudness\": -6.628, \"Speechiness\": 0.031, \"Acousticness\": 0.59, \"Liveness\": 0.112, \"Tempo\": 69.877, \"Duration (ms)\": 202133.0, \"Valence\": 0.414, \"Chord\": \"D#/Eb\"}, {\"Index\": 597, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"865\", \"Streams\": 5160123, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"0sKEilrw1GrBlG6qsTCrP4\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\", \"Popularity\": 70.0, \"Danceability\": 0.532, \"Energy\": 0.584, \"Loudness\": -5.254, \"Speechiness\": 0.0248, \"Acousticness\": 0.723, \"Liveness\": 0.101, \"Tempo\": 88.003, \"Duration (ms)\": 190680.0, \"Valence\": 0.367, \"Chord\": \"G#/Ab\"}, {\"Index\": 598, \"Highest Charting Position\": 53, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"7 Summers\", \"Streams\": 5064504, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"4obHzpwGrjoTuZh2DItEMZ\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2020-09-11--2020-09-18\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 73.0, \"Danceability\": 0.466, \"Energy\": 0.786, \"Loudness\": -5.13, \"Speechiness\": 0.0328, \"Acousticness\": 0.417, \"Liveness\": 0.125, \"Tempo\": 203.903, \"Duration (ms)\": 210507.0, \"Valence\": 0.571, \"Chord\": \"C\"}, {\"Index\": 599, \"Highest Charting Position\": 21, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"HACIENDO QUE ME AMAS\", \"Streams\": 4935633, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"26QApq0cuO9brJigr0C0W4\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 78.0, \"Danceability\": 0.584, \"Energy\": 0.411, \"Loudness\": -7.147, \"Speechiness\": 0.0838, \"Acousticness\": 0.869, \"Liveness\": 0.0955, \"Tempo\": 169.934, \"Duration (ms)\": 217769.0, \"Valence\": 0.412, \"Chord\": \"A#/Bb\"}, {\"Index\": 600, \"Highest Charting Position\": 65, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"La Luz\", \"Streams\": 4906324, \"Artist\": \"Sech, J Balvin\", \"Artist Followers\": 8766508.0, \"Song ID\": \"5zj8WNkBrEzlI5FKeYV4ol\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-10-31\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 70.0, \"Danceability\": 0.665, \"Energy\": 0.697, \"Loudness\": -4.819, \"Speechiness\": 0.154, \"Acousticness\": 0.427, \"Liveness\": 0.599, \"Tempo\": 94.053, \"Duration (ms)\": 216747.0, \"Valence\": 0.556, \"Chord\": \"A\"}, {\"Index\": 601, \"Highest Charting Position\": 17, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"The Woo (feat. 50 Cent & Roddy Ricch)\", \"Streams\": 4892682, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"1H7KnK26kc1YyellpbINEn\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 79.0, \"Danceability\": 0.49, \"Energy\": 0.618, \"Loudness\": -5.655, \"Speechiness\": 0.104, \"Acousticness\": 0.0221, \"Liveness\": 0.259, \"Tempo\": 99.7, \"Duration (ms)\": 201600.0, \"Valence\": 0.286, \"Chord\": \"C#/Db\"}, {\"Index\": 602, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"More Than My Hometown\", \"Streams\": 4879971, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"5OELUCYgOHKFAvCERnAvfS\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\", \"Popularity\": 75.0, \"Danceability\": 0.62, \"Energy\": 0.869, \"Loudness\": -5.479, \"Speechiness\": 0.0462, \"Acousticness\": 0.615, \"Liveness\": 0.131, \"Tempo\": 126.019, \"Duration (ms)\": 216573.0, \"Valence\": 0.597, \"Chord\": \"F#/Gb\"}, {\"Index\": 603, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Warning\", \"Streams\": 4860714, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"64SCQtbRtmO28ks1QhS3w5\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\", \"Popularity\": 68.0, \"Danceability\": 0.633, \"Energy\": 0.664, \"Loudness\": -5.037, \"Speechiness\": 0.0294, \"Acousticness\": 0.46, \"Liveness\": 0.108, \"Tempo\": 115.058, \"Duration (ms)\": 156747.0, \"Valence\": 0.268, \"Chord\": \"A#/Bb\"}, {\"Index\": 604, \"Highest Charting Position\": 117, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Recairei - Ao Vivo\", \"Streams\": 4815342, \"Artist\": \"Os Bar\\u00f5es Da Pisadinha\", \"Artist Followers\": 4281787.0, \"Song ID\": \"71FrGl0XcpL3VId65tB5mg\", \"Genre\": \"['forro', 'piseiro']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-27--2020-12-04\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 69.0, \"Danceability\": 0.582, \"Energy\": 0.937, \"Loudness\": -2.118, \"Speechiness\": 0.0858, \"Acousticness\": 0.449, \"Liveness\": 0.684, \"Tempo\": 168.096, \"Duration (ms)\": 166838.0, \"Valence\": 0.939, \"Chord\": \"A#/Bb\"}, {\"Index\": 605, \"Highest Charting Position\": 5, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Ice Cream (with Selena Gomez)\", \"Streams\": 4812765, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"4JUPEh2DVSXFGExu4Uxevz\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 71.0, \"Danceability\": 0.79, \"Energy\": 0.701, \"Loudness\": -4.81, \"Speechiness\": 0.365, \"Acousticness\": 0.0317, \"Liveness\": 0.0311, \"Tempo\": 159.972, \"Duration (ms)\": 177813.0, \"Valence\": 0.91, \"Chord\": \"A\"}, {\"Index\": 606, \"Highest Charting Position\": 22, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Be Kind (with Halsey)\", \"Streams\": 4790427, \"Artist\": \"Marshmello\", \"Artist Followers\": 31552500.0, \"Song ID\": \"3Z8FwOEN59mRMxDCtb8N0A\", \"Genre\": \"['brostep', 'edm', 'pop', 'pop dance', 'progressive electro house']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 80.0, \"Danceability\": 0.63, \"Energy\": 0.633, \"Loudness\": -7.088, \"Speechiness\": 0.0457, \"Acousticness\": 0.00776, \"Liveness\": 0.0541, \"Tempo\": 93.995, \"Duration (ms)\": 172762.0, \"Valence\": 0.452, \"Chord\": \"E\"}, {\"Index\": 607, \"Highest Charting Position\": 76, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Fever\", \"Streams\": 4769618, \"Artist\": \"Dua Lipa, Ang\\u00e8le\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3wJVBz7gvGTwTWVAxFa6ny\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-10-29\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 73.0, \"Danceability\": 0.868, \"Energy\": 0.693, \"Loudness\": -7.052, \"Speechiness\": 0.181, \"Acousticness\": 0.0597, \"Liveness\": 0.106, \"Tempo\": 114.999, \"Duration (ms)\": 156911.0, \"Valence\": 0.396, \"Chord\": \"F#/Gb\"}, {\"Index\": 608, \"Highest Charting Position\": 141, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Angst\", \"Streams\": 5317174, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"5yUzqd3H7cmJ1no6B4uTzu\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2021-01-01\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.599, \"Energy\": 0.79, \"Loudness\": -4.352, \"Speechiness\": 0.386, \"Acousticness\": 0.0213, \"Liveness\": 0.0778, \"Tempo\": 100.119, \"Duration (ms)\": 201501.0, \"Valence\": 0.528, \"Chord\": \"A\"}, {\"Index\": 609, \"Highest Charting Position\": 15, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"no body, no crime (feat. HAIM)\", \"Streams\": 4986214, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3RaT22zZsxVYxxKR7TAaYF\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 68.0, \"Danceability\": 0.546, \"Energy\": 0.613, \"Loudness\": -7.589, \"Speechiness\": 0.0264, \"Acousticness\": 0.418, \"Liveness\": 0.103, \"Tempo\": 79.015, \"Duration (ms)\": 215627.0, \"Valence\": 0.535, \"Chord\": \"G\"}, {\"Index\": 610, \"Highest Charting Position\": 13, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Sunday Best\", \"Streams\": 4858392, \"Artist\": \"Surfaces\", \"Artist Followers\": 724903.0, \"Song ID\": \"1Cv1YLb4q0RzL6pybtaMLo\", \"Genre\": \"['bedroom soul', 'pop']\", \"Release Date\": \"2019-01-06\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 80.0, \"Danceability\": 0.878, \"Energy\": 0.525, \"Loudness\": -6.832, \"Speechiness\": 0.0578, \"Acousticness\": 0.183, \"Liveness\": 0.0714, \"Tempo\": 112.022, \"Duration (ms)\": 158571.0, \"Valence\": 0.694, \"Chord\": \"F\"}, {\"Index\": 611, \"Highest Charting Position\": 171, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Amor ou o Litr\\u00e3o\", \"Streams\": 4848222, \"Artist\": \"Petter Ferraz, Menor Nico\", \"Artist Followers\": 14122.0, \"Song ID\": \"7qmnP8Woc47dLSrMD5MxL1\", \"Genre\": \"[]\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 66.0, \"Danceability\": 0.934, \"Energy\": 0.707, \"Loudness\": -4.214, \"Speechiness\": 0.0646, \"Acousticness\": 0.437, \"Liveness\": 0.0628, \"Tempo\": 138.023, \"Duration (ms)\": 173913.0, \"Valence\": 0.961, \"Chord\": \"A\"}, {\"Index\": 612, \"Highest Charting Position\": 66, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Happier\", \"Streams\": 4655272, \"Artist\": \"Marshmello, Bastille\", \"Artist Followers\": 31552500.0, \"Song ID\": \"2dpaYNEQHiRxtZbfNsse99\", \"Genre\": \"['brostep', 'edm', 'pop', 'pop dance', 'progressive electro house']\", \"Release Date\": \"2018-08-17\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-11-13--2020-11-20\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.687, \"Energy\": 0.792, \"Loudness\": -2.749, \"Speechiness\": 0.0452, \"Acousticness\": 0.191, \"Liveness\": 0.167, \"Tempo\": 100.015, \"Duration (ms)\": 214290.0, \"Valence\": 0.671, \"Chord\": \"F\"}, {\"Index\": 613, \"Highest Charting Position\": 138, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Don't Stop Me Now - Remastered 2011\", \"Streams\": 4630572, \"Artist\": \"Queen\", \"Artist Followers\": 35910149.0, \"Song ID\": \"7hQJA50XrCWABAu5v6QZ4i\", \"Genre\": \"['classic rock', 'glam rock', 'rock']\", \"Release Date\": \"1978-11-10\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-15--2020-05-22\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.563, \"Energy\": 0.865, \"Loudness\": -5.277, \"Speechiness\": 0.16, \"Acousticness\": 0.0472, \"Liveness\": 0.77, \"Tempo\": 156.271, \"Duration (ms)\": 209413.0, \"Valence\": 0.601, \"Chord\": \"F\"}, {\"Index\": 614, \"Highest Charting Position\": 61, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Azul\", \"Streams\": 4606011, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"2lCkncy6bIB0LTMT7kvrD1\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 77.0, \"Danceability\": 0.843, \"Energy\": 0.836, \"Loudness\": -2.474, \"Speechiness\": 0.0695, \"Acousticness\": 0.0816, \"Liveness\": 0.0532, \"Tempo\": 94.018, \"Duration (ms)\": 205933.0, \"Valence\": 0.65, \"Chord\": \"B\"}, {\"Index\": 615, \"Highest Charting Position\": 183, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Basta Voc\\u00ea Me Ligar - Ao Vivo\", \"Streams\": 4580123, \"Artist\": \"Os Bar\\u00f5es Da Pisadinha, Xand Avi\\u00e3o\", \"Artist Followers\": 4281787.0, \"Song ID\": \"3AV1KI22k1jGMz792lDrj1\", \"Genre\": \"['forro', 'piseiro']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 68.0, \"Danceability\": 0.599, \"Energy\": 0.914, \"Loudness\": -2.415, \"Speechiness\": 0.0629, \"Acousticness\": 0.5, \"Liveness\": 0.694, \"Tempo\": 168.008, \"Duration (ms)\": 182977.0, \"Valence\": 0.831, \"Chord\": \"F\"}, {\"Index\": 616, \"Highest Charting Position\": 49, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Tequila Shots\", \"Streams\": 4540781, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"30KctD1WsHKTIYczXjip5a\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 74.0, \"Danceability\": 0.712, \"Energy\": 0.556, \"Loudness\": -7.214, \"Speechiness\": 0.0531, \"Acousticness\": 0.084, \"Liveness\": 0.527, \"Tempo\": 90.494, \"Duration (ms)\": 193293.0, \"Valence\": 0.22, \"Chord\": \"F\"}, {\"Index\": 617, \"Highest Charting Position\": 27, \"Number of Times Charted\": 45, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Lose Control\", \"Streams\": 4516053, \"Artist\": \"MEDUZA, Becky Hill, Goodboys\", \"Artist Followers\": 441714.0, \"Song ID\": \"7CHi4DtfK4heMlQaudCuHK\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop house', 'tropical house']\", \"Release Date\": \"2019-10-11\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.598, \"Energy\": 0.526, \"Loudness\": -8.659, \"Speechiness\": 0.0415, \"Acousticness\": 0.129, \"Liveness\": 0.14, \"Tempo\": 123.935, \"Duration (ms)\": 168387.0, \"Valence\": 0.529, \"Chord\": \"A#/Bb\"}, {\"Index\": 618, \"Highest Charting Position\": 68, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"I CAN'T STOP ME\", \"Streams\": 4504304, \"Artist\": \"TWICE\", \"Artist Followers\": 9998991.0, \"Song ID\": \"37ZtpRBkHcaq6hHy0X98zn\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-26\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 76.0, \"Danceability\": 0.657, \"Energy\": 0.88, \"Loudness\": -3.672, \"Speechiness\": 0.102, \"Acousticness\": 0.121, \"Liveness\": 0.463, \"Tempo\": 150.084, \"Duration (ms)\": 205493.0, \"Valence\": 0.769, \"Chord\": \"A#/Bb\"}, {\"Index\": 619, \"Highest Charting Position\": 158, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"E-GIRLS ARE RUINING MY LIFE!\", \"Streams\": 4488125, \"Artist\": \"CORPSE, Savage Ga$p\", \"Artist Followers\": 1777797.0, \"Song ID\": \"7bCfHiRcfUjG0YVVNUL7Ve\", \"Genre\": \"['dream smp', 'viral rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 77.0, \"Danceability\": 0.614, \"Energy\": 0.937, \"Loudness\": -7.443, \"Speechiness\": 0.115, \"Acousticness\": 0.00161, \"Liveness\": 0.103, \"Tempo\": 84.98, \"Duration (ms)\": 105176.0, \"Valence\": 0.386, \"Chord\": \"C#/Db\"}, {\"Index\": 620, \"Highest Charting Position\": 1, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"All I Want for Christmas Is You\", \"Streams\": 23235257, \"Artist\": \"Mariah Carey\", \"Artist Followers\": 6931357.0, \"Song ID\": \"0bYg9bo50gSsH3LtXe2SQn\", \"Genre\": \"['dance pop', 'pop', 'r&b', 'urban contemporary']\", \"Release Date\": \"1994-11-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2019-12-27--2020-01-03\", \"Popularity\": 65.0, \"Danceability\": 0.336, \"Energy\": 0.627, \"Loudness\": -7.463, \"Speechiness\": 0.0384, \"Acousticness\": 0.164, \"Liveness\": 0.0708, \"Tempo\": 150.273, \"Duration (ms)\": 241107.0, \"Valence\": 0.35, \"Chord\": \"G\"}, {\"Index\": 621, \"Highest Charting Position\": 2, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Last Christmas\", \"Streams\": 20709328, \"Artist\": \"Wham!\", \"Artist Followers\": 1631876.0, \"Song ID\": \"2FRnf9qhLbvw8fu4IBXx78\", \"Genre\": \"['disco', 'europop', 'new romantic', 'new wave', 'new wave pop', 'soft rock', 'synthpop']\", \"Release Date\": \"1984-11-29\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 63.0, \"Danceability\": 0.735, \"Energy\": 0.478, \"Loudness\": -12.472, \"Speechiness\": 0.0293, \"Acousticness\": 0.189, \"Liveness\": 0.355, \"Tempo\": 107.682, \"Duration (ms)\": 262960.0, \"Valence\": 0.947, \"Chord\": \"D\"}, {\"Index\": 622, \"Highest Charting Position\": 3, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Tell Me\", \"Streams\": 16657592, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"0lizgQ7Qw35od7CYaoMBZb\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2014-11-24\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 61.0, \"Danceability\": 0.525, \"Energy\": 0.621, \"Loudness\": -7.364, \"Speechiness\": 0.116, \"Acousticness\": 0.0489, \"Liveness\": 0.294, \"Tempo\": 191.9, \"Duration (ms)\": 204093.0, \"Valence\": 0.591, \"Chord\": \"G\"}, {\"Index\": 623, \"Highest Charting Position\": 5, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Rockin' Around The Christmas Tree\", \"Streams\": 16613649, \"Artist\": \"Brenda Lee\", \"Artist Followers\": 222627.0, \"Song ID\": \"2EjXfH91m7f8HiJN1yQg97\", \"Genre\": \"['adult standards', 'brill building pop', 'easy listening', 'lounge', 'rockabilly', 'vocal jazz']\", \"Release Date\": \"1964-10-19\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 58.0, \"Danceability\": 0.589, \"Energy\": 0.472, \"Loudness\": -8.749, \"Speechiness\": 0.0502, \"Acousticness\": 0.614, \"Liveness\": 0.505, \"Tempo\": 67.196, \"Duration (ms)\": 126267.0, \"Valence\": 0.898, \"Chord\": \"G#/Ab\"}, {\"Index\": 624, \"Highest Charting Position\": 7, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Jingle Bell Rock\", \"Streams\": 16527404, \"Artist\": \"Bobby Helms\", \"Artist Followers\": 20637.0, \"Song ID\": \"7vQbuQcyTflfCIOu3Uzzya\", \"Genre\": \"[]\", \"Release Date\": \"1957-12-02\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 56.0, \"Danceability\": 0.754, \"Energy\": 0.424, \"Loudness\": -8.463, \"Speechiness\": 0.0363, \"Acousticness\": 0.643, \"Liveness\": 0.0652, \"Tempo\": 119.705, \"Duration (ms)\": 130973.0, \"Valence\": 0.806, \"Chord\": \"D\"}, {\"Index\": 625, \"Highest Charting Position\": 6, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"It's Beginning to Look a Lot like Christmas\", \"Streams\": 15424001, \"Artist\": \"Michael Bubl\\u00e9\", \"Artist Followers\": 4702232.0, \"Song ID\": \"5a1iz510sv2W9Dt1MvFd5R\", \"Genre\": \"['adult standards', 'canadian pop', 'jazz pop', 'lounge']\", \"Release Date\": \"2012-11-09\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 55.0, \"Danceability\": 0.339, \"Energy\": 0.214, \"Loudness\": -11.714, \"Speechiness\": 0.0375, \"Acousticness\": 0.908, \"Liveness\": 0.341, \"Tempo\": 94.775, \"Duration (ms)\": 206640.0, \"Valence\": 0.363, \"Chord\": \"E\"}, {\"Index\": 626, \"Highest Charting Position\": 8, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"It's the Most Wonderful Time of the Year\", \"Streams\": 14582001, \"Artist\": \"Andy Williams\", \"Artist Followers\": 369548.0, \"Song ID\": \"5hslUAKq9I9CG2bAulFkHN\", \"Genre\": \"['adult standards', 'brill building pop', 'easy listening', 'lounge', 'mellow gold', 'vocal jazz']\", \"Release Date\": \"1963-11-24\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 55.0, \"Danceability\": 0.24, \"Energy\": 0.598, \"Loudness\": -8.435, \"Speechiness\": 0.0369, \"Acousticness\": 0.766, \"Liveness\": 0.117, \"Tempo\": 201.629, \"Duration (ms)\": 151933.0, \"Valence\": 0.776, \"Chord\": \"G\"}, {\"Index\": 627, \"Highest Charting Position\": 9, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Underneath the Tree\", \"Streams\": 12266990, \"Artist\": \"Kelly Clarkson\", \"Artist Followers\": 7869617.0, \"Song ID\": \"3YZE5qDV7u1ZD1gZc47ZeR\", \"Genre\": \"['dance pop', 'neo mellow', 'pop', 'pop rock', 'post-teen pop', 'talent show']\", \"Release Date\": \"2013-10-29\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 49.0, \"Danceability\": 0.509, \"Energy\": 0.812, \"Loudness\": -5.439, \"Speechiness\": 0.0537, \"Acousticness\": 0.00128, \"Liveness\": 0.214, \"Tempo\": 159.878, \"Duration (ms)\": 229640.0, \"Valence\": 0.689, \"Chord\": \"G#/Ab\"}, {\"Index\": 628, \"Highest Charting Position\": 14, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Feliz Navidad\", \"Streams\": 11664490, \"Artist\": \"Jos\\u00e9 Feliciano\", \"Artist Followers\": 239129.0, \"Song ID\": \"0oPdaY4dXtc3ZsaG17V972\", \"Genre\": \"['latin pop', 'puerto rican pop']\", \"Release Date\": \"2002-09-24\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 49.0, \"Danceability\": 0.513, \"Energy\": 0.831, \"Loudness\": -9.004, \"Speechiness\": 0.0383, \"Acousticness\": 0.55, \"Liveness\": 0.336, \"Tempo\": 148.837, \"Duration (ms)\": 182067.0, \"Valence\": 0.963, \"Chord\": \"D\"}, {\"Index\": 629, \"Highest Charting Position\": 11, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Let It Snow! Let It Snow! Let It Snow!\", \"Streams\": 10884855, \"Artist\": \"Dean Martin\", \"Artist Followers\": 1139096.0, \"Song ID\": \"2uFaJJtFpPDc5Pa95XzTvg\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"1959-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 54.0, \"Danceability\": 0.451, \"Energy\": 0.24, \"Loudness\": -14.014, \"Speechiness\": 0.0351, \"Acousticness\": 0.912, \"Liveness\": 0.175, \"Tempo\": 134.009, \"Duration (ms)\": 117147.0, \"Valence\": 0.701, \"Chord\": \"C#/Db\"}, {\"Index\": 630, \"Highest Charting Position\": 19, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Let It Snow! Let It Snow! Let It Snow! (with The B. Swanson Quartet)\", \"Streams\": 10787165, \"Artist\": \"Frank Sinatra\", \"Artist Followers\": 4953667.0, \"Song ID\": \"4kKdvXD0ez7jp1296JmAts\", \"Genre\": \"['adult standards', 'easy listening', 'lounge']\", \"Release Date\": \"1994-11-08\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 53.0, \"Danceability\": 0.652, \"Energy\": 0.259, \"Loudness\": -13.336, \"Speechiness\": 0.0595, \"Acousticness\": 0.903, \"Liveness\": 0.362, \"Tempo\": 142.169, \"Duration (ms)\": 155453.0, \"Valence\": 0.836, \"Chord\": \"D\"}, {\"Index\": 631, \"Highest Charting Position\": 15, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Mistletoe\", \"Streams\": 10609206, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"7xapw9Oy21WpfEcib2ErSA\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2011-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 59.0, \"Danceability\": 0.657, \"Energy\": 0.56, \"Loudness\": -9.049, \"Speechiness\": 0.0467, \"Acousticness\": 0.498, \"Liveness\": 0.0794, \"Tempo\": 161.993, \"Duration (ms)\": 182947.0, \"Valence\": 0.854, \"Chord\": \"F#/Gb\"}, {\"Index\": 632, \"Highest Charting Position\": 16, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Sleigh Ride\", \"Streams\": 10508459, \"Artist\": \"The Ronettes\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5ASM6Qjiav2xPe7gRkQMsQ\", \"Genre\": \"[]\", \"Release Date\": \"1963\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 50.0, \"Danceability\": 0.529, \"Energy\": 0.772, \"Loudness\": -7.013, \"Speechiness\": 0.0287, \"Acousticness\": 0.403, \"Liveness\": 0.316, \"Tempo\": 91.751, \"Duration (ms)\": 181267.0, \"Valence\": 0.853, \"Chord\": \"D\"}, {\"Index\": 633, \"Highest Charting Position\": 17, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Do They Know It's Christmas? - 1984 Version\", \"Streams\": 10476212, \"Artist\": \"Band Aid\", \"Artist Followers\": 4883.0, \"Song ID\": \"0247StOpd3AkeBQzANX4Zf\", \"Genre\": \"['musical advocacy']\", \"Release Date\": \"2004-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 51.0, \"Danceability\": 0.599, \"Energy\": 0.642, \"Loudness\": -6.936, \"Speechiness\": 0.0363, \"Acousticness\": 0.164, \"Liveness\": 0.0992, \"Tempo\": 115.412, \"Duration (ms)\": 222533.0, \"Valence\": 0.349, \"Chord\": \"C\"}, {\"Index\": 634, \"Highest Charting Position\": 23, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Wonderful Christmastime - Edited Version / Remastered 2011\", \"Streams\": 9882989, \"Artist\": \"Paul McCartney\", \"Artist Followers\": 3609658.0, \"Song ID\": \"1SV1fxF65n9NhRHp3KlBuu\", \"Genre\": \"['album rock', 'art rock', 'beatlesque', 'classic rock', 'mellow gold', 'rock', 'soft rock']\", \"Release Date\": \"1980-05-16\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 51.0, \"Danceability\": 0.774, \"Energy\": 0.511, \"Loudness\": -8.914, \"Speechiness\": 0.0319, \"Acousticness\": 0.322, \"Liveness\": 0.0672, \"Tempo\": 94.736, \"Duration (ms)\": 227653.0, \"Valence\": 0.771, \"Chord\": \"B\"}, {\"Index\": 635, \"Highest Charting Position\": 21, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Holly Jolly Christmas\", \"Streams\": 9852792, \"Artist\": \"Michael Bubl\\u00e9\", \"Artist Followers\": 4702232.0, \"Song ID\": \"5PuKlCjfEVIXl0ZBp5ZW9g\", \"Genre\": \"['adult standards', 'canadian pop', 'jazz pop', 'lounge']\", \"Release Date\": \"2012-11-09\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 48.0, \"Danceability\": 0.647, \"Energy\": 0.465, \"Loudness\": -8.308, \"Speechiness\": 0.0428, \"Acousticness\": 0.865, \"Liveness\": 0.0882, \"Tempo\": 151.251, \"Duration (ms)\": 119787.0, \"Valence\": 0.699, \"Chord\": \"G\"}, {\"Index\": 636, \"Highest Charting Position\": 24, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Happy Xmas (War Is Over) - Remastered 2010\", \"Streams\": 9509781, \"Artist\": \"John Lennon, Yoko Ono\", \"Artist Followers\": 4313100.0, \"Song ID\": \"27RYrbL6S02LNVhDWVl38b\", \"Genre\": \"['album rock', 'art rock', 'beatlesque', 'classic rock', 'folk rock', 'mellow gold', 'rock']\", \"Release Date\": \"2010-10-05\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 53.0, \"Danceability\": 0.321, \"Energy\": 0.64, \"Loudness\": -10.023, \"Speechiness\": 0.0324, \"Acousticness\": 0.28, \"Liveness\": 0.718, \"Tempo\": 146.172, \"Duration (ms)\": 214333.0, \"Valence\": 0.414, \"Chord\": \"D\"}, {\"Index\": 637, \"Highest Charting Position\": 22, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Driving Home for Christmas - 2019 Remaster\", \"Streams\": 8804531, \"Artist\": \"Chris Rea\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 638, \"Highest Charting Position\": 32, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"The Christmas Song (Merry Christmas To You)\", \"Streams\": 8478518, \"Artist\": \"Nat King Cole\", \"Artist Followers\": 1634288.0, \"Song ID\": \"4PS1e8f2LvuTFgUs1Cn3ON\", \"Genre\": \"['adult standards', 'lounge', 'soul', 'vocal jazz']\", \"Release Date\": \"1962\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 53.0, \"Danceability\": 0.319, \"Energy\": 0.21, \"Loudness\": -15.231, \"Speechiness\": 0.0341, \"Acousticness\": 0.92, \"Liveness\": 0.138, \"Tempo\": 78.696, \"Duration (ms)\": 192160.0, \"Valence\": 0.209, \"Chord\": \"C#/Db\"}, {\"Index\": 639, \"Highest Charting Position\": 39, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"White Christmas\", \"Streams\": 7045348, \"Artist\": \"Bing Crosby, Ken Darby Singers, John Scott Trotter & His Orchestra\", \"Artist Followers\": 359973.0, \"Song ID\": \"4so0Wek9Ig1p6CRCHuINwW\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'swing', 'vocal jazz']\", \"Release Date\": \"1942-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 51.0, \"Danceability\": 0.317, \"Energy\": 0.158, \"Loudness\": -16.485, \"Speechiness\": 0.0381, \"Acousticness\": 0.673, \"Liveness\": 0.338, \"Tempo\": 130.503, \"Duration (ms)\": 177480.0, \"Valence\": 0.247, \"Chord\": \"A\"}, {\"Index\": 640, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Slay3r\", \"Streams\": 6912271, \"Artist\": \"Playboi Carti\", \"Artist Followers\": 4958353.0, \"Song ID\": \"1eMNW1HQjF1dbb4GtnmpaX\", \"Genre\": \"['atl hip hop', 'plugg', 'rap', 'trap']\", \"Release Date\": \"2020-12-25\", \"Weeks Charted\": \"2020-12-25--2021-01-01\", \"Popularity\": 63.0, \"Danceability\": 0.885, \"Energy\": 0.661, \"Loudness\": -5.062, \"Speechiness\": 0.141, \"Acousticness\": 0.165, \"Liveness\": 0.334, \"Tempo\": 140.028, \"Duration (ms)\": 164591.0, \"Valence\": 0.436, \"Chord\": \"E\"}, {\"Index\": 641, \"Highest Charting Position\": 42, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"A Holly Jolly Christmas - Single Version\", \"Streams\": 6716353, \"Artist\": \"Burl Ives\", \"Artist Followers\": 58479.0, \"Song ID\": \"77khP2fIVhSW23NwxrRluh\", \"Genre\": \"['adult standards', 'american folk revival']\", \"Release Date\": \"1965-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 49.0, \"Danceability\": 0.683, \"Energy\": 0.375, \"Loudness\": -13.056, \"Speechiness\": 0.0303, \"Acousticness\": 0.579, \"Liveness\": 0.076, \"Tempo\": 140.467, \"Duration (ms)\": 135533.0, \"Valence\": 0.888, \"Chord\": \"C\"}, {\"Index\": 642, \"Highest Charting Position\": 47, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Fairytale of New York (feat. Kirsty MacColl)\", \"Streams\": 6404964, \"Artist\": \"The Pogues\", \"Artist Followers\": 382997.0, \"Song ID\": \"3VTNVsTTu05dmTsVFrmGpK\", \"Genre\": \"['celtic', 'celtic punk', 'celtic rock', 'folk punk', 'irish folk', 'punk']\", \"Release Date\": \"1988-09-05\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 55.0, \"Danceability\": 0.271, \"Energy\": 0.551, \"Loudness\": -7.48, \"Speechiness\": 0.0457, \"Acousticness\": 0.582, \"Liveness\": 0.256, \"Tempo\": 78.111, \"Duration (ms)\": 272467.0, \"Valence\": 0.428, \"Chord\": \"D\"}, {\"Index\": 643, \"Highest Charting Position\": 38, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Merry Christmas Everyone\", \"Streams\": 6052105, \"Artist\": \"Shakin' Stevens\", \"Artist Followers\": 99249.0, \"Song ID\": \"2TE4xW3ImvpltVU0cPcKUn\", \"Genre\": \"['classic uk pop', 'new wave pop', 'rock-and-roll', 'rockabilly', 'soft rock']\", \"Release Date\": \"1991-11-25\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 47.0, \"Danceability\": 0.534, \"Energy\": 0.904, \"Loudness\": -3.315, \"Speechiness\": 0.0369, \"Acousticness\": 0.129, \"Liveness\": 0.128, \"Tempo\": 202.899, \"Duration (ms)\": 220160.0, \"Valence\": 0.96, \"Chord\": \"A\"}, {\"Index\": 644, \"Highest Charting Position\": 62, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Blue Christmas\", \"Streams\": 6007011, \"Artist\": \"Elvis Presley\", \"Artist Followers\": 5698788.0, \"Song ID\": \"3QiAAp20rPC3dcAtKtMaqQ\", \"Genre\": \"['rock-and-roll', 'rockabilly']\", \"Release Date\": \"1957-10-15\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 49.0, \"Danceability\": 0.465, \"Energy\": 0.27, \"Loudness\": -16.661, \"Speechiness\": 0.0425, \"Acousticness\": 0.9, \"Liveness\": 0.145, \"Tempo\": 94.518, \"Duration (ms)\": 129173.0, \"Valence\": 0.58, \"Chord\": \"E\"}, {\"Index\": 645, \"Highest Charting Position\": 65, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Run Rudolph Run - Single Version\", \"Streams\": 5802508, \"Artist\": \"Chuck Berry\", \"Artist Followers\": 1251372.0, \"Song ID\": \"47CIT5hMphuMQkpeyfGQTL\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 0.0, \"Danceability\": 0.647, \"Energy\": 0.876, \"Loudness\": -5.662, \"Speechiness\": 0.185, \"Acousticness\": 0.881, \"Liveness\": 0.26, \"Tempo\": 151.925, \"Duration (ms)\": 162897.0, \"Valence\": 0.949, \"Chord\": \"A#/Bb\"}, {\"Index\": 646, \"Highest Charting Position\": 59, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Claus Is Coming To Town\", \"Streams\": 5801639, \"Artist\": \"The Jackson 5\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5Gz7EYD7JAmItA7FbhKgKb\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 0.0, \"Danceability\": 0.691, \"Energy\": 0.776, \"Loudness\": -4.177, \"Speechiness\": 0.0341, \"Acousticness\": 0.458, \"Liveness\": 0.33, \"Tempo\": 146.861, \"Duration (ms)\": 144080.0, \"Valence\": 0.961, \"Chord\": \"C\"}, {\"Index\": 647, \"Highest Charting Position\": 52, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Baby\", \"Streams\": 5687085, \"Artist\": \"Kylie Minogue\", \"Artist Followers\": 1324920.0, \"Song ID\": \"0cM5URUqqQTpJWonmdzF1J\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'electropop', 'eurodance', 'europop', 'new wave pop', 'pop']\", \"Release Date\": \"2010-11-30\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 42.0, \"Danceability\": 0.685, \"Energy\": 0.391, \"Loudness\": -7.183, \"Speechiness\": 0.0435, \"Acousticness\": 0.744, \"Liveness\": 0.142, \"Tempo\": 87.101, \"Duration (ms)\": 202547.0, \"Valence\": 0.443, \"Chord\": \"C#/Db\"}, {\"Index\": 648, \"Highest Charting Position\": 60, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"It's Beginning to Look a Lot Like Christmas (with Mitchell Ayres & His Orchestra)\", \"Streams\": 5422082, \"Artist\": \"Perry Como, The Fontane Sisters\", \"Artist Followers\": 336373.0, \"Song ID\": \"2pXpURmn6zC5ZYDMms6fwa\", \"Genre\": \"['adult standards', 'brill building pop', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"1999-08-20\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 49.0, \"Danceability\": 0.724, \"Energy\": 0.276, \"Loudness\": -12.25, \"Speechiness\": 0.0599, \"Acousticness\": 0.76, \"Liveness\": 0.116, \"Tempo\": 112.874, \"Duration (ms)\": 155933.0, \"Valence\": 0.718, \"Chord\": \"G\"}, {\"Index\": 649, \"Highest Charting Position\": 69, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas (Baby Please Come Home)\", \"Streams\": 5394054, \"Artist\": \"Darlene Love\", \"Artist Followers\": 1251372.0, \"Song ID\": \"46pF1zFimM582ss1PrMy68\", \"Genre\": \"[]\", \"Release Date\": \"1963\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-12-04--2020-12-11\", \"Popularity\": 45.0, \"Danceability\": 0.325, \"Energy\": 0.759, \"Loudness\": -7.146, \"Speechiness\": 0.053, \"Acousticness\": 0.395, \"Liveness\": 0.0773, \"Tempo\": 126.627, \"Duration (ms)\": 166453.0, \"Valence\": 0.36, \"Chord\": \"G#/Ab\"}, {\"Index\": 650, \"Highest Charting Position\": 66, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Step Into Christmas\", \"Streams\": 5353591, \"Artist\": \"Elton John\", \"Artist Followers\": 7504724.0, \"Song ID\": \"6sBWmE23q6xQHlnEZ8jYPT\", \"Genre\": \"['glam rock', 'mellow gold', 'piano rock']\", \"Release Date\": \"1973-10-05\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 43.0, \"Danceability\": 0.526, \"Energy\": 0.925, \"Loudness\": -5.584, \"Speechiness\": 0.0363, \"Acousticness\": 0.102, \"Liveness\": 0.305, \"Tempo\": 140.308, \"Duration (ms)\": 272394.0, \"Valence\": 0.819, \"Chord\": \"D\"}, {\"Index\": 651, \"Highest Charting Position\": 54, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Show Out (with Skepta & Pop Smoke)\", \"Streams\": 5209372, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"5CFJRZRq6sdKKtRwNPWbYv\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 76.0, \"Danceability\": 0.619, \"Energy\": 0.589, \"Loudness\": -6.531, \"Speechiness\": 0.124, \"Acousticness\": 0.43, \"Liveness\": 0.378, \"Tempo\": 143.896, \"Duration (ms)\": 174960.0, \"Valence\": 0.158, \"Chord\": \"C#/Db\"}, {\"Index\": 652, \"Highest Charting Position\": 166, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Investe Em Mim\", \"Streams\": 5191001, \"Artist\": \"Jonas Esticado\", \"Artist Followers\": 1293055.0, \"Song ID\": \"15k1TDabqSEmyXOwMq9RM7\", \"Genre\": \"['forro', 'sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 72.0, \"Danceability\": 0.632, \"Energy\": 0.953, \"Loudness\": -1.283, \"Speechiness\": 0.0325, \"Acousticness\": 0.317, \"Liveness\": 0.125, \"Tempo\": 160.061, \"Duration (ms)\": 186533.0, \"Valence\": 0.798, \"Chord\": \"A\"}, {\"Index\": 653, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Lance Individual\", \"Streams\": 5152906, \"Artist\": \"Jorge & Mateus\", \"Artist Followers\": 15019109.0, \"Song ID\": \"7GLWWrk1YlkPYqJK3ynIA0\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-12-25--2021-01-01\", \"Popularity\": 72.0, \"Danceability\": 0.752, \"Energy\": 0.62, \"Loudness\": -5.536, \"Speechiness\": 0.0509, \"Acousticness\": 0.309, \"Liveness\": 0.075, \"Tempo\": 117.399, \"Duration (ms)\": 164459.0, \"Valence\": 0.962, \"Chord\": \"F\"}, {\"Index\": 654, \"Highest Charting Position\": 71, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Jingle Bell Rock - Daryl's Version\", \"Streams\": 10522305, \"Artist\": \"Daryl Hall & John Oates\", \"Artist Followers\": 1549216.0, \"Song ID\": \"6pVW5LRWgeLaHudxauOTJU\", \"Genre\": \"['album rock', 'classic rock', 'mellow gold', 'rock', 'soft rock', 'yacht rock']\", \"Release Date\": \"1983-11-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 43.0, \"Danceability\": 0.666, \"Energy\": 0.841, \"Loudness\": -3.592, \"Speechiness\": 0.0312, \"Acousticness\": 0.613, \"Liveness\": 0.113, \"Tempo\": 128.706, \"Duration (ms)\": 126360.0, \"Valence\": 0.84, \"Chord\": \"D\"}, {\"Index\": 655, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Thank God It's Christmas - Non-Album Single\", \"Streams\": 10509961, \"Artist\": \"Queen\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 656, \"Highest Charting Position\": 74, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas Lights\", \"Streams\": 10455065, \"Artist\": \"Coldplay\", \"Artist Followers\": 31161671.0, \"Song ID\": \"4QVdnpSO5JGMFOEl6ys4RQ\", \"Genre\": \"['permanent wave', 'pop']\", \"Release Date\": \"2016-12-16\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 53.0, \"Danceability\": 0.295, \"Energy\": 0.496, \"Loudness\": -9.478, \"Speechiness\": 0.0327, \"Acousticness\": 0.207, \"Liveness\": 0.858, \"Tempo\": 132.062, \"Duration (ms)\": 268521.0, \"Valence\": 0.224, \"Chord\": \"G\"}, {\"Index\": 657, \"Highest Charting Position\": 83, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Have Yourself A Merry Little Christmas\", \"Streams\": 9548924, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"1Qi2wh8fFgDV7tl4Sj3f2K\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2014-12-05\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 46.0, \"Danceability\": 0.438, \"Energy\": 0.178, \"Loudness\": -9.402, \"Speechiness\": 0.0414, \"Acousticness\": 0.957, \"Liveness\": 0.316, \"Tempo\": 75.248, \"Duration (ms)\": 170964.0, \"Valence\": 0.344, \"Chord\": \"F\"}, {\"Index\": 658, \"Highest Charting Position\": 85, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa's Coming for Us\", \"Streams\": 9474711, \"Artist\": \"Sia\", \"Artist Followers\": 20528724.0, \"Song ID\": \"1N1ZpYUJc9fwrqk53FGgWv\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'pop']\", \"Release Date\": \"2018-11-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 49.0, \"Danceability\": 0.547, \"Energy\": 0.814, \"Loudness\": -6.191, \"Speechiness\": 0.12, \"Acousticness\": 0.0215, \"Liveness\": 0.0475, \"Tempo\": 92.986, \"Duration (ms)\": 205267.0, \"Valence\": 0.724, \"Chord\": \"C#/Db\"}, {\"Index\": 659, \"Highest Charting Position\": 86, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"My Only Wish (This Year)\", \"Streams\": 9457199, \"Artist\": \"Britney Spears\", \"Artist Followers\": 9470311.0, \"Song ID\": \"0YWUHZPJVg4iujddsJDwhM\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2000-11-14\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-04--2020-12-11\", \"Popularity\": 43.0, \"Danceability\": 0.669, \"Energy\": 0.843, \"Loudness\": -3.766, \"Speechiness\": 0.0268, \"Acousticness\": 0.169, \"Liveness\": 0.195, \"Tempo\": 147.08, \"Duration (ms)\": 255400.0, \"Valence\": 0.702, \"Chord\": \"C\"}, {\"Index\": 660, \"Highest Charting Position\": 89, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Baby, It's Cold Outside (feat. Meghan Trainor)\", \"Streams\": 9270017, \"Artist\": \"Brett Eldredge\", \"Artist Followers\": 1298537.0, \"Song ID\": \"5Q2P43CJra0uRAogjHyJDK\", \"Genre\": \"['contemporary country', 'country', 'country road', 'modern country rock']\", \"Release Date\": \"2016-10-28\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 44.0, \"Danceability\": 0.583, \"Energy\": 0.572, \"Loudness\": -4.776, \"Speechiness\": 0.0366, \"Acousticness\": 0.738, \"Liveness\": 0.266, \"Tempo\": 113.998, \"Duration (ms)\": 173560.0, \"Valence\": 0.684, \"Chord\": \"C#/Db\"}, {\"Index\": 661, \"Highest Charting Position\": 92, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Like It's Christmas\", \"Streams\": 9167304, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"1OjmlSFuzYflWjSMTCyTJv\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-04--2020-12-11\", \"Popularity\": 47.0, \"Danceability\": 0.725, \"Energy\": 0.571, \"Loudness\": -6.007, \"Speechiness\": 0.102, \"Acousticness\": 0.0183, \"Liveness\": 0.0519, \"Tempo\": 146.035, \"Duration (ms)\": 200880.0, \"Valence\": 0.61, \"Chord\": \"C#/Db\"}, {\"Index\": 662, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas Without You\", \"Streams\": 8813922, \"Artist\": \"Ava Max\", \"Artist Followers\": 3916979.0, \"Song ID\": \"1QLZKzC2pjP4ySf4ALrNhm\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-10-15\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 45.0, \"Danceability\": 0.654, \"Energy\": 0.596, \"Loudness\": -4.68, \"Speechiness\": 0.0458, \"Acousticness\": 0.424, \"Liveness\": 0.11, \"Tempo\": 118.078, \"Duration (ms)\": 169245.0, \"Valence\": 0.382, \"Chord\": \"C#/Db\"}, {\"Index\": 663, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"You Make It Feel Like Christmas (feat. Blake Shelton)\", \"Streams\": 8696354, \"Artist\": \"Gwen Stefani\", \"Artist Followers\": 4805333.0, \"Song ID\": \"2OQ6a4CfUeYskpTTgyawyJ\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'post-teen pop', 'urban contemporary']\", \"Release Date\": \"2017-10-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.635, \"Energy\": 0.87, \"Loudness\": -4.291, \"Speechiness\": 0.04, \"Acousticness\": 0.0156, \"Liveness\": 0.118, \"Tempo\": 93.0, \"Duration (ms)\": 156773.0, \"Valence\": 0.912, \"Chord\": \"D\"}, {\"Index\": 664, \"Highest Charting Position\": 107, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Gnat\", \"Streams\": 8614955, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"6cS9PmLky2NhLOhpIsUlow\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 70.0, \"Danceability\": 0.835, \"Energy\": 0.869, \"Loudness\": -4.582, \"Speechiness\": 0.27, \"Acousticness\": 0.248, \"Liveness\": 0.462, \"Tempo\": 140.945, \"Duration (ms)\": 224656.0, \"Valence\": 0.82, \"Chord\": \"A#/Bb\"}, {\"Index\": 665, \"Highest Charting Position\": 111, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Joy To The World\", \"Streams\": 8387899, \"Artist\": \"Nat King Cole\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5oWFPbd340pwiXKMO1CQRy\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 0.0, \"Danceability\": 0.59, \"Energy\": 0.305, \"Loudness\": -12.955, \"Speechiness\": 0.032, \"Acousticness\": 0.894, \"Liveness\": 0.14, \"Tempo\": 102.103, \"Duration (ms)\": 86760.0, \"Valence\": 0.545, \"Chord\": \"A#/Bb\"}, {\"Index\": 666, \"Highest Charting Position\": 117, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Claus Is Coming to Town\", \"Streams\": 8177832, \"Artist\": \"Michael Bubl\\u00e9\", \"Artist Followers\": 4702232.0, \"Song ID\": \"1RMDXedcRno6rDBCbNHDJf\", \"Genre\": \"['adult standards', 'canadian pop', 'jazz pop', 'lounge']\", \"Release Date\": \"2012-11-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.594, \"Energy\": 0.389, \"Loudness\": -7.109, \"Speechiness\": 0.0517, \"Acousticness\": 0.785, \"Liveness\": 0.0313, \"Tempo\": 122.331, \"Duration (ms)\": 171093.0, \"Valence\": 0.396, \"Chord\": \"A#/Bb\"}, {\"Index\": 667, \"Highest Charting Position\": 119, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Baby It's Cold Outside (duet with Michael Bubl\\u00e9)\", \"Streams\": 8160534, \"Artist\": \"Idina Menzel\", \"Artist Followers\": 353571.0, \"Song ID\": \"0Ie5uiv54KgCr7P4sYDTHl\", \"Genre\": \"['hollywood', 'show tunes']\", \"Release Date\": \"2014-10-10\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 47.0, \"Danceability\": 0.553, \"Energy\": 0.476, \"Loudness\": -8.869, \"Speechiness\": 0.0649, \"Acousticness\": 0.647, \"Liveness\": 0.281, \"Tempo\": 113.401, \"Duration (ms)\": 166147.0, \"Valence\": 0.558, \"Chord\": \"C\"}, {\"Index\": 668, \"Highest Charting Position\": 22, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"\\u2018tis the damn season\", \"Streams\": 8115520, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7dW84mWkdWE5a6lFWxJCBG\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.575, \"Energy\": 0.434, \"Loudness\": -8.193, \"Speechiness\": 0.0312, \"Acousticness\": 0.735, \"Liveness\": 0.105, \"Tempo\": 145.916, \"Duration (ms)\": 229840.0, \"Valence\": 0.348, \"Chord\": \"F\"}, {\"Index\": 669, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"I Saw Mommy Kissing Santa Claus\", \"Streams\": 8064361, \"Artist\": \"The Jackson 5\", \"Artist Followers\": 1151360.0, \"Song ID\": \"15sxLiiChE5dCW3Y756oas\", \"Genre\": \"['motown', 'soul']\", \"Release Date\": \"1970-10-15\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.583, \"Energy\": 0.712, \"Loudness\": -8.222, \"Speechiness\": 0.0538, \"Acousticness\": 0.263, \"Liveness\": 0.817, \"Tempo\": 128.897, \"Duration (ms)\": 181267.0, \"Valence\": 0.614, \"Chord\": \"D#/Eb\"}, {\"Index\": 670, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Baby (with Henri Ren\\u00e9 & His Orchestra)\", \"Streams\": 8022773, \"Artist\": \"Eartha Kitt, Henri Rene & His Orchestra\", \"Artist Followers\": 127251.0, \"Song ID\": \"1foCxQtxBweJtZmdxhEHVO\", \"Genre\": \"['adult standards', 'lounge', 'torch song', 'vocal jazz']\", \"Release Date\": \"2002\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.7, \"Energy\": 0.139, \"Loudness\": -12.346, \"Speechiness\": 0.0607, \"Acousticness\": 0.902, \"Liveness\": 0.185, \"Tempo\": 84.485, \"Duration (ms)\": 206067.0, \"Valence\": 0.49, \"Chord\": \"G#/Ab\"}, {\"Index\": 671, \"Highest Charting Position\": 127, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Carol of the Bells\", \"Streams\": 7993078, \"Artist\": \"Mykola Dmytrovych Leontovych, John Williams\", \"Artist Followers\": 1024868.0, \"Song ID\": \"4tHqQMWSqmL6YjXwsqthDI\", \"Genre\": \"['soundtrack']\", \"Release Date\": \"1990\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 51.0, \"Danceability\": 0.418, \"Energy\": 0.106, \"Loudness\": -22.507, \"Speechiness\": 0.0448, \"Acousticness\": 0.994, \"Liveness\": 0.179, \"Tempo\": 46.718, \"Duration (ms)\": 85267.0, \"Valence\": 0.8, \"Chord\": \"G#/Ab\"}, {\"Index\": 672, \"Highest Charting Position\": 19, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"gold rush\", \"Streams\": 7901968, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5BK0uqwY9DNfZ630STAEaq\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 70.0, \"Danceability\": 0.512, \"Energy\": 0.462, \"Loudness\": -10.491, \"Speechiness\": 0.0408, \"Acousticness\": 0.83, \"Liveness\": 0.121, \"Tempo\": 112.05, \"Duration (ms)\": 185320.0, \"Valence\": 0.353, \"Chord\": \"A\"}, {\"Index\": 673, \"Highest Charting Position\": 133, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"What Christmas Means To Me\", \"Streams\": 7792643, \"Artist\": \"Stevie Wonder\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6Wn9zkkbWdK42uXCcADkRq\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 0.0, \"Danceability\": 0.545, \"Energy\": 0.7, \"Loudness\": -6.961, \"Speechiness\": 0.0323, \"Acousticness\": 0.0982, \"Liveness\": 0.1, \"Tempo\": 83.506, \"Duration (ms)\": 148147.0, \"Valence\": 0.799, \"Chord\": \"F\"}, {\"Index\": 674, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"The Christmas Song (Shawn Mendes & Camila Cabello)\", \"Streams\": 7536851, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 33893352.0, \"Song ID\": \"0fwxmtpxpMmEMphmJbCAEx\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2020-12-07\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 42.0, \"Danceability\": 0.341, \"Energy\": 0.181, \"Loudness\": -12.073, \"Speechiness\": 0.0366, \"Acousticness\": 0.888, \"Liveness\": 0.137, \"Tempo\": 83.608, \"Duration (ms)\": 196254.0, \"Valence\": 0.212, \"Chord\": \"D\"}, {\"Index\": 675, \"Highest Charting Position\": 144, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Baby, It's Cold Outside\", \"Streams\": 7367482, \"Artist\": \"Dean Martin\", \"Artist Followers\": 1139096.0, \"Song ID\": \"4MrfQL4TYQXJBlZYpAHTuE\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"1959-01-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.469, \"Energy\": 0.196, \"Loudness\": -16.093, \"Speechiness\": 0.0571, \"Acousticness\": 0.882, \"Liveness\": 0.0513, \"Tempo\": 130.036, \"Duration (ms)\": 143733.0, \"Valence\": 0.537, \"Chord\": \"C\"}, {\"Index\": 676, \"Highest Charting Position\": 145, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Claus Is Comin' to Town - Live at C.W. Post College, Greenvale, NY - December 1975\", \"Streams\": 7363913, \"Artist\": \"Bruce Springsteen\", \"Artist Followers\": 4224071.0, \"Song ID\": \"6s2wpWPFPAgKg2LXxi1Oee\", \"Genre\": \"['classic rock', 'heartland rock', 'mellow gold', 'permanent wave', 'rock', 'singer-songwriter']\", \"Release Date\": \"1981\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.357, \"Energy\": 0.668, \"Loudness\": -8.444, \"Speechiness\": 0.0479, \"Acousticness\": 0.362, \"Liveness\": 0.727, \"Tempo\": 139.986, \"Duration (ms)\": 267600.0, \"Valence\": 0.407, \"Chord\": \"C\"}, {\"Index\": 677, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"One More Sleep\", \"Streams\": 7350024, \"Artist\": \"Leona Lewis\", \"Artist Followers\": 2877234.0, \"Song ID\": \"78pn8k7RogKo2oxl0DyX6d\", \"Genre\": \"['british soul', 'dance pop', 'europop', 'pop', 'post-teen pop', 'talent show']\", \"Release Date\": \"2013-12-02\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 42.0, \"Danceability\": 0.638, \"Energy\": 0.813, \"Loudness\": -3.849, \"Speechiness\": 0.0362, \"Acousticness\": 0.464, \"Liveness\": 0.344, \"Tempo\": 112.986, \"Duration (ms)\": 239587.0, \"Valence\": 0.754, \"Chord\": \"B\"}, {\"Index\": 678, \"Highest Charting Position\": 149, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Little Saint Nick - 1991 Remix\", \"Streams\": 7301381, \"Artist\": \"The Beach Boys\", \"Artist Followers\": 1251372.0, \"Song ID\": \"63Lk6VuXdj7S58R3wLdv9r\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 0.0, \"Danceability\": 0.602, \"Energy\": 0.553, \"Loudness\": -9.336, \"Speechiness\": 0.0328, \"Acousticness\": 0.108, \"Liveness\": 0.0512, \"Tempo\": 130.594, \"Duration (ms)\": 118840.0, \"Valence\": 0.971, \"Chord\": \"B\"}, {\"Index\": 679, \"Highest Charting Position\": 150, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Naughty List (with Dixie)\", \"Streams\": 7299201, \"Artist\": \"Liam Payne\", \"Artist Followers\": 8037861.0, \"Song ID\": \"2Y0ktCGrGoGcQFXsGztvhi\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 51.0, \"Danceability\": 0.619, \"Energy\": 0.771, \"Loudness\": -2.204, \"Speechiness\": 0.0601, \"Acousticness\": 0.0318, \"Liveness\": 0.114, \"Tempo\": 81.966, \"Duration (ms)\": 154747.0, \"Valence\": 0.704, \"Chord\": \"A\"}, {\"Index\": 680, \"Highest Charting Position\": 152, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"I'll Be Home\", \"Streams\": 7281773, \"Artist\": \"Meghan Trainor\", \"Artist Followers\": 10606572.0, \"Song ID\": \"0lTurWECr2XL607eJAj1A3\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2015-01-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 45.0, \"Danceability\": 0.542, \"Energy\": 0.37, \"Loudness\": -7.779, \"Speechiness\": 0.0257, \"Acousticness\": 0.318, \"Liveness\": 0.108, \"Tempo\": 84.796, \"Duration (ms)\": 219653.0, \"Valence\": 0.289, \"Chord\": \"D\"}, {\"Index\": 681, \"Highest Charting Position\": 156, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Rudolph The Red-Nosed Reindeer\", \"Streams\": 7227612, \"Artist\": \"Dean Martin\", \"Artist Followers\": 1139096.0, \"Song ID\": \"2L9QLAhrvtP4EYg1lY0Tnw\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"1959-01-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.478, \"Energy\": 0.201, \"Loudness\": -16.768, \"Speechiness\": 0.0332, \"Acousticness\": 0.919, \"Liveness\": 0.0854, \"Tempo\": 136.471, \"Duration (ms)\": 135760.0, \"Valence\": 0.857, \"Chord\": \"G\"}, {\"Index\": 682, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Mistletoe And Holly - Remastered 1999\", \"Streams\": 7225080, \"Artist\": \"Frank Sinatra\", \"Artist Followers\": 4953667.0, \"Song ID\": \"7faDzZnZYqTyYThx2sbHVQ\", \"Genre\": \"['adult standards', 'easy listening', 'lounge']\", \"Release Date\": \"1957-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 38.0, \"Danceability\": 0.607, \"Energy\": 0.103, \"Loudness\": -14.405, \"Speechiness\": 0.0404, \"Acousticness\": 0.804, \"Liveness\": 0.076, \"Tempo\": 110.378, \"Duration (ms)\": 136427.0, \"Valence\": 0.341, \"Chord\": \"A\"}, {\"Index\": 683, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Jingle Bells - Remastered 1999\", \"Streams\": 7182262, \"Artist\": \"Frank Sinatra\", \"Artist Followers\": 4953667.0, \"Song ID\": \"4HEOgBHRCExyYVeTyrXsnL\", \"Genre\": \"['adult standards', 'easy listening', 'lounge']\", \"Release Date\": \"1957-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 36.0, \"Danceability\": 0.512, \"Energy\": 0.339, \"Loudness\": -13.119, \"Speechiness\": 0.0498, \"Acousticness\": 0.727, \"Liveness\": 0.0977, \"Tempo\": 174.609, \"Duration (ms)\": 120693.0, \"Valence\": 0.951, \"Chord\": \"G#/Ab\"}, {\"Index\": 684, \"Highest Charting Position\": 160, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Oh Santa! (feat. Ariana Grande & Jennifer Hudson)\", \"Streams\": 7170169, \"Artist\": \"Mariah Carey\", \"Artist Followers\": 6931357.0, \"Song ID\": \"1Ri9P0ZPrqr6h0REDRdJBd\", \"Genre\": \"['dance pop', 'pop', 'r&b', 'urban contemporary']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 47.0, \"Danceability\": 0.648, \"Energy\": 0.938, \"Loudness\": -3.298, \"Speechiness\": 0.115, \"Acousticness\": 0.0339, \"Liveness\": 0.0564, \"Tempo\": 78.496, \"Duration (ms)\": 200467.0, \"Valence\": 0.849, \"Chord\": \"C#/Db\"}, {\"Index\": 685, \"Highest Charting Position\": 161, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Do You Hear What I Hear? - Remastered 2006\", \"Streams\": 7149158, \"Artist\": \"Bing Crosby\", \"Artist Followers\": 359973.0, \"Song ID\": \"5aDoUmxBsbdpS16alksb5Z\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'swing', 'vocal jazz']\", \"Release Date\": \"2006-01-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.566, \"Energy\": 0.246, \"Loudness\": -15.499, \"Speechiness\": 0.0276, \"Acousticness\": 0.813, \"Liveness\": 0.195, \"Tempo\": 101.529, \"Duration (ms)\": 165667.0, \"Valence\": 0.412, \"Chord\": \"A#/Bb\"}, {\"Index\": 686, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Hallelujah\", \"Streams\": 6985392, \"Artist\": \"Pentatonix\", \"Artist Followers\": 3083825.0, \"Song ID\": \"0HZk0QsXPhMNAWNDR3rYE8\", \"Genre\": \"['a cappella']\", \"Release Date\": \"2017-12-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 60.0, \"Danceability\": 0.364, \"Energy\": 0.378, \"Loudness\": -7.381, \"Speechiness\": 0.0331, \"Acousticness\": 0.47, \"Liveness\": 0.339, \"Tempo\": 89.918, \"Duration (ms)\": 268960.0, \"Valence\": 0.366, \"Chord\": \"G\"}, {\"Index\": 687, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"This Christmas\", \"Streams\": 6809438, \"Artist\": \"Donny Hathaway\", \"Artist Followers\": 424935.0, \"Song ID\": \"38xhBO2AKrJnjdjVnhJES6\", \"Genre\": \"['chicago soul', 'classic soul', 'funk', 'motown', 'neo soul', 'quiet storm', 'soul', 'southern soul']\", \"Release Date\": \"1990-04-03\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 42.0, \"Danceability\": 0.634, \"Energy\": 0.645, \"Loudness\": -9.2, \"Speechiness\": 0.0376, \"Acousticness\": 0.292, \"Liveness\": 0.246, \"Tempo\": 93.047, \"Duration (ms)\": 231173.0, \"Valence\": 0.677, \"Chord\": \"F\"}, {\"Index\": 688, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Winter Wonderland\", \"Streams\": 6680928, \"Artist\": \"Tony Bennett\", \"Artist Followers\": 659472.0, \"Song ID\": \"6kkJlaBYdyFcwCg67hW40t\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"2014-12-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 29.0, \"Danceability\": 0.604, \"Energy\": 0.497, \"Loudness\": -6.676, \"Speechiness\": 0.0319, \"Acousticness\": 0.727, \"Liveness\": 0.102, \"Tempo\": 126.011, \"Duration (ms)\": 149307.0, \"Valence\": 0.72, \"Chord\": \"C#/Db\"}, {\"Index\": 689, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas Tree Farm\", \"Streams\": 6657404, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2mvabkN1i2gLnGAPUVdwek\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 52.0, \"Danceability\": 0.598, \"Energy\": 0.68, \"Loudness\": -4.505, \"Speechiness\": 0.0331, \"Acousticness\": 0.06, \"Liveness\": 0.324, \"Tempo\": 134.002, \"Duration (ms)\": 228027.0, \"Valence\": 0.437, \"Chord\": \"G\"}, {\"Index\": 690, \"Highest Charting Position\": 182, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Cozy Little Christmas\", \"Streams\": 6652130, \"Artist\": \"Katy Perry\", \"Artist Followers\": 18936929.0, \"Song ID\": \"02FaKXXL7KUtRc7K0k54tL\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-11-15\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.774, \"Energy\": 0.608, \"Loudness\": -6.264, \"Speechiness\": 0.128, \"Acousticness\": 0.128, \"Liveness\": 0.0895, \"Tempo\": 137.494, \"Duration (ms)\": 182521.0, \"Valence\": 0.56, \"Chord\": \"G\"}, {\"Index\": 691, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Merry Christmas, Happy Holidays\", \"Streams\": 6635128, \"Artist\": \"*NSYNC\", \"Artist Followers\": 1564750.0, \"Song ID\": \"4v9WbaxW8HdjqfUiWYWsII\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"1998-10-30\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.643, \"Energy\": 0.939, \"Loudness\": -3.967, \"Speechiness\": 0.0463, \"Acousticness\": 0.104, \"Liveness\": 0.881, \"Tempo\": 104.999, \"Duration (ms)\": 255307.0, \"Valence\": 0.756, \"Chord\": \"F\"}, {\"Index\": 692, \"Highest Charting Position\": 24, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"tolerate it\", \"Streams\": 6635109, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0PurA4JVJ8YQgSVopY8fn6\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 67.0, \"Danceability\": 0.316, \"Energy\": 0.361, \"Loudness\": -10.381, \"Speechiness\": 0.0488, \"Acousticness\": 0.878, \"Liveness\": 0.0797, \"Tempo\": 74.952, \"Duration (ms)\": 245440.0, \"Valence\": 0.221, \"Chord\": \"A\"}, {\"Index\": 693, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Please Come Home for Christmas - 2013 Remaster\", \"Streams\": 6400108, \"Artist\": \"Eagles\", \"Artist Followers\": 6896776.0, \"Song ID\": \"3QIoEi8Enr9uHffwInGIsC\", \"Genre\": \"['album rock', 'classic rock', 'country rock', 'folk rock', 'heartland rock', 'mellow gold', 'rock', 'soft rock', 'yacht rock']\", \"Release Date\": \"1994\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.612, \"Energy\": 0.289, \"Loudness\": -11.568, \"Speechiness\": 0.0421, \"Acousticness\": 0.599, \"Liveness\": 0.0561, \"Tempo\": 183.18, \"Duration (ms)\": 177440.0, \"Valence\": 0.466, \"Chord\": \"A\"}, {\"Index\": 694, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"My Kind Of Present\", \"Streams\": 6278993, \"Artist\": \"Meghan Trainor\", \"Artist Followers\": 10606572.0, \"Song ID\": \"2rkb8ijsPapKDMEh0cSe8I\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.485, \"Energy\": 0.444, \"Loudness\": -6.232, \"Speechiness\": 0.195, \"Acousticness\": 0.373, \"Liveness\": 0.0969, \"Tempo\": 179.967, \"Duration (ms)\": 161013.0, \"Valence\": 0.777, \"Chord\": \"C#/Db\"}, {\"Index\": 695, \"Highest Charting Position\": 28, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"happiness\", \"Streams\": 16213589, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"73YUReisjb3A9ActdLLjJQ\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 65.0, \"Danceability\": 0.559, \"Energy\": 0.334, \"Loudness\": -10.733, \"Speechiness\": 0.0376, \"Acousticness\": 0.87, \"Liveness\": 0.114, \"Tempo\": 122.079, \"Duration (ms)\": 315147.0, \"Valence\": 0.211, \"Chord\": \"B\"}, {\"Index\": 696, \"Highest Charting Position\": 34, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"ivy\", \"Streams\": 14519547, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"19CSr8rwW05VJL2F91KFNK\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.515, \"Energy\": 0.545, \"Loudness\": -9.277, \"Speechiness\": 0.0353, \"Acousticness\": 0.855, \"Liveness\": 0.0921, \"Tempo\": 88.856, \"Duration (ms)\": 260440.0, \"Valence\": 0.535, \"Chord\": \"D\"}, {\"Index\": 697, \"Highest Charting Position\": 38, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"dorothea\", \"Streams\": 14392788, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"670fUmXf4KQekzbEgaXyPA\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.605, \"Energy\": 0.488, \"Loudness\": -8.322, \"Speechiness\": 0.0264, \"Acousticness\": 0.696, \"Liveness\": 0.129, \"Tempo\": 119.966, \"Duration (ms)\": 225880.0, \"Valence\": 0.354, \"Chord\": \"E\"}, {\"Index\": 698, \"Highest Charting Position\": 39, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"coney island (feat. The National)\", \"Streams\": 14385703, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3k7ne7VmH43ZPWxPdvPUgR\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.537, \"Energy\": 0.537, \"Loudness\": -11.266, \"Speechiness\": 0.0617, \"Acousticness\": 0.819, \"Liveness\": 0.142, \"Tempo\": 107.895, \"Duration (ms)\": 275320.0, \"Valence\": 0.292, \"Chord\": \"G#/Ab\"}, {\"Index\": 699, \"Highest Charting Position\": 43, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"evermore (feat. Bon Iver)\", \"Streams\": 13810722, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3O5osWf1rSoKMwe6E9ZaXP\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.39, \"Energy\": 0.27, \"Loudness\": -10.673, \"Speechiness\": 0.0308, \"Acousticness\": 0.937, \"Liveness\": 0.111, \"Tempo\": 125.177, \"Duration (ms)\": 304107.0, \"Valence\": 0.32, \"Chord\": \"C#/Db\"}, {\"Index\": 700, \"Highest Charting Position\": 45, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"long story short\", \"Streams\": 13583538, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2o2sgVJIgFXk8GQjWTgI6U\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.546, \"Energy\": 0.73, \"Loudness\": -7.704, \"Speechiness\": 0.0417, \"Acousticness\": 0.66, \"Liveness\": 0.0972, \"Tempo\": 157.895, \"Duration (ms)\": 215920.0, \"Valence\": 0.573, \"Chord\": \"C\"}, {\"Index\": 701, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"cowboy like me\", \"Streams\": 12782098, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1XjHRolIXL2M1EEOUsGGR4\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.604, \"Energy\": 0.517, \"Loudness\": -9.014, \"Speechiness\": 0.0347, \"Acousticness\": 0.768, \"Liveness\": 0.123, \"Tempo\": 127.967, \"Duration (ms)\": 275040.0, \"Valence\": 0.511, \"Chord\": \"C\"}, {\"Index\": 702, \"Highest Charting Position\": 57, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"marjorie\", \"Streams\": 12234761, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"12ntTeqEeTg7GAVpe8Mhpl\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.535, \"Energy\": 0.561, \"Loudness\": -11.609, \"Speechiness\": 0.0484, \"Acousticness\": 0.876, \"Liveness\": 0.115, \"Tempo\": 96.103, \"Duration (ms)\": 257773.0, \"Valence\": 0.287, \"Chord\": \"F\"}, {\"Index\": 703, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"closure\", \"Streams\": 11245393, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"35rdVq36LMHQX0Suw9a6tK\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 62.0, \"Danceability\": 0.689, \"Energy\": 0.704, \"Loudness\": -10.813, \"Speechiness\": 0.245, \"Acousticness\": 0.835, \"Liveness\": 0.134, \"Tempo\": 151.884, \"Duration (ms)\": 180653.0, \"Valence\": 0.92, \"Chord\": \"A\"}, {\"Index\": 704, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"She Knows This\", \"Streams\": 10561183, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"1xzUQMiCoY5pdego0pHMeV\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.39, \"Energy\": 0.724, \"Loudness\": -7.607, \"Speechiness\": 0.0889, \"Acousticness\": 0.162, \"Liveness\": 0.393, \"Tempo\": 165.945, \"Duration (ms)\": 216560.0, \"Valence\": 0.312, \"Chord\": \"F#/Gb\"}, {\"Index\": 705, \"Highest Charting Position\": 97, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Another Day\", \"Streams\": 8901697, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"6myUpr3GDR80Dg3zqNTmmG\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 63.0, \"Danceability\": 0.646, \"Energy\": 0.758, \"Loudness\": -7.75, \"Speechiness\": 0.0708, \"Acousticness\": 0.556, \"Liveness\": 0.335, \"Tempo\": 172.995, \"Duration (ms)\": 199787.0, \"Valence\": 0.0642, \"Chord\": \"E\"}, {\"Index\": 706, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Solo Dolo, Pt. III\", \"Streams\": 7655623, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"27oVCAziETRbNuo5A8LNpg\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 61.0, \"Danceability\": 0.589, \"Energy\": 0.727, \"Loudness\": -6.907, \"Speechiness\": 0.0866, \"Acousticness\": 0.239, \"Liveness\": 0.164, \"Tempo\": 152.058, \"Duration (ms)\": 242267.0, \"Valence\": 0.52, \"Chord\": \"A#/Bb\"}, {\"Index\": 707, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Dive\", \"Streams\": 7524738, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"7Hc3YL8oDiAzbiAW32KXrw\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 60.0, \"Danceability\": 0.64, \"Energy\": 0.621, \"Loudness\": -8.269, \"Speechiness\": 0.0679, \"Acousticness\": 0.67, \"Liveness\": 0.36, \"Tempo\": 123.105, \"Duration (ms)\": 148707.0, \"Valence\": 0.332, \"Chord\": \"A\"}, {\"Index\": 708, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Heaven On Earth\", \"Streams\": 7117347, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"2koUj1Fn5TKFEkChSmBPIb\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 59.0, \"Danceability\": 0.786, \"Energy\": 0.61, \"Loudness\": -6.736, \"Speechiness\": 0.0558, \"Acousticness\": 0.379, \"Liveness\": 0.0765, \"Tempo\": 130.036, \"Duration (ms)\": 201093.0, \"Valence\": 0.228, \"Chord\": \"C\"}, {\"Index\": 709, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Sad People\", \"Streams\": 6865689, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"4nuAslShoN77tq12fzwjUq\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 62.0, \"Danceability\": 0.636, \"Energy\": 0.647, \"Loudness\": -6.971, \"Speechiness\": 0.0381, \"Acousticness\": 0.247, \"Liveness\": 0.113, \"Tempo\": 158.073, \"Duration (ms)\": 176027.0, \"Valence\": 0.416, \"Chord\": \"F\"}, {\"Index\": 710, \"Highest Charting Position\": 152, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Damaged\", \"Streams\": 6763705, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"2n7Ao4nyESBa5ti8gcAbBt\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 57.0, \"Danceability\": 0.625, \"Energy\": 0.581, \"Loudness\": -7.1, \"Speechiness\": 0.0316, \"Acousticness\": 0.553, \"Liveness\": 0.254, \"Tempo\": 142.04, \"Duration (ms)\": 150853.0, \"Valence\": 0.267, \"Chord\": \"G#/Ab\"}, {\"Index\": 711, \"Highest Charting Position\": 17, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"YO VISTO AS\\u00cd\", \"Streams\": 6388079, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5fROvzNghPid8mbKNDYvpJ\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 73.0, \"Danceability\": 0.688, \"Energy\": 0.881, \"Loudness\": -4.889, \"Speechiness\": 0.0474, \"Acousticness\": 0.0947, \"Liveness\": 0.0804, \"Tempo\": 123.013, \"Duration (ms)\": 191526.0, \"Valence\": 0.677, \"Chord\": \"G\"}, {\"Index\": 712, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Beautiful Trip\", \"Streams\": 6108393, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"4IIuCotvqijraSdnVLaFnM\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 54.0, \"Danceability\": 0.331, \"Energy\": 0.513, \"Loudness\": -15.392, \"Speechiness\": 0.632, \"Acousticness\": 0.972, \"Liveness\": 0.882, \"Tempo\": 133.971, \"Duration (ms)\": 37013.0, \"Valence\": 0.42, \"Chord\": \"B\"}, {\"Index\": 713, \"Highest Charting Position\": 185, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"The Void\", \"Streams\": 6068816, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"2yg7MXp8nSPaf61HVkhEr3\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 61.0, \"Danceability\": 0.464, \"Energy\": 0.459, \"Loudness\": -8.736, \"Speechiness\": 0.0314, \"Acousticness\": 0.365, \"Liveness\": 0.117, \"Tempo\": 142.017, \"Duration (ms)\": 325413.0, \"Valence\": 0.0786, \"Chord\": \"G\"}, {\"Index\": 714, \"Highest Charting Position\": 1, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"cardigan\", \"Streams\": 5845457, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"4R2kfaDFhslZEMJqAFNpdd\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-12-11--2020-12-18\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 79.0, \"Danceability\": 0.613, \"Energy\": 0.581, \"Loudness\": -8.588, \"Speechiness\": 0.0424, \"Acousticness\": 0.537, \"Liveness\": 0.25, \"Tempo\": 130.033, \"Duration (ms)\": 239560.0, \"Valence\": 0.551, \"Chord\": \"C\"}, {\"Index\": 715, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Real Shit (with benny blanco)\", \"Streams\": 9325928, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"3uVPLtkmDu8pDkYEAVqbgS\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-12-02\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 70.0, \"Danceability\": 0.703, \"Energy\": 0.703, \"Loudness\": -4.672, \"Speechiness\": 0.133, \"Acousticness\": 0.605, \"Liveness\": 0.12, \"Tempo\": 76.017, \"Duration (ms)\": 183783.0, \"Valence\": 0.697, \"Chord\": \"C#/Db\"}, {\"Index\": 716, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Teach Me How To Love\", \"Streams\": 7932101, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 33893352.0, \"Song ID\": \"5LZtB6nxvjIhUoElp3Zqk0\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 68.0, \"Danceability\": 0.592, \"Energy\": 0.885, \"Loudness\": -4.944, \"Speechiness\": 0.0807, \"Acousticness\": 0.0505, \"Liveness\": 0.0843, \"Tempo\": 98.991, \"Duration (ms)\": 202357.0, \"Valence\": 0.731, \"Chord\": \"A\"}, {\"Index\": 717, \"Highest Charting Position\": 138, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Blinding Lights (with ROSAL\\u00cdA) - Remix\", \"Streams\": 6653913, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"7MXgrcOQAJ5VwSNUL0lDd3\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 64.0, \"Danceability\": 0.49, \"Energy\": 0.694, \"Loudness\": -5.793, \"Speechiness\": 0.0618, \"Acousticness\": 0.0133, \"Liveness\": 0.0946, \"Tempo\": 170.903, \"Duration (ms)\": 216123.0, \"Valence\": 0.249, \"Chord\": \"F\"}, {\"Index\": 718, \"Highest Charting Position\": 15, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"WHATS POPPIN (feat. DaBaby, Tory Lanez & Lil Wayne) - Remix\", \"Streams\": 6567755, \"Artist\": \"Tory Lanez, Jack Harlow\", \"Artist Followers\": 3828418.0, \"Song ID\": \"2MbdDtCv5LUVjYy9RuGTgC\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-06-24\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 80.0, \"Danceability\": 0.904, \"Energy\": 0.723, \"Loudness\": -5.224, \"Speechiness\": 0.26, \"Acousticness\": 0.0631, \"Liveness\": 0.185, \"Tempo\": 145.013, \"Duration (ms)\": 227478.0, \"Valence\": 0.835, \"Chord\": \"B\"}, {\"Index\": 719, \"Highest Charting Position\": 29, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"TE DESEO LO MEJOR\", \"Streams\": 6204228, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"23XjN1s3DZC8Q9ZwuorYY4\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.763, \"Energy\": 0.597, \"Loudness\": -5.054, \"Speechiness\": 0.0416, \"Acousticness\": 0.158, \"Liveness\": 0.111, \"Tempo\": 126.054, \"Duration (ms)\": 139576.0, \"Valence\": 0.194, \"Chord\": \"C#/Db\"}, {\"Index\": 720, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Errbody\", \"Streams\": 5929516, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"6eVxH9Kyanzrw636zJRPcw\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-12-03\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 68.0, \"Danceability\": 0.887, \"Energy\": 0.606, \"Loudness\": -6.572, \"Speechiness\": 0.324, \"Acousticness\": 0.000407, \"Liveness\": 0.151, \"Tempo\": 139.995, \"Duration (ms)\": 210699.0, \"Valence\": 0.272, \"Chord\": \"D\"}, {\"Index\": 721, \"Highest Charting Position\": 86, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"Angels Like You\", \"Streams\": 5884221, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"1daDRI9ahBonbWD8YcxOIB\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 77.0, \"Danceability\": 0.672, \"Energy\": 0.642, \"Loudness\": -4.035, \"Speechiness\": 0.0313, \"Acousticness\": 0.0981, \"Liveness\": 0.1, \"Tempo\": 121.981, \"Duration (ms)\": 196453.0, \"Valence\": 0.494, \"Chord\": \"F\"}, {\"Index\": 722, \"Highest Charting Position\": 18, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Blue & Grey\", \"Streams\": 5698275, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"0n2moJpAEWHwaPYYjkzMDl\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 77.0, \"Danceability\": 0.547, \"Energy\": 0.605, \"Loudness\": -6.755, \"Speechiness\": 0.0415, \"Acousticness\": 0.42, \"Liveness\": 0.125, \"Tempo\": 121.953, \"Duration (ms)\": 254950.0, \"Valence\": 0.364, \"Chord\": \"G#/Ab\"}, {\"Index\": 723, \"Highest Charting Position\": 46, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Mad at Disney\", \"Streams\": 5436450, \"Artist\": \"salem ilese\", \"Artist Followers\": 133998.0, \"Song ID\": \"7aGyRfJWtLqgJaZoG9lJhE\", \"Genre\": \"['alt z', 'modern indie pop', 'social media pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 76.0, \"Danceability\": 0.738, \"Energy\": 0.621, \"Loudness\": -7.313, \"Speechiness\": 0.0486, \"Acousticness\": 0.424, \"Liveness\": 0.692, \"Tempo\": 113.968, \"Duration (ms)\": 136839.0, \"Valence\": 0.715, \"Chord\": \"C\"}, {\"Index\": 724, \"Highest Charting Position\": 9, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Safaera\", \"Streams\": 5390363, \"Artist\": \"Bad Bunny, Jowell & Randy, \\u00d1engo Flow\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2DEZmgHKAvm41k4J3R2E9Y\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 79.0, \"Danceability\": 0.607, \"Energy\": 0.829, \"Loudness\": -4.074, \"Speechiness\": 0.379, \"Acousticness\": 0.0103, \"Liveness\": 0.107, \"Tempo\": 96.172, \"Duration (ms)\": 295177.0, \"Valence\": 0.685, \"Chord\": \"D\"}, {\"Index\": 725, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"LA DROGA\", \"Streams\": 5375449, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"67ACYA3UI6QMNtHX6b34wX\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.643, \"Energy\": 0.727, \"Loudness\": -5.506, \"Speechiness\": 0.0389, \"Acousticness\": 0.0439, \"Liveness\": 0.123, \"Tempo\": 90.019, \"Duration (ms)\": 162299.0, \"Valence\": 0.295, \"Chord\": \"C#/Db\"}, {\"Index\": 726, \"Highest Charting Position\": 60, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"GO (feat. Juice WRLD)\", \"Streams\": 5370330, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"2rPHUAeUPbNgTmK18FPTiZ\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-06--2020-11-13\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 78.0, \"Danceability\": 0.487, \"Energy\": 0.74, \"Loudness\": -4.973, \"Speechiness\": 0.0944, \"Acousticness\": 0.157, \"Liveness\": 0.612, \"Tempo\": 73.779, \"Duration (ms)\": 181688.0, \"Valence\": 0.522, \"Chord\": \"F#/Gb\"}, {\"Index\": 727, \"Highest Charting Position\": 180, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"Jenny (I Wanna Ruin Our Friendship)\", \"Streams\": 5364223, \"Artist\": \"Studio Killers\", \"Artist Followers\": 181236.0, \"Song ID\": \"4JLBDUYSaOMPYND0iWeSWQ\", \"Genre\": \"[]\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 72.0, \"Danceability\": 0.668, \"Energy\": 0.798, \"Loudness\": -5.701, \"Speechiness\": 0.0334, \"Acousticness\": 0.00305, \"Liveness\": 0.277, \"Tempo\": 133.928, \"Duration (ms)\": 215280.0, \"Valence\": 0.575, \"Chord\": \"B\"}, {\"Index\": 728, \"Highest Charting Position\": 35, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Mood (Remix) feat. Justin Bieber, J Balvin & iann dior\", \"Streams\": 5314734, \"Artist\": \"24kGoldn\", \"Artist Followers\": 1276406.0, \"Song ID\": \"6FuGJB290AQMAHTfjOYVaK\", \"Genre\": \"['cali rap']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 77.0, \"Danceability\": 0.721, \"Energy\": 0.745, \"Loudness\": -3.508, \"Speechiness\": 0.0366, \"Acousticness\": 0.151, \"Liveness\": 0.372, \"Tempo\": 90.988, \"Duration (ms)\": 192745.0, \"Valence\": 0.699, \"Chord\": \"G\"}, {\"Index\": 729, \"Highest Charting Position\": 41, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"HOY COBR\\u00c9\", \"Streams\": 12914431, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0tjZv2hChdHZCW1zFXpy1J\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.86, \"Energy\": 0.725, \"Loudness\": -6.7, \"Speechiness\": 0.249, \"Acousticness\": 0.0464, \"Liveness\": 0.0994, \"Tempo\": 145.001, \"Duration (ms)\": 162151.0, \"Valence\": 0.375, \"Chord\": \"B\"}, {\"Index\": 730, \"Highest Charting Position\": 44, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"MALDITA POBREZA\", \"Streams\": 12660806, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0Lsis3LB0XAK6XlTHXaJk2\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 67.0, \"Danceability\": 0.762, \"Energy\": 0.861, \"Loudness\": -4.075, \"Speechiness\": 0.0652, \"Acousticness\": 0.139, \"Liveness\": 0.0956, \"Tempo\": 133.037, \"Duration (ms)\": 213609.0, \"Valence\": 0.588, \"Chord\": \"E\"}, {\"Index\": 731, \"Highest Charting Position\": 48, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"EL MUNDO ES M\\u00cdO\", \"Streams\": 12507010, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"36DHxTW2xdr9GG15T9oK9L\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 67.0, \"Danceability\": 0.716, \"Energy\": 0.522, \"Loudness\": -6.834, \"Speechiness\": 0.0582, \"Acousticness\": 0.166, \"Liveness\": 0.113, \"Tempo\": 76.993, \"Duration (ms)\": 165199.0, \"Valence\": 0.224, \"Chord\": \"F\"}, {\"Index\": 732, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"ANTES QUE SE ACABE\", \"Streams\": 11298839, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"7kjEqI6eZ7YlFrGhxixnlN\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 76.0, \"Danceability\": 0.693, \"Energy\": 0.549, \"Loudness\": -6.098, \"Speechiness\": 0.0577, \"Acousticness\": 0.505, \"Liveness\": 0.324, \"Tempo\": 139.988, \"Duration (ms)\": 221187.0, \"Valence\": 0.473, \"Chord\": \"D\"}, {\"Index\": 733, \"Highest Charting Position\": 59, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"SORRY PAPI\", \"Streams\": 11066606, \"Artist\": \"Bad Bunny, ABRA\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5jZ32WOU7sqzDYbzINwMUk\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.612, \"Energy\": 0.561, \"Loudness\": -6.054, \"Speechiness\": 0.0851, \"Acousticness\": 0.0601, \"Liveness\": 0.145, \"Tempo\": 191.911, \"Duration (ms)\": 163053.0, \"Valence\": 0.393, \"Chord\": \"C#/Db\"}, {\"Index\": 734, \"Highest Charting Position\": 63, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"120\", \"Streams\": 10957181, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3KJ3opyV29269SXkPrc19l\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 72.0, \"Danceability\": 0.636, \"Energy\": 0.656, \"Loudness\": -5.542, \"Speechiness\": 0.0676, \"Acousticness\": 0.451, \"Liveness\": 0.287, \"Tempo\": 171.918, \"Duration (ms)\": 151506.0, \"Valence\": 0.439, \"Chord\": \"D\"}, {\"Index\": 735, \"Highest Charting Position\": 66, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"TRELLAS\", \"Streams\": 10733416, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"09WAnxdBuebQopKhJT3oZS\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 66.0, \"Danceability\": 0.43, \"Energy\": 0.412, \"Loudness\": -5.372, \"Speechiness\": 0.0281, \"Acousticness\": 0.2, \"Liveness\": 0.324, \"Tempo\": 90.872, \"Duration (ms)\": 157673.0, \"Valence\": 0.0508, \"Chord\": \"D\"}, {\"Index\": 736, \"Highest Charting Position\": 83, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"Wonderful Christmastime [Edited Version] - Remastered 2011 / Edited Version\", \"Streams\": 9624871, \"Artist\": \"Paul McCartney\", \"Artist Followers\": 3609658.0, \"Song ID\": \"1SV1fxF65n9NhRHp3KlBuu\", \"Genre\": \"['album rock', 'art rock', 'beatlesque', 'classic rock', 'mellow gold', 'rock', 'soft rock']\", \"Release Date\": \"1980-05-16\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 51.0, \"Danceability\": 0.774, \"Energy\": 0.511, \"Loudness\": -8.914, \"Speechiness\": 0.0319, \"Acousticness\": 0.322, \"Liveness\": 0.0672, \"Tempo\": 94.736, \"Duration (ms)\": 227653.0, \"Valence\": 0.771, \"Chord\": \"B\"}, {\"Index\": 737, \"Highest Charting Position\": 16, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Fly To My Room\", \"Streams\": 8413330, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3QH8rQGNFX8VLbCgZ7uPTS\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 76.0, \"Danceability\": 0.764, \"Energy\": 0.526, \"Loudness\": -7.355, \"Speechiness\": 0.212, \"Acousticness\": 0.0484, \"Liveness\": 0.0718, \"Tempo\": 114.91, \"Duration (ms)\": 222243.0, \"Valence\": 0.588, \"Chord\": \"B\"}, {\"Index\": 738, \"Highest Charting Position\": 24, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Telepathy\", \"Streams\": 7703744, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"2FVpOsjT1iquZ3SpCjZ9Ne\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 77.0, \"Danceability\": 0.787, \"Energy\": 0.669, \"Loudness\": -4.333, \"Speechiness\": 0.0428, \"Acousticness\": 0.00782, \"Liveness\": 0.123, \"Tempo\": 104.994, \"Duration (ms)\": 202313.0, \"Valence\": 0.57, \"Chord\": \"F\"}, {\"Index\": 739, \"Highest Charting Position\": 26, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Dis-ease\", \"Streams\": 7165808, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"54DmTIv86D3sYdiawjULQ0\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 75.0, \"Danceability\": 0.731, \"Energy\": 0.845, \"Loudness\": -5.352, \"Speechiness\": 0.132, \"Acousticness\": 0.0132, \"Liveness\": 0.0782, \"Tempo\": 101.085, \"Duration (ms)\": 239722.0, \"Valence\": 0.484, \"Chord\": \"G#/Ab\"}, {\"Index\": 740, \"Highest Charting Position\": 27, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Stay\", \"Streams\": 7010227, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3ndCsZfq8OVwwkz9mmZvUz\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 76.0, \"Danceability\": 0.582, \"Energy\": 0.693, \"Loudness\": -5.048, \"Speechiness\": 0.0465, \"Acousticness\": 0.114, \"Liveness\": 0.13, \"Tempo\": 125.904, \"Duration (ms)\": 204800.0, \"Valence\": 0.341, \"Chord\": \"F#/Gb\"}, {\"Index\": 741, \"Highest Charting Position\": 151, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Heart Of Glass (Live from the iHeart Festival)\", \"Streams\": 6006877, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"5i7ThJfYLAzp2DyZuFpF6j\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-09-29\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 71.0, \"Danceability\": 0.58, \"Energy\": 0.908, \"Loudness\": -5.303, \"Speechiness\": 0.0341, \"Acousticness\": 0.000335, \"Liveness\": 0.087, \"Tempo\": 115.016, \"Duration (ms)\": 213672.0, \"Valence\": 0.427, \"Chord\": \"E\"}, {\"Index\": 742, \"Highest Charting Position\": 171, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"CANTARES DE NAVIDAD\", \"Streams\": 5842320, \"Artist\": \"Trio Vegabaje\\u00f1o\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2Iv6YBslkxslMJQsxshZh5\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 56.0, \"Danceability\": 0.764, \"Energy\": 0.523, \"Loudness\": -7.371, \"Speechiness\": 0.0406, \"Acousticness\": 0.777, \"Liveness\": 0.352, \"Tempo\": 118.671, \"Duration (ms)\": 199720.0, \"Valence\": 0.962, \"Chord\": \"D\"}, {\"Index\": 743, \"Highest Charting Position\": 172, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"Plastic Hearts\", \"Streams\": 5816739, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"6qCsKKS7Ol63SJW3LOIX5R\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 74.0, \"Danceability\": 0.551, \"Energy\": 0.756, \"Loudness\": -4.948, \"Speechiness\": 0.0652, \"Acousticness\": 0.0511, \"Liveness\": 0.0765, \"Tempo\": 175.984, \"Duration (ms)\": 205733.0, \"Valence\": 0.618, \"Chord\": \"D\"}, {\"Index\": 744, \"Highest Charting Position\": 63, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"C\\u00d3MO SE SIENTE - Remix\", \"Streams\": 5463964, \"Artist\": \"Jhay Cortez, Bad Bunny\", \"Artist Followers\": 2435159.0, \"Song ID\": \"2tFwfmceQa1Y6nRPhYbEtC\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-09\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 81.0, \"Danceability\": 0.807, \"Energy\": 0.606, \"Loudness\": -8.871, \"Speechiness\": 0.088, \"Acousticness\": 0.0946, \"Liveness\": 0.119, \"Tempo\": 92.988, \"Duration (ms)\": 227520.0, \"Valence\": 0.304, \"Chord\": \"D#/Eb\"}, {\"Index\": 745, \"Highest Charting Position\": 78, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Skit\", \"Streams\": 8392247, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4GVwjLRT7oSsKby7Vy8EHr\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 60.0, \"Danceability\": 0.703, \"Energy\": 0.321, \"Loudness\": -13.135, \"Speechiness\": 0.884, \"Acousticness\": 0.864, \"Liveness\": 0.908, \"Tempo\": 114.822, \"Duration (ms)\": 179548.0, \"Valence\": 0.544, \"Chord\": \"E\"}, {\"Index\": 746, \"Highest Charting Position\": 105, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Baby (with J Balvin)\", \"Streams\": 7276896, \"Artist\": \"Sfera Ebbasta\", \"Artist Followers\": 4430628.0, \"Song ID\": \"3eblNP3Zd5b5J3JaOckl8Y\", \"Genre\": \"['italian hip hop', 'italian pop', 'trap italiana']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 69.0, \"Danceability\": 0.755, \"Energy\": 0.882, \"Loudness\": -1.957, \"Speechiness\": 0.0532, \"Acousticness\": 0.125, \"Liveness\": 0.103, \"Tempo\": 99.984, \"Duration (ms)\": 193555.0, \"Valence\": 0.606, \"Chord\": \"A#/Bb\"}, {\"Index\": 747, \"Highest Charting Position\": 82, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Tick Tock (feat. 24kGoldn)\", \"Streams\": 6241923, \"Artist\": \"Clean Bandit, Mabel\", \"Artist Followers\": 4431309.0, \"Song ID\": \"27u7t9d7ZQoyjsCROHuZJ3\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk dance', 'uk funky']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 78.0, \"Danceability\": 0.779, \"Energy\": 0.705, \"Loudness\": -3.895, \"Speechiness\": 0.0344, \"Acousticness\": 0.369, \"Liveness\": 0.124, \"Tempo\": 101.022, \"Duration (ms)\": 178374.0, \"Valence\": 0.946, \"Chord\": \"C\"}, {\"Index\": 748, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Dime C\\u00f3mo Quieres\", \"Streams\": 6152821, \"Artist\": \"Christian Nodal, \\u00c1ngela Aguilar\", \"Artist Followers\": 8123757.0, \"Song ID\": \"4jcxBTrNvyqMJdMDyyjdYV\", \"Genre\": \"['mariachi', 'nuevo regional mexicano', 'ranchera', 'regional mexican']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 75.0, \"Danceability\": 0.839, \"Energy\": 0.667, \"Loudness\": -3.961, \"Speechiness\": 0.031, \"Acousticness\": 0.322, \"Liveness\": 0.244, \"Tempo\": 124.889, \"Duration (ms)\": 171360.0, \"Valence\": 0.878, \"Chord\": \"B\"}, {\"Index\": 749, \"Highest Charting Position\": 162, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Tik Tok (feat. Marracash & Gu\\u00e8 Pequeno)\", \"Streams\": 5504912, \"Artist\": \"Sfera Ebbasta\", \"Artist Followers\": 4430628.0, \"Song ID\": \"3tkYK45AZC0PqJ7MSe6IyJ\", \"Genre\": \"['italian hip hop', 'italian pop', 'trap italiana']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 59.0, \"Danceability\": 0.723, \"Energy\": 0.673, \"Loudness\": -7.636, \"Speechiness\": 0.137, \"Acousticness\": 0.0985, \"Liveness\": 0.323, \"Tempo\": 120.046, \"Duration (ms)\": 230389.0, \"Valence\": 0.302, \"Chord\": \"A\"}, {\"Index\": 750, \"Highest Charting Position\": 88, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Jerusalema (feat. Nomcebo Zikode)\", \"Streams\": 5362508, \"Artist\": \"Master KG\", \"Artist Followers\": 247480.0, \"Song ID\": \"2MlOUXmcofMackX3bxfSwi\", \"Genre\": \"['south african house']\", \"Release Date\": \"2020-01-24\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 78.0, \"Danceability\": 0.88, \"Energy\": 0.483, \"Loudness\": -7.012, \"Speechiness\": 0.0505, \"Acousticness\": 0.0185, \"Liveness\": 0.0607, \"Tempo\": 124.009, \"Duration (ms)\": 342613.0, \"Valence\": 0.827, \"Chord\": \"C#/Db\"}, {\"Index\": 751, \"Highest Charting Position\": 19, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Agua (with J Balvin) - Music From \\\"Sponge On The Run\\\" Movie\", \"Streams\": 5358940, \"Artist\": \"Tainy\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 752, \"Highest Charting Position\": 174, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Abracadabra (feat. Future)\", \"Streams\": 5263469, \"Artist\": \"Sfera Ebbasta\", \"Artist Followers\": 4430628.0, \"Song ID\": \"2GuLouaDNgLGxdJoe0vYf6\", \"Genre\": \"['italian hip hop', 'italian pop', 'trap italiana']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 55.0, \"Danceability\": 0.846, \"Energy\": 0.681, \"Loudness\": -7.091, \"Speechiness\": 0.174, \"Acousticness\": 0.0461, \"Liveness\": 0.112, \"Tempo\": 131.988, \"Duration (ms)\": 192965.0, \"Valence\": 0.809, \"Chord\": \"F\"}, {\"Index\": 753, \"Highest Charting Position\": 36, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Djadja (feat. Maluma) - Remix\", \"Streams\": 5203423, \"Artist\": \"Aya Nakamura\", \"Artist Followers\": 2953525.0, \"Song ID\": \"6AzKhCHOms83jvNVLsz0Bt\", \"Genre\": \"['basshall', 'francoton']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 72.0, \"Danceability\": 0.791, \"Energy\": 0.682, \"Loudness\": -7.328, \"Speechiness\": 0.158, \"Acousticness\": 0.175, \"Liveness\": 0.0926, \"Tempo\": 98.031, \"Duration (ms)\": 166851.0, \"Valence\": 0.672, \"Chord\": \"F\"}, {\"Index\": 754, \"Highest Charting Position\": 140, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"ALWAYS DO\", \"Streams\": 5196635, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"3QCU8BT0zDS9LPVfEhRFEE\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 76.0, \"Danceability\": 0.762, \"Energy\": 0.426, \"Loudness\": -6.865, \"Speechiness\": 0.113, \"Acousticness\": 0.0442, \"Liveness\": 0.0858, \"Tempo\": 167.827, \"Duration (ms)\": 151705.0, \"Valence\": 0.582, \"Chord\": \"G#/Ab\"}, {\"Index\": 755, \"Highest Charting Position\": 7, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Smile (with The Weeknd)\", \"Streams\": 5164187, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"6wQlQrTY5mVS8EGaFZVwVF\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 75.0, \"Danceability\": 0.694, \"Energy\": 0.685, \"Loudness\": -6.535, \"Speechiness\": 0.133, \"Acousticness\": 0.224, \"Liveness\": 0.124, \"Tempo\": 158.831, \"Duration (ms)\": 196180.0, \"Valence\": 0.306, \"Chord\": \"F#/Gb\"}, {\"Index\": 756, \"Highest Charting Position\": 22, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Pretty Savage\", \"Streams\": 5039047, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"1XnpzbOGptRwfJhZgLbmSr\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 75.0, \"Danceability\": 0.701, \"Energy\": 0.556, \"Loudness\": -7.42, \"Speechiness\": 0.0414, \"Acousticness\": 0.00886, \"Liveness\": 0.106, \"Tempo\": 152.045, \"Duration (ms)\": 201122.0, \"Valence\": 0.333, \"Chord\": \"A\"}, {\"Index\": 757, \"Highest Charting Position\": 41, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Savage Love (Laxed \\u2013 Siren Beat) [BTS Remix]\", \"Streams\": 4995203, \"Artist\": \"Jawsh 685, Jason Derulo\", \"Artist Followers\": 100635.0, \"Song ID\": \"4TgxFMOn5yoESW6zCidCXL\", \"Genre\": \"['nz pop']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 76.0, \"Danceability\": 0.758, \"Energy\": 0.598, \"Loudness\": -5.695, \"Speechiness\": 0.0868, \"Acousticness\": 0.16, \"Liveness\": 0.295, \"Tempo\": 149.836, \"Duration (ms)\": 184905.0, \"Valence\": 0.658, \"Chord\": \"C\"}, {\"Index\": 758, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Mirrors\", \"Streams\": 4988571, \"Artist\": \"Justin Timberlake\", \"Artist Followers\": 11034144.0, \"Song ID\": \"4rHZZAmHpZrA3iH5zx8frV\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2013-03-15\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 78.0, \"Danceability\": 0.574, \"Energy\": 0.512, \"Loudness\": -6.664, \"Speechiness\": 0.0503, \"Acousticness\": 0.234, \"Liveness\": 0.0946, \"Tempo\": 76.899, \"Duration (ms)\": 484147.0, \"Valence\": 0.512, \"Chord\": \"F\"}, {\"Index\": 759, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Hollywood (feat. Diplo)\", \"Streams\": 4920218, \"Artist\": \"Sfera Ebbasta\", \"Artist Followers\": 4430628.0, \"Song ID\": \"0WXU7I74NEN1DMLIT406Wx\", \"Genre\": \"['italian hip hop', 'italian pop', 'trap italiana']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 63.0, \"Danceability\": 0.848, \"Energy\": 0.708, \"Loudness\": -6.336, \"Speechiness\": 0.0366, \"Acousticness\": 0.153, \"Liveness\": 0.0948, \"Tempo\": 137.973, \"Duration (ms)\": 191869.0, \"Valence\": 0.926, \"Chord\": \"D\"}, {\"Index\": 760, \"Highest Charting Position\": 24, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Runnin\", \"Streams\": 4914682, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"5SWnsxjhdcEDc7LJjq9UHk\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 78.0, \"Danceability\": 0.819, \"Energy\": 0.626, \"Loudness\": -4.574, \"Speechiness\": 0.202, \"Acousticness\": 0.00748, \"Liveness\": 0.167, \"Tempo\": 143.01, \"Duration (ms)\": 195906.0, \"Valence\": 0.415, \"Chord\": \"A#/Bb\"}, {\"Index\": 761, \"Highest Charting Position\": 105, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Are You Bored Yet? (feat. Clairo)\", \"Streams\": 4911995, \"Artist\": \"Wallows\", \"Artist Followers\": 1963296.0, \"Song ID\": \"57RA3JGafJm5zRtKJiKPIm\", \"Genre\": \"['indie pop', 'modern rock', 'pop', 'rock']\", \"Release Date\": \"2019-03-22\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 81.0, \"Danceability\": 0.682, \"Energy\": 0.683, \"Loudness\": -6.444, \"Speechiness\": 0.0287, \"Acousticness\": 0.156, \"Liveness\": 0.273, \"Tempo\": 120.023, \"Duration (ms)\": 178000.0, \"Valence\": 0.64, \"Chord\": \"G#/Ab\"}, {\"Index\": 762, \"Highest Charting Position\": 44, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"10,000 Hours (with Justin Bieber)\", \"Streams\": 4911749, \"Artist\": \"Dan + Shay\", \"Artist Followers\": 2334615.0, \"Song ID\": \"2wrJq5XKLnmhRXHIAf9xBa\", \"Genre\": \"['contemporary country', 'country', 'pop']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.654, \"Energy\": 0.63, \"Loudness\": -4.644, \"Speechiness\": 0.0259, \"Acousticness\": 0.153, \"Liveness\": 0.111, \"Tempo\": 89.991, \"Duration (ms)\": 167693.0, \"Valence\": 0.43, \"Chord\": \"A#/Bb\"}, {\"Index\": 763, \"Highest Charting Position\": 87, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"You Got It\", \"Streams\": 4907925, \"Artist\": \"Vedo\", \"Artist Followers\": 260236.0, \"Song ID\": \"4lsHZ92XCFOQfzJFBTluk8\", \"Genre\": \"['pop r&b', 'r&b']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 79.0, \"Danceability\": 0.762, \"Energy\": 0.433, \"Loudness\": -8.937, \"Speechiness\": 0.187, \"Acousticness\": 0.143, \"Liveness\": 0.118, \"Tempo\": 122.074, \"Duration (ms)\": 203145.0, \"Valence\": 0.394, \"Chord\": \"F\"}, {\"Index\": 764, \"Highest Charting Position\": 129, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Qui\\u00e9reme Mientras Se Pueda\", \"Streams\": 4899440, \"Artist\": \"Manuel Turizo\", \"Artist Followers\": 7909963.0, \"Song ID\": \"34LI7rwi9H8w2S5KTHnv1M\", \"Genre\": \"['colombian pop', 'latin', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 74.0, \"Danceability\": 0.793, \"Energy\": 0.782, \"Loudness\": -3.945, \"Speechiness\": 0.0582, \"Acousticness\": 0.447, \"Liveness\": 0.124, \"Tempo\": 143.86, \"Duration (ms)\": 191945.0, \"Valence\": 0.81, \"Chord\": \"E\"}, {\"Index\": 765, \"Highest Charting Position\": 9, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Party Girl\", \"Streams\": 4878286, \"Artist\": \"StaySolidRocky\", \"Artist Followers\": 150587.0, \"Song ID\": \"5RqR4ZCCKJDcBLIn4sih9l\", \"Genre\": \"['melodic rap']\", \"Release Date\": \"2020-04-21\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 77.0, \"Danceability\": 0.728, \"Energy\": 0.431, \"Loudness\": -9.966, \"Speechiness\": 0.0622, \"Acousticness\": 0.749, \"Liveness\": 0.0996, \"Tempo\": 130.022, \"Duration (ms)\": 147800.0, \"Valence\": 0.629, \"Chord\": \"F#/Gb\"}, {\"Index\": 766, \"Highest Charting Position\": 95, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Drankin N Smokin\", \"Streams\": 7292247, \"Artist\": \"Future, Lil Uzi Vert\", \"Artist Followers\": 10491105.0, \"Song ID\": \"0k7wmahjkn389wAZdz19Cv\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-11-13--2020-11-20\", \"Popularity\": 78.0, \"Danceability\": 0.752, \"Energy\": 0.658, \"Loudness\": -6.297, \"Speechiness\": 0.342, \"Acousticness\": 0.0421, \"Liveness\": 0.0927, \"Tempo\": 151.951, \"Duration (ms)\": 213520.0, \"Valence\": 0.387, \"Chord\": \"C\"}, {\"Index\": 767, \"Highest Charting Position\": 86, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Be Like That - feat. Swae Lee & Khalid\", \"Streams\": 5929062, \"Artist\": \"Kane Brown\", \"Artist Followers\": 3509653.0, \"Song ID\": \"5f1joOtoMeyppIcJGZQvqJ\", \"Genre\": \"['contemporary country', 'country road']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 79.0, \"Danceability\": 0.727, \"Energy\": 0.626, \"Loudness\": -8.415, \"Speechiness\": 0.0726, \"Acousticness\": 0.0469, \"Liveness\": 0.126, \"Tempo\": 86.97, \"Duration (ms)\": 191406.0, \"Valence\": 0.322, \"Chord\": \"G\"}, {\"Index\": 768, \"Highest Charting Position\": 74, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"MORE\", \"Streams\": 5602168, \"Artist\": \"K/DA, Madison Beer, (G)I-DLE, Lexie Liu, Jaira Burns, Seraphine, League of Legends\", \"Artist Followers\": 1245965.0, \"Song ID\": \"6juLaduD4STCUDWT0AYun4\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2020-10-28\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 73.0, \"Danceability\": 0.66, \"Energy\": 0.787, \"Loudness\": -4.592, \"Speechiness\": 0.032, \"Acousticness\": 0.00257, \"Liveness\": 0.323, \"Tempo\": 142.018, \"Duration (ms)\": 217088.0, \"Valence\": 0.199, \"Chord\": \"C#/Db\"}, {\"Index\": 769, \"Highest Charting Position\": 140, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Enchule\", \"Streams\": 5561227, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6096559.0, \"Song ID\": \"3ThrfRAmijYU098H9q9tAs\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 70.0, \"Danceability\": 0.763, \"Energy\": 0.666, \"Loudness\": -3.316, \"Speechiness\": 0.194, \"Acousticness\": 0.153, \"Liveness\": 0.301, \"Tempo\": 90.086, \"Duration (ms)\": 185719.0, \"Valence\": 0.587, \"Chord\": \"G\"}, {\"Index\": 770, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Stripes Like Burberry\", \"Streams\": 5445204, \"Artist\": \"Future, Lil Uzi Vert\", \"Artist Followers\": 10491105.0, \"Song ID\": \"6lt8iodSkYWEV0ifKCSlfg\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-11-13--2020-11-20\", \"Popularity\": 56.0, \"Danceability\": 0.758, \"Energy\": 0.574, \"Loudness\": -7.833, \"Speechiness\": 0.217, \"Acousticness\": 0.216, \"Liveness\": 0.144, \"Tempo\": 144.081, \"Duration (ms)\": 274313.0, \"Valence\": 0.706, \"Chord\": \"A\"}, {\"Index\": 771, \"Highest Charting Position\": 117, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Papi Chulo\", \"Streams\": 5361669, \"Artist\": \"Octavian, Skepta\", \"Artist Followers\": 213344.0, \"Song ID\": \"6Juv5N0dNU1imms9c9u1dA\", \"Genre\": \"['afroswing', 'london rap', 'uk alternative hip hop', 'uk hip hop']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 73.0, \"Danceability\": 0.866, \"Energy\": 0.563, \"Loudness\": -6.964, \"Speechiness\": 0.108, \"Acousticness\": 0.185, \"Liveness\": 0.0889, \"Tempo\": 127.954, \"Duration (ms)\": 161668.0, \"Valence\": 0.307, \"Chord\": \"B\"}, {\"Index\": 772, \"Highest Charting Position\": 20, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"off the table (with The Weeknd)\", \"Streams\": 5308945, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"7E1jVNoWuemqUryI4FxsVD\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 67.0, \"Danceability\": 0.411, \"Energy\": 0.522, \"Loudness\": -7.295, \"Speechiness\": 0.0981, \"Acousticness\": 0.519, \"Liveness\": 0.398, \"Tempo\": 88.332, \"Duration (ms)\": 239949.0, \"Valence\": 0.382, \"Chord\": \"C\"}, {\"Index\": 773, \"Highest Charting Position\": 52, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Spicy (feat. Post Malone)\", \"Streams\": 5303146, \"Artist\": \"Ty Dolla $ign\", \"Artist Followers\": 3866304.0, \"Song ID\": \"5IUtvfNvOyVYZUa6AJFrnP\", \"Genre\": \"['hip hop', 'pop', 'pop rap', 'r&b', 'southern hip hop', 'trap', 'trap soul']\", \"Release Date\": \"2020-10-23\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 80.0, \"Danceability\": 0.782, \"Energy\": 0.51, \"Loudness\": -5.724, \"Speechiness\": 0.0419, \"Acousticness\": 0.143, \"Liveness\": 0.115, \"Tempo\": 99.993, \"Duration (ms)\": 143375.0, \"Valence\": 0.118, \"Chord\": \"E\"}, {\"Index\": 774, \"Highest Charting Position\": 124, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Sweet Melody\", \"Streams\": 5201322, \"Artist\": \"Little Mix\", \"Artist Followers\": 9398941.0, \"Song ID\": \"76Tuo484SLohJakHLnGI3B\", \"Genre\": \"['dance pop', 'girl group', 'pop', 'post-teen pop', 'talent show', 'uk pop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\", \"Popularity\": 73.0, \"Danceability\": 0.448, \"Energy\": 0.824, \"Loudness\": -4.249, \"Speechiness\": 0.057, \"Acousticness\": 0.0739, \"Liveness\": 0.113, \"Tempo\": 119.965, \"Duration (ms)\": 213693.0, \"Valence\": 0.419, \"Chord\": \"F\"}, {\"Index\": 775, \"Highest Charting Position\": 144, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Blueberry Eyes (feat. SUGA of BTS)\", \"Streams\": 5158896, \"Artist\": \"MAX\", \"Artist Followers\": 689627.0, \"Song ID\": \"5dn6QANKbf76pANGjMBida\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'pop rap', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2020-09-15\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 72.0, \"Danceability\": 0.746, \"Energy\": 0.611, \"Loudness\": -7.034, \"Speechiness\": 0.101, \"Acousticness\": 0.454, \"Liveness\": 0.133, \"Tempo\": 149.967, \"Duration (ms)\": 172245.0, \"Valence\": 0.411, \"Chord\": \"C\"}, {\"Index\": 776, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"That\\u2019s It\", \"Streams\": 5151014, \"Artist\": \"Future, Lil Uzi Vert\", \"Artist Followers\": 10491105.0, \"Song ID\": \"5n6gBhdEjCuj3obgCoTEFD\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-11-13--2020-11-20\", \"Popularity\": 64.0, \"Danceability\": 0.94, \"Energy\": 0.532, \"Loudness\": -5.998, \"Speechiness\": 0.358, \"Acousticness\": 0.12, \"Liveness\": 0.0925, \"Tempo\": 123.043, \"Duration (ms)\": 228796.0, \"Valence\": 0.599, \"Chord\": \"B\"}, {\"Index\": 777, \"Highest Charting Position\": 157, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Promiscuous\", \"Streams\": 5083648, \"Artist\": \"Nelly Furtado, Timbaland\", \"Artist Followers\": 2688557.0, \"Song ID\": \"2gam98EZKrF9XuOkU13ApN\", \"Genre\": \"['canadian latin', 'canadian pop', 'dance pop', 'pop', 'pop rap']\", \"Release Date\": \"2006-01-01\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 82.0, \"Danceability\": 0.808, \"Energy\": 0.97, \"Loudness\": -6.098, \"Speechiness\": 0.0506, \"Acousticness\": 0.0569, \"Liveness\": 0.154, \"Tempo\": 114.328, \"Duration (ms)\": 242293.0, \"Valence\": 0.868, \"Chord\": \"A#/Bb\"}, {\"Index\": 778, \"Highest Charting Position\": 22, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"GREECE (feat. Drake)\", \"Streams\": 5043665, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6281829.0, \"Song ID\": \"35RJhm1pEovTBwnNR0zWad\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-07-16\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 77.0, \"Danceability\": 0.695, \"Energy\": 0.343, \"Loudness\": -10.798, \"Speechiness\": 0.0432, \"Acousticness\": 0.0743, \"Liveness\": 0.107, \"Tempo\": 85.84, \"Duration (ms)\": 218902.0, \"Valence\": 0.229, \"Chord\": \"F\"}, {\"Index\": 779, \"Highest Charting Position\": 25, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"just like magic\", \"Streams\": 4980571, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"7Dx9Z6Aon1qPS2N0rHSWTe\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 69.0, \"Danceability\": 0.719, \"Energy\": 0.607, \"Loudness\": -5.156, \"Speechiness\": 0.165, \"Acousticness\": 0.08, \"Liveness\": 0.125, \"Tempo\": 128.006, \"Duration (ms)\": 149900.0, \"Valence\": 0.464, \"Chord\": \"G#/Ab\"}, {\"Index\": 780, \"Highest Charting Position\": 53, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Still Don't Know My Name\", \"Streams\": 4926802, \"Artist\": \"Labrinth\", \"Artist Followers\": 1685215.0, \"Song ID\": \"6N22FZs2ZhPBYi3b9XPajV\", \"Genre\": \"['indie poptimism', 'pop']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 80.0, \"Danceability\": 0.316, \"Energy\": 0.63, \"Loudness\": -5.963, \"Speechiness\": 0.117, \"Acousticness\": 0.471, \"Liveness\": 0.205, \"Tempo\": 89.643, \"Duration (ms)\": 153294.0, \"Valence\": 0.313, \"Chord\": \"F\"}, {\"Index\": 781, \"Highest Charting Position\": 32, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Hasta Que Dios Diga\", \"Streams\": 4899099, \"Artist\": \"Anuel AA, Bad Bunny\", \"Artist Followers\": 18306226.0, \"Song ID\": \"06s3QtMJVXw1AJX3UfvZG1\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 76.0, \"Danceability\": 0.691, \"Energy\": 0.765, \"Loudness\": -4.727, \"Speechiness\": 0.111, \"Acousticness\": 0.464, \"Liveness\": 0.203, \"Tempo\": 174.021, \"Duration (ms)\": 246000.0, \"Valence\": 0.855, \"Chord\": \"G#/Ab\"}, {\"Index\": 782, \"Highest Charting Position\": 102, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Get You The Moon (feat. Sn\\u00f8w)\", \"Streams\": 4872409, \"Artist\": \"Kina\", \"Artist Followers\": 661863.0, \"Song ID\": \"4ZLzoOkj0MPWrTLvooIuaa\", \"Genre\": \"['sad rap']\", \"Release Date\": \"2018-10-08\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.498, \"Energy\": 0.235, \"Loudness\": -16.541, \"Speechiness\": 0.188, \"Acousticness\": 0.72, \"Liveness\": 0.144, \"Tempo\": 118.917, \"Duration (ms)\": 179080.0, \"Valence\": 0.0895, \"Chord\": \"C#/Db\"}, {\"Index\": 783, \"Highest Charting Position\": 162, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Moonwalking in Calabasas (feat. Blueface) - Remix\", \"Streams\": 4863053, \"Artist\": \"DDG\", \"Artist Followers\": 486194.0, \"Song ID\": \"7o4gBbTM6UBLkOYPw9xMCz\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2020-12-02\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 74.0, \"Danceability\": 0.928, \"Energy\": 0.341, \"Loudness\": -10.196, \"Speechiness\": 0.103, \"Acousticness\": 0.0614, \"Liveness\": 0.162, \"Tempo\": 129.966, \"Duration (ms)\": 170233.0, \"Valence\": 0.745, \"Chord\": \"B\"}, {\"Index\": 784, \"Highest Charting Position\": 29, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Forever After All\", \"Streams\": 4746415, \"Artist\": \"Luke Combs\", \"Artist Followers\": 5371000.0, \"Song ID\": \"6IBcOGPsniK3Pso1wHIhew\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2020-10-23\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 80.0, \"Danceability\": 0.487, \"Energy\": 0.65, \"Loudness\": -5.195, \"Speechiness\": 0.0253, \"Acousticness\": 0.191, \"Liveness\": 0.0933, \"Tempo\": 151.964, \"Duration (ms)\": 232533.0, \"Valence\": 0.456, \"Chord\": \"C\"}, {\"Index\": 785, \"Highest Charting Position\": 76, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Lean (feat. Towy, Osquel, Beltito & Sammy & Falsetto)\", \"Streams\": 4739241, \"Artist\": \"Super Yei, Jone Quest\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 786, \"Highest Charting Position\": 156, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"SLOW DANCING IN THE DARK\", \"Streams\": 4732343, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"0rKtyWc8bvkriBthvHKY8d\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2018-10-26\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-05-08--2020-05-15\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.515, \"Energy\": 0.479, \"Loudness\": -7.458, \"Speechiness\": 0.0261, \"Acousticness\": 0.544, \"Liveness\": 0.191, \"Tempo\": 88.964, \"Duration (ms)\": 209274.0, \"Valence\": 0.284, \"Chord\": \"D#/Eb\"}, {\"Index\": 787, \"Highest Charting Position\": 92, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Don Don\", \"Streams\": 4731423, \"Artist\": \"Daddy Yankee, Anuel AA, Kendo Kaponi\", \"Artist Followers\": 23936368.0, \"Song ID\": \"3kml9ZdpT7UYk1ugkjqOzt\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-11\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 69.0, \"Danceability\": 0.838, \"Energy\": 0.819, \"Loudness\": -4.681, \"Speechiness\": 0.211, \"Acousticness\": 0.285, \"Liveness\": 0.224, \"Tempo\": 105.027, \"Duration (ms)\": 275893.0, \"Valence\": 0.656, \"Chord\": \"F\"}, {\"Index\": 788, \"Highest Charting Position\": 5, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"my future\", \"Streams\": 4721082, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"3YUMWmx8EJq0DurfuIwoGh\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-07-30\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 80.0, \"Danceability\": 0.456, \"Energy\": 0.285, \"Loudness\": -10.755, \"Speechiness\": 0.0979, \"Acousticness\": 0.814, \"Liveness\": 0.307, \"Tempo\": 104.89, \"Duration (ms)\": 210005.0, \"Valence\": 0.0809, \"Chord\": \"G#/Ab\"}, {\"Index\": 789, \"Highest Charting Position\": 163, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Nada\", \"Streams\": 4713873, \"Artist\": \"Cali Y El Dandee, Danna Paola\", \"Artist Followers\": 3152313.0, \"Song ID\": \"4K8cyoCDovlc4FvtUr2Hfx\", \"Genre\": \"['champeta', 'colombian pop', 'electro latino', 'latin', 'latin pop', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 76.0, \"Danceability\": 0.684, \"Energy\": 0.808, \"Loudness\": -2.737, \"Speechiness\": 0.061, \"Acousticness\": 0.0518, \"Liveness\": 0.0858, \"Tempo\": 173.905, \"Duration (ms)\": 174027.0, \"Valence\": 0.712, \"Chord\": \"C\"}, {\"Index\": 790, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"safety net (feat. Ty Dolla $ign)\", \"Streams\": 5798744, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"14gkWVFMwdxBMyqBw1wmIg\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 70.0, \"Danceability\": 0.552, \"Energy\": 0.599, \"Loudness\": -5.75, \"Speechiness\": 0.0404, \"Acousticness\": 0.0703, \"Liveness\": 0.0986, \"Tempo\": 161.884, \"Duration (ms)\": 208457.0, \"Valence\": 0.0916, \"Chord\": \"C#/Db\"}, {\"Index\": 791, \"Highest Charting Position\": 31, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"shut up\", \"Streams\": 5282490, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3ko9jEHNt4O5fjKN65ULJp\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 63.0, \"Danceability\": 0.499, \"Energy\": 0.462, \"Loudness\": -5.308, \"Speechiness\": 0.0312, \"Acousticness\": 0.801, \"Liveness\": 0.0946, \"Tempo\": 127.698, \"Duration (ms)\": 157710.0, \"Valence\": 0.599, \"Chord\": \"C\"}, {\"Index\": 792, \"Highest Charting Position\": 42, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"nasty\", \"Streams\": 5249342, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"0sci7ppTZFm4mjcH3nu8yO\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 69.0, \"Danceability\": 0.772, \"Energy\": 0.506, \"Loudness\": -6.558, \"Speechiness\": 0.139, \"Acousticness\": 0.0814, \"Liveness\": 0.182, \"Tempo\": 127.894, \"Duration (ms)\": 200733.0, \"Valence\": 0.456, \"Chord\": \"F#/Gb\"}, {\"Index\": 793, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"TRAGIC (feat. Youngboy Never Broke Again & Internet Money)\", \"Streams\": 5226940, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"13EW51DKru044OJDJ9Bm8o\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-11-06--2020-11-13\", \"Popularity\": 76.0, \"Danceability\": 0.779, \"Energy\": 0.642, \"Loudness\": -6.321, \"Speechiness\": 0.116, \"Acousticness\": 0.0383, \"Liveness\": 0.2, \"Tempo\": 82.363, \"Duration (ms)\": 153147.0, \"Valence\": 0.388, \"Chord\": \"G#/Ab\"}, {\"Index\": 794, \"Highest Charting Position\": 49, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Ayer Me Llam\\u00f3 Mi Ex (feat. Lenny Santos)\", \"Streams\": 5220504, \"Artist\": \"KHEA\", \"Artist Followers\": 3198705.0, \"Song ID\": \"6C6mUonH6MNdSg5pw7kOc9\", \"Genre\": \"['argentine hip hop', 'trap argentino', 'trap latino', 'trap triste']\", \"Release Date\": \"2020-08-20\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 71.0, \"Danceability\": 0.752, \"Energy\": 0.716, \"Loudness\": -5.2, \"Speechiness\": 0.0325, \"Acousticness\": 0.254, \"Liveness\": 0.243, \"Tempo\": 117.007, \"Duration (ms)\": 206760.0, \"Valence\": 0.553, \"Chord\": \"A#/Bb\"}, {\"Index\": 795, \"Highest Charting Position\": 119, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Madrid (feat. Myke Towers)\", \"Streams\": 5064484, \"Artist\": \"Maluma\", \"Artist Followers\": 26784251.0, \"Song ID\": \"19OXtYzrJyCrQvTbfukt4H\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 73.0, \"Danceability\": 0.764, \"Energy\": 0.741, \"Loudness\": -3.617, \"Speechiness\": 0.101, \"Acousticness\": 0.239, \"Liveness\": 0.107, \"Tempo\": 170.081, \"Duration (ms)\": 198570.0, \"Valence\": 0.802, \"Chord\": \"A\"}, {\"Index\": 796, \"Highest Charting Position\": 85, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Caramelo - Remix\", \"Streams\": 5033798, \"Artist\": \"Ozuna, KAROL G, Myke Towers\", \"Artist Followers\": 29238936.0, \"Song ID\": \"2uu2aGqA2UblCg581Q7l1g\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-08-17\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 72.0, \"Danceability\": 0.754, \"Energy\": 0.796, \"Loudness\": -3.743, \"Speechiness\": 0.139, \"Acousticness\": 0.062, \"Liveness\": 0.204, \"Tempo\": 168.045, \"Duration (ms)\": 233160.0, \"Valence\": 0.62, \"Chord\": \"D#/Eb\"}, {\"Index\": 797, \"Highest Charting Position\": 25, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Mr. Right Now (feat. Drake)\", \"Streams\": 4951481, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"4Q34FP1AT7GEl9oLgNtiWj\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 75.0, \"Danceability\": 0.647, \"Energy\": 0.667, \"Loudness\": -5.563, \"Speechiness\": 0.304, \"Acousticness\": 0.231, \"Liveness\": 0.133, \"Tempo\": 172.08, \"Duration (ms)\": 193839.0, \"Valence\": 0.704, \"Chord\": \"F\"}, {\"Index\": 798, \"Highest Charting Position\": 41, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Got It On Me\", \"Streams\": 4924030, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"25zlnOAzbVoOzIeXSvQFf1\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 78.0, \"Danceability\": 0.688, \"Energy\": 0.647, \"Loudness\": -7.258, \"Speechiness\": 0.19, \"Acousticness\": 0.00815, \"Liveness\": 0.095, \"Tempo\": 88.834, \"Duration (ms)\": 164580.0, \"Valence\": 0.195, \"Chord\": \"D\"}, {\"Index\": 799, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"my hair\", \"Streams\": 4896521, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"6u7gmPOz7pzzaeR9xSBpsR\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 66.0, \"Danceability\": 0.686, \"Energy\": 0.526, \"Loudness\": -6.842, \"Speechiness\": 0.0374, \"Acousticness\": 0.0815, \"Liveness\": 0.144, \"Tempo\": 92.013, \"Duration (ms)\": 158436.0, \"Valence\": 0.372, \"Chord\": \"C\"}, {\"Index\": 800, \"Highest Charting Position\": 59, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"obvious\", \"Streams\": 4865084, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"0q85C1JiECyYIQthz1posA\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 65.0, \"Danceability\": 0.624, \"Energy\": 0.672, \"Loudness\": -5.334, \"Speechiness\": 0.106, \"Acousticness\": 0.0967, \"Liveness\": 0.155, \"Tempo\": 159.852, \"Duration (ms)\": 146959.0, \"Valence\": 0.26, \"Chord\": \"C\"}, {\"Index\": 801, \"Highest Charting Position\": 30, \"Number of Times Charted\": 45, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Beautiful People (feat. Khalid)\", \"Streams\": 4813796, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"4evmHXcjt3bTUHD1cvny97\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.64, \"Energy\": 0.648, \"Loudness\": -8.113, \"Speechiness\": 0.187, \"Acousticness\": 0.124, \"Liveness\": 0.0802, \"Tempo\": 92.977, \"Duration (ms)\": 197867.0, \"Valence\": 0.548, \"Chord\": \"F\"}, {\"Index\": 802, \"Highest Charting Position\": 29, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Favorito\", \"Streams\": 4787127, \"Artist\": \"Camilo\", \"Artist Followers\": 10580764.0, \"Song ID\": \"0Snbzbd74RLfL0i4nn1vU5\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-26\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 73.0, \"Danceability\": 0.611, \"Energy\": 0.851, \"Loudness\": -2.982, \"Speechiness\": 0.0598, \"Acousticness\": 0.229, \"Liveness\": 0.232, \"Tempo\": 178.032, \"Duration (ms)\": 211613.0, \"Valence\": 0.823, \"Chord\": \"A\"}, {\"Index\": 803, \"Highest Charting Position\": 42, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"After Party\", \"Streams\": 4784580, \"Artist\": \"Don Toliver\", \"Artist Followers\": 1606884.0, \"Song ID\": \"527k23H0A4Q0UJN3vGs0Da\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 80.0, \"Danceability\": 0.629, \"Energy\": 0.692, \"Loudness\": -8.045, \"Speechiness\": 0.0376, \"Acousticness\": 0.00981, \"Liveness\": 0.603, \"Tempo\": 162.948, \"Duration (ms)\": 167916.0, \"Valence\": 0.453, \"Chord\": \"F\"}, {\"Index\": 804, \"Highest Charting Position\": 14, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Rojo\", \"Streams\": 4773792, \"Artist\": \"J Balvin\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3zR9JVqHsILrkNyCOqA6jM\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 0.0, \"Danceability\": 0.652, \"Energy\": 0.595, \"Loudness\": -4.04, \"Speechiness\": 0.117, \"Acousticness\": 0.15, \"Liveness\": 0.0836, \"Tempo\": 172.277, \"Duration (ms)\": 151147.0, \"Valence\": 0.421, \"Chord\": \"B\"}, {\"Index\": 805, \"Highest Charting Position\": 51, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"six thirty\", \"Streams\": 10941573, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"2IKJtXeR5UsaUjZB46fTOK\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 63.0, \"Danceability\": 0.739, \"Energy\": 0.516, \"Loudness\": -7.154, \"Speechiness\": 0.0539, \"Acousticness\": 0.67, \"Liveness\": 0.151, \"Tempo\": 120.109, \"Duration (ms)\": 183874.0, \"Valence\": 0.434, \"Chord\": \"C\"}, {\"Index\": 806, \"Highest Charting Position\": 65, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"love language\", \"Streams\": 9399230, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"6NYtLvyThMT0oALFdJFdzq\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 62.0, \"Danceability\": 0.688, \"Energy\": 0.573, \"Loudness\": -5.03, \"Speechiness\": 0.208, \"Acousticness\": 0.0686, \"Liveness\": 0.0749, \"Tempo\": 110.034, \"Duration (ms)\": 179861.0, \"Valence\": 0.553, \"Chord\": \"A#/Bb\"}, {\"Index\": 807, \"Highest Charting Position\": 66, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"west side\", \"Streams\": 9397167, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"1whfVLMKWqAX3uk97VXsNN\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 62.0, \"Danceability\": 0.688, \"Energy\": 0.455, \"Loudness\": -8.632, \"Speechiness\": 0.199, \"Acousticness\": 0.186, \"Liveness\": 0.0794, \"Tempo\": 87.865, \"Duration (ms)\": 132279.0, \"Valence\": 0.557, \"Chord\": \"B\"}, {\"Index\": 808, \"Highest Charting Position\": 146, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Thriller\", \"Streams\": 5605234, \"Artist\": \"Michael Jackson\", \"Artist Followers\": 19345579.0, \"Song ID\": \"7azo4rpSUh8nXgtonC6Pkq\", \"Genre\": \"['pop', 'r&b', 'soul']\", \"Release Date\": \"2017-09-27\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 68.0, \"Danceability\": 0.764, \"Energy\": 0.887, \"Loudness\": -3.726, \"Speechiness\": 0.0744, \"Acousticness\": 0.0816, \"Liveness\": 0.847, \"Tempo\": 118.427, \"Duration (ms)\": 358053.0, \"Valence\": 0.72, \"Chord\": \"B\"}, {\"Index\": 809, \"Highest Charting Position\": 105, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Dancing With A Stranger (with Normani)\", \"Streams\": 5229835, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"6Qs4SXO9dwPj5GKvVOv8Ki\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2019-01-11\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.741, \"Energy\": 0.52, \"Loudness\": -7.513, \"Speechiness\": 0.0656, \"Acousticness\": 0.45, \"Liveness\": 0.222, \"Tempo\": 102.998, \"Duration (ms)\": 171030.0, \"Valence\": 0.347, \"Chord\": \"G#/Ab\"}, {\"Index\": 810, \"Highest Charting Position\": 91, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Angeklagt\", \"Streams\": 5226264, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"5eu4Lxm5TlI0tKSTTDWJAT\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-10-29\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 60.0, \"Danceability\": 0.658, \"Energy\": 0.624, \"Loudness\": -9.155, \"Speechiness\": 0.0915, \"Acousticness\": 0.171, \"Liveness\": 0.116, \"Tempo\": 181.942, \"Duration (ms)\": 168991.0, \"Valence\": 0.314, \"Chord\": \"C#/Db\"}, {\"Index\": 811, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Kids Again\", \"Streams\": 5103194, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"1ABS9lKaZ1uXkXCqr9zFO7\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 62.0, \"Danceability\": 0.666, \"Energy\": 0.726, \"Loudness\": -2.998, \"Speechiness\": 0.0262, \"Acousticness\": 0.486, \"Liveness\": 0.0892, \"Tempo\": 128.044, \"Duration (ms)\": 207528.0, \"Valence\": 0.468, \"Chord\": \"B\"}, {\"Index\": 812, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Highway to Hell\", \"Streams\": 5096618, \"Artist\": \"AC/DC\", \"Artist Followers\": 20110171.0, \"Song ID\": \"2zYzyRzz6pRmhPzyfMEC8s\", \"Genre\": \"['australian rock', 'hard rock', 'rock']\", \"Release Date\": \"1979-07-27\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 83.0, \"Danceability\": 0.574, \"Energy\": 0.913, \"Loudness\": -4.793, \"Speechiness\": 0.133, \"Acousticness\": 0.061, \"Liveness\": 0.156, \"Tempo\": 115.728, \"Duration (ms)\": 208400.0, \"Valence\": 0.423, \"Chord\": \"F#/Gb\"}, {\"Index\": 813, \"Highest Charting Position\": 38, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Me Gusta (with Cardi B & Myke Towers)\", \"Streams\": 4914412, \"Artist\": \"Anitta\", \"Artist Followers\": 10741972.0, \"Song ID\": \"7e1VoRlNumuEkXlITMHKLE\", \"Genre\": \"['funk carioca', 'funk pop', 'pagode baiano', 'pop nacional']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 72.0, \"Danceability\": 0.91, \"Energy\": 0.604, \"Loudness\": -4.392, \"Speechiness\": 0.082, \"Acousticness\": 0.448, \"Liveness\": 0.0863, \"Tempo\": 110.075, \"Duration (ms)\": 180788.0, \"Valence\": 0.807, \"Chord\": \"F#/Gb\"}, {\"Index\": 814, \"Highest Charting Position\": 133, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"24 (feat. Lil Baby)\", \"Streams\": 4904772, \"Artist\": \"Money Man\", \"Artist Followers\": 345027.0, \"Song ID\": \"0xUvi7wldroBzaZCengPa5\", \"Genre\": \"['memphis hip hop', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 74.0, \"Danceability\": 0.868, \"Energy\": 0.638, \"Loudness\": -7.746, \"Speechiness\": 0.0736, \"Acousticness\": 0.146, \"Liveness\": 0.0931, \"Tempo\": 126.03, \"Duration (ms)\": 182857.0, \"Valence\": 0.459, \"Chord\": \"D\"}, {\"Index\": 815, \"Highest Charting Position\": 23, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Relaci\\u00f3n\", \"Streams\": 4825749, \"Artist\": \"Sech\", \"Artist Followers\": 8766508.0, \"Song ID\": \"35UUpTmrcFXNIVIN26ujXl\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-04-10--2020-04-17\", \"Popularity\": 80.0, \"Danceability\": 0.793, \"Energy\": 0.771, \"Loudness\": -3.417, \"Speechiness\": 0.0959, \"Acousticness\": 0.0337, \"Liveness\": 0.284, \"Tempo\": 171.943, \"Duration (ms)\": 247308.0, \"Valence\": 0.835, \"Chord\": \"F\"}, {\"Index\": 816, \"Highest Charting Position\": 14, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"FRANCHISE (feat. Young Thug & M.I.A.)\", \"Streams\": 4821213, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"4jVBIpuOiMj1crqd8LoCrJ\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 74.0, \"Danceability\": 0.835, \"Energy\": 0.699, \"Loudness\": -5.405, \"Speechiness\": 0.277, \"Acousticness\": 0.00671, \"Liveness\": 0.195, \"Tempo\": 154.981, \"Duration (ms)\": 202795.0, \"Valence\": 0.547, \"Chord\": \"G#/Ab\"}, {\"Index\": 817, \"Highest Charting Position\": 11, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Bet You Wanna (feat. Cardi B)\", \"Streams\": 6846771, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"7iAgNZdotu40NwtoIWJHFe\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 67.0, \"Danceability\": 0.653, \"Energy\": 0.662, \"Loudness\": -6.168, \"Speechiness\": 0.162, \"Acousticness\": 0.00465, \"Liveness\": 0.0626, \"Tempo\": 111.712, \"Duration (ms)\": 161168.0, \"Valence\": 0.674, \"Chord\": \"G\"}, {\"Index\": 818, \"Highest Charting Position\": 82, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Wolves (feat. Post Malone)\", \"Streams\": 5547002, \"Artist\": \"Big Sean\", \"Artist Followers\": 8673345.0, \"Song ID\": \"33gwZOGJWEZ7dRWPqPxBEZ\", \"Genre\": \"['detroit hip hop', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 79.0, \"Danceability\": 0.724, \"Energy\": 0.675, \"Loudness\": -5.267, \"Speechiness\": 0.0867, \"Acousticness\": 0.0978, \"Liveness\": 0.351, \"Tempo\": 160.048, \"Duration (ms)\": 199758.0, \"Valence\": 0.325, \"Chord\": \"D\"}, {\"Index\": 819, \"Highest Charting Position\": 88, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"thank u, next\", \"Streams\": 5079328, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3e9HZxeyfWwjeyPAMmWSSQ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-02-08\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.717, \"Energy\": 0.653, \"Loudness\": -5.634, \"Speechiness\": 0.0658, \"Acousticness\": 0.229, \"Liveness\": 0.101, \"Tempo\": 106.966, \"Duration (ms)\": 207320.0, \"Valence\": 0.412, \"Chord\": \"C#/Db\"}, {\"Index\": 820, \"Highest Charting Position\": 19, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"MAMACITA\", \"Streams\": 5016343, \"Artist\": \"Black Eyed Peas, Ozuna, J. Rey Soul\", \"Artist Followers\": 5966748.0, \"Song ID\": \"14wf185UxfNbSy8dwt4r4q\", \"Genre\": \"['dance pop', 'pop', 'pop rap']\", \"Release Date\": \"2020-04-10\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 74.0, \"Danceability\": 0.894, \"Energy\": 0.635, \"Loudness\": -6.929, \"Speechiness\": 0.0473, \"Acousticness\": 0.193, \"Liveness\": 0.0823, \"Tempo\": 105.013, \"Duration (ms)\": 249143.0, \"Valence\": 0.428, \"Chord\": \"D\"}, {\"Index\": 821, \"Highest Charting Position\": 137, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Fake\", \"Streams\": 5010179, \"Artist\": \"Lauv, Conan Gray\", \"Artist Followers\": 4442273.0, \"Song ID\": \"4Gt2kh3QbAGU6yquOWn4aW\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-13\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 73.0, \"Danceability\": 0.703, \"Energy\": 0.657, \"Loudness\": -5.363, \"Speechiness\": 0.0783, \"Acousticness\": 0.139, \"Liveness\": 0.093, \"Tempo\": 82.96, \"Duration (ms)\": 146375.0, \"Valence\": 0.455, \"Chord\": \"E\"}, {\"Index\": 822, \"Highest Charting Position\": 56, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"OK Not To Be OK\", \"Streams\": 4980744, \"Artist\": \"Marshmello, Demi Lovato\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6PiO7fUEPKnJfaCQbPrIyg\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 0.0, \"Danceability\": 0.743, \"Energy\": 0.837, \"Loudness\": -5.025, \"Speechiness\": 0.0649, \"Acousticness\": 0.0172, \"Liveness\": 0.0743, \"Tempo\": 103.072, \"Duration (ms)\": 159863.0, \"Valence\": 0.263, \"Chord\": \"C#/Db\"}, {\"Index\": 823, \"Highest Charting Position\": 1, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"THE SCOTTS\", \"Streams\": 4941592, \"Artist\": \"THE SCOTTS, Travis Scott, Kid Cudi\", \"Artist Followers\": 179193.0, \"Song ID\": \"39Yp9wwQiSRIDOvrVg7mbk\", \"Genre\": \"['pop rap']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 79.0, \"Danceability\": 0.716, \"Energy\": 0.537, \"Loudness\": -7.648, \"Speechiness\": 0.0514, \"Acousticness\": 0.233, \"Liveness\": 0.157, \"Tempo\": 129.979, \"Duration (ms)\": 165978.0, \"Valence\": 0.28, \"Chord\": \"C\"}, {\"Index\": 824, \"Highest Charting Position\": 37, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Mamichula - con Nicki Nicole\", \"Streams\": 4817969, \"Artist\": \"Trueno, Bizarrap, Taiu, TATOOL\", \"Artist Followers\": 2172969.0, \"Song ID\": \"0TUW9faHNaBmi89wsYGp9y\", \"Genre\": \"['argentine hip hop', 'trap argentino', 'trap latino']\", \"Release Date\": \"2020-07-23\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 75.0, \"Danceability\": 0.696, \"Energy\": 0.678, \"Loudness\": -5.893, \"Speechiness\": 0.0735, \"Acousticness\": 0.582, \"Liveness\": 0.134, \"Tempo\": 91.985, \"Duration (ms)\": 219202.0, \"Valence\": 0.346, \"Chord\": \"E\"}, {\"Index\": 825, \"Highest Charting Position\": 172, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Let Her Go\", \"Streams\": 4765198, \"Artist\": \"Passenger\", \"Artist Followers\": 2819406.0, \"Song ID\": \"0JmiBCpWc1IAc0et7Xm7FL\", \"Genre\": \"['folk-pop', 'neo mellow', 'pop', 'pop rock']\", \"Release Date\": \"2013-02-17\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 75.0, \"Danceability\": 0.479, \"Energy\": 0.545, \"Loudness\": -7.346, \"Speechiness\": 0.0688, \"Acousticness\": 0.365, \"Liveness\": 0.0963, \"Tempo\": 74.897, \"Duration (ms)\": 252733.0, \"Valence\": 0.243, \"Chord\": \"G\"}, {\"Index\": 826, \"Highest Charting Position\": 26, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Play Date\", \"Streams\": 4745568, \"Artist\": \"Melanie Martinez\", \"Artist Followers\": 10925614.0, \"Song ID\": \"4DpNNXFMMxQEKl7r0ykkWA\", \"Genre\": \"['alt z', 'electropop', 'modern rock', 'pop']\", \"Release Date\": \"2015-08-14\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 80.0, \"Danceability\": 0.68, \"Energy\": 0.729, \"Loudness\": -5.077, \"Speechiness\": 0.0475, \"Acousticness\": 0.612, \"Liveness\": 0.224, \"Tempo\": 123.97, \"Duration (ms)\": 179867.0, \"Valence\": 0.446, \"Chord\": \"F\"}, {\"Index\": 827, \"Highest Charting Position\": 32, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Lose Somebody\", \"Streams\": 4709053, \"Artist\": \"Kygo, OneRepublic\", \"Artist Followers\": 7593792.0, \"Song ID\": \"1sgDyuLooyvEML4oHspNza\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 75.0, \"Danceability\": 0.58, \"Energy\": 0.586, \"Loudness\": -6.883, \"Speechiness\": 0.0357, \"Acousticness\": 0.344, \"Liveness\": 0.0755, \"Tempo\": 147.988, \"Duration (ms)\": 199549.0, \"Valence\": 0.507, \"Chord\": \"C#/Db\"}, {\"Index\": 828, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Someone Like You\", \"Streams\": 4703672, \"Artist\": \"Adele\", \"Artist Followers\": 28335338.0, \"Song ID\": \"1zwMYTA5nlNjZxYrvBB2pV\", \"Genre\": \"['british soul', 'pop', 'pop soul', 'uk pop']\", \"Release Date\": \"2011-01-24\", \"Weeks Charted\": \"2020-10-23--2020-10-30\", \"Popularity\": 77.0, \"Danceability\": 0.556, \"Energy\": 0.319, \"Loudness\": -8.251, \"Speechiness\": 0.0281, \"Acousticness\": 0.893, \"Liveness\": 0.0996, \"Tempo\": 135.187, \"Duration (ms)\": 285240.0, \"Valence\": 0.294, \"Chord\": \"A\"}, {\"Index\": 829, \"Highest Charting Position\": 73, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"It's You\", \"Streams\": 4674658, \"Artist\": \"Ali Gatie\", \"Artist Followers\": 1758300.0, \"Song ID\": \"5DqdesEfbRyOlSS3Tf6c29\", \"Genre\": \"['canadian hip hop', 'pop']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.732, \"Energy\": 0.463, \"Loudness\": -6.972, \"Speechiness\": 0.0287, \"Acousticness\": 0.374, \"Liveness\": 0.194, \"Tempo\": 95.971, \"Duration (ms)\": 212607.0, \"Valence\": 0.397, \"Chord\": \"B\"}, {\"Index\": 830, \"Highest Charting Position\": 68, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Stunnin' (feat. Harm Franklin)\", \"Streams\": 5183246, \"Artist\": \"Curtis Waters\", \"Artist Followers\": 68875.0, \"Song ID\": \"2JSmxLqt8h7ZpJJkfuLJvK\", \"Genre\": \"[]\", \"Release Date\": \"2020-10-09\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 68.0, \"Danceability\": 0.885, \"Energy\": 0.685, \"Loudness\": -6.429, \"Speechiness\": 0.0627, \"Acousticness\": 0.33, \"Liveness\": 0.148, \"Tempo\": 99.954, \"Duration (ms)\": 144000.0, \"Valence\": 0.937, \"Chord\": \"B\"}, {\"Index\": 831, \"Highest Charting Position\": 35, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Love To Hate Me\", \"Streams\": 5125708, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"7iKDsPfLT0d5mu2htfMKBZ\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 69.0, \"Danceability\": 0.686, \"Energy\": 0.64, \"Loudness\": -5.491, \"Speechiness\": 0.159, \"Acousticness\": 0.0334, \"Liveness\": 0.0801, \"Tempo\": 162.225, \"Duration (ms)\": 171798.0, \"Valence\": 0.597, \"Chord\": \"G#/Ab\"}, {\"Index\": 832, \"Highest Charting Position\": 165, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Hate The Way (feat. blackbear)\", \"Streams\": 5116071, \"Artist\": \"G-Eazy\", \"Artist Followers\": 4894656.0, \"Song ID\": \"3QGppKBPd9gHOgHJzRbVIw\", \"Genre\": \"['hip hop', 'indie pop rap', 'oakland hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2020-10-16--2020-10-23\", \"Popularity\": 68.0, \"Danceability\": 0.569, \"Energy\": 0.865, \"Loudness\": -3.844, \"Speechiness\": 0.266, \"Acousticness\": 0.0673, \"Liveness\": 0.312, \"Tempo\": 82.011, \"Duration (ms)\": 214363.0, \"Valence\": 0.361, \"Chord\": \"E\"}, {\"Index\": 833, \"Highest Charting Position\": 89, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Bande organis\\u00e9e\", \"Streams\": 5112572, \"Artist\": \"13 Organis\\u00e9, SCH, Kofs, Jul, Naps, Soso Maness, Elams, Solda, Houari\", \"Artist Followers\": 249910.0, \"Song ID\": \"205HNJ73cgpC0LAOnuQiWT\", \"Genre\": \"['french hip hop', 'pop urbaine', 'rap francais', 'rap marseille']\", \"Release Date\": \"2020-08-15\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 72.0, \"Danceability\": 0.901, \"Energy\": 0.939, \"Loudness\": -2.762, \"Speechiness\": 0.274, \"Acousticness\": 0.117, \"Liveness\": 0.0643, \"Tempo\": 142.948, \"Duration (ms)\": 356347.0, \"Valence\": 0.805, \"Chord\": \"F#/Gb\"}, {\"Index\": 834, \"Highest Charting Position\": 32, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Crazy Over You\", \"Streams\": 5056387, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"7qq0EOPW4RRlqdvMBmdd73\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 68.0, \"Danceability\": 0.804, \"Energy\": 0.633, \"Loudness\": -6.186, \"Speechiness\": 0.0612, \"Acousticness\": 0.0371, \"Liveness\": 0.102, \"Tempo\": 115.002, \"Duration (ms)\": 163946.0, \"Valence\": 0.67, \"Chord\": \"E\"}, {\"Index\": 835, \"Highest Charting Position\": 109, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Baby, I'm Jealous (feat. Doja Cat)\", \"Streams\": 4870203, \"Artist\": \"Bebe Rexha\", \"Artist Followers\": 6569150.0, \"Song ID\": \"2fTdRdN73RgIgcUZN33dvt\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-09\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 69.0, \"Danceability\": 0.737, \"Energy\": 0.867, \"Loudness\": -2.259, \"Speechiness\": 0.0458, \"Acousticness\": 0.0398, \"Liveness\": 0.32, \"Tempo\": 98.05, \"Duration (ms)\": 175873.0, \"Valence\": 0.506, \"Chord\": \"B\"}, {\"Index\": 836, \"Highest Charting Position\": 15, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"TKN (feat. Travis Scott)\", \"Streams\": 4752289, \"Artist\": \"ROSAL\\u00cdA\", \"Artist Followers\": 4769627.0, \"Song ID\": \"4w47S36wQGBhGg073q3nt7\", \"Genre\": \"['r&b en espanol']\", \"Release Date\": \"2020-05-28\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 75.0, \"Danceability\": 0.776, \"Energy\": 0.509, \"Loudness\": -6.266, \"Speechiness\": 0.467, \"Acousticness\": 0.192, \"Liveness\": 0.115, \"Tempo\": 94.634, \"Duration (ms)\": 129371.0, \"Valence\": 0.485, \"Chord\": \"C\"}, {\"Index\": 837, \"Highest Charting Position\": 135, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"El Mismo Aire - con Pablo Albor\\u00e1n\", \"Streams\": 4705484, \"Artist\": \"Camilo\", \"Artist Followers\": 10580764.0, \"Song ID\": \"5EbtodsuLbxrFDH6j5avVS\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-06-10\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 75.0, \"Danceability\": 0.483, \"Energy\": 0.492, \"Loudness\": -6.591, \"Speechiness\": 0.295, \"Acousticness\": 0.603, \"Liveness\": 0.323, \"Tempo\": 144.511, \"Duration (ms)\": 188213.0, \"Valence\": 0.66, \"Chord\": \"C\"}, {\"Index\": 838, \"Highest Charting Position\": 18, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Yo Perreo Sola\", \"Streams\": 4680447, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0SqqAgdovOE24BzxIClpjw\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 78.0, \"Danceability\": 0.86, \"Energy\": 0.758, \"Loudness\": -5.16, \"Speechiness\": 0.0695, \"Acousticness\": 0.021, \"Liveness\": 0.344, \"Tempo\": 97.014, \"Duration (ms)\": 172127.0, \"Valence\": 0.453, \"Chord\": \"B\"}, {\"Index\": 839, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Let Me Love You Like A Woman\", \"Streams\": 4665053, \"Artist\": \"Lana Del Rey\", \"Artist Followers\": 13697048.0, \"Song ID\": \"1gxdWpeOUBpvB908fiZs4D\", \"Genre\": \"['art pop', 'pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2020-10-16--2020-10-23\", \"Popularity\": 67.0, \"Danceability\": 0.303, \"Energy\": 0.249, \"Loudness\": -11.715, \"Speechiness\": 0.111, \"Acousticness\": 0.97, \"Liveness\": 0.117, \"Tempo\": 66.932, \"Duration (ms)\": 200661.0, \"Valence\": 0.131, \"Chord\": \"C\"}, {\"Index\": 840, \"Highest Charting Position\": 69, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"DOLLAZ ON MY HEAD (feat. Young Thug)\", \"Streams\": 4652712, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"3nS9a01VvXHQriLqJYwRqG\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 76.0, \"Danceability\": 0.825, \"Energy\": 0.458, \"Loudness\": -7.47, \"Speechiness\": 0.0577, \"Acousticness\": 0.114, \"Liveness\": 0.102, \"Tempo\": 145.115, \"Duration (ms)\": 197760.0, \"Valence\": 0.161, \"Chord\": \"C\"}, {\"Index\": 841, \"Highest Charting Position\": 54, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Eleg\\u00ed (feat. D\\u00edmelo Flow)\", \"Streams\": 4607003, \"Artist\": \"Rauw Alejandro, Dalex, Lenny Tav\\u00e1rez\", \"Artist Followers\": 6096559.0, \"Song ID\": \"50ZC4PM7hywH27RcCfViau\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-03-26\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 75.0, \"Danceability\": 0.824, \"Energy\": 0.631, \"Loudness\": -2.791, \"Speechiness\": 0.0809, \"Acousticness\": 0.237, \"Liveness\": 0.0531, \"Tempo\": 171.965, \"Duration (ms)\": 197721.0, \"Valence\": 0.678, \"Chord\": \"C\"}, {\"Index\": 842, \"Highest Charting Position\": 77, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"July\", \"Streams\": 4598766, \"Artist\": \"Noah Cyrus\", \"Artist Followers\": 891555.0, \"Song ID\": \"6J2LdBN97cDWn0MLxYh9HB\", \"Genre\": \"['alt z', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.708, \"Energy\": 0.186, \"Loudness\": -8.953, \"Speechiness\": 0.042, \"Acousticness\": 0.868, \"Liveness\": 0.0779, \"Tempo\": 72.541, \"Duration (ms)\": 156106.0, \"Valence\": 0.322, \"Chord\": \"A\"}, {\"Index\": 843, \"Highest Charting Position\": 93, \"Number of Times Charted\": 38, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Bruises\", \"Streams\": 4560503, \"Artist\": \"Lewis Capaldi\", \"Artist Followers\": 8388838.0, \"Song ID\": \"4Of7rzpRpV1mWRbhp5rAqG\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.736, \"Energy\": 0.308, \"Loudness\": -7.83, \"Speechiness\": 0.0677, \"Acousticness\": 0.946, \"Liveness\": 0.186, \"Tempo\": 111.202, \"Duration (ms)\": 220492.0, \"Valence\": 0.361, \"Chord\": \"E\"}, {\"Index\": 844, \"Highest Charting Position\": 46, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"You Never Know\", \"Streams\": 5304382, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"3b7trEcKoglybN5MxGuSaw\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2021-08-03\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 54.0, \"Danceability\": 0.535, \"Energy\": 0.434, \"Loudness\": -5.768, \"Speechiness\": 0.0505, \"Acousticness\": 0.405, \"Liveness\": 0.253, \"Tempo\": 144.497, \"Duration (ms)\": 229236.0, \"Valence\": 0.271, \"Chord\": \"F\"}, {\"Index\": 845, \"Highest Charting Position\": 12, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Supalonely\", \"Streams\": 5089970, \"Artist\": \"BENEE, Gus Dapperton\", \"Artist Followers\": 638337.0, \"Song ID\": \"4nK5YrxbMGZstTLbvj6Gxw\", \"Genre\": \"['alt z', 'nz pop', 'pop']\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 77.0, \"Danceability\": 0.863, \"Energy\": 0.631, \"Loudness\": -4.689, \"Speechiness\": 0.0534, \"Acousticness\": 0.305, \"Liveness\": 0.123, \"Tempo\": 128.977, \"Duration (ms)\": 223480.0, \"Valence\": 0.817, \"Chord\": \"G\"}, {\"Index\": 846, \"Highest Charting Position\": 53, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Glock In My Lap\", \"Streams\": 4947593, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"6pcywuOeGGWeOQzdUyti6k\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 69.0, \"Danceability\": 0.847, \"Energy\": 0.733, \"Loudness\": -6.439, \"Speechiness\": 0.16, \"Acousticness\": 0.00574, \"Liveness\": 0.151, \"Tempo\": 130.029, \"Duration (ms)\": 193591.0, \"Valence\": 0.202, \"Chord\": \"A#/Bb\"}, {\"Index\": 847, \"Highest Charting Position\": 49, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Better\", \"Streams\": 4933462, \"Artist\": \"ZAYN\", \"Artist Followers\": 16655692.0, \"Song ID\": \"1dLXLETYiZohIZWnse4ypG\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-01-03--2020-01-10\", \"Popularity\": 68.0, \"Danceability\": 0.637, \"Energy\": 0.418, \"Loudness\": -7.137, \"Speechiness\": 0.301, \"Acousticness\": 0.353, \"Liveness\": 0.131, \"Tempo\": 84.295, \"Duration (ms)\": 174517.0, \"Valence\": 0.0807, \"Chord\": \"D\"}, {\"Index\": 848, \"Highest Charting Position\": 59, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"forget me too (feat. Halsey)\", \"Streams\": 4751756, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3868320.0, \"Song ID\": \"1VSuFS7PahCN3SWbOcQ98m\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 78.0, \"Danceability\": 0.654, \"Energy\": 0.875, \"Loudness\": -4.845, \"Speechiness\": 0.0744, \"Acousticness\": 0.000417, \"Liveness\": 0.194, \"Tempo\": 99.975, \"Duration (ms)\": 171621.0, \"Valence\": 0.522, \"Chord\": \"C#/Db\"}, {\"Index\": 849, \"Highest Charting Position\": 110, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Oh Juliana\", \"Streams\": 4751064, \"Artist\": \"Niack\", \"Artist Followers\": 352402.0, \"Song ID\": \"4xWzZmX4K1yyrdtRfbUvjt\", \"Genre\": \"['funk carioca']\", \"Release Date\": \"2020-06-30\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 66.0, \"Danceability\": 0.799, \"Energy\": 0.568, \"Loudness\": -3.089, \"Speechiness\": 0.25, \"Acousticness\": 0.387, \"Liveness\": 0.0892, \"Tempo\": 129.63, \"Duration (ms)\": 153078.0, \"Valence\": 0.963, \"Chord\": \"F#/Gb\"}, {\"Index\": 850, \"Highest Charting Position\": 81, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"PORFA Remix ( Feat. Maluma, Nicky Jam, Sech) - Remix\", \"Streams\": 4727923, \"Artist\": \"Feid, J Balvin, Justin Quiles\", \"Artist Followers\": 613348.0, \"Song ID\": \"7lUdbnz7wsv3C9zzf4WHl9\", \"Genre\": \"['colombian pop', 'latin', 'pop reggaeton', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 70.0, \"Danceability\": 0.793, \"Energy\": 0.737, \"Loudness\": -4.731, \"Speechiness\": 0.0785, \"Acousticness\": 0.0765, \"Liveness\": 0.0747, \"Tempo\": 167.969, \"Duration (ms)\": 333800.0, \"Valence\": 0.697, \"Chord\": \"F#/Gb\"}, {\"Index\": 851, \"Highest Charting Position\": 108, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"No Guidance (feat. Drake)\", \"Streams\": 4641393, \"Artist\": \"Chris Brown\", \"Artist Followers\": 14073083.0, \"Song ID\": \"6XHVuErjQ4XNm6nDPVCxVX\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'r&b', 'rap']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.696, \"Energy\": 0.454, \"Loudness\": -6.756, \"Speechiness\": 0.153, \"Acousticness\": 0.123, \"Liveness\": 0.155, \"Tempo\": 92.928, \"Duration (ms)\": 260640.0, \"Valence\": 0.136, \"Chord\": \"C#/Db\"}, {\"Index\": 852, \"Highest Charting Position\": 65, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Rich Nigga Shit (feat. Young Thug)\", \"Streams\": 9129562, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"3ruoIF2UnoXdzK8mR61ebq\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 73.0, \"Danceability\": 0.825, \"Energy\": 0.733, \"Loudness\": -5.625, \"Speechiness\": 0.0969, \"Acousticness\": 0.349, \"Liveness\": 0.112, \"Tempo\": 97.974, \"Duration (ms)\": 190331.0, \"Valence\": 0.62, \"Chord\": \"C#/Db\"}, {\"Index\": 853, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Many Men\", \"Streams\": 8675173, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"3CDVMejYHnB1SkEEx0T1N4\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 65.0, \"Danceability\": 0.635, \"Energy\": 0.793, \"Loudness\": -4.333, \"Speechiness\": 0.0322, \"Acousticness\": 0.000647, \"Liveness\": 0.113, \"Tempo\": 77.594, \"Duration (ms)\": 201856.0, \"Valence\": 0.281, \"Chord\": \"A#/Bb\"}, {\"Index\": 854, \"Highest Charting Position\": 77, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Slidin\", \"Streams\": 8243488, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"7fxSLnklnayJNBIKntXedZ\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 64.0, \"Danceability\": 0.774, \"Energy\": 0.706, \"Loudness\": -6.494, \"Speechiness\": 0.355, \"Acousticness\": 0.00163, \"Liveness\": 0.104, \"Tempo\": 152.891, \"Duration (ms)\": 185037.0, \"Valence\": 0.382, \"Chord\": \"D\"}, {\"Index\": 855, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Outta Time (feat. Drake)\", \"Streams\": 7762934, \"Artist\": \"Bryson Tiller\", \"Artist Followers\": 5019909.0, \"Song ID\": \"4SCnCPOUOUXUmCX2uHb3r7\", \"Genre\": \"['kentucky hip hop', 'pop', 'pop rap', 'r&b', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 68.0, \"Danceability\": 0.714, \"Energy\": 0.582, \"Loudness\": -7.272, \"Speechiness\": 0.0808, \"Acousticness\": 0.0129, \"Liveness\": 0.0774, \"Tempo\": 92.819, \"Duration (ms)\": 198822.0, \"Valence\": 0.338, \"Chord\": \"F\"}, {\"Index\": 856, \"Highest Charting Position\": 131, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"My Dawg\", \"Streams\": 6029118, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"42Tohunwlh34o0mgxYx5iq\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 60.0, \"Danceability\": 0.831, \"Energy\": 0.532, \"Loudness\": -5.319, \"Speechiness\": 0.301, \"Acousticness\": 0.0652, \"Liveness\": 0.464, \"Tempo\": 140.105, \"Duration (ms)\": 181716.0, \"Valence\": 0.364, \"Chord\": \"C\"}, {\"Index\": 857, \"Highest Charting Position\": 138, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Snitches & Rats (feat. Young Nudy)\", \"Streams\": 5846760, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"3WaDoMDQRqDdgtCDLxanpN\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 57.0, \"Danceability\": 0.821, \"Energy\": 0.671, \"Loudness\": -5.893, \"Speechiness\": 0.18, \"Acousticness\": 0.00843, \"Liveness\": 0.0972, \"Tempo\": 145.953, \"Duration (ms)\": 187773.0, \"Valence\": 0.494, \"Chord\": \"A\"}, {\"Index\": 858, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Brand New Draco\", \"Streams\": 5841110, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"4V9ynsDPwHtdItksqjuRu0\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 63.0, \"Danceability\": 0.697, \"Energy\": 0.709, \"Loudness\": -6.642, \"Speechiness\": 0.298, \"Acousticness\": 0.041, \"Liveness\": 0.0886, \"Tempo\": 155.023, \"Duration (ms)\": 202420.0, \"Valence\": 0.439, \"Chord\": \"B\"}, {\"Index\": 859, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Lemonade (Feat. Roddy Ricch & Don Toliver) [Remix]\", \"Streams\": 5550390, \"Artist\": \"Internet Money\", \"Artist Followers\": 412466.0, \"Song ID\": \"5sBplhIrmzA4kQGyIOpmDf\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-09-30\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 69.0, \"Danceability\": 0.832, \"Energy\": 0.549, \"Loudness\": -8.259, \"Speechiness\": 0.0602, \"Acousticness\": 0.168, \"Liveness\": 0.11, \"Tempo\": 140.045, \"Duration (ms)\": 181496.0, \"Valence\": 0.384, \"Chord\": \"C#/Db\"}, {\"Index\": 860, \"Highest Charting Position\": 77, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Your Man\", \"Streams\": 5233336, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"6Vgtvd7I5yopJdBuxqjBd2\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-24\", \"Weeks Charted\": \"2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 68.0, \"Danceability\": 0.785, \"Energy\": 0.818, \"Loudness\": -8.711, \"Speechiness\": 0.099, \"Acousticness\": 0.624, \"Liveness\": 0.149, \"Tempo\": 117.98, \"Duration (ms)\": 163759.0, \"Valence\": 0.0503, \"Chord\": \"G\"}, {\"Index\": 861, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"No Opp Left Behind\", \"Streams\": 5154955, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"50I7FNN2rl2rWiNwGxS146\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 61.0, \"Danceability\": 0.823, \"Energy\": 0.703, \"Loudness\": -2.691, \"Speechiness\": 0.298, \"Acousticness\": 0.0161, \"Liveness\": 0.294, \"Tempo\": 178.043, \"Duration (ms)\": 194214.0, \"Valence\": 0.26, \"Chord\": \"G#/Ab\"}, {\"Index\": 862, \"Highest Charting Position\": 106, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Lets Link\", \"Streams\": 5109038, \"Artist\": \"WhoHeem\", \"Artist Followers\": 25417.0, \"Song ID\": \"6fMzgFFGzWCwiHMzDzNpp5\", \"Genre\": \"['viral rap']\", \"Release Date\": \"2020-08-20\", \"Weeks Charted\": \"2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 61.0, \"Danceability\": 0.839, \"Energy\": 0.683, \"Loudness\": -9.232, \"Speechiness\": 0.165, \"Acousticness\": 0.00667, \"Liveness\": 0.241, \"Tempo\": 120.003, \"Duration (ms)\": 159955.0, \"Valence\": 0.522, \"Chord\": \"A#/Bb\"}, {\"Index\": 863, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"RIP Luv\", \"Streams\": 4915080, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"1wGnp7ejkCuXRsehXx0PNP\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 62.0, \"Danceability\": 0.63, \"Energy\": 0.399, \"Loudness\": -9.869, \"Speechiness\": 0.178, \"Acousticness\": 0.105, \"Liveness\": 0.234, \"Tempo\": 183.016, \"Duration (ms)\": 214192.0, \"Valence\": 0.0657, \"Chord\": \"F\"}, {\"Index\": 864, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Steppin On Niggas\", \"Streams\": 4853661, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"7FtZFla3ZH6PqsAJ9MvVCM\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 57.0, \"Danceability\": 0.849, \"Energy\": 0.635, \"Loudness\": -4.068, \"Speechiness\": 0.254, \"Acousticness\": 0.000608, \"Liveness\": 0.062, \"Tempo\": 89.484, \"Duration (ms)\": 140833.0, \"Valence\": 0.798, \"Chord\": \"G\"}, {\"Index\": 865, \"Highest Charting Position\": 58, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Gimme Love\", \"Streams\": 7471309, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"2hfoyc7ve6xM4ZEiNIiU1B\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-04-16\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 69.0, \"Danceability\": 0.482, \"Energy\": 0.631, \"Loudness\": -6.917, \"Speechiness\": 0.0986, \"Acousticness\": 0.696, \"Liveness\": 0.209, \"Tempo\": 126.576, \"Duration (ms)\": 214558.0, \"Valence\": 0.0743, \"Chord\": \"F\"}, {\"Index\": 866, \"Highest Charting Position\": 97, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Ew\", \"Streams\": 6936305, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"7xcUWyLh6fIMsYjoVI7NnZ\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 67.0, \"Danceability\": 0.48, \"Energy\": 0.373, \"Loudness\": -9.297, \"Speechiness\": 0.0278, \"Acousticness\": 0.804, \"Liveness\": 0.12, \"Tempo\": 114.078, \"Duration (ms)\": 207710.0, \"Valence\": 0.0376, \"Chord\": \"A#/Bb\"}, {\"Index\": 867, \"Highest Charting Position\": 99, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Daylight\", \"Streams\": 6819838, \"Artist\": \"Joji, Diplo\", \"Artist Followers\": 4759367.0, \"Song ID\": \"6Ed1q0X8oSKSm4IIhiQbYg\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-08-06\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-08-07--2020-08-14\", \"Popularity\": 72.0, \"Danceability\": 0.528, \"Energy\": 0.749, \"Loudness\": -7.571, \"Speechiness\": 0.0479, \"Acousticness\": 0.00488, \"Liveness\": 0.0949, \"Tempo\": 163.944, \"Duration (ms)\": 163906.0, \"Valence\": 0.729, \"Chord\": \"G\"}, {\"Index\": 868, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Epidemic\", \"Streams\": 6292620, \"Artist\": \"Polo G\", \"Artist Followers\": 4849204.0, \"Song ID\": \"170DNUSnQRp1tGpppF26pA\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 71.0, \"Danceability\": 0.616, \"Energy\": 0.617, \"Loudness\": -8.431, \"Speechiness\": 0.52, \"Acousticness\": 0.128, \"Liveness\": 0.177, \"Tempo\": 175.929, \"Duration (ms)\": 177273.0, \"Valence\": 0.476, \"Chord\": \"C#/Db\"}, {\"Index\": 869, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"bloody valentine\", \"Streams\": 6032935, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3868320.0, \"Song ID\": \"6mADjHs6FXdroPzEGW6KVJ\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 77.0, \"Danceability\": 0.533, \"Energy\": 0.858, \"Loudness\": -4.212, \"Speechiness\": 0.0766, \"Acousticness\": 0.00021, \"Liveness\": 0.148, \"Tempo\": 160.057, \"Duration (ms)\": 205159.0, \"Valence\": 0.506, \"Chord\": \"D\"}, {\"Index\": 870, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"MODUS\", \"Streams\": 6013371, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"5SjtAe7xzUgHDtNTmt8zS7\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 66.0, \"Danceability\": 0.738, \"Energy\": 0.533, \"Loudness\": -7.617, \"Speechiness\": 0.0492, \"Acousticness\": 0.183, \"Liveness\": 0.115, \"Tempo\": 132.008, \"Duration (ms)\": 207265.0, \"Valence\": 0.262, \"Chord\": \"G\"}, {\"Index\": 871, \"Highest Charting Position\": 145, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Tick Tock\", \"Streams\": 5547939, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"5E7p95xh9Ul4vZp4LEoJwi\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 65.0, \"Danceability\": 0.781, \"Energy\": 0.613, \"Loudness\": -5.582, \"Speechiness\": 0.0524, \"Acousticness\": 0.0399, \"Liveness\": 0.0976, \"Tempo\": 80.53, \"Duration (ms)\": 132215.0, \"Valence\": 0.613, \"Chord\": \"E\"}, {\"Index\": 872, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Sanctuary\", \"Streams\": 5482390, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"3xaugmCyXrVkrDTXbFkMW3\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2019-06-14\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 69.0, \"Danceability\": 0.552, \"Energy\": 0.65, \"Loudness\": -7.199, \"Speechiness\": 0.128, \"Acousticness\": 0.422, \"Liveness\": 0.372, \"Tempo\": 167.788, \"Duration (ms)\": 180019.0, \"Valence\": 0.316, \"Chord\": \"C#/Db\"}, {\"Index\": 873, \"Highest Charting Position\": 112, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"feel something\", \"Streams\": 5463424, \"Artist\": \"Bea Miller\", \"Artist Followers\": 2396662.0, \"Song ID\": \"7JDWhC422Gtk1Bq0mL3OTC\", \"Genre\": \"['alt z', 'dance pop', 'electropop', 'indie cafe pop', 'indie poptimism', 'modern rock', 'pop', 'pop rap', 'post-teen pop', 'talent show']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 75.0, \"Danceability\": 0.74, \"Energy\": 0.415, \"Loudness\": -8.914, \"Speechiness\": 0.0707, \"Acousticness\": 0.242, \"Liveness\": 0.319, \"Tempo\": 136.029, \"Duration (ms)\": 180161.0, \"Valence\": 0.156, \"Chord\": \"C\"}, {\"Index\": 874, \"Highest Charting Position\": 86, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Tap In\", \"Streams\": 5220309, \"Artist\": \"Saweetie\", \"Artist Followers\": 1255573.0, \"Song ID\": \"4Hpib09wXgD84w4uwTPnYD\", \"Genre\": \"['cali rap', 'dance pop', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-06-17\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 73.0, \"Danceability\": 0.954, \"Energy\": 0.696, \"Loudness\": -7.117, \"Speechiness\": 0.204, \"Acousticness\": 0.00576, \"Liveness\": 0.0754, \"Tempo\": 100.036, \"Duration (ms)\": 139413.0, \"Valence\": 0.432, \"Chord\": \"A#/Bb\"}, {\"Index\": 875, \"Highest Charting Position\": 171, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Pretty Boy (feat. Lil Yachty)\", \"Streams\": 5141212, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"0f1G5SHFoFC9lO03gHCGVS\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 66.0, \"Danceability\": 0.656, \"Energy\": 0.776, \"Loudness\": -6.184, \"Speechiness\": 0.0672, \"Acousticness\": 0.16, \"Liveness\": 0.372, \"Tempo\": 156.049, \"Duration (ms)\": 156759.0, \"Valence\": 0.638, \"Chord\": \"F#/Gb\"}, {\"Index\": 876, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Afterthought\", \"Streams\": 4977405, \"Artist\": \"Joji, BENEE\", \"Artist Followers\": 4759367.0, \"Song ID\": \"6zvqq50PL7io0rprbkrYc9\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 67.0, \"Danceability\": 0.668, \"Energy\": 0.547, \"Loudness\": -8.024, \"Speechiness\": 0.0353, \"Acousticness\": 0.398, \"Liveness\": 0.0931, \"Tempo\": 83.5, \"Duration (ms)\": 194871.0, \"Valence\": 0.192, \"Chord\": \"C#/Db\"}, {\"Index\": 877, \"Highest Charting Position\": 164, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"+Linda\", \"Streams\": 4964708, \"Artist\": \"Dalex\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-08-28--2020-09-04\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 878, \"Highest Charting Position\": 24, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Over Now (with The Weeknd)\", \"Streams\": 4867620, \"Artist\": \"Calvin Harris\", \"Artist Followers\": 21946934.0, \"Song ID\": \"58AGoOGbwsQMhBbH0eFLRR\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'house', 'pop', 'progressive house', 'uk dance']\", \"Release Date\": \"2020-08-28\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 72.0, \"Danceability\": 0.612, \"Energy\": 0.884, \"Loudness\": -4.113, \"Speechiness\": 0.0454, \"Acousticness\": 0.0759, \"Liveness\": 0.247, \"Tempo\": 178.043, \"Duration (ms)\": 210795.0, \"Valence\": 0.679, \"Chord\": \"E\"}, {\"Index\": 879, \"Highest Charting Position\": 14, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Hate The Other Side (with Marshmello & The Kid Laroi)\", \"Streams\": 4851997, \"Artist\": \"Juice WRLD, Polo G\", \"Artist Followers\": 19102888.0, \"Song ID\": \"0ada5XsQGLPUVbmTCkAP49\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 78.0, \"Danceability\": 0.701, \"Energy\": 0.65, \"Loudness\": -6.313, \"Speechiness\": 0.104, \"Acousticness\": 0.291, \"Liveness\": 0.112, \"Tempo\": 90.003, \"Duration (ms)\": 160212.0, \"Valence\": 0.647, \"Chord\": \"F#/Gb\"}, {\"Index\": 880, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"drunk face\", \"Streams\": 4834258, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3868320.0, \"Song ID\": \"3k0YJnqMKRZb8swo86vCkq\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 72.0, \"Danceability\": 0.691, \"Energy\": 0.77, \"Loudness\": -4.578, \"Speechiness\": 0.0367, \"Acousticness\": 0.0282, \"Liveness\": 0.497, \"Tempo\": 90.024, \"Duration (ms)\": 143901.0, \"Valence\": 0.344, \"Chord\": \"G\"}, {\"Index\": 881, \"Highest Charting Position\": 76, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Tak Tiki Tak\", \"Streams\": 4761286, \"Artist\": \"Harry Nach\", \"Artist Followers\": 134339.0, \"Song ID\": \"7gwwt1IaAWwmB7af0AcuBM\", \"Genre\": \"['trap chileno', 'trap latino']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\", \"Popularity\": 71.0, \"Danceability\": 0.801, \"Energy\": 0.579, \"Loudness\": -4.78, \"Speechiness\": 0.0813, \"Acousticness\": 0.333, \"Liveness\": 0.172, \"Tempo\": 99.994, \"Duration (ms)\": 212406.0, \"Valence\": 0.231, \"Chord\": \"B\"}, {\"Index\": 882, \"Highest Charting Position\": 26, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"WHATS POPPIN\", \"Streams\": 4745752, \"Artist\": \"Jack Harlow\", \"Artist Followers\": 3828418.0, \"Song ID\": \"2MbdDtCv5LUVjYy9RuGTgC\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-06-24\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 80.0, \"Danceability\": 0.904, \"Energy\": 0.723, \"Loudness\": -5.224, \"Speechiness\": 0.26, \"Acousticness\": 0.0631, \"Liveness\": 0.185, \"Tempo\": 145.013, \"Duration (ms)\": 227478.0, \"Valence\": 0.835, \"Chord\": \"B\"}, {\"Index\": 883, \"Highest Charting Position\": 143, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Money Trees\", \"Streams\": 4632724, \"Artist\": \"Kendrick Lamar, Jay Rock\", \"Artist Followers\": 17931101.0, \"Song ID\": \"2HbKqm4o0w5wEeEFXm2sD4\", \"Genre\": \"['conscious hip hop', 'hip hop', 'rap', 'west coast rap']\", \"Release Date\": \"2012\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 75.0, \"Danceability\": 0.716, \"Energy\": 0.531, \"Loudness\": -7.355, \"Speechiness\": 0.122, \"Acousticness\": 0.0703, \"Liveness\": 0.224, \"Tempo\": 71.994, \"Duration (ms)\": 386907.0, \"Valence\": 0.344, \"Chord\": \"G\"}, {\"Index\": 884, \"Highest Charting Position\": 65, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Blastoff (feat. Juice Wrld & Trippie Redd)\", \"Streams\": 4628159, \"Artist\": \"Internet Money, Diplo\", \"Artist Followers\": 412466.0, \"Song ID\": \"2rFsFjq0D9JAmc0APpCO6P\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-08-29\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 70.0, \"Danceability\": 0.761, \"Energy\": 0.517, \"Loudness\": -6.916, \"Speechiness\": 0.0927, \"Acousticness\": 0.114, \"Liveness\": 0.157, \"Tempo\": 147.912, \"Duration (ms)\": 174730.0, \"Valence\": 0.46, \"Chord\": \"F\"}, {\"Index\": 885, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"September\", \"Streams\": 5329256, \"Artist\": \"Earth, Wind & Fire\", \"Artist Followers\": 3008916.0, \"Song ID\": \"2grjqo0Frpf2okIBiifQKs\", \"Genre\": \"['disco', 'funk', 'jazz funk', 'motown', 'quiet storm', 'soul']\", \"Release Date\": \"1978-11-23\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 80.0, \"Danceability\": 0.697, \"Energy\": 0.832, \"Loudness\": -7.264, \"Speechiness\": 0.0298, \"Acousticness\": 0.168, \"Liveness\": 0.269, \"Tempo\": 125.926, \"Duration (ms)\": 215093.0, \"Valence\": 0.979, \"Chord\": \"A\"}, {\"Index\": 886, \"Highest Charting Position\": 64, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Secrets\", \"Streams\": 5178107, \"Artist\": \"Regard, RAYE\", \"Artist Followers\": 152237.0, \"Song ID\": \"66W1rVTnEv86dIkFhoiElg\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop edm', 'slap house', 'tropical house']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 78.0, \"Danceability\": 0.848, \"Energy\": 0.768, \"Loudness\": -5.386, \"Speechiness\": 0.0373, \"Acousticness\": 0.0412, \"Liveness\": 0.195, \"Tempo\": 118.961, \"Duration (ms)\": 176767.0, \"Valence\": 0.777, \"Chord\": \"F#/Gb\"}, {\"Index\": 887, \"Highest Charting Position\": 150, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"21\", \"Streams\": 5151406, \"Artist\": \"Polo G\", \"Artist Followers\": 4849204.0, \"Song ID\": \"3JKgcAa7r07ocVWcV8bS0H\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 80.0, \"Danceability\": 0.783, \"Energy\": 0.479, \"Loudness\": -10.646, \"Speechiness\": 0.541, \"Acousticness\": 0.149, \"Liveness\": 0.101, \"Tempo\": 176.027, \"Duration (ms)\": 163798.0, \"Valence\": 0.533, \"Chord\": \"G\"}, {\"Index\": 888, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"BXL ZOO\", \"Streams\": 5101640, \"Artist\": \"Damso, Hamza\", \"Artist Followers\": 3071170.0, \"Song ID\": \"1VBt9dPtYfLnVeKaa6CQPr\", \"Genre\": \"['belgian hip hop', 'french hip hop', 'pop urbaine', 'rap belge', 'rap conscient']\", \"Release Date\": \"2021-04-28\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 62.0, \"Danceability\": 0.745, \"Energy\": 0.656, \"Loudness\": -6.829, \"Speechiness\": 0.203, \"Acousticness\": 0.0604, \"Liveness\": 0.11, \"Tempo\": 137.997, \"Duration (ms)\": 201333.0, \"Valence\": 0.405, \"Chord\": \"B\"}, {\"Index\": 889, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"DEUX TOILES DE MER\", \"Streams\": 5094137, \"Artist\": \"Damso\", \"Artist Followers\": 3071170.0, \"Song ID\": \"6vw0mOQ5vm3C5RPm7Rvl2w\", \"Genre\": \"['belgian hip hop', 'french hip hop', 'pop urbaine', 'rap belge', 'rap conscient']\", \"Release Date\": \"2021-04-28\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 62.0, \"Danceability\": 0.521, \"Energy\": 0.39, \"Loudness\": -9.726, \"Speechiness\": 0.128, \"Acousticness\": 0.582, \"Liveness\": 0.112, \"Tempo\": 104.106, \"Duration (ms)\": 315640.0, \"Valence\": 0.157, \"Chord\": \"G#/Ab\"}, {\"Index\": 890, \"Highest Charting Position\": 4, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"exile (feat. Bon Iver)\", \"Streams\": 4924533, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"4pvb0WLRcMtbPGmtejJJ6y\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 77.0, \"Danceability\": 0.298, \"Energy\": 0.38, \"Loudness\": -8.426, \"Speechiness\": 0.0287, \"Acousticness\": 0.778, \"Liveness\": 0.11, \"Tempo\": 75.602, \"Duration (ms)\": 285634.0, \"Valence\": 0.152, \"Chord\": \"F#/Gb\"}, {\"Index\": 891, \"Highest Charting Position\": 10, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Righteous\", \"Streams\": 4819362, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5dOxHHMOFAbG3VH23t0xNm\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 78.0, \"Danceability\": 0.706, \"Energy\": 0.625, \"Loudness\": -7.426, \"Speechiness\": 0.0314, \"Acousticness\": 0.0417, \"Liveness\": 0.129, \"Tempo\": 142.948, \"Duration (ms)\": 242181.0, \"Valence\": 0.225, \"Chord\": \"C\"}, {\"Index\": 892, \"Highest Charting Position\": 9, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Conversations\", \"Streams\": 4805366, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4K06PO78fW4mnBVenxGNob\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 75.0, \"Danceability\": 0.747, \"Energy\": 0.622, \"Loudness\": -5.825, \"Speechiness\": 0.0838, \"Acousticness\": 0.176, \"Liveness\": 0.151, \"Tempo\": 159.93, \"Duration (ms)\": 181661.0, \"Valence\": 0.57, \"Chord\": \"B\"}, {\"Index\": 893, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Dolly (with Lil Uzi Vert)\", \"Streams\": 4800543, \"Artist\": \"Lil Tecca\", \"Artist Followers\": 4022792.0, \"Song ID\": \"77Xwqkw7VrV8E5FCq9JhO8\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 63.0, \"Danceability\": 0.664, \"Energy\": 0.586, \"Loudness\": -7.813, \"Speechiness\": 0.238, \"Acousticness\": 0.212, \"Liveness\": 0.216, \"Tempo\": 88.502, \"Duration (ms)\": 179813.0, \"Valence\": 0.589, \"Chord\": \"G\"}, {\"Index\": 894, \"Highest Charting Position\": 23, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Chicago Freestyle (feat. Giveon)\", \"Streams\": 4799038, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"4wVOKKEHUJxHCFFNUWDn0B\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 80.0, \"Danceability\": 0.735, \"Energy\": 0.449, \"Loudness\": -7.507, \"Speechiness\": 0.347, \"Acousticness\": 0.629, \"Liveness\": 0.113, \"Tempo\": 122.947, \"Duration (ms)\": 220488.0, \"Valence\": 0.0397, \"Chord\": \"A#/Bb\"}, {\"Index\": 895, \"Highest Charting Position\": 4, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"GOOBA\", \"Streams\": 4690955, \"Artist\": \"6ix9ine\", \"Artist Followers\": 6514102.0, \"Song ID\": \"4NhDYoQTYCdWHTvlbGVgwo\", \"Genre\": \"['emo rap', 'rap']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 70.0, \"Danceability\": 0.611, \"Energy\": 0.688, \"Loudness\": -5.688, \"Speechiness\": 0.341, \"Acousticness\": 0.0264, \"Liveness\": 0.251, \"Tempo\": 178.462, \"Duration (ms)\": 132303.0, \"Valence\": 0.393, \"Chord\": \"C#/Db\"}, {\"Index\": 896, \"Highest Charting Position\": 12, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Physical\", \"Streams\": 4599807, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3AzjcOeAmA57TIOr9zF1ZW\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 77.0, \"Danceability\": 0.647, \"Energy\": 0.844, \"Loudness\": -3.756, \"Speechiness\": 0.0457, \"Acousticness\": 0.0137, \"Liveness\": 0.102, \"Tempo\": 146.967, \"Duration (ms)\": 193829.0, \"Valence\": 0.746, \"Chord\": \"C\"}, {\"Index\": 897, \"Highest Charting Position\": 194, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Hot Stuff\", \"Streams\": 4569978, \"Artist\": \"Kygo, Donna Summer\", \"Artist Followers\": 7593792.0, \"Song ID\": \"00ETaeHUQ6lops3oWU1Wrt\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 71.0, \"Danceability\": 0.681, \"Energy\": 0.773, \"Loudness\": -5.749, \"Speechiness\": 0.148, \"Acousticness\": 0.019, \"Liveness\": 0.11, \"Tempo\": 119.961, \"Duration (ms)\": 199008.0, \"Valence\": 0.429, \"Chord\": \"F\"}, {\"Index\": 898, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Who's Laughing Now\", \"Streams\": 4526982, \"Artist\": \"Ava Max\", \"Artist Followers\": 3916979.0, \"Song ID\": \"1Pmp486RrLRkaEkE3HFHXP\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 73.0, \"Danceability\": 0.648, \"Energy\": 0.641, \"Loudness\": -5.521, \"Speechiness\": 0.0389, \"Acousticness\": 0.00565, \"Liveness\": 0.109, \"Tempo\": 184.021, \"Duration (ms)\": 180348.0, \"Valence\": 0.505, \"Chord\": \"G\"}, {\"Index\": 899, \"Highest Charting Position\": 91, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Sweet but Psycho\", \"Streams\": 4502853, \"Artist\": \"Ava Max\", \"Artist Followers\": 3916979.0, \"Song ID\": \"7DnAm9FOTWE3cUvso43HhI\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.72, \"Energy\": 0.706, \"Loudness\": -4.719, \"Speechiness\": 0.0473, \"Acousticness\": 0.0684, \"Liveness\": 0.166, \"Tempo\": 133.002, \"Duration (ms)\": 187436.0, \"Valence\": 0.62, \"Chord\": \"C#/Db\"}, {\"Index\": 900, \"Highest Charting Position\": 83, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Del Mar\", \"Streams\": 5698099, \"Artist\": \"Ozuna, Doja Cat, Sia\", \"Artist Followers\": 29238936.0, \"Song ID\": \"5cpJFiNwYyWwFLH0V6B3N8\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 79.0, \"Danceability\": 0.759, \"Energy\": 0.636, \"Loudness\": -5.585, \"Speechiness\": 0.0369, \"Acousticness\": 0.0224, \"Liveness\": 0.166, \"Tempo\": 109.976, \"Duration (ms)\": 214507.0, \"Valence\": 0.536, \"Chord\": \"F#/Gb\"}, {\"Index\": 901, \"Highest Charting Position\": 72, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Hit Different\", \"Streams\": 5049863, \"Artist\": \"SZA, The Neptunes, Pharrell Williams, Ty Dolla $ign\", \"Artist Followers\": 5888533.0, \"Song ID\": \"7Bar1kLTmsRmH6FCKKMEyU\", \"Genre\": \"['pop', 'pop rap', 'r&b']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 74.0, \"Danceability\": 0.679, \"Energy\": 0.516, \"Loudness\": -6.371, \"Speechiness\": 0.0452, \"Acousticness\": 0.199, \"Liveness\": 0.0965, \"Tempo\": 120.074, \"Duration (ms)\": 202008.0, \"Valence\": 0.716, \"Chord\": \"C\"}, {\"Index\": 902, \"Highest Charting Position\": 65, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Nobody's Love\", \"Streams\": 4957966, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32279979.0, \"Song ID\": \"2ST72jD2KVe7f3fbcGyX1b\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 73.0, \"Danceability\": 0.485, \"Energy\": 0.567, \"Loudness\": -6.456, \"Speechiness\": 0.0388, \"Acousticness\": 0.316, \"Liveness\": 0.0949, \"Tempo\": 93.676, \"Duration (ms)\": 211254.0, \"Valence\": 0.157, \"Chord\": \"C#/Db\"}, {\"Index\": 903, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"M\\u00e1quina do Tempo\", \"Streams\": 4938139, \"Artist\": \"Matu\\u00ea\", \"Artist Followers\": 3263283.0, \"Song ID\": \"5oI9blwsXC8AkTWw6wASY8\", \"Genre\": \"['r&b brasileiro', 'rap cearense', 'trap brasileiro']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-09-11--2020-09-18\", \"Popularity\": 70.0, \"Danceability\": 0.629, \"Energy\": 0.727, \"Loudness\": -4.387, \"Speechiness\": 0.0499, \"Acousticness\": 0.0647, \"Liveness\": 0.138, \"Tempo\": 149.978, \"Duration (ms)\": 230400.0, \"Valence\": 0.132, \"Chord\": \"E\"}, {\"Index\": 904, \"Highest Charting Position\": 112, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Fuckst mich nur ab\", \"Streams\": 4898520, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"0y8mJFmm4ogCHnfe0oTuT6\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 63.0, \"Danceability\": 0.817, \"Energy\": 0.468, \"Loudness\": -10.945, \"Speechiness\": 0.287, \"Acousticness\": 0.233, \"Liveness\": 0.0905, \"Tempo\": 104.875, \"Duration (ms)\": 182931.0, \"Valence\": 0.237, \"Chord\": \"C#/Db\"}, {\"Index\": 905, \"Highest Charting Position\": 122, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Jangueo\", \"Streams\": 4877753, \"Artist\": \"Alex Rose, Rafa Pab\\u00f6n\", \"Artist Followers\": 2168452.0, \"Song ID\": \"1bRpSCFv6P2OUhciByeRYR\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 74.0, \"Danceability\": 0.861, \"Energy\": 0.678, \"Loudness\": -4.157, \"Speechiness\": 0.0536, \"Acousticness\": 0.253, \"Liveness\": 0.106, \"Tempo\": 103.994, \"Duration (ms)\": 259600.0, \"Valence\": 0.723, \"Chord\": \"G#/Ab\"}, {\"Index\": 906, \"Highest Charting Position\": 68, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"We Paid (feat. 42 Dugg)\", \"Streams\": 4776686, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"6gxKUmycQX7uyMwJcweFjp\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 76.0, \"Danceability\": 0.926, \"Energy\": 0.542, \"Loudness\": -5.064, \"Speechiness\": 0.293, \"Acousticness\": 0.135, \"Liveness\": 0.0877, \"Tempo\": 135.14, \"Duration (ms)\": 181929.0, \"Valence\": 0.564, \"Chord\": \"C#/Db\"}, {\"Index\": 907, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Ihr Hobby\", \"Streams\": 4723116, \"Artist\": \"Bonez MC, Maxwell\", \"Artist Followers\": 1683006.0, \"Song ID\": \"4aZfvvgfoSfmSZpfwQYzC0\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-09-11--2020-09-18\", \"Popularity\": 59.0, \"Danceability\": 0.774, \"Energy\": 0.814, \"Loudness\": -6.145, \"Speechiness\": 0.0584, \"Acousticness\": 0.204, \"Liveness\": 0.118, \"Tempo\": 109.019, \"Duration (ms)\": 185330.0, \"Valence\": 0.254, \"Chord\": \"A#/Bb\"}, {\"Index\": 908, \"Highest Charting Position\": 150, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"When I Look At You\", \"Streams\": 4652583, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"7ywzEdEuVG1lsjsRCGJfLy\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2009-01-01\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 63.0, \"Danceability\": 0.459, \"Energy\": 0.545, \"Loudness\": -4.874, \"Speechiness\": 0.0282, \"Acousticness\": 0.142, \"Liveness\": 0.105, \"Tempo\": 137.941, \"Duration (ms)\": 248587.0, \"Valence\": 0.194, \"Chord\": \"F#/Gb\"}, {\"Index\": 909, \"Highest Charting Position\": 21, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Boss Bitch\", \"Streams\": 4620838, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"78qd8dvwea0Gosb6Fe6j3k\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-01-23\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 81.0, \"Danceability\": 0.707, \"Energy\": 0.955, \"Loudness\": -4.593, \"Speechiness\": 0.222, \"Acousticness\": 0.127, \"Liveness\": 0.202, \"Tempo\": 125.989, \"Duration (ms)\": 134240.0, \"Valence\": 0.575, \"Chord\": \"A#/Bb\"}, {\"Index\": 910, \"Highest Charting Position\": 142, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Ain't It Different (feat. AJ Tracey & Stormzy)\", \"Streams\": 4602336, \"Artist\": \"Headie One\", \"Artist Followers\": 328877.0, \"Song ID\": \"6NJfIydBMYrXvlaXsFxmc8\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2020-08-20\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 69.0, \"Danceability\": 0.767, \"Energy\": 0.569, \"Loudness\": -6.805, \"Speechiness\": 0.216, \"Acousticness\": 0.00988, \"Liveness\": 0.109, \"Tempo\": 77.052, \"Duration (ms)\": 196363.0, \"Valence\": 0.524, \"Chord\": \"E\"}, {\"Index\": 911, \"Highest Charting Position\": 75, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Some Say - Felix Jaehn Remix\", \"Streams\": 4598325, \"Artist\": \"Nea\", \"Artist Followers\": 38111.0, \"Song ID\": \"7C1trmcQQ5n5RNy4l6ziCv\", \"Genre\": \"['scandipop', 'swedish pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 77.0, \"Danceability\": 0.682, \"Energy\": 0.7, \"Loudness\": -5.591, \"Speechiness\": 0.0397, \"Acousticness\": 0.406, \"Liveness\": 0.174, \"Tempo\": 120.03, \"Duration (ms)\": 186878.0, \"Valence\": 0.637, \"Chord\": \"F#/Gb\"}, {\"Index\": 912, \"Highest Charting Position\": 13, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Savage Remix (feat. Beyonc\\u00e9)\", \"Streams\": 4568308, \"Artist\": \"Beyonc\\u00e9, Megan Thee Stallion\", \"Artist Followers\": 28335112.0, \"Song ID\": \"5v4GgrXPMghOnBBLmveLac\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'r&b']\", \"Release Date\": \"2020-04-29\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 73.0, \"Danceability\": 0.822, \"Energy\": 0.743, \"Loudness\": -4.772, \"Speechiness\": 0.28, \"Acousticness\": 0.016, \"Liveness\": 0.127, \"Tempo\": 84.459, \"Duration (ms)\": 242001.0, \"Valence\": 0.636, \"Chord\": \"A#/Bb\"}, {\"Index\": 913, \"Highest Charting Position\": 115, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Lithuania (feat. Travis Scott)\", \"Streams\": 5949270, \"Artist\": \"Big Sean\", \"Artist Followers\": 8673345.0, \"Song ID\": \"4VLTxHOyFX5FRtkpsFm5Pc\", \"Genre\": \"['detroit hip hop', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-09-04--2020-09-11\", \"Popularity\": 62.0, \"Danceability\": 0.676, \"Energy\": 0.82, \"Loudness\": -5.217, \"Speechiness\": 0.0554, \"Acousticness\": 0.0493, \"Liveness\": 0.615, \"Tempo\": 152.028, \"Duration (ms)\": 199250.0, \"Valence\": 0.618, \"Chord\": \"G\"}, {\"Index\": 914, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Tap In (feat. Post Malone, DaBaby & Jack Harlow)\", \"Streams\": 5117128, \"Artist\": \"Saweetie\", \"Artist Followers\": 1255573.0, \"Song ID\": \"5woaU1FNkqCwg6WzWiQPW5\", \"Genre\": \"['cali rap', 'dance pop', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-08-28\", \"Weeks Charted\": \"2020-09-04--2020-09-11\", \"Popularity\": 64.0, \"Danceability\": 0.948, \"Energy\": 0.63, \"Loudness\": -7.011, \"Speechiness\": 0.219, \"Acousticness\": 0.00647, \"Liveness\": 0.0737, \"Tempo\": 100.032, \"Duration (ms)\": 253569.0, \"Valence\": 0.425, \"Chord\": \"C#/Db\"}, {\"Index\": 915, \"Highest Charting Position\": 91, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Not Shy\", \"Streams\": 4982232, \"Artist\": \"ITZY\", \"Artist Followers\": 2384076.0, \"Song ID\": \"4ecVWqbtW6phQGpZMAyqIU\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2020-08-17\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 73.0, \"Danceability\": 0.776, \"Energy\": 0.911, \"Loudness\": -3.08, \"Speechiness\": 0.131, \"Acousticness\": 0.155, \"Liveness\": 0.268, \"Tempo\": 101.027, \"Duration (ms)\": 177728.0, \"Valence\": 0.56, \"Chord\": \"D\"}, {\"Index\": 916, \"Highest Charting Position\": 71, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"The Plan - From the Motion Picture \\\"TENET\\\"\", \"Streams\": 4876238, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"551xyaSJsg8hILXFq9JdST\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2020-08-22\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 67.0, \"Danceability\": 0.433, \"Energy\": 0.443, \"Loudness\": -10.568, \"Speechiness\": 0.0361, \"Acousticness\": 0.0922, \"Liveness\": 0.117, \"Tempo\": 79.903, \"Duration (ms)\": 185851.0, \"Valence\": 0.0363, \"Chord\": \"C#/Db\"}, {\"Index\": 917, \"Highest Charting Position\": 152, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"ADMV\", \"Streams\": 4737291, \"Artist\": \"Maluma\", \"Artist Followers\": 26784251.0, \"Song ID\": \"3eJMSq78dDaFb7VvhNFnq6\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-04-23\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 72.0, \"Danceability\": 0.565, \"Energy\": 0.39, \"Loudness\": -4.959, \"Speechiness\": 0.0556, \"Acousticness\": 0.817, \"Liveness\": 0.126, \"Tempo\": 163.781, \"Duration (ms)\": 193700.0, \"Valence\": 0.708, \"Chord\": \"A\"}, {\"Index\": 918, \"Highest Charting Position\": 122, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Alane\", \"Streams\": 4668193, \"Artist\": \"Robin Schulz, Wes\", \"Artist Followers\": 2786366.0, \"Song ID\": \"2u6Jm2klS4yvAlbSHlxUwI\", \"Genre\": \"['dance pop', 'deep euro house', 'deep house', 'edm', 'german dance', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 67.0, \"Danceability\": 0.581, \"Energy\": 0.799, \"Loudness\": -6.66, \"Speechiness\": 0.164, \"Acousticness\": 0.0419, \"Liveness\": 0.11, \"Tempo\": 124.002, \"Duration (ms)\": 175016.0, \"Valence\": 0.662, \"Chord\": \"D#/Eb\"}, {\"Index\": 919, \"Highest Charting Position\": 82, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"THE BADDEST\", \"Streams\": 4642057, \"Artist\": \"K/DA, (G)I-DLE, Wolftyla, Bea Miller, League of Legends\", \"Artist Followers\": 1245965.0, \"Song ID\": \"2V4Fx72svQRxrFvNT1eq5f\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2020-08-27\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 70.0, \"Danceability\": 0.676, \"Energy\": 0.857, \"Loudness\": -4.368, \"Speechiness\": 0.0438, \"Acousticness\": 0.0215, \"Liveness\": 0.254, \"Tempo\": 149.981, \"Duration (ms)\": 162600.0, \"Valence\": 0.717, \"Chord\": \"A#/Bb\"}, {\"Index\": 920, \"Highest Charting Position\": 112, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Desce Pro Play (PA PA PA)\", \"Streams\": 4615520, \"Artist\": \"Mc Zaac, Anitta, Tyga\", \"Artist Followers\": 1555628.0, \"Song ID\": \"4zGtfOglDBfVUypabBwIjQ\", \"Genre\": \"['funk carioca', 'funk pop']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 68.0, \"Danceability\": 0.935, \"Energy\": 0.71, \"Loudness\": -5.085, \"Speechiness\": 0.158, \"Acousticness\": 0.0769, \"Liveness\": 0.173, \"Tempo\": 100.009, \"Duration (ms)\": 168507.0, \"Valence\": 0.635, \"Chord\": \"B\"}, {\"Index\": 921, \"Highest Charting Position\": 103, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Mariposa\", \"Streams\": 4593366, \"Artist\": \"Peach Tree Rascals\", \"Artist Followers\": 177972.0, \"Song ID\": \"4ja2gzrNh9VNigzoXfmbwD\", \"Genre\": \"['alternative r&b', 'chill r&b', 'indie r&b', 'pop']\", \"Release Date\": \"2019-08-28\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 76.0, \"Danceability\": 0.676, \"Energy\": 0.525, \"Loudness\": -5.88, \"Speechiness\": 0.028, \"Acousticness\": 0.617, \"Liveness\": 0.356, \"Tempo\": 112.011, \"Duration (ms)\": 210000.0, \"Valence\": 0.421, \"Chord\": \"A\"}, {\"Index\": 922, \"Highest Charting Position\": 5, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"the 1\", \"Streams\": 4587573, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0Jlcvv8IykzHaSmj49uNW8\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 75.0, \"Danceability\": 0.777, \"Energy\": 0.357, \"Loudness\": -6.942, \"Speechiness\": 0.0522, \"Acousticness\": 0.757, \"Liveness\": 0.108, \"Tempo\": 139.883, \"Duration (ms)\": 210252.0, \"Valence\": 0.172, \"Chord\": \"C\"}, {\"Index\": 923, \"Highest Charting Position\": 11, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"RITMO (Bad Boys For Life)\", \"Streams\": 4585895, \"Artist\": \"Black Eyed Peas, J Balvin\", \"Artist Followers\": 5966748.0, \"Song ID\": \"6cy3ki60hLwimwIje7tALf\", \"Genre\": \"['dance pop', 'pop', 'pop rap']\", \"Release Date\": \"2019-10-12\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.721, \"Energy\": 0.716, \"Loudness\": -7.037, \"Speechiness\": 0.0657, \"Acousticness\": 0.0334, \"Liveness\": 0.237, \"Tempo\": 104.994, \"Duration (ms)\": 221714.0, \"Valence\": 0.667, \"Chord\": \"A#/Bb\"}, {\"Index\": 924, \"Highest Charting Position\": 134, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Unterwegs\", \"Streams\": 4572706, \"Artist\": \"KitschKrieg, Jamule, SFR\", \"Artist Followers\": 166517.0, \"Song ID\": \"7mrWTjhYctgEQb0lJKrVWy\", \"Genre\": \"['german hip hop', 'german pop', 'hamburg hip hop']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 68.0, \"Danceability\": 0.88, \"Energy\": 0.607, \"Loudness\": -7.067, \"Speechiness\": 0.0777, \"Acousticness\": 0.195, \"Liveness\": 0.15, \"Tempo\": 126.039, \"Duration (ms)\": 233905.0, \"Valence\": 0.823, \"Chord\": \"F#/Gb\"}, {\"Index\": 925, \"Highest Charting Position\": 86, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"What's Love Got to Do with It\", \"Streams\": 4538382, \"Artist\": \"Kygo, Tina Turner\", \"Artist Followers\": 7593792.0, \"Song ID\": \"3Be7CLdHZpyzsVijme39cW\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-07-17\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 74.0, \"Danceability\": 0.75, \"Energy\": 0.664, \"Loudness\": -5.908, \"Speechiness\": 0.154, \"Acousticness\": 0.275, \"Liveness\": 0.0632, \"Tempo\": 105.023, \"Duration (ms)\": 208156.0, \"Valence\": 0.617, \"Chord\": \"G#/Ab\"}, {\"Index\": 926, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Cry About It Later\", \"Streams\": 5306994, \"Artist\": \"Katy Perry\", \"Artist Followers\": 18936929.0, \"Song ID\": \"43WYPxyEfIxlIjNlxQGYzc\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2020-08-28--2020-09-04\", \"Popularity\": 67.0, \"Danceability\": 0.676, \"Energy\": 0.794, \"Loudness\": -4.78, \"Speechiness\": 0.0366, \"Acousticness\": 0.0513, \"Liveness\": 0.0723, \"Tempo\": 125.957, \"Duration (ms)\": 159286.0, \"Valence\": 0.161, \"Chord\": \"D\"}, {\"Index\": 927, \"Highest Charting Position\": 71, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Banana (feat. Shaggy) - DJ FLe - Minisiren Remix\", \"Streams\": 4624448, \"Artist\": \"Conkarah\", \"Artist Followers\": 67074.0, \"Song ID\": \"0dZpw3h6KZhcHec61qwevZ\", \"Genre\": \"['jawaiian']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 70.0, \"Danceability\": 0.824, \"Energy\": 0.854, \"Loudness\": -5.312, \"Speechiness\": 0.177, \"Acousticness\": 0.016, \"Liveness\": 0.117, \"Tempo\": 95.114, \"Duration (ms)\": 210329.0, \"Valence\": 0.896, \"Chord\": \"G#/Ab\"}, {\"Index\": 928, \"Highest Charting Position\": 185, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Gifted (feat. Roddy Ricch)\", \"Streams\": 4609169, \"Artist\": \"Cordae\", \"Artist Followers\": 1492551.0, \"Song ID\": \"0mb3uDw5vfFUcZfJYFOMRu\", \"Genre\": \"['dmv rap', 'hip hop', 'pop rap', 'rap', 'trap', 'underground hip hop', 'vapor trap']\", \"Release Date\": \"2020-08-27\", \"Weeks Charted\": \"2020-08-28--2020-09-04\", \"Popularity\": 65.0, \"Danceability\": 0.653, \"Energy\": 0.603, \"Loudness\": -5.697, \"Speechiness\": 0.171, \"Acousticness\": 0.175, \"Liveness\": 0.18, \"Tempo\": 151.016, \"Duration (ms)\": 168477.0, \"Valence\": 0.551, \"Chord\": \"F\"}, {\"Index\": 929, \"Highest Charting Position\": 27, \"Number of Times Charted\": 36, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"OUT WEST (feat. Young Thug)\", \"Streams\": 4597001, \"Artist\": \"JACKBOYS, Travis Scott\", \"Artist Followers\": 437907.0, \"Song ID\": \"6gi6y1xwmVszDWkUqab1qw\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.802, \"Energy\": 0.591, \"Loudness\": -4.895, \"Speechiness\": 0.225, \"Acousticness\": 0.0104, \"Liveness\": 0.196, \"Tempo\": 139.864, \"Duration (ms)\": 157712.0, \"Valence\": 0.309, \"Chord\": \"G#/Ab\"}, {\"Index\": 930, \"Highest Charting Position\": 174, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Anaranjado\", \"Streams\": 4575403, \"Artist\": \"Jowell & Randy, J Balvin\", \"Artist Followers\": 2919696.0, \"Song ID\": \"5iw28wvyHgj4ppOu5AdcEU\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-07-16\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 66.0, \"Danceability\": 0.763, \"Energy\": 0.58, \"Loudness\": -6.196, \"Speechiness\": 0.144, \"Acousticness\": 0.0466, \"Liveness\": 0.154, \"Tempo\": 175.937, \"Duration (ms)\": 212011.0, \"Valence\": 0.608, \"Chord\": \"G#/Ab\"}, {\"Index\": 931, \"Highest Charting Position\": 111, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Reggaetonera\", \"Streams\": 4564331, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"6yVkakCN460KOVol9ZazjH\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-05-29--2020-06-05\", \"Popularity\": 69.0, \"Danceability\": 0.694, \"Energy\": 0.796, \"Loudness\": -4.164, \"Speechiness\": 0.0565, \"Acousticness\": 0.48, \"Liveness\": 0.108, \"Tempo\": 93.064, \"Duration (ms)\": 212312.0, \"Valence\": 0.515, \"Chord\": \"F#/Gb\"}, {\"Index\": 932, \"Highest Charting Position\": 5, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Sour Candy (with BLACKPINK)\", \"Streams\": 4556900, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"6R6ZoHTypt5lt68MWbzZXv\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-28\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 70.0, \"Danceability\": 0.752, \"Energy\": 0.87, \"Loudness\": -3.812, \"Speechiness\": 0.0623, \"Acousticness\": 0.0604, \"Liveness\": 0.489, \"Tempo\": 120.006, \"Duration (ms)\": 157707.0, \"Valence\": 0.784, \"Chord\": \"A\"}, {\"Index\": 933, \"Highest Charting Position\": 113, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Rags2Riches 2 (feat. Lil Baby)\", \"Streams\": 4547965, \"Artist\": \"Rod Wave\", \"Artist Followers\": 2203386.0, \"Song ID\": \"40TPiJpvwGIyvPjJMDTKfy\", \"Genre\": \"['florida rap']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 60.0, \"Danceability\": 0.874, \"Energy\": 0.443, \"Loudness\": -9.628, \"Speechiness\": 0.241, \"Acousticness\": 0.147, \"Liveness\": 0.124, \"Tempo\": 118.004, \"Duration (ms)\": 235988.0, \"Valence\": 0.298, \"Chord\": \"F\"}, {\"Index\": 934, \"Highest Charting Position\": 31, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Bandit (with YoungBoy Never Broke Again)\", \"Streams\": 4514763, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"6Gg1gjgKi2AK4e0qzsR7sd\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.474, \"Energy\": 0.631, \"Loudness\": -5.884, \"Speechiness\": 0.343, \"Acousticness\": 0.0687, \"Liveness\": 0.132, \"Tempo\": 180.051, \"Duration (ms)\": 189323.0, \"Valence\": 0.425, \"Chord\": \"F\"}, {\"Index\": 935, \"Highest Charting Position\": 117, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"PAM\", \"Streams\": 4501441, \"Artist\": \"Justin Quiles, Daddy Yankee, El Alfa\", \"Artist Followers\": 2897862.0, \"Song ID\": \"0eeKDrQxjqNl5bX5VCHDcn\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 73.0, \"Danceability\": 0.889, \"Energy\": 0.863, \"Loudness\": -3.011, \"Speechiness\": 0.0757, \"Acousticness\": 0.289, \"Liveness\": 0.0798, \"Tempo\": 112.953, \"Duration (ms)\": 201000.0, \"Valence\": 0.776, \"Chord\": \"B\"}, {\"Index\": 936, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Lemonade\", \"Streams\": 11373347, \"Artist\": \"Internet Money, Gunna, Don Toliver, NAV\", \"Artist Followers\": 412466.0, \"Song ID\": \"02kDW379Yfd5PzW5A6vuGt\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 82.0, \"Danceability\": 0.799, \"Energy\": 0.66, \"Loudness\": -6.153, \"Speechiness\": 0.079, \"Acousticness\": 0.256, \"Liveness\": 0.111, \"Tempo\": 140.04, \"Duration (ms)\": 195429.0, \"Valence\": 0.471, \"Chord\": \"C#/Db\"}, {\"Index\": 937, \"Highest Charting Position\": 145, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Fr\\u00fchst\\u00fcck in Paris\", \"Streams\": 5440253, \"Artist\": \"Capital Bra, Cro\", \"Artist Followers\": 4093115.0, \"Song ID\": \"1ddbNJwDjjmCYz1GFGYnsw\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-09-17\", \"Weeks Charted\": \"2020-08-21--2020-08-28\", \"Popularity\": 56.0, \"Danceability\": 0.744, \"Energy\": 0.644, \"Loudness\": -5.562, \"Speechiness\": 0.0641, \"Acousticness\": 0.229, \"Liveness\": 0.204, \"Tempo\": 96.852, \"Duration (ms)\": 151360.0, \"Valence\": 0.577, \"Chord\": \"G#/Ab\"}, {\"Index\": 938, \"Highest Charting Position\": 22, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"ON\", \"Streams\": 5391018, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"2QyuXBcV1LJ2rq01KhreMF\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 77.0, \"Danceability\": 0.583, \"Energy\": 0.817, \"Loudness\": -5.146, \"Speechiness\": 0.0987, \"Acousticness\": 0.118, \"Liveness\": 0.338, \"Tempo\": 105.936, \"Duration (ms)\": 246381.0, \"Valence\": 0.438, \"Chord\": \"A\"}, {\"Index\": 939, \"Highest Charting Position\": 106, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"My Oasis (feat. Burna Boy)\", \"Streams\": 4887204, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"2KoHxhRyWxJzA0VafWd5Nk\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-07-30\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 69.0, \"Danceability\": 0.691, \"Energy\": 0.474, \"Loudness\": -8.742, \"Speechiness\": 0.0583, \"Acousticness\": 0.569, \"Liveness\": 0.099, \"Tempo\": 143.783, \"Duration (ms)\": 179917.0, \"Valence\": 0.381, \"Chord\": \"A#/Bb\"}, {\"Index\": 940, \"Highest Charting Position\": 8, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Life's A Mess (feat. Halsey)\", \"Streams\": 4883202, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5wWAwzGp2OaaoIkwcz6wZs\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 74.0, \"Danceability\": 0.63, \"Energy\": 0.446, \"Loudness\": -8.9, \"Speechiness\": 0.0351, \"Acousticness\": 0.337, \"Liveness\": 0.166, \"Tempo\": 143.078, \"Duration (ms)\": 202193.0, \"Valence\": 0.177, \"Chord\": \"C#/Db\"}, {\"Index\": 941, \"Highest Charting Position\": 56, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"PORFA\", \"Streams\": 4702117, \"Artist\": \"Feid, Justin Quiles\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5PwAiSk3ufe0YwOHRFPHEG\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 0.0, \"Danceability\": 0.843, \"Energy\": 0.549, \"Loudness\": -8.018, \"Speechiness\": 0.164, \"Acousticness\": 0.0948, \"Liveness\": 0.155, \"Tempo\": 83.982, \"Duration (ms)\": 233000.0, \"Valence\": 0.542, \"Chord\": \"F#/Gb\"}, {\"Index\": 942, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"2012\", \"Streams\": 4685894, \"Artist\": \"Bausa, Juju\", \"Artist Followers\": 961181.0, \"Song ID\": \"6bM4daGlfZHtKMQp8tEqVz\", \"Genre\": \"['german hip hop', 'german pop']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-08-21--2020-08-28\", \"Popularity\": 62.0, \"Danceability\": 0.805, \"Energy\": 0.619, \"Loudness\": -7.907, \"Speechiness\": 0.0771, \"Acousticness\": 0.218, \"Liveness\": 0.114, \"Tempo\": 98.995, \"Duration (ms)\": 170200.0, \"Valence\": 0.476, \"Chord\": \"F\"}, {\"Index\": 943, \"Highest Charting Position\": 11, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"august\", \"Streams\": 4586236, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3hUxzQpSfdDqwM3ZTFQY0K\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 76.0, \"Danceability\": 0.532, \"Energy\": 0.623, \"Loudness\": -9.208, \"Speechiness\": 0.0331, \"Acousticness\": 0.538, \"Liveness\": 0.0925, \"Tempo\": 89.937, \"Duration (ms)\": 261923.0, \"Valence\": 0.403, \"Chord\": \"F\"}, {\"Index\": 944, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"if i were u (with Lauv)\", \"Streams\": 4561189, \"Artist\": \"blackbear\", \"Artist Followers\": 4272745.0, \"Song ID\": \"0CF1RH8dQKuK2lQPSQw2lZ\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2020-08-19\", \"Weeks Charted\": \"2020-08-21--2020-08-28\", \"Popularity\": 64.0, \"Danceability\": 0.666, \"Energy\": 0.628, \"Loudness\": -5.613, \"Speechiness\": 0.0623, \"Acousticness\": 0.144, \"Liveness\": 0.189, \"Tempo\": 82.992, \"Duration (ms)\": 186468.0, \"Valence\": 0.767, \"Chord\": \"G#/Ab\"}, {\"Index\": 945, \"Highest Charting Position\": 37, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Ballin' (with Roddy Ricch)\", \"Streams\": 4436934, \"Artist\": \"Mustard\", \"Artist Followers\": 881797.0, \"Song ID\": \"3QzAOrNlsabgbMwlZt7TAY\", \"Genre\": \"['cali rap', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.809, \"Energy\": 0.545, \"Loudness\": -6.678, \"Speechiness\": 0.0735, \"Acousticness\": 0.392, \"Liveness\": 0.151, \"Tempo\": 97.008, \"Duration (ms)\": 180435.0, \"Valence\": 0.244, \"Chord\": \"G\"}, {\"Index\": 946, \"Highest Charting Position\": 72, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Stay Gold\", \"Streams\": 4405338, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3Ys2PYl1wyPKQIwyqhP9cQ\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-07-14\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-07-10--2020-07-17\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 73.0, \"Danceability\": 0.723, \"Energy\": 0.634, \"Loudness\": -5.415, \"Speechiness\": 0.0542, \"Acousticness\": 0.0892, \"Liveness\": 0.0787, \"Tempo\": 129.017, \"Duration (ms)\": 243267.0, \"Valence\": 0.582, \"Chord\": \"C#/Db\"}, {\"Index\": 947, \"Highest Charting Position\": 186, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"I'm Yours\", \"Streams\": 4391666, \"Artist\": \"Jason Mraz\", \"Artist Followers\": 6167871.0, \"Song ID\": \"1EzrEOXmMH3G43AXT1y7pA\", \"Genre\": \"['acoustic pop', 'neo mellow', 'pop', 'pop rock']\", \"Release Date\": \"2008-05-12\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\", \"Popularity\": 80.0, \"Danceability\": 0.686, \"Energy\": 0.457, \"Loudness\": -8.322, \"Speechiness\": 0.0468, \"Acousticness\": 0.595, \"Liveness\": 0.105, \"Tempo\": 150.953, \"Duration (ms)\": 242187.0, \"Valence\": 0.718, \"Chord\": \"B\"}, {\"Index\": 948, \"Highest Charting Position\": 136, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Youngblood\", \"Streams\": 4390823, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"2iUXsYOEPhVqEBwsqP70rE\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-06-15\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.596, \"Energy\": 0.854, \"Loudness\": -5.114, \"Speechiness\": 0.463, \"Acousticness\": 0.0169, \"Liveness\": 0.124, \"Tempo\": 120.274, \"Duration (ms)\": 203418.0, \"Valence\": 0.152, \"Chord\": \"G\"}, {\"Index\": 949, \"Highest Charting Position\": 8, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"the last great american dynasty\", \"Streams\": 4389670, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2Eeur20xVqfUoM3Q7EFPFt\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.686, \"Energy\": 0.662, \"Loudness\": -8.505, \"Speechiness\": 0.0413, \"Acousticness\": 0.467, \"Liveness\": 0.109, \"Tempo\": 147.922, \"Duration (ms)\": 230999.0, \"Valence\": 0.706, \"Chord\": \"G\"}, {\"Index\": 950, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Levitating (feat. Madonna and Missy Elliott) [The Blessed Madonna Remix]\", \"Streams\": 5254969, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"0pk1hxhJLBSZZ5RKBhcwOa\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-08-13\", \"Weeks Charted\": \"2020-08-14--2020-08-21\", \"Popularity\": 62.0, \"Danceability\": 0.808, \"Energy\": 0.655, \"Loudness\": -7.34, \"Speechiness\": 0.139, \"Acousticness\": 0.0373, \"Liveness\": 0.208, \"Tempo\": 116.029, \"Duration (ms)\": 250280.0, \"Valence\": 0.56, \"Chord\": \"B\"}, {\"Index\": 951, \"Highest Charting Position\": 10, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"my tears ricochet\", \"Streams\": 5111416, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1MgV7FIyNxIG7WzMRJV5HC\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.456, \"Energy\": 0.263, \"Loudness\": -10.63, \"Speechiness\": 0.0332, \"Acousticness\": 0.806, \"Liveness\": 0.0749, \"Tempo\": 129.86, \"Duration (ms)\": 255894.0, \"Valence\": 0.111, \"Chord\": \"C\"}, {\"Index\": 952, \"Highest Charting Position\": 59, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Rags2Riches (feat. ATR Son Son)\", \"Streams\": 4737306, \"Artist\": \"Rod Wave\", \"Artist Followers\": 2203386.0, \"Song ID\": \"0qg0GJp7HSewRCVPP4fKGk\", \"Genre\": \"['florida rap']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 55.0, \"Danceability\": 0.904, \"Energy\": 0.26, \"Loudness\": -17.57, \"Speechiness\": 0.101, \"Acousticness\": 0.277, \"Liveness\": 0.121, \"Tempo\": 117.967, \"Duration (ms)\": 167147.0, \"Valence\": 0.231, \"Chord\": \"F\"}, {\"Index\": 953, \"Highest Charting Position\": 79, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Flex (feat. Juice WRLD)\", \"Streams\": 4664281, \"Artist\": \"Polo G\", \"Artist Followers\": 4849204.0, \"Song ID\": \"2QqJTIlGKRLJC3onkavYEz\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 76.0, \"Danceability\": 0.752, \"Energy\": 0.673, \"Loudness\": -5.792, \"Speechiness\": 0.153, \"Acousticness\": 0.0538, \"Liveness\": 0.133, \"Tempo\": 164.009, \"Duration (ms)\": 163902.0, \"Valence\": 0.35, \"Chord\": \"A#/Bb\"}, {\"Index\": 954, \"Highest Charting Position\": 77, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Rover (feat. DTG)\", \"Streams\": 4488631, \"Artist\": \"S1mba\", \"Artist Followers\": 46992.0, \"Song ID\": \"4slSrbTK1sNK4I1mDYEthf\", \"Genre\": \"['afroswing', 'social media pop']\", \"Release Date\": \"2020-03-04\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 73.0, \"Danceability\": 0.613, \"Energy\": 0.624, \"Loudness\": -6.66, \"Speechiness\": 0.206, \"Acousticness\": 0.496, \"Liveness\": 0.283, \"Tempo\": 62.948, \"Duration (ms)\": 167917.0, \"Valence\": 0.804, \"Chord\": \"B\"}, {\"Index\": 955, \"Highest Charting Position\": 74, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Only You Freestyle\", \"Streams\": 4480780, \"Artist\": \"Headie One, Drake\", \"Artist Followers\": 328877.0, \"Song ID\": \"4OENnoidV0h8gJV6bhrw7r\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2020-07-20\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 68.0, \"Danceability\": 0.68, \"Energy\": 0.826, \"Loudness\": -2.561, \"Speechiness\": 0.27, \"Acousticness\": 0.562, \"Liveness\": 0.254, \"Tempo\": 146.95, \"Duration (ms)\": 248937.0, \"Valence\": 0.804, \"Chord\": \"F\"}, {\"Index\": 956, \"Highest Charting Position\": 55, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Hallucinate\", \"Streams\": 4472669, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"1nYeVF5vIBxMxfPoL0SIWg\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 72.0, \"Danceability\": 0.627, \"Energy\": 0.69, \"Loudness\": -5.396, \"Speechiness\": 0.139, \"Acousticness\": 0.033, \"Liveness\": 0.0742, \"Tempo\": 122.053, \"Duration (ms)\": 208505.0, \"Valence\": 0.627, \"Chord\": \"A#/Bb\"}, {\"Index\": 957, \"Highest Charting Position\": 100, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"El Efecto\", \"Streams\": 4466143, \"Artist\": \"Rauw Alejandro, Chencho Corleone\", \"Artist Followers\": 6096559.0, \"Song ID\": \"4SJHHpKhcuXwDsCsPqshXj\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2019-03-15\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 76.0, \"Danceability\": 0.849, \"Energy\": 0.781, \"Loudness\": -4.635, \"Speechiness\": 0.159, \"Acousticness\": 0.406, \"Liveness\": 0.0801, \"Tempo\": 84.041, \"Duration (ms)\": 217143.0, \"Valence\": 0.893, \"Chord\": \"C\"}, {\"Index\": 958, \"Highest Charting Position\": 176, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Co\\u00f1o\", \"Streams\": 4462411, \"Artist\": \"Jason Derulo, Puri, Jhorrmountain\", \"Artist Followers\": 9778632.0, \"Song ID\": \"5DV4ZSCqbFv74ui3ZhimXo\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 69.0, \"Danceability\": 0.899, \"Energy\": 0.528, \"Loudness\": -5.442, \"Speechiness\": 0.181, \"Acousticness\": 0.000554, \"Liveness\": 0.105, \"Tempo\": 100.037, \"Duration (ms)\": 111852.0, \"Valence\": 0.456, \"Chord\": \"A\"}, {\"Index\": 959, \"Highest Charting Position\": 126, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Jolie nana\", \"Streams\": 4449437, \"Artist\": \"Aya Nakamura\", \"Artist Followers\": 2953525.0, \"Song ID\": \"65RWVU6N81CeH65nu52K1U\", \"Genre\": \"['basshall', 'francoton']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 69.0, \"Danceability\": 0.813, \"Energy\": 0.64, \"Loudness\": -5.908, \"Speechiness\": 0.272, \"Acousticness\": 0.269, \"Liveness\": 0.131, \"Tempo\": 92.989, \"Duration (ms)\": 147076.0, \"Valence\": 0.488, \"Chord\": \"D\"}, {\"Index\": 960, \"Highest Charting Position\": 189, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Lovefool\", \"Streams\": 4439790, \"Artist\": \"twocolors\", \"Artist Followers\": 36369.0, \"Song ID\": \"51Of5p3lKZeOg6itfs4og4\", \"Genre\": \"['edm', 'pop dance', 'pop edm', 'tropical house']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 79.0, \"Danceability\": 0.677, \"Energy\": 0.766, \"Loudness\": -6.896, \"Speechiness\": 0.0568, \"Acousticness\": 0.0219, \"Liveness\": 0.129, \"Tempo\": 123.062, \"Duration (ms)\": 190488.0, \"Valence\": 0.198, \"Chord\": \"F#/Gb\"}, {\"Index\": 961, \"Highest Charting Position\": 17, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"invisible string\", \"Streams\": 4424118, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6VsvKPJ4xjVNKpI8VVZ3SV\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.653, \"Energy\": 0.452, \"Loudness\": -11.143, \"Speechiness\": 0.055, \"Acousticness\": 0.838, \"Liveness\": 0.108, \"Tempo\": 83.433, \"Duration (ms)\": 252881.0, \"Valence\": 0.45, \"Chord\": \"E\"}, {\"Index\": 962, \"Highest Charting Position\": 118, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Higher Love\", \"Streams\": 4392936, \"Artist\": \"Kygo, Whitney Houston\", \"Artist Followers\": 7593792.0, \"Song ID\": \"6oJ6le65B3SEqPwMRNXWjY\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.693, \"Energy\": 0.678, \"Loudness\": -7.159, \"Speechiness\": 0.0324, \"Acousticness\": 0.0151, \"Liveness\": 0.101, \"Tempo\": 103.952, \"Duration (ms)\": 228267.0, \"Valence\": 0.404, \"Chord\": \"G#/Ab\"}, {\"Index\": 963, \"Highest Charting Position\": 185, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Como Llora\", \"Streams\": 4380308, \"Artist\": \"Juanfran\", \"Artist Followers\": 117894.0, \"Song ID\": \"52zq2a71SGs3f1vJuv59ui\", \"Genre\": \"['dominican pop', 'pop reggaeton', 'urbano espanol']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 67.0, \"Danceability\": 0.827, \"Energy\": 0.629, \"Loudness\": -3.966, \"Speechiness\": 0.185, \"Acousticness\": 0.183, \"Liveness\": 0.084, \"Tempo\": 88.064, \"Duration (ms)\": 187500.0, \"Valence\": 0.486, \"Chord\": \"F#/Gb\"}, {\"Index\": 964, \"Highest Charting Position\": 50, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Walk Em Down (feat. Roddy Ricch)\", \"Streams\": 4371370, \"Artist\": \"NLE Choppa\", \"Artist Followers\": 6608815.0, \"Song ID\": \"4cSSL3YafYjM3yjgFO1vJg\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 74.0, \"Danceability\": 0.867, \"Energy\": 0.744, \"Loudness\": -5.171, \"Speechiness\": 0.227, \"Acousticness\": 0.268, \"Liveness\": 0.0713, \"Tempo\": 84.005, \"Duration (ms)\": 173288.0, \"Valence\": 0.645, \"Chord\": \"D\"}, {\"Index\": 965, \"Highest Charting Position\": 74, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Wow.\", \"Streams\": 4351784, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"7xQAfvXzm3AkraOtGPWIZg\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.829, \"Energy\": 0.539, \"Loudness\": -7.359, \"Speechiness\": 0.208, \"Acousticness\": 0.136, \"Liveness\": 0.103, \"Tempo\": 99.96, \"Duration (ms)\": 149547.0, \"Valence\": 0.388, \"Chord\": \"B\"}, {\"Index\": 966, \"Highest Charting Position\": 13, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"mirrorball\", \"Streams\": 5564072, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0ZNU020wNYvgW84iljPkPP\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.553, \"Energy\": 0.413, \"Loudness\": -10.037, \"Speechiness\": 0.0334, \"Acousticness\": 0.687, \"Liveness\": 0.0594, \"Tempo\": 110.107, \"Duration (ms)\": 208978.0, \"Valence\": 0.379, \"Chord\": \"D\"}, {\"Index\": 967, \"Highest Charting Position\": 15, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"seven\", \"Streams\": 5459423, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6KJqZcs9XDgVck7Lg9QOTC\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 69.0, \"Danceability\": 0.596, \"Energy\": 0.488, \"Loudness\": -10.769, \"Speechiness\": 0.0274, \"Acousticness\": 0.9, \"Liveness\": 0.091, \"Tempo\": 94.926, \"Duration (ms)\": 208907.0, \"Valence\": 0.415, \"Chord\": \"E\"}, {\"Index\": 968, \"Highest Charting Position\": 18, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"this is me trying\", \"Streams\": 5128412, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7kt9e9LFSpN1zQtYEl19o1\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.515, \"Energy\": 0.476, \"Loudness\": -9.843, \"Speechiness\": 0.0328, \"Acousticness\": 0.314, \"Liveness\": 0.171, \"Tempo\": 135.886, \"Duration (ms)\": 195097.0, \"Valence\": 0.412, \"Chord\": \"A\"}, {\"Index\": 969, \"Highest Charting Position\": 24, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"betty\", \"Streams\": 5112180, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5kI4eCXXzyuIUXjQra0Cxi\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.593, \"Energy\": 0.377, \"Loudness\": -8.761, \"Speechiness\": 0.0253, \"Acousticness\": 0.6, \"Liveness\": 0.0976, \"Tempo\": 95.939, \"Duration (ms)\": 294521.0, \"Valence\": 0.502, \"Chord\": \"C\"}, {\"Index\": 970, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"BLIND (feat. Young Thug)\", \"Streams\": 5074613, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"2T5NBwKRySiCR78vVk08vr\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-08-04\", \"Weeks Charted\": \"2020-08-07--2020-08-14\", \"Popularity\": 69.0, \"Danceability\": 0.709, \"Energy\": 0.679, \"Loudness\": -6.503, \"Speechiness\": 0.346, \"Acousticness\": 0.0115, \"Liveness\": 0.0971, \"Tempo\": 162.973, \"Duration (ms)\": 153467.0, \"Valence\": 0.754, \"Chord\": \"B\"}, {\"Index\": 971, \"Highest Charting Position\": 20, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"illicit affairs\", \"Streams\": 5053658, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2NmsngXHeC1GQ9wWrzhOMf\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.559, \"Energy\": 0.31, \"Loudness\": -10.445, \"Speechiness\": 0.0338, \"Acousticness\": 0.881, \"Liveness\": 0.106, \"Tempo\": 119.845, \"Duration (ms)\": 190898.0, \"Valence\": 0.46, \"Chord\": \"A#/Bb\"}, {\"Index\": 972, \"Highest Charting Position\": 170, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Freak\", \"Streams\": 4736059, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"3aA6xB0tOilDDX17fIJ0Bl\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2020-08-07--2020-08-14\", \"Popularity\": 75.0, \"Danceability\": 0.688, \"Energy\": 0.716, \"Loudness\": -5.702, \"Speechiness\": 0.0385, \"Acousticness\": 0.0969, \"Liveness\": 0.0989, \"Tempo\": 116.912, \"Duration (ms)\": 284480.0, \"Valence\": 0.373, \"Chord\": \"G\"}, {\"Index\": 973, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"PUNANI\", \"Streams\": 4625985, \"Artist\": \"6ix9ine\", \"Artist Followers\": 6514102.0, \"Song ID\": \"41xKiK40e7MFu1bqcGSz1d\", \"Genre\": \"['emo rap', 'rap']\", \"Release Date\": \"2020-08-02\", \"Weeks Charted\": \"2020-08-07--2020-08-14\", \"Popularity\": 58.0, \"Danceability\": 0.841, \"Energy\": 0.541, \"Loudness\": -7.121, \"Speechiness\": 0.229, \"Acousticness\": 0.0186, \"Liveness\": 0.123, \"Tempo\": 97.961, \"Duration (ms)\": 115255.0, \"Valence\": 0.42, \"Chord\": \"A\"}, {\"Index\": 974, \"Highest Charting Position\": 50, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Bl\\u00e4ulich\", \"Streams\": 4599408, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"2WRTnY0slmFgWcrmEr8dPj\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 60.0, \"Danceability\": 0.79, \"Energy\": 0.704, \"Loudness\": -7.935, \"Speechiness\": 0.417, \"Acousticness\": 0.069, \"Liveness\": 0.113, \"Tempo\": 154.007, \"Duration (ms)\": 196213.0, \"Valence\": 0.212, \"Chord\": \"A#/Bb\"}, {\"Index\": 975, \"Highest Charting Position\": 170, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Never Let Me Down\", \"Streams\": 4522005, \"Artist\": \"VIZE, Tom Gregory\", \"Artist Followers\": 141016.0, \"Song ID\": \"3bXiWZWR3CoZbhcsqfsMNa\", \"Genre\": \"['dance pop', 'german dance', 'pop dance', 'slap house', 'tropical house']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 61.0, \"Danceability\": 0.758, \"Energy\": 0.848, \"Loudness\": -3.84, \"Speechiness\": 0.0457, \"Acousticness\": 0.21, \"Liveness\": 0.114, \"Tempo\": 127.96, \"Duration (ms)\": 153149.0, \"Valence\": 0.706, \"Chord\": \"A#/Bb\"}, {\"Index\": 976, \"Highest Charting Position\": 16, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Savage\", \"Streams\": 4510218, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"55CHeLEfn5iJ0IIkgaa4si\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 75.0, \"Danceability\": 0.843, \"Energy\": 0.741, \"Loudness\": -5.609, \"Speechiness\": 0.334, \"Acousticness\": 0.0252, \"Liveness\": 0.096, \"Tempo\": 168.983, \"Duration (ms)\": 155497.0, \"Valence\": 0.68, \"Chord\": \"B\"}, {\"Index\": 977, \"Highest Charting Position\": 29, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"mad woman\", \"Streams\": 6796343, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2QDyYdZyhlP2fp79KZX8Bi\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 67.0, \"Danceability\": 0.592, \"Energy\": 0.699, \"Loudness\": -8.995, \"Speechiness\": 0.0471, \"Acousticness\": 0.655, \"Liveness\": 0.114, \"Tempo\": 141.916, \"Duration (ms)\": 237258.0, \"Valence\": 0.506, \"Chord\": \"D#/Eb\"}, {\"Index\": 978, \"Highest Charting Position\": 33, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"epiphany\", \"Streams\": 6085522, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"08fa9LFcFBTcilB3iq2e2A\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 66.0, \"Danceability\": 0.354, \"Energy\": 0.267, \"Loudness\": -13.69, \"Speechiness\": 0.0281, \"Acousticness\": 0.731, \"Liveness\": 0.0858, \"Tempo\": 94.219, \"Duration (ms)\": 289749.0, \"Valence\": 0.113, \"Chord\": \"C#/Db\"}, {\"Index\": 979, \"Highest Charting Position\": 41, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"peace\", \"Streams\": 5943851, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7MbT4I8qGntX4fMdqMQgke\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 67.0, \"Danceability\": 0.647, \"Energy\": 0.272, \"Loudness\": -12.906, \"Speechiness\": 0.0916, \"Acousticness\": 0.918, \"Liveness\": 0.0918, \"Tempo\": 150.044, \"Duration (ms)\": 234000.0, \"Valence\": 0.339, \"Chord\": \"F\"}, {\"Index\": 980, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Move Ya Hips (feat. Nicki Minaj & MadeinTYO)\", \"Streams\": 5768616, \"Artist\": \"A$AP Ferg\", \"Artist Followers\": 3037935.0, \"Song ID\": \"13v5IXnvO2BccWwOx5rb4s\", \"Genre\": \"['hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap', 'underground hip hop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 61.0, \"Danceability\": 0.808, \"Energy\": 0.676, \"Loudness\": -4.902, \"Speechiness\": 0.223, \"Acousticness\": 0.0618, \"Liveness\": 0.11, \"Tempo\": 144.018, \"Duration (ms)\": 144973.0, \"Valence\": 0.0763, \"Chord\": \"E\"}, {\"Index\": 981, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Sie ruft\", \"Streams\": 5752169, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"4CyCHkhRsDXUeP5K4Y3xjU\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 59.0, \"Danceability\": 0.819, \"Energy\": 0.507, \"Loudness\": -7.336, \"Speechiness\": 0.0881, \"Acousticness\": 0.482, \"Liveness\": 0.105, \"Tempo\": 130.009, \"Duration (ms)\": 152013.0, \"Valence\": 0.634, \"Chord\": \"C#/Db\"}, {\"Index\": 982, \"Highest Charting Position\": 144, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Tilidin Weg\", \"Streams\": 5674945, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"7idxewQZ24F0gQy2EWE6Ug\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 60.0, \"Danceability\": 0.882, \"Energy\": 0.526, \"Loudness\": -8.553, \"Speechiness\": 0.237, \"Acousticness\": 0.118, \"Liveness\": 0.0835, \"Tempo\": 109.075, \"Duration (ms)\": 180950.0, \"Valence\": 0.182, \"Chord\": \"A#/Bb\"}, {\"Index\": 983, \"Highest Charting Position\": 149, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Over Your Head\", \"Streams\": 5534361, \"Artist\": \"Future, Lil Uzi Vert\", \"Artist Followers\": 10491105.0, \"Song ID\": \"0Tcw8w9pvPrZoORgxsNASW\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 59.0, \"Danceability\": 0.773, \"Energy\": 0.742, \"Loudness\": -5.453, \"Speechiness\": 0.162, \"Acousticness\": 0.00198, \"Liveness\": 0.558, \"Tempo\": 148.949, \"Duration (ms)\": 186843.0, \"Valence\": 0.35, \"Chord\": \"F\"}, {\"Index\": 984, \"Highest Charting Position\": 47, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"hoax\", \"Streams\": 5375944, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6MWoRt97mnSTXZhu3ggi9C\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 66.0, \"Danceability\": 0.662, \"Energy\": 0.181, \"Loudness\": -15.065, \"Speechiness\": 0.0415, \"Acousticness\": 0.966, \"Liveness\": 0.133, \"Tempo\": 118.819, \"Duration (ms)\": 220043.0, \"Valence\": 0.429, \"Chord\": \"G#/Ab\"}, {\"Index\": 985, \"Highest Charting Position\": 25, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Blood On My Jeans\", \"Streams\": 4978899, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"0fCwrjKfWxF3xQhZrYUw4T\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 73.0, \"Danceability\": 0.868, \"Energy\": 0.55, \"Loudness\": -6.417, \"Speechiness\": 0.226, \"Acousticness\": 0.183, \"Liveness\": 0.109, \"Tempo\": 117.943, \"Duration (ms)\": 154767.0, \"Valence\": 0.464, \"Chord\": \"F#/Gb\"}, {\"Index\": 986, \"Highest Charting Position\": 171, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Narrow Road (feat. Lil Baby)\", \"Streams\": 4828004, \"Artist\": \"NLE Choppa\", \"Artist Followers\": 3372385.0, \"Song ID\": \"3GZd1aDsgKL71Kt3VIp0hc\", \"Genre\": \"['memphis hip hop']\", \"Release Date\": \"2020-07-30\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 64.0, \"Danceability\": 0.614, \"Energy\": 0.553, \"Loudness\": -8.225, \"Speechiness\": 0.169, \"Acousticness\": 0.0306, \"Liveness\": 0.203, \"Tempo\": 159.999, \"Duration (ms)\": 240297.0, \"Valence\": 0.161, \"Chord\": \"G\"}, {\"Index\": 987, \"Highest Charting Position\": 26, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Amarillo\", \"Streams\": 4695091, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"6zEgnpM0qYmHLDnh8WPejL\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 73.0, \"Danceability\": 0.641, \"Energy\": 0.857, \"Loudness\": -5.725, \"Speechiness\": 0.301, \"Acousticness\": 0.013, \"Liveness\": 0.0695, \"Tempo\": 122.728, \"Duration (ms)\": 157733.0, \"Valence\": 0.961, \"Chord\": \"C#/Db\"}, {\"Index\": 988, \"Highest Charting Position\": 179, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Singapur\", \"Streams\": 4661170, \"Artist\": \"El Alfa, Chael Produciendo\", \"Artist Followers\": 1779640.0, \"Song ID\": \"4QfZYDhGZc0T2RDvGiI69E\", \"Genre\": \"['dembow', 'latin', 'rap dominicano', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 69.0, \"Danceability\": 0.853, \"Energy\": 0.909, \"Loudness\": -2.473, \"Speechiness\": 0.229, \"Acousticness\": 0.0522, \"Liveness\": 0.129, \"Tempo\": 112.987, \"Duration (ms)\": 178407.0, \"Valence\": 0.803, \"Chord\": \"G\"}, {\"Index\": 989, \"Highest Charting Position\": 42, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Tattoo\", \"Streams\": 4588064, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6096559.0, \"Song ID\": \"4ZRrLHqzhGRXYj2qcB4s5S\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-07-09\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 78.0, \"Danceability\": 0.848, \"Energy\": 0.637, \"Loudness\": -5.132, \"Speechiness\": 0.156, \"Acousticness\": 0.0413, \"Liveness\": 0.0521, \"Tempo\": 96.988, \"Duration (ms)\": 222680.0, \"Valence\": 0.698, \"Chord\": \"A\"}, {\"Index\": 990, \"Highest Charting Position\": 86, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Ego Death (feat. Kanye West, FKA twigs & Skrillex)\", \"Streams\": 4583475, \"Artist\": \"Ty Dolla $ign\", \"Artist Followers\": 3866304.0, \"Song ID\": \"3Q5cLvkKsHJvYltf8k7HkO\", \"Genre\": \"['hip hop', 'pop', 'pop rap', 'r&b', 'southern hip hop', 'trap', 'trap soul']\", \"Release Date\": \"2020-10-22\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 71.0, \"Danceability\": 0.818, \"Energy\": 0.598, \"Loudness\": -5.948, \"Speechiness\": 0.113, \"Acousticness\": 0.0573, \"Liveness\": 0.634, \"Tempo\": 111.052, \"Duration (ms)\": 231618.0, \"Valence\": 0.331, \"Chord\": \"A#/Bb\"}, {\"Index\": 991, \"Highest Charting Position\": 33, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Morado\", \"Streams\": 4561936, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"3mQ6SLdxxaL52Yte7KF2Ks\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-01-09\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 71.0, \"Danceability\": 0.881, \"Energy\": 0.696, \"Loudness\": -3.838, \"Speechiness\": 0.0797, \"Acousticness\": 0.137, \"Liveness\": 0.0927, \"Tempo\": 97.002, \"Duration (ms)\": 200667.0, \"Valence\": 0.781, \"Chord\": \"B\"}, {\"Index\": 992, \"Highest Charting Position\": 101, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"ocean eyes\", \"Streams\": 4476954, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6pFTDHGJtKOxrQ85xRZ8Ue\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 1.0, \"Danceability\": 0.358, \"Energy\": 0.372, \"Loudness\": -7.664, \"Speechiness\": 0.0464, \"Acousticness\": 0.81, \"Liveness\": 0.0877, \"Tempo\": 144.833, \"Duration (ms)\": 200387.0, \"Valence\": 0.16, \"Chord\": \"E\"}, {\"Index\": 993, \"Highest Charting Position\": 82, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Lion King On Ice\", \"Streams\": 8293983, \"Artist\": \"J. Cole\", \"Artist Followers\": 14103694.0, \"Song ID\": \"1ZvBVbsaNqHEP6ymXaPGlj\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2020-07-22\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 64.0, \"Danceability\": 0.732, \"Energy\": 0.663, \"Loudness\": -7.616, \"Speechiness\": 0.192, \"Acousticness\": 0.0819, \"Liveness\": 0.115, \"Tempo\": 139.964, \"Duration (ms)\": 210587.0, \"Valence\": 0.227, \"Chord\": \"F#/Gb\"}, {\"Index\": 994, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Andere Welt\", \"Streams\": 5600868, \"Artist\": \"Capital Bra, Clueso, KC Rebell\", \"Artist Followers\": 4093115.0, \"Song ID\": \"5PAAUJTKLT0nCmHUlLdPXb\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-07-23\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 60.0, \"Danceability\": 0.692, \"Energy\": 0.764, \"Loudness\": -5.233, \"Speechiness\": 0.113, \"Acousticness\": 0.574, \"Liveness\": 0.106, \"Tempo\": 84.029, \"Duration (ms)\": 189686.0, \"Valence\": 0.564, \"Chord\": \"F\"}, {\"Index\": 995, \"Highest Charting Position\": 163, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"TELL ME WHY\", \"Streams\": 5056986, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"3jlxX3VXPiY3lvBBbppQD3\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.6, \"Energy\": 0.723, \"Loudness\": -4.928, \"Speechiness\": 0.158, \"Acousticness\": 0.109, \"Liveness\": 0.167, \"Tempo\": 149.881, \"Duration (ms)\": 195268.0, \"Valence\": 0.463, \"Chord\": \"F#/Gb\"}, {\"Index\": 996, \"Highest Charting Position\": 37, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Stay High\", \"Streams\": 5047752, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"21CkzgKCBCq5V4XKjiGSIj\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 75.0, \"Danceability\": 0.745, \"Energy\": 0.5, \"Loudness\": -6.184, \"Speechiness\": 0.135, \"Acousticness\": 0.439, \"Liveness\": 0.0943, \"Tempo\": 76.968, \"Duration (ms)\": 168685.0, \"Valence\": 0.433, \"Chord\": \"G#/Ab\"}, {\"Index\": 997, \"Highest Charting Position\": 161, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"What Makes You Beautiful\", \"Streams\": 4966428, \"Artist\": \"One Direction\", \"Artist Followers\": 22536304.0, \"Song ID\": \"4cluDES4hQEUhmXj6TXkSo\", \"Genre\": \"['boy band', 'pop', 'post-teen pop', 'talent show']\", \"Release Date\": \"2012-05-25\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 82.0, \"Danceability\": 0.726, \"Energy\": 0.787, \"Loudness\": -2.494, \"Speechiness\": 0.0737, \"Acousticness\": 0.009, \"Liveness\": 0.0596, \"Tempo\": 124.99, \"Duration (ms)\": 199987.0, \"Valence\": 0.888, \"Chord\": \"E\"}, {\"Index\": 998, \"Highest Charting Position\": 174, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Shit Changed\", \"Streams\": 4823401, \"Artist\": \"Ufo361, Sonus030\", \"Artist Followers\": 1700759.0, \"Song ID\": \"6du77YHyGWoFjbuHCFBHU3\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 52.0, \"Danceability\": 0.824, \"Energy\": 0.528, \"Loudness\": -9.236, \"Speechiness\": 0.175, \"Acousticness\": 0.144, \"Liveness\": 0.104, \"Tempo\": 157.005, \"Duration (ms)\": 183839.0, \"Valence\": 0.32, \"Chord\": \"A\"}, {\"Index\": 999, \"Highest Charting Position\": 35, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Tell Me U Luv Me (with Trippie Redd)\", \"Streams\": 4798078, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5JAYDuLRkODlVt6dgoalKk\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 72.0, \"Danceability\": 0.66, \"Energy\": 0.76, \"Loudness\": -5.726, \"Speechiness\": 0.0787, \"Acousticness\": 0.291, \"Liveness\": 0.632, \"Tempo\": 127.984, \"Duration (ms)\": 180129.0, \"Valence\": 0.394, \"Chord\": \"D\"}, {\"Index\": 1000, \"Highest Charting Position\": 27, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Bad Energy\", \"Streams\": 4761155, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"7d94IqWX2UmSKMGUYSGFJG\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 72.0, \"Danceability\": 0.654, \"Energy\": 0.452, \"Loudness\": -6.36, \"Speechiness\": 0.0439, \"Acousticness\": 0.17, \"Liveness\": 0.114, \"Tempo\": 138.034, \"Duration (ms)\": 186749.0, \"Valence\": 0.532, \"Chord\": \"G\"}, {\"Index\": 1001, \"Highest Charting Position\": 24, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Titanic\", \"Streams\": 4687464, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"1YM6c2sxbf2Jacl9IFgn4I\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 71.0, \"Danceability\": 0.567, \"Energy\": 0.545, \"Loudness\": -6.668, \"Speechiness\": 0.0448, \"Acousticness\": 0.168, \"Liveness\": 0.112, \"Tempo\": 174.146, \"Duration (ms)\": 176650.0, \"Valence\": 0.234, \"Chord\": \"C#/Db\"}, {\"Index\": 1002, \"Highest Charting Position\": 31, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Skechers\", \"Streams\": 4669248, \"Artist\": \"DripReport\", \"Artist Followers\": 92356.0, \"Song ID\": \"2alc8VZAzDgdAsL2QMk3hu\", \"Genre\": \"['viral rap']\", \"Release Date\": \"2020-01-12\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 73.0, \"Danceability\": 0.903, \"Energy\": 0.327, \"Loudness\": -9.727, \"Speechiness\": 0.0877, \"Acousticness\": 0.26, \"Liveness\": 0.108, \"Tempo\": 100.008, \"Duration (ms)\": 106000.0, \"Valence\": 0.274, \"Chord\": \"C#/Db\"}, {\"Index\": 1003, \"Highest Charting Position\": 47, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"The Bigger Picture\", \"Streams\": 4629083, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"44gRhRi2OhEf7moAUj6MD1\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 70.0, \"Danceability\": 0.59, \"Energy\": 0.618, \"Loudness\": -5.756, \"Speechiness\": 0.334, \"Acousticness\": 0.0127, \"Liveness\": 0.244, \"Tempo\": 96.459, \"Duration (ms)\": 252729.0, \"Valence\": 0.153, \"Chord\": \"C#/Db\"}, {\"Index\": 1004, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Story of My Life\", \"Streams\": 4628772, \"Artist\": \"One Direction\", \"Artist Followers\": 22536304.0, \"Song ID\": \"4nVBt6MZDDP6tRVdQTgxJg\", \"Genre\": \"['boy band', 'pop', 'post-teen pop', 'talent show']\", \"Release Date\": \"2013-11-25\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 81.0, \"Danceability\": 0.6, \"Energy\": 0.663, \"Loudness\": -5.802, \"Speechiness\": 0.0477, \"Acousticness\": 0.225, \"Liveness\": 0.119, \"Tempo\": 121.07, \"Duration (ms)\": 245493.0, \"Valence\": 0.286, \"Chord\": \"D#/Eb\"}, {\"Index\": 1005, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Hit My Line\", \"Streams\": 4621205, \"Artist\": \"Logic\", \"Artist Followers\": 5449291.0, \"Song ID\": \"24FR8mXTaiGZPrxnkf1kcP\", \"Genre\": \"['conscious hip hop', 'dmv rap', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 60.0, \"Danceability\": 0.62, \"Energy\": 0.786, \"Loudness\": -5.22, \"Speechiness\": 0.167, \"Acousticness\": 0.143, \"Liveness\": 0.46, \"Tempo\": 164.057, \"Duration (ms)\": 265191.0, \"Valence\": 0.679, \"Chord\": \"A\"}, {\"Index\": 1006, \"Highest Charting Position\": 10, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Party Girl (Remix)\", \"Streams\": 15129295, \"Artist\": \"StaySolidRocky, Lil Uzi Vert\", \"Artist Followers\": 150587.0, \"Song ID\": \"0XkmeG97T4mtYlWRJcrxec\", \"Genre\": \"['melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 62.0, \"Danceability\": 0.752, \"Energy\": 0.375, \"Loudness\": -10.157, \"Speechiness\": 0.204, \"Acousticness\": 0.533, \"Liveness\": 0.175, \"Tempo\": 129.995, \"Duration (ms)\": 147673.0, \"Valence\": 0.591, \"Chord\": \"F#/Gb\"}, {\"Index\": 1007, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Up Up And Away\", \"Streams\": 6229316, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"7pbg3ABlAZv2NiIdKbBBFm\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 72.0, \"Danceability\": 0.661, \"Energy\": 0.665, \"Loudness\": -6.356, \"Speechiness\": 0.053, \"Acousticness\": 0.538, \"Liveness\": 0.0981, \"Tempo\": 75.059, \"Duration (ms)\": 147548.0, \"Valence\": 0.486, \"Chord\": \"E\"}, {\"Index\": 1008, \"Highest Charting Position\": 46, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Man Of The Year\", \"Streams\": 6223001, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"7AvprzMsRJpybaalckaT8c\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 73.0, \"Danceability\": 0.621, \"Energy\": 0.695, \"Loudness\": -5.124, \"Speechiness\": 0.0911, \"Acousticness\": 0.00584, \"Liveness\": 0.086, \"Tempo\": 173.966, \"Duration (ms)\": 136408.0, \"Valence\": 0.298, \"Chord\": \"E\"}, {\"Index\": 1009, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Fighting Demons\", \"Streams\": 5946573, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"0440JCJyIAmINA8KcYgFb5\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 70.0, \"Danceability\": 0.707, \"Energy\": 0.67, \"Loudness\": -6.328, \"Speechiness\": 0.257, \"Acousticness\": 0.0813, \"Liveness\": 0.098, \"Tempo\": 163.099, \"Duration (ms)\": 200629.0, \"Valence\": 0.235, \"Chord\": \"G\"}, {\"Index\": 1010, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Can't Die\", \"Streams\": 5777859, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4PPLJAEYBSOcnzr9TZoqf9\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 71.0, \"Danceability\": 0.652, \"Energy\": 0.671, \"Loudness\": -5.89, \"Speechiness\": 0.0756, \"Acousticness\": 0.0222, \"Liveness\": 0.107, \"Tempo\": 84.008, \"Duration (ms)\": 182922.0, \"Valence\": 0.274, \"Chord\": \"D\"}, {\"Index\": 1011, \"Highest Charting Position\": 44, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Screw Juice\", \"Streams\": 5394197, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4F6YLjakjqWFTgC5qfEwPQ\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 69.0, \"Danceability\": 0.595, \"Energy\": 0.528, \"Loudness\": -7.371, \"Speechiness\": 0.0935, \"Acousticness\": 0.082, \"Liveness\": 0.142, \"Tempo\": 150.075, \"Duration (ms)\": 179464.0, \"Valence\": 0.515, \"Chord\": \"F\"}, {\"Index\": 1012, \"Highest Charting Position\": 129, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Past Life (with Selena Gomez)\", \"Streams\": 5228433, \"Artist\": \"Trevor Daniel\", \"Artist Followers\": 632097.0, \"Song ID\": \"7MN8RYSofZsFROBlEOAzXq\", \"Genre\": \"['alternative r&b', 'melodic rap', 'pop rap']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 47.0, \"Danceability\": 0.575, \"Energy\": 0.543, \"Loudness\": -5.062, \"Speechiness\": 0.0529, \"Acousticness\": 0.102, \"Liveness\": 0.176, \"Tempo\": 159.905, \"Duration (ms)\": 186480.0, \"Valence\": 0.283, \"Chord\": \"D#/Eb\"}, {\"Index\": 1013, \"Highest Charting Position\": 45, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"I Want It\", \"Streams\": 5137482, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"2SVx3uds6jTWALFxevIWMA\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 69.0, \"Danceability\": 0.288, \"Energy\": 0.638, \"Loudness\": -6.935, \"Speechiness\": 0.0779, \"Acousticness\": 0.133, \"Liveness\": 0.14, \"Tempo\": 66.424, \"Duration (ms)\": 173114.0, \"Valence\": 0.147, \"Chord\": \"E\"}, {\"Index\": 1014, \"Highest Charting Position\": 56, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Ransom\", \"Streams\": 5097394, \"Artist\": \"Lil Tecca\", \"Artist Followers\": 4022792.0, \"Song ID\": \"1lOe9qE0vR9zwWQAOk6CoO\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-08-30\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.745, \"Energy\": 0.642, \"Loudness\": -6.257, \"Speechiness\": 0.287, \"Acousticness\": 0.0204, \"Liveness\": 0.0658, \"Tempo\": 179.974, \"Duration (ms)\": 131240.0, \"Valence\": 0.226, \"Chord\": \"G\"}, {\"Index\": 1015, \"Highest Charting Position\": 49, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Diosa\", \"Streams\": 4868180, \"Artist\": \"Myke Towers\", \"Artist Followers\": 6161098.0, \"Song ID\": \"3JHpk0DOTOzyh0777JFAky\", \"Genre\": \"['trap latino']\", \"Release Date\": \"2020-01-24\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 74.0, \"Danceability\": 0.801, \"Energy\": 0.745, \"Loudness\": -3.733, \"Speechiness\": 0.063, \"Acousticness\": 0.398, \"Liveness\": 0.153, \"Tempo\": 104.965, \"Duration (ms)\": 214013.0, \"Valence\": 0.245, \"Chord\": \"F#/Gb\"}, {\"Index\": 1016, \"Highest Charting Position\": 169, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Never Know (feat. SHIRIN DAVID)\", \"Streams\": 4803071, \"Artist\": \"Luciano\", \"Artist Followers\": 942380.0, \"Song ID\": \"5Hkj1XjMJv5QCGc9NwZm6z\", \"Genre\": \"['german drill', 'german hip hop']\", \"Release Date\": \"2020-07-16\", \"Weeks Charted\": \"2020-07-17--2020-07-24\", \"Popularity\": 60.0, \"Danceability\": 0.874, \"Energy\": 0.542, \"Loudness\": -7.064, \"Speechiness\": 0.344, \"Acousticness\": 0.0621, \"Liveness\": 0.181, \"Tempo\": 142.016, \"Duration (ms)\": 196933.0, \"Valence\": 0.481, \"Chord\": \"A#/Bb\"}, {\"Index\": 1017, \"Highest Charting Position\": 5, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"La Dif\\u00edcil\", \"Streams\": 4727554, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"6NfrH0ANGmgBXyxgV2PeXt\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 78.0, \"Danceability\": 0.685, \"Energy\": 0.848, \"Loudness\": -4.561, \"Speechiness\": 0.0858, \"Acousticness\": 0.0861, \"Liveness\": 0.0783, \"Tempo\": 179.87, \"Duration (ms)\": 163084.0, \"Valence\": 0.761, \"Chord\": \"G#/Ab\"}, {\"Index\": 1018, \"Highest Charting Position\": 20, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"TROLLZ (with Nicki Minaj)\", \"Streams\": 4700152, \"Artist\": \"6ix9ine\", \"Artist Followers\": 6514102.0, \"Song ID\": \"3dVvWnj4D8JGkKvo6Hucso\", \"Genre\": \"['emo rap', 'rap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 65.0, \"Danceability\": 0.744, \"Energy\": 0.422, \"Loudness\": -8.946, \"Speechiness\": 0.294, \"Acousticness\": 0.0319, \"Liveness\": 0.11, \"Tempo\": 180.006, \"Duration (ms)\": 202667.0, \"Valence\": 0.493, \"Chord\": \"C#/Db\"}, {\"Index\": 1019, \"Highest Charting Position\": 44, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Old Town Road - Remix\", \"Streams\": 4643817, \"Artist\": \"Lil Nas X, Billy Ray Cyrus\", \"Artist Followers\": 5488666.0, \"Song ID\": \"2YpeDb67231RjR0MgVLzsG\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.878, \"Energy\": 0.619, \"Loudness\": -5.56, \"Speechiness\": 0.102, \"Acousticness\": 0.0533, \"Liveness\": 0.113, \"Tempo\": 136.041, \"Duration (ms)\": 157067.0, \"Valence\": 0.639, \"Chord\": \"F#/Gb\"}, {\"Index\": 1020, \"Highest Charting Position\": 67, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"The Adventures of Moon Man & Slim Shady (with Eminem)\", \"Streams\": 4639929, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"38iBrrbbXyWaSPkmuDNgjZ\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 67.0, \"Danceability\": 0.88, \"Energy\": 0.787, \"Loudness\": -5.189, \"Speechiness\": 0.118, \"Acousticness\": 0.226, \"Liveness\": 0.12, \"Tempo\": 113.018, \"Duration (ms)\": 264834.0, \"Valence\": 0.588, \"Chord\": \"G#/Ab\"}, {\"Index\": 1021, \"Highest Charting Position\": 25, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"China\", \"Streams\": 4627026, \"Artist\": \"Anuel AA, Daddy Yankee, KAROL G, Ozuna, J Balvin\", \"Artist Followers\": 18306226.0, \"Song ID\": \"2ksOAxtIxY8yElEWw8RhgK\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2019-07-19\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.786, \"Energy\": 0.808, \"Loudness\": -3.702, \"Speechiness\": 0.0882, \"Acousticness\": 0.0846, \"Liveness\": 0.0822, \"Tempo\": 105.027, \"Duration (ms)\": 301714.0, \"Valence\": 0.609, \"Chord\": \"G\"}, {\"Index\": 1022, \"Highest Charting Position\": 29, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Hola - Remix\", \"Streams\": 4617726, \"Artist\": \"Dalex, Lenny Tav\\u00e1rez, Chencho Corleone, Juhn, D\\u00edmelo Flow\", \"Artist Followers\": 3600989.0, \"Song ID\": \"5stPVcRqb4qixbafP9e8lt\", \"Genre\": \"['latin', 'r&b en espanol', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-01\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.654, \"Energy\": 0.672, \"Loudness\": -5.98, \"Speechiness\": 0.311, \"Acousticness\": 0.471, \"Liveness\": 0.0781, \"Tempo\": 181.857, \"Duration (ms)\": 249520.0, \"Valence\": 0.343, \"Chord\": \"C\"}, {\"Index\": 1023, \"Highest Charting Position\": 6, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Ignorantes\", \"Streams\": 4613982, \"Artist\": \"Bad Bunny, Sech\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3wYRLYuO1M88d8woWUIxct\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 74.0, \"Danceability\": 0.85, \"Energy\": 0.536, \"Loudness\": -5.161, \"Speechiness\": 0.0599, \"Acousticness\": 0.267, \"Liveness\": 0.0996, \"Tempo\": 96.029, \"Duration (ms)\": 210607.0, \"Valence\": 0.505, \"Chord\": \"C#/Db\"}, {\"Index\": 1024, \"Highest Charting Position\": 2, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Yummy\", \"Streams\": 4599349, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"41L3O37CECZt3N7ziG2z7l\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-03\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 72.0, \"Danceability\": 0.687, \"Energy\": 0.514, \"Loudness\": -6.612, \"Speechiness\": 0.0897, \"Acousticness\": 0.366, \"Liveness\": 0.116, \"Tempo\": 145.921, \"Duration (ms)\": 210427.0, \"Valence\": 0.494, \"Chord\": \"A\"}, {\"Index\": 1025, \"Highest Charting Position\": 29, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"High Fashion (feat. Mustard)\", \"Streams\": 4592772, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6608815.0, \"Song ID\": \"07KXEDMj78x68D884wgVEm\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 77.0, \"Danceability\": 0.831, \"Energy\": 0.499, \"Loudness\": -8.442, \"Speechiness\": 0.114, \"Acousticness\": 0.269, \"Liveness\": 0.3, \"Tempo\": 97.956, \"Duration (ms)\": 220487.0, \"Valence\": 0.511, \"Chord\": \"B\"}, {\"Index\": 1026, \"Highest Charting Position\": 69, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Like That (feat. Gucci Mane)\", \"Streams\": 4565377, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"4EivmOT13NMpNSfTKn9p4s\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 77.0, \"Danceability\": 0.879, \"Energy\": 0.498, \"Loudness\": -6.027, \"Speechiness\": 0.18, \"Acousticness\": 0.239, \"Liveness\": 0.0967, \"Tempo\": 106.044, \"Duration (ms)\": 163173.0, \"Valence\": 0.405, \"Chord\": \"E\"}, {\"Index\": 1027, \"Highest Charting Position\": 132, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Goodbyes (feat. Young Thug)\", \"Streams\": 4527742, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"0t3ZvGKlmYmVsDzBJAXK8C\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 78.0, \"Danceability\": 0.548, \"Energy\": 0.653, \"Loudness\": -3.875, \"Speechiness\": 0.081, \"Acousticness\": 0.456, \"Liveness\": 0.103, \"Tempo\": 150.068, \"Duration (ms)\": 174853.0, \"Valence\": 0.163, \"Chord\": \"F\"}, {\"Index\": 1028, \"Highest Charting Position\": 23, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"BOP\", \"Streams\": 4496450, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"6Ozh9Ok6h4Oi1wUSLtBseN\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.769, \"Energy\": 0.787, \"Loudness\": -3.909, \"Speechiness\": 0.367, \"Acousticness\": 0.189, \"Liveness\": 0.129, \"Tempo\": 126.77, \"Duration (ms)\": 159715.0, \"Valence\": 0.836, \"Chord\": \"B\"}, {\"Index\": 1029, \"Highest Charting Position\": 21, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Sigues Con El\", \"Streams\": 4485060, \"Artist\": \"D\\u00edmelo Flow, Arcangel, Sech\", \"Artist Followers\": 231580.0, \"Song ID\": \"7sQKy5vlPQllr0k9IjYJv3\", \"Genre\": \"['latin', 'perreo', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.883, \"Energy\": 0.668, \"Loudness\": -2.957, \"Speechiness\": 0.113, \"Acousticness\": 0.11, \"Liveness\": 0.0734, \"Tempo\": 87.972, \"Duration (ms)\": 226533.0, \"Valence\": 0.676, \"Chord\": \"A\"}, {\"Index\": 1030, \"Highest Charting Position\": 78, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Anxiety - Intro\", \"Streams\": 8449557, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"02XcRGWPkvomFvzTamEKHg\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 60.0, \"Danceability\": 0.307, \"Energy\": 0.528, \"Loudness\": -11.337, \"Speechiness\": 0.108, \"Acousticness\": 0.972, \"Liveness\": 0.222, \"Tempo\": 174.795, \"Duration (ms)\": 70395.0, \"Valence\": 0.58, \"Chord\": \"B\"}, {\"Index\": 1031, \"Highest Charting Position\": 112, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Juice WRLD Speaks From Heaven - Outro\", \"Streams\": 6682917, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"1OjiYjgPZyxS0AiXiSnuYI\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 59.0, \"Danceability\": 0.392, \"Energy\": 0.373, \"Loudness\": -14.097, \"Speechiness\": 0.0968, \"Acousticness\": 0.991, \"Liveness\": 0.545, \"Tempo\": 121.678, \"Duration (ms)\": 30583.0, \"Valence\": 0.519, \"Chord\": \"C\"}, {\"Index\": 1032, \"Highest Charting Position\": 113, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"The Man, The Myth, The Legend - Interlude\", \"Streams\": 6640728, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4sjdZEEQvR1sXrRNSuBfbA\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 58.0, \"Danceability\": 0.667, \"Energy\": 0.447, \"Loudness\": -14.625, \"Speechiness\": 0.761, \"Acousticness\": 0.916, \"Liveness\": 0.612, \"Tempo\": 83.534, \"Duration (ms)\": 136545.0, \"Valence\": 0.829, \"Chord\": \"D\"}, {\"Index\": 1033, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Tiefschwarz (feat. Samra)\", \"Streams\": 5867111, \"Artist\": \"Kontra K\", \"Artist Followers\": 1818624.0, \"Song ID\": \"7jMMoHhgq6iwVT5ykyxsJt\", \"Genre\": \"['christlicher rap', 'german hip hop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 62.0, \"Danceability\": 0.751, \"Energy\": 0.783, \"Loudness\": -5.926, \"Speechiness\": 0.22, \"Acousticness\": 0.0715, \"Liveness\": 0.114, \"Tempo\": 94.003, \"Duration (ms)\": 189739.0, \"Valence\": 0.379, \"Chord\": \"G\"}, {\"Index\": 1034, \"Highest Charting Position\": 57, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Wash Us In The Blood\", \"Streams\": 5586085, \"Artist\": \"Kanye West, Travis Scott\", \"Artist Followers\": 14624703.0, \"Song ID\": \"7mEUjhl6aTztdHCrxoTgBG\", \"Genre\": \"['chicago rap', 'rap']\", \"Release Date\": \"2020-06-30\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 64.0, \"Danceability\": 0.67, \"Energy\": 0.847, \"Loudness\": -4.85, \"Speechiness\": 0.409, \"Acousticness\": 0.184, \"Liveness\": 0.304, \"Tempo\": 137.22, \"Duration (ms)\": 189827.0, \"Valence\": 0.381, \"Chord\": \"A#/Bb\"}, {\"Index\": 1035, \"Highest Charting Position\": 53, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Gangstas\", \"Streams\": 5104422, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"1hg3RlqFZXJb5YgRoK9qmF\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 71.0, \"Danceability\": 0.548, \"Energy\": 0.506, \"Loudness\": -7.434, \"Speechiness\": 0.102, \"Acousticness\": 0.203, \"Liveness\": 0.0788, \"Tempo\": 119.987, \"Duration (ms)\": 160000.0, \"Valence\": 0.557, \"Chord\": \"E\"}, {\"Index\": 1036, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Monster\", \"Streams\": 5030481, \"Artist\": \"Red Velvet - IRENE & SEULGI\", \"Artist Followers\": 383695.0, \"Song ID\": \"6c1QaQHdDhtFMfUkhueuXK\", \"Genre\": \"['k-pop']\", \"Release Date\": \"2020-07-06\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 70.0, \"Danceability\": 0.631, \"Energy\": 0.748, \"Loudness\": -2.569, \"Speechiness\": 0.0488, \"Acousticness\": 0.212, \"Liveness\": 0.537, \"Tempo\": 115.665, \"Duration (ms)\": 178413.0, \"Valence\": 0.351, \"Chord\": \"E\"}, {\"Index\": 1037, \"Highest Charting Position\": 139, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"YAYA\", \"Streams\": 4729070, \"Artist\": \"6ix9ine\", \"Artist Followers\": 6514102.0, \"Song ID\": \"6EfBMJQwe2xLgldra6DaYp\", \"Genre\": \"['emo rap', 'rap']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 60.0, \"Danceability\": 0.672, \"Energy\": 0.733, \"Loudness\": -5.377, \"Speechiness\": 0.0566, \"Acousticness\": 0.00289, \"Liveness\": 0.199, \"Tempo\": 105.043, \"Duration (ms)\": 149857.0, \"Valence\": 0.354, \"Chord\": \"B\"}, {\"Index\": 1038, \"Highest Charting Position\": 174, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Narcos\", \"Streams\": 4633313, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"7mcdgAXmb35dakBnfDIv3q\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 68.0, \"Danceability\": 0.614, \"Energy\": 0.746, \"Loudness\": -3.527, \"Speechiness\": 0.196, \"Acousticness\": 0.347, \"Liveness\": 0.0874, \"Tempo\": 168.072, \"Duration (ms)\": 259250.0, \"Valence\": 0.601, \"Chord\": \"A#/Bb\"}, {\"Index\": 1039, \"Highest Charting Position\": 105, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"This City\", \"Streams\": 4597406, \"Artist\": \"Sam Fischer\", \"Artist Followers\": 122883.0, \"Song ID\": \"3H3r2nKWa3Yk5gt8xgmsEt\", \"Genre\": \"['alt z', 'australian pop', 'dance pop', 'indie cafe pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2019-12-11\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 80.0, \"Danceability\": 0.605, \"Energy\": 0.377, \"Loudness\": -6.213, \"Speechiness\": 0.0443, \"Acousticness\": 0.733, \"Liveness\": 0.0808, \"Tempo\": 73.877, \"Duration (ms)\": 194853.0, \"Valence\": 0.519, \"Chord\": \"B\"}, {\"Index\": 1040, \"Highest Charting Position\": 64, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Make It Rain (feat. Rowdy Rebel)\", \"Streams\": 4594248, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"71d7LaAgPcNcUopu3OzmP7\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 62.0, \"Danceability\": 0.5, \"Energy\": 0.767, \"Loudness\": -4.105, \"Speechiness\": 0.403, \"Acousticness\": 0.162, \"Liveness\": 0.385, \"Tempo\": 159.477, \"Duration (ms)\": 202443.0, \"Valence\": 0.58, \"Chord\": \"C#/Db\"}, {\"Index\": 1041, \"Highest Charting Position\": 46, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lalala\", \"Streams\": 4541965, \"Artist\": \"Y2K, bbno$\", \"Artist Followers\": 268766.0, \"Song ID\": \"51Fjme0JiitpyXKuyQiCDo\", \"Genre\": \"['pop rap']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.843, \"Energy\": 0.39, \"Loudness\": -7.899, \"Speechiness\": 0.0846, \"Acousticness\": 0.178, \"Liveness\": 0.137, \"Tempo\": 129.972, \"Duration (ms)\": 160627.0, \"Valence\": 0.495, \"Chord\": \"D\"}, {\"Index\": 1042, \"Highest Charting Position\": 79, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Something Special\", \"Streams\": 4535580, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"5kkaSMcf4BFlhRRICCKZb6\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 72.0, \"Danceability\": 0.739, \"Energy\": 0.616, \"Loudness\": -6.963, \"Speechiness\": 0.0338, \"Acousticness\": 0.252, \"Liveness\": 0.101, \"Tempo\": 91.071, \"Duration (ms)\": 158466.0, \"Valence\": 0.654, \"Chord\": \"G\"}, {\"Index\": 1043, \"Highest Charting Position\": 58, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Aim For The Moon (feat. Quavo)\", \"Streams\": 9011502, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"6O7fPYTsb2mY0PiFt2ymDB\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 67.0, \"Danceability\": 0.713, \"Energy\": 0.605, \"Loudness\": -7.487, \"Speechiness\": 0.107, \"Acousticness\": 0.497, \"Liveness\": 0.115, \"Tempo\": 142.025, \"Duration (ms)\": 175756.0, \"Valence\": 0.432, \"Chord\": \"B\"}, {\"Index\": 1044, \"Highest Charting Position\": 63, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"44 BullDog\", \"Streams\": 8443771, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"7sjFIZ1g5QLJLGja3k592K\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 66.0, \"Danceability\": 0.8, \"Energy\": 0.564, \"Loudness\": -5.817, \"Speechiness\": 0.4, \"Acousticness\": 0.0287, \"Liveness\": 0.112, \"Tempo\": 139.989, \"Duration (ms)\": 150857.0, \"Valence\": 0.318, \"Chord\": \"G#/Ab\"}, {\"Index\": 1045, \"Highest Charting Position\": 88, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Creature (feat. Swae Lee)\", \"Streams\": 7308690, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"3eV2WT9YhfzkxbufnBF8wK\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 66.0, \"Danceability\": 0.794, \"Energy\": 0.717, \"Loudness\": -5.73, \"Speechiness\": 0.251, \"Acousticness\": 0.0511, \"Liveness\": 0.195, \"Tempo\": 141.881, \"Duration (ms)\": 202816.0, \"Valence\": 0.372, \"Chord\": \"G\"}, {\"Index\": 1046, \"Highest Charting Position\": 95, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Yea Yea\", \"Streams\": 7112419, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"0bjgQ24UZGwKikldIyEOgf\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 63.0, \"Danceability\": 0.717, \"Energy\": 0.474, \"Loudness\": -8.383, \"Speechiness\": 0.403, \"Acousticness\": 0.0509, \"Liveness\": 0.139, \"Tempo\": 123.906, \"Duration (ms)\": 185804.0, \"Valence\": 0.448, \"Chord\": \"F\"}, {\"Index\": 1047, \"Highest Charting Position\": 100, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Enjoy Yourself (feat. Karol G)\", \"Streams\": 6620040, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"3NWrHCwvyII4fTx05PN3IO\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 70.0, \"Danceability\": 0.764, \"Energy\": 0.676, \"Loudness\": -6.761, \"Speechiness\": 0.0927, \"Acousticness\": 0.389, \"Liveness\": 0.215, \"Tempo\": 97.02, \"Duration (ms)\": 197938.0, \"Valence\": 0.461, \"Chord\": \"B\"}, {\"Index\": 1048, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Bad Bitch From Tokyo (Intro)\", \"Streams\": 6144736, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"4OGIeHtYhRTJ8iW21UUyZW\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 59.0, \"Danceability\": 0.645, \"Energy\": 0.64, \"Loudness\": -6.871, \"Speechiness\": 0.179, \"Acousticness\": 0.395, \"Liveness\": 0.286, \"Tempo\": 140.248, \"Duration (ms)\": 48000.0, \"Valence\": 0.674, \"Chord\": \"A#/Bb\"}, {\"Index\": 1049, \"Highest Charting Position\": 117, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Snitching (feat. Quavo & Future)\", \"Streams\": 6102253, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"2FhEj9lvEIaJihjFprRrGt\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 59.0, \"Danceability\": 0.944, \"Energy\": 0.579, \"Loudness\": -4.961, \"Speechiness\": 0.191, \"Acousticness\": 0.0381, \"Liveness\": 0.253, \"Tempo\": 135.033, \"Duration (ms)\": 259346.0, \"Valence\": 0.769, \"Chord\": \"G#/Ab\"}, {\"Index\": 1050, \"Highest Charting Position\": 121, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"West Coast Shit (feat. Tyga & Quavo)\", \"Streams\": 5931242, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"1JDhNQ0oOT7XpclZn3aQ8F\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 61.0, \"Danceability\": 0.831, \"Energy\": 0.762, \"Loudness\": -5.656, \"Speechiness\": 0.207, \"Acousticness\": 0.0885, \"Liveness\": 0.107, \"Tempo\": 99.999, \"Duration (ms)\": 192000.0, \"Valence\": 0.495, \"Chord\": \"B\"}, {\"Index\": 1051, \"Highest Charting Position\": 72, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Deep End Freestyle\", \"Streams\": 5280810, \"Artist\": \"Sleepy Hallow, Foushe\\u00e9\", \"Artist Followers\": 411262.0, \"Song ID\": \"2AlYncTpVHKwHb55F9lF6O\", \"Genre\": \"['brooklyn drill', 'nyc rap']\", \"Release Date\": \"2020-06-05\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 72.0, \"Danceability\": 0.868, \"Energy\": 0.479, \"Loudness\": -6.687, \"Speechiness\": 0.445, \"Acousticness\": 0.703, \"Liveness\": 0.102, \"Tempo\": 133.928, \"Duration (ms)\": 115200.0, \"Valence\": 0.776, \"Chord\": \"E\"}, {\"Index\": 1052, \"Highest Charting Position\": 56, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Tommy Lee (feat. Post Malone)\", \"Streams\": 5031845, \"Artist\": \"Tyla Yaweh\", \"Artist Followers\": 359133.0, \"Song ID\": \"5QZKcQDp0tCcvMdyqEciBV\", \"Genre\": \"['cali rap', 'melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 73.0, \"Danceability\": 0.457, \"Energy\": 0.621, \"Loudness\": -5.923, \"Speechiness\": 0.138, \"Acousticness\": 0.218, \"Liveness\": 0.0944, \"Tempo\": 85.359, \"Duration (ms)\": 224638.0, \"Valence\": 0.634, \"Chord\": \"A#/Bb\"}, {\"Index\": 1053, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Tunnel Vision (Outro)\", \"Streams\": 4907751, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"2SxR5RitJdsG6wINvJLBSD\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 60.0, \"Danceability\": 0.718, \"Energy\": 0.66, \"Loudness\": -7.39, \"Speechiness\": 0.325, \"Acousticness\": 0.363, \"Liveness\": 0.159, \"Tempo\": 142.879, \"Duration (ms)\": 132587.0, \"Valence\": 0.659, \"Chord\": \"D\"}, {\"Index\": 1054, \"Highest Charting Position\": 7, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Si Veo a Tu Mam\\u00e1\", \"Streams\": 4638728, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"41wtwzCZkXwpnakmwJ239F\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 80.0, \"Danceability\": 0.9, \"Energy\": 0.603, \"Loudness\": -5.313, \"Speechiness\": 0.0646, \"Acousticness\": 0.402, \"Liveness\": 0.134, \"Tempo\": 129.928, \"Duration (ms)\": 170972.0, \"Valence\": 0.824, \"Chord\": \"D\"}, {\"Index\": 1055, \"Highest Charting Position\": 177, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Prospect (ft. Lil Baby)\", \"Streams\": 4571916, \"Artist\": \"iann dior\", \"Artist Followers\": 1276292.0, \"Song ID\": \"4iHSE5R1U8jf84tRn52xRt\", \"Genre\": \"['melodic rap', 'pop rap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 68.0, \"Danceability\": 0.816, \"Energy\": 0.579, \"Loudness\": -6.097, \"Speechiness\": 0.0867, \"Acousticness\": 0.203, \"Liveness\": 0.127, \"Tempo\": 120.078, \"Duration (ms)\": 226314.0, \"Valence\": 0.43, \"Chord\": \"C#/Db\"}, {\"Index\": 1056, \"Highest Charting Position\": 55, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"No Me Conoce - Remix\", \"Streams\": 4501188, \"Artist\": \"Jhay Cortez, J Balvin, Bad Bunny\", \"Artist Followers\": 2435159.0, \"Song ID\": \"4R8BJggjosTswLxtkw8V7P\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-05-24\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.806, \"Energy\": 0.786, \"Loudness\": -3.831, \"Speechiness\": 0.0741, \"Acousticness\": 0.145, \"Liveness\": 0.0935, \"Tempo\": 91.973, \"Duration (ms)\": 309120.0, \"Valence\": 0.58, \"Chord\": \"A#/Bb\"}, {\"Index\": 1057, \"Highest Charting Position\": 189, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"El Manual\", \"Streams\": 4470597, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"7kOf0qHO4Rcwk6QJifZDRJ\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 67.0, \"Danceability\": 0.843, \"Energy\": 0.845, \"Loudness\": -2.344, \"Speechiness\": 0.0503, \"Acousticness\": 0.35, \"Liveness\": 0.0527, \"Tempo\": 126.989, \"Duration (ms)\": 210624.0, \"Valence\": 0.898, \"Chord\": \"C\"}, {\"Index\": 1058, \"Highest Charting Position\": 181, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Thunder\", \"Streams\": 4468668, \"Artist\": \"Imagine Dragons\", \"Artist Followers\": 35299488.0, \"Song ID\": \"1zB4vmk8tFRmM9UULNzbLB\", \"Genre\": \"['modern rock', 'pop', 'rock']\", \"Release Date\": \"2017-06-23\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-05--2020-06-12\\n2020-02-07--2020-02-14\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.605, \"Energy\": 0.822, \"Loudness\": -4.833, \"Speechiness\": 0.0438, \"Acousticness\": 0.00671, \"Liveness\": 0.147, \"Tempo\": 167.997, \"Duration (ms)\": 187147.0, \"Valence\": 0.288, \"Chord\": \"C\"}, {\"Index\": 1059, \"Highest Charting Position\": 158, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"El Efecto - Remix\", \"Streams\": 4433384, \"Artist\": \"Rauw Alejandro, Chencho Corleone, KEVVO, Bryant Myers, Lyanno, Dalex\", \"Artist Followers\": 6096559.0, \"Song ID\": \"74j34STf8L6uADnTN69ohv\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 73.0, \"Danceability\": 0.771, \"Energy\": 0.769, \"Loudness\": -3.504, \"Speechiness\": 0.0694, \"Acousticness\": 0.18, \"Liveness\": 0.345, \"Tempo\": 167.969, \"Duration (ms)\": 289899.0, \"Valence\": 0.931, \"Chord\": \"C\"}, {\"Index\": 1060, \"Highest Charting Position\": 122, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Better Now\", \"Streams\": 4431571, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"7dt6x5M1jzdTEt8oCbisTK\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2018-04-27\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.68, \"Energy\": 0.578, \"Loudness\": -5.804, \"Speechiness\": 0.04, \"Acousticness\": 0.331, \"Liveness\": 0.135, \"Tempo\": 145.038, \"Duration (ms)\": 231267.0, \"Valence\": 0.341, \"Chord\": \"A#/Bb\"}, {\"Index\": 1061, \"Highest Charting Position\": 185, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Don't Stop Believin'\", \"Streams\": 4394985, \"Artist\": \"Journey\", \"Artist Followers\": 3731820.0, \"Song ID\": \"4bHsxqR3GMrXTxEPLuK5ue\", \"Genre\": \"['album rock', 'classic rock', 'hard rock', 'mellow gold', 'rock', 'soft rock']\", \"Release Date\": \"1981\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-19--2020-06-26\", \"Popularity\": 81.0, \"Danceability\": 0.5, \"Energy\": 0.748, \"Loudness\": -9.072, \"Speechiness\": 0.0363, \"Acousticness\": 0.127, \"Liveness\": 0.447, \"Tempo\": 118.852, \"Duration (ms)\": 250987.0, \"Valence\": 0.514, \"Chord\": \"E\"}, {\"Index\": 1062, \"Highest Charting Position\": 90, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"BLACK PARADE\", \"Streams\": 5474807, \"Artist\": \"Beyonc\\u00e9\", \"Artist Followers\": 28335112.0, \"Song ID\": \"2qzUpSVI4NnPyWxbXwumTj\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'r&b']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 61.0, \"Danceability\": 0.824, \"Energy\": 0.555, \"Loudness\": -5.817, \"Speechiness\": 0.05, \"Acousticness\": 0.00337, \"Liveness\": 0.217, \"Tempo\": 120.002, \"Duration (ms)\": 281273.0, \"Valence\": 0.0611, \"Chord\": \"C#/Db\"}, {\"Index\": 1063, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"XXL\", \"Streams\": 5415994, \"Artist\": \"Miksu / Macloud, Summer Cem, Luciano, Jamule\", \"Artist Followers\": 30683.0, \"Song ID\": \"0p3euGPg5LgFeQGC7bBFuR\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 64.0, \"Danceability\": 0.798, \"Energy\": 0.527, \"Loudness\": -7.671, \"Speechiness\": 0.0447, \"Acousticness\": 0.227, \"Liveness\": 0.108, \"Tempo\": 114.008, \"Duration (ms)\": 166173.0, \"Valence\": 0.548, \"Chord\": \"F\"}, {\"Index\": 1064, \"Highest Charting Position\": 70, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Salt\", \"Streams\": 4874960, \"Artist\": \"Ava Max\", \"Artist Followers\": 1251372.0, \"Song ID\": \"2o2p9xH3bkSDLcp6phIF4J\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 1.0, \"Danceability\": 0.693, \"Energy\": 0.835, \"Loudness\": -3.242, \"Speechiness\": 0.0624, \"Acousticness\": 0.131, \"Liveness\": 0.073, \"Tempo\": 128.052, \"Duration (ms)\": 180283.0, \"Valence\": 0.744, \"Chord\": \"F#/Gb\"}, {\"Index\": 1065, \"Highest Charting Position\": 52, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Daisies\", \"Streams\": 4838067, \"Artist\": \"Katy Perry\", \"Artist Followers\": 18936929.0, \"Song ID\": \"4uqh9bualXNHXXwO2wPorc\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 68.0, \"Danceability\": 0.639, \"Energy\": 0.546, \"Loudness\": -5.382, \"Speechiness\": 0.0407, \"Acousticness\": 0.0837, \"Liveness\": 0.122, \"Tempo\": 122.179, \"Duration (ms)\": 173124.0, \"Valence\": 0.149, \"Chord\": \"C#/Db\"}, {\"Index\": 1066, \"Highest Charting Position\": 142, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Emotionally Scarred\", \"Streams\": 4633237, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"7ge7BHazYbVKi8qyZUX1Bm\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 71.0, \"Danceability\": 0.585, \"Energy\": 0.641, \"Loudness\": -4.269, \"Speechiness\": 0.133, \"Acousticness\": 0.0286, \"Liveness\": 0.316, \"Tempo\": 88.284, \"Duration (ms)\": 197530.0, \"Valence\": 0.266, \"Chord\": \"F#/Gb\"}, {\"Index\": 1067, \"Highest Charting Position\": 32, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Myron\", \"Streams\": 4593309, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"56uXDJRCuoS7abX3SkzHKQ\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 76.0, \"Danceability\": 0.771, \"Energy\": 0.654, \"Loudness\": -6.976, \"Speechiness\": 0.298, \"Acousticness\": 0.055, \"Liveness\": 0.214, \"Tempo\": 155.047, \"Duration (ms)\": 224955.0, \"Valence\": 0.573, \"Chord\": \"G#/Ab\"}, {\"Index\": 1068, \"Highest Charting Position\": 67, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"MORE & MORE\", \"Streams\": 4592745, \"Artist\": \"TWICE\", \"Artist Followers\": 9998991.0, \"Song ID\": \"3omvXShuRPM3zbDpWYqf5g\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-06-01\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 70.0, \"Danceability\": 0.739, \"Energy\": 0.841, \"Loudness\": -4.162, \"Speechiness\": 0.06, \"Acousticness\": 0.0312, \"Liveness\": 0.173, \"Tempo\": 106.99, \"Duration (ms)\": 199653.0, \"Valence\": 0.562, \"Chord\": \"F\"}, {\"Index\": 1069, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Girls in the Hood\", \"Streams\": 4577209, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"6WbTTAGKrQtCQvmc5BuYfh\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 72.0, \"Danceability\": 0.821, \"Energy\": 0.863, \"Loudness\": -3.159, \"Speechiness\": 0.353, \"Acousticness\": 0.00824, \"Liveness\": 0.0377, \"Tempo\": 180.013, \"Duration (ms)\": 154324.0, \"Valence\": 0.874, \"Chord\": \"F#/Gb\"}, {\"Index\": 1070, \"Highest Charting Position\": 169, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Parasite Eve\", \"Streams\": 4545883, \"Artist\": \"Bring Me The Horizon\", \"Artist Followers\": 3912138.0, \"Song ID\": \"5OxclJsdFESni44YlpNpkR\", \"Genre\": \"['melodic metalcore', 'metalcore', 'rock', 'uk metalcore']\", \"Release Date\": \"2020-06-25\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 67.0, \"Danceability\": 0.589, \"Energy\": 0.797, \"Loudness\": -5.464, \"Speechiness\": 0.15, \"Acousticness\": 0.0289, \"Liveness\": 0.383, \"Tempo\": 102.489, \"Duration (ms)\": 291813.0, \"Valence\": 0.232, \"Chord\": \"A\"}, {\"Index\": 1071, \"Highest Charting Position\": 78, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Sucker\", \"Streams\": 4543863, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"22vgEDb5hykfaTwLuskFGD\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-06-07\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.842, \"Energy\": 0.734, \"Loudness\": -5.065, \"Speechiness\": 0.0588, \"Acousticness\": 0.0427, \"Liveness\": 0.106, \"Tempo\": 137.958, \"Duration (ms)\": 181027.0, \"Valence\": 0.952, \"Chord\": \"C#/Db\"}, {\"Index\": 1072, \"Highest Charting Position\": 147, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"I Like Me Better\", \"Streams\": 4430642, \"Artist\": \"Lauv\", \"Artist Followers\": 4442273.0, \"Song ID\": \"2P91MQbaiQOfbiz9VqhqKQ\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-05-31\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.752, \"Energy\": 0.505, \"Loudness\": -7.621, \"Speechiness\": 0.253, \"Acousticness\": 0.535, \"Liveness\": 0.104, \"Tempo\": 91.97, \"Duration (ms)\": 197437.0, \"Valence\": 0.419, \"Chord\": \"A\"}, {\"Index\": 1073, \"Highest Charting Position\": 116, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"High Hopes\", \"Streams\": 4426791, \"Artist\": \"Panic! At The Disco\", \"Artist Followers\": 10850424.0, \"Song ID\": \"1rqqCSm0Qe4I9rUvWncaom\", \"Genre\": \"['modern rock']\", \"Release Date\": \"2018-06-22\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.579, \"Energy\": 0.904, \"Loudness\": -2.729, \"Speechiness\": 0.0618, \"Acousticness\": 0.193, \"Liveness\": 0.064, \"Tempo\": 82.014, \"Duration (ms)\": 190947.0, \"Valence\": 0.681, \"Chord\": \"F\"}, {\"Index\": 1074, \"Highest Charting Position\": 88, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Money In The Grave (Drake ft. Rick Ross)\", \"Streams\": 4403348, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5ry2OE6R2zPQFDO85XkgRb\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2019-06-15\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.831, \"Energy\": 0.502, \"Loudness\": -4.045, \"Speechiness\": 0.046, \"Acousticness\": 0.101, \"Liveness\": 0.122, \"Tempo\": 100.541, \"Duration (ms)\": 205427.0, \"Valence\": 0.101, \"Chord\": \"A#/Bb\"}, {\"Index\": 1075, \"Highest Charting Position\": 25, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Say So (feat. Nicki Minaj)\", \"Streams\": 4385148, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"11VApNQCWLJdzxWrlmwzUa\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 69.0, \"Danceability\": 0.856, \"Energy\": 0.641, \"Loudness\": -4.64, \"Speechiness\": 0.204, \"Acousticness\": 0.119, \"Liveness\": 0.427, \"Tempo\": 111.004, \"Duration (ms)\": 206221.0, \"Valence\": 0.745, \"Chord\": \"B\"}, {\"Index\": 1076, \"Highest Charting Position\": 189, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Karaoke\", \"Streams\": 4374448, \"Artist\": \"Boomdabash, Alessandra Amoroso\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3n6TeHSnNhDe991nJS2S90\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-10\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 0.0, \"Danceability\": 0.929, \"Energy\": 0.625, \"Loudness\": -5.728, \"Speechiness\": 0.14, \"Acousticness\": 0.289, \"Liveness\": 0.386, \"Tempo\": 122.03, \"Duration (ms)\": 156493.0, \"Valence\": 0.578, \"Chord\": \"C#/Db\"}, {\"Index\": 1077, \"Highest Charting Position\": 36, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Know Your Worth\", \"Streams\": 4374392, \"Artist\": \"Khalid, Disclosure\", \"Artist Followers\": 14190858.0, \"Song ID\": \"0TrPqhAMoaKUFLR7iYDokf\", \"Genre\": \"['pop']\", \"Release Date\": \"2020-02-04\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 76.0, \"Danceability\": 0.79, \"Energy\": 0.694, \"Loudness\": -7.726, \"Speechiness\": 0.0708, \"Acousticness\": 0.145, \"Liveness\": 0.281, \"Tempo\": 103.007, \"Duration (ms)\": 181436.0, \"Valence\": 0.508, \"Chord\": \"A\"}, {\"Index\": 1078, \"Highest Charting Position\": 26, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"No Idea\", \"Streams\": 4369849, \"Artist\": \"Don Toliver\", \"Artist Followers\": 1606884.0, \"Song ID\": \"7AzlLxHn24DxjgQX73F9fU\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.652, \"Energy\": 0.631, \"Loudness\": -5.718, \"Speechiness\": 0.0893, \"Acousticness\": 0.524, \"Liveness\": 0.165, \"Tempo\": 127.998, \"Duration (ms)\": 154424.0, \"Valence\": 0.35, \"Chord\": \"F#/Gb\"}, {\"Index\": 1079, \"Highest Charting Position\": 145, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Airwaves\", \"Streams\": 4352767, \"Artist\": \"Pashanim\", \"Artist Followers\": 208926.0, \"Song ID\": \"5CqkgDH8QZjSqqI3HmYxDD\", \"Genre\": \"['german alternative rap', 'german drill', 'german hip hop', 'german trap']\", \"Release Date\": \"2020-05-14\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 71.0, \"Danceability\": 0.885, \"Energy\": 0.578, \"Loudness\": -7.416, \"Speechiness\": 0.0783, \"Acousticness\": 0.0739, \"Liveness\": 0.102, \"Tempo\": 131.999, \"Duration (ms)\": 178933.0, \"Valence\": 0.388, \"Chord\": \"F\"}, {\"Index\": 1080, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Kill This Love\", \"Streams\": 4341050, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"6hvczQ05jc1yGlp9zhb95V\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2019-04-05\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 76.0, \"Danceability\": 0.763, \"Energy\": 0.835, \"Loudness\": -5.234, \"Speechiness\": 0.191, \"Acousticness\": 0.323, \"Liveness\": 0.225, \"Tempo\": 131.875, \"Duration (ms)\": 191050.0, \"Valence\": 0.645, \"Chord\": \"D\"}, {\"Index\": 1081, \"Highest Charting Position\": 68, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lights Up\", \"Streams\": 4325411, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16127908.0, \"Song ID\": \"4jAIqgrPjKLTY9Gbez25Qb\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.575, \"Energy\": 0.621, \"Loudness\": -8.165, \"Speechiness\": 0.032, \"Acousticness\": 0.0392, \"Liveness\": 0.141, \"Tempo\": 101.987, \"Duration (ms)\": 172213.0, \"Valence\": 0.27, \"Chord\": \"A#/Bb\"}, {\"Index\": 1082, \"Highest Charting Position\": 14, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Lose You To Love Me\", \"Streams\": 4322088, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4l0Mvzj72xxOpRrp6h8nHi\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.488, \"Energy\": 0.343, \"Loudness\": -8.985, \"Speechiness\": 0.0436, \"Acousticness\": 0.556, \"Liveness\": 0.21, \"Tempo\": 102.819, \"Duration (ms)\": 206459.0, \"Valence\": 0.0978, \"Chord\": \"E\"}, {\"Index\": 1083, \"Highest Charting Position\": 94, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Girls Like You (feat. Cardi B)\", \"Streams\": 4318772, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32279979.0, \"Song ID\": \"6V1bu6o1Yo5ZXnsCJU8Ovk\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2018-06-15\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.851, \"Energy\": 0.541, \"Loudness\": -6.825, \"Speechiness\": 0.0505, \"Acousticness\": 0.568, \"Liveness\": 0.13, \"Tempo\": 124.959, \"Duration (ms)\": 235545.0, \"Valence\": 0.448, \"Chord\": \"C\"}, {\"Index\": 1084, \"Highest Charting Position\": 47, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"PA' ROMPERLA\", \"Streams\": 4312675, \"Artist\": \"Bad Bunny, Don Omar\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5XqCz18k96K8tx6DAYM97i\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 72.0, \"Danceability\": 0.772, \"Energy\": 0.83, \"Loudness\": -5.019, \"Speechiness\": 0.0599, \"Acousticness\": 0.016, \"Liveness\": 0.0843, \"Tempo\": 94.011, \"Duration (ms)\": 194200.0, \"Valence\": 0.697, \"Chord\": \"G\"}, {\"Index\": 1085, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"VACATION\", \"Streams\": 6883487, \"Artist\": \"Tyga\", \"Artist Followers\": 6298789.0, \"Song ID\": \"6q2uIyLqASSpv2SIv2ehWK\", \"Genre\": \"['dance pop', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 51.0, \"Danceability\": 0.821, \"Energy\": 0.61, \"Loudness\": -6.22, \"Speechiness\": 0.0959, \"Acousticness\": 0.0247, \"Liveness\": 0.185, \"Tempo\": 110.973, \"Duration (ms)\": 192936.0, \"Valence\": 0.47, \"Chord\": \"C#/Db\"}, {\"Index\": 1086, \"Highest Charting Position\": 86, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Big Body Benz\", \"Streams\": 6707101, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"2WOJ7D52Ng3myrKlEf4Azj\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-06-18\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 61.0, \"Danceability\": 0.884, \"Energy\": 0.451, \"Loudness\": -8.969, \"Speechiness\": 0.393, \"Acousticness\": 0.0731, \"Liveness\": 0.268, \"Tempo\": 94.024, \"Duration (ms)\": 148284.0, \"Valence\": 0.311, \"Chord\": \"A\"}, {\"Index\": 1087, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Ich wei\\u00df nicht mal wie sie hei\\u00dft\", \"Streams\": 5827600, \"Artist\": \"Capital Bra, Bozza\", \"Artist Followers\": 4093115.0, \"Song ID\": \"4KfL3Ne8bc9bC2PUB8QGwA\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-06-18\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 57.0, \"Danceability\": 0.498, \"Energy\": 0.836, \"Loudness\": -3.905, \"Speechiness\": 0.184, \"Acousticness\": 0.525, \"Liveness\": 0.0994, \"Tempo\": 199.846, \"Duration (ms)\": 168750.0, \"Valence\": 0.609, \"Chord\": \"A#/Bb\"}, {\"Index\": 1088, \"Highest Charting Position\": 101, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"F\\u00fatbol & Rumba (feat. Enrique Iglesias)\", \"Streams\": 5124116, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"2hDe0Ls5mVqs1XJqv7sbcM\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 67.0, \"Danceability\": 0.735, \"Energy\": 0.916, \"Loudness\": -2.082, \"Speechiness\": 0.117, \"Acousticness\": 0.397, \"Liveness\": 0.0918, \"Tempo\": 167.994, \"Duration (ms)\": 221429.0, \"Valence\": 0.691, \"Chord\": \"D\"}, {\"Index\": 1089, \"Highest Charting Position\": 131, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Bleed\", \"Streams\": 5095478, \"Artist\": \"A Boogie Wit da Hoodie\", \"Artist Followers\": 5865895.0, \"Song ID\": \"5XzombolzpiaOSTdj1W0VS\", \"Genre\": \"['melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 61.0, \"Danceability\": 0.698, \"Energy\": 0.572, \"Loudness\": -7.735, \"Speechiness\": 0.198, \"Acousticness\": 0.135, \"Liveness\": 0.154, \"Tempo\": 71.446, \"Duration (ms)\": 176959.0, \"Valence\": 0.391, \"Chord\": \"D\"}, {\"Index\": 1090, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Snow On Tha Bluff\", \"Streams\": 5060764, \"Artist\": \"J. Cole\", \"Artist Followers\": 14103694.0, \"Song ID\": \"1oOEkBNp4zWnkD7nWjJdog\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2020-06-16\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 66.0, \"Danceability\": 0.586, \"Energy\": 0.512, \"Loudness\": -8.819, \"Speechiness\": 0.0668, \"Acousticness\": 0.723, \"Liveness\": 0.119, \"Tempo\": 75.857, \"Duration (ms)\": 235480.0, \"Valence\": 0.235, \"Chord\": \"G#/Ab\"}, {\"Index\": 1091, \"Highest Charting Position\": 113, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Djomb - Bien ou quoi\", \"Streams\": 4924714, \"Artist\": \"Bosh\", \"Artist Followers\": 300500.0, \"Song ID\": \"0KBwGCY9RYD9t2zjeW4h48\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 64.0, \"Danceability\": 0.945, \"Energy\": 0.676, \"Loudness\": -6.6, \"Speechiness\": 0.207, \"Acousticness\": 0.172, \"Liveness\": 0.322, \"Tempo\": 123.109, \"Duration (ms)\": 141893.0, \"Valence\": 0.631, \"Chord\": \"C#/Db\"}, {\"Index\": 1092, \"Highest Charting Position\": 84, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"In Your Eyes (feat. Alida)\", \"Streams\": 4654587, \"Artist\": \"Alida, Robin Schulz\", \"Artist Followers\": 2786366.0, \"Song ID\": \"61ZM92T2zaXIVsqncThQzC\", \"Genre\": \"['dance pop', 'deep euro house', 'deep house', 'edm', 'german dance', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 71.0, \"Danceability\": 0.57, \"Energy\": 0.672, \"Loudness\": -5.888, \"Speechiness\": 0.0716, \"Acousticness\": 0.172, \"Liveness\": 0.0768, \"Tempo\": 120.018, \"Duration (ms)\": 208222.0, \"Valence\": 0.461, \"Chord\": \"G#/Ab\"}, {\"Index\": 1093, \"Highest Charting Position\": 13, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Stupid Love\", \"Streams\": 4609858, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 1251372.0, \"Song ID\": \"1zPwSOUc5MPtPg8EgXAGKU\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-08\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 0.0, \"Danceability\": 0.68, \"Energy\": 0.825, \"Loudness\": -4.296, \"Speechiness\": 0.0702, \"Acousticness\": 0.00173, \"Liveness\": 0.27, \"Tempo\": 117.987, \"Duration (ms)\": 193533.0, \"Valence\": 0.784, \"Chord\": \"G#/Ab\"}, {\"Index\": 1094, \"Highest Charting Position\": 93, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Shotta Flow 5\", \"Streams\": 4513982, \"Artist\": \"NLE Choppa\", \"Artist Followers\": 3372385.0, \"Song ID\": \"1orjH4IkSH9VrWmRCToKV8\", \"Genre\": \"['memphis hip hop']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 62.0, \"Danceability\": 0.806, \"Energy\": 0.749, \"Loudness\": -5.268, \"Speechiness\": 0.328, \"Acousticness\": 0.0838, \"Liveness\": 0.0621, \"Tempo\": 140.032, \"Duration (ms)\": 145167.0, \"Valence\": 0.77, \"Chord\": \"C#/Db\"}, {\"Index\": 1095, \"Highest Charting Position\": 145, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"IDK You Yet\", \"Streams\": 4473413, \"Artist\": \"Alexander 23\", \"Artist Followers\": 207170.0, \"Song ID\": \"0j1Ia2lQWrcXrQZI4AdJlk\", \"Genre\": \"['alt z', 'indie cafe pop', 'pop', 'post-teen pop', 'social media pop']\", \"Release Date\": \"2020-06-23\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 79.0, \"Danceability\": 0.648, \"Energy\": 0.308, \"Loudness\": -11.729, \"Speechiness\": 0.04, \"Acousticness\": 0.886, \"Liveness\": 0.124, \"Tempo\": 76.997, \"Duration (ms)\": 184638.0, \"Valence\": 0.198, \"Chord\": \"C#/Db\"}, {\"Index\": 1096, \"Highest Charting Position\": 75, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Piece Of Your Heart\", \"Streams\": 4422905, \"Artist\": \"MEDUZA, Goodboys\", \"Artist Followers\": 441714.0, \"Song ID\": \"1DFD5Fotzgn6yYXkYsKiGs\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop house', 'tropical house']\", \"Release Date\": \"2019-02-01\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.677, \"Energy\": 0.744, \"Loudness\": -6.806, \"Speechiness\": 0.0295, \"Acousticness\": 0.0404, \"Liveness\": 0.074, \"Tempo\": 124.08, \"Duration (ms)\": 152913.0, \"Valence\": 0.631, \"Chord\": \"A#/Bb\"}, {\"Index\": 1097, \"Highest Charting Position\": 129, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Na Raba Toma Tap\\u00e3o\", \"Streams\": 4396629, \"Artist\": \"Niack\", \"Artist Followers\": 352402.0, \"Song ID\": \"0AGS6ZRgzobrazmCi6pYMe\", \"Genre\": \"['funk carioca']\", \"Release Date\": \"2020-06-06\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 61.0, \"Danceability\": 0.962, \"Energy\": 0.787, \"Loudness\": 1.509, \"Speechiness\": 0.0554, \"Acousticness\": 0.666, \"Liveness\": 0.176, \"Tempo\": 130.003, \"Duration (ms)\": 165231.0, \"Valence\": 0.968, \"Chord\": \"D#/Eb\"}, {\"Index\": 1098, \"Highest Charting Position\": 14, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"La Santa\", \"Streams\": 4384527, \"Artist\": \"Bad Bunny, Daddy Yankee\", \"Artist Followers\": 36177712.0, \"Song ID\": \"69vlMrzHwATKzupwNcUPyK\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 79.0, \"Danceability\": 0.744, \"Energy\": 0.868, \"Loudness\": -4.524, \"Speechiness\": 0.047, \"Acousticness\": 0.0326, \"Liveness\": 0.0822, \"Tempo\": 93.037, \"Duration (ms)\": 206420.0, \"Valence\": 0.586, \"Chord\": \"C#/Db\"}, {\"Index\": 1099, \"Highest Charting Position\": 125, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Make You Mine\", \"Streams\": 4356213, \"Artist\": \"PUBLIC\", \"Artist Followers\": 165504.0, \"Song ID\": \"5iFwAOB2TFkPJk8sMlxP8g\", \"Genre\": \"['indie rockism']\", \"Release Date\": \"2019-08-09\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 77.0, \"Danceability\": 0.606, \"Energy\": 0.799, \"Loudness\": -4.452, \"Speechiness\": 0.0261, \"Acousticness\": 0.0128, \"Liveness\": 0.15, \"Tempo\": 103.014, \"Duration (ms)\": 232907.0, \"Valence\": 0.638, \"Chord\": \"A\"}, {\"Index\": 1100, \"Highest Charting Position\": 76, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"ROCKSTAR (feat. Roddy Ricch) - BLM REMIX\", \"Streams\": 7353153, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"4Aykm3xrOFSHrAnv80KUhh\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 62.0, \"Danceability\": 0.747, \"Energy\": 0.689, \"Loudness\": -7.246, \"Speechiness\": 0.242, \"Acousticness\": 0.197, \"Liveness\": 0.0884, \"Tempo\": 89.901, \"Duration (ms)\": 204547.0, \"Valence\": 0.75, \"Chord\": \"B\"}, {\"Index\": 1101, \"Highest Charting Position\": 97, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Make It Rain\", \"Streams\": 6042929, \"Artist\": \"Pop Smoke, Rowdy Rebel\", \"Artist Followers\": 6852509.0, \"Song ID\": \"4TgHt7vKCimpywaiKfl0uj\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 64.0, \"Danceability\": 0.54, \"Energy\": 0.77, \"Loudness\": -3.981, \"Speechiness\": 0.389, \"Acousticness\": 0.194, \"Liveness\": 0.372, \"Tempo\": 159.494, \"Duration (ms)\": 204000.0, \"Valence\": 0.565, \"Chord\": \"C#/Db\"}, {\"Index\": 1102, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"M' Manc (con Geolier & Sfera Ebbasta)\", \"Streams\": 5171235, \"Artist\": \"Shablo\", \"Artist Followers\": 40045.0, \"Song ID\": \"0MLu1cFYL4ikdRTdasCQT9\", \"Genre\": \"['italian hip hop']\", \"Release Date\": \"2020-06-11\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 66.0, \"Danceability\": 0.703, \"Energy\": 0.704, \"Loudness\": -6.117, \"Speechiness\": 0.0641, \"Acousticness\": 0.048, \"Liveness\": 0.41, \"Tempo\": 139.933, \"Duration (ms)\": 180000.0, \"Valence\": 0.725, \"Chord\": \"F#/Gb\"}, {\"Index\": 1103, \"Highest Charting Position\": 143, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Emotions 2.0\", \"Streams\": 5113459, \"Artist\": \"Ufo361, C\\u00c9LINE\", \"Artist Followers\": 1700759.0, \"Song ID\": \"3yZCjDTxzZxx1kll1sRjGc\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 65.0, \"Danceability\": 0.788, \"Energy\": 0.491, \"Loudness\": -9.884, \"Speechiness\": 0.109, \"Acousticness\": 0.386, \"Liveness\": 0.107, \"Tempo\": 98.543, \"Duration (ms)\": 146028.0, \"Valence\": 0.271, \"Chord\": \"G#/Ab\"}, {\"Index\": 1104, \"Highest Charting Position\": 21, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"P2\", \"Streams\": 4769996, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"3kW4z2pIj5VY5fLjBrMRL5\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 73.0, \"Danceability\": 0.775, \"Energy\": 0.72, \"Loudness\": -5.353, \"Speechiness\": 0.193, \"Acousticness\": 0.0236, \"Liveness\": 0.114, \"Tempo\": 155.086, \"Duration (ms)\": 234627.0, \"Valence\": 0.49, \"Chord\": \"B\"}, {\"Index\": 1105, \"Highest Charting Position\": 79, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Selfish\", \"Streams\": 4754830, \"Artist\": \"Madison Beer\", \"Artist Followers\": 3370013.0, \"Song ID\": \"4PV0uE5pZSh44E3NqNNDEH\", \"Genre\": \"['alt z', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 70.0, \"Danceability\": 0.375, \"Energy\": 0.461, \"Loudness\": -6.202, \"Speechiness\": 0.0279, \"Acousticness\": 0.627, \"Liveness\": 0.386, \"Tempo\": 75.217, \"Duration (ms)\": 223270.0, \"Valence\": 0.233, \"Chord\": \"A\"}, {\"Index\": 1106, \"Highest Charting Position\": 154, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Surrender\", \"Streams\": 4627942, \"Artist\": \"Natalie Taylor\", \"Artist Followers\": 120208.0, \"Song ID\": \"0ecC8p17cDNlxHXkuYqeR6\", \"Genre\": \"[]\", \"Release Date\": \"2019-10-29\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 76.0, \"Danceability\": 0.39, \"Energy\": 0.448, \"Loudness\": -8.57, \"Speechiness\": 0.0276, \"Acousticness\": 0.8, \"Liveness\": 0.107, \"Tempo\": 144.89, \"Duration (ms)\": 183103.0, \"Valence\": 0.077, \"Chord\": \"F\"}, {\"Index\": 1107, \"Highest Charting Position\": 86, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Turks (with Gunna & ft. Travis Scott)\", \"Streams\": 4623279, \"Artist\": \"NAV\", \"Artist Followers\": 2613211.0, \"Song ID\": \"7IMwEtpAiJanqF6vQteZN2\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'hip hop', 'melodic rap', 'pop rap', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 67.0, \"Danceability\": 0.894, \"Energy\": 0.618, \"Loudness\": -4.356, \"Speechiness\": 0.129, \"Acousticness\": 0.0808, \"Liveness\": 0.558, \"Tempo\": 119.1, \"Duration (ms)\": 161320.0, \"Valence\": 0.379, \"Chord\": \"G\"}, {\"Index\": 1108, \"Highest Charting Position\": 48, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"BYE ME FUI\", \"Streams\": 4567732, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0FktnzDqjClqU6iqOZVEs2\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 72.0, \"Danceability\": 0.712, \"Energy\": 0.599, \"Loudness\": -6.342, \"Speechiness\": 0.112, \"Acousticness\": 0.412, \"Liveness\": 0.103, \"Tempo\": 179.788, \"Duration (ms)\": 178000.0, \"Valence\": 0.588, \"Chord\": \"F\"}, {\"Index\": 1109, \"Highest Charting Position\": 15, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Vete\", \"Streams\": 4486408, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5DxXgozhkPLgrbKFY91w0c\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-21\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.886, \"Energy\": 0.672, \"Loudness\": -4.394, \"Speechiness\": 0.188, \"Acousticness\": 0.0363, \"Liveness\": 0.101, \"Tempo\": 91.976, \"Duration (ms)\": 192024.0, \"Valence\": 0.526, \"Chord\": \"C#/Db\"}, {\"Index\": 1110, \"Highest Charting Position\": 43, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Like It Is\", \"Streams\": 4463865, \"Artist\": \"Kygo, Zara Larsson, Tyga\", \"Artist Followers\": 7593792.0, \"Song ID\": \"3frUvGrmGcay91lvFbOgsN\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 68.0, \"Danceability\": 0.794, \"Energy\": 0.728, \"Loudness\": -6.759, \"Speechiness\": 0.114, \"Acousticness\": 0.121, \"Liveness\": 0.227, \"Tempo\": 105.024, \"Duration (ms)\": 183067.0, \"Valence\": 0.36, \"Chord\": \"C#/Db\"}, {\"Index\": 1111, \"Highest Charting Position\": 15, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"My Oh My (feat. DaBaby)\", \"Streams\": 4413457, \"Artist\": \"Camila Cabello\", \"Artist Followers\": 22698747.0, \"Song ID\": \"3yOlyBJuViE2YSGn3nVE1K\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.724, \"Energy\": 0.491, \"Loudness\": -6.024, \"Speechiness\": 0.0296, \"Acousticness\": 0.018, \"Liveness\": 0.0887, \"Tempo\": 105.046, \"Duration (ms)\": 170746.0, \"Valence\": 0.383, \"Chord\": \"G#/Ab\"}, {\"Index\": 1112, \"Highest Charting Position\": 161, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Let Me Down Slowly\", \"Streams\": 4393932, \"Artist\": \"Alec Benjamin\", \"Artist Followers\": 2808285.0, \"Song ID\": \"2qxmye6gAegTMjLKEBoR3d\", \"Genre\": \"['alt z', 'electropop', 'pop']\", \"Release Date\": \"2018-11-16\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.652, \"Energy\": 0.557, \"Loudness\": -5.714, \"Speechiness\": 0.0318, \"Acousticness\": 0.74, \"Liveness\": 0.124, \"Tempo\": 150.073, \"Duration (ms)\": 169354.0, \"Valence\": 0.483, \"Chord\": \"C#/Db\"}, {\"Index\": 1113, \"Highest Charting Position\": 22, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"BELIEVE IT\", \"Streams\": 4361970, \"Artist\": \"PARTYNEXTDOOR, Rihanna\", \"Artist Followers\": 3129968.0, \"Song ID\": \"4HDCLYli2SUdkq9OjmvhSD\", \"Genre\": \"['pop', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap', 'urban contemporary']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 74.0, \"Danceability\": 0.43, \"Energy\": 0.7, \"Loudness\": -5.35, \"Speechiness\": 0.264, \"Acousticness\": 0.0902, \"Liveness\": 0.216, \"Tempo\": 158.373, \"Duration (ms)\": 183219.0, \"Valence\": 0.731, \"Chord\": \"F#/Gb\"}, {\"Index\": 1114, \"Highest Charting Position\": 86, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Boot\", \"Streams\": 6375562, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"12KENAKQY5JvAsRURN7TzB\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2020-06-05--2020-06-12\", \"Popularity\": 54.0, \"Danceability\": 0.534, \"Energy\": 0.565, \"Loudness\": -7.546, \"Speechiness\": 0.307, \"Acousticness\": 0.0627, \"Liveness\": 0.112, \"Tempo\": 194.034, \"Duration (ms)\": 193360.0, \"Valence\": 0.529, \"Chord\": \"G#/Ab\"}, {\"Index\": 1115, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Riot\", \"Streams\": 5163633, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"4aOOExMBUyxKnEYb39SrTg\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2020-06-01\", \"Weeks Charted\": \"2020-06-05--2020-06-12\", \"Popularity\": 70.0, \"Danceability\": 0.509, \"Energy\": 0.542, \"Loudness\": -8.027, \"Speechiness\": 0.442, \"Acousticness\": 0.019, \"Liveness\": 0.23, \"Tempo\": 97.767, \"Duration (ms)\": 78681.0, \"Valence\": 0.151, \"Chord\": \"D#/Eb\"}, {\"Index\": 1116, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"VALLA NEIN (feat. Luciano)\", \"Streams\": 5029858, \"Artist\": \"KC Rebell, Summer Cem\", \"Artist Followers\": 1101597.0, \"Song ID\": \"2rxxXYtTIFKyrhJpofeoIX\", \"Genre\": \"['german drill', 'german hip hop']\", \"Release Date\": \"2020-06-05\", \"Weeks Charted\": \"2020-06-05--2020-06-12\", \"Popularity\": 55.0, \"Danceability\": 0.761, \"Energy\": 0.657, \"Loudness\": -7.246, \"Speechiness\": 0.138, \"Acousticness\": 0.114, \"Liveness\": 0.356, \"Tempo\": 135.909, \"Duration (ms)\": 182040.0, \"Valence\": 0.589, \"Chord\": \"A#/Bb\"}, {\"Index\": 1117, \"Highest Charting Position\": 27, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"I\\u2019m Ready (with Demi Lovato)\", \"Streams\": 4764355, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"1fipvP2zmef6vN2IwXfJhY\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-04-16\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 68.0, \"Danceability\": 0.501, \"Energy\": 0.674, \"Loudness\": -6.363, \"Speechiness\": 0.0408, \"Acousticness\": 0.00346, \"Liveness\": 0.282, \"Tempo\": 155.051, \"Duration (ms)\": 200838.0, \"Valence\": 0.152, \"Chord\": \"F\"}, {\"Index\": 1118, \"Highest Charting Position\": 63, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"This Is America\", \"Streams\": 4727415, \"Artist\": \"Childish Gambino\", \"Artist Followers\": 8099554.0, \"Song ID\": \"0b9oOr2ZgvyQu88wzixux9\", \"Genre\": \"['atl hip hop', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2018-05-06\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 71.0, \"Danceability\": 0.854, \"Energy\": 0.463, \"Loudness\": -6.159, \"Speechiness\": 0.137, \"Acousticness\": 0.117, \"Liveness\": 0.354, \"Tempo\": 120.024, \"Duration (ms)\": 225773.0, \"Valence\": 0.549, \"Chord\": \"F\"}, {\"Index\": 1119, \"Highest Charting Position\": 33, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Fantasias\", \"Streams\": 4432324, \"Artist\": \"Rauw Alejandro, Farruko\", \"Artist Followers\": 6096559.0, \"Song ID\": \"6mAN61JH0dzyZpWslS11jy\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2019-08-29\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.879, \"Energy\": 0.703, \"Loudness\": -4.219, \"Speechiness\": 0.0701, \"Acousticness\": 0.143, \"Liveness\": 0.0569, \"Tempo\": 94.004, \"Duration (ms)\": 199711.0, \"Valence\": 0.788, \"Chord\": \"C#/Db\"}, {\"Index\": 1120, \"Highest Charting Position\": 60, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"BAD CON NICKY\", \"Streams\": 4432210, \"Artist\": \"Bad Bunny, Nicky Jam\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5bmSver2b3ZXyuyLKtgnFI\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 71.0, \"Danceability\": 0.59, \"Energy\": 0.729, \"Loudness\": -4.95, \"Speechiness\": 0.0893, \"Acousticness\": 0.321, \"Liveness\": 0.659, \"Tempo\": 93.094, \"Duration (ms)\": 202240.0, \"Valence\": 0.712, \"Chord\": \"G\"}, {\"Index\": 1121, \"Highest Charting Position\": 145, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"If I Can't Have You\", \"Streams\": 4364166, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 33893352.0, \"Song ID\": \"6LsAAHotRLMOHfCsSfYCsz\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2019-05-03\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.692, \"Energy\": 0.809, \"Loudness\": -4.198, \"Speechiness\": 0.0602, \"Acousticness\": 0.524, \"Liveness\": 0.147, \"Tempo\": 123.911, \"Duration (ms)\": 190800.0, \"Valence\": 0.864, \"Chord\": \"D\"}, {\"Index\": 1122, \"Highest Charting Position\": 27, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"What A Man Gotta Do\", \"Streams\": 4360660, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"4wNIkl5XGiAACjFBlDWuSd\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 77.0, \"Danceability\": 0.852, \"Energy\": 0.698, \"Loudness\": -7.206, \"Speechiness\": 0.0629, \"Acousticness\": 0.00839, \"Liveness\": 0.0773, \"Tempo\": 113.039, \"Duration (ms)\": 180645.0, \"Valence\": 0.324, \"Chord\": \"A\"}, {\"Index\": 1123, \"Highest Charting Position\": 50, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Callaita\", \"Streams\": 4350496, \"Artist\": \"Bad Bunny, Tainy\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2TH65lNHgvLxCKXM3apjxI\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-05-31\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.61, \"Energy\": 0.624, \"Loudness\": -4.773, \"Speechiness\": 0.309, \"Acousticness\": 0.6, \"Liveness\": 0.243, \"Tempo\": 176.169, \"Duration (ms)\": 250534.0, \"Valence\": 0.244, \"Chord\": \"D\"}, {\"Index\": 1124, \"Highest Charting Position\": 51, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Solitaires (feat. Travis Scott)\", \"Streams\": 4334669, \"Artist\": \"Future\", \"Artist Followers\": 10491105.0, \"Song ID\": \"4kfeRwpq5KUaqTkgi4TbDF\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 67.0, \"Danceability\": 0.691, \"Energy\": 0.632, \"Loudness\": -7.598, \"Speechiness\": 0.0513, \"Acousticness\": 0.122, \"Liveness\": 0.0646, \"Tempo\": 169.982, \"Duration (ms)\": 205666.0, \"Valence\": 0.488, \"Chord\": \"C#/Db\"}, {\"Index\": 1125, \"Highest Charting Position\": 137, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"XO Tour Llif3\", \"Streams\": 4314080, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7GX5flRQZVHRAGd6B4TmDO\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2017-08-25\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-08--2020-05-15\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 82.0, \"Danceability\": 0.732, \"Energy\": 0.75, \"Loudness\": -6.366, \"Speechiness\": 0.231, \"Acousticness\": 0.00264, \"Liveness\": 0.109, \"Tempo\": 155.096, \"Duration (ms)\": 182707.0, \"Valence\": 0.401, \"Chord\": \"B\"}, {\"Index\": 1126, \"Highest Charting Position\": 189, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"changes\", \"Streams\": 4299334, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"7AFASza1mXqntmGtbxXprO\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2018-03-16\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 81.0, \"Danceability\": 0.669, \"Energy\": 0.308, \"Loudness\": -10.068, \"Speechiness\": 0.029, \"Acousticness\": 0.883, \"Liveness\": 0.0984, \"Tempo\": 64.934, \"Duration (ms)\": 121887.0, \"Valence\": 0.52, \"Chord\": \"B\"}, {\"Index\": 1127, \"Highest Charting Position\": 66, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Suicidal (Remix) [feat. Juice WRLD]\", \"Streams\": 4296154, \"Artist\": \"YNW Melly\", \"Artist Followers\": 6332535.0, \"Song ID\": \"4S2uhQE8L9V6p7rj7SiauJ\", \"Genre\": \"['melodic rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 76.0, \"Danceability\": 0.655, \"Energy\": 0.441, \"Loudness\": -5.245, \"Speechiness\": 0.0629, \"Acousticness\": 0.474, \"Liveness\": 0.099, \"Tempo\": 139.957, \"Duration (ms)\": 225857.0, \"Valence\": 0.273, \"Chord\": \"A\"}, {\"Index\": 1128, \"Highest Charting Position\": 30, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Level of Concern\", \"Streams\": 4252898, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20829526.0, \"Song ID\": \"6xZ4Q2k2ompmDppyeESIY8\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 72.0, \"Danceability\": 0.754, \"Energy\": 0.583, \"Loudness\": -7.34, \"Speechiness\": 0.0432, \"Acousticness\": 0.32, \"Liveness\": 0.144, \"Tempo\": 122.012, \"Duration (ms)\": 220051.0, \"Valence\": 0.77, \"Chord\": \"E\"}, {\"Index\": 1129, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Alice\", \"Streams\": 10342277, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"41A89rj3GoMG6ktN37L7PG\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 64.0, \"Danceability\": 0.723, \"Energy\": 0.88, \"Loudness\": -4.287, \"Speechiness\": 0.038, \"Acousticness\": 0.00334, \"Liveness\": 0.0632, \"Tempo\": 123.036, \"Duration (ms)\": 177600.0, \"Valence\": 0.323, \"Chord\": \"B\"}, {\"Index\": 1130, \"Highest Charting Position\": 58, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Free Woman\", \"Streams\": 9266945, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"4L6ihclQPu1hqP9r3WNJjQ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 63.0, \"Danceability\": 0.731, \"Energy\": 0.927, \"Loudness\": -3.634, \"Speechiness\": 0.0781, \"Acousticness\": 0.0228, \"Liveness\": 0.187, \"Tempo\": 119.006, \"Duration (ms)\": 191467.0, \"Valence\": 0.478, \"Chord\": \"C\"}, {\"Index\": 1131, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Fun Tonight\", \"Streams\": 7907329, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"6hyQVqfHFvsJDjcmj4qrHf\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.645, \"Energy\": 0.923, \"Loudness\": -4.262, \"Speechiness\": 0.0725, \"Acousticness\": 0.364, \"Liveness\": 0.14, \"Tempo\": 117.945, \"Duration (ms)\": 173427.0, \"Valence\": 0.323, \"Chord\": \"B\"}, {\"Index\": 1132, \"Highest Charting Position\": 75, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Sine From Above (with Elton John)\", \"Streams\": 7734309, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"0zzsyWc45eUcSjw4FNHxeN\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 60.0, \"Danceability\": 0.642, \"Energy\": 0.792, \"Loudness\": -5.746, \"Speechiness\": 0.0488, \"Acousticness\": 0.158, \"Liveness\": 0.68, \"Tempo\": 122.965, \"Duration (ms)\": 244880.0, \"Valence\": 0.0903, \"Chord\": \"C\"}, {\"Index\": 1133, \"Highest Charting Position\": 77, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Enigma\", \"Streams\": 7695566, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"7JDbfYUHjDzQPFSDh5lzGs\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 59.0, \"Danceability\": 0.669, \"Energy\": 0.804, \"Loudness\": -4.035, \"Speechiness\": 0.036, \"Acousticness\": 0.0306, \"Liveness\": 0.694, \"Tempo\": 116.001, \"Duration (ms)\": 179760.0, \"Valence\": 0.184, \"Chord\": \"C\"}, {\"Index\": 1134, \"Highest Charting Position\": 79, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Replay\", \"Streams\": 7479618, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"7sKbyYeJnITO1Eh9xd0lKd\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 63.0, \"Danceability\": 0.658, \"Energy\": 0.878, \"Loudness\": -3.875, \"Speechiness\": 0.123, \"Acousticness\": 0.00792, \"Liveness\": 0.944, \"Tempo\": 122.015, \"Duration (ms)\": 186653.0, \"Valence\": 0.683, \"Chord\": \"C#/Db\"}, {\"Index\": 1135, \"Highest Charting Position\": 80, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Plastic Doll\", \"Streams\": 7451452, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"3CidPLqWXqgesJlwYVJZdy\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.743, \"Energy\": 0.853, \"Loudness\": -4.842, \"Speechiness\": 0.04, \"Acousticness\": 0.0019, \"Liveness\": 0.0872, \"Tempo\": 121.028, \"Duration (ms)\": 221667.0, \"Valence\": 0.422, \"Chord\": \"C\"}, {\"Index\": 1136, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Chromatica II\", \"Streams\": 7136521, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"0oQc0F6KUE7QY7k5TU6bic\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.184, \"Energy\": 0.297, \"Loudness\": -14.534, \"Speechiness\": 0.0359, \"Acousticness\": 0.473, \"Liveness\": 0.527, \"Tempo\": 75.824, \"Duration (ms)\": 41867.0, \"Valence\": 0.113, \"Chord\": \"D\"}, {\"Index\": 1137, \"Highest Charting Position\": 91, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Babylon\", \"Streams\": 6996402, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"5DttNeiizFqWUON9hZBqTY\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 61.0, \"Danceability\": 0.698, \"Energy\": 0.799, \"Loudness\": -4.372, \"Speechiness\": 0.0342, \"Acousticness\": 0.0129, \"Liveness\": 0.215, \"Tempo\": 115.957, \"Duration (ms)\": 161733.0, \"Valence\": 0.351, \"Chord\": \"D\"}, {\"Index\": 1138, \"Highest Charting Position\": 93, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Chromatica I\", \"Streams\": 6630385, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"0oQc0F6KUE7QY7k5TU6bic\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.184, \"Energy\": 0.297, \"Loudness\": -14.534, \"Speechiness\": 0.0359, \"Acousticness\": 0.473, \"Liveness\": 0.527, \"Tempo\": 75.824, \"Duration (ms)\": 41867.0, \"Valence\": 0.113, \"Chord\": \"D\"}, {\"Index\": 1139, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"1000 Doves\", \"Streams\": 6069544, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"62hTXlVQacy3pjBW4ntRPl\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.668, \"Energy\": 0.826, \"Loudness\": -4.466, \"Speechiness\": 0.0383, \"Acousticness\": 0.0236, \"Liveness\": 0.474, \"Tempo\": 122.973, \"Duration (ms)\": 215480.0, \"Valence\": 0.388, \"Chord\": \"A\"}, {\"Index\": 1140, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Broken Glass\", \"Streams\": 5867930, \"Artist\": \"Kygo, Kim Petras\", \"Artist Followers\": 7593792.0, \"Song ID\": \"78ldtCaBRJVp2i91B715L0\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 66.0, \"Danceability\": 0.526, \"Energy\": 0.633, \"Loudness\": -7.002, \"Speechiness\": 0.134, \"Acousticness\": 0.372, \"Liveness\": 0.129, \"Tempo\": 171.044, \"Duration (ms)\": 203947.0, \"Valence\": 0.272, \"Chord\": \"G\"}, {\"Index\": 1141, \"Highest Charting Position\": 131, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"In meinem Benz\", \"Streams\": 5494500, \"Artist\": \"AK AUSSERKONTROLLE, Bonez MC\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 1142, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"FLY\", \"Streams\": 4681054, \"Artist\": \"KC Rebell, Summer Cem\", \"Artist Followers\": 1101597.0, \"Song ID\": \"1WoM4mof0Nl1xPtwf6h6ow\", \"Genre\": \"['german drill', 'german hip hop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 59.0, \"Danceability\": 0.835, \"Energy\": 0.596, \"Loudness\": -6.637, \"Speechiness\": 0.297, \"Acousticness\": 0.137, \"Liveness\": 0.164, \"Tempo\": 100.706, \"Duration (ms)\": 174893.0, \"Valence\": 0.897, \"Chord\": \"F\"}, {\"Index\": 1143, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"SKRR\", \"Streams\": 4629320, \"Artist\": \"KALIM, Ufo361\", \"Artist Followers\": 218931.0, \"Song ID\": \"2J0adlQth373uw9y0yqWAz\", \"Genre\": \"['german hip hop', 'german trap', 'german underground rap', 'hamburg hip hop']\", \"Release Date\": \"2020-09-24\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 60.0, \"Danceability\": 0.803, \"Energy\": 0.649, \"Loudness\": -6.599, \"Speechiness\": 0.132, \"Acousticness\": 0.163, \"Liveness\": 0.152, \"Tempo\": 125.038, \"Duration (ms)\": 119040.0, \"Valence\": 0.584, \"Chord\": \"A#/Bb\"}, {\"Index\": 1144, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"T.D (Lil Yachty & Tierra Whack feat. A$AP Rocky & Tyler, The Creator)\", \"Streams\": 4601709, \"Artist\": \"Lil Yachty\", \"Artist Followers\": 7358720.0, \"Song ID\": \"0gO3E51A3fqp0ypJ26QbVP\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap', 'underground hip hop', 'viral rap']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 66.0, \"Danceability\": 0.784, \"Energy\": 0.632, \"Loudness\": -6.083, \"Speechiness\": 0.347, \"Acousticness\": 0.156, \"Liveness\": 0.605, \"Tempo\": 124.603, \"Duration (ms)\": 232839.0, \"Valence\": 0.746, \"Chord\": \"A#/Bb\"}, {\"Index\": 1145, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Oprah's Bank Account (Lil Yachty & DaBaby feat. Drake)\", \"Streams\": 4598294, \"Artist\": \"Lil Yachty\", \"Artist Followers\": 7358720.0, \"Song ID\": \"7wsmIIm0xWmtP7TmACXkJn\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap', 'underground hip hop', 'viral rap']\", \"Release Date\": \"2020-03-09\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 69.0, \"Danceability\": 0.836, \"Energy\": 0.617, \"Loudness\": -4.363, \"Speechiness\": 0.0534, \"Acousticness\": 0.17, \"Liveness\": 0.319, \"Tempo\": 138.066, \"Duration (ms)\": 206702.0, \"Valence\": 0.866, \"Chord\": \"C\"}, {\"Index\": 1146, \"Highest Charting Position\": 78, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Roadrunner\", \"Streams\": 4596162, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"0atjNG0rNW2m6zPaiK4Co7\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 64.0, \"Danceability\": 0.804, \"Energy\": 0.606, \"Loudness\": -9.045, \"Speechiness\": 0.242, \"Acousticness\": 0.137, \"Liveness\": 0.111, \"Tempo\": 99.024, \"Duration (ms)\": 149028.0, \"Valence\": 0.247, \"Chord\": \"G\"}, {\"Index\": 1147, \"Highest Charting Position\": 99, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Freedom\", \"Streams\": 4573723, \"Artist\": \"Kygo, Zak Abel\", \"Artist Followers\": 7593792.0, \"Song ID\": \"5Gj1wG8b12VQdEd3hUuSwo\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-05-29--2020-06-05\\n2020-04-17--2020-04-24\", \"Popularity\": 72.0, \"Danceability\": 0.715, \"Energy\": 0.635, \"Loudness\": -6.591, \"Speechiness\": 0.0791, \"Acousticness\": 0.127, \"Liveness\": 0.0862, \"Tempo\": 112.887, \"Duration (ms)\": 198635.0, \"Valence\": 0.39, \"Chord\": \"G\"}, {\"Index\": 1148, \"Highest Charting Position\": 45, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Fame\", \"Streams\": 4556947, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"3goH7O78TLkV9RhCAyM4AT\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 62.0, \"Danceability\": 0.811, \"Energy\": 0.645, \"Loudness\": -8.008, \"Speechiness\": 0.104, \"Acousticness\": 0.184, \"Liveness\": 0.103, \"Tempo\": 129.967, \"Duration (ms)\": 173761.0, \"Valence\": 0.474, \"Chord\": \"C#/Db\"}, {\"Index\": 1149, \"Highest Charting Position\": 55, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Daechwita\", \"Streams\": 8908179, \"Artist\": \"Agust D\", \"Artist Followers\": 5564366.0, \"Song ID\": \"0H4ugk6rhnXmTl47ayy9O5\", \"Genre\": \"['k-rap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 77.0, \"Danceability\": 0.65, \"Energy\": 0.827, \"Loudness\": -4.014, \"Speechiness\": 0.0599, \"Acousticness\": 0.0229, \"Liveness\": 0.121, \"Tempo\": 144.995, \"Duration (ms)\": 225668.0, \"Valence\": 0.223, \"Chord\": \"G#/Ab\"}, {\"Index\": 1150, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"COOLER THAN A BITCH (feat. Roddy Ricch)\", \"Streams\": 6642144, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"5LHHKZOwV8XW4LJP2C64mw\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 67.0, \"Danceability\": 0.837, \"Energy\": 0.586, \"Loudness\": -8.521, \"Speechiness\": 0.0807, \"Acousticness\": 0.281, \"Liveness\": 0.134, \"Tempo\": 117.066, \"Duration (ms)\": 197000.0, \"Valence\": 0.618, \"Chord\": \"B\"}, {\"Index\": 1151, \"Highest Charting Position\": 90, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"In Your Eyes (with Doja Cat) - Remix\", \"Streams\": 6511008, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"0UnTaVkntyh3vqvLEvbpQx\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-05-21\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 67.0, \"Danceability\": 0.679, \"Energy\": 0.731, \"Loudness\": -5.522, \"Speechiness\": 0.0319, \"Acousticness\": 0.00518, \"Liveness\": 0.0614, \"Tempo\": 99.984, \"Duration (ms)\": 237912.0, \"Valence\": 0.727, \"Chord\": \"G\"}, {\"Index\": 1152, \"Highest Charting Position\": 92, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"WUNNA\", \"Streams\": 6384306, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"0y7Ao3CVJsyKFmqdjutiIF\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 60.0, \"Danceability\": 0.89, \"Energy\": 0.455, \"Loudness\": -9.0, \"Speechiness\": 0.255, \"Acousticness\": 0.0217, \"Liveness\": 0.11, \"Tempo\": 148.009, \"Duration (ms)\": 158240.0, \"Valence\": 0.313, \"Chord\": \"C\"}, {\"Index\": 1153, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Komm Komm\", \"Streams\": 5552890, \"Artist\": \"Capital Bra\", \"Artist Followers\": 4093115.0, \"Song ID\": \"3US6RbELvvrPw3DcvtJmis\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-05-21\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 53.0, \"Danceability\": 0.485, \"Energy\": 0.793, \"Loudness\": -3.836, \"Speechiness\": 0.426, \"Acousticness\": 0.251, \"Liveness\": 0.146, \"Tempo\": 87.629, \"Duration (ms)\": 160667.0, \"Valence\": 0.371, \"Chord\": \"B\"}, {\"Index\": 1154, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"TOP FLOOR (feat. Travis Scott)\", \"Streams\": 5193309, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"4YhJ3a6kBPGJWX4Ek77sDd\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 63.0, \"Danceability\": 0.823, \"Energy\": 0.504, \"Loudness\": -8.65, \"Speechiness\": 0.16, \"Acousticness\": 0.206, \"Liveness\": 0.417, \"Tempo\": 112.985, \"Duration (ms)\": 169907.0, \"Valence\": 0.481, \"Chord\": \"G#/Ab\"}, {\"Index\": 1155, \"Highest Charting Position\": 54, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Goodbyes (Feat. Young Thug)\", \"Streams\": 5134161, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"0t3ZvGKlmYmVsDzBJAXK8C\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.548, \"Energy\": 0.653, \"Loudness\": -3.875, \"Speechiness\": 0.081, \"Acousticness\": 0.456, \"Liveness\": 0.103, \"Tempo\": 150.068, \"Duration (ms)\": 174853.0, \"Valence\": 0.163, \"Chord\": \"F\"}, {\"Index\": 1156, \"Highest Charting Position\": 59, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"CANCI\\u00d3N CON YANDEL\", \"Streams\": 5132247, \"Artist\": \"Yandel, Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3pm4XtcsRIFFtH2UErk62R\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 76.0, \"Danceability\": 0.75, \"Energy\": 0.741, \"Loudness\": -4.43, \"Speechiness\": 0.402, \"Acousticness\": 0.447, \"Liveness\": 0.121, \"Tempo\": 79.968, \"Duration (ms)\": 209180.0, \"Valence\": 0.495, \"Chord\": \"A\"}, {\"Index\": 1157, \"Highest Charting Position\": 92, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"X (with KAROL G)\", \"Streams\": 5018592, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"77fvnWALKJR0ws1VUx09CY\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 70.0, \"Danceability\": 0.715, \"Energy\": 0.827, \"Loudness\": -5.09, \"Speechiness\": 0.0617, \"Acousticness\": 0.0485, \"Liveness\": 0.321, \"Tempo\": 117.977, \"Duration (ms)\": 185277.0, \"Valence\": 0.75, \"Chord\": \"E\"}, {\"Index\": 1158, \"Highest Charting Position\": 56, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"M\\u00c1S DE UNA CITA\", \"Streams\": 4987116, \"Artist\": \"Bad Bunny, Zion & Lennox\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4EJHKSnHENfjOxXWryyNtL\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 67.0, \"Danceability\": 0.865, \"Energy\": 0.5, \"Loudness\": -10.805, \"Speechiness\": 0.0861, \"Acousticness\": 0.0122, \"Liveness\": 0.098, \"Tempo\": 92.976, \"Duration (ms)\": 183520.0, \"Valence\": 0.317, \"Chord\": \"F\"}, {\"Index\": 1159, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Together\", \"Streams\": 4861870, \"Artist\": \"Sia\", \"Artist Followers\": 20528724.0, \"Song ID\": \"5id3Rqn7SPj1LX4FfY4nGz\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'pop']\", \"Release Date\": \"2020-05-20\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 71.0, \"Danceability\": 0.521, \"Energy\": 0.877, \"Loudness\": -5.444, \"Speechiness\": 0.0683, \"Acousticness\": 0.0132, \"Liveness\": 0.0929, \"Tempo\": 180.007, \"Duration (ms)\": 205208.0, \"Valence\": 0.199, \"Chord\": \"G\"}, {\"Index\": 1160, \"Highest Charting Position\": 62, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"eight(Prod.&Feat. SUGA of BTS)\", \"Streams\": 4764954, \"Artist\": \"IU\", \"Artist Followers\": 4939593.0, \"Song ID\": \"0pYacDCZuRhcrwGUA5nTBe\", \"Genre\": \"['k-pop']\", \"Release Date\": \"2020-05-06\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 75.0, \"Danceability\": 0.676, \"Energy\": 0.869, \"Loudness\": -1.573, \"Speechiness\": 0.0423, \"Acousticness\": 0.115, \"Liveness\": 0.132, \"Tempo\": 120.029, \"Duration (ms)\": 167573.0, \"Valence\": 0.594, \"Chord\": \"C#/Db\"}, {\"Index\": 1161, \"Highest Charting Position\": 16, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"You should be sad\", \"Streams\": 4761908, \"Artist\": \"Halsey\", \"Artist Followers\": 15663384.0, \"Song ID\": \"7lidXGPXPYLNThITAOTlkK\", \"Genre\": \"['dance pop', 'electropop', 'etherpop', 'indie poptimism', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 76.0, \"Danceability\": 0.591, \"Energy\": 0.585, \"Loudness\": -6.35, \"Speechiness\": 0.0277, \"Acousticness\": 0.143, \"Liveness\": 0.109, \"Tempo\": 110.94, \"Duration (ms)\": 205473.0, \"Valence\": 0.324, \"Chord\": \"D\"}, {\"Index\": 1162, \"Highest Charting Position\": 54, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"CITY OF ANGELS\", \"Streams\": 4645541, \"Artist\": \"24kGoldn\", \"Artist Followers\": 1276406.0, \"Song ID\": \"6ap9lSRJ0iLriGLqoJ44cq\", \"Genre\": \"['cali rap']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 76.0, \"Danceability\": 0.686, \"Energy\": 0.541, \"Loudness\": -4.993, \"Speechiness\": 0.0493, \"Acousticness\": 0.042, \"Liveness\": 0.0675, \"Tempo\": 120.082, \"Duration (ms)\": 112493.0, \"Valence\": 0.724, \"Chord\": \"C\"}, {\"Index\": 1163, \"Highest Charting Position\": 98, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Astronomia\", \"Streams\": 4642284, \"Artist\": \"Vicetone, Tony Igy\", \"Artist Followers\": 378114.0, \"Song ID\": \"3hWfKBt3n7j1xqIy6LA5ve\", \"Genre\": \"['edm', 'electro house', 'pop dance', 'pop edm', 'progressive electro house', 'tropical house']\", \"Release Date\": \"2016-09-16\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 71.0, \"Danceability\": 0.653, \"Energy\": 0.945, \"Loudness\": -2.634, \"Speechiness\": 0.096, \"Acousticness\": 0.00561, \"Liveness\": 0.439, \"Tempo\": 126.093, \"Duration (ms)\": 198095.0, \"Valence\": 0.326, \"Chord\": \"F\"}, {\"Index\": 1164, \"Highest Charting Position\": 7, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"After Hours\", \"Streams\": 4559855, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"2p8IUWQDrpjuFltbdgLOag\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 75.0, \"Danceability\": 0.664, \"Energy\": 0.572, \"Loudness\": -6.099, \"Speechiness\": 0.0305, \"Acousticness\": 0.0811, \"Liveness\": 0.121, \"Tempo\": 108.959, \"Duration (ms)\": 361027.0, \"Valence\": 0.143, \"Chord\": \"F\"}, {\"Index\": 1165, \"Highest Charting Position\": 51, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"BUTTERFLY EFFECT\", \"Streams\": 4537762, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"2cYqizR4lgvp4Qu6IQ3qGN\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2018-08-03\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 79.0, \"Danceability\": 0.763, \"Energy\": 0.628, \"Loudness\": -5.85, \"Speechiness\": 0.05, \"Acousticness\": 0.0531, \"Liveness\": 0.114, \"Tempo\": 140.958, \"Duration (ms)\": 190557.0, \"Valence\": 0.193, \"Chord\": \"B\"}, {\"Index\": 1166, \"Highest Charting Position\": 74, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Never Seen the Rain\", \"Streams\": 4473968, \"Artist\": \"Tones And I\", \"Artist Followers\": 1251372.0, \"Song ID\": \"1xUCDewhwnORlcFflAgml0\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.742, \"Energy\": 0.464, \"Loudness\": -5.624, \"Speechiness\": 0.0318, \"Acousticness\": 0.425, \"Liveness\": 0.284, \"Tempo\": 92.107, \"Duration (ms)\": 200742.0, \"Valence\": 0.281, \"Chord\": \"F#/Gb\"}, {\"Index\": 1167, \"Highest Charting Position\": 120, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Sigues Con El - Remix\", \"Streams\": 4440738, \"Artist\": \"Arcangel, Sech, Romeo Santos\", \"Artist Followers\": 6671084.0, \"Song ID\": \"4Pu0a2TuHOYtI4CCE3HEXI\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-04-10\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 69.0, \"Danceability\": 0.747, \"Energy\": 0.693, \"Loudness\": -2.97, \"Speechiness\": 0.298, \"Acousticness\": 0.102, \"Liveness\": 0.0872, \"Tempo\": 175.994, \"Duration (ms)\": 189567.0, \"Valence\": 0.736, \"Chord\": \"C#/Db\"}, {\"Index\": 1168, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"ANGELS & DEMONS\", \"Streams\": 4435538, \"Artist\": \"jxdn\", \"Artist Followers\": 799682.0, \"Song ID\": \"3mkz6eI4Sram8UhO3teU76\", \"Genre\": \"[]\", \"Release Date\": \"2021-07-02\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 72.0, \"Danceability\": 0.554, \"Energy\": 0.8, \"Loudness\": -3.936, \"Speechiness\": 0.0395, \"Acousticness\": 0.119, \"Liveness\": 0.629, \"Tempo\": 115.056, \"Duration (ms)\": 160120.0, \"Valence\": 0.463, \"Chord\": \"G#/Ab\"}, {\"Index\": 1169, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Conf\\u00eda\", \"Streams\": 4419295, \"Artist\": \"Sech, Daddy Yankee\", \"Artist Followers\": 8766508.0, \"Song ID\": \"5kbps8unnGH4raN5WduZuq\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-21\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 62.0, \"Danceability\": 0.722, \"Energy\": 0.757, \"Loudness\": -3.592, \"Speechiness\": 0.0782, \"Acousticness\": 0.17, \"Liveness\": 0.0657, \"Tempo\": 167.987, \"Duration (ms)\": 202308.0, \"Valence\": 0.763, \"Chord\": \"C\"}, {\"Index\": 1170, \"Highest Charting Position\": 44, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Mu\\u00e9velo\", \"Streams\": 4407165, \"Artist\": \"Nicky Jam, Daddy Yankee\", \"Artist Followers\": 14831925.0, \"Song ID\": \"4VgYtXCVJ7IbWAZ5ryfvEQ\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-01-08\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 72.0, \"Danceability\": 0.594, \"Energy\": 0.808, \"Loudness\": -2.409, \"Speechiness\": 0.0489, \"Acousticness\": 0.415, \"Liveness\": 0.565, \"Tempo\": 188.09, \"Duration (ms)\": 194892.0, \"Valence\": 0.919, \"Chord\": \"G\"}, {\"Index\": 1171, \"Highest Charting Position\": 105, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"All Bad (feat. Lil Uzi Vert)\", \"Streams\": 6194224, \"Artist\": \"Future\", \"Artist Followers\": 10491105.0, \"Song ID\": \"021lWIHJrURZrmvYQ1xcM8\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 60.0, \"Danceability\": 0.931, \"Energy\": 0.667, \"Loudness\": -7.043, \"Speechiness\": 0.318, \"Acousticness\": 0.0144, \"Liveness\": 0.15, \"Tempo\": 142.039, \"Duration (ms)\": 207739.0, \"Valence\": 0.667, \"Chord\": \"F#/Gb\"}, {\"Index\": 1172, \"Highest Charting Position\": 12, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Pain 1993 (with Playboi Carti)\", \"Streams\": 6085143, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"6Kj17Afjo1OKJYpf5VzCeo\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 67.0, \"Danceability\": 0.825, \"Energy\": 0.373, \"Loudness\": -5.532, \"Speechiness\": 0.108, \"Acousticness\": 0.163, \"Liveness\": 0.368, \"Tempo\": 77.271, \"Duration (ms)\": 149078.0, \"Valence\": 0.12, \"Chord\": \"F\"}, {\"Index\": 1173, \"Highest Charting Position\": 110, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Trillionaire (feat. Youngboy Never Broke Again)\", \"Streams\": 6057848, \"Artist\": \"Future\", \"Artist Followers\": 10491105.0, \"Song ID\": \"740kQ8xwSGloumdiKR5Cwz\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 61.0, \"Danceability\": 0.768, \"Energy\": 0.526, \"Loudness\": -7.182, \"Speechiness\": 0.209, \"Acousticness\": 0.237, \"Liveness\": 0.139, \"Tempo\": 139.999, \"Duration (ms)\": 167552.0, \"Valence\": 0.473, \"Chord\": \"C\"}, {\"Index\": 1174, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Go Stupid\", \"Streams\": 5464816, \"Artist\": \"Polo G, Stunna 4 Vegas, NLE Choppa, Mike WiLL Made-It\", \"Artist Followers\": 4849204.0, \"Song ID\": \"4PklAHGXT5ityno3IA8SKd\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 74.0, \"Danceability\": 0.92, \"Energy\": 0.833, \"Loudness\": -3.18, \"Speechiness\": 0.253, \"Acousticness\": 0.0277, \"Liveness\": 0.0596, \"Tempo\": 141.034, \"Duration (ms)\": 165726.0, \"Valence\": 0.645, \"Chord\": \"C#/Db\"}, {\"Index\": 1175, \"Highest Charting Position\": 149, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"A Gente Fez Amor - Ao Vivo\", \"Streams\": 5006457, \"Artist\": \"Gusttavo Lima\", \"Artist Followers\": 12981319.0, \"Song ID\": \"3tv697PZNnaQN0Mn2zGhS5\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2019-12-05\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-02-07--2020-02-14\\n2020-01-03--2020-01-10\", \"Popularity\": 66.0, \"Danceability\": 0.794, \"Energy\": 0.937, \"Loudness\": -2.44, \"Speechiness\": 0.0336, \"Acousticness\": 0.366, \"Liveness\": 0.962, \"Tempo\": 134.012, \"Duration (ms)\": 237517.0, \"Valence\": 0.826, \"Chord\": \"G#/Ab\"}, {\"Index\": 1176, \"Highest Charting Position\": 173, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Racks 2 Skinny\", \"Streams\": 4729629, \"Artist\": \"Migos\", \"Artist Followers\": 11692972.0, \"Song ID\": \"568OIKgeHyGRD3uWR44JbO\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-11\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 61.0, \"Danceability\": 0.814, \"Energy\": 0.584, \"Loudness\": -5.425, \"Speechiness\": 0.0819, \"Acousticness\": 0.00839, \"Liveness\": 0.0646, \"Tempo\": 141.016, \"Duration (ms)\": 178025.0, \"Valence\": 0.405, \"Chord\": \"C#/Db\"}, {\"Index\": 1177, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Be Something (feat. Lil Baby)\", \"Streams\": 4687909, \"Artist\": \"Polo G\", \"Artist Followers\": 4849204.0, \"Song ID\": \"65jw6GhwQW3Db55PxlPEpS\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 69.0, \"Danceability\": 0.829, \"Energy\": 0.52, \"Loudness\": -10.34, \"Speechiness\": 0.294, \"Acousticness\": 0.0232, \"Liveness\": 0.134, \"Tempo\": 136.103, \"Duration (ms)\": 194118.0, \"Valence\": 0.248, \"Chord\": \"G#/Ab\"}, {\"Index\": 1178, \"Highest Charting Position\": 82, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"BENDICIONES\", \"Streams\": 4639997, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2CoMYp2uIKsT09nreEZnZn\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 67.0, \"Danceability\": 0.828, \"Energy\": 0.581, \"Loudness\": -9.909, \"Speechiness\": 0.0725, \"Acousticness\": 0.0378, \"Liveness\": 0.103, \"Tempo\": 143.995, \"Duration (ms)\": 155060.0, \"Valence\": 0.843, \"Chord\": \"B\"}, {\"Index\": 1179, \"Highest Charting Position\": 126, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"PTSD\", \"Streams\": 4500903, \"Artist\": \"G Herbo, Juice WRLD, Lil Uzi Vert, Chance the Rapper\", \"Artist Followers\": 1253138.0, \"Song ID\": \"1C8ux1YWLMHCenYJFiIV4Z\", \"Genre\": \"['chicago drill', 'chicago rap', 'drill', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-02-28--2020-03-06\", \"Popularity\": 76.0, \"Danceability\": 0.883, \"Energy\": 0.808, \"Loudness\": -3.158, \"Speechiness\": 0.182, \"Acousticness\": 0.0313, \"Liveness\": 0.207, \"Tempo\": 119.01, \"Duration (ms)\": 232065.0, \"Valence\": 0.806, \"Chord\": \"C#/Db\"}, {\"Index\": 1180, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Excitement\", \"Streams\": 4416484, \"Artist\": \"Trippie Redd, PARTYNEXTDOOR\", \"Artist Followers\": 6434201.0, \"Song ID\": \"7FullO2NDkyvxLuxYVKINa\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 69.0, \"Danceability\": 0.443, \"Energy\": 0.536, \"Loudness\": -8.187, \"Speechiness\": 0.0378, \"Acousticness\": 0.0194, \"Liveness\": 0.1, \"Tempo\": 121.967, \"Duration (ms)\": 283285.0, \"Valence\": 0.0391, \"Chord\": \"E\"}, {\"Index\": 1181, \"Highest Charting Position\": 131, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Can We Kiss Forever?\", \"Streams\": 4397385, \"Artist\": \"Kina, Adriana Proenza\", \"Artist Followers\": 661863.0, \"Song ID\": \"58wyJLv6yH1La9NIZPl3ne\", \"Genre\": \"['sad rap']\", \"Release Date\": \"2018-08-31\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.522, \"Energy\": 0.128, \"Loudness\": -18.717, \"Speechiness\": 0.0357, \"Acousticness\": 0.894, \"Liveness\": 0.0941, \"Tempo\": 109.986, \"Duration (ms)\": 187932.0, \"Valence\": 0.124, \"Chord\": \"E\"}, {\"Index\": 1182, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"SI ELLA SALE\", \"Streams\": 7055918, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"1zaDh3qaGSeSmulNyWlUxm\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 63.0, \"Danceability\": 0.869, \"Energy\": 0.727, \"Loudness\": -7.397, \"Speechiness\": 0.123, \"Acousticness\": 0.0589, \"Liveness\": 0.107, \"Tempo\": 147.967, \"Duration (ms)\": 143240.0, \"Valence\": 0.92, \"Chord\": \"G\"}, {\"Index\": 1183, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"RONCA FREESTYLE\", \"Streams\": 5784075, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3XZeOzJ9tqnu58YP6cqApI\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 64.0, \"Danceability\": 0.856, \"Energy\": 0.656, \"Loudness\": -6.483, \"Speechiness\": 0.131, \"Acousticness\": 0.165, \"Liveness\": 0.0998, \"Tempo\": 90.041, \"Duration (ms)\": 150060.0, \"Valence\": 0.586, \"Chord\": \"F\"}, {\"Index\": 1184, \"Highest Charting Position\": 130, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Zoo York (feat. Fivio Foreign & Pop Smoke)\", \"Streams\": 5368705, \"Artist\": \"Lil Tjay\", \"Artist Followers\": 3559267.0, \"Song ID\": \"3Ddny34bFoYBb8dIGq5lwp\", \"Genre\": \"['brooklyn drill', 'melodic rap', 'nyc rap']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 70.0, \"Danceability\": 0.565, \"Energy\": 0.569, \"Loudness\": -6.084, \"Speechiness\": 0.379, \"Acousticness\": 0.0352, \"Liveness\": 0.106, \"Tempo\": 92.466, \"Duration (ms)\": 214825.0, \"Valence\": 0.303, \"Chord\": \"F#/Gb\"}, {\"Index\": 1185, \"Highest Charting Position\": 131, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"EN CASITA\", \"Streams\": 5364262, \"Artist\": \"Bad Bunny, Gabriela\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2DhNdoHxavs7Qtf5MnhZD0\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 62.0, \"Danceability\": 0.779, \"Energy\": 0.764, \"Loudness\": -8.217, \"Speechiness\": 0.0938, \"Acousticness\": 0.221, \"Liveness\": 0.0909, \"Tempo\": 158.093, \"Duration (ms)\": 176440.0, \"Valence\": 0.675, \"Chord\": \"C\"}, {\"Index\": 1186, \"Highest Charting Position\": 71, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Qu\\u00e9 Maldici\\u00f3n\", \"Streams\": 4971559, \"Artist\": \"Banda MS de Sergio Liz\\u00e1rraga, Snoop Dogg\", \"Artist Followers\": 12140496.0, \"Song ID\": \"2RxC2peY3FtrurYmbbmanr\", \"Genre\": \"['banda', 'corrido', 'norteno', 'regional mexican']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 69.0, \"Danceability\": 0.755, \"Energy\": 0.531, \"Loudness\": -8.051, \"Speechiness\": 0.196, \"Acousticness\": 0.213, \"Liveness\": 0.13, \"Tempo\": 177.951, \"Duration (ms)\": 203360.0, \"Valence\": 0.683, \"Chord\": \"A\"}, {\"Index\": 1187, \"Highest Charting Position\": 69, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Nicht verdient\", \"Streams\": 4912914, \"Artist\": \"Capital Bra, Loredana\", \"Artist Followers\": 4093115.0, \"Song ID\": \"7v8OynJxOxHoeS5C2UA9Y7\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-04-29\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 58.0, \"Danceability\": 0.719, \"Energy\": 0.65, \"Loudness\": -7.274, \"Speechiness\": 0.232, \"Acousticness\": 0.381, \"Liveness\": 0.167, \"Tempo\": 77.981, \"Duration (ms)\": 176953.0, \"Valence\": 0.488, \"Chord\": \"B\"}, {\"Index\": 1188, \"Highest Charting Position\": 52, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"A Tu Merced\", \"Streams\": 4909499, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4r9jkMEnArtWGH2rL2FZl0\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 82.0, \"Danceability\": 0.86, \"Energy\": 0.791, \"Loudness\": -4.784, \"Speechiness\": 0.0568, \"Acousticness\": 0.169, \"Liveness\": 0.106, \"Tempo\": 92.023, \"Duration (ms)\": 175918.0, \"Valence\": 0.887, \"Chord\": \"C\"}, {\"Index\": 1189, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Demons (feat. Fivio Foreign & Sosa Geek)\", \"Streams\": 4766829, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"05aZ9sAU1YXndHv0FMi9iW\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 63.0, \"Danceability\": 0.543, \"Energy\": 0.766, \"Loudness\": -3.387, \"Speechiness\": 0.343, \"Acousticness\": 0.423, \"Liveness\": 0.155, \"Tempo\": 106.869, \"Duration (ms)\": 204805.0, \"Valence\": 0.729, \"Chord\": \"C\"}, {\"Index\": 1190, \"Highest Charting Position\": 42, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Moral of the Story\", \"Streams\": 4609358, \"Artist\": \"Ashe\", \"Artist Followers\": 644479.0, \"Song ID\": \"2nC3QhMI9reBIOWutbU3Tj\", \"Genre\": \"['alt z', 'electropop', 'indie pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-02-14\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 75.0, \"Danceability\": 0.572, \"Energy\": 0.406, \"Loudness\": -8.624, \"Speechiness\": 0.0427, \"Acousticness\": 0.587, \"Liveness\": 0.102, \"Tempo\": 119.812, \"Duration (ms)\": 201084.0, \"Valence\": 0.265, \"Chord\": \"A#/Bb\"}, {\"Index\": 1191, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Can I\", \"Streams\": 4603243, \"Artist\": \"Kehlani\", \"Artist Followers\": 4894562.0, \"Song ID\": \"0uDdI4fAXCuNhQbmxENdsO\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop', 'r&b']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 68.0, \"Danceability\": 0.574, \"Energy\": 0.791, \"Loudness\": -3.752, \"Speechiness\": 0.11, \"Acousticness\": 0.419, \"Liveness\": 0.0982, \"Tempo\": 119.537, \"Duration (ms)\": 167810.0, \"Valence\": 0.612, \"Chord\": \"C#/Db\"}, {\"Index\": 1192, \"Highest Charting Position\": 46, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"STARGAZING\", \"Streams\": 4499820, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"7wBJfHzpfI3032CSD7CE2m\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2018-08-03\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 76.0, \"Danceability\": 0.487, \"Energy\": 0.789, \"Loudness\": -3.69, \"Speechiness\": 0.044, \"Acousticness\": 0.00947, \"Liveness\": 0.189, \"Tempo\": 150.007, \"Duration (ms)\": 270715.0, \"Valence\": 0.0564, \"Chord\": \"G#/Ab\"}, {\"Index\": 1193, \"Highest Charting Position\": 124, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Eastside (with Halsey & Khalid)\", \"Streams\": 4397708, \"Artist\": \"benny blanco\", \"Artist Followers\": 804613.0, \"Song ID\": \"0d2iYfpKoM0QCKvcLCkBao\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2018-07-12\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.56, \"Energy\": 0.68, \"Loudness\": -7.648, \"Speechiness\": 0.321, \"Acousticness\": 0.555, \"Liveness\": 0.116, \"Tempo\": 89.391, \"Duration (ms)\": 173800.0, \"Valence\": 0.319, \"Chord\": \"F#/Gb\"}, {\"Index\": 1194, \"Highest Charting Position\": 23, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Suicidal\", \"Streams\": 4320116, \"Artist\": \"YNW Melly\", \"Artist Followers\": 6332535.0, \"Song ID\": \"4S2uhQE8L9V6p7rj7SiauJ\", \"Genre\": \"['melodic rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.655, \"Energy\": 0.441, \"Loudness\": -5.245, \"Speechiness\": 0.0629, \"Acousticness\": 0.474, \"Liveness\": 0.099, \"Tempo\": 139.957, \"Duration (ms)\": 225857.0, \"Valence\": 0.273, \"Chord\": \"A\"}, {\"Index\": 1195, \"Highest Charting Position\": 39, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"How Do You Sleep?\", \"Streams\": 4313625, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"6b2RcmUt1g9N9mQ3CbjX2Y\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2019-07-19\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.477, \"Energy\": 0.682, \"Loudness\": -4.931, \"Speechiness\": 0.0925, \"Acousticness\": 0.153, \"Liveness\": 0.0763, \"Tempo\": 110.567, \"Duration (ms)\": 202205.0, \"Valence\": 0.345, \"Chord\": \"C#/Db\"}, {\"Index\": 1196, \"Highest Charting Position\": 4, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"No Time To Die\", \"Streams\": 4293009, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"73SpzrcaHk0RQPFP73vqVR\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2020-02-13\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 75.0, \"Danceability\": 0.38, \"Energy\": 0.219, \"Loudness\": -13.273, \"Speechiness\": 0.0358, \"Acousticness\": 0.917, \"Liveness\": 0.0827, \"Tempo\": 73.537, \"Duration (ms)\": 242265.0, \"Valence\": 0.0517, \"Chord\": \"E\"}, {\"Index\": 1197, \"Highest Charting Position\": 46, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"D4L\", \"Streams\": 10537097, \"Artist\": \"Future, Drake, Young Thug\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5fHrHoJKfCgBd35zwIBmUK\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 63.0, \"Danceability\": 0.718, \"Energy\": 0.706, \"Loudness\": -5.709, \"Speechiness\": 0.06, \"Acousticness\": 0.0128, \"Liveness\": 0.352, \"Tempo\": 170.004, \"Duration (ms)\": 189176.0, \"Valence\": 0.815, \"Chord\": \"C#/Db\"}, {\"Index\": 1198, \"Highest Charting Position\": 51, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Time Flies\", \"Streams\": 9904749, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5H4mXWKcicuLKDn4Jy0sK7\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 71.0, \"Danceability\": 0.864, \"Energy\": 0.477, \"Loudness\": -5.786, \"Speechiness\": 0.224, \"Acousticness\": 0.201, \"Liveness\": 0.182, \"Tempo\": 86.46, \"Duration (ms)\": 192932.0, \"Valence\": 0.5, \"Chord\": \"A#/Bb\"}, {\"Index\": 1199, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Desires (with Future)\", \"Streams\": 9628215, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"7eYAHC0RbBF9eaqWzT34Aq\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.812, \"Energy\": 0.506, \"Loudness\": -7.706, \"Speechiness\": 0.116, \"Acousticness\": 0.281, \"Liveness\": 0.325, \"Tempo\": 145.074, \"Duration (ms)\": 237946.0, \"Valence\": 0.554, \"Chord\": \"F\"}, {\"Index\": 1200, \"Highest Charting Position\": 55, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Not You Too (feat. Chris Brown)\", \"Streams\": 9284383, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"3Q4gttWQ6hxqWOa3tHoTNi\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.458, \"Energy\": 0.452, \"Loudness\": -9.299, \"Speechiness\": 0.047, \"Acousticness\": 0.342, \"Liveness\": 0.0703, \"Tempo\": 86.318, \"Duration (ms)\": 269680.0, \"Valence\": 0.316, \"Chord\": \"A\"}, {\"Index\": 1201, \"Highest Charting Position\": 67, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Landed\", \"Streams\": 8355036, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"3KixNgUEaDtrKJVzdqjU5q\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 60.0, \"Danceability\": 0.881, \"Energy\": 0.636, \"Loudness\": -4.629, \"Speechiness\": 0.287, \"Acousticness\": 0.00606, \"Liveness\": 0.111, \"Tempo\": 163.949, \"Duration (ms)\": 152195.0, \"Valence\": 0.715, \"Chord\": \"G\"}, {\"Index\": 1202, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"When To Say When\", \"Streams\": 8304928, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5TCBWmEBrin7etRa4Lswr1\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 60.0, \"Danceability\": 0.41, \"Energy\": 0.82, \"Loudness\": -6.808, \"Speechiness\": 0.533, \"Acousticness\": 0.252, \"Liveness\": 0.538, \"Tempo\": 170.718, \"Duration (ms)\": 223124.0, \"Valence\": 0.526, \"Chord\": \"C#/Db\"}, {\"Index\": 1203, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Deep Pockets\", \"Streams\": 8285754, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"3IvMYBE7A3c7to1aEcfFJk\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 58.0, \"Danceability\": 0.473, \"Energy\": 0.824, \"Loudness\": -3.68, \"Speechiness\": 0.163, \"Acousticness\": 0.482, \"Liveness\": 0.605, \"Tempo\": 77.888, \"Duration (ms)\": 222929.0, \"Valence\": 0.374, \"Chord\": \"G\"}, {\"Index\": 1204, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"War\", \"Streams\": 7821869, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"1I55Ea0zVoSKs6MqW7DQ3i\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.749, \"Energy\": 0.792, \"Loudness\": -4.151, \"Speechiness\": 0.0826, \"Acousticness\": 0.292, \"Liveness\": 0.109, \"Tempo\": 144.064, \"Duration (ms)\": 180000.0, \"Valence\": 0.239, \"Chord\": \"A#/Bb\"}, {\"Index\": 1205, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"From Florida With Love\", \"Streams\": 7216610, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"0YkUwXxnTkeJBvt5upeEtP\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.787, \"Energy\": 0.477, \"Loudness\": -7.837, \"Speechiness\": 0.199, \"Acousticness\": 0.768, \"Liveness\": 0.104, \"Tempo\": 80.506, \"Duration (ms)\": 234783.0, \"Valence\": 0.476, \"Chord\": \"F#/Gb\"}, {\"Index\": 1206, \"Highest Charting Position\": 89, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Losses\", \"Streams\": 6894756, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"6fLVTVaHWaEfVKfEgbkf4D\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 57.0, \"Danceability\": 0.551, \"Energy\": 0.57, \"Loudness\": -7.385, \"Speechiness\": 0.351, \"Acousticness\": 0.28, \"Liveness\": 0.424, \"Tempo\": 85.687, \"Duration (ms)\": 271184.0, \"Valence\": 0.505, \"Chord\": \"C#/Db\"}, {\"Index\": 1207, \"Highest Charting Position\": 25, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Turks (feat. Travis Scott)\", \"Streams\": 5594561, \"Artist\": \"NAV, Gunna\", \"Artist Followers\": 2613211.0, \"Song ID\": \"0lSZh5W0wDeurkGzLYY6hf\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'hip hop', 'melodic rap', 'pop rap', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 70.0, \"Danceability\": 0.893, \"Energy\": 0.618, \"Loudness\": -4.425, \"Speechiness\": 0.112, \"Acousticness\": 0.0827, \"Liveness\": 0.542, \"Tempo\": 119.099, \"Duration (ms)\": 161377.0, \"Valence\": 0.389, \"Chord\": \"G\"}, {\"Index\": 1208, \"Highest Charting Position\": 40, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Boyfriend\", \"Streams\": 5236730, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4QnC1bIaMSfDQvF4XDhV5M\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 62.0, \"Danceability\": 0.811, \"Energy\": 0.512, \"Loudness\": -6.381, \"Speechiness\": 0.17, \"Acousticness\": 0.218, \"Liveness\": 0.0768, \"Tempo\": 92.046, \"Duration (ms)\": 161188.0, \"Valence\": 0.346, \"Chord\": \"D\"}, {\"Index\": 1209, \"Highest Charting Position\": 29, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"What If I Told You That I Love You\", \"Streams\": 5234645, \"Artist\": \"Ali Gatie\", \"Artist Followers\": 1758300.0, \"Song ID\": \"6USdi8uX5GNAPYziFhisHb\", \"Genre\": \"['canadian hip hop', 'pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 69.0, \"Danceability\": 0.596, \"Energy\": 0.366, \"Loudness\": -11.144, \"Speechiness\": 0.115, \"Acousticness\": 0.63, \"Liveness\": 0.0554, \"Tempo\": 84.394, \"Duration (ms)\": 193668.0, \"Valence\": 0.229, \"Chord\": \"G\"}, {\"Index\": 1210, \"Highest Charting Position\": 85, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Emotions\", \"Streams\": 4901960, \"Artist\": \"Ufo361\", \"Artist Followers\": 1700759.0, \"Song ID\": \"3yZCjDTxzZxx1kll1sRjGc\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 65.0, \"Danceability\": 0.788, \"Energy\": 0.491, \"Loudness\": -9.884, \"Speechiness\": 0.109, \"Acousticness\": 0.386, \"Liveness\": 0.107, \"Tempo\": 98.543, \"Duration (ms)\": 146028.0, \"Valence\": 0.271, \"Chord\": \"G#/Ab\"}, {\"Index\": 1211, \"Highest Charting Position\": 32, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"FIND MY WAY\", \"Streams\": 4753495, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"1gVCEnryJhkdQcuC0Kbvor\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 66.0, \"Danceability\": 0.836, \"Energy\": 0.624, \"Loudness\": -6.75, \"Speechiness\": 0.184, \"Acousticness\": 0.187, \"Liveness\": 0.138, \"Tempo\": 103.0, \"Duration (ms)\": 139890.0, \"Valence\": 0.7, \"Chord\": \"E\"}, {\"Index\": 1212, \"Highest Charting Position\": 37, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Keii\", \"Streams\": 4687605, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"5eEQCfq7MXQr6aHLNRUZLs\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 67.0, \"Danceability\": 0.708, \"Energy\": 0.797, \"Loudness\": -3.095, \"Speechiness\": 0.0391, \"Acousticness\": 0.4, \"Liveness\": 0.096, \"Tempo\": 88.015, \"Duration (ms)\": 210000.0, \"Valence\": 0.51, \"Chord\": \"C\"}, {\"Index\": 1213, \"Highest Charting Position\": 130, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"God's Plan\", \"Streams\": 4565400, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"6DCZcSspjsKoFjzjrWoCdn\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2018-06-29\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.754, \"Energy\": 0.449, \"Loudness\": -9.211, \"Speechiness\": 0.109, \"Acousticness\": 0.0332, \"Liveness\": 0.552, \"Tempo\": 77.169, \"Duration (ms)\": 198973.0, \"Valence\": 0.357, \"Chord\": \"G\"}, {\"Index\": 1214, \"Highest Charting Position\": 103, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Por Primera Vez\", \"Streams\": 4478685, \"Artist\": \"Camilo, Evaluna Montaner\", \"Artist Followers\": 10580764.0, \"Song ID\": \"0gWbAFRcUyZKdfUxEOuOiD\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-09\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 70.0, \"Danceability\": 0.716, \"Energy\": 0.588, \"Loudness\": -3.952, \"Speechiness\": 0.116, \"Acousticness\": 0.152, \"Liveness\": 0.0847, \"Tempo\": 165.896, \"Duration (ms)\": 183547.0, \"Valence\": 0.707, \"Chord\": \"C#/Db\"}, {\"Index\": 1215, \"Highest Charting Position\": 32, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"@ MEH\", \"Streams\": 4420187, \"Artist\": \"Playboi Carti\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5rffvRUaCvkPnkwMVcQYgZ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 1.0, \"Danceability\": 0.877, \"Energy\": 0.492, \"Loudness\": -8.11, \"Speechiness\": 0.153, \"Acousticness\": 0.0136, \"Liveness\": 0.0678, \"Tempo\": 151.042, \"Duration (ms)\": 166799.0, \"Valence\": 0.4, \"Chord\": \"B\"}, {\"Index\": 1216, \"Highest Charting Position\": 109, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Broke In A Minute\", \"Streams\": 4402281, \"Artist\": \"Tory Lanez\", \"Artist Followers\": 3828418.0, \"Song ID\": \"4xqIYGwwZTEem9U8A42SPF\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-04-10\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-02-07--2020-02-14\", \"Popularity\": 75.0, \"Danceability\": 0.929, \"Energy\": 0.7, \"Loudness\": -5.595, \"Speechiness\": 0.0906, \"Acousticness\": 0.144, \"Liveness\": 0.349, \"Tempo\": 120.009, \"Duration (ms)\": 132024.0, \"Valence\": 0.802, \"Chord\": \"C\"}, {\"Index\": 1217, \"Highest Charting Position\": 139, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Fantasias - Remix\", \"Streams\": 4401019, \"Artist\": \"Rauw Alejandro, Anuel AA, Natti Natasha, Farruko, Lunay\", \"Artist Followers\": 6096559.0, \"Song ID\": \"0A37XY67wSdGqkGjtfW6aV\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 70.0, \"Danceability\": 0.816, \"Energy\": 0.72, \"Loudness\": -4.454, \"Speechiness\": 0.0684, \"Acousticness\": 0.206, \"Liveness\": 0.277, \"Tempo\": 94.004, \"Duration (ms)\": 267242.0, \"Valence\": 0.78, \"Chord\": \"C#/Db\"}, {\"Index\": 1218, \"Highest Charting Position\": 38, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"SUGAR\", \"Streams\": 4362442, \"Artist\": \"BROCKHAMPTON\", \"Artist Followers\": 1836564.0, \"Song ID\": \"6U0FIYXCQ3TGrk4tFpLrEA\", \"Genre\": \"['boy band', 'hip hop', 'rap']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 75.0, \"Danceability\": 0.453, \"Energy\": 0.538, \"Loudness\": -8.212, \"Speechiness\": 0.0638, \"Acousticness\": 0.449, \"Liveness\": 0.19, \"Tempo\": 122.973, \"Duration (ms)\": 204533.0, \"Valence\": 0.516, \"Chord\": \"C#/Db\"}, {\"Index\": 1219, \"Highest Charting Position\": 112, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"90-60-111\", \"Streams\": 5750861, \"Artist\": \"Shirin David\", \"Artist Followers\": 559215.0, \"Song ID\": \"3ZdDYeaZzeYnrP4crgXzPk\", \"Genre\": \"['frauenrap', 'german hip hop', 'german pop']\", \"Release Date\": \"2020-04-23\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 64.0, \"Danceability\": 0.8, \"Energy\": 0.628, \"Loudness\": -6.615, \"Speechiness\": 0.285, \"Acousticness\": 0.103, \"Liveness\": 0.391, \"Tempo\": 143.979, \"Duration (ms)\": 141387.0, \"Valence\": 0.745, \"Chord\": \"D\"}, {\"Index\": 1220, \"Highest Charting Position\": 115, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"YOSEMITE\", \"Streams\": 5686981, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"7lAK3oHbfEnvUQWosrMMpR\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2018-08-03\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 75.0, \"Danceability\": 0.785, \"Energy\": 0.554, \"Loudness\": -6.571, \"Speechiness\": 0.0409, \"Acousticness\": 0.283, \"Liveness\": 0.116, \"Tempo\": 128.047, \"Duration (ms)\": 150043.0, \"Valence\": 0.144, \"Chord\": \"C\"}, {\"Index\": 1221, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Houdini (feat. Swarmz & Tion Wayne)\", \"Streams\": 4914429, \"Artist\": \"KSI\", \"Artist Followers\": 2010879.0, \"Song ID\": \"3lay6f81Lhy0qp2Uvp4cNJ\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 58.0, \"Danceability\": 0.572, \"Energy\": 0.519, \"Loudness\": -8.054, \"Speechiness\": 0.243, \"Acousticness\": 0.000415, \"Liveness\": 0.129, \"Tempo\": 100.453, \"Duration (ms)\": 169355.0, \"Valence\": 0.704, \"Chord\": \"A#/Bb\"}, {\"Index\": 1222, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Sasuke\", \"Streams\": 4701551, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"0ROE31C8Wu4neZoR9stM9e\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 56.0, \"Danceability\": 0.859, \"Energy\": 0.477, \"Loudness\": -6.116, \"Speechiness\": 0.428, \"Acousticness\": 0.00414, \"Liveness\": 0.0819, \"Tempo\": 145.979, \"Duration (ms)\": 251336.0, \"Valence\": 0.153, \"Chord\": \"C#/Db\"}, {\"Index\": 1223, \"Highest Charting Position\": 47, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Me Gusta\", \"Streams\": 4440661, \"Artist\": \"Shakira, Anuel AA\", \"Artist Followers\": 22136717.0, \"Song ID\": \"5Xhqh4lwJPtMUTsdBztN1a\", \"Genre\": \"['colombian pop', 'dance pop', 'latin', 'latin pop', 'pop']\", \"Release Date\": \"2020-01-13\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 72.0, \"Danceability\": 0.775, \"Energy\": 0.696, \"Loudness\": -5.184, \"Speechiness\": 0.0681, \"Acousticness\": 0.0559, \"Liveness\": 0.157, \"Tempo\": 92.007, \"Duration (ms)\": 190570.0, \"Valence\": 0.775, \"Chord\": \"C#/Db\"}, {\"Index\": 1224, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"If You\\u2019re Too Shy (Let Me Know) - Edit\", \"Streams\": 4429092, \"Artist\": \"The 1975\", \"Artist Followers\": 5044278.0, \"Song ID\": \"3iEqGBZ2wcpVzhiAcwXVC6\", \"Genre\": \"['modern alternative rock', 'modern rock', 'pop', 'rock']\", \"Release Date\": \"2020-04-23\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 59.0, \"Danceability\": 0.651, \"Energy\": 0.806, \"Loudness\": -4.842, \"Speechiness\": 0.0311, \"Acousticness\": 0.00399, \"Liveness\": 0.0927, \"Tempo\": 125.641, \"Duration (ms)\": 239877.0, \"Valence\": 0.386, \"Chord\": \"D\"}, {\"Index\": 1225, \"Highest Charting Position\": 80, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Alone, Pt. II\", \"Streams\": 4395061, \"Artist\": \"Alan Walker, Ava Max\", \"Artist Followers\": 29679430.0, \"Song ID\": \"0bMbDctzMmTyK2j74j3nF3\", \"Genre\": \"['electro house']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.67, \"Energy\": 0.668, \"Loudness\": -4.306, \"Speechiness\": 0.0422, \"Acousticness\": 0.536, \"Liveness\": 0.133, \"Tempo\": 88.033, \"Duration (ms)\": 179053.0, \"Valence\": 0.608, \"Chord\": \"D#/Eb\"}, {\"Index\": 1226, \"Highest Charting Position\": 97, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Tutu\", \"Streams\": 4393037, \"Artist\": \"Camilo, Pedro Cap\\u00f3\", \"Artist Followers\": 10580764.0, \"Song ID\": \"1nocRtwyNPVtGcIJqfgdzZ\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2019-08-09\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.731, \"Energy\": 0.832, \"Loudness\": -2.592, \"Speechiness\": 0.0503, \"Acousticness\": 0.273, \"Liveness\": 0.0665, \"Tempo\": 146.013, \"Duration (ms)\": 178613.0, \"Valence\": 0.94, \"Chord\": \"A\"}, {\"Index\": 1227, \"Highest Charting Position\": 85, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Hate Me (with Juice WRLD)\", \"Streams\": 4367368, \"Artist\": \"Ellie Goulding\", \"Artist Followers\": 9747805.0, \"Song ID\": \"6kls8cSlUyHW2BUOkDJIZE\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'indietronica', 'metropopolis', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2019-06-26\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.657, \"Energy\": 0.768, \"Loudness\": -4.628, \"Speechiness\": 0.0507, \"Acousticness\": 0.108, \"Liveness\": 0.144, \"Tempo\": 75.025, \"Duration (ms)\": 186223.0, \"Valence\": 0.759, \"Chord\": \"G#/Ab\"}, {\"Index\": 1228, \"Highest Charting Position\": 109, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Still Be Friends (feat. Tory Lanez & Tyga)\", \"Streams\": 4299422, \"Artist\": \"G-Eazy\", \"Artist Followers\": 4894656.0, \"Song ID\": \"0JjM9bKm4wrwohMslcm892\", \"Genre\": \"['hip hop', 'indie pop rap', 'oakland hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 76.0, \"Danceability\": 0.803, \"Energy\": 0.759, \"Loudness\": -4.692, \"Speechiness\": 0.0494, \"Acousticness\": 0.00509, \"Liveness\": 0.0921, \"Tempo\": 104.0, \"Duration (ms)\": 213308.0, \"Valence\": 0.284, \"Chord\": \"G\"}, {\"Index\": 1229, \"Highest Charting Position\": 74, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Blanco\", \"Streams\": 4214147, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"2rc7BkzO8qepMFAxHtOrXc\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.87, \"Energy\": 0.706, \"Loudness\": -5.395, \"Speechiness\": 0.126, \"Acousticness\": 0.0253, \"Liveness\": 0.0872, \"Tempo\": 100.013, \"Duration (ms)\": 145800.0, \"Valence\": 0.593, \"Chord\": \"A\"}, {\"Index\": 1230, \"Highest Charting Position\": 78, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"PICK UP (feat. Quavo)\", \"Streams\": 7065060, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"5gNOINI5dXZVom2b36LMOd\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 65.0, \"Danceability\": 0.915, \"Energy\": 0.612, \"Loudness\": -4.535, \"Speechiness\": 0.407, \"Acousticness\": 0.0944, \"Liveness\": 0.115, \"Tempo\": 129.93, \"Duration (ms)\": 118547.0, \"Valence\": 0.758, \"Chord\": \"C#/Db\"}, {\"Index\": 1231, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"JUMP (feat. YoungBoy Never Broke Again)\", \"Streams\": 6033348, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"0oT9ElXYSxvnOOagP9efDq\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 62.0, \"Danceability\": 0.896, \"Energy\": 0.72, \"Loudness\": -6.262, \"Speechiness\": 0.355, \"Acousticness\": 0.169, \"Liveness\": 0.252, \"Tempo\": 140.1, \"Duration (ms)\": 212093.0, \"Valence\": 0.966, \"Chord\": \"C\"}, {\"Index\": 1232, \"Highest Charting Position\": 156, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"LIGHTSKIN SH*T (feat. Future & jetsonmade)\", \"Streams\": 4861875, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"16oi4OiKmkO51l60F5R9kR\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 56.0, \"Danceability\": 0.932, \"Energy\": 0.578, \"Loudness\": -4.478, \"Speechiness\": 0.366, \"Acousticness\": 0.115, \"Liveness\": 0.115, \"Tempo\": 129.991, \"Duration (ms)\": 111173.0, \"Valence\": 0.623, \"Chord\": \"A\"}, {\"Index\": 1233, \"Highest Charting Position\": 16, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"That Way - Bonus Track\", \"Streams\": 4825741, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2ajzBr7vwHTEBeqDzcsNRC\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.712, \"Energy\": 0.598, \"Loudness\": -5.368, \"Speechiness\": 0.0388, \"Acousticness\": 0.0546, \"Liveness\": 0.154, \"Tempo\": 130.007, \"Duration (ms)\": 212354.0, \"Valence\": 0.504, \"Chord\": \"G\"}, {\"Index\": 1234, \"Highest Charting Position\": 162, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"No Me Ame\", \"Streams\": 4822090, \"Artist\": \"Rvssian, Anuel AA, Juice WRLD\", \"Artist Followers\": 1397067.0, \"Song ID\": \"2AuWgceaQyfMoI3EGavwGb\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 64.0, \"Danceability\": 0.68, \"Energy\": 0.766, \"Loudness\": -4.799, \"Speechiness\": 0.0923, \"Acousticness\": 0.0411, \"Liveness\": 0.116, \"Tempo\": 160.095, \"Duration (ms)\": 180000.0, \"Valence\": 0.28, \"Chord\": \"B\"}, {\"Index\": 1235, \"Highest Charting Position\": 80, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"I'll Wait\", \"Streams\": 4674532, \"Artist\": \"Kygo, Sasha Alex Sloan\", \"Artist Followers\": 7593792.0, \"Song ID\": \"6Q3K9gVUZRMZqZKrXovbM2\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 70.0, \"Danceability\": 0.611, \"Energy\": 0.651, \"Loudness\": -6.973, \"Speechiness\": 0.0589, \"Acousticness\": 0.144, \"Liveness\": 0.105, \"Tempo\": 122.983, \"Duration (ms)\": 215361.0, \"Valence\": 0.351, \"Chord\": \"C#/Db\"}, {\"Index\": 1236, \"Highest Charting Position\": 63, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Oprah\\u2019s Bank Account (Lil Yachty & DaBaby feat. Drake)\", \"Streams\": 4618744, \"Artist\": \"Lil Yachty\", \"Artist Followers\": 7358720.0, \"Song ID\": \"7wsmIIm0xWmtP7TmACXkJn\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap', 'underground hip hop', 'viral rap']\", \"Release Date\": \"2020-03-09\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 69.0, \"Danceability\": 0.836, \"Energy\": 0.617, \"Loudness\": -4.363, \"Speechiness\": 0.0534, \"Acousticness\": 0.17, \"Liveness\": 0.319, \"Tempo\": 138.066, \"Duration (ms)\": 206702.0, \"Valence\": 0.866, \"Chord\": \"C\"}, {\"Index\": 1237, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"BLAME IT ON BABY\", \"Streams\": 4616034, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"0jWm0VyD8p3MrSInczpows\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 57.0, \"Danceability\": 0.875, \"Energy\": 0.687, \"Loudness\": -5.734, \"Speechiness\": 0.387, \"Acousticness\": 0.236, \"Liveness\": 0.141, \"Tempo\": 109.791, \"Duration (ms)\": 125907.0, \"Valence\": 0.864, \"Chord\": \"A\"}, {\"Index\": 1238, \"Highest Charting Position\": 128, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Follow\", \"Streams\": 4593449, \"Artist\": \"KAROL G, Anuel AA\", \"Artist Followers\": 17792779.0, \"Song ID\": \"2w1rq80FIrbxeJy9WYURxw\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-04-01\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 63.0, \"Danceability\": 0.735, \"Energy\": 0.787, \"Loudness\": -4.375, \"Speechiness\": 0.16, \"Acousticness\": 0.667, \"Liveness\": 0.0721, \"Tempo\": 168.997, \"Duration (ms)\": 203093.0, \"Valence\": 0.455, \"Chord\": \"G\"}, {\"Index\": 1239, \"Highest Charting Position\": 156, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"3 Nights\", \"Streams\": 4411998, \"Artist\": \"Dominic Fike\", \"Artist Followers\": 554042.0, \"Song ID\": \"1tNJrcVe6gwLEiZCtprs1u\", \"Genre\": \"['alternative pop rock', 'pop']\", \"Release Date\": \"2018-10-16\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.815, \"Energy\": 0.518, \"Loudness\": -6.594, \"Speechiness\": 0.0897, \"Acousticness\": 0.223, \"Liveness\": 0.104, \"Tempo\": 151.891, \"Duration (ms)\": 177667.0, \"Valence\": 0.877, \"Chord\": \"G\"}, {\"Index\": 1240, \"Highest Charting Position\": 163, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"The Take (feat. Chris Brown)\", \"Streams\": 4394195, \"Artist\": \"Tory Lanez\", \"Artist Followers\": 3828418.0, \"Song ID\": \"0Odu228D0yGcFySGuxU4rY\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 73.0, \"Danceability\": 0.464, \"Energy\": 0.547, \"Loudness\": -8.137, \"Speechiness\": 0.339, \"Acousticness\": 0.0511, \"Liveness\": 0.155, \"Tempo\": 67.003, \"Duration (ms)\": 221492.0, \"Valence\": 0.423, \"Chord\": \"G\"}, {\"Index\": 1241, \"Highest Charting Position\": 101, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Stupid Again\", \"Streams\": 5938996, \"Artist\": \"Tory Lanez\", \"Artist Followers\": 3828418.0, \"Song ID\": \"1fPnUpoXCpD2NDI4vPVeLw\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-04-10\", \"Weeks Charted\": \"2020-04-10--2020-04-17\", \"Popularity\": 66.0, \"Danceability\": 0.775, \"Energy\": 0.823, \"Loudness\": -4.941, \"Speechiness\": 0.0635, \"Acousticness\": 0.0881, \"Liveness\": 0.309, \"Tempo\": 120.059, \"Duration (ms)\": 174848.0, \"Valence\": 0.65, \"Chord\": \"F\"}, {\"Index\": 1242, \"Highest Charting Position\": 127, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Shotz Fired\", \"Streams\": 5291167, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"0dy5NFDnx5fuZvE8ZXEX35\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-04-10--2020-04-17\", \"Popularity\": 59.0, \"Danceability\": 0.839, \"Energy\": 0.594, \"Loudness\": -9.087, \"Speechiness\": 0.139, \"Acousticness\": 0.249, \"Liveness\": 0.165, \"Tempo\": 76.007, \"Duration (ms)\": 179844.0, \"Valence\": 0.58, \"Chord\": \"C\"}, {\"Index\": 1243, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"BaeBae\", \"Streams\": 5290730, \"Artist\": \"Samra\", \"Artist Followers\": 1045091.0, \"Song ID\": \"1yYBOIXO2H9LDqEPui42GM\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-04-10--2020-04-17\", \"Popularity\": 57.0, \"Danceability\": 0.628, \"Energy\": 0.712, \"Loudness\": -4.864, \"Speechiness\": 0.156, \"Acousticness\": 0.282, \"Liveness\": 0.156, \"Tempo\": 86.627, \"Duration (ms)\": 167827.0, \"Valence\": 0.45, \"Chord\": \"E\"}, {\"Index\": 1244, \"Highest Charting Position\": 30, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"To Die For\", \"Streams\": 4527835, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"2ZTYlnhhV1UAReg7wIGolx\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 70.0, \"Danceability\": 0.483, \"Energy\": 0.361, \"Loudness\": -7.889, \"Speechiness\": 0.0738, \"Acousticness\": 0.832, \"Liveness\": 0.098, \"Tempo\": 171.649, \"Duration (ms)\": 193795.0, \"Valence\": 0.307, \"Chord\": \"C\"}, {\"Index\": 1245, \"Highest Charting Position\": 86, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"WANNABE\", \"Streams\": 4383521, \"Artist\": \"ITZY\", \"Artist Followers\": 2384076.0, \"Song ID\": \"6tCssnvTUREcperDOUTqvA\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2020-03-09\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 75.0, \"Danceability\": 0.809, \"Energy\": 0.911, \"Loudness\": -4.41, \"Speechiness\": 0.0617, \"Acousticness\": 0.00795, \"Liveness\": 0.181, \"Tempo\": 122.035, \"Duration (ms)\": 191242.0, \"Valence\": 0.64, \"Chord\": \"F#/Gb\"}, {\"Index\": 1246, \"Highest Charting Position\": 152, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Takeaway\", \"Streams\": 4359727, \"Artist\": \"The Chainsmokers, ILLENIUM, Lennon Stella\", \"Artist Followers\": 18195884.0, \"Song ID\": \"3g0mEQx3NTanacLseoP0Gw\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.528, \"Energy\": 0.511, \"Loudness\": -8.144, \"Speechiness\": 0.0324, \"Acousticness\": 0.126, \"Liveness\": 0.101, \"Tempo\": 100.1, \"Duration (ms)\": 209880.0, \"Valence\": 0.351, \"Chord\": \"D#/Eb\"}, {\"Index\": 1247, \"Highest Charting Position\": 190, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Heart On Ice\", \"Streams\": 4324610, \"Artist\": \"Rod Wave\", \"Artist Followers\": 2203386.0, \"Song ID\": \"6fWa5CRgy0z30OeGZyMBvD\", \"Genre\": \"['florida rap']\", \"Release Date\": \"2019-06-14\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 70.0, \"Danceability\": 0.733, \"Energy\": 0.389, \"Loudness\": -8.468, \"Speechiness\": 0.0738, \"Acousticness\": 0.0513, \"Liveness\": 0.141, \"Tempo\": 157.878, \"Duration (ms)\": 159670.0, \"Valence\": 0.244, \"Chord\": \"A#/Bb\"}, {\"Index\": 1248, \"Highest Charting Position\": 194, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"La Cama - Remix\", \"Streams\": 4261965, \"Artist\": \"Lunay, Myke Towers, Ozuna, Chencho Corleone, Rauw Alejandro\", \"Artist Followers\": 4963516.0, \"Song ID\": \"2tGENA8xef0wABdHvyXwv9\", \"Genre\": \"['latin', 'latin pop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 69.0, \"Danceability\": 0.737, \"Energy\": 0.832, \"Loudness\": -2.622, \"Speechiness\": 0.0798, \"Acousticness\": 0.12, \"Liveness\": 0.255, \"Tempo\": 173.986, \"Duration (ms)\": 330240.0, \"Valence\": 0.865, \"Chord\": \"D\"}, {\"Index\": 1249, \"Highest Charting Position\": 105, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Go Stupid (feat. NLE Choppa & Mike WiLL Made-It)\", \"Streams\": 4244510, \"Artist\": \"Polo G, Stunna 4 Vegas\", \"Artist Followers\": 4849204.0, \"Song ID\": \"0L8OsjxbagaGkJI0PezdRg\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 41.0, \"Danceability\": 0.922, \"Energy\": 0.813, \"Loudness\": -3.268, \"Speechiness\": 0.251, \"Acousticness\": 0.0198, \"Liveness\": 0.0539, \"Tempo\": 141.087, \"Duration (ms)\": 165726.0, \"Valence\": 0.724, \"Chord\": \"C#/Db\"}, {\"Index\": 1250, \"Highest Charting Position\": 192, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Cradles\", \"Streams\": 4218201, \"Artist\": \"Sub Urban\", \"Artist Followers\": 908351.0, \"Song ID\": \"1y4jsQt7MjnZhiD1L6qFBC\", \"Genre\": \"['modern indie pop']\", \"Release Date\": \"2019-01-04\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 73.0, \"Danceability\": 0.534, \"Energy\": 0.589, \"Loudness\": -1.865, \"Speechiness\": 0.325, \"Acousticness\": 0.256, \"Liveness\": 0.176, \"Tempo\": 78.616, \"Duration (ms)\": 209829.0, \"Valence\": 0.632, \"Chord\": \"C#/Db\"}, {\"Index\": 1251, \"Highest Charting Position\": 117, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Good as Hell (feat. Ariana Grande)\", \"Streams\": 4176083, \"Artist\": \"Lizzo\", \"Artist Followers\": 3991674.0, \"Song ID\": \"07Oz5StQ7GRoygNLaXs2pd\", \"Genre\": \"['dance pop', 'escape room', 'minnesota hip hop', 'pop', 'pop rap', 'post-teen pop', 'trap queen']\", \"Release Date\": \"2016\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 71.0, \"Danceability\": 0.668, \"Energy\": 0.892, \"Loudness\": -3.001, \"Speechiness\": 0.0645, \"Acousticness\": 0.298, \"Liveness\": 0.735, \"Tempo\": 95.927, \"Duration (ms)\": 159011.0, \"Valence\": 0.478, \"Chord\": \"F\"}, {\"Index\": 1252, \"Highest Charting Position\": 15, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Forever (feat. Post Malone & Clever)\", \"Streams\": 6517807, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2ZlCGeK30BLRNSPC832pNZ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 68.0, \"Danceability\": 0.825, \"Energy\": 0.483, \"Loudness\": -5.746, \"Speechiness\": 0.08, \"Acousticness\": 0.538, \"Liveness\": 0.204, \"Tempo\": 139.98, \"Duration (ms)\": 219933.0, \"Valence\": 0.892, \"Chord\": \"G#/Ab\"}, {\"Index\": 1253, \"Highest Charting Position\": 46, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"I Love Me\", \"Streams\": 5449099, \"Artist\": \"Demi Lovato\", \"Artist Followers\": 20338833.0, \"Song ID\": \"2IHLaN6wwYKQ3S24NsQqpA\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.664, \"Energy\": 0.561, \"Loudness\": -7.031, \"Speechiness\": 0.0495, \"Acousticness\": 0.00261, \"Liveness\": 0.0764, \"Tempo\": 150.093, \"Duration (ms)\": 203672.0, \"Valence\": 0.713, \"Chord\": \"F#/Gb\"}, {\"Index\": 1254, \"Highest Charting Position\": 103, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Old Me\", \"Streams\": 4724056, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"58qO4dGa5SgNdtvqvpewyz\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 67.0, \"Danceability\": 0.722, \"Energy\": 0.62, \"Loudness\": -3.639, \"Speechiness\": 0.0483, \"Acousticness\": 0.313, \"Liveness\": 0.26, \"Tempo\": 127.978, \"Duration (ms)\": 186786.0, \"Valence\": 0.474, \"Chord\": \"C\"}, {\"Index\": 1255, \"Highest Charting Position\": 29, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Pero Ya No\", \"Streams\": 4666658, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"75pQqzwgCjUOSSy5CpmAjy\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 72.0, \"Danceability\": 0.882, \"Energy\": 0.612, \"Loudness\": -6.103, \"Speechiness\": 0.118, \"Acousticness\": 0.0475, \"Liveness\": 0.182, \"Tempo\": 147.982, \"Duration (ms)\": 160638.0, \"Valence\": 0.742, \"Chord\": \"E\"}, {\"Index\": 1256, \"Highest Charting Position\": 24, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Hardest To Love\", \"Streams\": 4553544, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"6kWxIqQDsKFYCJGbU4AjCX\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.467, \"Energy\": 0.608, \"Loudness\": -7.847, \"Speechiness\": 0.0707, \"Acousticness\": 0.0909, \"Liveness\": 0.125, \"Tempo\": 80.957, \"Duration (ms)\": 211400.0, \"Valence\": 0.108, \"Chord\": \"A#/Bb\"}, {\"Index\": 1257, \"Highest Charting Position\": 191, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"BRABA\", \"Streams\": 4452819, \"Artist\": \"Lu\\u00edsa Sonza\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6DEEuFNv0K3aJtFYZag8gv\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-11\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 0.0, \"Danceability\": 0.812, \"Energy\": 0.689, \"Loudness\": -5.113, \"Speechiness\": 0.0619, \"Acousticness\": 0.181, \"Liveness\": 0.0784, \"Tempo\": 144.011, \"Duration (ms)\": 129782.0, \"Valence\": 0.663, \"Chord\": \"C\"}, {\"Index\": 1258, \"Highest Charting Position\": 77, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Woah\", \"Streams\": 4425610, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"598yNsG1JFrGd4n2kMoz7F\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 69.0, \"Danceability\": 0.882, \"Energy\": 0.602, \"Loudness\": -5.554, \"Speechiness\": 0.245, \"Acousticness\": 0.0177, \"Liveness\": 0.178, \"Tempo\": 142.959, \"Duration (ms)\": 183011.0, \"Valence\": 0.43, \"Chord\": \"B\"}, {\"Index\": 1259, \"Highest Charting Position\": 69, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Pretty Please\", \"Streams\": 4305034, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"6DXZiYUbrYgrVIhfX3U9Z2\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 67.0, \"Danceability\": 0.906, \"Energy\": 0.474, \"Loudness\": -6.124, \"Speechiness\": 0.194, \"Acousticness\": 0.0311, \"Liveness\": 0.286, \"Tempo\": 106.976, \"Duration (ms)\": 194607.0, \"Valence\": 0.656, \"Chord\": \"C#/Db\"}, {\"Index\": 1260, \"Highest Charting Position\": 170, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"I.F.L.Y.\", \"Streams\": 4284951, \"Artist\": \"Bazzi\", \"Artist Followers\": 4421378.0, \"Song ID\": \"4a6q8CR2hzLk2plDkSxkfD\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-08-09\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-13--2020-03-20\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 76.0, \"Danceability\": 0.812, \"Energy\": 0.519, \"Loudness\": -4.823, \"Speechiness\": 0.0385, \"Acousticness\": 0.379, \"Liveness\": 0.13, \"Tempo\": 104.954, \"Duration (ms)\": 165714.0, \"Valence\": 0.554, \"Chord\": \"D\"}, {\"Index\": 1261, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Cool\", \"Streams\": 8136247, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"4Ulqu89XempybuL8ApUeqL\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.469, \"Energy\": 0.785, \"Loudness\": -4.015, \"Speechiness\": 0.0664, \"Acousticness\": 0.133, \"Liveness\": 0.0931, \"Tempo\": 89.719, \"Duration (ms)\": 209583.0, \"Valence\": 0.79, \"Chord\": \"F\"}, {\"Index\": 1262, \"Highest Charting Position\": 71, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Future Nostalgia\", \"Streams\": 8091754, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3iYNJX4FTRGlfMQySjlGNr\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.875, \"Energy\": 0.813, \"Loudness\": -4.502, \"Speechiness\": 0.0579, \"Acousticness\": 0.00618, \"Liveness\": 0.321, \"Tempo\": 114.993, \"Duration (ms)\": 184882.0, \"Valence\": 0.859, \"Chord\": \"G\"}, {\"Index\": 1263, \"Highest Charting Position\": 92, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Good In Bed\", \"Streams\": 6802068, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3pyodt4pb554dMz8fCv7oi\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 64.0, \"Danceability\": 0.68, \"Energy\": 0.701, \"Loudness\": -5.001, \"Speechiness\": 0.0917, \"Acousticness\": 0.138, \"Liveness\": 0.168, \"Tempo\": 94.06, \"Duration (ms)\": 218754.0, \"Valence\": 0.649, \"Chord\": \"F\"}, {\"Index\": 1264, \"Highest Charting Position\": 27, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Scared To Live\", \"Streams\": 6566099, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"4BGZF4oLbTL0pWm7C18pbv\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 66.0, \"Danceability\": 0.504, \"Energy\": 0.498, \"Loudness\": -8.24, \"Speechiness\": 0.0499, \"Acousticness\": 0.131, \"Liveness\": 0.0929, \"Tempo\": 87.221, \"Duration (ms)\": 191307.0, \"Valence\": 0.196, \"Chord\": \"C\"}, {\"Index\": 1265, \"Highest Charting Position\": 21, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Alone Again\", \"Streams\": 6055294, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"6b5P51m8xx2XA6U7sdNZ5E\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 66.0, \"Danceability\": 0.218, \"Energy\": 0.652, \"Loudness\": -7.953, \"Speechiness\": 0.0641, \"Acousticness\": 0.033, \"Liveness\": 0.172, \"Tempo\": 65.375, \"Duration (ms)\": 250053.0, \"Valence\": 0.0599, \"Chord\": \"E\"}, {\"Index\": 1266, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Boys Will Be Boys\", \"Streams\": 6015914, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"4szI7zRh7kLApCSqiB6R7b\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 63.0, \"Danceability\": 0.768, \"Energy\": 0.486, \"Loudness\": -5.954, \"Speechiness\": 0.0353, \"Acousticness\": 0.408, \"Liveness\": 0.098, \"Tempo\": 125.021, \"Duration (ms)\": 166266.0, \"Valence\": 0.519, \"Chord\": \"D#/Eb\"}, {\"Index\": 1267, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Auto Blu\", \"Streams\": 5995116, \"Artist\": \"Shiva, Eiffel 65\", \"Artist Followers\": 561372.0, \"Song ID\": \"5swpvba5YLqVDy1nbzUdog\", \"Genre\": \"['italian hip hop', 'trap italiana']\", \"Release Date\": \"2020-03-26\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 56.0, \"Danceability\": 0.82, \"Energy\": 0.783, \"Loudness\": -6.146, \"Speechiness\": 0.0621, \"Acousticness\": 0.0158, \"Liveness\": 0.0938, \"Tempo\": 130.015, \"Duration (ms)\": 166087.0, \"Valence\": 0.653, \"Chord\": \"F\"}, {\"Index\": 1268, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Du bist mein\", \"Streams\": 5878493, \"Artist\": \"Zuna, Loredana, SRNO\", \"Artist Followers\": 900975.0, \"Song ID\": \"719aY5gAzJbx2PHjyalZQu\", \"Genre\": \"['albanian hip hop', 'german hip hop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 54.0, \"Danceability\": 0.761, \"Energy\": 0.556, \"Loudness\": -6.943, \"Speechiness\": 0.364, \"Acousticness\": 0.138, \"Liveness\": 0.0976, \"Tempo\": 187.81, \"Duration (ms)\": 160357.0, \"Valence\": 0.521, \"Chord\": \"C#/Db\"}, {\"Index\": 1269, \"Highest Charting Position\": 28, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Too Late\", \"Streams\": 5867746, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"2K9Ovn1o2bTGqbsABGC6m3\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.638, \"Energy\": 0.863, \"Loudness\": -5.221, \"Speechiness\": 0.132, \"Acousticness\": 0.052, \"Liveness\": 0.685, \"Tempo\": 120.077, \"Duration (ms)\": 239973.0, \"Valence\": 0.226, \"Chord\": \"E\"}, {\"Index\": 1270, \"Highest Charting Position\": 136, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Wildflower\", \"Streams\": 5791343, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"6qlcjGJPTZEwR8nf2nSe9C\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.644, \"Energy\": 0.768, \"Loudness\": -4.316, \"Speechiness\": 0.0455, \"Acousticness\": 0.174, \"Liveness\": 0.469, \"Tempo\": 108.992, \"Duration (ms)\": 220536.0, \"Valence\": 0.598, \"Chord\": \"F#/Gb\"}, {\"Index\": 1271, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Faith\", \"Streams\": 5730081, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"3orEOtd8CPL8GFlpRpKuoE\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.375, \"Energy\": 0.605, \"Loudness\": -7.268, \"Speechiness\": 0.0729, \"Acousticness\": 0.612, \"Liveness\": 0.147, \"Tempo\": 175.946, \"Duration (ms)\": 283227.0, \"Valence\": 0.128, \"Chord\": \"C\"}, {\"Index\": 1272, \"Highest Charting Position\": 35, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Snowchild\", \"Streams\": 5423997, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"3WlbeuhfRSqU7ylK2Ui5U7\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 66.0, \"Danceability\": 0.55, \"Energy\": 0.611, \"Loudness\": -7.475, \"Speechiness\": 0.137, \"Acousticness\": 0.162, \"Liveness\": 0.121, \"Tempo\": 148.062, \"Duration (ms)\": 247187.0, \"Valence\": 0.243, \"Chord\": \"C\"}, {\"Index\": 1273, \"Highest Charting Position\": 37, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Escape From LA\", \"Streams\": 5307288, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"1sOW4PuG5X3Ie3EXUhAopJ\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.404, \"Energy\": 0.524, \"Loudness\": -8.996, \"Speechiness\": 0.0593, \"Acousticness\": 0.0456, \"Liveness\": 0.199, \"Tempo\": 145.74, \"Duration (ms)\": 355960.0, \"Valence\": 0.168, \"Chord\": \"F\"}, {\"Index\": 1274, \"Highest Charting Position\": 161, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Allein sein\", \"Streams\": 5119993, \"Artist\": \"Ufo361\", \"Artist Followers\": 1700759.0, \"Song ID\": \"2TrhpvxwuF6hrboTdRXwnS\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 54.0, \"Danceability\": 0.774, \"Energy\": 0.588, \"Loudness\": -8.529, \"Speechiness\": 0.225, \"Acousticness\": 0.0386, \"Liveness\": 0.258, \"Tempo\": 75.978, \"Duration (ms)\": 147353.0, \"Valence\": 0.392, \"Chord\": \"C#/Db\"}, {\"Index\": 1275, \"Highest Charting Position\": 44, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Bichiyal\", \"Streams\": 4946613, \"Artist\": \"Bad Bunny, Yaviah\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4j4w4CXm6BSr0s25wAWrrX\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 75.0, \"Danceability\": 0.737, \"Energy\": 0.766, \"Loudness\": -4.242, \"Speechiness\": 0.0458, \"Acousticness\": 0.31, \"Liveness\": 0.114, \"Tempo\": 93.956, \"Duration (ms)\": 196500.0, \"Valence\": 0.662, \"Chord\": \"A#/Bb\"}, {\"Index\": 1276, \"Highest Charting Position\": 85, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Medusa\", \"Streams\": 4901559, \"Artist\": \"Jhay Cortez, Anuel AA, J Balvin\", \"Artist Followers\": 2435159.0, \"Song ID\": \"3qM0vBxIe4VUbK0Z0smuVP\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-05\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 70.0, \"Danceability\": 0.886, \"Energy\": 0.604, \"Loudness\": -7.293, \"Speechiness\": 0.208, \"Acousticness\": 0.194, \"Liveness\": 0.107, \"Tempo\": 98.023, \"Duration (ms)\": 305333.0, \"Valence\": 0.383, \"Chord\": \"C\"}, {\"Index\": 1277, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Break Up Song\", \"Streams\": 4593343, \"Artist\": \"Little Mix\", \"Artist Followers\": 9398941.0, \"Song ID\": \"5HArmECc1y0lCHKVKDKXa4\", \"Genre\": \"['dance pop', 'girl group', 'pop', 'post-teen pop', 'talent show', 'uk pop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.631, \"Energy\": 0.75, \"Loudness\": -5.416, \"Speechiness\": 0.0394, \"Acousticness\": 0.00388, \"Liveness\": 0.286, \"Tempo\": 90.019, \"Duration (ms)\": 200293.0, \"Valence\": 0.593, \"Chord\": \"F\"}, {\"Index\": 1278, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Teeth\", \"Streams\": 4571612, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"26wLOs3ZuHJa2Ihhx6QIE6\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 78.0, \"Danceability\": 0.749, \"Energy\": 0.461, \"Loudness\": -2.961, \"Speechiness\": 0.0416, \"Acousticness\": 0.0516, \"Liveness\": 0.0738, \"Tempo\": 139.02, \"Duration (ms)\": 204887.0, \"Valence\": 0.42, \"Chord\": \"A#/Bb\"}, {\"Index\": 1279, \"Highest Charting Position\": 51, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Repeat After Me (Interlude)\", \"Streams\": 10058303, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"40U8d12pC5UHqmHwXjHjjl\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 63.0, \"Danceability\": 0.555, \"Energy\": 0.619, \"Loudness\": -7.918, \"Speechiness\": 0.0314, \"Acousticness\": 0.0323, \"Liveness\": 0.0917, \"Tempo\": 95.032, \"Duration (ms)\": 195813.0, \"Valence\": 0.141, \"Chord\": \"C\"}, {\"Index\": 1280, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Until I Bleed Out\", \"Streams\": 9132077, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"2BcnxwxBuar5wjCaLqm5N3\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 63.0, \"Danceability\": 0.245, \"Energy\": 0.394, \"Loudness\": -9.887, \"Speechiness\": 0.0374, \"Acousticness\": 0.423, \"Liveness\": 0.093, \"Tempo\": 115.233, \"Duration (ms)\": 190173.0, \"Valence\": 0.148, \"Chord\": \"C\"}, {\"Index\": 1281, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Rosa\", \"Streams\": 7564893, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"464uJVLmr0fDJGXOnciaDe\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 64.0, \"Danceability\": 0.651, \"Energy\": 0.561, \"Loudness\": -5.715, \"Speechiness\": 0.25, \"Acousticness\": 0.25, \"Liveness\": 0.435, \"Tempo\": 175.992, \"Duration (ms)\": 189827.0, \"Valence\": 0.369, \"Chord\": \"A\"}, {\"Index\": 1282, \"Highest Charting Position\": 88, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Gris\", \"Streams\": 7514854, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"1syf62zw48zu4FrPwMtDHk\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 65.0, \"Danceability\": 0.849, \"Energy\": 0.709, \"Loudness\": -4.717, \"Speechiness\": 0.0794, \"Acousticness\": 0.229, \"Liveness\": 0.329, \"Tempo\": 93.06, \"Duration (ms)\": 176627.0, \"Valence\": 0.916, \"Chord\": \"F#/Gb\"}, {\"Index\": 1283, \"Highest Charting Position\": 103, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Negro\", \"Streams\": 6651425, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"2hsA9YWuF3C9Gosi4dpjJN\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.795, \"Energy\": 0.911, \"Loudness\": -2.228, \"Speechiness\": 0.0875, \"Acousticness\": 0.0157, \"Liveness\": 0.131, \"Tempo\": 164.081, \"Duration (ms)\": 182093.0, \"Valence\": 0.8, \"Chord\": \"C\"}, {\"Index\": 1284, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Verde\", \"Streams\": 5745393, \"Artist\": \"J Balvin, Sky Rompiendo\", \"Artist Followers\": 29067437.0, \"Song ID\": \"3HTbI3yUJQw3fP0Po8qLcD\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 63.0, \"Danceability\": 0.828, \"Energy\": 0.738, \"Loudness\": -4.295, \"Speechiness\": 0.0516, \"Acousticness\": 0.0381, \"Liveness\": 0.0917, \"Tempo\": 94.995, \"Duration (ms)\": 142547.0, \"Valence\": 0.818, \"Chord\": \"G#/Ab\"}, {\"Index\": 1285, \"Highest Charting Position\": 15, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Baby Pluto\", \"Streams\": 5600261, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7hav1MHURQf5SAoPk0egqh\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 69.0, \"Danceability\": 0.772, \"Energy\": 0.634, \"Loudness\": -6.101, \"Speechiness\": 0.212, \"Acousticness\": 0.135, \"Liveness\": 0.432, \"Tempo\": 160.052, \"Duration (ms)\": 210261.0, \"Valence\": 0.671, \"Chord\": \"A#/Bb\"}, {\"Index\": 1286, \"Highest Charting Position\": 31, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Lo Mein\", \"Streams\": 5231134, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"6CUP2khYzdphXebxVTfPE3\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.855, \"Energy\": 0.676, \"Loudness\": -5.736, \"Speechiness\": 0.325, \"Acousticness\": 0.0888, \"Liveness\": 0.144, \"Tempo\": 133.082, \"Duration (ms)\": 195299.0, \"Valence\": 0.509, \"Chord\": \"C#/Db\"}, {\"Index\": 1287, \"Highest Charting Position\": 113, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"No Judgement\", \"Streams\": 5082563, \"Artist\": \"Niall Horan\", \"Artist Followers\": 7564659.0, \"Song ID\": \"5IUOU5xkzGHsRFOYNu3GSK\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 65.0, \"Danceability\": 0.723, \"Energy\": 0.726, \"Loudness\": -3.835, \"Speechiness\": 0.0472, \"Acousticness\": 0.0564, \"Liveness\": 0.057, \"Tempo\": 100.051, \"Duration (ms)\": 176283.0, \"Valence\": 0.962, \"Chord\": \"C#/Db\"}, {\"Index\": 1288, \"Highest Charting Position\": 57, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Futsal Shuffle 2020 - Bonus Track\", \"Streams\": 5068849, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2fOlBMkWR7lXJfqp5VTbDG\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 63.0, \"Danceability\": 0.879, \"Energy\": 0.448, \"Loudness\": -8.57, \"Speechiness\": 0.222, \"Acousticness\": 0.0346, \"Liveness\": 0.224, \"Tempo\": 136.985, \"Duration (ms)\": 198913.0, \"Valence\": 0.278, \"Chord\": \"G\"}, {\"Index\": 1289, \"Highest Charting Position\": 163, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Arco\\u00edris\", \"Streams\": 5044774, \"Artist\": \"J Balvin, Mr Eazi\", \"Artist Followers\": 29067437.0, \"Song ID\": \"5zzbORcD0GwLY0wQHP1Xs1\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 62.0, \"Danceability\": 0.731, \"Energy\": 0.787, \"Loudness\": -5.26, \"Speechiness\": 0.0721, \"Acousticness\": 0.0853, \"Liveness\": 0.316, \"Tempo\": 92.971, \"Duration (ms)\": 186693.0, \"Valence\": 0.393, \"Chord\": \"E\"}, {\"Index\": 1290, \"Highest Charting Position\": 65, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"TOES (feat. Lil Baby & Moneybagg Yo)\", \"Streams\": 4878903, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"2FvD20Z8aoWIePi7PoN8sG\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 73.0, \"Danceability\": 0.816, \"Energy\": 0.582, \"Loudness\": -4.141, \"Speechiness\": 0.341, \"Acousticness\": 0.0794, \"Liveness\": 0.0916, \"Tempo\": 160.004, \"Duration (ms)\": 136366.0, \"Valence\": 0.542, \"Chord\": \"G#/Ab\"}, {\"Index\": 1291, \"Highest Charting Position\": 42, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Feel Me\", \"Streams\": 4765672, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"6XXYdF6pJR1K3wKvuxmu7n\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 63.0, \"Danceability\": 0.71, \"Energy\": 0.808, \"Loudness\": -6.703, \"Speechiness\": 0.0433, \"Acousticness\": 0.44, \"Liveness\": 0.0734, \"Tempo\": 99.989, \"Duration (ms)\": 226003.0, \"Valence\": 0.392, \"Chord\": \"D\"}, {\"Index\": 1292, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"H <3 T E L\", \"Streams\": 4701388, \"Artist\": \"Dardan, Monet192\", \"Artist Followers\": 861082.0, \"Song ID\": \"3S1NOXjDr2A4xXXsWo8kLr\", \"Genre\": \"['albanian hip hop', 'german hip hop']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 34.0, \"Danceability\": 0.726, \"Energy\": 0.646, \"Loudness\": -6.9, \"Speechiness\": 0.0977, \"Acousticness\": 0.0495, \"Liveness\": 0.112, \"Tempo\": 134.999, \"Duration (ms)\": 163253.0, \"Valence\": 0.58, \"Chord\": \"C#/Db\"}, {\"Index\": 1293, \"Highest Charting Position\": 63, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"25/8\", \"Streams\": 4684378, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4NqQaovM14WR2hNPMFxgjb\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 71.0, \"Danceability\": 0.761, \"Energy\": 0.732, \"Loudness\": -5.469, \"Speechiness\": 0.0549, \"Acousticness\": 0.092, \"Liveness\": 0.0716, \"Tempo\": 151.982, \"Duration (ms)\": 243276.0, \"Valence\": 0.542, \"Chord\": \"E\"}, {\"Index\": 1294, \"Highest Charting Position\": 81, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Se Me Olvid\\u00f3\", \"Streams\": 4591194, \"Artist\": \"Christian Nodal\", \"Artist Followers\": 8123757.0, \"Song ID\": \"7paFC3FEu1WtPVP4Do6VZN\", \"Genre\": \"['mariachi', 'nuevo regional mexicano', 'ranchera', 'regional mexican']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 71.0, \"Danceability\": 0.65, \"Energy\": 0.558, \"Loudness\": -3.082, \"Speechiness\": 0.0309, \"Acousticness\": 0.368, \"Liveness\": 0.303, \"Tempo\": 141.82, \"Duration (ms)\": 159533.0, \"Valence\": 0.725, \"Chord\": \"C\"}, {\"Index\": 1295, \"Highest Charting Position\": 130, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"B.S. (feat. H.E.R.)\", \"Streams\": 4557817, \"Artist\": \"Jhen\\u00e9 Aiko\", \"Artist Followers\": 4720858.0, \"Song ID\": \"63wx9vdskaXbYxyDx4oJCZ\", \"Genre\": \"['alternative r&b', 'dance pop', 'pop', 'pop rap', 'r&b', 'urban contemporary']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 72.0, \"Danceability\": 0.617, \"Energy\": 0.525, \"Loudness\": -10.426, \"Speechiness\": 0.12, \"Acousticness\": 0.554, \"Liveness\": 0.135, \"Tempo\": 135.781, \"Duration (ms)\": 212867.0, \"Valence\": 0.377, \"Chord\": \"G#/Ab\"}, {\"Index\": 1296, \"Highest Charting Position\": 45, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Soli\\u00e1\", \"Streams\": 4516243, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"7sOfmPd18RWp3FoCzpa7Kw\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 72.0, \"Danceability\": 0.71, \"Energy\": 0.81, \"Loudness\": -5.507, \"Speechiness\": 0.0854, \"Acousticness\": 0.117, \"Liveness\": 0.154, \"Tempo\": 92.041, \"Duration (ms)\": 159282.0, \"Valence\": 0.184, \"Chord\": \"D\"}, {\"Index\": 1297, \"Highest Charting Position\": 55, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Est\\u00e1 Cabr\\u00f3n Ser Yo\", \"Streams\": 4438261, \"Artist\": \"Bad Bunny, Anuel AA\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4saHEjXw7O1NXJOzBkUKKG\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.81, \"Energy\": 0.854, \"Loudness\": -3.999, \"Speechiness\": 0.254, \"Acousticness\": 0.0732, \"Liveness\": 0.123, \"Tempo\": 154.083, \"Duration (ms)\": 227939.0, \"Valence\": 0.879, \"Chord\": \"A#/Bb\"}, {\"Index\": 1298, \"Highest Charting Position\": 61, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Bean (Kobe) [feat. Chief Keef]\", \"Streams\": 9039518, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"0IpnZchq8ek2A6pGEP2Qb1\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 67.0, \"Danceability\": 0.733, \"Energy\": 0.567, \"Loudness\": -6.718, \"Speechiness\": 0.319, \"Acousticness\": 0.0129, \"Liveness\": 0.382, \"Tempo\": 75.491, \"Duration (ms)\": 238816.0, \"Valence\": 0.319, \"Chord\": \"C\"}, {\"Index\": 1299, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Yessirskiii\", \"Streams\": 8374259, \"Artist\": \"Lil Uzi Vert, 21 Savage\", \"Artist Followers\": 11821805.0, \"Song ID\": \"59JWp4PjZ9TRM8cmtaDYB1\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 70.0, \"Danceability\": 0.895, \"Energy\": 0.739, \"Loudness\": -6.633, \"Speechiness\": 0.283, \"Acousticness\": 0.0183, \"Liveness\": 0.102, \"Tempo\": 140.007, \"Duration (ms)\": 219340.0, \"Valence\": 0.763, \"Chord\": \"G#/Ab\"}, {\"Index\": 1300, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Cardigan\", \"Streams\": 6586204, \"Artist\": \"Don Toliver\", \"Artist Followers\": 1606884.0, \"Song ID\": \"0Li1OuXXfi7950ilZUFGkF\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 70.0, \"Danceability\": 0.747, \"Energy\": 0.497, \"Loudness\": -6.542, \"Speechiness\": 0.0401, \"Acousticness\": 0.248, \"Liveness\": 0.138, \"Tempo\": 142.046, \"Duration (ms)\": 158709.0, \"Valence\": 0.0663, \"Chord\": \"E\"}, {\"Index\": 1301, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Silly Watch\", \"Streams\": 6442451, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"5egD7A5x9AHdVO2fMo3Wbo\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 65.0, \"Danceability\": 0.903, \"Energy\": 0.535, \"Loudness\": -6.238, \"Speechiness\": 0.286, \"Acousticness\": 0.0298, \"Liveness\": 0.0851, \"Tempo\": 130.117, \"Duration (ms)\": 195692.0, \"Valence\": 0.157, \"Chord\": \"G#/Ab\"}, {\"Index\": 1302, \"Highest Charting Position\": 70, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Hablamos Ma\\u00f1ana\", \"Streams\": 6105711, \"Artist\": \"Bad Bunny, Duki, Pablo Chill-E\", \"Artist Followers\": 36177712.0, \"Song ID\": \"1V8XneTrX6kKeoxYbk4x6h\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.683, \"Energy\": 0.677, \"Loudness\": -4.496, \"Speechiness\": 0.0469, \"Acousticness\": 0.0869, \"Liveness\": 0.0998, \"Tempo\": 156.019, \"Duration (ms)\": 240253.0, \"Valence\": 0.514, \"Chord\": \"C#/Db\"}, {\"Index\": 1303, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Lotus\", \"Streams\": 6017103, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4SnlSaLJJ7reJMCHM5YUuX\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 58.0, \"Danceability\": 0.802, \"Energy\": 0.748, \"Loudness\": -5.708, \"Speechiness\": 0.207, \"Acousticness\": 0.24, \"Liveness\": 0.165, \"Tempo\": 150.063, \"Duration (ms)\": 193861.0, \"Valence\": 0.516, \"Chord\": \"G#/Ab\"}, {\"Index\": 1304, \"Highest Charting Position\": 126, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Lettre \\u00e0 une femme\", \"Streams\": 5895243, \"Artist\": \"Ninho\", \"Artist Followers\": 4764552.0, \"Song ID\": \"10rwyGbKAWZ8JZbL7uHl28\", \"Genre\": \"['french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2020-03-07\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 54.0, \"Danceability\": 0.487, \"Energy\": 0.398, \"Loudness\": -9.901, \"Speechiness\": 0.0697, \"Acousticness\": 0.835, \"Liveness\": 0.12, \"Tempo\": 149.367, \"Duration (ms)\": 157766.0, \"Valence\": 0.905, \"Chord\": \"C#/Db\"}, {\"Index\": 1305, \"Highest Charting Position\": 57, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Que Malo\", \"Streams\": 5544180, \"Artist\": \"Bad Bunny, \\u00d1engo Flow\", \"Artist Followers\": 36177712.0, \"Song ID\": \"53v2u51nq3CxiKUNphRzP1\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.802, \"Energy\": 0.787, \"Loudness\": -6.181, \"Speechiness\": 0.0599, \"Acousticness\": 0.0832, \"Liveness\": 0.153, \"Tempo\": 94.026, \"Duration (ms)\": 167975.0, \"Valence\": 0.446, \"Chord\": \"G\"}, {\"Index\": 1306, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Leaders (feat. NAV)\", \"Streams\": 5496780, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4D7NrSeqkTarBrJ80b2sBc\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 60.0, \"Danceability\": 0.95, \"Energy\": 0.654, \"Loudness\": -5.895, \"Speechiness\": 0.307, \"Acousticness\": 0.0744, \"Liveness\": 0.138, \"Tempo\": 132.936, \"Duration (ms)\": 194844.0, \"Valence\": 0.886, \"Chord\": \"C\"}, {\"Index\": 1307, \"Highest Charting Position\": 149, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Strawberry Peels (feat. Young Thug & Gunna)\", \"Streams\": 5468083, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4lAQfuREAHG8IC0PiiigBt\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 59.0, \"Danceability\": 0.862, \"Energy\": 0.65, \"Loudness\": -6.978, \"Speechiness\": 0.355, \"Acousticness\": 0.0207, \"Liveness\": 0.568, \"Tempo\": 131.194, \"Duration (ms)\": 115350.0, \"Valence\": 0.658, \"Chord\": \"A#/Bb\"}, {\"Index\": 1308, \"Highest Charting Position\": 60, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"La Zona\", \"Streams\": 5440382, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5kqNIqFjijuzvVLhuY9B8j\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.762, \"Energy\": 0.801, \"Loudness\": -3.661, \"Speechiness\": 0.0409, \"Acousticness\": 0.2, \"Liveness\": 0.254, \"Tempo\": 93.992, \"Duration (ms)\": 136893.0, \"Valence\": 0.81, \"Chord\": \"C#/Db\"}, {\"Index\": 1309, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Wassup (feat. Future)\", \"Streams\": 5415044, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"19Ec2gbNtQTE44IizcPjtD\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 57.0, \"Danceability\": 0.762, \"Energy\": 0.622, \"Loudness\": -6.293, \"Speechiness\": 0.223, \"Acousticness\": 0.352, \"Liveness\": 0.145, \"Tempo\": 130.019, \"Duration (ms)\": 193314.0, \"Valence\": 0.626, \"Chord\": \"F\"}, {\"Index\": 1310, \"Highest Charting Position\": 69, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Una Vez\", \"Streams\": 5411302, \"Artist\": \"Bad Bunny, Mora\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5J7teKIJGtqVypgYI6sqXj\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 77.0, \"Danceability\": 0.55, \"Energy\": 0.598, \"Loudness\": -5.402, \"Speechiness\": 0.0831, \"Acousticness\": 0.132, \"Liveness\": 0.0955, \"Tempo\": 83.836, \"Duration (ms)\": 232496.0, \"Valence\": 0.543, \"Chord\": \"B\"}, {\"Index\": 1311, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Moon Relate\", \"Streams\": 5324545, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4sWGHlZGM1XA7TyWdtBAbA\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 58.0, \"Danceability\": 0.867, \"Energy\": 0.768, \"Loudness\": -3.73, \"Speechiness\": 0.0791, \"Acousticness\": 0.18, \"Liveness\": 0.254, \"Tempo\": 102.021, \"Duration (ms)\": 181826.0, \"Valence\": 0.34, \"Chord\": \"G\"}, {\"Index\": 1312, \"Highest Charting Position\": 163, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Black And White\", \"Streams\": 5204120, \"Artist\": \"Niall Horan\", \"Artist Followers\": 7564659.0, \"Song ID\": \"7rpNuuoMbid56XkDsx2FjE\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 75.0, \"Danceability\": 0.443, \"Energy\": 0.582, \"Loudness\": -6.02, \"Speechiness\": 0.0482, \"Acousticness\": 0.0301, \"Liveness\": 0.127, \"Tempo\": 147.589, \"Duration (ms)\": 193090.0, \"Valence\": 0.239, \"Chord\": \"D\"}, {\"Index\": 1313, \"Highest Charting Position\": 81, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"The Other Side (from Trolls World Tour)\", \"Streams\": 5193927, \"Artist\": \"SZA, Justin Timberlake\", \"Artist Followers\": 5888533.0, \"Song ID\": \"463PQggkmk5tTw8ug0ahOX\", \"Genre\": \"['pop', 'pop rap', 'r&b']\", \"Release Date\": \"2020-02-26\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 68.0, \"Danceability\": 0.76, \"Energy\": 0.607, \"Loudness\": -6.274, \"Speechiness\": 0.0964, \"Acousticness\": 0.00277, \"Liveness\": 0.132, \"Tempo\": 105.979, \"Duration (ms)\": 188187.0, \"Valence\": 0.709, \"Chord\": \"G\"}, {\"Index\": 1314, \"Highest Charting Position\": 53, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Whine Up\", \"Streams\": 5130783, \"Artist\": \"Nicky Jam, Anuel AA\", \"Artist Followers\": 14831925.0, \"Song ID\": \"2pWOMNQJW3g2zmGjP0Vkb0\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-01\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.817, \"Energy\": 0.665, \"Loudness\": -6.224, \"Speechiness\": 0.0758, \"Acousticness\": 0.0549, \"Liveness\": 0.103, \"Tempo\": 104.957, \"Duration (ms)\": 215460.0, \"Valence\": 0.662, \"Chord\": \"A\"}, {\"Index\": 1315, \"Highest Charting Position\": 37, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Ayy Macarena\", \"Streams\": 5046905, \"Artist\": \"Tyga\", \"Artist Followers\": 6298789.0, \"Song ID\": \"6LcauUZjF1eXQrgqMUecHX\", \"Genre\": \"['dance pop', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2019-11-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.816, \"Energy\": 0.629, \"Loudness\": -5.568, \"Speechiness\": 0.226, \"Acousticness\": 0.133, \"Liveness\": 0.0692, \"Tempo\": 96.493, \"Duration (ms)\": 131607.0, \"Valence\": 0.714, \"Chord\": \"D\"}, {\"Index\": 1316, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Trap This Way (This Way)\", \"Streams\": 5043990, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7vTspUAmMKFkUpKL9HLZNL\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 59.0, \"Danceability\": 0.71, \"Energy\": 0.586, \"Loudness\": -5.331, \"Speechiness\": 0.381, \"Acousticness\": 0.248, \"Liveness\": 0.193, \"Tempo\": 175.987, \"Duration (ms)\": 185439.0, \"Valence\": 0.207, \"Chord\": \"D\"}, {\"Index\": 1317, \"Highest Charting Position\": 113, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Who (feat. BTS)\", \"Streams\": 5004752, \"Artist\": \"Lauv\", \"Artist Followers\": 4442273.0, \"Song ID\": \"2qG81jL9UIP54uS8gYyP4k\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 74.0, \"Danceability\": 0.632, \"Energy\": 0.345, \"Loudness\": -8.0, \"Speechiness\": 0.0349, \"Acousticness\": 0.551, \"Liveness\": 0.104, \"Tempo\": 141.641, \"Duration (ms)\": 180413.0, \"Valence\": 0.0818, \"Chord\": \"B\"}, {\"Index\": 1318, \"Highest Charting Position\": 51, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Homecoming\", \"Streams\": 4988839, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"6vxU64pcIuQ38O015Zy4qj\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 63.0, \"Danceability\": 0.929, \"Energy\": 0.563, \"Loudness\": -7.428, \"Speechiness\": 0.49, \"Acousticness\": 0.000592, \"Liveness\": 0.244, \"Tempo\": 129.957, \"Duration (ms)\": 213885.0, \"Valence\": 0.353, \"Chord\": \"A\"}, {\"Index\": 1319, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Got The Guap (feat. Young Thug)\", \"Streams\": 4946997, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"1HF6P40Z7nfExGaB1Gk99v\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 58.0, \"Danceability\": 0.837, \"Energy\": 0.601, \"Loudness\": -5.628, \"Speechiness\": 0.198, \"Acousticness\": 0.21, \"Liveness\": 0.0928, \"Tempo\": 142.977, \"Duration (ms)\": 176756.0, \"Valence\": 0.749, \"Chord\": \"G#/Ab\"}, {\"Index\": 1320, \"Highest Charting Position\": 53, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Prices\", \"Streams\": 4898167, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4YcWzLSnGqLjSCycuSMHnn\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 65.0, \"Danceability\": 0.786, \"Energy\": 0.683, \"Loudness\": -5.397, \"Speechiness\": 0.205, \"Acousticness\": 0.173, \"Liveness\": 0.706, \"Tempo\": 126.002, \"Duration (ms)\": 233333.0, \"Valence\": 0.57, \"Chord\": \"G\"}, {\"Index\": 1321, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"I Can Show You\", \"Streams\": 4831405, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"0AhJag7VI8uFf3mJFsTwvf\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 57.0, \"Danceability\": 0.817, \"Energy\": 0.656, \"Loudness\": -7.086, \"Speechiness\": 0.277, \"Acousticness\": 0.051, \"Liveness\": 0.115, \"Tempo\": 139.915, \"Duration (ms)\": 120076.0, \"Valence\": 0.314, \"Chord\": \"A#/Bb\"}, {\"Index\": 1322, \"Highest Charting Position\": 52, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"I'm Sorry\", \"Streams\": 4818039, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"1xcOYJxDa5pObgxY1r0I9c\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 60.0, \"Danceability\": 0.858, \"Energy\": 0.547, \"Loudness\": -5.822, \"Speechiness\": 0.29, \"Acousticness\": 0.213, \"Liveness\": 0.104, \"Tempo\": 128.02, \"Duration (ms)\": 211883.0, \"Valence\": 0.303, \"Chord\": \"C#/Db\"}, {\"Index\": 1323, \"Highest Charting Position\": 19, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Black Swan\", \"Streams\": 4802069, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3bkkMZEAhx7rTVz1C0itRQ\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 70.0, \"Danceability\": 0.719, \"Energy\": 0.758, \"Loudness\": -5.167, \"Speechiness\": 0.0851, \"Acousticness\": 0.137, \"Liveness\": 0.129, \"Tempo\": 147.023, \"Duration (ms)\": 198261.0, \"Valence\": 0.49, \"Chord\": \"D\"}, {\"Index\": 1324, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Bad Child\", \"Streams\": 4787180, \"Artist\": \"Tones And I\", \"Artist Followers\": 1251372.0, \"Song ID\": \"2hBeHlR2d7wFJVLcj2fivL\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 0.0, \"Danceability\": 0.756, \"Energy\": 0.553, \"Loudness\": -4.24, \"Speechiness\": 0.0343, \"Acousticness\": 0.404, \"Liveness\": 0.158, \"Tempo\": 117.992, \"Duration (ms)\": 221467.0, \"Valence\": 0.597, \"Chord\": \"F#/Gb\"}, {\"Index\": 1325, \"Highest Charting Position\": 61, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Adicto (with Anuel AA & Ozuna)\", \"Streams\": 4785720, \"Artist\": \"Tainy\", \"Artist Followers\": 509411.0, \"Song ID\": \"3jbT1Y5MoPwEIpZndDDwVq\", \"Genre\": \"['latin', 'latin hip hop', 'latin pop', 'pop reggaeton', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-08-22\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.734, \"Energy\": 0.836, \"Loudness\": -4.803, \"Speechiness\": 0.0735, \"Acousticness\": 0.017, \"Liveness\": 0.179, \"Tempo\": 80.002, \"Duration (ms)\": 270741.0, \"Valence\": 0.623, \"Chord\": \"A#/Bb\"}, {\"Index\": 1326, \"Highest Charting Position\": 66, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"<3\", \"Streams\": 4755477, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4MZSqgwlE71CWZ6qQ3gkKm\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.631, \"Energy\": 0.665, \"Loudness\": -7.589, \"Speechiness\": 0.229, \"Acousticness\": 0.602, \"Liveness\": 0.152, \"Tempo\": 80.353, \"Duration (ms)\": 157967.0, \"Valence\": 0.634, \"Chord\": \"A#/Bb\"}, {\"Index\": 1327, \"Highest Charting Position\": 198, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Bad Girls, Good Vibes\", \"Streams\": 4752181, \"Artist\": \"Ufo361\", \"Artist Followers\": 1700759.0, \"Song ID\": \"7IxGslFZA5QhgXbUsDmcjf\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 53.0, \"Danceability\": 0.826, \"Energy\": 0.368, \"Loudness\": -12.761, \"Speechiness\": 0.133, \"Acousticness\": 0.516, \"Liveness\": 0.0914, \"Tempo\": 127.977, \"Duration (ms)\": 107446.0, \"Valence\": 0.158, \"Chord\": \"G\"}, {\"Index\": 1328, \"Highest Charting Position\": 120, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Liberdade Provis\\u00f3ria - Ao Vivo\", \"Streams\": 4730891, \"Artist\": \"Henrique & Juliano\", \"Artist Followers\": 13312073.0, \"Song ID\": \"3Ghyp3X5Ua9ypHnBIgOObI\", \"Genre\": \"['sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 58.0, \"Danceability\": 0.668, \"Energy\": 0.684, \"Loudness\": -5.937, \"Speechiness\": 0.0527, \"Acousticness\": 0.627, \"Liveness\": 0.923, \"Tempo\": 108.138, \"Duration (ms)\": 187986.0, \"Valence\": 0.7, \"Chord\": \"C#/Db\"}, {\"Index\": 1329, \"Highest Charting Position\": 60, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"POP\", \"Streams\": 10484727, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"1jDbQz6tr52WgScCTXMnaN\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 58.0, \"Danceability\": 0.741, \"Energy\": 0.599, \"Loudness\": -6.672, \"Speechiness\": 0.419, \"Acousticness\": 0.00961, \"Liveness\": 0.785, \"Tempo\": 139.891, \"Duration (ms)\": 227474.0, \"Valence\": 0.276, \"Chord\": \"C#/Db\"}, {\"Index\": 1330, \"Highest Charting Position\": 61, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Celebration Station\", \"Streams\": 10396969, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"25B5fGr9K0VdZJiRFsnMO4\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 61.0, \"Danceability\": 0.748, \"Energy\": 0.771, \"Loudness\": -4.156, \"Speechiness\": 0.15, \"Acousticness\": 0.101, \"Liveness\": 0.135, \"Tempo\": 142.086, \"Duration (ms)\": 195058.0, \"Valence\": 0.792, \"Chord\": \"F#/Gb\"}, {\"Index\": 1331, \"Highest Charting Position\": 64, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Bigger Than Life\", \"Streams\": 9974143, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2oHDJHNondITqbl8xZ9vPn\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 62.0, \"Danceability\": 0.776, \"Energy\": 0.752, \"Loudness\": -4.711, \"Speechiness\": 0.193, \"Acousticness\": 0.325, \"Liveness\": 0.33, \"Tempo\": 140.013, \"Duration (ms)\": 192705.0, \"Valence\": 0.716, \"Chord\": \"G#/Ab\"}, {\"Index\": 1332, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Venetia\", \"Streams\": 9824605, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"3BYIzNZ3t9lRQCACXSMLrT\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 63.0, \"Danceability\": 0.775, \"Energy\": 0.757, \"Loudness\": -4.139, \"Speechiness\": 0.175, \"Acousticness\": 0.162, \"Liveness\": 0.148, \"Tempo\": 142.933, \"Duration (ms)\": 188800.0, \"Valence\": 0.562, \"Chord\": \"A\"}, {\"Index\": 1333, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"You Better Move\", \"Streams\": 9533898, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"6YAxCn4juTWn5hWl2hzHGw\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 60.0, \"Danceability\": 0.842, \"Energy\": 0.556, \"Loudness\": -6.793, \"Speechiness\": 0.442, \"Acousticness\": 0.159, \"Liveness\": 0.204, \"Tempo\": 118.836, \"Duration (ms)\": 196639.0, \"Valence\": 0.306, \"Chord\": \"G#/Ab\"}, {\"Index\": 1334, \"Highest Charting Position\": 93, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Chrome Heart Tags\", \"Streams\": 8219307, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"46mT9NR7N9Zf5MolcrBgE3\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 57.0, \"Danceability\": 0.702, \"Energy\": 0.768, \"Loudness\": -4.055, \"Speechiness\": 0.0669, \"Acousticness\": 0.541, \"Liveness\": 0.105, \"Tempo\": 70.056, \"Duration (ms)\": 212821.0, \"Valence\": 0.574, \"Chord\": \"C\"}, {\"Index\": 1335, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Bust Me\", \"Streams\": 7828045, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4wBcaYqLPm7EtDVoJQORU4\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 57.0, \"Danceability\": 0.734, \"Energy\": 0.703, \"Loudness\": -6.256, \"Speechiness\": 0.355, \"Acousticness\": 0.237, \"Liveness\": 0.413, \"Tempo\": 151.923, \"Duration (ms)\": 194452.0, \"Valence\": 0.608, \"Chord\": \"B\"}, {\"Index\": 1336, \"Highest Charting Position\": 46, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Ren\\u00e9\", \"Streams\": 7240117, \"Artist\": \"Residente\", \"Artist Followers\": 878491.0, \"Song ID\": \"6gm12xlADJwiBbHIKBXzGW\", \"Genre\": \"['venezuelan hip hop']\", \"Release Date\": \"2020-02-27\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 65.0, \"Danceability\": 0.486, \"Energy\": 0.388, \"Loudness\": -9.326, \"Speechiness\": 0.126, \"Acousticness\": 0.435, \"Liveness\": 0.196, \"Tempo\": 90.471, \"Duration (ms)\": 457592.0, \"Valence\": 0.467, \"Chord\": \"C\"}, {\"Index\": 1337, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Secure The Bag\", \"Streams\": 7053947, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7gHZGXSJzM29WA384suYY2\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 57.0, \"Danceability\": 0.803, \"Energy\": 0.719, \"Loudness\": -4.485, \"Speechiness\": 0.392, \"Acousticness\": 0.344, \"Liveness\": 0.425, \"Tempo\": 129.945, \"Duration (ms)\": 238425.0, \"Valence\": 0.549, \"Chord\": \"C\"}, {\"Index\": 1338, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Urgency (feat. Syd)\", \"Streams\": 6224412, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"5KlPy74NOEAt8jC3FYURnQ\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 53.0, \"Danceability\": 0.619, \"Energy\": 0.784, \"Loudness\": -6.11, \"Speechiness\": 0.123, \"Acousticness\": 0.0326, \"Liveness\": 0.315, \"Tempo\": 156.035, \"Duration (ms)\": 181161.0, \"Valence\": 0.471, \"Chord\": \"C#/Db\"}, {\"Index\": 1339, \"Highest Charting Position\": 34, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"ON (Feat. Sia)\", \"Streams\": 6219276, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3IB5qOeMayvpOdHxYCL5tZ\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 64.0, \"Danceability\": 0.591, \"Energy\": 0.848, \"Loudness\": -4.397, \"Speechiness\": 0.0828, \"Acousticness\": 0.137, \"Liveness\": 0.372, \"Tempo\": 105.922, \"Duration (ms)\": 246816.0, \"Valence\": 0.386, \"Chord\": \"A\"}, {\"Index\": 1340, \"Highest Charting Position\": 99, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"P FKN R\", \"Streams\": 6041127, \"Artist\": \"Bad Bunny, Kendo Kaponi, Arcangel\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0fgsKar6uBO08vzHXkTjWi\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 66.0, \"Danceability\": 0.82, \"Energy\": 0.635, \"Loudness\": -5.749, \"Speechiness\": 0.0772, \"Acousticness\": 0.409, \"Liveness\": 0.244, \"Tempo\": 101.024, \"Duration (ms)\": 258280.0, \"Valence\": 0.528, \"Chord\": \"F\"}, {\"Index\": 1341, \"Highest Charting Position\": 108, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Modern Loneliness\", \"Streams\": 6020508, \"Artist\": \"Lauv\", \"Artist Followers\": 4442273.0, \"Song ID\": \"1eyek0KJEh2v5HQ9uQSybb\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 68.0, \"Danceability\": 0.702, \"Energy\": 0.508, \"Loudness\": -7.105, \"Speechiness\": 0.035, \"Acousticness\": 0.144, \"Liveness\": 0.108, \"Tempo\": 82.008, \"Duration (ms)\": 252337.0, \"Valence\": 0.143, \"Chord\": \"G#/Ab\"}, {\"Index\": 1342, \"Highest Charting Position\": 65, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Heatin Up (feat. Gunna)\", \"Streams\": 6004839, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"7KSSdFCBHCfq4KPzz78ghk\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 66.0, \"Danceability\": 0.788, \"Energy\": 0.436, \"Loudness\": -9.435, \"Speechiness\": 0.364, \"Acousticness\": 0.0611, \"Liveness\": 0.0979, \"Tempo\": 129.847, \"Duration (ms)\": 177314.0, \"Valence\": 0.341, \"Chord\": \"C#/Db\"}, {\"Index\": 1343, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"SKYBOX\", \"Streams\": 5846484, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"7GwYENSg87oERcW0Wacd6m\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 59.0, \"Danceability\": 0.779, \"Energy\": 0.707, \"Loudness\": -6.527, \"Speechiness\": 0.16, \"Acousticness\": 0.0991, \"Liveness\": 0.0934, \"Tempo\": 140.894, \"Duration (ms)\": 178097.0, \"Valence\": 0.343, \"Chord\": \"C#/Db\"}, {\"Index\": 1344, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Young & Alive\", \"Streams\": 5578323, \"Artist\": \"Bazzi\", \"Artist Followers\": 4421378.0, \"Song ID\": \"5RsKelNxucrDxgMbZ3vd3W\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-05\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 71.0, \"Danceability\": 0.716, \"Energy\": 0.563, \"Loudness\": -5.486, \"Speechiness\": 0.0425, \"Acousticness\": 0.326, \"Liveness\": 0.119, \"Tempo\": 86.005, \"Duration (ms)\": 160465.0, \"Valence\": 0.495, \"Chord\": \"D#/Eb\"}, {\"Index\": 1345, \"Highest Charting Position\": 169, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"i'm so tired...\", \"Streams\": 5547770, \"Artist\": \"Lauv, Troye Sivan\", \"Artist Followers\": 4442273.0, \"Song ID\": \"4vjpLMyL3ZO6aphdYr8XYw\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-01-03--2020-01-10\", \"Popularity\": 77.0, \"Danceability\": 0.599, \"Energy\": 0.733, \"Loudness\": -7.058, \"Speechiness\": 0.203, \"Acousticness\": 0.176, \"Liveness\": 0.242, \"Tempo\": 102.211, \"Duration (ms)\": 162583.0, \"Valence\": 0.534, \"Chord\": \"B\"}, {\"Index\": 1346, \"Highest Charting Position\": 53, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Numbers (feat. Roddy Ricch, Gunna and London On Da Track)\", \"Streams\": 5487069, \"Artist\": \"A Boogie Wit da Hoodie\", \"Artist Followers\": 5865895.0, \"Song ID\": \"733c1CWmIGymoQXdp7Us88\", \"Genre\": \"['melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 68.0, \"Danceability\": 0.819, \"Energy\": 0.654, \"Loudness\": -6.665, \"Speechiness\": 0.136, \"Acousticness\": 0.517, \"Liveness\": 0.0996, \"Tempo\": 133.503, \"Duration (ms)\": 188563.0, \"Valence\": 0.455, \"Chord\": \"B\"}, {\"Index\": 1347, \"Highest Charting Position\": 105, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Girl\", \"Streams\": 5434180, \"Artist\": \"Myke Towers\", \"Artist Followers\": 6161098.0, \"Song ID\": \"43NqTeL8pgBxKHPMiJKUP5\", \"Genre\": \"['trap latino']\", \"Release Date\": \"2020-01-24\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 72.0, \"Danceability\": 0.733, \"Energy\": 0.708, \"Loudness\": -4.957, \"Speechiness\": 0.0937, \"Acousticness\": 0.0325, \"Liveness\": 0.324, \"Tempo\": 93.021, \"Duration (ms)\": 186427.0, \"Valence\": 0.694, \"Chord\": \"F#/Gb\"}, {\"Index\": 1348, \"Highest Charting Position\": 104, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Puesto Pa' Guerrial\", \"Streams\": 5359969, \"Artist\": \"Bad Bunny, Myke Towers\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5gCg2qMPzKkW4jS4dBKdDs\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 64.0, \"Danceability\": 0.867, \"Energy\": 0.686, \"Loudness\": -5.342, \"Speechiness\": 0.221, \"Acousticness\": 0.311, \"Liveness\": 0.1, \"Tempo\": 139.968, \"Duration (ms)\": 190207.0, \"Valence\": 0.658, \"Chord\": \"E\"}, {\"Index\": 1349, \"Highest Charting Position\": 114, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Definitivamente\", \"Streams\": 5325447, \"Artist\": \"Daddy Yankee, Sech\", \"Artist Followers\": 23936368.0, \"Song ID\": \"113PlnpZbHd3WIqeYjhZWv\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 66.0, \"Danceability\": 0.813, \"Energy\": 0.764, \"Loudness\": -3.39, \"Speechiness\": 0.105, \"Acousticness\": 0.586, \"Liveness\": 0.253, \"Tempo\": 100.047, \"Duration (ms)\": 217773.0, \"Valence\": 0.429, \"Chord\": \"G#/Ab\"}, {\"Index\": 1350, \"Highest Charting Position\": 41, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"South of the Border (feat. Camila Cabello & Cardi B)\", \"Streams\": 5315827, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"4vUmTMuQqjdnvlZmAH61Qk\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-07-12\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.857, \"Energy\": 0.621, \"Loudness\": -6.376, \"Speechiness\": 0.0825, \"Acousticness\": 0.148, \"Liveness\": 0.0865, \"Tempo\": 97.989, \"Duration (ms)\": 204467.0, \"Valence\": 0.668, \"Chord\": \"A\"}, {\"Index\": 1351, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"I Fall Apart\", \"Streams\": 5251918, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"75ZvA4QfFiZvzhj2xkaWAh\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2016-12-09\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 80.0, \"Danceability\": 0.556, \"Energy\": 0.538, \"Loudness\": -5.408, \"Speechiness\": 0.0382, \"Acousticness\": 0.0689, \"Liveness\": 0.196, \"Tempo\": 143.95, \"Duration (ms)\": 223347.0, \"Valence\": 0.291, \"Chord\": \"G#/Ab\"}, {\"Index\": 1352, \"Highest Charting Position\": 191, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"fuck, i'm lonely (with Anne-Marie)\", \"Streams\": 5226991, \"Artist\": \"Lauv\", \"Artist Followers\": 4442273.0, \"Song ID\": \"09PGubKAMryhOWv1LHpCYz\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 74.0, \"Danceability\": 0.806, \"Energy\": 0.558, \"Loudness\": -6.46, \"Speechiness\": 0.0683, \"Acousticness\": 0.482, \"Liveness\": 0.0618, \"Tempo\": 95.016, \"Duration (ms)\": 198973.0, \"Valence\": 0.678, \"Chord\": \"A\"}, {\"Index\": 1353, \"Highest Charting Position\": 78, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Aventura\", \"Streams\": 5206102, \"Artist\": \"Lunay, Ozuna, Anuel AA\", \"Artist Followers\": 4963516.0, \"Song ID\": \"37zdqI4r1gswIzczSBkRon\", \"Genre\": \"['latin', 'latin pop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-10-25\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.729, \"Energy\": 0.726, \"Loudness\": -3.208, \"Speechiness\": 0.0422, \"Acousticness\": 0.223, \"Liveness\": 0.101, \"Tempo\": 92.025, \"Duration (ms)\": 217130.0, \"Valence\": 0.876, \"Chord\": \"F\"}, {\"Index\": 1354, \"Highest Charting Position\": 12, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Rare\", \"Streams\": 5195842, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"7HMmFQsKsljwTw8bS7lu19\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 68.0, \"Danceability\": 0.838, \"Energy\": 0.545, \"Loudness\": -6.713, \"Speechiness\": 0.0706, \"Acousticness\": 0.208, \"Liveness\": 0.103, \"Tempo\": 114.998, \"Duration (ms)\": 220590.0, \"Valence\": 0.631, \"Chord\": \"F\"}, {\"Index\": 1355, \"Highest Charting Position\": 69, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"VIBEZ\", \"Streams\": 5121486, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"0fySG6A6qLE8IvDpayb5bM\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.768, \"Energy\": 0.652, \"Loudness\": -2.708, \"Speechiness\": 0.307, \"Acousticness\": 0.113, \"Liveness\": 0.107, \"Tempo\": 154.187, \"Duration (ms)\": 144935.0, \"Valence\": 0.777, \"Chord\": \"C#/Db\"}, {\"Index\": 1356, \"Highest Charting Position\": 69, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Mean It\", \"Streams\": 5110064, \"Artist\": \"Lauv, LANY\", \"Artist Followers\": 4442273.0, \"Song ID\": \"3uc8AGNL0KbvISIrjnfRvN\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.746, \"Energy\": 0.45, \"Loudness\": -8.543, \"Speechiness\": 0.0872, \"Acousticness\": 0.0407, \"Liveness\": 0.172, \"Tempo\": 95.998, \"Duration (ms)\": 232853.0, \"Valence\": 0.336, \"Chord\": \"G\"}, {\"Index\": 1357, \"Highest Charting Position\": 49, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"That Way\", \"Streams\": 12059592, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"5raTDhlbxFDnpn89bxArdH\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-01\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 67.0, \"Danceability\": 0.719, \"Energy\": 0.611, \"Loudness\": -5.01, \"Speechiness\": 0.0403, \"Acousticness\": 0.0582, \"Liveness\": 0.155, \"Tempo\": 129.962, \"Duration (ms)\": 212354.0, \"Valence\": 0.489, \"Chord\": \"G\"}, {\"Index\": 1358, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Live Off My Closet (feat. Future)\", \"Streams\": 7410327, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"6AyWdCtEn1DdxjnxPeojR2\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 59.0, \"Danceability\": 0.807, \"Energy\": 0.678, \"Loudness\": -3.244, \"Speechiness\": 0.177, \"Acousticness\": 0.0345, \"Liveness\": 0.0986, \"Tempo\": 147.004, \"Duration (ms)\": 173061.0, \"Valence\": 0.21, \"Chord\": \"F#/Gb\"}, {\"Index\": 1359, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Commercial (feat. Lil Uzi Vert)\", \"Streams\": 6540577, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"3tDqEKKUs6gf8zMvSuLyLA\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 67.0, \"Danceability\": 0.892, \"Energy\": 0.486, \"Loudness\": -8.637, \"Speechiness\": 0.384, \"Acousticness\": 0.048, \"Liveness\": 0.146, \"Tempo\": 120.998, \"Duration (ms)\": 214215.0, \"Valence\": 0.535, \"Chord\": \"B\"}, {\"Index\": 1360, \"Highest Charting Position\": 75, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Sum 2 Prove\", \"Streams\": 6497610, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"2u3EyuCqqV31woqGvO9LBz\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 71.0, \"Danceability\": 0.823, \"Energy\": 0.552, \"Loudness\": -7.57, \"Speechiness\": 0.324, \"Acousticness\": 0.0174, \"Liveness\": 0.122, \"Tempo\": 124.038, \"Duration (ms)\": 205760.0, \"Valence\": 0.418, \"Chord\": \"E\"}, {\"Index\": 1361, \"Highest Charting Position\": 47, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Filter\", \"Streams\": 5913946, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"0ono6UCNVZ1XqOm6j78Blu\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 79.0, \"Danceability\": 0.781, \"Energy\": 0.762, \"Loudness\": -5.188, \"Speechiness\": 0.0626, \"Acousticness\": 0.0222, \"Liveness\": 0.121, \"Tempo\": 110.042, \"Duration (ms)\": 180221.0, \"Valence\": 0.86, \"Chord\": \"A#/Bb\"}, {\"Index\": 1362, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Matrix\", \"Streams\": 5724739, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"7ygVaACDENw4PgLbN1awFE\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-02-24\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 55.0, \"Danceability\": 0.789, \"Energy\": 0.509, \"Loudness\": -8.766, \"Speechiness\": 0.291, \"Acousticness\": 0.768, \"Liveness\": 0.272, \"Tempo\": 114.957, \"Duration (ms)\": 183793.0, \"Valence\": 0.418, \"Chord\": \"A\"}, {\"Index\": 1363, \"Highest Charting Position\": 91, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Bellaquita - Remix\", \"Streams\": 5676621, \"Artist\": \"Dalex, Lenny Tav\\u00e1rez, Anitta, Natti Natasha, Farruko, Justin Quiles\", \"Artist Followers\": 3600989.0, \"Song ID\": \"1Xnn1TPyr5h0hpRAT4B4EA\", \"Genre\": \"['latin', 'r&b en espanol', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.795, \"Energy\": 0.715, \"Loudness\": -3.582, \"Speechiness\": 0.0838, \"Acousticness\": 0.141, \"Liveness\": 0.179, \"Tempo\": 165.941, \"Duration (ms)\": 304733.0, \"Valence\": 0.758, \"Chord\": \"C#/Db\"}, {\"Index\": 1364, \"Highest Charting Position\": 139, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Infeliz\", \"Streams\": 5490386, \"Artist\": \"Arcangel, Bad Bunny\", \"Artist Followers\": 6671084.0, \"Song ID\": \"4z6wo6PJG4Fve45OXK6D9m\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-12-20\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 72.0, \"Danceability\": 0.713, \"Energy\": 0.798, \"Loudness\": -3.147, \"Speechiness\": 0.219, \"Acousticness\": 0.366, \"Liveness\": 0.246, \"Tempo\": 176.073, \"Duration (ms)\": 221103.0, \"Valence\": 0.721, \"Chord\": \"C#/Db\"}, {\"Index\": 1365, \"Highest Charting Position\": 60, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Que Tire Pa Lante\", \"Streams\": 5436773, \"Artist\": \"Daddy Yankee\", \"Artist Followers\": 23936368.0, \"Song ID\": \"6RyaV7owmVU6fzEPE17sF1\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-10-18\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.658, \"Energy\": 0.901, \"Loudness\": -2.814, \"Speechiness\": 0.0357, \"Acousticness\": 0.0478, \"Liveness\": 0.12, \"Tempo\": 93.979, \"Duration (ms)\": 210520.0, \"Valence\": 0.708, \"Chord\": \"G\"}, {\"Index\": 1366, \"Highest Charting Position\": 32, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Futsal Shuffle 2020\", \"Streams\": 5386512, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2Ec33AVlkTTq8BHFgBTdQs\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-12\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.881, \"Energy\": 0.457, \"Loudness\": -8.191, \"Speechiness\": 0.156, \"Acousticness\": 0.0327, \"Liveness\": 0.231, \"Tempo\": 136.97, \"Duration (ms)\": 198913.0, \"Valence\": 0.296, \"Chord\": \"G\"}, {\"Index\": 1367, \"Highest Charting Position\": 123, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"GOODMORNINGTOKYO!\", \"Streams\": 5286044, \"Artist\": \"TOKYO\\u2019S REVENGE\", \"Artist Followers\": 313480.0, \"Song ID\": \"0Q2n5yzl2XRqYbV77tZNYp\", \"Genre\": \"['meme rap', 'sad rap', 'vapor trap', 'viral rap']\", \"Release Date\": \"2019-10-18\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 74.0, \"Danceability\": 0.907, \"Energy\": 0.539, \"Loudness\": -7.782, \"Speechiness\": 0.36, \"Acousticness\": 0.0408, \"Liveness\": 0.253, \"Tempo\": 124.918, \"Duration (ms)\": 150115.0, \"Valence\": 0.664, \"Chord\": \"E\"}, {\"Index\": 1368, \"Highest Charting Position\": 58, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Own It (feat. Ed Sheeran & Burna Boy)\", \"Streams\": 5273046, \"Artist\": \"Stormzy\", \"Artist Followers\": 2317758.0, \"Song ID\": \"4QPEwDdOMhY7rNS05mTyMR\", \"Genre\": \"['grime', 'uk hip hop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.817, \"Energy\": 0.781, \"Loudness\": -4.178, \"Speechiness\": 0.112, \"Acousticness\": 0.00838, \"Liveness\": 0.123, \"Tempo\": 104.0, \"Duration (ms)\": 216707.0, \"Valence\": 0.359, \"Chord\": \"G\"}, {\"Index\": 1369, \"Highest Charting Position\": 128, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Life Is Good (feat. Drake, DaBaby & Lil Baby) - Remix\", \"Streams\": 5260351, \"Artist\": \"Future\", \"Artist Followers\": 10491105.0, \"Song ID\": \"4iiWcajF1fEUpwcUewc464\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-02-15\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 61.0, \"Danceability\": 0.81, \"Energy\": 0.566, \"Loudness\": -8.33, \"Speechiness\": 0.433, \"Acousticness\": 0.107, \"Liveness\": 0.122, \"Tempo\": 142.069, \"Duration (ms)\": 315346.0, \"Valence\": 0.582, \"Chord\": \"F\"}, {\"Index\": 1370, \"Highest Charting Position\": 58, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"My Time\", \"Streams\": 5212053, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4vTgx6h4seHvkuFh84JXYP\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 74.0, \"Danceability\": 0.674, \"Energy\": 0.64, \"Loudness\": -5.139, \"Speechiness\": 0.0339, \"Acousticness\": 0.151, \"Liveness\": 0.0925, \"Tempo\": 99.908, \"Duration (ms)\": 234458.0, \"Valence\": 0.664, \"Chord\": \"C\"}, {\"Index\": 1371, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"100k Cash\", \"Streams\": 5192813, \"Artist\": \"Capital Bra, Samra\", \"Artist Followers\": 4093115.0, \"Song ID\": \"033if6Adj8fwBYsQzHOfQ8\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-02-27\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 52.0, \"Danceability\": 0.701, \"Energy\": 0.714, \"Loudness\": -5.906, \"Speechiness\": 0.524, \"Acousticness\": 0.289, \"Liveness\": 0.0883, \"Tempo\": 86.91, \"Duration (ms)\": 173353.0, \"Valence\": 0.604, \"Chord\": \"A#/Bb\"}, {\"Index\": 1372, \"Highest Charting Position\": 185, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Drown (feat. Clinton Kane)\", \"Streams\": 5186141, \"Artist\": \"Martin Garrix\", \"Artist Followers\": 14921269.0, \"Song ID\": \"4RVtBlHFKj51Ipvpfv5ER4\", \"Genre\": \"['dance pop', 'dutch edm', 'edm', 'pop', 'pop dance', 'progressive house', 'tropical house']\", \"Release Date\": \"2020-02-27\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 74.0, \"Danceability\": 0.573, \"Energy\": 0.739, \"Loudness\": -5.455, \"Speechiness\": 0.0581, \"Acousticness\": 0.212, \"Liveness\": 0.175, \"Tempo\": 120.077, \"Duration (ms)\": 174062.0, \"Valence\": 0.363, \"Chord\": \"A\"}, {\"Index\": 1373, \"Highest Charting Position\": 103, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"me & ur ghost\", \"Streams\": 5184069, \"Artist\": \"blackbear\", \"Artist Followers\": 4272745.0, \"Song ID\": \"38KsRHYE10bG0paU78gL9r\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 71.0, \"Danceability\": 0.742, \"Energy\": 0.679, \"Loudness\": -4.594, \"Speechiness\": 0.0259, \"Acousticness\": 0.0488, \"Liveness\": 0.0754, \"Tempo\": 100.041, \"Duration (ms)\": 201398.0, \"Valence\": 0.856, \"Chord\": \"G\"}, {\"Index\": 1374, \"Highest Charting Position\": 146, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"QUE PRETENDES\", \"Streams\": 5141047, \"Artist\": \"J Balvin, Bad Bunny\", \"Artist Followers\": 29067437.0, \"Song ID\": \"25ZAibhr3bdlMCLmubZDVt\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.639, \"Energy\": 0.791, \"Loudness\": -4.443, \"Speechiness\": 0.253, \"Acousticness\": 0.0275, \"Liveness\": 0.362, \"Tempo\": 92.603, \"Duration (ms)\": 222347.0, \"Valence\": 0.939, \"Chord\": \"A#/Bb\"}, {\"Index\": 1375, \"Highest Charting Position\": 140, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"You Need To Calm Down\", \"Streams\": 5115153, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6RRNNciQGZEXnqk8SQ9yv5\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.771, \"Energy\": 0.671, \"Loudness\": -5.617, \"Speechiness\": 0.0553, \"Acousticness\": 0.00929, \"Liveness\": 0.0637, \"Tempo\": 85.026, \"Duration (ms)\": 171360.0, \"Valence\": 0.714, \"Chord\": \"D\"}, {\"Index\": 1376, \"Highest Charting Position\": 90, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Quizas\", \"Streams\": 5112244, \"Artist\": \"Rich Music LTD, Sech, Dalex, Justin Quiles, Lenny Tav\\u00e1rez, Feid, Wisin, Zion\", \"Artist Followers\": 206225.0, \"Song ID\": \"5Id5B3dxJZhPcV9GzgYZZe\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-10-11\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.727, \"Energy\": 0.815, \"Loudness\": -2.454, \"Speechiness\": 0.153, \"Acousticness\": 0.0258, \"Liveness\": 0.231, \"Tempo\": 176.075, \"Duration (ms)\": 216067.0, \"Valence\": 0.677, \"Chord\": \"D#/Eb\"}, {\"Index\": 1377, \"Highest Charting Position\": 106, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Soltera - Remix\", \"Streams\": 5078459, \"Artist\": \"Lunay, Daddy Yankee, Bad Bunny\", \"Artist Followers\": 4963516.0, \"Song ID\": \"1c0hsvHLELX6y8qymnpLKL\", \"Genre\": \"['latin', 'latin pop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-05-10\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.795, \"Energy\": 0.783, \"Loudness\": -4.271, \"Speechiness\": 0.0432, \"Acousticness\": 0.361, \"Liveness\": 0.437, \"Tempo\": 92.01, \"Duration (ms)\": 266087.0, \"Valence\": 0.799, \"Chord\": \"F\"}, {\"Index\": 1378, \"Highest Charting Position\": 46, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Trampoline (with ZAYN)\", \"Streams\": 5075520, \"Artist\": \"SHAED\", \"Artist Followers\": 139434.0, \"Song ID\": \"1iQDltZqI7BXnHrFy4Qo1k\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-09-26\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 73.0, \"Danceability\": 0.619, \"Energy\": 0.459, \"Loudness\": -5.782, \"Speechiness\": 0.0334, \"Acousticness\": 0.56, \"Liveness\": 0.137, \"Tempo\": 126.803, \"Duration (ms)\": 184280.0, \"Valence\": 0.498, \"Chord\": \"G\"}, {\"Index\": 1379, \"Highest Charting Position\": 82, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Truth Hurts\", \"Streams\": 5024683, \"Artist\": \"Lizzo\", \"Artist Followers\": 3991674.0, \"Song ID\": \"3HWzoMvoF3TQfYg4UPszDq\", \"Genre\": \"['dance pop', 'escape room', 'minnesota hip hop', 'pop', 'pop rap', 'post-teen pop', 'trap queen']\", \"Release Date\": \"2019-04-19\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.715, \"Energy\": 0.624, \"Loudness\": -3.046, \"Speechiness\": 0.114, \"Acousticness\": 0.11, \"Liveness\": 0.123, \"Tempo\": 158.087, \"Duration (ms)\": 173325.0, \"Valence\": 0.412, \"Chord\": \"E\"}, {\"Index\": 1380, \"Highest Charting Position\": 91, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"bury a friend\", \"Streams\": 5020303, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"7p6ZK1vOxKELFwlDfwkJCp\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 1.0, \"Danceability\": 0.887, \"Energy\": 0.388, \"Loudness\": -14.505, \"Speechiness\": 0.349, \"Acousticness\": 0.739, \"Liveness\": 0.106, \"Tempo\": 120.035, \"Duration (ms)\": 193143.0, \"Valence\": 0.205, \"Chord\": \"G#/Ab\"}, {\"Index\": 1381, \"Highest Charting Position\": 54, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Louder than bombs\", \"Streams\": 10016907, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3op7HNwLli54MBjFGzIlZO\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.643, \"Energy\": 0.667, \"Loudness\": -6.993, \"Speechiness\": 0.152, \"Acousticness\": 0.0433, \"Liveness\": 0.0904, \"Tempo\": 145.999, \"Duration (ms)\": 217404.0, \"Valence\": 0.485, \"Chord\": \"C\"}, {\"Index\": 1382, \"Highest Charting Position\": 56, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"UGH!\", \"Streams\": 9991177, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"1aKuG1GG76xPLUkjBbQo3W\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.72, \"Energy\": 0.824, \"Loudness\": -5.086, \"Speechiness\": 0.128, \"Acousticness\": 0.0394, \"Liveness\": 0.0509, \"Tempo\": 165.998, \"Duration (ms)\": 225012.0, \"Valence\": 0.333, \"Chord\": \"A#/Bb\"}, {\"Index\": 1383, \"Highest Charting Position\": 67, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"00:00 (Zero O\\u2019Clock)\", \"Streams\": 9372219, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4AlihYDqxXshKhvh5tnMfP\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.566, \"Energy\": 0.548, \"Loudness\": -6.456, \"Speechiness\": 0.0579, \"Acousticness\": 0.0802, \"Liveness\": 0.11, \"Tempo\": 157.999, \"Duration (ms)\": 250296.0, \"Valence\": 0.196, \"Chord\": \"C#/Db\"}, {\"Index\": 1384, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Friends\", \"Streams\": 8822365, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"7w05lsU2VLSeiT8Nukrv5M\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.55, \"Energy\": 0.747, \"Loudness\": -5.211, \"Speechiness\": 0.0407, \"Acousticness\": 0.0668, \"Liveness\": 0.0536, \"Tempo\": 79.98, \"Duration (ms)\": 199339.0, \"Valence\": 0.648, \"Chord\": \"C#/Db\"}, {\"Index\": 1385, \"Highest Charting Position\": 75, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"We are Bulletproof : the Eternal\", \"Streams\": 8516710, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"44WLOqH7QayQOQdeUHeKUK\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.526, \"Energy\": 0.575, \"Loudness\": -5.215, \"Speechiness\": 0.0309, \"Acousticness\": 0.225, \"Liveness\": 0.108, \"Tempo\": 84.047, \"Duration (ms)\": 261543.0, \"Valence\": 0.19, \"Chord\": \"A\"}, {\"Index\": 1386, \"Highest Charting Position\": 79, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Inner Child\", \"Streams\": 8312399, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4BKOjYosPhw334moS3wlbO\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 71.0, \"Danceability\": 0.589, \"Energy\": 0.696, \"Loudness\": -7.981, \"Speechiness\": 0.0725, \"Acousticness\": 0.017, \"Liveness\": 0.0808, \"Tempo\": 134.953, \"Duration (ms)\": 233266.0, \"Valence\": 0.332, \"Chord\": \"B\"}, {\"Index\": 1387, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Moon\", \"Streams\": 7850129, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"1xfXXujIlLZAx5wpu46Nyk\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.703, \"Energy\": 0.646, \"Loudness\": -6.658, \"Speechiness\": 0.0596, \"Acousticness\": 0.0104, \"Liveness\": 0.191, \"Tempo\": 141.87, \"Duration (ms)\": 208590.0, \"Valence\": 0.64, \"Chord\": \"F#/Gb\"}, {\"Index\": 1388, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Outro : Ego\", \"Streams\": 6857808, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3r9FFjLrAIQjoR8pSHVPC9\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 69.0, \"Danceability\": 0.808, \"Energy\": 0.903, \"Loudness\": -3.106, \"Speechiness\": 0.0958, \"Acousticness\": 0.0121, \"Liveness\": 0.0993, \"Tempo\": 116.988, \"Duration (ms)\": 196199.0, \"Valence\": 0.473, \"Chord\": \"C\"}, {\"Index\": 1389, \"Highest Charting Position\": 109, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Interlude : Shadow\", \"Streams\": 6655856, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"2Nib4r0saYQf2pUV4RFDhl\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 68.0, \"Danceability\": 0.385, \"Energy\": 0.798, \"Loudness\": -6.439, \"Speechiness\": 0.483, \"Acousticness\": 0.115, \"Liveness\": 0.181, \"Tempo\": 149.756, \"Duration (ms)\": 259821.0, \"Valence\": 0.141, \"Chord\": \"A\"}, {\"Index\": 1390, \"Highest Charting Position\": 120, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Respect\", \"Streams\": 6373954, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"37TSJmYKLxXmx8OehFpqMN\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 67.0, \"Danceability\": 0.661, \"Energy\": 0.84, \"Loudness\": -4.805, \"Speechiness\": 0.116, \"Acousticness\": 0.00485, \"Liveness\": 0.287, \"Tempo\": 91.457, \"Duration (ms)\": 237540.0, \"Valence\": 0.524, \"Chord\": \"C\"}, {\"Index\": 1391, \"Highest Charting Position\": 154, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Tudo Ok\", \"Streams\": 5510844, \"Artist\": \"Thiaguinho MT, Mila, JS o M\\u00e3o de Ouro\", \"Artist Followers\": 28017.0, \"Song ID\": \"4HUZBG98TYbxSR9V1V2DWS\", \"Genre\": \"['brega funk', 'funk carioca']\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 57.0, \"Danceability\": 0.814, \"Energy\": 0.755, \"Loudness\": -6.164, \"Speechiness\": 0.0942, \"Acousticness\": 0.239, \"Liveness\": 0.306, \"Tempo\": 79.976, \"Duration (ms)\": 178500.0, \"Valence\": 0.963, \"Chord\": \"B\"}, {\"Index\": 1392, \"Highest Charting Position\": 128, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Perreo en La Luna\", \"Streams\": 5135469, \"Artist\": \"Rich Music LTD, Sech, Dalex, Justin Quiles, Lenny Tav\\u00e1rez, Feid\", \"Artist Followers\": 206225.0, \"Song ID\": \"0RDgqtvOHLwcI6yz9bjsZV\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-10-11\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.711, \"Energy\": 0.757, \"Loudness\": -4.188, \"Speechiness\": 0.29, \"Acousticness\": 0.268, \"Liveness\": 0.367, \"Tempo\": 174.013, \"Duration (ms)\": 218587.0, \"Valence\": 0.724, \"Chord\": \"C#/Db\"}, {\"Index\": 1393, \"Highest Charting Position\": 129, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Lose Yourself - From \\\"8 Mile\\\" Soundtrack\", \"Streams\": 5118004, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5Z01UMMf7V1o0MzF86s6WJ\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2005-12-06\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 75.0, \"Danceability\": 0.692, \"Energy\": 0.744, \"Loudness\": -4.565, \"Speechiness\": 0.257, \"Acousticness\": 0.00868, \"Liveness\": 0.359, \"Tempo\": 171.374, \"Duration (ms)\": 326467.0, \"Valence\": 0.0612, \"Chord\": \"D\"}, {\"Index\": 1394, \"Highest Charting Position\": 118, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"all the good girls go to hell\", \"Streams\": 5074485, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"6IRdLKIyS4p7XNiP8r6rsx\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-03-29\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.726, \"Energy\": 0.444, \"Loudness\": -8.922, \"Speechiness\": 0.372, \"Acousticness\": 0.283, \"Liveness\": 0.177, \"Tempo\": 185.044, \"Duration (ms)\": 168840.0, \"Valence\": 0.569, \"Chord\": \"G#/Ab\"}, {\"Index\": 1395, \"Highest Charting Position\": 155, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"SENTAD\\u00c3O\", \"Streams\": 5013019, \"Artist\": \"PEDRO SAMPAIO, Felipe Original, JS o M\\u00e3o de Ouro\", \"Artist Followers\": 1050520.0, \"Song ID\": \"4lKuzrdZrJuCAedbIslF3A\", \"Genre\": \"['funk carioca']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2019-12-27--2020-01-03\", \"Popularity\": 64.0, \"Danceability\": 0.68, \"Energy\": 0.869, \"Loudness\": -1.94, \"Speechiness\": 0.0589, \"Acousticness\": 0.178, \"Liveness\": 0.223, \"Tempo\": 173.997, \"Duration (ms)\": 143448.0, \"Valence\": 0.924, \"Chord\": \"F#/Gb\"}, {\"Index\": 1396, \"Highest Charting Position\": 182, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Lottery (Renegade)\", \"Streams\": 4994448, \"Artist\": \"K CAMP\", \"Artist Followers\": 1347589.0, \"Song ID\": \"4dZTZbmJBCCofAExHwefda\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'pop r&b', 'pop rap', 'r&b', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 61.0, \"Danceability\": 0.915, \"Energy\": 0.556, \"Loudness\": -8.601, \"Speechiness\": 0.216, \"Acousticness\": 0.0145, \"Liveness\": 0.0733, \"Tempo\": 148.964, \"Duration (ms)\": 170947.0, \"Valence\": 0.67, \"Chord\": \"C#/Db\"}, {\"Index\": 1397, \"Highest Charting Position\": 104, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Si Te Vas\", \"Streams\": 4954292, \"Artist\": \"Sech, Ozuna\", \"Artist Followers\": 8766508.0, \"Song ID\": \"6Y4PDQv4XjYjHLeLmvyOt0\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-09-26\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.73, \"Energy\": 0.644, \"Loudness\": -4.124, \"Speechiness\": 0.132, \"Acousticness\": 0.0933, \"Liveness\": 0.143, \"Tempo\": 174.101, \"Duration (ms)\": 204907.0, \"Valence\": 0.554, \"Chord\": \"C\"}, {\"Index\": 1398, \"Highest Charting Position\": 121, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Que Calor (with J Balvin & El Alfa)\", \"Streams\": 4950254, \"Artist\": \"Major Lazer, Diplo\", \"Artist Followers\": 6223652.0, \"Song ID\": \"3iQGDAAKMrlJarnaYNgnSE\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'moombahton', 'pop', 'pop dance', 'pop rap']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 29.0, \"Danceability\": 0.873, \"Energy\": 0.656, \"Loudness\": -6.043, \"Speechiness\": 0.068, \"Acousticness\": 0.00477, \"Liveness\": 0.0726, \"Tempo\": 125.982, \"Duration (ms)\": 206811.0, \"Valence\": 0.546, \"Chord\": \"G#/Ab\"}, {\"Index\": 1399, \"Highest Charting Position\": 186, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Rich Rich\", \"Streams\": 4938864, \"Artist\": \"Ufo361\", \"Artist Followers\": 1700759.0, \"Song ID\": \"2QfmSvSMwTXcvlIkU0w1Yk\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 50.0, \"Danceability\": 0.548, \"Energy\": 0.648, \"Loudness\": -4.796, \"Speechiness\": 0.292, \"Acousticness\": 0.0842, \"Liveness\": 0.123, \"Tempo\": 141.937, \"Duration (ms)\": 204319.0, \"Valence\": 0.232, \"Chord\": \"E\"}, {\"Index\": 1400, \"Highest Charting Position\": 86, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Indeciso\", \"Streams\": 4897374, \"Artist\": \"Reik, J Balvin, Lalo Ebratt\", \"Artist Followers\": 1251372.0, \"Song ID\": \"0FnPT2g07W4aXuHjniC1of\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.738, \"Energy\": 0.748, \"Loudness\": -4.902, \"Speechiness\": 0.0453, \"Acousticness\": 0.182, \"Liveness\": 0.109, \"Tempo\": 94.949, \"Duration (ms)\": 217253.0, \"Valence\": 0.896, \"Chord\": \"C\"}, {\"Index\": 1401, \"Highest Charting Position\": 148, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"i love you\", \"Streams\": 4863910, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"0np7TYPZSum9xTxe9QTr21\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-03--2020-01-10\", \"Popularity\": 2.0, \"Danceability\": 0.42, \"Energy\": 0.131, \"Loudness\": -18.435, \"Speechiness\": 0.0382, \"Acousticness\": 0.953, \"Liveness\": 0.109, \"Tempo\": 137.421, \"Duration (ms)\": 291796.0, \"Valence\": 0.12, \"Chord\": \"C\"}, {\"Index\": 1402, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Mejor\", \"Streams\": 4851895, \"Artist\": \"Dalex, Sech\", \"Artist Followers\": 3600989.0, \"Song ID\": \"6C1jKbkCUgFws7M0M4oGCB\", \"Genre\": \"['latin', 'r&b en espanol', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 63.0, \"Danceability\": 0.524, \"Energy\": 0.577, \"Loudness\": -4.501, \"Speechiness\": 0.18, \"Acousticness\": 0.185, \"Liveness\": 0.103, \"Tempo\": 175.396, \"Duration (ms)\": 201361.0, \"Valence\": 0.19, \"Chord\": \"D\"}, {\"Index\": 1403, \"Highest Charting Position\": 57, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Give No Fxk\", \"Streams\": 9652399, \"Artist\": \"Migos, Travis Scott, Young Thug\", \"Artist Followers\": 11692972.0, \"Song ID\": \"6ZelF5APDN5r6XnFqcnvWR\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 59.0, \"Danceability\": 0.904, \"Energy\": 0.627, \"Loudness\": -5.608, \"Speechiness\": 0.222, \"Acousticness\": 0.0303, \"Liveness\": 0.0923, \"Tempo\": 145.976, \"Duration (ms)\": 224243.0, \"Valence\": 0.236, \"Chord\": \"C#/Db\"}, {\"Index\": 1404, \"Highest Charting Position\": 61, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Come Around Me\", \"Streams\": 9533583, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2o9LAypwGH4ctV0i9boo6d\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 66.0, \"Danceability\": 0.648, \"Energy\": 0.681, \"Loudness\": -8.389, \"Speechiness\": 0.0378, \"Acousticness\": 0.263, \"Liveness\": 0.0971, \"Tempo\": 157.941, \"Duration (ms)\": 200773.0, \"Valence\": 0.767, \"Chord\": \"D\"}, {\"Index\": 1405, \"Highest Charting Position\": 64, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Habitual\", \"Streams\": 9120086, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"40qyPyljksBEqlNw5sW37T\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 62.0, \"Danceability\": 0.764, \"Energy\": 0.443, \"Loudness\": -6.625, \"Speechiness\": 0.0439, \"Acousticness\": 0.52, \"Liveness\": 0.0749, \"Tempo\": 138.999, \"Duration (ms)\": 168200.0, \"Valence\": 0.63, \"Chord\": \"E\"}, {\"Index\": 1406, \"Highest Charting Position\": 65, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"All Around Me\", \"Streams\": 9010535, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5Py8zRKGkZvgHniVVtvNCN\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 63.0, \"Danceability\": 0.566, \"Energy\": 0.438, \"Loudness\": -7.564, \"Speechiness\": 0.0367, \"Acousticness\": 0.809, \"Liveness\": 0.212, \"Tempo\": 117.127, \"Duration (ms)\": 136907.0, \"Valence\": 0.692, \"Chord\": \"C\"}, {\"Index\": 1407, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Get Me (feat. Kehlani)\", \"Streams\": 8362828, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5VwwpU7KsLhgfbMEecedhJ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 61.0, \"Danceability\": 0.832, \"Energy\": 0.508, \"Loudness\": -6.913, \"Speechiness\": 0.149, \"Acousticness\": 0.0492, \"Liveness\": 0.107, \"Tempo\": 109.352, \"Duration (ms)\": 185427.0, \"Valence\": 0.75, \"Chord\": \"F#/Gb\"}, {\"Index\": 1408, \"Highest Charting Position\": 79, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Second Emotion (feat. Travis Scott)\", \"Streams\": 8109572, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"1PnAx788sAvcI3ZxTlEyX8\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 61.0, \"Danceability\": 0.796, \"Energy\": 0.777, \"Loudness\": -6.112, \"Speechiness\": 0.0567, \"Acousticness\": 0.0276, \"Liveness\": 0.095, \"Tempo\": 141.97, \"Duration (ms)\": 202720.0, \"Valence\": 0.96, \"Chord\": \"B\"}, {\"Index\": 1409, \"Highest Charting Position\": 85, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Running Over (feat. Lil Dicky)\", \"Streams\": 7493188, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"75nKBP8jQu681pTNCtrEnn\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.774, \"Energy\": 0.603, \"Loudness\": -7.319, \"Speechiness\": 0.0591, \"Acousticness\": 0.438, \"Liveness\": 0.0869, \"Tempo\": 149.982, \"Duration (ms)\": 179627.0, \"Valence\": 0.977, \"Chord\": \"B\"}, {\"Index\": 1410, \"Highest Charting Position\": 86, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Available\", \"Streams\": 7473249, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"1b6tPXXCV2fSNtR3SKWUQA\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.702, \"Energy\": 0.608, \"Loudness\": -6.843, \"Speechiness\": 0.0359, \"Acousticness\": 0.0736, \"Liveness\": 0.129, \"Tempo\": 75.012, \"Duration (ms)\": 195333.0, \"Valence\": 0.597, \"Chord\": \"D#/Eb\"}, {\"Index\": 1411, \"Highest Charting Position\": 96, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Breathe Deeper\", \"Streams\": 7142364, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"3LbZIhU0smEU5SUnxod4j4\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 66.0, \"Danceability\": 0.664, \"Energy\": 0.848, \"Loudness\": -4.51, \"Speechiness\": 0.0322, \"Acousticness\": 0.0245, \"Liveness\": 0.172, \"Tempo\": 104.998, \"Duration (ms)\": 372867.0, \"Valence\": 0.502, \"Chord\": \"B\"}, {\"Index\": 1412, \"Highest Charting Position\": 103, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Changes\", \"Streams\": 6865229, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"521Os1SMlxmsoevsqyjNmJ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 62.0, \"Danceability\": 0.485, \"Energy\": 0.412, \"Loudness\": -7.766, \"Speechiness\": 0.042, \"Acousticness\": 0.738, \"Liveness\": 0.12, \"Tempo\": 64.062, \"Duration (ms)\": 135493.0, \"Valence\": 0.612, \"Chord\": \"A\"}, {\"Index\": 1413, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Confirmation\", \"Streams\": 6520106, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"60brXKLTC15vK0av5gIldm\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.438, \"Energy\": 0.315, \"Loudness\": -8.186, \"Speechiness\": 0.0375, \"Acousticness\": 0.608, \"Liveness\": 0.151, \"Tempo\": 190.064, \"Duration (ms)\": 170587.0, \"Valence\": 0.449, \"Chord\": \"G#/Ab\"}, {\"Index\": 1414, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Mios mit Bars\", \"Streams\": 6341141, \"Artist\": \"Luciano\", \"Artist Followers\": 942380.0, \"Song ID\": \"7Ek9e3eIuktIFjpDRQfmHE\", \"Genre\": \"['german drill', 'german hip hop']\", \"Release Date\": \"2020-02-13\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 57.0, \"Danceability\": 0.677, \"Energy\": 0.633, \"Loudness\": -7.353, \"Speechiness\": 0.0467, \"Acousticness\": 0.111, \"Liveness\": 0.217, \"Tempo\": 145.012, \"Duration (ms)\": 232147.0, \"Valence\": 0.404, \"Chord\": \"A\"}, {\"Index\": 1415, \"Highest Charting Position\": 135, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"E.T.A.\", \"Streams\": 6008945, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6PzOPrXx8tJEqace76yrv2\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.465, \"Energy\": 0.494, \"Loudness\": -7.595, \"Speechiness\": 0.066, \"Acousticness\": 0.49, \"Liveness\": 0.127, \"Tempo\": 127.298, \"Duration (ms)\": 176733.0, \"Valence\": 0.457, \"Chord\": \"E\"}, {\"Index\": 1416, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Borderline\", \"Streams\": 5921044, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"5hM5arv9KDbCHS0k9uqwjr\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 77.0, \"Danceability\": 0.621, \"Energy\": 0.873, \"Loudness\": -3.067, \"Speechiness\": 0.0369, \"Acousticness\": 0.0406, \"Liveness\": 0.0824, \"Tempo\": 97.96, \"Duration (ms)\": 237800.0, \"Valence\": 0.873, \"Chord\": \"F\"}, {\"Index\": 1417, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Take It Out On Me\", \"Streams\": 5858768, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"39nTNk5MfyiiRupTwn1iyC\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 54.0, \"Danceability\": 0.772, \"Energy\": 0.616, \"Loudness\": -4.673, \"Speechiness\": 0.102, \"Acousticness\": 0.00337, \"Liveness\": 0.104, \"Tempo\": 129.967, \"Duration (ms)\": 178013.0, \"Valence\": 0.279, \"Chord\": \"G\"}, {\"Index\": 1418, \"Highest Charting Position\": 67, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"No Shame\", \"Streams\": 5835260, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"5EbidH3lGB30WuDsoR4km6\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 62.0, \"Danceability\": 0.576, \"Energy\": 0.807, \"Loudness\": -3.019, \"Speechiness\": 0.0374, \"Acousticness\": 0.0185, \"Liveness\": 0.0963, \"Tempo\": 90.932, \"Duration (ms)\": 192737.0, \"Valence\": 0.479, \"Chord\": \"G\"}, {\"Index\": 1419, \"Highest Charting Position\": 160, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Might Not Give Up (feat. Young Thug)\", \"Streams\": 5503902, \"Artist\": \"A Boogie Wit da Hoodie\", \"Artist Followers\": 5865895.0, \"Song ID\": \"4l2rsMfr20dj6nf6i6F3Y8\", \"Genre\": \"['melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 57.0, \"Danceability\": 0.687, \"Energy\": 0.592, \"Loudness\": -6.378, \"Speechiness\": 0.224, \"Acousticness\": 0.203, \"Liveness\": 0.279, \"Tempo\": 178.83, \"Duration (ms)\": 225266.0, \"Valence\": 0.246, \"Chord\": \"D\"}, {\"Index\": 1420, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"That's What Love Is\", \"Streams\": 5440037, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2hLu8L8SNfCN4yKyPdX0h3\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 59.0, \"Danceability\": 0.639, \"Energy\": 0.437, \"Loudness\": -6.959, \"Speechiness\": 0.0355, \"Acousticness\": 0.692, \"Liveness\": 0.12, \"Tempo\": 147.575, \"Duration (ms)\": 165120.0, \"Valence\": 0.751, \"Chord\": \"A\"}, {\"Index\": 1421, \"Highest Charting Position\": 80, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Forever Yours - Avicii Tribute\", \"Streams\": 5421905, \"Artist\": \"Kygo, Sandro Cavazza\", \"Artist Followers\": 1251372.0, \"Song ID\": \"418ohXmKnlngIosIn6gG0H\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-10\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 15.0, \"Danceability\": 0.53, \"Energy\": 0.612, \"Loudness\": -8.794, \"Speechiness\": 0.0518, \"Acousticness\": 0.253, \"Liveness\": 0.246, \"Tempo\": 119.255, \"Duration (ms)\": 193847.0, \"Valence\": 0.433, \"Chord\": \"A#/Bb\"}, {\"Index\": 1422, \"Highest Charting Position\": 68, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Baby\", \"Streams\": 5376451, \"Artist\": \"Joker Bra, VIZE\", \"Artist Followers\": 191521.0, \"Song ID\": \"1V7JaMp11LKGwKiVmSetf0\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-01-30\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 63.0, \"Danceability\": 0.771, \"Energy\": 0.921, \"Loudness\": -4.228, \"Speechiness\": 0.109, \"Acousticness\": 0.166, \"Liveness\": 0.119, \"Tempo\": 128.021, \"Duration (ms)\": 148125.0, \"Valence\": 0.56, \"Chord\": \"C#/Db\"}, {\"Index\": 1423, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"One More Year\", \"Streams\": 5279739, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"5ozqshq2dtU7SYCpCBu0NE\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 56.0, \"Danceability\": 0.602, \"Energy\": 0.88, \"Loudness\": -5.414, \"Speechiness\": 0.0354, \"Acousticness\": 0.057, \"Liveness\": 0.284, \"Tempo\": 114.009, \"Duration (ms)\": 324013.0, \"Valence\": 0.493, \"Chord\": \"C#/Db\"}, {\"Index\": 1424, \"Highest Charting Position\": 14, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Good News\", \"Streams\": 5210780, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"1DWZUa5Mzf2BwzpHtgbHPY\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 75.0, \"Danceability\": 0.794, \"Energy\": 0.32, \"Loudness\": -12.92, \"Speechiness\": 0.173, \"Acousticness\": 0.853, \"Liveness\": 0.112, \"Tempo\": 174.088, \"Duration (ms)\": 342040.0, \"Valence\": 0.241, \"Chord\": \"C#/Db\"}, {\"Index\": 1425, \"Highest Charting Position\": 141, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"wish you were gay\", \"Streams\": 5187997, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"3Fj47GNK2kUF0uaEDgXLaD\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-03-29\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.853, \"Energy\": 0.351, \"Loudness\": -10.198, \"Speechiness\": 0.241, \"Acousticness\": 0.39, \"Liveness\": 0.752, \"Tempo\": 118.028, \"Duration (ms)\": 221543.0, \"Valence\": 0.282, \"Chord\": \"G\"}, {\"Index\": 1426, \"Highest Charting Position\": 61, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Only The Young - Featured in Miss Americana\", \"Streams\": 5111068, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2slqvGLwzZZYsT4K4Y1GBC\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 63.0, \"Danceability\": 0.56, \"Energy\": 0.78, \"Loudness\": -4.895, \"Speechiness\": 0.0517, \"Acousticness\": 0.00244, \"Liveness\": 0.0714, \"Tempo\": 93.516, \"Duration (ms)\": 157507.0, \"Valence\": 0.602, \"Chord\": \"F\"}, {\"Index\": 1427, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Lost In Yesterday\", \"Streams\": 5096624, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"5JWPUEov2wlX7c0jhYZpeB\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 69.0, \"Danceability\": 0.569, \"Energy\": 0.84, \"Loudness\": -4.123, \"Speechiness\": 0.118, \"Acousticness\": 0.0295, \"Liveness\": 0.0995, \"Tempo\": 183.059, \"Duration (ms)\": 249587.0, \"Valence\": 0.749, \"Chord\": \"C#/Db\"}, {\"Index\": 1428, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"At Least For Now\", \"Streams\": 5033764, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6VLkgf5YmLixsabdqiCVGU\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 54.0, \"Danceability\": 0.375, \"Energy\": 0.304, \"Loudness\": -9.897, \"Speechiness\": 0.0325, \"Acousticness\": 0.683, \"Liveness\": 0.196, \"Tempo\": 83.832, \"Duration (ms)\": 149653.0, \"Valence\": 0.295, \"Chord\": \"A\"}, {\"Index\": 1429, \"Highest Charting Position\": 167, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"you should see me in a crown\", \"Streams\": 4988054, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6WbvBhwCaUuYHcHGEuVgqo\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 0.0, \"Danceability\": 0.683, \"Energy\": 0.534, \"Loudness\": -10.348, \"Speechiness\": 0.189, \"Acousticness\": 0.519, \"Liveness\": 0.148, \"Tempo\": 150.469, \"Duration (ms)\": 180567.0, \"Valence\": 0.284, \"Chord\": \"E\"}, {\"Index\": 1430, \"Highest Charting Position\": 186, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Too Good At Goodbyes\", \"Streams\": 4984764, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"3VlbOrM6nYPprVvzBZllE5\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2017-11-03\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 72.0, \"Danceability\": 0.681, \"Energy\": 0.372, \"Loudness\": -8.237, \"Speechiness\": 0.0432, \"Acousticness\": 0.64, \"Liveness\": 0.169, \"Tempo\": 91.873, \"Duration (ms)\": 201000.0, \"Valence\": 0.476, \"Chord\": \"F\"}, {\"Index\": 1431, \"Highest Charting Position\": 7, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Intentions\", \"Streams\": 28509534, \"Artist\": \"Justin Bieber, Quavo\", \"Artist Followers\": 48544923.0, \"Song ID\": \"4umIPjkehX1r7uhmGvXiSV\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-07--2020-02-14\", \"Popularity\": 77.0, \"Danceability\": 0.806, \"Energy\": 0.546, \"Loudness\": -6.637, \"Speechiness\": 0.0575, \"Acousticness\": 0.3, \"Liveness\": 0.102, \"Tempo\": 147.986, \"Duration (ms)\": 212867.0, \"Valence\": 0.874, \"Chord\": \"A\"}, {\"Index\": 1432, \"Highest Charting Position\": 105, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Yikes\", \"Streams\": 6561188, \"Artist\": \"Nicki Minaj\", \"Artist Followers\": 22170982.0, \"Song ID\": \"75dLEqanQTupF3dtP9exT5\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'pop rap', 'post-teen pop', 'queens hip hop']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-02-07--2020-02-14\", \"Popularity\": 70.0, \"Danceability\": 0.911, \"Energy\": 0.637, \"Loudness\": -8.381, \"Speechiness\": 0.447, \"Acousticness\": 0.0409, \"Liveness\": 0.238, \"Tempo\": 149.996, \"Duration (ms)\": 156882.0, \"Valence\": 0.66, \"Chord\": \"G#/Ab\"}, {\"Index\": 1433, \"Highest Charting Position\": 66, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Yellow Hearts\", \"Streams\": 6554824, \"Artist\": \"Ant Saunders\", \"Artist Followers\": 82522.0, \"Song ID\": \"2W4yABdLc4Jnds67Poi5Nl\", \"Genre\": \"['chill r&b', 'pop']\", \"Release Date\": \"2019-06-18\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.866, \"Energy\": 0.438, \"Loudness\": -8.943, \"Speechiness\": 0.0719, \"Acousticness\": 0.177, \"Liveness\": 0.0743, \"Tempo\": 129.039, \"Duration (ms)\": 223258.0, \"Valence\": 0.695, \"Chord\": \"G\"}, {\"Index\": 1434, \"Highest Charting Position\": 120, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Birthday\", \"Streams\": 6207326, \"Artist\": \"Anne-Marie\", \"Artist Followers\": 8153871.0, \"Song ID\": \"5hff5RQeE84pznOt8WEWeO\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-02-07--2020-02-14\", \"Popularity\": 65.0, \"Danceability\": 0.609, \"Energy\": 0.785, \"Loudness\": -3.32, \"Speechiness\": 0.0891, \"Acousticness\": 0.0502, \"Liveness\": 0.171, \"Tempo\": 151.995, \"Duration (ms)\": 181467.0, \"Valence\": 0.756, \"Chord\": \"B\"}, {\"Index\": 1435, \"Highest Charting Position\": 16, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"HIGHEST IN THE ROOM (feat. ROSAL\\u00cdA & Lil Baby) - REMIX\", \"Streams\": 6107499, \"Artist\": \"Travis Scott\", \"Artist Followers\": 437907.0, \"Song ID\": \"7h0d2h0fUmzbs7zeFigJPn\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.559, \"Energy\": 0.491, \"Loudness\": -6.406, \"Speechiness\": 0.0346, \"Acousticness\": 0.0567, \"Liveness\": 0.0992, \"Tempo\": 153.131, \"Duration (ms)\": 244874.0, \"Valence\": 0.114, \"Chord\": \"D\"}, {\"Index\": 1436, \"Highest Charting Position\": 65, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Good as Hell (feat. Ariana Grande) - Remix\", \"Streams\": 6066001, \"Artist\": \"Lizzo\", \"Artist Followers\": 3991674.0, \"Song ID\": \"07Oz5StQ7GRoygNLaXs2pd\", \"Genre\": \"['dance pop', 'escape room', 'minnesota hip hop', 'pop', 'pop rap', 'post-teen pop', 'trap queen']\", \"Release Date\": \"2016\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.668, \"Energy\": 0.892, \"Loudness\": -3.001, \"Speechiness\": 0.0645, \"Acousticness\": 0.298, \"Liveness\": 0.735, \"Tempo\": 95.927, \"Duration (ms)\": 159011.0, \"Valence\": 0.478, \"Chord\": \"F\"}, {\"Index\": 1437, \"Highest Charting Position\": 70, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"I Do It (ft. Big Sean, Lil Baby)\", \"Streams\": 5561205, \"Artist\": \"Lil Wayne\", \"Artist Followers\": 10710088.0, \"Song ID\": \"1bRO28yzxgO3y3UmNR29TZ\", \"Genre\": \"['hip hop', 'new orleans rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 60.0, \"Danceability\": 0.804, \"Energy\": 0.528, \"Loudness\": -3.231, \"Speechiness\": 0.378, \"Acousticness\": 0.125, \"Liveness\": 0.41, \"Tempo\": 138.005, \"Duration (ms)\": 184440.0, \"Valence\": 0.321, \"Chord\": \"C#/Db\"}, {\"Index\": 1438, \"Highest Charting Position\": 45, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Get Me\", \"Streams\": 5236560, \"Artist\": \"Justin Bieber, Kehlani\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5VwwpU7KsLhgfbMEecedhJ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 61.0, \"Danceability\": 0.832, \"Energy\": 0.508, \"Loudness\": -6.913, \"Speechiness\": 0.149, \"Acousticness\": 0.0492, \"Liveness\": 0.107, \"Tempo\": 109.352, \"Duration (ms)\": 185427.0, \"Valence\": 0.75, \"Chord\": \"F#/Gb\"}, {\"Index\": 1439, \"Highest Charting Position\": 95, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Yo x Ti, Tu x Mi\", \"Streams\": 5202210, \"Artist\": \"ROSAL\\u00cdA, Ozuna\", \"Artist Followers\": 4769627.0, \"Song ID\": \"7BlBVFwvbWvcwNcUarQmjk\", \"Genre\": \"['r&b en espanol']\", \"Release Date\": \"2019-08-15\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.78, \"Energy\": 0.759, \"Loudness\": -3.292, \"Speechiness\": 0.225, \"Acousticness\": 0.462, \"Liveness\": 0.143, \"Tempo\": 91.952, \"Duration (ms)\": 201040.0, \"Valence\": 0.579, \"Chord\": \"C#/Db\"}, {\"Index\": 1440, \"Highest Charting Position\": 161, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"DJ No Pare (feat. Zion, Dalex, Lenny Tav\\u00e1rez) - Remix\", \"Streams\": 5148516, \"Artist\": \"Justin Quiles, Natti Natasha, Farruko\", \"Artist Followers\": 2897862.0, \"Song ID\": \"1ndyl3wJCFs872XZ3ztPk6\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.743, \"Energy\": 0.709, \"Loudness\": -3.922, \"Speechiness\": 0.0879, \"Acousticness\": 0.0451, \"Liveness\": 0.0809, \"Tempo\": 170.001, \"Duration (ms)\": 258600.0, \"Valence\": 0.831, \"Chord\": \"D#/Eb\"}, {\"Index\": 1441, \"Highest Charting Position\": 160, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"EARFQUAKE\", \"Streams\": 5079657, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6782693.0, \"Song ID\": \"5hVghJ4KaYES3BFUATCYn0\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 79.0, \"Danceability\": 0.554, \"Energy\": 0.498, \"Loudness\": -8.866, \"Speechiness\": 0.0685, \"Acousticness\": 0.23, \"Liveness\": 0.795, \"Tempo\": 79.635, \"Duration (ms)\": 190067.0, \"Valence\": 0.413, \"Chord\": \"A\"}, {\"Index\": 1442, \"Highest Charting Position\": 157, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Pa' Olvidarme De Ella\", \"Streams\": 5066711, \"Artist\": \"Piso 21, Christian Nodal\", \"Artist Followers\": 7226268.0, \"Song ID\": \"1cVlW9WQiGlFdWUXFdFZGh\", \"Genre\": \"['colombian pop', 'latin', 'latin pop', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.728, \"Energy\": 0.542, \"Loudness\": -5.195, \"Speechiness\": 0.0514, \"Acousticness\": 0.259, \"Liveness\": 0.136, \"Tempo\": 90.016, \"Duration (ms)\": 227234.0, \"Valence\": 0.637, \"Chord\": \"C\"}, {\"Index\": 1443, \"Highest Charting Position\": 89, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Loco Contigo (feat. J. Balvin & Tyga)\", \"Streams\": 5013732, \"Artist\": \"DJ Snake, J Balvin\", \"Artist Followers\": 7408249.0, \"Song ID\": \"6osaMSJh9NguagEDQcZaKx\", \"Genre\": \"['dance pop', 'edm', 'electronic trap', 'pop', 'pop dance']\", \"Release Date\": \"2019-07-25\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.694, \"Energy\": 0.758, \"Loudness\": -2.986, \"Speechiness\": 0.218, \"Acousticness\": 0.278, \"Liveness\": 0.102, \"Tempo\": 192.091, \"Duration (ms)\": 185195.0, \"Valence\": 0.371, \"Chord\": \"B\"}, {\"Index\": 1444, \"Highest Charting Position\": 54, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Psycho\", \"Streams\": 4991751, \"Artist\": \"Red Velvet\", \"Artist Followers\": 5688315.0, \"Song ID\": \"3CYH422oy1cZNoo0GTG1TK\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2019-12-23\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.664, \"Energy\": 0.666, \"Loudness\": -2.203, \"Speechiness\": 0.0446, \"Acousticness\": 0.193, \"Liveness\": 0.0854, \"Tempo\": 139.987, \"Duration (ms)\": 210560.0, \"Valence\": 0.405, \"Chord\": \"G#/Ab\"}, {\"Index\": 1445, \"Highest Charting Position\": 113, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Suge\", \"Streams\": 4986299, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"2gwkD6igEhQbDQegRCcdoB\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-03-01\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.876, \"Energy\": 0.662, \"Loudness\": -6.482, \"Speechiness\": 0.426, \"Acousticness\": 0.0608, \"Liveness\": 0.127, \"Tempo\": 75.445, \"Duration (ms)\": 163320.0, \"Valence\": 0.844, \"Chord\": \"D\"}, {\"Index\": 1446, \"Highest Charting Position\": 101, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Con Altura\", \"Streams\": 4961249, \"Artist\": \"ROSAL\\u00cdA, J Balvin, El Guincho\", \"Artist Followers\": 4769627.0, \"Song ID\": \"2qG5sZ7Si6sdK74qLxedYM\", \"Genre\": \"['r&b en espanol']\", \"Release Date\": \"2019-03-28\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.882, \"Energy\": 0.689, \"Loudness\": -4.027, \"Speechiness\": 0.124, \"Acousticness\": 0.39, \"Liveness\": 0.0501, \"Tempo\": 97.963, \"Duration (ms)\": 161627.0, \"Valence\": 0.746, \"Chord\": \"F#/Gb\"}, {\"Index\": 1447, \"Highest Charting Position\": 140, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Only Human\", \"Streams\": 4953866, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"0DiDStADDVh3SvAsoJAFMk\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-06-07\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.795, \"Energy\": 0.496, \"Loudness\": -5.883, \"Speechiness\": 0.0722, \"Acousticness\": 0.108, \"Liveness\": 0.0645, \"Tempo\": 94.01, \"Duration (ms)\": 183000.0, \"Valence\": 0.874, \"Chord\": \"C\"}, {\"Index\": 1448, \"Highest Charting Position\": 51, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Eleven\", \"Streams\": 4947780, \"Artist\": \"Khalid\", \"Artist Followers\": 14190858.0, \"Song ID\": \"18O00Y7yrkJ0pRXm1n21Og\", \"Genre\": \"['pop']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 68.0, \"Danceability\": 0.679, \"Energy\": 0.408, \"Loudness\": -9.754, \"Speechiness\": 0.0882, \"Acousticness\": 0.133, \"Liveness\": 0.23, \"Tempo\": 129.079, \"Duration (ms)\": 206080.0, \"Valence\": 0.151, \"Chord\": \"E\"}, {\"Index\": 1449, \"Highest Charting Position\": 135, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Talk (feat. Disclosure)\", \"Streams\": 4940984, \"Artist\": \"Khalid\", \"Artist Followers\": 14190858.0, \"Song ID\": \"6TqXcAFInzjp0bODyvrWEq\", \"Genre\": \"['pop']\", \"Release Date\": \"2019-04-05\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.9, \"Energy\": 0.4, \"Loudness\": -8.575, \"Speechiness\": 0.127, \"Acousticness\": 0.0516, \"Liveness\": 0.0599, \"Tempo\": 135.984, \"Duration (ms)\": 197573.0, \"Valence\": 0.346, \"Chord\": \"C\"}, {\"Index\": 1450, \"Highest Charting Position\": 117, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Hot (Remix) [feat. Gunna and Travis Scott]\", \"Streams\": 4905155, \"Artist\": \"Travis Scott, Young Thug\", \"Artist Followers\": 3337982.0, \"Song ID\": \"56AMYGJzxBO6p8v0wEe9de\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-11-01\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.845, \"Energy\": 0.631, \"Loudness\": -8.206, \"Speechiness\": 0.216, \"Acousticness\": 0.188, \"Liveness\": 0.0806, \"Tempo\": 111.983, \"Duration (ms)\": 279907.0, \"Valence\": 0.545, \"Chord\": \"G\"}, {\"Index\": 1451, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Weiss\", \"Streams\": 4872077, \"Artist\": \"Samra\", \"Artist Followers\": 1045091.0, \"Song ID\": \"38YP1STiBe3AZevFFJILf4\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-02-07--2020-02-14\", \"Popularity\": 56.0, \"Danceability\": 0.6, \"Energy\": 0.525, \"Loudness\": -6.585, \"Speechiness\": 0.423, \"Acousticness\": 0.393, \"Liveness\": 0.111, \"Tempo\": 96.989, \"Duration (ms)\": 162702.0, \"Valence\": 0.436, \"Chord\": \"D\"}, {\"Index\": 1452, \"Highest Charting Position\": 105, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Con Calma\", \"Streams\": 4861378, \"Artist\": \"Daddy Yankee, Snow\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3GIhMWNecxw8GyCFwviF6v\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 3.0, \"Danceability\": 0.737, \"Energy\": 0.86, \"Loudness\": -2.652, \"Speechiness\": 0.0594, \"Acousticness\": 0.11, \"Liveness\": 0.0574, \"Tempo\": 93.989, \"Duration (ms)\": 193227.0, \"Valence\": 0.656, \"Chord\": \"G#/Ab\"}, {\"Index\": 1453, \"Highest Charting Position\": 148, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"MIDDLE CHILD\", \"Streams\": 4836113, \"Artist\": \"J. Cole\", \"Artist Followers\": 14103694.0, \"Song ID\": \"2JvzF1RMd7lE3KmFlsyZD8\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2019-01-23\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.837, \"Energy\": 0.364, \"Loudness\": -11.713, \"Speechiness\": 0.276, \"Acousticness\": 0.149, \"Liveness\": 0.271, \"Tempo\": 123.984, \"Duration (ms)\": 213594.0, \"Valence\": 0.463, \"Chord\": \"G#/Ab\"}, {\"Index\": 1454, \"Highest Charting Position\": 136, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Otro Trago - Remix\", \"Streams\": 4803294, \"Artist\": \"Sech, Ozuna, Anuel AA, Darell, Nicky Jam\", \"Artist Followers\": 8766508.0, \"Song ID\": \"4bTZeO72FwMa6wKOiqoynL\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-07-26\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.725, \"Energy\": 0.79, \"Loudness\": -2.331, \"Speechiness\": 0.197, \"Acousticness\": 0.0711, \"Liveness\": 0.0602, \"Tempo\": 175.988, \"Duration (ms)\": 287773.0, \"Valence\": 0.763, \"Chord\": \"C\"}, {\"Index\": 1455, \"Highest Charting Position\": 113, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"FML\", \"Streams\": 6350496, \"Artist\": \"Arizona Zervas\", \"Artist Followers\": 621200.0, \"Song ID\": \"6lruHh1jF7ezgbLv72xYmf\", \"Genre\": \"['pop rap', 'rhode island rap']\", \"Release Date\": \"2018-06-03\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 74.0, \"Danceability\": 0.822, \"Energy\": 0.575, \"Loudness\": -5.95, \"Speechiness\": 0.0934, \"Acousticness\": 0.113, \"Liveness\": 0.106, \"Tempo\": 100.087, \"Duration (ms)\": 223000.0, \"Valence\": 0.616, \"Chord\": \"F\"}, {\"Index\": 1456, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"King Of My City\", \"Streams\": 5922748, \"Artist\": \"A Boogie Wit da Hoodie\", \"Artist Followers\": 1251372.0, \"Song ID\": \"4JEz0Iz8PnzHe5B0CkYSjP\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 0.0, \"Danceability\": 0.679, \"Energy\": 0.679, \"Loudness\": -6.747, \"Speechiness\": 0.167, \"Acousticness\": 0.443, \"Liveness\": 0.153, \"Tempo\": 119.921, \"Duration (ms)\": 148676.0, \"Valence\": 0.245, \"Chord\": \"E\"}, {\"Index\": 1457, \"Highest Charting Position\": 22, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Those Kinda Nights (feat. Ed Sheeran)\", \"Streams\": 5823422, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"0VSzREd1OjEWJ9tXoFHRQH\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 66.0, \"Danceability\": 0.794, \"Energy\": 0.637, \"Loudness\": -6.29, \"Speechiness\": 0.339, \"Acousticness\": 0.028, \"Liveness\": 0.0919, \"Tempo\": 103.868, \"Duration (ms)\": 177693.0, \"Valence\": 0.393, \"Chord\": \"E\"}, {\"Index\": 1458, \"Highest Charting Position\": 136, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Mon Ami\", \"Streams\": 5774770, \"Artist\": \"Samra\", \"Artist Followers\": 1045091.0, \"Song ID\": \"1R4xkZXQUQ8QJtAdwHkSgC\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-01-29\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 53.0, \"Danceability\": 0.801, \"Energy\": 0.731, \"Loudness\": -3.723, \"Speechiness\": 0.383, \"Acousticness\": 0.188, \"Liveness\": 0.111, \"Tempo\": 105.666, \"Duration (ms)\": 138409.0, \"Valence\": 0.537, \"Chord\": \"G#/Ab\"}, {\"Index\": 1459, \"Highest Charting Position\": 120, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Break My Stride\", \"Streams\": 5312936, \"Artist\": \"Matthew Wilder\", \"Artist Followers\": 30386.0, \"Song ID\": \"1mCsF9Tw4AkIZOjvZbZZdT\", \"Genre\": \"['new wave pop']\", \"Release Date\": \"1983-03-19\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 73.0, \"Danceability\": 0.917, \"Energy\": 0.588, \"Loudness\": -11.047, \"Speechiness\": 0.0607, \"Acousticness\": 0.195, \"Liveness\": 0.0914, \"Tempo\": 110.077, \"Duration (ms)\": 184480.0, \"Valence\": 0.828, \"Chord\": \"A#/Bb\"}, {\"Index\": 1460, \"Highest Charting Position\": 76, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Kein Wort\", \"Streams\": 5208651, \"Artist\": \"Juju, Loredana, Miksu / Macloud\", \"Artist Followers\": 486474.0, \"Song ID\": \"1hoLUVBx0ixX3kn0EX0P5n\", \"Genre\": \"['frauenrap', 'german hip hop', 'german pop']\", \"Release Date\": \"2020-01-16\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.746, \"Energy\": 0.592, \"Loudness\": -6.861, \"Speechiness\": 0.0914, \"Acousticness\": 0.462, \"Liveness\": 0.187, \"Tempo\": 160.065, \"Duration (ms)\": 162094.0, \"Valence\": 0.629, \"Chord\": \"F#/Gb\"}, {\"Index\": 1461, \"Highest Charting Position\": 86, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Graveyard\", \"Streams\": 5044853, \"Artist\": \"Halsey\", \"Artist Followers\": 15663384.0, \"Song ID\": \"2ufmtcIFdFpuUYBPXK5f67\", \"Genre\": \"['dance pop', 'electropop', 'etherpop', 'indie poptimism', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.667, \"Energy\": 0.583, \"Loudness\": -5.127, \"Speechiness\": 0.0747, \"Acousticness\": 0.231, \"Liveness\": 0.181, \"Tempo\": 92.043, \"Duration (ms)\": 181806.0, \"Valence\": 0.187, \"Chord\": \"B\"}, {\"Index\": 1462, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Wake Up Call (feat. Trippie Redd)\", \"Streams\": 5029979, \"Artist\": \"KSI\", \"Artist Followers\": 2010879.0, \"Song ID\": \"5MYzajZVxBaPT2JUSRa99L\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2020-01-27\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 56.0, \"Danceability\": 0.642, \"Energy\": 0.669, \"Loudness\": -5.774, \"Speechiness\": 0.0486, \"Acousticness\": 0.318, \"Liveness\": 0.119, \"Tempo\": 156.084, \"Duration (ms)\": 175067.0, \"Valence\": 0.227, \"Chord\": \"F#/Gb\"}, {\"Index\": 1463, \"Highest Charting Position\": 131, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Turn Me On (feat. Vula)\", \"Streams\": 4925843, \"Artist\": \"Riton, Oliver Heldens\", \"Artist Followers\": 83743.0, \"Song ID\": \"0qaWEvPkts34WF68r8Dzx9\", \"Genre\": \"['dance pop', 'house', 'pop dance', 'tropical house', 'uk dance']\", \"Release Date\": \"2019-09-13\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.737, \"Energy\": 0.828, \"Loudness\": -4.711, \"Speechiness\": 0.0396, \"Acousticness\": 0.0149, \"Liveness\": 0.0862, \"Tempo\": 124.051, \"Duration (ms)\": 208474.0, \"Valence\": 0.517, \"Chord\": \"B\"}, {\"Index\": 1464, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Hips Don't Lie (feat. Wyclef Jean)\", \"Streams\": 4918636, \"Artist\": \"Shakira\", \"Artist Followers\": 22136717.0, \"Song ID\": \"3ZFTkvIE7kyPt6Nu3PEa7V\", \"Genre\": \"['colombian pop', 'dance pop', 'latin', 'latin pop', 'pop']\", \"Release Date\": \"2005-11-28\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 83.0, \"Danceability\": 0.778, \"Energy\": 0.824, \"Loudness\": -5.892, \"Speechiness\": 0.0707, \"Acousticness\": 0.284, \"Liveness\": 0.405, \"Tempo\": 100.024, \"Duration (ms)\": 218093.0, \"Valence\": 0.758, \"Chord\": \"A#/Bb\"}, {\"Index\": 1465, \"Highest Charting Position\": 106, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Liar\", \"Streams\": 4896939, \"Artist\": \"Camila Cabello\", \"Artist Followers\": 22698747.0, \"Song ID\": \"7LzouaWGFCy4tkXDOOnEyM\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-09-04\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 69.0, \"Danceability\": 0.74, \"Energy\": 0.498, \"Loudness\": -6.684, \"Speechiness\": 0.0456, \"Acousticness\": 0.0169, \"Liveness\": 0.319, \"Tempo\": 98.016, \"Duration (ms)\": 207039.0, \"Valence\": 0.652, \"Chord\": \"B\"}, {\"Index\": 1466, \"Highest Charting Position\": 191, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Going Bad (feat. Drake)\", \"Streams\": 4889500, \"Artist\": \"Meek Mill\", \"Artist Followers\": 5241145.0, \"Song ID\": \"2IRZnDFmlqMuOrYOLnZZyc\", \"Genre\": \"['hip hop', 'philly rap', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2018-11-30\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.889, \"Energy\": 0.496, \"Loudness\": -6.365, \"Speechiness\": 0.0905, \"Acousticness\": 0.259, \"Liveness\": 0.252, \"Tempo\": 86.003, \"Duration (ms)\": 180522.0, \"Valence\": 0.544, \"Chord\": \"E\"}, {\"Index\": 1467, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"ME! (feat. Brendon Urie of Panic! At The Disco)\", \"Streams\": 4884909, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2Rk4JlNc2TPmZe2af99d45\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 77.0, \"Danceability\": 0.61, \"Energy\": 0.83, \"Loudness\": -4.105, \"Speechiness\": 0.0571, \"Acousticness\": 0.033, \"Liveness\": 0.118, \"Tempo\": 182.162, \"Duration (ms)\": 193000.0, \"Valence\": 0.728, \"Chord\": \"C\"}, {\"Index\": 1468, \"Highest Charting Position\": 134, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Panini\", \"Streams\": 4867723, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5488666.0, \"Song ID\": \"1000nHvUdawXuUHgBod4Wv\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2019-09-13\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.703, \"Energy\": 0.594, \"Loudness\": -6.146, \"Speechiness\": 0.0752, \"Acousticness\": 0.342, \"Liveness\": 0.123, \"Tempo\": 153.848, \"Duration (ms)\": 114893.0, \"Valence\": 0.475, \"Chord\": \"F\"}, {\"Index\": 1469, \"Highest Charting Position\": 191, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"idontwannabeyouanymore\", \"Streams\": 4824483, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"41zXlQxzTi6cGAjpOXyLYH\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2017-12-22\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 78.0, \"Danceability\": 0.483, \"Energy\": 0.412, \"Loudness\": -8.461, \"Speechiness\": 0.0402, \"Acousticness\": 0.737, \"Liveness\": 0.116, \"Tempo\": 170.163, \"Duration (ms)\": 203569.0, \"Valence\": 0.247, \"Chord\": \"G\"}, {\"Index\": 1470, \"Highest Charting Position\": 158, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"The London (feat. J. Cole & Travis Scott)\", \"Streams\": 4791732, \"Artist\": \"J. Cole, Young Thug\", \"Artist Followers\": 6383275.0, \"Song ID\": \"7DcvwMAiqKJQD1rrdfxSDx\", \"Genre\": \"['atl hip hop', 'atl trap', 'gangster rap', 'hip hop', 'melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2019-05-23\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.796, \"Energy\": 0.586, \"Loudness\": -6.946, \"Speechiness\": 0.147, \"Acousticness\": 0.0247, \"Liveness\": 0.132, \"Tempo\": 97.981, \"Duration (ms)\": 200107.0, \"Valence\": 0.179, \"Chord\": \"E\"}, {\"Index\": 1471, \"Highest Charting Position\": 123, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"223's (feat. 9lokknine)\", \"Streams\": 4781697, \"Artist\": \"YNW Melly\", \"Artist Followers\": 6332535.0, \"Song ID\": \"4sjiIpEv617LDXaidKioOI\", \"Genre\": \"['melodic rap', 'trap']\", \"Release Date\": \"2019-08-09\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.932, \"Energy\": 0.547, \"Loudness\": -7.787, \"Speechiness\": 0.333, \"Acousticness\": 0.0388, \"Liveness\": 0.0924, \"Tempo\": 94.998, \"Duration (ms)\": 176640.0, \"Valence\": 0.695, \"Chord\": \"C\"}, {\"Index\": 1472, \"Highest Charting Position\": 26, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Darkness\", \"Streams\": 7618955, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5SiZJoLXp3WOl3J4C8IK0d\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 65.0, \"Danceability\": 0.671, \"Energy\": 0.623, \"Loudness\": -7.161, \"Speechiness\": 0.308, \"Acousticness\": 0.00998, \"Liveness\": 0.643, \"Tempo\": 75.055, \"Duration (ms)\": 337147.0, \"Valence\": 0.195, \"Chord\": \"D\"}, {\"Index\": 1473, \"Highest Charting Position\": 30, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"You Gon\\u2019 Learn (feat. Royce Da 5'9\\\" & White Gold)\", \"Streams\": 7157402, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"0GQ5bFTVFFKpwNPc7KwQnB\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 66.0, \"Danceability\": 0.68, \"Energy\": 0.82, \"Loudness\": -4.197, \"Speechiness\": 0.151, \"Acousticness\": 0.0614, \"Liveness\": 0.597, \"Tempo\": 140.033, \"Duration (ms)\": 234653.0, \"Valence\": 0.243, \"Chord\": \"E\"}, {\"Index\": 1474, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Blue World\", \"Streams\": 7060589, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"2hwOoMtWPtTSSn6WHV7Vp5\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 75.0, \"Danceability\": 0.742, \"Energy\": 0.553, \"Loudness\": -8.98, \"Speechiness\": 0.419, \"Acousticness\": 0.389, \"Liveness\": 0.0694, \"Tempo\": 84.931, \"Duration (ms)\": 209440.0, \"Valence\": 0.508, \"Chord\": \"G#/Ab\"}, {\"Index\": 1475, \"Highest Charting Position\": 99, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Liberdade Provis\\u00f3ria\", \"Streams\": 6442626, \"Artist\": \"Henrique & Juliano\", \"Artist Followers\": 13312073.0, \"Song ID\": \"1vG3YuKRYqPwTmNmYgqkpg\", \"Genre\": \"['sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.668, \"Energy\": 0.684, \"Loudness\": -5.937, \"Speechiness\": 0.0527, \"Acousticness\": 0.627, \"Liveness\": 0.923, \"Tempo\": 108.138, \"Duration (ms)\": 187986.0, \"Valence\": 0.7, \"Chord\": \"C#/Db\"}, {\"Index\": 1476, \"Highest Charting Position\": 32, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Unaccommodating (feat. Young M.A)\", \"Streams\": 6374807, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"0q2vG0UVuy6ajjcpkQHdZM\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 65.0, \"Danceability\": 0.852, \"Energy\": 0.752, \"Loudness\": -5.793, \"Speechiness\": 0.0597, \"Acousticness\": 0.0169, \"Liveness\": 0.394, \"Tempo\": 89.95, \"Duration (ms)\": 216600.0, \"Valence\": 0.389, \"Chord\": \"C#/Db\"}, {\"Index\": 1477, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Donuts\", \"Streams\": 6113037, \"Artist\": \"Gzuz\", \"Artist Followers\": 1140383.0, \"Song ID\": \"5XVPNr0CAoUn1jD033Ucoo\", \"Genre\": \"['deep german hip hop', 'german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-02-13\", \"Weeks Charted\": \"2020-01-24--2020-01-31\", \"Popularity\": 62.0, \"Danceability\": 0.784, \"Energy\": 0.703, \"Loudness\": -7.491, \"Speechiness\": 0.236, \"Acousticness\": 0.0973, \"Liveness\": 0.0754, \"Tempo\": 141.035, \"Duration (ms)\": 162938.0, \"Valence\": 0.556, \"Chord\": \"B\"}, {\"Index\": 1478, \"Highest Charting Position\": 44, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Leaving Heaven (feat. Skylar Grey)\", \"Streams\": 5466161, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5CpsIb7SMFHjmAG8RvIWfq\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.661, \"Energy\": 0.748, \"Loudness\": -4.809, \"Speechiness\": 0.206, \"Acousticness\": 0.175, \"Liveness\": 0.254, \"Tempo\": 171.983, \"Duration (ms)\": 265947.0, \"Valence\": 0.509, \"Chord\": \"D\"}, {\"Index\": 1479, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Zu Ende\", \"Streams\": 5297101, \"Artist\": \"Samra, ELIF\", \"Artist Followers\": 1045091.0, \"Song ID\": \"0Vl4eICpXMjtiK0RhdaWov\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-01-23\", \"Weeks Charted\": \"2020-01-24--2020-01-31\", \"Popularity\": 57.0, \"Danceability\": 0.707, \"Energy\": 0.747, \"Loudness\": -5.212, \"Speechiness\": 0.279, \"Acousticness\": 0.307, \"Liveness\": 0.183, \"Tempo\": 80.025, \"Duration (ms)\": 197861.0, \"Valence\": 0.491, \"Chord\": \"G#/Ab\"}, {\"Index\": 1480, \"Highest Charting Position\": 171, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"B.I.T.C.H.\", \"Streams\": 5215211, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"06scTb0zbkxYNgpAB3J9fN\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-01-24\", \"Weeks Charted\": \"2020-01-24--2020-01-31\", \"Popularity\": 59.0, \"Danceability\": 0.742, \"Energy\": 0.731, \"Loudness\": -4.362, \"Speechiness\": 0.306, \"Acousticness\": 0.0851, \"Liveness\": 0.131, \"Tempo\": 174.019, \"Duration (ms)\": 183143.0, \"Valence\": 0.547, \"Chord\": \"B\"}, {\"Index\": 1481, \"Highest Charting Position\": 56, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Look At Her Now\", \"Streams\": 5066377, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 1251372.0, \"Song ID\": \"2XUPkAie1nz9SYIhbdIVWb\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.753, \"Energy\": 0.564, \"Loudness\": -7.908, \"Speechiness\": 0.251, \"Acousticness\": 0.114, \"Liveness\": 0.359, \"Tempo\": 77.341, \"Duration (ms)\": 162596.0, \"Valence\": 0.55, \"Chord\": \"A#/Bb\"}, {\"Index\": 1482, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Bi Sonraki Hayat\\u0131mda Gel\", \"Streams\": 5037967, \"Artist\": \"Murda, Ezhel\", \"Artist Followers\": 862965.0, \"Song ID\": \"5SYkeNpjhJPFUMOP5TK8iw\", \"Genre\": \"['basshall', 'turkish trap']\", \"Release Date\": \"2020-08-28\", \"Weeks Charted\": \"2020-01-24--2020-01-31\", \"Popularity\": 57.0, \"Danceability\": 0.933, \"Energy\": 0.448, \"Loudness\": -4.491, \"Speechiness\": 0.136, \"Acousticness\": 0.0253, \"Liveness\": 0.104, \"Tempo\": 103.981, \"Duration (ms)\": 167350.0, \"Valence\": 0.737, \"Chord\": \"G#/Ab\"}, {\"Index\": 1483, \"Highest Charting Position\": 126, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Legends\", \"Streams\": 4922369, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"1Knctxx9vGZxpZfF66BIEa\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2018-06-22\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.594, \"Energy\": 0.798, \"Loudness\": -5.244, \"Speechiness\": 0.0844, \"Acousticness\": 0.115, \"Liveness\": 0.143, \"Tempo\": 142.049, \"Duration (ms)\": 191840.0, \"Valence\": 0.381, \"Chord\": \"E\"}, {\"Index\": 1484, \"Highest Charting Position\": 157, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"11 PM\", \"Streams\": 4891989, \"Artist\": \"Maluma\", \"Artist Followers\": 26784251.0, \"Song ID\": \"7KbF6AdprOXEEHlsq11Z6d\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.777, \"Energy\": 0.712, \"Loudness\": -4.84, \"Speechiness\": 0.277, \"Acousticness\": 0.217, \"Liveness\": 0.091, \"Tempo\": 95.692, \"Duration (ms)\": 175733.0, \"Valence\": 0.68, \"Chord\": \"A#/Bb\"}, {\"Index\": 1485, \"Highest Charting Position\": 182, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Post Malone (feat. RANI)\", \"Streams\": 4855270, \"Artist\": \"Sam Feldt\", \"Artist Followers\": 639516.0, \"Song ID\": \"0qc4QlcCxVTGyShurEv1UU\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'pop', 'pop dance', 'pop edm', 'tropical house']\", \"Release Date\": \"2019-05-24\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.59, \"Energy\": 0.642, \"Loudness\": -3.87, \"Speechiness\": 0.122, \"Acousticness\": 0.0771, \"Liveness\": 0.105, \"Tempo\": 107.356, \"Duration (ms)\": 174444.0, \"Valence\": 0.651, \"Chord\": \"G\"}, {\"Index\": 1486, \"Highest Charting Position\": 52, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"In Too Deep\", \"Streams\": 4824037, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"7Dj2wqPYXfSRFwa6qyOztr\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.72, \"Energy\": 0.767, \"Loudness\": -5.839, \"Speechiness\": 0.214, \"Acousticness\": 0.0387, \"Liveness\": 0.202, \"Tempo\": 88.966, \"Duration (ms)\": 194707.0, \"Valence\": 0.595, \"Chord\": \"A#/Bb\"}, {\"Index\": 1487, \"Highest Charting Position\": 57, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Premonition - Intro\", \"Streams\": 10830400, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"7ccTcabbJlCJiIqtrSSwBk\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.847, \"Energy\": 0.637, \"Loudness\": -5.193, \"Speechiness\": 0.367, \"Acousticness\": 0.0258, \"Liveness\": 0.382, \"Tempo\": 165.979, \"Duration (ms)\": 173893.0, \"Valence\": 0.511, \"Chord\": \"C#/Db\"}, {\"Index\": 1488, \"Highest Charting Position\": 62, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"I Can See\", \"Streams\": 10086930, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"3R8CyhJfVjvgIROd5RSGhQ\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.699, \"Energy\": 0.503, \"Loudness\": -9.922, \"Speechiness\": 0.0882, \"Acousticness\": 0.391, \"Liveness\": 0.0996, \"Tempo\": 114.86, \"Duration (ms)\": 220853.0, \"Valence\": 0.0546, \"Chord\": \"F\"}, {\"Index\": 1489, \"Highest Charting Position\": 69, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Hand Me Downs\", \"Streams\": 9521654, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"2Yv2mHzr5AQavVdwQjEokV\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.677, \"Energy\": 0.33, \"Loudness\": -11.198, \"Speechiness\": 0.149, \"Acousticness\": 0.474, \"Liveness\": 0.064, \"Tempo\": 68.985, \"Duration (ms)\": 298440.0, \"Valence\": 0.336, \"Chord\": \"D\"}, {\"Index\": 1490, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"No Regrets (feat. Don Toliver)\", \"Streams\": 9493884, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"1lO9CZo6eDrOy0S7khgryG\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 63.0, \"Danceability\": 0.756, \"Energy\": 0.747, \"Loudness\": -5.407, \"Speechiness\": 0.046, \"Acousticness\": 0.0048, \"Liveness\": 0.588, \"Tempo\": 134.935, \"Duration (ms)\": 200947.0, \"Valence\": 0.0687, \"Chord\": \"A\"}, {\"Index\": 1491, \"Highest Charting Position\": 71, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Complicated\", \"Streams\": 9443725, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"3WfSNAoj2D8C9noPSGZZFM\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.831, \"Energy\": 0.36, \"Loudness\": -8.073, \"Speechiness\": 0.052, \"Acousticness\": 0.136, \"Liveness\": 0.0703, \"Tempo\": 75.014, \"Duration (ms)\": 232212.0, \"Valence\": 0.601, \"Chord\": \"C\"}, {\"Index\": 1492, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Lock It Up (feat. Anderson .Paak)\", \"Streams\": 9328951, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"1qwMkkRiD5jqLeUUjfgblh\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.848, \"Energy\": 0.745, \"Loudness\": -3.052, \"Speechiness\": 0.221, \"Acousticness\": 0.0949, \"Liveness\": 0.0796, \"Tempo\": 137.024, \"Duration (ms)\": 170227.0, \"Valence\": 0.516, \"Chord\": \"F#/Gb\"}, {\"Index\": 1493, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Marsh\", \"Streams\": 9260007, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"34d7sGX6WUqq8f04e7CSNF\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.871, \"Energy\": 0.493, \"Loudness\": -6.356, \"Speechiness\": 0.205, \"Acousticness\": 0.0134, \"Liveness\": 0.385, \"Tempo\": 144.989, \"Duration (ms)\": 200573.0, \"Valence\": 0.0495, \"Chord\": \"C#/Db\"}, {\"Index\": 1494, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Stepdad\", \"Streams\": 9159901, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"3QVHSV8YKYq4L8tI5rnFgj\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 61.0, \"Danceability\": 0.779, \"Energy\": 0.805, \"Loudness\": -3.121, \"Speechiness\": 0.178, \"Acousticness\": 0.018, \"Liveness\": 0.321, \"Tempo\": 145.68, \"Duration (ms)\": 213413.0, \"Valence\": 0.557, \"Chord\": \"C#/Db\"}, {\"Index\": 1495, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Yah Yah (feat. Royce Da 5'9\\\", Black Thought, Q-Tip & Denaun)\", \"Streams\": 8695060, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5mZXWEH2eh8zMZGCxT5aW0\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.458, \"Energy\": 0.966, \"Loudness\": -2.107, \"Speechiness\": 0.384, \"Acousticness\": 0.14, \"Liveness\": 0.11, \"Tempo\": 183.586, \"Duration (ms)\": 286960.0, \"Valence\": 0.356, \"Chord\": \"C#/Db\"}, {\"Index\": 1496, \"Highest Charting Position\": 90, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Never Love Again\", \"Streams\": 8335790, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"40YbWniIEmqy6s58fYXLUh\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.747, \"Energy\": 0.899, \"Loudness\": -5.125, \"Speechiness\": 0.246, \"Acousticness\": 0.1, \"Liveness\": 0.486, \"Tempo\": 92.029, \"Duration (ms)\": 177547.0, \"Valence\": 0.581, \"Chord\": \"F\"}, {\"Index\": 1497, \"Highest Charting Position\": 91, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Woods\", \"Streams\": 8329349, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"3Qa944OTMZkg8DHjET8JQv\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.779, \"Energy\": 0.362, \"Loudness\": -10.847, \"Speechiness\": 0.0474, \"Acousticness\": 0.135, \"Liveness\": 0.111, \"Tempo\": 85.011, \"Duration (ms)\": 286387.0, \"Valence\": 0.46, \"Chord\": \"C\"}, {\"Index\": 1498, \"Highest Charting Position\": 94, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Farewell\", \"Streams\": 8277608, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"74gykWHknHDrg4eMdcmdRq\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 61.0, \"Danceability\": 0.89, \"Energy\": 0.664, \"Loudness\": -6.625, \"Speechiness\": 0.106, \"Acousticness\": 0.00487, \"Liveness\": 0.257, \"Tempo\": 93.007, \"Duration (ms)\": 247733.0, \"Valence\": 0.467, \"Chord\": \"E\"}, {\"Index\": 1499, \"Highest Charting Position\": 98, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Everybody\", \"Streams\": 8172098, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"1OuN92HcVG6NVpWbeESNB3\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.875, \"Energy\": 0.599, \"Loudness\": -9.077, \"Speechiness\": 0.138, \"Acousticness\": 0.0333, \"Liveness\": 0.113, \"Tempo\": 152.061, \"Duration (ms)\": 256507.0, \"Valence\": 0.112, \"Chord\": \"A\"}, {\"Index\": 1500, \"Highest Charting Position\": 100, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Alfred - Interlude\", \"Streams\": 8030151, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"4EmunTy7kNBYQivOa8F6b8\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 57.0, \"Danceability\": 0.429, \"Energy\": 0.231, \"Loudness\": -20.43, \"Speechiness\": 0.402, \"Acousticness\": 0.878, \"Liveness\": 0.279, \"Tempo\": 74.545, \"Duration (ms)\": 30133.0, \"Valence\": 0.914, \"Chord\": \"F\"}, {\"Index\": 1501, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Little Engine\", \"Streams\": 7913461, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"4qNWEOMyexn7b8Icyk29t9\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.769, \"Energy\": 0.811, \"Loudness\": -4.162, \"Speechiness\": 0.228, \"Acousticness\": 0.0234, \"Liveness\": 0.0451, \"Tempo\": 155.081, \"Duration (ms)\": 177293.0, \"Valence\": 0.76, \"Chord\": \"A#/Bb\"}, {\"Index\": 1502, \"Highest Charting Position\": 113, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"I Will (feat. KXNG Crooked, Royce Da 5'9\\\" & Joell Ortiz)\", \"Streams\": 7115414, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"3CJbxqRQ0JNCqboWDNUUeX\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.635, \"Energy\": 0.543, \"Loudness\": -5.941, \"Speechiness\": 0.067, \"Acousticness\": 0.0454, \"Liveness\": 0.272, \"Tempo\": 98.743, \"Duration (ms)\": 303000.0, \"Valence\": 0.036, \"Chord\": \"G#/Ab\"}, {\"Index\": 1503, \"Highest Charting Position\": 115, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Still Learning\", \"Streams\": 7050815, \"Artist\": \"Halsey\", \"Artist Followers\": 15663384.0, \"Song ID\": \"2Mfv5HaqnI18Q9JRv9hqnn\", \"Genre\": \"['dance pop', 'electropop', 'etherpop', 'indie poptimism', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 59.0, \"Danceability\": 0.708, \"Energy\": 0.661, \"Loudness\": -6.543, \"Speechiness\": 0.0546, \"Acousticness\": 0.0396, \"Liveness\": 0.113, \"Tempo\": 102.046, \"Duration (ms)\": 211784.0, \"Valence\": 0.317, \"Chord\": \"C\"}, {\"Index\": 1504, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Surf\", \"Streams\": 6960699, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"1kwnxJNVl7cwcU98RvMBaR\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 67.0, \"Danceability\": 0.828, \"Energy\": 0.182, \"Loudness\": -13.066, \"Speechiness\": 0.166, \"Acousticness\": 0.754, \"Liveness\": 0.15, \"Tempo\": 147.279, \"Duration (ms)\": 330507.0, \"Valence\": 0.231, \"Chord\": \"C#/Db\"}, {\"Index\": 1505, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"That's On Me\", \"Streams\": 6462701, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"0udOCZp7yk0Ml92C0k8H8D\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.583, \"Energy\": 0.499, \"Loudness\": -10.086, \"Speechiness\": 0.0261, \"Acousticness\": 0.591, \"Liveness\": 0.33, \"Tempo\": 155.199, \"Duration (ms)\": 217868.0, \"Valence\": 0.342, \"Chord\": \"A#/Bb\"}, {\"Index\": 1506, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Once A Day\", \"Streams\": 6159873, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"26G5nmIx7Yvq79bIIluyZV\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 61.0, \"Danceability\": 0.762, \"Energy\": 0.054, \"Loudness\": -16.735, \"Speechiness\": 0.0503, \"Acousticness\": 0.947, \"Liveness\": 0.124, \"Tempo\": 96.838, \"Duration (ms)\": 160267.0, \"Valence\": 0.339, \"Chord\": \"D\"}, {\"Index\": 1507, \"Highest Charting Position\": 155, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Big Drip\", \"Streams\": 6010373, \"Artist\": \"Ufo361, Future\", \"Artist Followers\": 1700759.0, \"Song ID\": \"7HZoWhGQaKg97OsqG7HLOS\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 48.0, \"Danceability\": 0.791, \"Energy\": 0.535, \"Loudness\": -6.753, \"Speechiness\": 0.311, \"Acousticness\": 0.0448, \"Liveness\": 0.129, \"Tempo\": 158.922, \"Duration (ms)\": 173785.0, \"Valence\": 0.443, \"Chord\": \"C\"}, {\"Index\": 1508, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Hands\", \"Streams\": 5934464, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"6CrnvqCxBKVWahSiQwOesM\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 58.0, \"Danceability\": 0.739, \"Energy\": 0.627, \"Loudness\": -8.608, \"Speechiness\": 0.171, \"Acousticness\": 0.0459, \"Liveness\": 0.159, \"Tempo\": 74.962, \"Duration (ms)\": 199981.0, \"Valence\": 0.542, \"Chord\": \"C\"}, {\"Index\": 1509, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Dans l'espace (feat. Heuss l'Enfoir\\u00e9)\", \"Streams\": 5678754, \"Artist\": \"Gambi\", \"Artist Followers\": 951798.0, \"Song ID\": \"2KAkkba3PaYFegfmYpUITv\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 59.0, \"Danceability\": 0.916, \"Energy\": 0.57, \"Loudness\": -6.278, \"Speechiness\": 0.18, \"Acousticness\": 0.0286, \"Liveness\": 0.0851, \"Tempo\": 110.05, \"Duration (ms)\": 169702.0, \"Valence\": 0.7, \"Chord\": \"C#/Db\"}, {\"Index\": 1510, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Blanche\", \"Streams\": 5656775, \"Artist\": \"Maes, Booba\", \"Artist Followers\": 1603670.0, \"Song ID\": \"5GyyPRvEwdI4wJSUbzxHQv\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2020-01-16\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 65.0, \"Danceability\": 0.776, \"Energy\": 0.713, \"Loudness\": -6.121, \"Speechiness\": 0.143, \"Acousticness\": 0.525, \"Liveness\": 0.306, \"Tempo\": 127.987, \"Duration (ms)\": 193453.0, \"Valence\": 0.551, \"Chord\": \"E\"}, {\"Index\": 1511, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Vulnerable\", \"Streams\": 7531094, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"11OwAR3GlBj9E35Cznf7Lj\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 55.0, \"Danceability\": 0.695, \"Energy\": 0.573, \"Loudness\": -8.882, \"Speechiness\": 0.167, \"Acousticness\": 0.132, \"Liveness\": 0.156, \"Tempo\": 100.031, \"Duration (ms)\": 192172.0, \"Valence\": 0.38, \"Chord\": \"A#/Bb\"}, {\"Index\": 1512, \"Highest Charting Position\": 90, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Dance Again\", \"Streams\": 7394604, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"5sK3o66yupTNIK6gWgzGjf\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 56.0, \"Danceability\": 0.784, \"Energy\": 0.552, \"Loudness\": -7.261, \"Speechiness\": 0.0871, \"Acousticness\": 0.0447, \"Liveness\": 0.192, \"Tempo\": 111.984, \"Duration (ms)\": 170498.0, \"Valence\": 0.465, \"Chord\": \"C#/Db\"}, {\"Index\": 1513, \"Highest Charting Position\": 107, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Ring\", \"Streams\": 6693229, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"11Ey4yJVeWEsA73KjACkVY\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 55.0, \"Danceability\": 0.873, \"Energy\": 0.51, \"Loudness\": -5.35, \"Speechiness\": 0.0661, \"Acousticness\": 0.565, \"Liveness\": 0.0738, \"Tempo\": 110.953, \"Duration (ms)\": 148776.0, \"Valence\": 0.871, \"Chord\": \"D#/Eb\"}, {\"Index\": 1514, \"Highest Charting Position\": 111, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Crowded Room (feat. 6LACK)\", \"Streams\": 6483001, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"2C0hTkdEoikhKzDCJl32QZ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 55.0, \"Danceability\": 0.724, \"Energy\": 0.415, \"Loudness\": -8.408, \"Speechiness\": 0.0518, \"Acousticness\": 0.764, \"Liveness\": 0.103, \"Tempo\": 89.999, \"Duration (ms)\": 186459.0, \"Valence\": 0.328, \"Chord\": \"G\"}, {\"Index\": 1515, \"Highest Charting Position\": 119, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"People You Know\", \"Streams\": 6255954, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"63mdJr3NMY3wReOkNE6c6W\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 54.0, \"Danceability\": 0.695, \"Energy\": 0.62, \"Loudness\": -8.082, \"Speechiness\": 0.0521, \"Acousticness\": 0.0881, \"Liveness\": 0.111, \"Tempo\": 150.032, \"Duration (ms)\": 194900.0, \"Valence\": 0.62, \"Chord\": \"G#/Ab\"}, {\"Index\": 1516, \"Highest Charting Position\": 83, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Up All Night\", \"Streams\": 5834918, \"Artist\": \"Khalid\", \"Artist Followers\": 14190858.0, \"Song ID\": \"1mpD5Q8IM32I4bF6eCpU74\", \"Genre\": \"['pop']\", \"Release Date\": \"2019-11-14\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 69.0, \"Danceability\": 0.665, \"Energy\": 0.712, \"Loudness\": -7.536, \"Speechiness\": 0.0527, \"Acousticness\": 0.00103, \"Liveness\": 0.102, \"Tempo\": 93.992, \"Duration (ms)\": 157220.0, \"Valence\": 0.669, \"Chord\": \"C#/Db\"}, {\"Index\": 1517, \"Highest Charting Position\": 111, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Nice To Meet Ya\", \"Streams\": 5730427, \"Artist\": \"Niall Horan\", \"Artist Followers\": 7564659.0, \"Song ID\": \"3cphb8kdsjElYR7r5icK3H\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.591, \"Energy\": 0.841, \"Loudness\": -4.351, \"Speechiness\": 0.0304, \"Acousticness\": 0.0119, \"Liveness\": 0.395, \"Tempo\": 109.034, \"Duration (ms)\": 158805.0, \"Valence\": 0.392, \"Chord\": \"E\"}, {\"Index\": 1518, \"Highest Charting Position\": 102, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Into the Unknown\", \"Streams\": 5705999, \"Artist\": \"Idina Menzel, AURORA\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3Z0oQ8r78OUaHvGPiDBR3W\", \"Genre\": \"[]\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.323, \"Energy\": 0.405, \"Loudness\": -8.533, \"Speechiness\": 0.0413, \"Acousticness\": 0.849, \"Liveness\": 0.138, \"Tempo\": 145.104, \"Duration (ms)\": 194848.0, \"Valence\": 0.274, \"Chord\": \"A#/Bb\"}, {\"Index\": 1519, \"Highest Charting Position\": 161, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Let Me Get Me\", \"Streams\": 5356671, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"0uFForNKQPvgSCnxlZIhQy\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 51.0, \"Danceability\": 0.826, \"Energy\": 0.571, \"Loudness\": -9.263, \"Speechiness\": 0.0426, \"Acousticness\": 0.249, \"Liveness\": 0.215, \"Tempo\": 121.06, \"Duration (ms)\": 189145.0, \"Valence\": 0.475, \"Chord\": \"D\"}, {\"Index\": 1520, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"A Sweeter Place (feat. Kid Cudi)\", \"Streams\": 5291134, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4bb94wZVF1cX66vQjNeJTX\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 52.0, \"Danceability\": 0.583, \"Energy\": 0.777, \"Loudness\": -6.991, \"Speechiness\": 0.185, \"Acousticness\": 0.109, \"Liveness\": 0.108, \"Tempo\": 190.054, \"Duration (ms)\": 263306.0, \"Valence\": 0.31, \"Chord\": \"A#/Bb\"}, {\"Index\": 1521, \"Highest Charting Position\": 131, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Stuck In A Dream (feat. Gunna)\", \"Streams\": 5258047, \"Artist\": \"Lil Mosey\", \"Artist Followers\": 3818503.0, \"Song ID\": \"7iHHxY2NLlJRAmlAmC4ahQ\", \"Genre\": \"['melodic rap', 'rap', 'rap conscient', 'trap', 'vapor trap']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.748, \"Energy\": 0.648, \"Loudness\": -6.445, \"Speechiness\": 0.0816, \"Acousticness\": 0.484, \"Liveness\": 0.126, \"Tempo\": 139.952, \"Duration (ms)\": 123560.0, \"Valence\": 0.726, \"Chord\": \"A#/Bb\"}, {\"Index\": 1522, \"Highest Charting Position\": 138, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Take What You Want (feat. Ozzy Osbourne & Travis Scott)\", \"Streams\": 5199618, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"7CZyCXKG6d5ALeq41sLzbw\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.499, \"Energy\": 0.8, \"Loudness\": -2.665, \"Speechiness\": 0.0502, \"Acousticness\": 0.0906, \"Liveness\": 0.147, \"Tempo\": 139.919, \"Duration (ms)\": 229573.0, \"Valence\": 0.272, \"Chord\": \"C#/Db\"}, {\"Index\": 1523, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Tip Toe (feat. A Boogie Wit da Hoodie)\", \"Streams\": 5150724, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6608815.0, \"Song ID\": \"6ztvsy3C6hPjVg9j4x1XKJ\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 63.0, \"Danceability\": 0.757, \"Energy\": 0.673, \"Loudness\": -8.513, \"Speechiness\": 0.141, \"Acousticness\": 0.095, \"Liveness\": 0.338, \"Tempo\": 92.958, \"Duration (ms)\": 185806.0, \"Valence\": 0.574, \"Chord\": \"C#/Db\"}, {\"Index\": 1524, \"Highest Charting Position\": 182, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Start Wit Me (feat. Gunna)\", \"Streams\": 5085706, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6608815.0, \"Song ID\": \"7A20WnLkjtZU2d7hIB6Ziu\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 68.0, \"Danceability\": 0.886, \"Energy\": 0.479, \"Loudness\": -8.054, \"Speechiness\": 0.334, \"Acousticness\": 0.077, \"Liveness\": 0.135, \"Tempo\": 130.029, \"Duration (ms)\": 158692.0, \"Valence\": 0.408, \"Chord\": \"E\"}, {\"Index\": 1525, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Diamonds (with Normani)\", \"Streams\": 4981484, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"0PQsrLxPbOBBwwmXCnGvcF\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 58.0, \"Danceability\": 0.785, \"Energy\": 0.753, \"Loudness\": -3.841, \"Speechiness\": 0.0873, \"Acousticness\": 0.188, \"Liveness\": 0.265, \"Tempo\": 94.012, \"Duration (ms)\": 199301.0, \"Valence\": 0.488, \"Chord\": \"C#/Db\"}, {\"Index\": 1526, \"Highest Charting Position\": 140, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Don't Call Me Up\", \"Streams\": 4931458, \"Artist\": \"Mabel\", \"Artist Followers\": 1374784.0, \"Song ID\": \"5WHTFyqSii0lmT9R21abT8\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2019-01-18\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.674, \"Energy\": 0.881, \"Loudness\": -2.853, \"Speechiness\": 0.147, \"Acousticness\": 0.296, \"Liveness\": 0.0793, \"Tempo\": 98.994, \"Duration (ms)\": 178480.0, \"Valence\": 0.234, \"Chord\": \"A\"}, {\"Index\": 1527, \"Highest Charting Position\": 177, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Death\", \"Streams\": 4929396, \"Artist\": \"Trippie Redd, DaBaby\", \"Artist Followers\": 6434201.0, \"Song ID\": \"3Kd6Wp3lG5HXMB2dlvuy7y\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 65.0, \"Danceability\": 0.802, \"Energy\": 0.82, \"Loudness\": -5.969, \"Speechiness\": 0.146, \"Acousticness\": 0.0579, \"Liveness\": 0.149, \"Tempo\": 164.005, \"Duration (ms)\": 172196.0, \"Valence\": 0.613, \"Chord\": \"A#/Bb\"}, {\"Index\": 1528, \"Highest Charting Position\": 133, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Calma - Remix\", \"Streams\": 4879713, \"Artist\": \"Pedro Cap\\u00f3, Farruko\", \"Artist Followers\": 1353049.0, \"Song ID\": \"5iwz1NiezX7WWjnCgY5TH4\", \"Genre\": \"['latin', 'latin pop', 'puerto rican pop']\", \"Release Date\": \"2018-10-05\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.826, \"Energy\": 0.773, \"Loudness\": -4.218, \"Speechiness\": 0.0524, \"Acousticness\": 0.323, \"Liveness\": 0.143, \"Tempo\": 126.899, \"Duration (ms)\": 238200.0, \"Valence\": 0.761, \"Chord\": \"B\"}, {\"Index\": 1529, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Cut You Off\", \"Streams\": 4874380, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4OtHGdb0KqEbaWb6edUnR9\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 51.0, \"Danceability\": 0.855, \"Energy\": 0.294, \"Loudness\": -8.676, \"Speechiness\": 0.286, \"Acousticness\": 0.3, \"Liveness\": 0.091, \"Tempo\": 139.745, \"Duration (ms)\": 182017.0, \"Valence\": 0.842, \"Chord\": \"F\"}, {\"Index\": 1530, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Kinda Crazy\", \"Streams\": 4866777, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"59iGOjPSOcPLGl3vqEStUp\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 49.0, \"Danceability\": 0.691, \"Energy\": 0.446, \"Loudness\": -10.304, \"Speechiness\": 0.0472, \"Acousticness\": 0.484, \"Liveness\": 0.183, \"Tempo\": 93.03, \"Duration (ms)\": 212436.0, \"Valence\": 0.534, \"Chord\": \"B\"}, {\"Index\": 1531, \"Highest Charting Position\": 179, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"2002\", \"Streams\": 4831644, \"Artist\": \"Anne-Marie\", \"Artist Followers\": 8153871.0, \"Song ID\": \"2BgEsaKNfHUdlh97KmvFyo\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2018-04-27\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.697, \"Energy\": 0.683, \"Loudness\": -2.881, \"Speechiness\": 0.117, \"Acousticness\": 0.0372, \"Liveness\": 0.137, \"Tempo\": 96.133, \"Duration (ms)\": 186987.0, \"Valence\": 0.603, \"Chord\": \"C#/Db\"}, {\"Index\": 1532, \"Highest Charting Position\": 153, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Taki Taki (feat. Selena Gomez, Ozuna & Cardi B)\", \"Streams\": 4816702, \"Artist\": \"DJ Snake\", \"Artist Followers\": 7408249.0, \"Song ID\": \"0KoiMHhqKLoL4xM54rcWYY\", \"Genre\": \"['dance pop', 'edm', 'electronic trap', 'pop', 'pop dance']\", \"Release Date\": \"2019-07-25\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.842, \"Energy\": 0.801, \"Loudness\": -4.167, \"Speechiness\": 0.228, \"Acousticness\": 0.157, \"Liveness\": 0.0642, \"Tempo\": 95.881, \"Duration (ms)\": 212500.0, \"Valence\": 0.617, \"Chord\": \"G#/Ab\"}, {\"Index\": 1533, \"Highest Charting Position\": 107, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Family\", \"Streams\": 6145132, \"Artist\": \"The Chainsmokers, Kygo\", \"Artist Followers\": 18195884.0, \"Song ID\": \"3TKpJrY9q49Mj1JOsM9zGL\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.584, \"Energy\": 0.607, \"Loudness\": -6.605, \"Speechiness\": 0.0356, \"Acousticness\": 0.426, \"Liveness\": 0.101, \"Tempo\": 117.817, \"Duration (ms)\": 194827.0, \"Valence\": 0.374, \"Chord\": \"B\"}, {\"Index\": 1534, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"GANG GANG\", \"Streams\": 5898484, \"Artist\": \"JACKBOYS, Sheck Wes\", \"Artist Followers\": 437907.0, \"Song ID\": \"6uJONCdr2rC65BNmCnTBWK\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 69.0, \"Danceability\": 0.859, \"Energy\": 0.6, \"Loudness\": -4.63, \"Speechiness\": 0.301, \"Acousticness\": 0.071, \"Liveness\": 0.353, \"Tempo\": 123.017, \"Duration (ms)\": 244761.0, \"Valence\": 0.568, \"Chord\": \"G\"}, {\"Index\": 1535, \"Highest Charting Position\": 39, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Had Enough (feat. Quavo & Offset)\", \"Streams\": 5748010, \"Artist\": \"Don Toliver\", \"Artist Followers\": 437907.0, \"Song ID\": \"7LGWmZaoS7jZJ5tEi9EcDi\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.75, \"Energy\": 0.789, \"Loudness\": -4.578, \"Speechiness\": 0.108, \"Acousticness\": 0.253, \"Liveness\": 0.129, \"Tempo\": 147.957, \"Duration (ms)\": 157133.0, \"Valence\": 0.673, \"Chord\": \"D\"}, {\"Index\": 1536, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"WHAT TO DO? (feat. Don Toliver)\", \"Streams\": 5586351, \"Artist\": \"JACKBOYS, Travis Scott\", \"Artist Followers\": 437907.0, \"Song ID\": \"4AO1XhrgJczQ9bNVxdfKQe\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.643, \"Energy\": 0.594, \"Loudness\": -5.191, \"Speechiness\": 0.0312, \"Acousticness\": 0.0695, \"Liveness\": 0.115, \"Tempo\": 118.037, \"Duration (ms)\": 250142.0, \"Valence\": 0.195, \"Chord\": \"A\"}, {\"Index\": 1537, \"Highest Charting Position\": 125, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Writing on the Wall (feat. Post Malone, Cardi B & Rvssian)\", \"Streams\": 5229616, \"Artist\": \"French Montana\", \"Artist Followers\": 4039037.0, \"Song ID\": \"7x9nXsowok1JszkVztI5NI\", \"Genre\": \"['gangster rap', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 59.0, \"Danceability\": 0.773, \"Energy\": 0.836, \"Loudness\": -2.326, \"Speechiness\": 0.153, \"Acousticness\": 0.283, \"Liveness\": 0.0828, \"Tempo\": 112.01, \"Duration (ms)\": 201271.0, \"Valence\": 0.497, \"Chord\": \"A\"}, {\"Index\": 1538, \"Highest Charting Position\": 169, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"VALENTINO\", \"Streams\": 4935492, \"Artist\": \"24kGoldn\", \"Artist Followers\": 1276406.0, \"Song ID\": \"6piAUJJQFD8oHDUr0b7l7q\", \"Genre\": \"['cali rap']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.746, \"Energy\": 0.717, \"Loudness\": -4.841, \"Speechiness\": 0.179, \"Acousticness\": 0.199, \"Liveness\": 0.132, \"Tempo\": 150.964, \"Duration (ms)\": 179133.0, \"Valence\": 0.523, \"Chord\": \"A\"}, {\"Index\": 1539, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"fuck, i'm lonely (with Anne-Marie) - from \\u201c13 Reasons Why: Season 3\\u201d\", \"Streams\": 4856458, \"Artist\": \"Lauv\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-01-03--2020-01-10\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 1540, \"Highest Charting Position\": 150, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Roller\", \"Streams\": 4732292, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"6hw1Sy9wZ8UCxYGdpKrU6M\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2019-10-25\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.941, \"Energy\": 0.758, \"Loudness\": -6.47, \"Speechiness\": 0.17, \"Acousticness\": 0.0256, \"Liveness\": 0.193, \"Tempo\": 128.017, \"Duration (ms)\": 157093.0, \"Valence\": 0.683, \"Chord\": \"A#/Bb\"}, {\"Index\": 1541, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Never Really Over\", \"Streams\": 4679948, \"Artist\": \"Katy Perry\", \"Artist Followers\": 18936929.0, \"Song ID\": \"5PYQUBXc7NYeI1obMKSJK0\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-05-31\", \"Weeks Charted\": \"2020-01-03--2020-01-10\", \"Popularity\": 74.0, \"Danceability\": 0.77, \"Energy\": 0.882, \"Loudness\": -4.792, \"Speechiness\": 0.0602, \"Acousticness\": 0.194, \"Liveness\": 0.316, \"Tempo\": 99.991, \"Duration (ms)\": 223523.0, \"Valence\": 0.385, \"Chord\": \"G#/Ab\"}, {\"Index\": 1542, \"Highest Charting Position\": 145, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"One Kiss (with Dua Lipa)\", \"Streams\": 4594157, \"Artist\": \"Calvin Harris\", \"Artist Followers\": 21946934.0, \"Song ID\": \"7ef4DlsgrMEH11cDZd32M6\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'house', 'pop', 'progressive house', 'uk dance']\", \"Release Date\": \"2018-04-06\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.791, \"Energy\": 0.862, \"Loudness\": -3.24, \"Speechiness\": 0.11, \"Acousticness\": 0.037, \"Liveness\": 0.0814, \"Tempo\": 123.994, \"Duration (ms)\": 214847.0, \"Valence\": 0.592, \"Chord\": \"A\"}, {\"Index\": 1543, \"Highest Charting Position\": 192, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Fantas\\u00eda\", \"Streams\": 4543012, \"Artist\": \"Ozuna\", \"Artist Followers\": 29238936.0, \"Song ID\": \"40rXWke6SnXiGkSmaT8ZUr\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-29\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 59.0, \"Danceability\": 0.695, \"Energy\": 0.719, \"Loudness\": -5.938, \"Speechiness\": 0.0903, \"Acousticness\": 0.227, \"Liveness\": 0.0884, \"Tempo\": 180.074, \"Duration (ms)\": 175187.0, \"Valence\": 0.781, \"Chord\": \"D\"}, {\"Index\": 1544, \"Highest Charting Position\": 59, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Trampoline\", \"Streams\": 8896030, \"Artist\": \"SHAED, ZAYN\", \"Artist Followers\": 139434.0, \"Song ID\": \"1iQDltZqI7BXnHrFy4Qo1k\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-09-26\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.619, \"Energy\": 0.459, \"Loudness\": -5.782, \"Speechiness\": 0.0334, \"Acousticness\": 0.56, \"Liveness\": 0.137, \"Tempo\": 126.803, \"Duration (ms)\": 184280.0, \"Valence\": 0.498, \"Chord\": \"G\"}, {\"Index\": 1545, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"GATTI\", \"Streams\": 7685470, \"Artist\": \"JACKBOYS, Pop Smoke, Travis Scott\", \"Artist Followers\": 437907.0, \"Song ID\": \"40mjsnRjCpycdUw3xhS20g\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.594, \"Energy\": 0.676, \"Loudness\": -5.808, \"Speechiness\": 0.344, \"Acousticness\": 0.135, \"Liveness\": 0.163, \"Tempo\": 143.477, \"Duration (ms)\": 181145.0, \"Valence\": 0.472, \"Chord\": \"D\"}, {\"Index\": 1546, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Candy\", \"Streams\": 5632102, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"1VJwtWR6z7SpZRwipI12be\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2018-03-30\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.689, \"Energy\": 0.516, \"Loudness\": -5.857, \"Speechiness\": 0.0444, \"Acousticness\": 0.513, \"Liveness\": 0.163, \"Tempo\": 124.876, \"Duration (ms)\": 190920.0, \"Valence\": 0.209, \"Chord\": \"G#/Ab\"}, {\"Index\": 1547, \"Highest Charting Position\": 143, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"JACKBOYS\", \"Streams\": 5363493, \"Artist\": \"JACKBOYS\", \"Artist Followers\": 437907.0, \"Song ID\": \"62zKJrpbLxz6InR3tGyr7o\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 56.0, \"Danceability\": 0.413, \"Energy\": 0.13, \"Loudness\": -25.166, \"Speechiness\": 0.0336, \"Acousticness\": 0.9, \"Liveness\": 0.111, \"Tempo\": 123.342, \"Duration (ms)\": 46837.0, \"Valence\": 0.0676, \"Chord\": \"C\"}, {\"Index\": 1548, \"Highest Charting Position\": 156, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Combatchy (feat. MC Rebecca)\", \"Streams\": 5149797, \"Artist\": \"Anitta, Lexa, Lu\\u00edsa Sonza\", \"Artist Followers\": 10741972.0, \"Song ID\": \"2bPtwnrpFNEe8N7Q85kLHw\", \"Genre\": \"['funk carioca', 'funk pop', 'pagode baiano', 'pop nacional']\", \"Release Date\": \"2019-11-20\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 64.0, \"Danceability\": 0.826, \"Energy\": 0.73, \"Loudness\": -3.032, \"Speechiness\": 0.0809, \"Acousticness\": 0.383, \"Liveness\": 0.0197, \"Tempo\": 150.134, \"Duration (ms)\": 157600.0, \"Valence\": 0.605, \"Chord\": \"C#/Db\"}, {\"Index\": 1549, \"Highest Charting Position\": 178, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Old Town Road\", \"Streams\": 4852004, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5488666.0, \"Song ID\": \"2YpeDb67231RjR0MgVLzsG\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.878, \"Energy\": 0.619, \"Loudness\": -5.56, \"Speechiness\": 0.102, \"Acousticness\": 0.0533, \"Liveness\": 0.113, \"Tempo\": 136.041, \"Duration (ms)\": 157067.0, \"Valence\": 0.639, \"Chord\": \"F#/Gb\"}, {\"Index\": 1550, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Let Me Know (I Wonder Why Freestyle)\", \"Streams\": 4701532, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"3wwo0bJvDSorOpNfzEkfXx\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2019-12-07\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.635, \"Energy\": 0.537, \"Loudness\": -7.895, \"Speechiness\": 0.0832, \"Acousticness\": 0.172, \"Liveness\": 0.418, \"Tempo\": 125.028, \"Duration (ms)\": 215381.0, \"Valence\": 0.383, \"Chord\": \"G\"}, {\"Index\": 1551, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Ne reviens pas\", \"Streams\": 4676857, \"Artist\": \"Gradur, Heuss L'enfoir\\u00e9\", \"Artist Followers\": 1390813.0, \"Song ID\": \"4TnFANpjVwVKWzkxNzIyFH\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2019-11-29\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 62.0, \"Danceability\": 0.932, \"Energy\": 0.778, \"Loudness\": -3.384, \"Speechiness\": 0.0638, \"Acousticness\": 0.212, \"Liveness\": 0.168, \"Tempo\": 124.996, \"Duration (ms)\": 188613.0, \"Valence\": 0.933, \"Chord\": \"A#/Bb\"}, {\"Index\": 1552, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"New Rules\", \"Streams\": 4630675, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"2ekn2ttSfGqwhhate0LSR0\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2017-06-02\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.762, \"Energy\": 0.7, \"Loudness\": -6.021, \"Speechiness\": 0.0694, \"Acousticness\": 0.00261, \"Liveness\": 0.153, \"Tempo\": 116.073, \"Duration (ms)\": 209320.0, \"Valence\": 0.608, \"Chord\": \"A\"}, {\"Index\": 1553, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Cheirosa - Ao Vivo\", \"Streams\": 4623030, \"Artist\": \"Jorge & Mateus\", \"Artist Followers\": 15019109.0, \"Song ID\": \"2PWjKmjyTZeDpmOUa3a5da\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2019-10-11\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.528, \"Energy\": 0.87, \"Loudness\": -3.123, \"Speechiness\": 0.0851, \"Acousticness\": 0.24, \"Liveness\": 0.333, \"Tempo\": 152.37, \"Duration (ms)\": 181930.0, \"Valence\": 0.714, \"Chord\": \"B\"}, {\"Index\": 1554, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Havana (feat. Young Thug)\", \"Streams\": 4620876, \"Artist\": \"Camila Cabello\", \"Artist Followers\": 22698747.0, \"Song ID\": \"1rfofaqEpACxVEHIZBJe6W\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-01-12\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.765, \"Energy\": 0.523, \"Loudness\": -4.333, \"Speechiness\": 0.03, \"Acousticness\": 0.184, \"Liveness\": 0.132, \"Tempo\": 104.988, \"Duration (ms)\": 217307.0, \"Valence\": 0.394, \"Chord\": \"D\"}, {\"Index\": 1555, \"Highest Charting Position\": 198, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Surtada - Remix Brega Funk\", \"Streams\": 4607385, \"Artist\": \"Dad\\u00e1 Bolad\\u00e3o, Tati Zaqui, OIK\", \"Artist Followers\": 208630.0, \"Song ID\": \"5F8ffc8KWKNawllr5WsW0r\", \"Genre\": \"['brega funk', 'funk carioca']\", \"Release Date\": \"2019-09-25\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 60.0, \"Danceability\": 0.832, \"Energy\": 0.55, \"Loudness\": -7.026, \"Speechiness\": 0.0587, \"Acousticness\": 0.249, \"Liveness\": 0.182, \"Tempo\": 154.064, \"Duration (ms)\": 152784.0, \"Valence\": 0.881, \"Chord\": \"F\"}, {\"Index\": 1556, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lover (Remix) [feat. Shawn Mendes]\", \"Streams\": 4595450, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3i9UVldZOE0aD0JnyfAZZ0\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-11-13\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.448, \"Energy\": 0.603, \"Loudness\": -7.176, \"Speechiness\": 0.064, \"Acousticness\": 0.433, \"Liveness\": 0.0862, \"Tempo\": 205.272, \"Duration (ms)\": 221307.0, \"Valence\": 0.422, \"Chord\": \"G\"}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 19,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "alt.Chart(df).mark_circle().encode(\n",
    "    x = \"Energy\",\n",
    "    y = \"Loudness\",\n",
    "    color = alt.Color('Acousticness',scale=alt.Scale(scheme=\"goldred\")),\n",
    "    tooltip = [\"Artist\",\"Song Name\",\"Release Date\",\"Chord\"]\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "12c507be",
   "metadata": {},
   "source": [
    "Sometimes the colors look more natural if they are reversed.  We do that by adding `reverse=True` in the `alt.Scale` component."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 20,
   "id": "b5c2a91e",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-11379d9d42e146bfa4277a07cff36d4f\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-11379d9d42e146bfa4277a07cff36d4f\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-11379d9d42e146bfa4277a07cff36d4f\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-67c9fb159873386c9c7303ca2ad81ad2\"}, \"mark\": \"circle\", \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"Acousticness\", \"scale\": {\"reverse\": true, \"scheme\": \"goldred\"}}, \"tooltip\": [{\"type\": \"nominal\", \"field\": \"Artist\"}, {\"type\": \"nominal\", \"field\": \"Song Name\"}, {\"type\": \"nominal\", \"field\": \"Release Date\"}, {\"type\": \"nominal\", \"field\": \"Chord\"}], \"x\": {\"type\": \"quantitative\", \"field\": \"Energy\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"Loudness\"}}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-67c9fb159873386c9c7303ca2ad81ad2\": [{\"Index\": 1, \"Highest Charting Position\": 1, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Beggin'\", \"Streams\": 48633449, \"Artist\": \"M\\u00e5neskin\", \"Artist Followers\": 3377762.0, \"Song ID\": \"3Wrjm47oTz2sjIgck11l5e\", \"Genre\": \"['indie rock italiano', 'italian pop']\", \"Release Date\": \"2017-12-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 100.0, \"Danceability\": 0.714, \"Energy\": 0.8, \"Loudness\": -4.808, \"Speechiness\": 0.0504, \"Acousticness\": 0.127, \"Liveness\": 0.359, \"Tempo\": 134.002, \"Duration (ms)\": 211560.0, \"Valence\": 0.589, \"Chord\": \"B\"}, {\"Index\": 2, \"Highest Charting Position\": 2, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"STAY (with Justin Bieber)\", \"Streams\": 47248719, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2230022.0, \"Song ID\": \"5HCyWlXZPP0y6Gqq8TgA20\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 99.0, \"Danceability\": 0.591, \"Energy\": 0.764, \"Loudness\": -5.484, \"Speechiness\": 0.0483, \"Acousticness\": 0.0383, \"Liveness\": 0.103, \"Tempo\": 169.928, \"Duration (ms)\": 141806.0, \"Valence\": 0.478, \"Chord\": \"C#/Db\"}, {\"Index\": 3, \"Highest Charting Position\": 1, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"good 4 u\", \"Streams\": 40162559, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"4ZtFanR9U6ndgddUvNcjcG\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 99.0, \"Danceability\": 0.563, \"Energy\": 0.664, \"Loudness\": -5.044, \"Speechiness\": 0.154, \"Acousticness\": 0.335, \"Liveness\": 0.0849, \"Tempo\": 166.928, \"Duration (ms)\": 178147.0, \"Valence\": 0.688, \"Chord\": \"A\"}, {\"Index\": 4, \"Highest Charting Position\": 3, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Bad Habits\", \"Streams\": 37799456, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83293380.0, \"Song ID\": \"6PQ88X9TkUIAUIZJHW2upE\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 98.0, \"Danceability\": 0.808, \"Energy\": 0.897, \"Loudness\": -3.712, \"Speechiness\": 0.0348, \"Acousticness\": 0.0469, \"Liveness\": 0.364, \"Tempo\": 126.026, \"Duration (ms)\": 231041.0, \"Valence\": 0.591, \"Chord\": \"B\"}, {\"Index\": 5, \"Highest Charting Position\": 5, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"INDUSTRY BABY (feat. Jack Harlow)\", \"Streams\": 33948454, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5473565.0, \"Song ID\": \"27NovPIUIRrOZoCHxABJwK\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2021-07-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 96.0, \"Danceability\": 0.736, \"Energy\": 0.704, \"Loudness\": -7.409, \"Speechiness\": 0.0615, \"Acousticness\": 0.0203, \"Liveness\": 0.0501, \"Tempo\": 149.995, \"Duration (ms)\": 212000.0, \"Valence\": 0.894, \"Chord\": \"D#/Eb\"}, {\"Index\": 6, \"Highest Charting Position\": 1, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"MONTERO (Call Me By Your Name)\", \"Streams\": 30071134, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5473565.0, \"Song ID\": \"67BtfxlNbhBmCDR2L2l8qd\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2021-03-31\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 97.0, \"Danceability\": 0.61, \"Energy\": 0.508, \"Loudness\": -6.682, \"Speechiness\": 0.152, \"Acousticness\": 0.297, \"Liveness\": 0.384, \"Tempo\": 178.818, \"Duration (ms)\": 137876.0, \"Valence\": 0.758, \"Chord\": \"G#/Ab\"}, {\"Index\": 7, \"Highest Charting Position\": 3, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Kiss Me More (feat. SZA)\", \"Streams\": 29356736, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"748mdHapucXQri7IAO8yFK\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 94.0, \"Danceability\": 0.762, \"Energy\": 0.701, \"Loudness\": -3.541, \"Speechiness\": 0.0286, \"Acousticness\": 0.235, \"Liveness\": 0.123, \"Tempo\": 110.968, \"Duration (ms)\": 208867.0, \"Valence\": 0.742, \"Chord\": \"G#/Ab\"}, {\"Index\": 8, \"Highest Charting Position\": 2, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Todo De Ti\", \"Streams\": 26951613, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6080597.0, \"Song ID\": \"4fSIb4hdOQ151TILNsSEaF\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2021-05-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 95.0, \"Danceability\": 0.78, \"Energy\": 0.718, \"Loudness\": -3.605, \"Speechiness\": 0.0506, \"Acousticness\": 0.31, \"Liveness\": 0.0932, \"Tempo\": 127.949, \"Duration (ms)\": 199604.0, \"Valence\": 0.342, \"Chord\": \"D#/Eb\"}, {\"Index\": 9, \"Highest Charting Position\": 3, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Yonaguni\", \"Streams\": 25030128, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36142273.0, \"Song ID\": \"2JPLbjOn0wPCngEot2STUS\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 96.0, \"Danceability\": 0.644, \"Energy\": 0.648, \"Loudness\": -4.601, \"Speechiness\": 0.118, \"Acousticness\": 0.276, \"Liveness\": 0.135, \"Tempo\": 179.951, \"Duration (ms)\": 206710.0, \"Valence\": 0.44, \"Chord\": \"C#/Db\"}, {\"Index\": 10, \"Highest Charting Position\": 8, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"I WANNA BE YOUR SLAVE\", \"Streams\": 24551591, \"Artist\": \"M\\u00e5neskin\", \"Artist Followers\": 3377762.0, \"Song ID\": \"4pt5fDVTg5GhEvEtlz9dKk\", \"Genre\": \"['indie rock italiano', 'italian pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 95.0, \"Danceability\": 0.75, \"Energy\": 0.608, \"Loudness\": -4.008, \"Speechiness\": 0.0387, \"Acousticness\": 0.00165, \"Liveness\": 0.178, \"Tempo\": 132.507, \"Duration (ms)\": 173347.0, \"Valence\": 0.958, \"Chord\": \"C#/Db\"}, {\"Index\": 11, \"Highest Charting Position\": 4, \"Number of Times Charted\": 43, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Levitating (feat. DaBaby)\", \"Streams\": 23518010, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"463CkQjx2Zk1yXoBuierM9\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-10-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 89.0, \"Danceability\": 0.702, \"Energy\": 0.825, \"Loudness\": -3.787, \"Speechiness\": 0.0601, \"Acousticness\": 0.00883, \"Liveness\": 0.0674, \"Tempo\": 102.977, \"Duration (ms)\": 203064.0, \"Valence\": 0.915, \"Chord\": \"F#/Gb\"}, {\"Index\": 12, \"Highest Charting Position\": 9, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Qu\\u00e9 M\\u00e1s Pues?\", \"Streams\": 22405111, \"Artist\": \"J Balvin, Maria Becerra\", \"Artist Followers\": 29051363.0, \"Song ID\": \"6hf0RpxTbOprT5nnwzkk8e\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\", \"Popularity\": 95.0, \"Danceability\": 0.891, \"Energy\": 0.819, \"Loudness\": -3.964, \"Speechiness\": 0.106, \"Acousticness\": 0.0261, \"Liveness\": 0.173, \"Tempo\": 101.968, \"Duration (ms)\": 217773.0, \"Valence\": 0.768, \"Chord\": \"G#/Ab\"}, {\"Index\": 13, \"Highest Charting Position\": 5, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Permission to Dance\", \"Streams\": 22062812, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"0LThjFY2iTtNdd4wviwVV2\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 95.0, \"Danceability\": 0.702, \"Energy\": 0.741, \"Loudness\": -5.33, \"Speechiness\": 0.0427, \"Acousticness\": 0.00544, \"Liveness\": 0.337, \"Tempo\": 124.925, \"Duration (ms)\": 187585.0, \"Valence\": 0.646, \"Chord\": \"A\"}, {\"Index\": 14, \"Highest Charting Position\": 1, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Peaches (feat. Daniel Caesar & Giveon)\", \"Streams\": 20294457, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48504126.0, \"Song ID\": \"4iJyoBOLtHqaGxP12qzhQI\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 94.0, \"Danceability\": 0.677, \"Energy\": 0.696, \"Loudness\": -6.181, \"Speechiness\": 0.119, \"Acousticness\": 0.321, \"Liveness\": 0.42, \"Tempo\": 90.03, \"Duration (ms)\": 198082.0, \"Valence\": 0.464, \"Chord\": \"C\"}, {\"Index\": 15, \"Highest Charting Position\": 2, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Butter\", \"Streams\": 19985713, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"2bgTY4UwhfBYhGT4HUYStN\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 95.0, \"Danceability\": 0.759, \"Energy\": 0.459, \"Loudness\": -5.187, \"Speechiness\": 0.0948, \"Acousticness\": 0.00323, \"Liveness\": 0.0906, \"Tempo\": 109.997, \"Duration (ms)\": 164442.0, \"Valence\": 0.695, \"Chord\": \"G#/Ab\"}, {\"Index\": 16, \"Highest Charting Position\": 7, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"traitor\", \"Streams\": 19480679, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"5CZ40GBx1sQ9agT82CLQCT\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 94.0, \"Danceability\": 0.38, \"Energy\": 0.339, \"Loudness\": -7.885, \"Speechiness\": 0.0338, \"Acousticness\": 0.691, \"Liveness\": 0.12, \"Tempo\": 100.607, \"Duration (ms)\": 229227.0, \"Valence\": 0.0849, \"Chord\": \"D#/Eb\"}, {\"Index\": 17, \"Highest Charting Position\": 3, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"deja vu\", \"Streams\": 18571755, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"6HU7h9RYOaPRFeh0R3UeAr\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 93.0, \"Danceability\": 0.442, \"Energy\": 0.612, \"Loudness\": -7.222, \"Speechiness\": 0.112, \"Acousticness\": 0.584, \"Liveness\": 0.37, \"Tempo\": 180.917, \"Duration (ms)\": 215507.0, \"Valence\": 0.178, \"Chord\": \"D\"}, {\"Index\": 18, \"Highest Charting Position\": 5, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Save Your Tears (with Ariana Grande) (Remix)\", \"Streams\": 18053141, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"37BZB0z9T8Xu7U3e65qxFy\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 94.0, \"Danceability\": 0.65, \"Energy\": 0.825, \"Loudness\": -4.645, \"Speechiness\": 0.0325, \"Acousticness\": 0.0215, \"Liveness\": 0.0936, \"Tempo\": 118.091, \"Duration (ms)\": 191014.0, \"Valence\": 0.593, \"Chord\": \"C\"}, {\"Index\": 19, \"Highest Charting Position\": 14, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"AM Remix\", \"Streams\": 17617965, \"Artist\": \"Nio Garcia, J Balvin, Bad Bunny\", \"Artist Followers\": 2123734.0, \"Song ID\": \"05bfbizlM5AX6Mf1RRyMho\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-24\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 93.0, \"Danceability\": 0.743, \"Energy\": 0.655, \"Loudness\": -5.015, \"Speechiness\": 0.159, \"Acousticness\": 0.114, \"Liveness\": 0.0764, \"Tempo\": 172.031, \"Duration (ms)\": 261335.0, \"Valence\": 0.785, \"Chord\": \"F#/Gb\"}, {\"Index\": 20, \"Highest Charting Position\": 20, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Need To Know\", \"Streams\": 16908917, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"3Vi5XqYrmQgOYBajMWSvCi\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 90.0, \"Danceability\": 0.664, \"Energy\": 0.609, \"Loudness\": -6.509, \"Speechiness\": 0.0707, \"Acousticness\": 0.304, \"Liveness\": 0.0926, \"Tempo\": 130.041, \"Duration (ms)\": 210560.0, \"Valence\": 0.194, \"Chord\": \"C#/Db\"}, {\"Index\": 21, \"Highest Charting Position\": 19, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Volando - Remix\", \"Streams\": 16606925, \"Artist\": \"Mora, Bad Bunny, Sech\", \"Artist Followers\": 151486.0, \"Song ID\": \"0G2zPzWqVjR68iNPmx2TBe\", \"Genre\": \"['reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 91.0, \"Danceability\": 0.659, \"Energy\": 0.688, \"Loudness\": -4.649, \"Speechiness\": 0.0673, \"Acousticness\": 0.207, \"Liveness\": 0.113, \"Tempo\": 153.979, \"Duration (ms)\": 273474.0, \"Valence\": 0.632, \"Chord\": \"F#/Gb\"}, {\"Index\": 22, \"Highest Charting Position\": 22, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Ain't Shit\", \"Streams\": 16126897, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"5lAnYvAIkSDNXqfo7DyFUm\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 90.0, \"Danceability\": 0.855, \"Energy\": 0.488, \"Loudness\": -4.601, \"Speechiness\": 0.208, \"Acousticness\": 0.506, \"Liveness\": 0.347, \"Tempo\": 124.097, \"Duration (ms)\": 174253.0, \"Valence\": 0.619, \"Chord\": \"D#/Eb\"}, {\"Index\": 23, \"Highest Charting Position\": 1, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"drivers license\", \"Streams\": 15684978, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"5wANPM4fQCJwkGd4rN57mH\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 92.0, \"Danceability\": 0.561, \"Energy\": 0.431, \"Loudness\": -8.81, \"Speechiness\": 0.0578, \"Acousticness\": 0.768, \"Liveness\": 0.106, \"Tempo\": 143.875, \"Duration (ms)\": 242013.0, \"Valence\": 0.137, \"Chord\": \"A#/Bb\"}, {\"Index\": 24, \"Highest Charting Position\": 24, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Heat Waves\", \"Streams\": 15089184, \"Artist\": \"Glass Animals\", \"Artist Followers\": 1890510.0, \"Song ID\": \"3USxtqRwSYz57Ewm6wWRMp\", \"Genre\": \"['gauze pop', 'indietronica', 'shiver pop']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 85.0, \"Danceability\": 0.761, \"Energy\": 0.525, \"Loudness\": -6.9, \"Speechiness\": 0.0944, \"Acousticness\": 0.44, \"Liveness\": 0.0921, \"Tempo\": 80.87, \"Duration (ms)\": 238805.0, \"Valence\": 0.531, \"Chord\": \"B\"}, {\"Index\": 25, \"Highest Charting Position\": 1, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Blinding Lights\", \"Streams\": 15011809, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"0VjIjW4GlUZAMYd2vXMi3b\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 92.0, \"Danceability\": 0.514, \"Energy\": 0.73, \"Loudness\": -5.934, \"Speechiness\": 0.0598, \"Acousticness\": 0.00146, \"Liveness\": 0.0897, \"Tempo\": 171.005, \"Duration (ms)\": 200040.0, \"Valence\": 0.334, \"Chord\": \"C#/Db\"}, {\"Index\": 26, \"Highest Charting Position\": 12, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"happier\", \"Streams\": 14849078, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"2tGvwE8GcFKwNdAXMnlbfl\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 92.0, \"Danceability\": 0.395, \"Energy\": 0.443, \"Loudness\": -9.72, \"Speechiness\": 0.133, \"Acousticness\": 0.765, \"Liveness\": 0.0839, \"Tempo\": 168.924, \"Duration (ms)\": 175933.0, \"Valence\": 0.338, \"Chord\": \"F#/Gb\"}, {\"Index\": 27, \"Highest Charting Position\": 27, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Pepas\", \"Streams\": 14809458, \"Artist\": \"Farruko\", \"Artist Followers\": 10502148.0, \"Song ID\": \"5fwSHlTEWpluwOM0Sxnh5k\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-24\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 92.0, \"Danceability\": 0.762, \"Energy\": 0.766, \"Loudness\": -3.955, \"Speechiness\": 0.0343, \"Acousticness\": 0.00776, \"Liveness\": 0.128, \"Tempo\": 130.001, \"Duration (ms)\": 287120.0, \"Valence\": 0.442, \"Chord\": \"G\"}, {\"Index\": 28, \"Highest Charting Position\": 18, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Motley Crew\", \"Streams\": 14329162, \"Artist\": \"Post Malone\", \"Artist Followers\": 33651775.0, \"Song ID\": \"40uMIn2zJLAQhNXghRjBed\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 90.0, \"Danceability\": 0.797, \"Energy\": 0.631, \"Loudness\": -3.818, \"Speechiness\": 0.0786, \"Acousticness\": 0.0904, \"Liveness\": 0.0998, \"Tempo\": 129.915, \"Duration (ms)\": 184213.0, \"Valence\": 0.288, \"Chord\": \"D#/Eb\"}, {\"Index\": 29, \"Highest Charting Position\": 15, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Friday (feat. Mufasa & Hypeman) - Dopamine Re-Edit\", \"Streams\": 14273637, \"Artist\": \"Riton, Nightcrawlers\", \"Artist Followers\": 83689.0, \"Song ID\": \"4cG7HUWYHBV6R6tHn1gxrl\", \"Genre\": \"['dance pop', 'house', 'pop dance', 'tropical house', 'uk dance']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 92.0, \"Danceability\": 0.824, \"Energy\": 0.862, \"Loudness\": -3.424, \"Speechiness\": 0.126, \"Acousticness\": 0.0076, \"Liveness\": 0.303, \"Tempo\": 122.98, \"Duration (ms)\": 169153.0, \"Valence\": 0.801, \"Chord\": \"D\"}, {\"Index\": 30, \"Highest Charting Position\": 3, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Astronaut In The Ocean\", \"Streams\": 14174752, \"Artist\": \"Masked Wolf\", \"Artist Followers\": 365975.0, \"Song ID\": \"3Ofmpyhv5UAQ70mENzB277\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2021-01-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 89.0, \"Danceability\": 0.778, \"Energy\": 0.695, \"Loudness\": -6.865, \"Speechiness\": 0.0913, \"Acousticness\": 0.175, \"Liveness\": 0.15, \"Tempo\": 149.996, \"Duration (ms)\": 132780.0, \"Valence\": 0.472, \"Chord\": \"E\"}, {\"Index\": 31, \"Highest Charting Position\": 5, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Leave The Door Open\", \"Streams\": 13963568, \"Artist\": \"Bruno Mars, Anderson .Paak, Silk Sonic\", \"Artist Followers\": 32574754.0, \"Song ID\": \"7MAibcTli4IisCtbHKrGMh\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 92.0, \"Danceability\": 0.586, \"Energy\": 0.616, \"Loudness\": -7.964, \"Speechiness\": 0.0324, \"Acousticness\": 0.182, \"Liveness\": 0.0927, \"Tempo\": 148.088, \"Duration (ms)\": 242096.0, \"Valence\": 0.719, \"Chord\": \"F\"}, {\"Index\": 32, \"Highest Charting Position\": 32, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Don't Go Yet\", \"Streams\": 13205250, \"Artist\": \"Camila Cabello\", \"Artist Followers\": 22683756.0, \"Song ID\": \"1058fW9H3fZA6QjYCdOBad\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-07-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 88.0, \"Danceability\": 0.666, \"Energy\": 0.796, \"Loudness\": -6.967, \"Speechiness\": 0.103, \"Acousticness\": 0.0492, \"Liveness\": 0.0442, \"Tempo\": 110.108, \"Duration (ms)\": 164842.0, \"Valence\": 0.61, \"Chord\": \"A#/Bb\"}, {\"Index\": 33, \"Highest Charting Position\": 11, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"favorite crime\", \"Streams\": 12818935, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"5JCoSi02qi3jJeHdZXMmR8\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 91.0, \"Danceability\": 0.369, \"Energy\": 0.272, \"Loudness\": -10.497, \"Speechiness\": 0.0364, \"Acousticness\": 0.866, \"Liveness\": 0.147, \"Tempo\": 172.929, \"Duration (ms)\": 152667.0, \"Valence\": 0.218, \"Chord\": \"A\"}, {\"Index\": 34, \"Highest Charting Position\": 10, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Pareja Del A\\u00f1o\", \"Streams\": 12572307, \"Artist\": \"Sebastian Yatra, Myke Towers\", \"Artist Followers\": 16216789.0, \"Song ID\": \"2rCbl9naJYhaxjLsfx88uM\", \"Genre\": \"['colombian pop', 'latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 91.0, \"Danceability\": 0.715, \"Energy\": 0.622, \"Loudness\": -5.102, \"Speechiness\": 0.046, \"Acousticness\": 0.163, \"Liveness\": 0.0948, \"Tempo\": 80.015, \"Duration (ms)\": 195053.0, \"Valence\": 0.808, \"Chord\": \"E\"}, {\"Index\": 35, \"Highest Charting Position\": 4, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Watermelon Sugar\", \"Streams\": 11996689, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16112621.0, \"Song ID\": \"6UelLqGlWMcVH1E5c4H7lY\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 90.0, \"Danceability\": 0.548, \"Energy\": 0.816, \"Loudness\": -4.209, \"Speechiness\": 0.0465, \"Acousticness\": 0.122, \"Liveness\": 0.335, \"Tempo\": 95.39, \"Duration (ms)\": 174000.0, \"Valence\": 0.557, \"Chord\": \"C\"}, {\"Index\": 36, \"Highest Charting Position\": 36, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"NOT SOBER (feat. Polo G & Stunna Gambino)\", \"Streams\": 11869336, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 37, \"Highest Charting Position\": 3, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"RAPSTAR\", \"Streams\": 11683383, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"43PGPuHIlVOc04jrZVh9L6\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 89.0, \"Danceability\": 0.789, \"Energy\": 0.536, \"Loudness\": -6.862, \"Speechiness\": 0.242, \"Acousticness\": 0.41, \"Liveness\": 0.129, \"Tempo\": 81.039, \"Duration (ms)\": 165926.0, \"Valence\": 0.437, \"Chord\": \"F#/Gb\"}, {\"Index\": 38, \"Highest Charting Position\": 15, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"You Right\", \"Streams\": 11629418, \"Artist\": \"Doja Cat, The Weeknd\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0k4d5YPDr1r7FX77VdqWez\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 89.0, \"Danceability\": 0.828, \"Energy\": 0.621, \"Loudness\": -6.414, \"Speechiness\": 0.0565, \"Acousticness\": 0.0164, \"Liveness\": 0.0845, \"Tempo\": 128.986, \"Duration (ms)\": 186173.0, \"Valence\": 0.436, \"Chord\": \"G#/Ab\"}, {\"Index\": 39, \"Highest Charting Position\": 39, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"911 - Remix\", \"Streams\": 11553846, \"Artist\": \"Sech, Jhay Cortez\", \"Artist Followers\": 8758283.0, \"Song ID\": \"27RSJHEA99Y0Vsow7nA37A\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 89.0, \"Danceability\": 0.816, \"Energy\": 0.71, \"Loudness\": -3.728, \"Speechiness\": 0.0398, \"Acousticness\": 0.165, \"Liveness\": 0.292, \"Tempo\": 93.02, \"Duration (ms)\": 208631.0, \"Valence\": 0.784, \"Chord\": \"G\"}, {\"Index\": 40, \"Highest Charting Position\": 1, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"D\\u00c1KITI\", \"Streams\": 11524288, \"Artist\": \"Bad Bunny, Jhay Cortez\", \"Artist Followers\": 36142273.0, \"Song ID\": \"4MzXwWMhyBbmu6hOcLVD49\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 86.0, \"Danceability\": 0.731, \"Energy\": 0.573, \"Loudness\": -10.059, \"Speechiness\": 0.0544, \"Acousticness\": 0.401, \"Liveness\": 0.113, \"Tempo\": 109.928, \"Duration (ms)\": 205090.0, \"Valence\": 0.145, \"Chord\": \"E\"}, {\"Index\": 41, \"Highest Charting Position\": 41, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Mi\\u00e9nteme\", \"Streams\": 11477024, \"Artist\": \"TINI, Maria Becerra\", \"Artist Followers\": 2936204.0, \"Song ID\": \"0cOa970mzTWAxKtltpkpLc\", \"Genre\": \"['latin pop', 'pop argentino']\", \"Release Date\": \"2021-04-29\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 90.0, \"Danceability\": 0.85, \"Energy\": 0.541, \"Loudness\": -4.522, \"Speechiness\": 0.0674, \"Acousticness\": 0.161, \"Liveness\": 0.286, \"Tempo\": 92.003, \"Duration (ms)\": 165275.0, \"Valence\": 0.916, \"Chord\": \"D\"}, {\"Index\": 42, \"Highest Charting Position\": 17, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"jealousy, jealousy\", \"Streams\": 11287301, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"0MMyJUC3WNnFS1lit5pTjk\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 90.0, \"Danceability\": 0.695, \"Energy\": 0.575, \"Loudness\": -6.334, \"Speechiness\": 0.116, \"Acousticness\": 0.198, \"Liveness\": 0.0614, \"Tempo\": 163.929, \"Duration (ms)\": 173160.0, \"Valence\": 0.699, \"Chord\": \"A#/Bb\"}, {\"Index\": 43, \"Highest Charting Position\": 33, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Poblado - Remix\", \"Streams\": 11283626, \"Artist\": \"J Balvin, KAROL G, Nicky Jam, Crissin, Totoy El Frio, Natan & Shander\", \"Artist Followers\": 29051363.0, \"Song ID\": \"1WedZeiezCmCEOzLwhx0hV\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 89.0, \"Danceability\": 0.813, \"Energy\": 0.809, \"Loudness\": -5.382, \"Speechiness\": 0.0846, \"Acousticness\": 0.102, \"Liveness\": 0.377, \"Tempo\": 93.005, \"Duration (ms)\": 393280.0, \"Valence\": 0.646, \"Chord\": \"D#/Eb\"}, {\"Index\": 44, \"Highest Charting Position\": 2, \"Number of Times Charted\": 49, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Dynamite\", \"Streams\": 11196819, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"4saklk6nie3yiGePpBwUoc\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 89.0, \"Danceability\": 0.746, \"Energy\": 0.765, \"Loudness\": -4.41, \"Speechiness\": 0.0993, \"Acousticness\": 0.0112, \"Liveness\": 0.0936, \"Tempo\": 114.044, \"Duration (ms)\": 199054.0, \"Valence\": 0.737, \"Chord\": \"F#/Gb\"}, {\"Index\": 45, \"Highest Charting Position\": 9, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"The Business\", \"Streams\": 10739770, \"Artist\": \"Ti\\u00ebsto\", \"Artist Followers\": 5785065.0, \"Song ID\": \"6f3Slt0GbA2bPZlz0aIFXN\", \"Genre\": \"['big room', 'brostep', 'dance pop', 'dutch edm', 'edm', 'electro house', 'house', 'pop dance', 'slap house', 'trance', 'tropical house']\", \"Release Date\": \"2020-09-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 90.0, \"Danceability\": 0.798, \"Energy\": 0.62, \"Loudness\": -7.079, \"Speechiness\": 0.232, \"Acousticness\": 0.414, \"Liveness\": 0.112, \"Tempo\": 120.031, \"Duration (ms)\": 164000.0, \"Valence\": 0.235, \"Chord\": \"G#/Ab\"}, {\"Index\": 46, \"Highest Charting Position\": 46, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Heartbreak Anthem (with David Guetta & Little Mix)\", \"Streams\": 10315460, \"Artist\": \"Galantis\", \"Artist Followers\": 3120157.0, \"Song ID\": \"5K6Ssv4Z3zRvxt0P6EKUAP\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2021-05-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 89.0, \"Danceability\": 0.595, \"Energy\": 0.784, \"Loudness\": -4.878, \"Speechiness\": 0.102, \"Acousticness\": 0.216, \"Liveness\": 0.0608, \"Tempo\": 124.111, \"Duration (ms)\": 183726.0, \"Valence\": 0.479, \"Chord\": \"C#/Db\"}, {\"Index\": 47, \"Highest Charting Position\": 1, \"Number of Times Charted\": 51, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Mood (feat. iann dior)\", \"Streams\": 10222056, \"Artist\": \"24kGoldn\", \"Artist Followers\": 1274433.0, \"Song ID\": \"4jPy3l0RUwlUI9T5XHBW2m\", \"Genre\": \"['cali rap']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 89.0, \"Danceability\": 0.701, \"Energy\": 0.716, \"Loudness\": -3.671, \"Speechiness\": 0.0361, \"Acousticness\": 0.174, \"Liveness\": 0.324, \"Tempo\": 91.007, \"Duration (ms)\": 140533.0, \"Valence\": 0.732, \"Chord\": \"G\"}, {\"Index\": 48, \"Highest Charting Position\": 48, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Entre Nosotros\", \"Streams\": 10215216, \"Artist\": \"Tiago PZK, LIT killah\", \"Artist Followers\": 375865.0, \"Song ID\": \"6w8yBI2vthyN9UnwO4UBWb\", \"Genre\": \"['trap argentino']\", \"Release Date\": \"2021-07-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 89.0, \"Danceability\": 0.729, \"Energy\": 0.513, \"Loudness\": -6.345, \"Speechiness\": 0.0455, \"Acousticness\": 0.494, \"Liveness\": 0.137, \"Tempo\": 170.064, \"Duration (ms)\": 192353.0, \"Valence\": 0.789, \"Chord\": \"F\"}, {\"Index\": 49, \"Highest Charting Position\": 29, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Fiel - Remix\", \"Streams\": 10032746, \"Artist\": \"Wisin, Jhay Cortez, Anuel AA, Los Legendarios, Myke Towers\", \"Artist Followers\": 6929075.0, \"Song ID\": \"43qcs9NpJhDxtG91zxFkj7\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 89.0, \"Danceability\": 0.839, \"Energy\": 0.711, \"Loudness\": -4.733, \"Speechiness\": 0.0473, \"Acousticness\": 0.398, \"Liveness\": 0.118, \"Tempo\": 97.99, \"Duration (ms)\": 349547.0, \"Valence\": 0.573, \"Chord\": \"F#/Gb\"}, {\"Index\": 50, \"Highest Charting Position\": 20, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Build a Bitch\", \"Streams\": 9841998, \"Artist\": \"Bella Poarch\", \"Artist Followers\": 389076.0, \"Song ID\": \"7BoobGhD4x5K96Me0hqC8Q\", \"Genre\": \"[]\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 89.0, \"Danceability\": 0.855, \"Energy\": 0.463, \"Loudness\": -7.454, \"Speechiness\": 0.0367, \"Acousticness\": 0.217, \"Liveness\": 0.347, \"Tempo\": 102.931, \"Duration (ms)\": 122773.0, \"Valence\": 0.866, \"Chord\": \"D#/Eb\"}, {\"Index\": 51, \"Highest Charting Position\": 19, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Nicky Jam: Bzrp Music Sessions, Vol. 41\", \"Streams\": 9799701, \"Artist\": \"Bizarrap, Nicky Jam\", \"Artist Followers\": 3126961.0, \"Song ID\": \"03LfOYi0icz4souspZVVhq\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2021-06-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 88.0, \"Danceability\": 0.627, \"Energy\": 0.849, \"Loudness\": -3.167, \"Speechiness\": 0.153, \"Acousticness\": 0.0913, \"Liveness\": 0.145, \"Tempo\": 89.907, \"Duration (ms)\": 158087.0, \"Valence\": 0.818, \"Chord\": \"C#/Db\"}, {\"Index\": 52, \"Highest Charting Position\": 52, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Tiroteo - Remix\", \"Streams\": 9781153, \"Artist\": \"Marc Segu\\u00ed, Rauw Alejandro, Pol Granch\", \"Artist Followers\": 45362.0, \"Song ID\": \"4OwhwvKESFtuu06dTgct7i\", \"Genre\": \"[]\", \"Release Date\": \"2021-04-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 88.0, \"Danceability\": 0.75, \"Energy\": 0.522, \"Loudness\": -7.018, \"Speechiness\": 0.0293, \"Acousticness\": 0.282, \"Liveness\": 0.0743, \"Tempo\": 110.427, \"Duration (ms)\": 321556.0, \"Valence\": 0.601, \"Chord\": \"A\"}, {\"Index\": 53, \"Highest Charting Position\": 19, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"NDA\", \"Streams\": 9635619, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47014200.0, \"Song ID\": \"38GBNKZUhfBkk3oNlWzRYd\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-07-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 84.0, \"Danceability\": 0.765, \"Energy\": 0.373, \"Loudness\": -9.921, \"Speechiness\": 0.0713, \"Acousticness\": 0.341, \"Liveness\": 0.112, \"Tempo\": 85.016, \"Duration (ms)\": 195777.0, \"Valence\": 0.554, \"Chord\": \"G#/Ab\"}, {\"Index\": 54, \"Highest Charting Position\": 40, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Rasputin\", \"Streams\": 9600707, \"Artist\": \"Majestic, Boney M.\", \"Artist Followers\": 32178.0, \"Song ID\": \"6FO4K7MrMoYkc5BlpX5LNV\", \"Genre\": \"['house', 'pop dance', 'uk dance']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 49.0, \"Danceability\": 0.83, \"Energy\": 0.839, \"Loudness\": -6.985, \"Speechiness\": 0.0699, \"Acousticness\": 0.00201, \"Liveness\": 0.0353, \"Tempo\": 128.012, \"Duration (ms)\": 345543.0, \"Valence\": 0.59, \"Chord\": \"F#/Gb\"}, {\"Index\": 55, \"Highest Charting Position\": 52, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Leave Before You Love Me (with Jonas Brothers)\", \"Streams\": 9428494, \"Artist\": \"Marshmello\", \"Artist Followers\": 31541310.0, \"Song ID\": \"4qu63nuBpdn0qHUHuObEj1\", \"Genre\": \"['brostep', 'edm', 'pop', 'pop dance', 'progressive electro house']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\", \"Popularity\": 89.0, \"Danceability\": 0.721, \"Energy\": 0.738, \"Loudness\": -4.77, \"Speechiness\": 0.0403, \"Acousticness\": 0.00226, \"Liveness\": 0.118, \"Tempo\": 119.976, \"Duration (ms)\": 154983.0, \"Valence\": 0.637, \"Chord\": \"G\"}, {\"Index\": 56, \"Highest Charting Position\": 56, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Freaks\", \"Streams\": 9319465, \"Artist\": \"Surf Curse\", \"Artist Followers\": 495226.0, \"Song ID\": \"7EkWXAI1wn8Ii883ecd9xr\", \"Genre\": \"['dreamo', 'indie surf', 'surf punk', 'vegas indie']\", \"Release Date\": \"2021-05-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 89.0, \"Danceability\": 0.345, \"Energy\": 0.941, \"Loudness\": -9.918, \"Speechiness\": 0.0466, \"Acousticness\": 3.84e-05, \"Liveness\": 0.0511, \"Tempo\": 179.626, \"Duration (ms)\": 147062.0, \"Valence\": 0.407, \"Chord\": \"A\"}, {\"Index\": 57, \"Highest Charting Position\": 57, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Meu Peda\\u00e7o de Pecado\", \"Streams\": 9206366, \"Artist\": \"Jo\\u00e3o Gomes\", \"Artist Followers\": 409173.0, \"Song ID\": \"2kJRlOyrxsy7Ot3c5TZ8Q6\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 83.0, \"Danceability\": 0.668, \"Energy\": 0.887, \"Loudness\": -4.404, \"Speechiness\": 0.0564, \"Acousticness\": 0.369, \"Liveness\": 0.257, \"Tempo\": 151.92, \"Duration (ms)\": 157176.0, \"Valence\": 0.907, \"Chord\": \"B\"}, {\"Index\": 58, \"Highest Charting Position\": 31, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"2/Catorce\", \"Streams\": 9086979, \"Artist\": \"Rauw Alejandro, Mr. Naisgai\", \"Artist Followers\": 6080597.0, \"Song ID\": \"71R8HJxQk5qMiRstrlXN9t\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2021-02-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 87.0, \"Danceability\": 0.54, \"Energy\": 0.455, \"Loudness\": -5.988, \"Speechiness\": 0.224, \"Acousticness\": 0.675, \"Liveness\": 0.12, \"Tempo\": 83.876, \"Duration (ms)\": 212032.0, \"Valence\": 0.432, \"Chord\": \"D#/Eb\"}, {\"Index\": 59, \"Highest Charting Position\": 34, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Beautiful Mistakes (feat. Megan Thee Stallion)\", \"Streams\": 9048966, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32262679.0, \"Song ID\": \"5zFglKYiknIxks8geR8rcL\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 88.0, \"Danceability\": 0.713, \"Energy\": 0.676, \"Loudness\": -5.483, \"Speechiness\": 0.027, \"Acousticness\": 0.0377, \"Liveness\": 0.154, \"Tempo\": 99.048, \"Duration (ms)\": 227395.0, \"Valence\": 0.721, \"Chord\": \"A#/Bb\"}, {\"Index\": 60, \"Highest Charting Position\": 31, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Run\", \"Streams\": 9017356, \"Artist\": \"OneRepublic\", \"Artist Followers\": 12169108.0, \"Song ID\": \"2UbVnbE5FH6008mAm6Mmgw\", \"Genre\": \"['dance pop', 'piano rock', 'pop', 'pop rock']\", \"Release Date\": \"2021-05-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2020-09-25--2020-10-02\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 88.0, \"Danceability\": 0.682, \"Energy\": 0.72, \"Loudness\": -8.173, \"Speechiness\": 0.0381, \"Acousticness\": 0.326, \"Liveness\": 0.148, \"Tempo\": 117.003, \"Duration (ms)\": 169011.0, \"Valence\": 0.673, \"Chord\": \"B\"}, {\"Index\": 61, \"Highest Charting Position\": 46, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Thot Shit\", \"Streams\": 8977336, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4787261.0, \"Song ID\": \"5zNW5ARjYhJQJz1AChP33n\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 88.0, \"Danceability\": 0.95, \"Energy\": 0.693, \"Loudness\": -3.424, \"Speechiness\": 0.0898, \"Acousticness\": 0.0133, \"Liveness\": 0.173, \"Tempo\": 130.02, \"Duration (ms)\": 184635.0, \"Valence\": 0.891, \"Chord\": \"A\"}, {\"Index\": 62, \"Highest Charting Position\": 26, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Your Love (9PM)\", \"Streams\": 8935418, \"Artist\": \"ATB, Topic, A7S\", \"Artist Followers\": 291777.0, \"Song ID\": \"5YaskwnGDZFDRipaqzbwQx\", \"Genre\": \"['german dance', 'german techno', 'german trance', 'trance']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 88.0, \"Danceability\": 0.669, \"Energy\": 0.784, \"Loudness\": -5.603, \"Speechiness\": 0.112, \"Acousticness\": 0.194, \"Liveness\": 0.115, \"Tempo\": 125.993, \"Duration (ms)\": 150053.0, \"Valence\": 0.517, \"Chord\": \"G\"}, {\"Index\": 63, \"Highest Charting Position\": 9, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"brutal\", \"Streams\": 8881356, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"6SRsiMl7w1USE4mFqrOhHC\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 89.0, \"Danceability\": 0.672, \"Energy\": 0.526, \"Loudness\": -6.446, \"Speechiness\": 0.0599, \"Acousticness\": 0.0311, \"Liveness\": 0.28, \"Tempo\": 123.999, \"Duration (ms)\": 143747.0, \"Valence\": 0.28, \"Chord\": \"E\"}, {\"Index\": 64, \"Highest Charting Position\": 2, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Save Your Tears\", \"Streams\": 8843110, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"37BZB0z9T8Xu7U3e65qxFy\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 94.0, \"Danceability\": 0.65, \"Energy\": 0.825, \"Loudness\": -4.645, \"Speechiness\": 0.0325, \"Acousticness\": 0.0215, \"Liveness\": 0.0936, \"Tempo\": 118.091, \"Duration (ms)\": 191014.0, \"Valence\": 0.593, \"Chord\": \"C\"}, {\"Index\": 65, \"Highest Charting Position\": 8, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Heartbreak Anniversary\", \"Streams\": 8832945, \"Artist\": \"Giveon\", \"Artist Followers\": 1398563.0, \"Song ID\": \"3FAJ6O0NOHQV8Mc5Ri6ENp\", \"Genre\": \"['pop', 'r&b']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 87.0, \"Danceability\": 0.449, \"Energy\": 0.465, \"Loudness\": -8.964, \"Speechiness\": 0.0791, \"Acousticness\": 0.524, \"Liveness\": 0.303, \"Tempo\": 89.087, \"Duration (ms)\": 198371.0, \"Valence\": 0.543, \"Chord\": \"C\"}, {\"Index\": 66, \"Highest Charting Position\": 2, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Don't Start Now\", \"Streams\": 8821971, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 1250353.0, \"Song ID\": \"7njGslFmqBmOSSOpTyZCs9\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.793, \"Energy\": 0.793, \"Loudness\": -4.521, \"Speechiness\": 0.083, \"Acousticness\": 0.0123, \"Liveness\": 0.0951, \"Tempo\": 123.95, \"Duration (ms)\": 183290.0, \"Valence\": 0.679, \"Chord\": \"B\"}, {\"Index\": 67, \"Highest Charting Position\": 33, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Dinero\", \"Streams\": 8564775, \"Artist\": \"Trinidad Cardona\", \"Artist Followers\": 116817.0, \"Song ID\": \"3ggtU1ZOKO8ZNiqPNyXGcm\", \"Genre\": \"[]\", \"Release Date\": \"2018-02-02\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 87.0, \"Danceability\": 0.708, \"Energy\": 0.782, \"Loudness\": -4.687, \"Speechiness\": 0.0674, \"Acousticness\": 0.00772, \"Liveness\": 0.107, \"Tempo\": 119.997, \"Duration (ms)\": 160880.0, \"Valence\": 0.484, \"Chord\": \"D\"}, {\"Index\": 68, \"Highest Charting Position\": 35, \"Number of Times Charted\": 48, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Sweater Weather\", \"Streams\": 8564017, \"Artist\": \"The Neighbourhood\", \"Artist Followers\": 6662605.0, \"Song ID\": \"2QjOHCTQ1Jl3zawyYOpxh6\", \"Genre\": \"['modern alternative rock', 'modern rock', 'pop']\", \"Release Date\": \"2013-04-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 87.0, \"Danceability\": 0.612, \"Energy\": 0.807, \"Loudness\": -2.81, \"Speechiness\": 0.0336, \"Acousticness\": 0.0495, \"Liveness\": 0.101, \"Tempo\": 124.053, \"Duration (ms)\": 240400.0, \"Valence\": 0.398, \"Chord\": \"A#/Bb\"}, {\"Index\": 69, \"Highest Charting Position\": 69, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Sobrio\", \"Streams\": 8514480, \"Artist\": \"Maluma\", \"Artist Followers\": 26769304.0, \"Song ID\": \"4HzqWEdAbzcVFDv0pvxV4w\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-07-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 87.0, \"Danceability\": 0.762, \"Energy\": 0.77, \"Loudness\": -2.758, \"Speechiness\": 0.223, \"Acousticness\": 0.138, \"Liveness\": 0.15, \"Tempo\": 177.998, \"Duration (ms)\": 201181.0, \"Valence\": 0.631, \"Chord\": \"F\"}, {\"Index\": 70, \"Highest Charting Position\": 12, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Someone You Loved\", \"Streams\": 8490162, \"Artist\": \"Lewis Capaldi\", \"Artist Followers\": 8384096.0, \"Song ID\": \"7qEHsqek33rTcFNT9PFqLf\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.501, \"Energy\": 0.405, \"Loudness\": -5.679, \"Speechiness\": 0.0319, \"Acousticness\": 0.751, \"Liveness\": 0.105, \"Tempo\": 109.891, \"Duration (ms)\": 182161.0, \"Valence\": 0.446, \"Chord\": \"C#/Db\"}, {\"Index\": 71, \"Highest Charting Position\": 71, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Over The Top (feat. Drake)\", \"Streams\": 8269753, \"Artist\": \"Smiley\", \"Artist Followers\": 26131.0, \"Song ID\": \"3yaYgjEFkRw3PVjW9mV1TO\", \"Genre\": \"['canadian hip hop', 'toronto rap']\", \"Release Date\": \"2021-07-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 83.0, \"Danceability\": 0.833, \"Energy\": 0.498, \"Loudness\": -5.196, \"Speechiness\": 0.117, \"Acousticness\": 0.0493, \"Liveness\": 0.119, \"Tempo\": 139.928, \"Duration (ms)\": 153406.0, \"Valence\": 0.259, \"Chord\": \"A#/Bb\"}, {\"Index\": 72, \"Highest Charting Position\": 72, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"2055\", \"Streams\": 8133401, \"Artist\": \"Sleepy Hallow\", \"Artist Followers\": 408696.0, \"Song ID\": \"4XvcHTUfIlWfyJTRG0aqlo\", \"Genre\": \"['brooklyn drill', 'nyc rap']\", \"Release Date\": \"2021-06-02\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 85.0, \"Danceability\": 0.829, \"Energy\": 0.512, \"Loudness\": -5.865, \"Speechiness\": 0.187, \"Acousticness\": 0.492, \"Liveness\": 0.12, \"Tempo\": 80.511, \"Duration (ms)\": 123987.0, \"Valence\": 0.638, \"Chord\": \"F#/Gb\"}, {\"Index\": 73, \"Highest Charting Position\": 33, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"EL MAKINON\", \"Streams\": 8102107, \"Artist\": \"KAROL G, Mariah Angeliq\", \"Artist Followers\": 17775316.0, \"Song ID\": \"2FSGUA0gFgGeQdprjtGM2M\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 87.0, \"Danceability\": 0.635, \"Energy\": 0.706, \"Loudness\": -3.224, \"Speechiness\": 0.125, \"Acousticness\": 0.256, \"Liveness\": 0.108, \"Tempo\": 88.863, \"Duration (ms)\": 209160.0, \"Valence\": 0.443, \"Chord\": \"F\"}, {\"Index\": 74, \"Highest Charting Position\": 74, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Loco\", \"Streams\": 8093413, \"Artist\": \"Justin Quiles, Chimbala, Zion & Lennox\", \"Artist Followers\": 2895789.0, \"Song ID\": \"6PDlkWmrq2ZKiUuFt2aQsH\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 87.0, \"Danceability\": 0.77, \"Energy\": 0.899, \"Loudness\": -2.981, \"Speechiness\": 0.0494, \"Acousticness\": 0.222, \"Liveness\": 0.0894, \"Tempo\": 128.05, \"Duration (ms)\": 231604.0, \"Valence\": 0.851, \"Chord\": \"G#/Ab\"}, {\"Index\": 75, \"Highest Charting Position\": 75, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Love Tonight - Edit\", \"Streams\": 8006336, \"Artist\": \"Shouse\", \"Artist Followers\": 27116.0, \"Song ID\": \"6OufwUcCqo81guU2jAlDVP\", \"Genre\": \"['aussietronica']\", \"Release Date\": \"2017-12-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 87.0, \"Danceability\": 0.727, \"Energy\": 0.681, \"Loudness\": -7.114, \"Speechiness\": 0.0265, \"Acousticness\": 0.00214, \"Liveness\": 0.0861, \"Tempo\": 123.028, \"Duration (ms)\": 241970.0, \"Valence\": 0.448, \"Chord\": \"F\"}, {\"Index\": 76, \"Highest Charting Position\": 12, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"ZITTI E BUONI\", \"Streams\": 7975148, \"Artist\": \"M\\u00e5neskin\", \"Artist Followers\": 3377762.0, \"Song ID\": \"776AftMmFFAWUIEAb3lHhw\", \"Genre\": \"['indie rock italiano', 'italian pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-03-05--2021-03-12\", \"Popularity\": 86.0, \"Danceability\": 0.625, \"Energy\": 0.939, \"Loudness\": -3.115, \"Speechiness\": 0.0669, \"Acousticness\": 0.00138, \"Liveness\": 0.424, \"Tempo\": 102.999, \"Duration (ms)\": 194787.0, \"Valence\": 0.644, \"Chord\": \"E\"}, {\"Index\": 77, \"Highest Charting Position\": 2, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"telepat\\u00eda\", \"Streams\": 7912399, \"Artist\": \"Kali Uchis\", \"Artist Followers\": 1999954.0, \"Song ID\": \"6tDDoYIxWvMLTdKpjFkc1B\", \"Genre\": \"['colombian pop', 'pop']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 88.0, \"Danceability\": 0.653, \"Energy\": 0.524, \"Loudness\": -9.016, \"Speechiness\": 0.0502, \"Acousticness\": 0.112, \"Liveness\": 0.203, \"Tempo\": 83.97, \"Duration (ms)\": 160191.0, \"Valence\": 0.553, \"Chord\": \"B\"}, {\"Index\": 78, \"Highest Charting Position\": 9, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Botella Tras Botella\", \"Streams\": 7735223, \"Artist\": \"Gera MX, Christian Nodal\", \"Artist Followers\": 2043294.0, \"Song ID\": \"2MnLkFqY9Rpg9s3Zv6ZJdK\", \"Genre\": \"['mexican hip hop', 'rap conciencia']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 87.0, \"Danceability\": 0.727, \"Energy\": 0.546, \"Loudness\": -4.572, \"Speechiness\": 0.0437, \"Acousticness\": 0.656, \"Liveness\": 0.122, \"Tempo\": 106.891, \"Duration (ms)\": 197333.0, \"Valence\": 0.69, \"Chord\": \"C\"}, {\"Index\": 79, \"Highest Charting Position\": 7, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Fiel\", \"Streams\": 7717211, \"Artist\": \"Los Legendarios, Wisin, Jhay Cortez\", \"Artist Followers\": 31488.0, \"Song ID\": \"7Bk0uXKk1uPT0XuQbpFzvs\", \"Genre\": \"['reggaeton', 'trap latino']\", \"Release Date\": \"2021-02-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 88.0, \"Danceability\": 0.849, \"Energy\": 0.701, \"Loudness\": -4.407, \"Speechiness\": 0.06, \"Acousticness\": 0.407, \"Liveness\": 0.112, \"Tempo\": 98.005, \"Duration (ms)\": 261667.0, \"Valence\": 0.505, \"Chord\": \"F#/Gb\"}, {\"Index\": 80, \"Highest Charting Position\": 1, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Dance Monkey\", \"Streams\": 7687058, \"Artist\": \"Tones And I\", \"Artist Followers\": 2819593.0, \"Song ID\": \"2XU0oxnq2qxCpomAAuJY8K\", \"Genre\": \"['australian pop', 'pop']\", \"Release Date\": \"2019-10-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.824, \"Energy\": 0.588, \"Loudness\": -6.4, \"Speechiness\": 0.0924, \"Acousticness\": 0.692, \"Liveness\": 0.149, \"Tempo\": 98.027, \"Duration (ms)\": 209438.0, \"Valence\": 0.513, \"Chord\": \"F#/Gb\"}, {\"Index\": 81, \"Highest Charting Position\": 7, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"WITHOUT YOU\", \"Streams\": 7642130, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2230022.0, \"Song ID\": \"27OeeYzk6klgBh83TSvGMA\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 87.0, \"Danceability\": 0.662, \"Energy\": 0.413, \"Loudness\": -7.357, \"Speechiness\": 0.0299, \"Acousticness\": 0.213, \"Liveness\": 0.134, \"Tempo\": 93.005, \"Duration (ms)\": 161385.0, \"Valence\": 0.467, \"Chord\": \"C\"}, {\"Index\": 82, \"Highest Charting Position\": 6, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Wants and Needs (feat. Lil Baby)\", \"Streams\": 7637626, \"Artist\": \"Drake\", \"Artist Followers\": 56308172.0, \"Song ID\": \"65OVbaJR5O1RmwOQx0875b\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 87.0, \"Danceability\": 0.578, \"Energy\": 0.449, \"Loudness\": -6.349, \"Speechiness\": 0.286, \"Acousticness\": 0.0618, \"Liveness\": 0.119, \"Tempo\": 136.006, \"Duration (ms)\": 192956.0, \"Valence\": 0.1, \"Chord\": \"C#/Db\"}, {\"Index\": 83, \"Highest Charting Position\": 83, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Bezos I\", \"Streams\": 7516291, \"Artist\": \"Bo Burnham\", \"Artist Followers\": 1042079.0, \"Song ID\": \"0Kdj7nwaYQmvhxnqZaIQuW\", \"Genre\": \"['comic']\", \"Release Date\": \"2021-06-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 84.0, \"Danceability\": 0.694, \"Energy\": 0.948, \"Loudness\": -5.307, \"Speechiness\": 0.0361, \"Acousticness\": 0.00936, \"Liveness\": 0.139, \"Tempo\": 115.044, \"Duration (ms)\": 58149.0, \"Valence\": 0.705, \"Chord\": \"D\"}, {\"Index\": 84, \"Highest Charting Position\": 76, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Love Again\", \"Streams\": 7465445, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 1250353.0, \"Song ID\": \"2sN1pMv6d2t5GlvN6IBMlK\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2020-03-27--2020-04-03\", \"Popularity\": 0.0, \"Danceability\": 0.659, \"Energy\": 0.667, \"Loudness\": -4.668, \"Speechiness\": 0.0339, \"Acousticness\": 0.00173, \"Liveness\": 0.1, \"Tempo\": 115.982, \"Duration (ms)\": 258004.0, \"Valence\": 0.468, \"Chord\": \"B\"}, {\"Index\": 85, \"Highest Charting Position\": 32, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Goosebumps - Remix\", \"Streams\": 7452633, \"Artist\": \"Travis Scott, HVME\", \"Artist Followers\": 17719446.0, \"Song ID\": \"5uEYRdEIh9Bo4fpjDd4Na9\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 87.0, \"Danceability\": 0.841, \"Energy\": 0.593, \"Loudness\": -7.846, \"Speechiness\": 0.0379, \"Acousticness\": 0.418, \"Liveness\": 0.124, \"Tempo\": 124.917, \"Duration (ms)\": 162803.0, \"Valence\": 0.808, \"Chord\": \"C#/Db\"}, {\"Index\": 86, \"Highest Charting Position\": 11, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Head & Heart (feat. MNEK)\", \"Streams\": 7434252, \"Artist\": \"Joel Corry\", \"Artist Followers\": 207547.0, \"Song ID\": \"6cx06DFPPHchuUAcTxznu9\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance', 'tropical house', 'uk dance']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 87.0, \"Danceability\": 0.734, \"Energy\": 0.874, \"Loudness\": -3.158, \"Speechiness\": 0.0662, \"Acousticness\": 0.168, \"Liveness\": 0.0489, \"Tempo\": 122.953, \"Duration (ms)\": 166028.0, \"Valence\": 0.905, \"Chord\": \"G#/Ab\"}, {\"Index\": 87, \"Highest Charting Position\": 42, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"BED\", \"Streams\": 7383369, \"Artist\": \"Joel Corry, RAYE, David Guetta\", \"Artist Followers\": 207547.0, \"Song ID\": \"0siYMEsGrzzzlWLXK5zJfS\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance', 'tropical house', 'uk dance']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 87.0, \"Danceability\": 0.671, \"Energy\": 0.782, \"Loudness\": -4.593, \"Speechiness\": 0.0341, \"Acousticness\": 0.0142, \"Liveness\": 0.333, \"Tempo\": 123.989, \"Duration (ms)\": 178088.0, \"Valence\": 0.618, \"Chord\": \"F#/Gb\"}, {\"Index\": 88, \"Highest Charting Position\": 78, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Iko Iko (My Bestie)\", \"Streams\": 7381585, \"Artist\": \"Justin Wellington, Small Jam\", \"Artist Followers\": 18228.0, \"Song ID\": \"7MC4XR9M9amdmKQr2iDF7i\", \"Genre\": \"['melanesian pop', 'pacific islands pop', 'png pop']\", \"Release Date\": \"2019-06-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 87.0, \"Danceability\": 0.862, \"Energy\": 0.753, \"Loudness\": -5.356, \"Speechiness\": 0.0625, \"Acousticness\": 0.131, \"Liveness\": 0.077, \"Tempo\": 105.039, \"Duration (ms)\": 182857.0, \"Valence\": 0.827, \"Chord\": \"F\"}, {\"Index\": 89, \"Highest Charting Position\": 89, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Better Believe\", \"Streams\": 7365053, \"Artist\": \"Belly, The Weeknd, Young Thug\", \"Artist Followers\": 203972.0, \"Song ID\": \"3zs87EV3EZSh2UpiXxT52Y\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'pop rap', 'rap', 'southern hip hop', 'trap', 'trap soul', 'underground hip hop']\", \"Release Date\": \"2021-07-22\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 80.0, \"Danceability\": 0.797, \"Energy\": 0.573, \"Loudness\": -7.85, \"Speechiness\": 0.319, \"Acousticness\": 0.159, \"Liveness\": 0.144, \"Tempo\": 124.995, \"Duration (ms)\": 206629.0, \"Valence\": 0.445, \"Chord\": \"C\"}, {\"Index\": 90, \"Highest Charting Position\": 23, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Arcade\", \"Streams\": 7353795, \"Artist\": \"Duncan Laurence\", \"Artist Followers\": 287361.0, \"Song ID\": \"1Xi84slp6FryDSCbzq4UCD\", \"Genre\": \"['dutch pop']\", \"Release Date\": \"2019-03-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 84.0, \"Danceability\": 0.45, \"Energy\": 0.329, \"Loudness\": -12.603, \"Speechiness\": 0.0441, \"Acousticness\": 0.818, \"Liveness\": 0.135, \"Tempo\": 71.884, \"Duration (ms)\": 183624.0, \"Valence\": 0.266, \"Chord\": \"A\"}, {\"Index\": 91, \"Highest Charting Position\": 55, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"512\", \"Streams\": 7336542, \"Artist\": \"Mora, Jhay Cortez\", \"Artist Followers\": 151486.0, \"Song ID\": \"5jzEwSyyymBlf1fa1o39T2\", \"Genre\": \"['reggaeton', 'trap latino']\", \"Release Date\": \"2021-02-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 87.0, \"Danceability\": 0.818, \"Energy\": 0.673, \"Loudness\": -7.542, \"Speechiness\": 0.148, \"Acousticness\": 0.348, \"Liveness\": 0.172, \"Tempo\": 87.961, \"Duration (ms)\": 193636.0, \"Valence\": 0.695, \"Chord\": \"E\"}, {\"Index\": 92, \"Highest Charting Position\": 1, \"Number of Times Charted\": 40, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"positions\", \"Streams\": 7244853, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67158068.0, \"Song ID\": \"35mvY5S1H3J2QZyna3TFe0\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 86.0, \"Danceability\": 0.737, \"Energy\": 0.802, \"Loudness\": -4.771, \"Speechiness\": 0.0878, \"Acousticness\": 0.468, \"Liveness\": 0.0931, \"Tempo\": 144.015, \"Duration (ms)\": 172325.0, \"Valence\": 0.682, \"Chord\": \"C\"}, {\"Index\": 93, \"Highest Charting Position\": 6, \"Number of Times Charted\": 84, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Circles\", \"Streams\": 7156162, \"Artist\": \"Post Malone\", \"Artist Followers\": 33651775.0, \"Song ID\": \"21jGcNKet2qwijlDFuPiPb\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 87.0, \"Danceability\": 0.695, \"Energy\": 0.762, \"Loudness\": -3.497, \"Speechiness\": 0.0395, \"Acousticness\": 0.192, \"Liveness\": 0.0863, \"Tempo\": 120.042, \"Duration (ms)\": 215280.0, \"Valence\": 0.553, \"Chord\": \"C\"}, {\"Index\": 94, \"Highest Charting Position\": 94, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Blaues Licht\", \"Streams\": 7084292, \"Artist\": \"RAF Camora, Bonez MC\", \"Artist Followers\": 1329531.0, \"Song ID\": \"08EPQiLMyGB8GJX2EiVoCM\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 78.0, \"Danceability\": 0.819, \"Energy\": 0.835, \"Loudness\": -4.899, \"Speechiness\": 0.102, \"Acousticness\": 0.398, \"Liveness\": 0.252, \"Tempo\": 144.955, \"Duration (ms)\": 144264.0, \"Valence\": 0.703, \"Chord\": \"G#/Ab\"}, {\"Index\": 95, \"Highest Charting Position\": 75, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Ram Pam Pam\", \"Streams\": 7064003, \"Artist\": \"Natti Natasha, Becky G\", \"Artist Followers\": 6341942.0, \"Song ID\": \"4DHDIdeayp8xvlyg22wREO\", \"Genre\": \"['latin', 'latin pop', 'rap latina', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-04-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 86.0, \"Danceability\": 0.908, \"Energy\": 0.813, \"Loudness\": -2.749, \"Speechiness\": 0.0777, \"Acousticness\": 0.305, \"Liveness\": 0.278, \"Tempo\": 97.018, \"Duration (ms)\": 200785.0, \"Valence\": 0.924, \"Chord\": \"F\"}, {\"Index\": 96, \"Highest Charting Position\": 96, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"In Da Getto\", \"Streams\": 6984262, \"Artist\": \"J Balvin, Skrillex\", \"Artist Followers\": 1250353.0, \"Song ID\": \"5lGtPshEJlsJgmqKLi41LY\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 2.0, \"Danceability\": 0.915, \"Energy\": 0.72, \"Loudness\": -3.126, \"Speechiness\": 0.0459, \"Acousticness\": 0.025, \"Liveness\": 0.0942, \"Tempo\": 126.986, \"Duration (ms)\": 131067.0, \"Valence\": 0.631, \"Chord\": \"G#/Ab\"}, {\"Index\": 97, \"Highest Charting Position\": 97, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Woman\", \"Streams\": 6858466, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"6Uj1ctrBOjOas8xZXGqKk4\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-06-25--2021-07-02\", \"Popularity\": 86.0, \"Danceability\": 0.824, \"Energy\": 0.764, \"Loudness\": -4.175, \"Speechiness\": 0.0854, \"Acousticness\": 0.0888, \"Liveness\": 0.117, \"Tempo\": 107.998, \"Duration (ms)\": 172627.0, \"Valence\": 0.881, \"Chord\": \"F\"}, {\"Index\": 98, \"Highest Charting Position\": 60, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"t r a n s p a r e n t s o u l feat. Travis Barker\", \"Streams\": 6853994, \"Artist\": \"WILLOW\", \"Artist Followers\": 1521837.0, \"Song ID\": \"1QL7nSDZCwZMnbisV4KOXt\", \"Genre\": \"['afrofuturism', 'dance pop', 'electropop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2021-04-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 85.0, \"Danceability\": 0.39, \"Energy\": 0.83, \"Loudness\": -5.201, \"Speechiness\": 0.0563, \"Acousticness\": 0.0021, \"Liveness\": 0.156, \"Tempo\": 90.021, \"Duration (ms)\": 168030.0, \"Valence\": 0.191, \"Chord\": \"B\"}, {\"Index\": 99, \"Highest Charting Position\": 99, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Clash (feat. Stormzy)\", \"Streams\": 6825463, \"Artist\": \"Dave\", \"Artist Followers\": 1427540.0, \"Song ID\": \"2oUwMN5VfdGX10XeQJLBBi\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2021-07-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-09--2021-07-16\", \"Popularity\": 79.0, \"Danceability\": 0.871, \"Energy\": 0.519, \"Loudness\": -6.549, \"Speechiness\": 0.258, \"Acousticness\": 0.313, \"Liveness\": 0.0869, \"Tempo\": 140.013, \"Duration (ms)\": 251733.0, \"Valence\": 0.532, \"Chord\": \"D\"}, {\"Index\": 100, \"Highest Charting Position\": 22, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Before You Go\", \"Streams\": 6813800, \"Artist\": \"Lewis Capaldi\", \"Artist Followers\": 8384096.0, \"Song ID\": \"2gMXnyrvIjhVBUZwvLZDMP\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.459, \"Energy\": 0.575, \"Loudness\": -4.858, \"Speechiness\": 0.0573, \"Acousticness\": 0.604, \"Liveness\": 0.0885, \"Tempo\": 111.881, \"Duration (ms)\": 215107.0, \"Valence\": 0.183, \"Chord\": \"D#/Eb\"}, {\"Index\": 101, \"Highest Charting Position\": 52, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Levitating\", \"Streams\": 6799831, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"463CkQjx2Zk1yXoBuierM9\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-10-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 89.0, \"Danceability\": 0.702, \"Energy\": 0.825, \"Loudness\": -3.787, \"Speechiness\": 0.0601, \"Acousticness\": 0.00883, \"Liveness\": 0.0674, \"Tempo\": 102.977, \"Duration (ms)\": 203064.0, \"Valence\": 0.915, \"Chord\": \"F#/Gb\"}, {\"Index\": 102, \"Highest Charting Position\": 85, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Reckless\", \"Streams\": 6711375, \"Artist\": \"Madison Beer\", \"Artist Followers\": 3363988.0, \"Song ID\": \"5ajjAnNRh8bxFvaVHzpPjh\", \"Genre\": \"['alt z', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 86.0, \"Danceability\": 0.386, \"Energy\": 0.426, \"Loudness\": -6.642, \"Speechiness\": 0.0363, \"Acousticness\": 0.807, \"Liveness\": 0.14, \"Tempo\": 180.104, \"Duration (ms)\": 203385.0, \"Valence\": 0.261, \"Chord\": \"D#/Eb\"}, {\"Index\": 103, \"Highest Charting Position\": 103, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"No Me Conocen (Remix) [con DUKI, Rei & Tiago PZK]\", \"Streams\": 6709106, \"Artist\": \"BANDIDO\", \"Artist Followers\": 16074.0, \"Song ID\": \"7COGuXyTr12KvdaYXMqheC\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 85.0, \"Danceability\": 0.769, \"Energy\": 0.812, \"Loudness\": -2.088, \"Speechiness\": 0.0825, \"Acousticness\": 0.281, \"Liveness\": 0.0781, \"Tempo\": 180.003, \"Duration (ms)\": 280274.0, \"Valence\": 0.926, \"Chord\": \"C#/Db\"}, {\"Index\": 104, \"Highest Charting Position\": 88, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Believer\", \"Streams\": 6699895, \"Artist\": \"Imagine Dragons\", \"Artist Followers\": 35285425.0, \"Song ID\": \"0pqnGHJpmpxLKifKRmU6WP\", \"Genre\": \"['modern rock', 'pop', 'rock']\", \"Release Date\": \"2017-06-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.776, \"Energy\": 0.78, \"Loudness\": -4.374, \"Speechiness\": 0.128, \"Acousticness\": 0.0622, \"Liveness\": 0.081, \"Tempo\": 124.949, \"Duration (ms)\": 204347.0, \"Valence\": 0.666, \"Chord\": \"A#/Bb\"}, {\"Index\": 105, \"Highest Charting Position\": 2, \"Number of Times Charted\": 48, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Lemonade (feat. Gunna, Don Toliver & NAV)\", \"Streams\": 6697067, \"Artist\": \"Internet Money\", \"Artist Followers\": 411579.0, \"Song ID\": \"02kDW379Yfd5PzW5A6vuGt\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 82.0, \"Danceability\": 0.799, \"Energy\": 0.66, \"Loudness\": -6.153, \"Speechiness\": 0.079, \"Acousticness\": 0.256, \"Liveness\": 0.111, \"Tempo\": 140.04, \"Duration (ms)\": 195429.0, \"Valence\": 0.471, \"Chord\": \"C#/Db\"}, {\"Index\": 106, \"Highest Charting Position\": 45, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Talking to the Moon\", \"Streams\": 6660319, \"Artist\": \"Bruno Mars\", \"Artist Followers\": 32574754.0, \"Song ID\": \"161DnLWsx1i3u1JT05lzqU\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2010-10-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 83.0, \"Danceability\": 0.523, \"Energy\": 0.606, \"Loudness\": -4.754, \"Speechiness\": 0.0301, \"Acousticness\": 0.512, \"Liveness\": 0.106, \"Tempo\": 145.837, \"Duration (ms)\": 217867.0, \"Valence\": 0.065, \"Chord\": \"C#/Db\"}, {\"Index\": 107, \"Highest Charting Position\": 3, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Roses - Imanbek Remix\", \"Streams\": 6653690, \"Artist\": \"SAINt JHN\", \"Artist Followers\": 742692.0, \"Song ID\": \"0zLCBJZSiELJf02ucPP9wb\", \"Genre\": \"['melodic rap', 'pop rap', 'rap', 'slap house', 'trap']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.769, \"Energy\": 0.719, \"Loudness\": -5.472, \"Speechiness\": 0.0474, \"Acousticness\": 0.0143, \"Liveness\": 0.359, \"Tempo\": 121.955, \"Duration (ms)\": 176867.0, \"Valence\": 0.863, \"Chord\": \"G#/Ab\"}, {\"Index\": 108, \"Highest Charting Position\": 59, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Sal y Perrea\", \"Streams\": 6635076, \"Artist\": \"Sech\", \"Artist Followers\": 8758283.0, \"Song ID\": \"5u7twkeask1VIyDeNTElSU\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-04-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 86.0, \"Danceability\": 0.786, \"Energy\": 0.899, \"Loudness\": -0.515, \"Speechiness\": 0.127, \"Acousticness\": 0.192, \"Liveness\": 0.299, \"Tempo\": 90.025, \"Duration (ms)\": 216510.0, \"Valence\": 0.813, \"Chord\": \"A#/Bb\"}, {\"Index\": 109, \"Highest Charting Position\": 109, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Fulanito\", \"Streams\": 6614072, \"Artist\": \"Becky G, El Alfa\", \"Artist Followers\": 10356559.0, \"Song ID\": \"59L8x0xy8njj75vzVCPMqg\", \"Genre\": \"['dance pop', 'latin', 'latin pop', 'latin viral pop', 'pop', 'rap latina', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 86.0, \"Danceability\": 0.93, \"Energy\": 0.837, \"Loudness\": -4.632, \"Speechiness\": 0.187, \"Acousticness\": 0.256, \"Liveness\": 0.239, \"Tempo\": 111.898, \"Duration (ms)\": 158532.0, \"Valence\": 0.821, \"Chord\": \"G\"}, {\"Index\": 110, \"Highest Charting Position\": 110, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Par\\u00eds\", \"Streams\": 6584896, \"Artist\": \"Ingratax\", \"Artist Followers\": 56699.0, \"Song ID\": \"4bF2y8rR7GUjrd5LNEvej3\", \"Genre\": \"[]\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 86.0, \"Danceability\": 0.57, \"Energy\": 0.455, \"Loudness\": -5.748, \"Speechiness\": 0.0996, \"Acousticness\": 0.441, \"Liveness\": 0.0654, \"Tempo\": 167.933, \"Duration (ms)\": 151429.0, \"Valence\": 0.399, \"Chord\": \"C#/Db\"}, {\"Index\": 111, \"Highest Charting Position\": 46, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"lovely (with Khalid)\", \"Streams\": 6569547, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47014200.0, \"Song ID\": \"0u2P5u6lvoDfwTYjAADbn4\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2018-04-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.351, \"Energy\": 0.296, \"Loudness\": -10.109, \"Speechiness\": 0.0333, \"Acousticness\": 0.934, \"Liveness\": 0.095, \"Tempo\": 115.284, \"Duration (ms)\": 200186.0, \"Valence\": 0.12, \"Chord\": \"E\"}, {\"Index\": 112, \"Highest Charting Position\": 24, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Sunflower - Spider-Man: Into the Spider-Verse\", \"Streams\": 6546948, \"Artist\": \"Post Malone, Swae Lee\", \"Artist Followers\": 1250353.0, \"Song ID\": \"3KkXRkHbMCARz0aVfEt68P\", \"Genre\": \"[]\", \"Release Date\": \"2018-12-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.76, \"Energy\": 0.479, \"Loudness\": -5.574, \"Speechiness\": 0.0466, \"Acousticness\": 0.556, \"Liveness\": 0.0703, \"Tempo\": 89.911, \"Duration (ms)\": 158040.0, \"Valence\": 0.913, \"Chord\": \"D\"}, {\"Index\": 113, \"Highest Charting Position\": 113, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"double take\", \"Streams\": 6539852, \"Artist\": \"dhruv\", \"Artist Followers\": 73211.0, \"Song ID\": \"2CVChktEKBsM6v4IfdFU5k\", \"Genre\": \"['chill r&b', 'nyc pop']\", \"Release Date\": \"2019-05-24\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 86.0, \"Danceability\": 0.663, \"Energy\": 0.434, \"Loudness\": -11.177, \"Speechiness\": 0.0648, \"Acousticness\": 0.828, \"Liveness\": 0.249, \"Tempo\": 109.075, \"Duration (ms)\": 171743.0, \"Valence\": 0.225, \"Chord\": \"G#/Ab\"}, {\"Index\": 114, \"Highest Charting Position\": 9, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Streets\", \"Streams\": 6502302, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"60ynsPSSKe6O3sfwRnIBRf\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 86.0, \"Danceability\": 0.749, \"Energy\": 0.463, \"Loudness\": -8.433, \"Speechiness\": 0.0842, \"Acousticness\": 0.21, \"Liveness\": 0.338, \"Tempo\": 90.035, \"Duration (ms)\": 226987.0, \"Valence\": 0.189, \"Chord\": \"B\"}, {\"Index\": 115, \"Highest Charting Position\": 80, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"By Your Side (feat. Tom Grennan)\", \"Streams\": 6488622, \"Artist\": \"Calvin Harris\", \"Artist Followers\": 21942793.0, \"Song ID\": \"0vR2rIVORmgeKiGIgNT0fV\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'house', 'pop', 'progressive house', 'uk dance']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 85.0, \"Danceability\": 0.733, \"Energy\": 0.96, \"Loudness\": -3.597, \"Speechiness\": 0.0295, \"Acousticness\": 0.0514, \"Liveness\": 0.287, \"Tempo\": 124.01, \"Duration (ms)\": 189672.0, \"Valence\": 0.811, \"Chord\": \"G\"}, {\"Index\": 116, \"Highest Charting Position\": 116, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"MORENA\", \"Streams\": 6469500, \"Artist\": \"Luan Santana\", \"Artist Followers\": 5420471.0, \"Song ID\": \"4PQdrXMDHDPl1RczrrlADd\", \"Genre\": \"['sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2021-06-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 85.0, \"Danceability\": 0.526, \"Energy\": 0.731, \"Loudness\": -4.662, \"Speechiness\": 0.0887, \"Acousticness\": 0.18, \"Liveness\": 0.0891, \"Tempo\": 86.959, \"Duration (ms)\": 193221.0, \"Valence\": 0.476, \"Chord\": \"B\"}, {\"Index\": 117, \"Highest Charting Position\": 80, \"Number of Times Charted\": 80, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Shape of You\", \"Streams\": 6452492, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83293380.0, \"Song ID\": \"7qiZfU4dY1lWllzX7mPBI3\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2017-03-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.825, \"Energy\": 0.652, \"Loudness\": -3.183, \"Speechiness\": 0.0802, \"Acousticness\": 0.581, \"Liveness\": 0.0931, \"Tempo\": 95.977, \"Duration (ms)\": 233713.0, \"Valence\": 0.931, \"Chord\": \"C#/Db\"}, {\"Index\": 118, \"Highest Charting Position\": 9, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Se\\u00f1orita\", \"Streams\": 6317487, \"Artist\": \"Shawn Mendes, Camila Cabello\", \"Artist Followers\": 33879560.0, \"Song ID\": \"0TK2YIli7K1leLovkQiNik\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.759, \"Energy\": 0.54, \"Loudness\": -6.039, \"Speechiness\": 0.0287, \"Acousticness\": 0.037, \"Liveness\": 0.0945, \"Tempo\": 116.947, \"Duration (ms)\": 190960.0, \"Valence\": 0.75, \"Chord\": \"A\"}, {\"Index\": 119, \"Highest Charting Position\": 5, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Hold On\", \"Streams\": 6300416, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 1250353.0, \"Song ID\": \"49xx65gvlD7xXjDTavFqaJ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 0.0, \"Danceability\": 0.658, \"Energy\": 0.634, \"Loudness\": -5.797, \"Speechiness\": 0.0413, \"Acousticness\": 0.0106, \"Liveness\": 0.132, \"Tempo\": 139.98, \"Duration (ms)\": 170813.0, \"Valence\": 0.29, \"Chord\": \"C#/Db\"}, {\"Index\": 120, \"Highest Charting Position\": 99, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Perfect\", \"Streams\": 6278765, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83293380.0, \"Song ID\": \"0tgVpDi06FyKpA1z0VMD4v\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2017-03-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.599, \"Energy\": 0.448, \"Loudness\": -6.312, \"Speechiness\": 0.0232, \"Acousticness\": 0.163, \"Liveness\": 0.106, \"Tempo\": 95.05, \"Duration (ms)\": 263400.0, \"Valence\": 0.168, \"Chord\": \"G#/Ab\"}, {\"Index\": 121, \"Highest Charting Position\": 80, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"2:50 Remix\", \"Streams\": 6244011, \"Artist\": \"MYA, TINI, Duki\", \"Artist Followers\": 282045.0, \"Song ID\": \"74znaWw1hmQBusGPSOuTFy\", \"Genre\": \"['latin pop']\", \"Release Date\": \"2021-06-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 85.0, \"Danceability\": 0.818, \"Energy\": 0.812, \"Loudness\": -4.425, \"Speechiness\": 0.0475, \"Acousticness\": 0.112, \"Liveness\": 0.234, \"Tempo\": 139.966, \"Duration (ms)\": 231708.0, \"Valence\": 0.844, \"Chord\": \"A\"}, {\"Index\": 122, \"Highest Charting Position\": 2, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"LA NOCHE DE ANOCHE\", \"Streams\": 6242863, \"Artist\": \"Bad Bunny, ROSAL\\u00cdA\", \"Artist Followers\": 36142273.0, \"Song ID\": \"2XIc1pqjXV3Cr2BQUGNBck\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 86.0, \"Danceability\": 0.856, \"Energy\": 0.618, \"Loudness\": -4.892, \"Speechiness\": 0.286, \"Acousticness\": 0.0303, \"Liveness\": 0.0866, \"Tempo\": 81.993, \"Duration (ms)\": 203201.0, \"Valence\": 0.391, \"Chord\": \"G\"}, {\"Index\": 123, \"Highest Charting Position\": 1, \"Number of Times Charted\": 67, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"ROCKSTAR (feat. Roddy Ricch)\", \"Streams\": 6180056, \"Artist\": \"DaBaby\", \"Artist Followers\": 7593046.0, \"Song ID\": \"7ytR5pFWmSjzHJIeQkgog4\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 86.0, \"Danceability\": 0.746, \"Energy\": 0.69, \"Loudness\": -7.956, \"Speechiness\": 0.164, \"Acousticness\": 0.247, \"Liveness\": 0.101, \"Tempo\": 89.977, \"Duration (ms)\": 181733.0, \"Valence\": 0.497, \"Chord\": \"B\"}, {\"Index\": 124, \"Highest Charting Position\": 12, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Heather\", \"Streams\": 6164795, \"Artist\": \"Conan Gray\", \"Artist Followers\": 3794081.0, \"Song ID\": \"4xqrdfXkTW4T0RauPLv3WA\", \"Genre\": \"['alt z', 'bedroom pop', 'electropop', 'indie pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 86.0, \"Danceability\": 0.357, \"Energy\": 0.425, \"Loudness\": -7.301, \"Speechiness\": 0.0333, \"Acousticness\": 0.584, \"Liveness\": 0.322, \"Tempo\": 102.078, \"Duration (ms)\": 198040.0, \"Valence\": 0.27, \"Chord\": \"F\"}, {\"Index\": 125, \"Highest Charting Position\": 13, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"you broke me first\", \"Streams\": 6152121, \"Artist\": \"Tate McRae\", \"Artist Followers\": 1647262.0, \"Song ID\": \"45bE4HXI0AwGZXfZtMp8JR\", \"Genre\": \"['alt z', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 86.0, \"Danceability\": 0.667, \"Energy\": 0.373, \"Loudness\": -9.389, \"Speechiness\": 0.05, \"Acousticness\": 0.785, \"Liveness\": 0.0906, \"Tempo\": 124.148, \"Duration (ms)\": 169266.0, \"Valence\": 0.0823, \"Chord\": \"E\"}, {\"Index\": 126, \"Highest Charting Position\": 126, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"The Nights\", \"Streams\": 6136340, \"Artist\": \"Avicii\", \"Artist Followers\": 20270895.0, \"Song ID\": \"0ct6r3EGTcMLPtrXHDvVjc\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance']\", \"Release Date\": \"2014-01-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 85.0, \"Danceability\": 0.527, \"Energy\": 0.835, \"Loudness\": -5.298, \"Speechiness\": 0.0433, \"Acousticness\": 0.0166, \"Liveness\": 0.249, \"Tempo\": 125.983, \"Duration (ms)\": 176658.0, \"Valence\": 0.654, \"Chord\": \"F#/Gb\"}, {\"Index\": 127, \"Highest Charting Position\": 122, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Riptide\", \"Streams\": 6089242, \"Artist\": \"Vance Joy\", \"Artist Followers\": 2421254.0, \"Song ID\": \"3JvrhDOgAt6p7K8mDyZwRd\", \"Genre\": \"['folk-pop', 'modern rock', 'pop', 'pop rock']\", \"Release Date\": \"2014-09-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 78.0, \"Danceability\": 0.484, \"Energy\": 0.731, \"Loudness\": -6.694, \"Speechiness\": 0.0379, \"Acousticness\": 0.431, \"Liveness\": 0.151, \"Tempo\": 101.654, \"Duration (ms)\": 204280.0, \"Valence\": 0.51, \"Chord\": \"C#/Db\"}, {\"Index\": 128, \"Highest Charting Position\": 128, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Smells Like Teen Spirit\", \"Streams\": 6065267, \"Artist\": \"Nirvana\", \"Artist Followers\": 13261089.0, \"Song ID\": \"5ghIJDpPoe3CfHMGu71E6T\", \"Genre\": \"['grunge', 'permanent wave', 'rock']\", \"Release Date\": \"1991-09-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\", \"Popularity\": 77.0, \"Danceability\": 0.502, \"Energy\": 0.912, \"Loudness\": -4.556, \"Speechiness\": 0.0564, \"Acousticness\": 2.55e-05, \"Liveness\": 0.106, \"Tempo\": 116.761, \"Duration (ms)\": 301920.0, \"Valence\": 0.72, \"Chord\": \"C#/Db\"}, {\"Index\": 129, \"Highest Charting Position\": 11, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"enough for you\", \"Streams\": 6040918, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"2TOzTqQXNmR2zDJXihjZ2e\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 86.0, \"Danceability\": 0.638, \"Energy\": 0.259, \"Loudness\": -10.706, \"Speechiness\": 0.0898, \"Acousticness\": 0.753, \"Liveness\": 0.219, \"Tempo\": 88.485, \"Duration (ms)\": 202827.0, \"Valence\": 0.269, \"Chord\": \"G\"}, {\"Index\": 130, \"Highest Charting Position\": 99, \"Number of Times Charted\": 42, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Daddy Issues\", \"Streams\": 6014443, \"Artist\": \"The Neighbourhood\", \"Artist Followers\": 6662605.0, \"Song ID\": \"5E30LdtzQTGqRvNd7l6kG5\", \"Genre\": \"['modern alternative rock', 'modern rock', 'pop']\", \"Release Date\": \"2015-10-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 85.0, \"Danceability\": 0.588, \"Energy\": 0.521, \"Loudness\": -9.461, \"Speechiness\": 0.0329, \"Acousticness\": 0.0678, \"Liveness\": 0.123, \"Tempo\": 85.012, \"Duration (ms)\": 260173.0, \"Valence\": 0.337, \"Chord\": \"A#/Bb\"}, {\"Index\": 131, \"Highest Charting Position\": 131, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Aquelas Coisas\", \"Streams\": 6012839, \"Artist\": \"Jo\\u00e3o Gomes\", \"Artist Followers\": 409173.0, \"Song ID\": \"0FqVtQxRD3HsPltldG5v5M\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 84.0, \"Danceability\": 0.682, \"Energy\": 0.873, \"Loudness\": -4.163, \"Speechiness\": 0.0449, \"Acousticness\": 0.402, \"Liveness\": 0.0946, \"Tempo\": 150.006, \"Duration (ms)\": 147072.0, \"Valence\": 0.964, \"Chord\": \"F#/Gb\"}, {\"Index\": 132, \"Highest Charting Position\": 19, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Miss The Rage (feat. Playboi Carti)\", \"Streams\": 5952490, \"Artist\": \"Trippie Redd\", \"Artist Followers\": 6430522.0, \"Song ID\": \"2BITQ360Knh6qNAOqR7Dyq\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2021-05-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 85.0, \"Danceability\": 0.584, \"Energy\": 0.859, \"Loudness\": -5.616, \"Speechiness\": 0.121, \"Acousticness\": 0.0144, \"Liveness\": 0.847, \"Tempo\": 77.005, \"Duration (ms)\": 236883.0, \"Valence\": 0.369, \"Chord\": \"G#/Ab\"}, {\"Index\": 133, \"Highest Charting Position\": 4, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Memories\", \"Streams\": 5928329, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32262679.0, \"Song ID\": \"4cktbXiXOapiLBMprHFErI\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.775, \"Energy\": 0.327, \"Loudness\": -7.241, \"Speechiness\": 0.0557, \"Acousticness\": 0.841, \"Liveness\": 0.0821, \"Tempo\": 91.05, \"Duration (ms)\": 189486.0, \"Valence\": 0.595, \"Chord\": \"B\"}, {\"Index\": 134, \"Highest Charting Position\": 76, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Another Love\", \"Streams\": 5914661, \"Artist\": \"Tom Odell\", \"Artist Followers\": 1838616.0, \"Song ID\": \"7otCGmgp9h4CsR2LhwB6gt\", \"Genre\": \"['pop']\", \"Release Date\": \"2013-09-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 67.0, \"Danceability\": 0.445, \"Energy\": 0.537, \"Loudness\": -8.532, \"Speechiness\": 0.04, \"Acousticness\": 0.695, \"Liveness\": 0.0941, \"Tempo\": 122.764, \"Duration (ms)\": 244360.0, \"Valence\": 0.131, \"Chord\": \"E\"}, {\"Index\": 135, \"Highest Charting Position\": 135, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Here's Your Perfect\", \"Streams\": 5912784, \"Artist\": \"Jamie Miller\", \"Artist Followers\": 64288.0, \"Song ID\": \"2aTKrdenCq5qBOoJPFdn4P\", \"Genre\": \"['pop soul']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 85.0, \"Danceability\": 0.558, \"Energy\": 0.454, \"Loudness\": -5.335, \"Speechiness\": 0.0551, \"Acousticness\": 0.499, \"Liveness\": 0.146, \"Tempo\": 113.12, \"Duration (ms)\": 158594.0, \"Valence\": 0.424, \"Chord\": \"F#/Gb\"}, {\"Index\": 136, \"Highest Charting Position\": 108, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Take Me To Church\", \"Streams\": 5907750, \"Artist\": \"Hozier\", \"Artist Followers\": 4781906.0, \"Song ID\": \"1CS7Sd1u5tWkstBhpssyjP\", \"Genre\": \"['irish singer-songwriter', 'modern rock', 'pop']\", \"Release Date\": \"2014-09-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 74.0, \"Danceability\": 0.566, \"Energy\": 0.664, \"Loudness\": -5.303, \"Speechiness\": 0.0464, \"Acousticness\": 0.634, \"Liveness\": 0.116, \"Tempo\": 128.945, \"Duration (ms)\": 241693.0, \"Valence\": 0.437, \"Chord\": \"E\"}, {\"Index\": 137, \"Highest Charting Position\": 110, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Little Bit of Love\", \"Streams\": 5848466, \"Artist\": \"Tom Grennan\", \"Artist Followers\": 261225.0, \"Song ID\": \"2sX7lJXsOYGP1Us6CqM9t1\", \"Genre\": \"['modern rock', 'uk pop']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 80.0, \"Danceability\": 0.689, \"Energy\": 0.706, \"Loudness\": -4.48, \"Speechiness\": 0.0312, \"Acousticness\": 0.0833, \"Liveness\": 0.105, \"Tempo\": 106.52, \"Duration (ms)\": 226268.0, \"Valence\": 0.623, \"Chord\": \"C#/Db\"}, {\"Index\": 138, \"Highest Charting Position\": 138, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Ficha Limpa\", \"Streams\": 5847975, \"Artist\": \"Gusttavo Lima\", \"Artist Followers\": 12969190.0, \"Song ID\": \"5SwyN9hzmWjBsINlif8li8\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2021-06-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 85.0, \"Danceability\": 0.774, \"Energy\": 0.732, \"Loudness\": -4.227, \"Speechiness\": 0.0308, \"Acousticness\": 0.108, \"Liveness\": 0.243, \"Tempo\": 135.005, \"Duration (ms)\": 192725.0, \"Valence\": 0.734, \"Chord\": \"A\"}, {\"Index\": 139, \"Highest Charting Position\": 14, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Up\", \"Streams\": 5845156, \"Artist\": \"Cardi B\", \"Artist Followers\": 17353707.0, \"Song ID\": \"1XXimziG1uhM0eDNCZCrUl\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'rap']\", \"Release Date\": \"2021-02-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 83.0, \"Danceability\": 0.868, \"Energy\": 0.795, \"Loudness\": -6.044, \"Speechiness\": 0.269, \"Acousticness\": 0.0012, \"Liveness\": 0.0461, \"Tempo\": 166.0, \"Duration (ms)\": 156945.0, \"Valence\": 0.819, \"Chord\": \"B\"}, {\"Index\": 140, \"Highest Charting Position\": 2, \"Number of Times Charted\": 52, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Haw\\u00e1i\", \"Streams\": 5769714, \"Artist\": \"Maluma\", \"Artist Followers\": 26769304.0, \"Song ID\": \"0GzuHFG4Ql6DoyxFRnIk3F\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-11-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 77.0, \"Danceability\": 0.766, \"Energy\": 0.788, \"Loudness\": -3.128, \"Speechiness\": 0.312, \"Acousticness\": 0.105, \"Liveness\": 0.142, \"Tempo\": 179.984, \"Duration (ms)\": 200482.0, \"Valence\": 0.609, \"Chord\": \"F#/Gb\"}, {\"Index\": 141, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"New Normal\", \"Streams\": 5768653, \"Artist\": \"Khalid\", \"Artist Followers\": 14187747.0, \"Song ID\": \"2CIYemjFXdmCWpJnfbtrD6\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-07-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 79.0, \"Danceability\": 0.39, \"Energy\": 0.534, \"Loudness\": -9.575, \"Speechiness\": 0.0709, \"Acousticness\": 0.0807, \"Liveness\": 0.184, \"Tempo\": 92.047, \"Duration (ms)\": 198765.0, \"Valence\": 0.244, \"Chord\": \"C\"}, {\"Index\": 142, \"Highest Charting Position\": 81, \"Number of Times Charted\": 81, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Bohemian Rhapsody - Remastered 2011\", \"Streams\": 5756583, \"Artist\": \"Queen\", \"Artist Followers\": 35888760.0, \"Song ID\": \"7tFiyTwD0nx5a1eklYtX2J\", \"Genre\": \"['classic rock', 'glam rock', 'rock']\", \"Release Date\": \"1975-11-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.392, \"Energy\": 0.402, \"Loudness\": -9.961, \"Speechiness\": 0.0536, \"Acousticness\": 0.288, \"Liveness\": 0.243, \"Tempo\": 143.883, \"Duration (ms)\": 354320.0, \"Valence\": 0.228, \"Chord\": \"C\"}, {\"Index\": 143, \"Highest Charting Position\": 5, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Bandido\", \"Streams\": 5734402, \"Artist\": \"Myke Towers, Juhn\", \"Artist Followers\": 6150675.0, \"Song ID\": \"1xK1Gg9SxG8fy2Ya373oqb\", \"Genre\": \"['trap latino']\", \"Release Date\": \"2020-12-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\", \"Popularity\": 85.0, \"Danceability\": 0.713, \"Energy\": 0.617, \"Loudness\": -4.637, \"Speechiness\": 0.0887, \"Acousticness\": 0.122, \"Liveness\": 0.0962, \"Tempo\": 168.021, \"Duration (ms)\": 232853.0, \"Valence\": 0.682, \"Chord\": \"G#/Ab\"}, {\"Index\": 144, \"Highest Charting Position\": 25, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Paradise (feat. Dermot Kennedy)\", \"Streams\": 5693848, \"Artist\": \"MEDUZA\", \"Artist Followers\": 441674.0, \"Song ID\": \"6ft4hAq6yde8jPZY2i5zLr\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop house', 'tropical house']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 85.0, \"Danceability\": 0.632, \"Energy\": 0.595, \"Loudness\": -7.644, \"Speechiness\": 0.0401, \"Acousticness\": 0.0689, \"Liveness\": 0.209, \"Tempo\": 124.114, \"Duration (ms)\": 167903.0, \"Valence\": 0.435, \"Chord\": \"G#/Ab\"}, {\"Index\": 145, \"Highest Charting Position\": 13, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"goosebumps\", \"Streams\": 5691540, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17719446.0, \"Song ID\": \"5uEYRdEIh9Bo4fpjDd4Na9\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 87.0, \"Danceability\": 0.841, \"Energy\": 0.593, \"Loudness\": -7.846, \"Speechiness\": 0.0379, \"Acousticness\": 0.418, \"Liveness\": 0.124, \"Tempo\": 124.917, \"Duration (ms)\": 162803.0, \"Valence\": 0.808, \"Chord\": \"C#/Db\"}, {\"Index\": 146, \"Highest Charting Position\": 90, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Wasted Love (feat. Lagique)\", \"Streams\": 5690260, \"Artist\": \"Ofenbach\", \"Artist Followers\": 432581.0, \"Song ID\": \"2pPO9YecZimmuVQfIzfV6U\", \"Genre\": \"['edm', 'new french touch', 'pop dance', 'tropical house']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 85.0, \"Danceability\": 0.734, \"Energy\": 0.855, \"Loudness\": -4.578, \"Speechiness\": 0.135, \"Acousticness\": 0.0821, \"Liveness\": 0.0901, \"Tempo\": 121.955, \"Duration (ms)\": 139563.0, \"Valence\": 0.54, \"Chord\": \"F#/Gb\"}, {\"Index\": 147, \"Highest Charting Position\": 100, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"KESI - Remix\", \"Streams\": 5682062, \"Artist\": \"Camilo, Shawn Mendes\", \"Artist Followers\": 10561047.0, \"Song ID\": \"0IqCoZ168iRc9LqfrYgpZy\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2021-07-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 83.0, \"Danceability\": 0.871, \"Energy\": 0.815, \"Loudness\": -4.439, \"Speechiness\": 0.0477, \"Acousticness\": 0.127, \"Liveness\": 0.094, \"Tempo\": 122.959, \"Duration (ms)\": 176575.0, \"Valence\": 0.823, \"Chord\": \"E\"}, {\"Index\": 148, \"Highest Charting Position\": 59, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Shallow\", \"Streams\": 5672480, \"Artist\": \"Lady Gaga, Bradley Cooper\", \"Artist Followers\": 18572085.0, \"Song ID\": \"2VxeLyX666F8uXCJ0dZF8B\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-10-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.572, \"Energy\": 0.385, \"Loudness\": -6.362, \"Speechiness\": 0.0308, \"Acousticness\": 0.371, \"Liveness\": 0.231, \"Tempo\": 95.799, \"Duration (ms)\": 215733.0, \"Valence\": 0.323, \"Chord\": \"G\"}, {\"Index\": 149, \"Highest Charting Position\": 110, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Tell Em\", \"Streams\": 5668576, \"Artist\": \"Cochise, $NOT\", \"Artist Followers\": 159647.0, \"Song ID\": \"7nc7mlSdWYeFom84zZ8Wr8\", \"Genre\": \"['plugg', 'vapor trap', 'viral rap']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\", \"Popularity\": 85.0, \"Danceability\": 0.672, \"Energy\": 0.717, \"Loudness\": -7.476, \"Speechiness\": 0.226, \"Acousticness\": 0.103, \"Liveness\": 0.398, \"Tempo\": 157.905, \"Duration (ms)\": 180380.0, \"Valence\": 0.473, \"Chord\": \"F\"}, {\"Index\": 150, \"Highest Charting Position\": 103, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"N\\u00e3o, N\\u00e3o Vou\", \"Streams\": 5652272, \"Artist\": \"Mari Fernandez\", \"Artist Followers\": 15889.0, \"Song ID\": \"0xBQvhJAm6f7J142ympKOn\", \"Genre\": \"[]\", \"Release Date\": \"2021-04-29\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.631, \"Energy\": 0.861, \"Loudness\": -1.891, \"Speechiness\": 0.0424, \"Acousticness\": 0.427, \"Liveness\": 0.215, \"Tempo\": 149.95, \"Duration (ms)\": 173038.0, \"Valence\": 0.822, \"Chord\": \"B\"}, {\"Index\": 151, \"Highest Charting Position\": 147, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Counting Stars\", \"Streams\": 5647568, \"Artist\": \"OneRepublic\", \"Artist Followers\": 12169108.0, \"Song ID\": \"6sy3LkhNFjJWlaeSMNwQ62\", \"Genre\": \"['dance pop', 'piano rock', 'pop', 'pop rock']\", \"Release Date\": \"2014-01-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 74.0, \"Danceability\": 0.664, \"Energy\": 0.705, \"Loudness\": -4.972, \"Speechiness\": 0.0382, \"Acousticness\": 0.0654, \"Liveness\": 0.115, \"Tempo\": 122.017, \"Duration (ms)\": 257840.0, \"Valence\": 0.477, \"Chord\": \"C#/Db\"}, {\"Index\": 152, \"Highest Charting Position\": 121, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Yellow\", \"Streams\": 5628703, \"Artist\": \"Coldplay\", \"Artist Followers\": 31151294.0, \"Song ID\": \"3AJwUDP919kvQ9QcozQPxg\", \"Genre\": \"['permanent wave', 'pop']\", \"Release Date\": \"2000-07-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 85.0, \"Danceability\": 0.429, \"Energy\": 0.661, \"Loudness\": -7.227, \"Speechiness\": 0.0281, \"Acousticness\": 0.00239, \"Liveness\": 0.234, \"Tempo\": 173.372, \"Duration (ms)\": 266773.0, \"Valence\": 0.285, \"Chord\": \"B\"}, {\"Index\": 153, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Como Si No Importara\", \"Streams\": 5627257, \"Artist\": \"Emilia, Duki\", \"Artist Followers\": 205590.0, \"Song ID\": \"1GYJpuLq41vEVKXiHGEY9j\", \"Genre\": \"[]\", \"Release Date\": \"2021-07-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 83.0, \"Danceability\": 0.843, \"Energy\": 0.534, \"Loudness\": -6.658, \"Speechiness\": 0.142, \"Acousticness\": 0.467, \"Liveness\": 0.0984, \"Tempo\": 94.984, \"Duration (ms)\": 173053.0, \"Valence\": 0.528, \"Chord\": \"C#/Db\"}, {\"Index\": 154, \"Highest Charting Position\": 154, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Se For Amor\", \"Streams\": 5618268, \"Artist\": \"Jo\\u00e3o Gomes, Vitor Fernandes\", \"Artist Followers\": 409173.0, \"Song ID\": \"5F2xRvRFkxDvqdFtUNAEyw\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 81.0, \"Danceability\": 0.667, \"Energy\": 0.899, \"Loudness\": -4.402, \"Speechiness\": 0.0322, \"Acousticness\": 0.423, \"Liveness\": 0.332, \"Tempo\": 147.962, \"Duration (ms)\": 239928.0, \"Valence\": 0.835, \"Chord\": \"B\"}, {\"Index\": 155, \"Highest Charting Position\": 142, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Wake Me Up\", \"Streams\": 5607285, \"Artist\": \"Avicii\", \"Artist Followers\": 20270895.0, \"Song ID\": \"0nrRP2bk19rLc0orkWPQk2\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance']\", \"Release Date\": \"2013-01-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-01--2021-01-08\\n2020-08-07--2020-08-14\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.532, \"Energy\": 0.783, \"Loudness\": -5.697, \"Speechiness\": 0.0523, \"Acousticness\": 0.0038, \"Liveness\": 0.161, \"Tempo\": 124.08, \"Duration (ms)\": 247427.0, \"Valence\": 0.643, \"Chord\": \"D\"}, {\"Index\": 156, \"Highest Charting Position\": 128, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Baby Me Atende\", \"Streams\": 5594505, \"Artist\": \"Matheus Fernandes, Dilsinho\", \"Artist Followers\": 77034.0, \"Song ID\": \"5R9KPXQVeyqsHZoPLMgfNy\", \"Genre\": \"['forro', 'sertanejo pop']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 83.0, \"Danceability\": 0.65, \"Energy\": 0.792, \"Loudness\": -3.825, \"Speechiness\": 0.0393, \"Acousticness\": 0.607, \"Liveness\": 0.92, \"Tempo\": 154.027, \"Duration (ms)\": 225672.0, \"Valence\": 0.872, \"Chord\": \"F#/Gb\"}, {\"Index\": 157, \"Highest Charting Position\": 68, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Ramenez la coupe \\u00e0 la maison\", \"Streams\": 5576844, \"Artist\": \"Vegedream\", \"Artist Followers\": 1250353.0, \"Song ID\": \"0dqVP9CnGjaYNjya3gYbYy\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 0.0, \"Danceability\": 0.808, \"Energy\": 0.66, \"Loudness\": -6.237, \"Speechiness\": 0.0395, \"Acousticness\": 0.0358, \"Liveness\": 0.138, \"Tempo\": 107.994, \"Duration (ms)\": 235556.0, \"Valence\": 0.804, \"Chord\": \"C\"}, {\"Index\": 158, \"Highest Charting Position\": 6, \"Number of Times Charted\": 47, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"What You Know Bout Love\", \"Streams\": 5570735, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"1tkg4EHVoqnhR6iFEXb60y\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-07-03--2020-07-10\", \"Popularity\": 85.0, \"Danceability\": 0.709, \"Energy\": 0.548, \"Loudness\": -8.493, \"Speechiness\": 0.353, \"Acousticness\": 0.65, \"Liveness\": 0.133, \"Tempo\": 83.995, \"Duration (ms)\": 160000.0, \"Valence\": 0.543, \"Chord\": \"A#/Bb\"}, {\"Index\": 159, \"Highest Charting Position\": 19, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Runaway\", \"Streams\": 5566150, \"Artist\": \"AURORA\", \"Artist Followers\": 1687399.0, \"Song ID\": \"0TCmhnbMpw5zwPsTvlXTJi\", \"Genre\": \"['art pop', 'norwegian pop']\", \"Release Date\": \"2014\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 77.0, \"Danceability\": 0.521, \"Energy\": 0.277, \"Loudness\": -10.34, \"Speechiness\": 0.0356, \"Acousticness\": 0.634, \"Liveness\": 0.103, \"Tempo\": 115.01, \"Duration (ms)\": 248827.0, \"Valence\": 0.13, \"Chord\": \"B\"}, {\"Index\": 160, \"Highest Charting Position\": 121, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Red Light Green Light\", \"Streams\": 5493760, \"Artist\": \"DaBaby\", \"Artist Followers\": 7593046.0, \"Song ID\": \"1YDebgap5OFwXEBG18NJvy\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.933, \"Energy\": 0.656, \"Loudness\": -5.85, \"Speechiness\": 0.322, \"Acousticness\": 0.129, \"Liveness\": 0.161, \"Tempo\": 119.987, \"Duration (ms)\": 159083.0, \"Valence\": 0.934, \"Chord\": \"D\"}, {\"Index\": 161, \"Highest Charting Position\": 120, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Ball If I Want To\", \"Streams\": 5478055, \"Artist\": \"DaBaby\", \"Artist Followers\": 7593046.0, \"Song ID\": \"0cu0rhnlCnJ7JIeHRiLpj3\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\", \"Popularity\": 84.0, \"Danceability\": 0.902, \"Energy\": 0.669, \"Loudness\": -5.049, \"Speechiness\": 0.457, \"Acousticness\": 0.161, \"Liveness\": 0.0728, \"Tempo\": 139.949, \"Duration (ms)\": 112547.0, \"Valence\": 0.628, \"Chord\": \"C#/Db\"}, {\"Index\": 162, \"Highest Charting Position\": 31, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lucid Dreams\", \"Streams\": 5477563, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"285pBltuF7vW8TeWk8hdRR\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2018-12-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.511, \"Energy\": 0.566, \"Loudness\": -7.23, \"Speechiness\": 0.2, \"Acousticness\": 0.349, \"Liveness\": 0.34, \"Tempo\": 83.903, \"Duration (ms)\": 239836.0, \"Valence\": 0.218, \"Chord\": \"F#/Gb\"}, {\"Index\": 163, \"Highest Charting Position\": 4, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Calling My Phone\", \"Streams\": 5467753, \"Artist\": \"Lil Tjay, 6LACK\", \"Artist Followers\": 3553442.0, \"Song ID\": \"3J8EOeKLTLXORtWPpOU5bE\", \"Genre\": \"['brooklyn drill', 'melodic rap', 'nyc rap']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 85.0, \"Danceability\": 0.907, \"Energy\": 0.393, \"Loudness\": -7.636, \"Speechiness\": 0.0539, \"Acousticness\": 0.451, \"Liveness\": 0.135, \"Tempo\": 104.949, \"Duration (ms)\": 205458.0, \"Valence\": 0.202, \"Chord\": \"E\"}, {\"Index\": 164, \"Highest Charting Position\": 5, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"34+35\", \"Streams\": 5453159, \"Artist\": \"Ariana Grande\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 165, \"Highest Charting Position\": 13, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"bad guy\", \"Streams\": 5436286, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"1hewNsVmijBqjKvFRQfk4m\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.701, \"Energy\": 0.425, \"Loudness\": -10.965, \"Speechiness\": 0.375, \"Acousticness\": 0.328, \"Liveness\": 0.1, \"Tempo\": 135.128, \"Duration (ms)\": 194088.0, \"Valence\": 0.562, \"Chord\": \"G\"}, {\"Index\": 166, \"Highest Charting Position\": 59, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Cover Me In Sunshine\", \"Streams\": 5434073, \"Artist\": \"P!nk, Willow Sage Hart\", \"Artist Followers\": 11477164.0, \"Song ID\": \"6Tio0ZoDeSQnI7EBAqWer2\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-02-12\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 83.0, \"Danceability\": 0.476, \"Energy\": 0.594, \"Loudness\": -6.879, \"Speechiness\": 0.135, \"Acousticness\": 0.0599, \"Liveness\": 0.0785, \"Tempo\": 159.702, \"Duration (ms)\": 141050.0, \"Valence\": 0.314, \"Chord\": \"F\"}, {\"Index\": 167, \"Highest Charting Position\": 7, \"Number of Times Charted\": 56, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"For The Night (feat. Lil Baby & DaBaby)\", \"Streams\": 5431375, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"0PvFJmanyNQMseIFrU708S\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 84.0, \"Danceability\": 0.823, \"Energy\": 0.586, \"Loudness\": -6.606, \"Speechiness\": 0.2, \"Acousticness\": 0.114, \"Liveness\": 0.193, \"Tempo\": 125.971, \"Duration (ms)\": 190476.0, \"Valence\": 0.347, \"Chord\": \"F#/Gb\"}, {\"Index\": 168, \"Highest Charting Position\": 13, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"1 step forward, 3 steps back\", \"Streams\": 5420003, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"4wcBRRpIfesgcyUtis7PEg\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 85.0, \"Danceability\": 0.473, \"Energy\": 0.203, \"Loudness\": -12.627, \"Speechiness\": 0.102, \"Acousticness\": 0.941, \"Liveness\": 0.126, \"Tempo\": 168.884, \"Duration (ms)\": 163587.0, \"Valence\": 0.419, \"Chord\": \"D\"}, {\"Index\": 169, \"Highest Charting Position\": 1, \"Number of Times Charted\": 51, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"WAP (feat. Megan Thee Stallion)\", \"Streams\": 5386268, \"Artist\": \"Cardi B\", \"Artist Followers\": 17353707.0, \"Song ID\": \"4Oun2ylbjFKMPTiaSbbCih\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'rap']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 84.0, \"Danceability\": 0.935, \"Energy\": 0.454, \"Loudness\": -7.509, \"Speechiness\": 0.375, \"Acousticness\": 0.0194, \"Liveness\": 0.0824, \"Tempo\": 133.073, \"Duration (ms)\": 187541.0, \"Valence\": 0.357, \"Chord\": \"C#/Db\"}, {\"Index\": 170, \"Highest Charting Position\": 155, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Mr. Brightside\", \"Streams\": 5382191, \"Artist\": \"The Killers\", \"Artist Followers\": 6118063.0, \"Song ID\": \"7oK9VyNzrYvRFo7nQEYkWN\", \"Genre\": \"['dance rock', 'modern rock', 'permanent wave', 'rock']\", \"Release Date\": \"2004-06-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-12--2021-03-19\\n2021-02-26--2021-03-05\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 75.0, \"Danceability\": 0.356, \"Energy\": 0.924, \"Loudness\": -3.74, \"Speechiness\": 0.0808, \"Acousticness\": 0.00101, \"Liveness\": 0.0953, \"Tempo\": 148.017, \"Duration (ms)\": 222587.0, \"Valence\": 0.232, \"Chord\": \"C#/Db\"}, {\"Index\": 171, \"Highest Charting Position\": 144, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Every Breath You Take\", \"Streams\": 5379704, \"Artist\": \"The Police\", \"Artist Followers\": 4339245.0, \"Song ID\": \"1JSTJqkT5qHq8MDJnJbRE1\", \"Genre\": \"['album rock', 'art rock', 'classic rock', 'mellow gold', 'new wave', 'permanent wave', 'rock', 'soft rock']\", \"Release Date\": \"1983-06-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-01-01--2021-01-08\\n2020-06-19--2020-06-26\\n2020-06-05--2020-06-12\", \"Popularity\": 83.0, \"Danceability\": 0.82, \"Energy\": 0.452, \"Loudness\": -9.796, \"Speechiness\": 0.0348, \"Acousticness\": 0.543, \"Liveness\": 0.0714, \"Tempo\": 117.401, \"Duration (ms)\": 253920.0, \"Valence\": 0.74, \"Chord\": \"C#/Db\"}, {\"Index\": 172, \"Highest Charting Position\": 20, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Dreams - 2004 Remaster\", \"Streams\": 5378971, \"Artist\": \"Fleetwood Mac\", \"Artist Followers\": 6930669.0, \"Song ID\": \"0ofHAoxe9vBkTCp2UQIavz\", \"Genre\": \"['album rock', 'classic rock', 'mellow gold', 'rock', 'soft rock', 'yacht rock']\", \"Release Date\": \"1977-02-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 84.0, \"Danceability\": 0.828, \"Energy\": 0.492, \"Loudness\": -9.744, \"Speechiness\": 0.0276, \"Acousticness\": 0.0644, \"Liveness\": 0.128, \"Tempo\": 120.151, \"Duration (ms)\": 257800.0, \"Valence\": 0.789, \"Chord\": \"C\"}, {\"Index\": 173, \"Highest Charting Position\": 94, \"Number of Times Charted\": 82, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Say You Won't Let Go\", \"Streams\": 5375426, \"Artist\": \"James Arthur\", \"Artist Followers\": 8441598.0, \"Song ID\": \"5uCax9HTNlzGybIStD3vDh\", \"Genre\": \"['pop', 'post-teen pop', 'talent show', 'uk pop']\", \"Release Date\": \"2016-10-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.358, \"Energy\": 0.557, \"Loudness\": -7.398, \"Speechiness\": 0.059, \"Acousticness\": 0.695, \"Liveness\": 0.0902, \"Tempo\": 85.043, \"Duration (ms)\": 211467.0, \"Valence\": 0.494, \"Chord\": \"A#/Bb\"}, {\"Index\": 174, \"Highest Charting Position\": 110, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Wild Side (feat. Cardi B)\", \"Streams\": 5366242, \"Artist\": \"Normani\", \"Artist Followers\": 1304510.0, \"Song ID\": \"2vXgyN14LX2zl7JEASw242\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop', 'r&b', 'urban contemporary']\", \"Release Date\": \"2021-07-22\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 75.0, \"Danceability\": 0.74, \"Energy\": 0.576, \"Loudness\": -6.744, \"Speechiness\": 0.146, \"Acousticness\": 0.0249, \"Liveness\": 0.104, \"Tempo\": 110.095, \"Duration (ms)\": 209476.0, \"Valence\": 0.315, \"Chord\": \"F#/Gb\"}, {\"Index\": 175, \"Highest Charting Position\": 65, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Bout A Million (feat. 42 Dugg & 21 Savage)\", \"Streams\": 5315734, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"4LaGu95Ui2s4vprSQYWUAZ\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 81.0, \"Danceability\": 0.716, \"Energy\": 0.67, \"Loudness\": -6.995, \"Speechiness\": 0.101, \"Acousticness\": 0.526, \"Liveness\": 0.13, \"Tempo\": 145.043, \"Duration (ms)\": 203586.0, \"Valence\": 0.411, \"Chord\": \"C\"}, {\"Index\": 176, \"Highest Charting Position\": 72, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Demeanor (feat. Dua Lipa)\", \"Streams\": 5245618, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"3DMs7bahbQTnoxCjgP7qoK\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 81.0, \"Danceability\": 0.675, \"Energy\": 0.608, \"Loudness\": -6.934, \"Speechiness\": 0.103, \"Acousticness\": 0.336, \"Liveness\": 0.11, \"Tempo\": 99.865, \"Duration (ms)\": 184800.0, \"Valence\": 0.728, \"Chord\": \"D#/Eb\"}, {\"Index\": 177, \"Highest Charting Position\": 4, \"Number of Times Charted\": 76, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"death bed (coffee for your head)\", \"Streams\": 5238547, \"Artist\": \"Powfu, beabadoobee\", \"Artist Followers\": 924083.0, \"Song ID\": \"7eJMfftS33KTjuF7lTsMCx\", \"Genre\": \"['sad rap']\", \"Release Date\": \"2020-02-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 85.0, \"Danceability\": 0.726, \"Energy\": 0.431, \"Loudness\": -8.765, \"Speechiness\": 0.135, \"Acousticness\": 0.731, \"Liveness\": 0.696, \"Tempo\": 144.026, \"Duration (ms)\": 173333.0, \"Valence\": 0.348, \"Chord\": \"G#/Ab\"}, {\"Index\": 178, \"Highest Charting Position\": 100, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Our Song\", \"Streams\": 5235335, \"Artist\": \"Anne-Marie, Niall Horan\", \"Artist Followers\": 8148393.0, \"Song ID\": \"5zqObw7wjBgL9TDiAymxPn\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 83.0, \"Danceability\": 0.595, \"Energy\": 0.759, \"Loudness\": -4.245, \"Speechiness\": 0.0423, \"Acousticness\": 0.141, \"Liveness\": 0.172, \"Tempo\": 80.953, \"Duration (ms)\": 163733.0, \"Valence\": 0.515, \"Chord\": \"B\"}, {\"Index\": 179, \"Highest Charting Position\": 138, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Another One Bites The Dust - Remastered 2011\", \"Streams\": 5204983, \"Artist\": \"Queen\", \"Artist Followers\": 35888760.0, \"Song ID\": \"57JVGBtBLCfHw2muk5416J\", \"Genre\": \"['classic rock', 'glam rock', 'rock']\", \"Release Date\": \"1980-06-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.933, \"Energy\": 0.528, \"Loudness\": -6.472, \"Speechiness\": 0.162, \"Acousticness\": 0.112, \"Liveness\": 0.163, \"Tempo\": 109.975, \"Duration (ms)\": 214653.0, \"Valence\": 0.756, \"Chord\": \"F\"}, {\"Index\": 180, \"Highest Charting Position\": 149, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"One Dance\", \"Streams\": 5178490, \"Artist\": \"Drake, WizKid, Kyla\", \"Artist Followers\": 56308172.0, \"Song ID\": \"1zi7xx7UVEFkmKfv06H8x0\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2016-05-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 84.0, \"Danceability\": 0.792, \"Energy\": 0.625, \"Loudness\": -5.609, \"Speechiness\": 0.0536, \"Acousticness\": 0.00776, \"Liveness\": 0.329, \"Tempo\": 103.967, \"Duration (ms)\": 173987.0, \"Valence\": 0.37, \"Chord\": \"C#/Db\"}, {\"Index\": 181, \"Highest Charting Position\": 15, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Adore You\", \"Streams\": 5166847, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16112621.0, \"Song ID\": \"3jjujdWJ72nww5eGnfs2E7\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.676, \"Energy\": 0.771, \"Loudness\": -3.675, \"Speechiness\": 0.0483, \"Acousticness\": 0.0237, \"Liveness\": 0.102, \"Tempo\": 99.048, \"Duration (ms)\": 207133.0, \"Valence\": 0.569, \"Chord\": \"G#/Ab\"}, {\"Index\": 182, \"Highest Charting Position\": 181, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"As the World Caves In\", \"Streams\": 5145493, \"Artist\": \"Sarah Cothran\", \"Artist Followers\": 180723.0, \"Song ID\": \"2xXNLutYAOELYVObYb1C1S\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-04--2021-06-11\", \"Popularity\": 71.0, \"Danceability\": 0.422, \"Energy\": 0.25, \"Loudness\": -6.836, \"Speechiness\": 0.0351, \"Acousticness\": 0.441, \"Liveness\": 0.35, \"Tempo\": 124.026, \"Duration (ms)\": 161613.0, \"Valence\": 0.246, \"Chord\": \"C\"}, {\"Index\": 183, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Fancy Like\", \"Streams\": 5145432, \"Artist\": \"Walker Hayes\", \"Artist Followers\": 304995.0, \"Song ID\": \"3ZozFqJJlDBNIm4xqxn2ZD\", \"Genre\": \"['contemporary country', 'country', 'country road', 'modern country rock']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 83.0, \"Danceability\": 0.649, \"Energy\": 0.76, \"Loudness\": -6.487, \"Speechiness\": 0.0574, \"Acousticness\": 0.114, \"Liveness\": 0.317, \"Tempo\": 80.018, \"Duration (ms)\": 161853.0, \"Valence\": 0.843, \"Chord\": \"C#/Db\"}, {\"Index\": 184, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"C\\u00farame\", \"Streams\": 5104206, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6080597.0, \"Song ID\": \"3PwRuzdphgedcWVUOVYJ7I\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 85.0, \"Danceability\": 0.765, \"Energy\": 0.625, \"Loudness\": -3.599, \"Speechiness\": 0.0548, \"Acousticness\": 0.584, \"Liveness\": 0.112, \"Tempo\": 102.101, \"Duration (ms)\": 164706.0, \"Valence\": 0.262, \"Chord\": \"A\"}, {\"Index\": 185, \"Highest Charting Position\": 110, \"Number of Times Charted\": 78, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"All of Me\", \"Streams\": 5103014, \"Artist\": \"John Legend\", \"Artist Followers\": 5799137.0, \"Song ID\": \"3U4isOIWM3VvDubwSI3y7a\", \"Genre\": \"['neo soul', 'pop', 'pop soul', 'r&b', 'urban contemporary']\", \"Release Date\": \"2013-08-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.422, \"Energy\": 0.264, \"Loudness\": -7.064, \"Speechiness\": 0.0322, \"Acousticness\": 0.922, \"Liveness\": 0.132, \"Tempo\": 119.93, \"Duration (ms)\": 269560.0, \"Valence\": 0.331, \"Chord\": \"G#/Ab\"}, {\"Index\": 186, \"Highest Charting Position\": 80, \"Number of Times Charted\": 41, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Martin & Gina\", \"Streams\": 5098609, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"1VLtjHwRWOVJiE5Py7JxoQ\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 85.0, \"Danceability\": 0.832, \"Energy\": 0.534, \"Loudness\": -7.813, \"Speechiness\": 0.253, \"Acousticness\": 0.345, \"Liveness\": 0.165, \"Tempo\": 93.924, \"Duration (ms)\": 132833.0, \"Valence\": 0.116, \"Chord\": \"C#/Db\"}, {\"Index\": 187, \"Highest Charting Position\": 40, \"Number of Times Charted\": 65, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Dior\", \"Streams\": 5092354, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"79s5XnCN4TJKTVMSmOx8Ep\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2019-07-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-06-18--2021-06-25\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 83.0, \"Danceability\": 0.548, \"Energy\": 0.805, \"Loudness\": -5.732, \"Speechiness\": 0.351, \"Acousticness\": 0.212, \"Liveness\": 0.408, \"Tempo\": 142.094, \"Duration (ms)\": 216387.0, \"Valence\": 0.648, \"Chord\": \"G\"}, {\"Index\": 188, \"Highest Charting Position\": 45, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Best Friend (feat. Doja Cat)\", \"Streams\": 5090062, \"Artist\": \"Saweetie\", \"Artist Followers\": 1254432.0, \"Song ID\": \"2etHQJxIbV0soyPhelVs9Y\", \"Genre\": \"['cali rap', 'dance pop', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2021-01-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 83.0, \"Danceability\": 0.84, \"Energy\": 0.766, \"Loudness\": -4.12, \"Speechiness\": 0.136, \"Acousticness\": 0.00302, \"Liveness\": 0.0684, \"Tempo\": 94.018, \"Duration (ms)\": 155884.0, \"Valence\": 0.402, \"Chord\": \"E\"}, {\"Index\": 189, \"Highest Charting Position\": 52, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"The Hills\", \"Streams\": 5068864, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"7fBv7CLKzipRk6EC6TWHOB\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2015-08-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 84.0, \"Danceability\": 0.585, \"Energy\": 0.564, \"Loudness\": -7.063, \"Speechiness\": 0.0515, \"Acousticness\": 0.0671, \"Liveness\": 0.135, \"Tempo\": 113.003, \"Duration (ms)\": 242253.0, \"Valence\": 0.137, \"Chord\": \"C\"}, {\"Index\": 190, \"Highest Charting Position\": 5, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Good Days\", \"Streams\": 5065132, \"Artist\": \"SZA\", \"Artist Followers\": 5881963.0, \"Song ID\": \"3YJJjQPAbDT7mGpX3WtQ9A\", \"Genre\": \"['pop', 'pop rap', 'r&b']\", \"Release Date\": \"2020-12-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 84.0, \"Danceability\": 0.436, \"Energy\": 0.655, \"Loudness\": -8.37, \"Speechiness\": 0.0583, \"Acousticness\": 0.499, \"Liveness\": 0.688, \"Tempo\": 121.002, \"Duration (ms)\": 279204.0, \"Valence\": 0.412, \"Chord\": \"C#/Db\"}, {\"Index\": 191, \"Highest Charting Position\": 191, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Kiss My (Uh Oh)\", \"Streams\": 5063181, \"Artist\": \"Anne-Marie, Little Mix\", \"Artist Followers\": 8148393.0, \"Song ID\": \"0MWiSBKm8Avs8iDIxcertp\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2021-07-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 78.0, \"Danceability\": 0.638, \"Energy\": 0.878, \"Loudness\": -3.639, \"Speechiness\": 0.0484, \"Acousticness\": 0.0151, \"Liveness\": 0.308, \"Tempo\": 103.948, \"Duration (ms)\": 176800.0, \"Valence\": 0.481, \"Chord\": \"F\"}, {\"Index\": 192, \"Highest Charting Position\": 64, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"De Museo\", \"Streams\": 5016125, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36142273.0, \"Song ID\": \"267NGliXM8YLVZiKAD9Otm\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 83.0, \"Danceability\": 0.592, \"Energy\": 0.494, \"Loudness\": -10.618, \"Speechiness\": 0.0747, \"Acousticness\": 0.237, \"Liveness\": 0.13, \"Tempo\": 132.037, \"Duration (ms)\": 209771.0, \"Valence\": 0.231, \"Chord\": \"E\"}, {\"Index\": 193, \"Highest Charting Position\": 41, \"Number of Times Charted\": 81, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"7 rings\", \"Streams\": 5002227, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67158068.0, \"Song ID\": \"6ocbgoVGwYJhOv1GgI9NsF\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-02-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.778, \"Energy\": 0.317, \"Loudness\": -10.732, \"Speechiness\": 0.334, \"Acousticness\": 0.592, \"Liveness\": 0.0881, \"Tempo\": 140.048, \"Duration (ms)\": 178627.0, \"Valence\": 0.327, \"Chord\": \"C#/Db\"}, {\"Index\": 194, \"Highest Charting Position\": 194, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Chosen (feat. Ty Dolla $ign)\", \"Streams\": 4992405, \"Artist\": \"Blxst, Tyga\", \"Artist Followers\": 167628.0, \"Song ID\": \"1dIWPXMX4kRHj6Dt2DStUQ\", \"Genre\": \"[]\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 84.0, \"Danceability\": 0.571, \"Energy\": 0.767, \"Loudness\": -5.16, \"Speechiness\": 0.287, \"Acousticness\": 0.336, \"Liveness\": 0.0809, \"Tempo\": 93.421, \"Duration (ms)\": 161684.0, \"Valence\": 0.605, \"Chord\": \"D\"}, {\"Index\": 195, \"Highest Charting Position\": 149, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"N\\u00e3o Nasceu pra Namorar\", \"Streams\": 4978559, \"Artist\": \"MC Zaquin, MC Rick\", \"Artist Followers\": 130627.0, \"Song ID\": \"6pQKUKBpwr6GhfhcFFFozo\", \"Genre\": \"['funk bh', 'funk carioca']\", \"Release Date\": \"2021-02-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.525, \"Energy\": 0.448, \"Loudness\": -4.075, \"Speechiness\": 0.0443, \"Acousticness\": 0.14, \"Liveness\": 0.0922, \"Tempo\": 83.406, \"Duration (ms)\": 140308.0, \"Valence\": 0.527, \"Chord\": \"C#/Db\"}, {\"Index\": 196, \"Highest Charting Position\": 8, \"Number of Times Charted\": 71, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Breaking Me\", \"Streams\": 4977498, \"Artist\": \"Topic, A7S\", \"Artist Followers\": 151832.0, \"Song ID\": \"3H7ihDc1dqLriiWXwsc2po\", \"Genre\": \"['dance pop', 'edm', 'german dance', 'pop dance', 'pop edm', 'tropical house']\", \"Release Date\": \"2019-12-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 84.0, \"Danceability\": 0.789, \"Energy\": 0.72, \"Loudness\": -5.652, \"Speechiness\": 0.218, \"Acousticness\": 0.223, \"Liveness\": 0.129, \"Tempo\": 122.031, \"Duration (ms)\": 166794.0, \"Valence\": 0.664, \"Chord\": \"G#/Ab\"}, {\"Index\": 197, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"penhasco.\", \"Streams\": 4973937, \"Artist\": \"Lu\\u00edsa Sonza\", \"Artist Followers\": 1909059.0, \"Song ID\": \"5VTqW8raQYnj2avZ27nO2a\", \"Genre\": \"['funk carioca', 'pop nacional']\", \"Release Date\": \"2021-07-18\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 80.0, \"Danceability\": 0.43, \"Energy\": 0.467, \"Loudness\": -8.56, \"Speechiness\": 0.051, \"Acousticness\": 0.775, \"Liveness\": 0.0933, \"Tempo\": 77.249, \"Duration (ms)\": 186121.0, \"Valence\": 0.382, \"Chord\": \"G#/Ab\"}, {\"Index\": 198, \"Highest Charting Position\": 58, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Late At Night\", \"Streams\": 4954899, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6603627.0, \"Song ID\": \"1fxYz1s15pyZLsJT0Hdh1m\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 84.0, \"Danceability\": 0.643, \"Energy\": 0.403, \"Loudness\": -11.254, \"Speechiness\": 0.41, \"Acousticness\": 0.343, \"Liveness\": 0.138, \"Tempo\": 98.54, \"Duration (ms)\": 174682.0, \"Valence\": 0.111, \"Chord\": \"C#/Db\"}, {\"Index\": 199, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Verdansk\", \"Streams\": 4950275, \"Artist\": \"Dave\", \"Artist Followers\": 1427540.0, \"Song ID\": \"7IPKXYU2rTMnrLW5IZ7ZI5\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2021-07-22\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 77.0, \"Danceability\": 0.961, \"Energy\": 0.502, \"Loudness\": -8.605, \"Speechiness\": 0.312, \"Acousticness\": 0.28, \"Liveness\": 0.145, \"Tempo\": 117.078, \"Duration (ms)\": 182285.0, \"Valence\": 0.536, \"Chord\": \"D\"}, {\"Index\": 200, \"Highest Charting Position\": 172, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"The Real Slim Shady\", \"Streams\": 4948965, \"Artist\": \"Eminem\", \"Artist Followers\": 46785561.0, \"Song ID\": \"3yfqSUWxFvZELEM4PmlwIR\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2000-05-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 84.0, \"Danceability\": 0.949, \"Energy\": 0.661, \"Loudness\": -4.244, \"Speechiness\": 0.0572, \"Acousticness\": 0.0302, \"Liveness\": 0.0454, \"Tempo\": 104.504, \"Duration (ms)\": 284200.0, \"Valence\": 0.76, \"Chord\": \"F\"}, {\"Index\": 201, \"Highest Charting Position\": 66, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Tell The Vision (feat. Kanye West & Pusha T)\", \"Streams\": 8859168, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"1Eu51GaXEehPMrDMh5QghA\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 57.0, \"Danceability\": 0.662, \"Energy\": 0.686, \"Loudness\": -8.302, \"Speechiness\": 0.332, \"Acousticness\": 0.251, \"Liveness\": 0.349, \"Tempo\": 143.971, \"Duration (ms)\": 215000.0, \"Valence\": 0.678, \"Chord\": \"G\"}, {\"Index\": 202, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Woo Baby (feat. Chris Brown)\", \"Streams\": 7371935, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"6bsqes8Zg9gUULzuCkMUs0\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 56.0, \"Danceability\": 0.563, \"Energy\": 0.672, \"Loudness\": -7.226, \"Speechiness\": 0.0765, \"Acousticness\": 0.359, \"Liveness\": 0.0972, \"Tempo\": 99.772, \"Duration (ms)\": 156000.0, \"Valence\": 0.284, \"Chord\": \"A\"}, {\"Index\": 203, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Holy Smokes\", \"Streams\": 6464206, \"Artist\": \"Trippie Redd, Lil Uzi Vert\", \"Artist Followers\": 6430522.0, \"Song ID\": \"3EpF150nXMSNjiH0bbmXIL\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 79.0, \"Danceability\": 0.437, \"Energy\": 0.527, \"Loudness\": -6.967, \"Speechiness\": 0.465, \"Acousticness\": 0.185, \"Liveness\": 0.153, \"Tempo\": 187.815, \"Duration (ms)\": 181714.0, \"Valence\": 0.701, \"Chord\": \"F#/Gb\"}, {\"Index\": 204, \"Highest Charting Position\": 127, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"More Time\", \"Streams\": 6238351, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"7wAnRqccDr2tzcSKLR4jKl\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 55.0, \"Danceability\": 0.628, \"Energy\": 0.581, \"Loudness\": -8.377, \"Speechiness\": 0.188, \"Acousticness\": 0.46, \"Liveness\": 0.152, \"Tempo\": 145.396, \"Duration (ms)\": 120828.0, \"Valence\": 0.259, \"Chord\": \"D\"}, {\"Index\": 205, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Coupe\", \"Streams\": 6161664, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"7LB3ilSpX1mSMKKztNTnu2\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 54.0, \"Danceability\": 0.912, \"Energy\": 0.589, \"Loudness\": -7.476, \"Speechiness\": 0.2, \"Acousticness\": 0.0332, \"Liveness\": 0.0795, \"Tempo\": 135.921, \"Duration (ms)\": 123549.0, \"Valence\": 0.486, \"Chord\": \"G#/Ab\"}, {\"Index\": 206, \"Highest Charting Position\": 76, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Holiday\", \"Streams\": 5883145, \"Artist\": \"KSI\", \"Artist Followers\": 2008516.0, \"Song ID\": \"6nV2dFZXpv1JlqDWBeTXRl\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 81.0, \"Danceability\": 0.356, \"Energy\": 0.684, \"Loudness\": -7.347, \"Speechiness\": 0.0878, \"Acousticness\": 0.152, \"Liveness\": 0.101, \"Tempo\": 87.188, \"Duration (ms)\": 193733.0, \"Valence\": 0.347, \"Chord\": \"G#/Ab\"}, {\"Index\": 207, \"Highest Charting Position\": 150, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Manslaughter (feat. Rick Ross & The-Dream)\", \"Streams\": 5822266, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"4byRwLo7EmkCNBU6S8G6u0\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 55.0, \"Danceability\": 0.441, \"Energy\": 0.623, \"Loudness\": -7.331, \"Speechiness\": 0.0414, \"Acousticness\": 0.135, \"Liveness\": 0.14, \"Tempo\": 78.082, \"Duration (ms)\": 249231.0, \"Valence\": 0.285, \"Chord\": \"C#/Db\"}, {\"Index\": 208, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Genius (feat. Lil Tjay & Swae Lee)\", \"Streams\": 5702636, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"2mmRtchzDVpCj9LSyexgjS\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 53.0, \"Danceability\": 0.723, \"Energy\": 0.667, \"Loudness\": -7.524, \"Speechiness\": 0.351, \"Acousticness\": 0.256, \"Liveness\": 0.261, \"Tempo\": 143.044, \"Duration (ms)\": 208112.0, \"Valence\": 0.396, \"Chord\": \"D\"}, {\"Index\": 209, \"Highest Charting Position\": 22, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"WUSYANAME (feat. Youngboy Never Broke Again & Ty Dolla $ign)\", \"Streams\": 5696113, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"5B0kgjHULYJhAQkK5XsMoC\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.493, \"Energy\": 0.653, \"Loudness\": -5.666, \"Speechiness\": 0.0466, \"Acousticness\": 0.269, \"Liveness\": 0.511, \"Tempo\": 142.347, \"Duration (ms)\": 121573.0, \"Valence\": 0.852, \"Chord\": \"C\"}, {\"Index\": 210, \"Highest Charting Position\": 105, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Sommergewitter\", \"Streams\": 5627519, \"Artist\": \"Pashanim\", \"Artist Followers\": 208554.0, \"Song ID\": \"2H7jZg2HliuQhZjfBblLrZ\", \"Genre\": \"['german alternative rap', 'german drill', 'german hip hop', 'german trap']\", \"Release Date\": \"2021-06-24\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.787, \"Energy\": 0.531, \"Loudness\": -10.569, \"Speechiness\": 0.101, \"Acousticness\": 0.132, \"Liveness\": 0.112, \"Tempo\": 91.996, \"Duration (ms)\": 138533.0, \"Valence\": 0.721, \"Chord\": \"B\"}, {\"Index\": 211, \"Highest Charting Position\": 17, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Body (Remix) [feat. ArrDee, E1 (3x3), ZT (3x3), Bugzy Malone, Buni, Fivio Foreign & Darkoo]\", \"Streams\": 5383125, \"Artist\": \"Tion Wayne, Russ Millions\", \"Artist Followers\": 323203.0, \"Song ID\": \"6uvMKqNlrSvcC4NaKnrwjZ\", \"Genre\": \"['london rap']\", \"Release Date\": \"2021-04-22\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 84.0, \"Danceability\": 0.883, \"Energy\": 0.674, \"Loudness\": -8.043, \"Speechiness\": 0.357, \"Acousticness\": 0.21, \"Liveness\": 0.0678, \"Tempo\": 141.02, \"Duration (ms)\": 278085.0, \"Valence\": 0.73, \"Chord\": \"B\"}, {\"Index\": 212, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Brush Em (feat. Rah Swish)\", \"Streams\": 5335271, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"58aW6yZGFl7rVM7SLfLnLL\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 54.0, \"Danceability\": 0.654, \"Energy\": 0.724, \"Loudness\": -6.59, \"Speechiness\": 0.355, \"Acousticness\": 0.106, \"Liveness\": 0.655, \"Tempo\": 71.696, \"Duration (ms)\": 150449.0, \"Valence\": 0.717, \"Chord\": \"D#/Eb\"}, {\"Index\": 213, \"Highest Charting Position\": 13, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"AM\", \"Streams\": 5288927, \"Artist\": \"Nio Garcia, Flow La Movie\", \"Artist Followers\": 2123734.0, \"Song ID\": \"2dNhNlpZAtV4lwAFW45LIv\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-01-28\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 85.0, \"Danceability\": 0.83, \"Energy\": 0.517, \"Loudness\": -6.416, \"Speechiness\": 0.333, \"Acousticness\": 0.399, \"Liveness\": 0.0916, \"Tempo\": 171.959, \"Duration (ms)\": 182496.0, \"Valence\": 0.616, \"Chord\": \"F#/Gb\"}, {\"Index\": 214, \"Highest Charting Position\": 175, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"MI FAI IMPAZZIRE\", \"Streams\": 5242097, \"Artist\": \"BLANCO, Sfera Ebbasta\", \"Artist Followers\": 127364.0, \"Song ID\": \"1x3Qb8np6S1UvpSLthwEJN\", \"Genre\": \"['italian hip hop', 'italian pop']\", \"Release Date\": \"2021-06-17\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\", \"Popularity\": 83.0, \"Danceability\": 0.477, \"Energy\": 0.844, \"Loudness\": -4.87, \"Speechiness\": 0.0458, \"Acousticness\": 0.00273, \"Liveness\": 0.137, \"Tempo\": 169.941, \"Duration (ms)\": 220235.0, \"Valence\": 0.203, \"Chord\": \"B\"}, {\"Index\": 215, \"Highest Charting Position\": 20, \"Number of Times Charted\": 82, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Ride It\", \"Streams\": 5235088, \"Artist\": \"Regard\", \"Artist Followers\": 152226.0, \"Song ID\": \"2tnVG71enUj33Ic2nFN6kZ\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop edm', 'slap house', 'tropical house']\", \"Release Date\": \"2019-07-26\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.88, \"Energy\": 0.751, \"Loudness\": -4.258, \"Speechiness\": 0.0874, \"Acousticness\": 0.177, \"Liveness\": 0.106, \"Tempo\": 117.948, \"Duration (ms)\": 157606.0, \"Valence\": 0.884, \"Chord\": \"G\"}, {\"Index\": 216, \"Highest Charting Position\": 15, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Lost Cause\", \"Streams\": 5203319, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"36fhyo5QlxBW7DrDHIOn1G\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 0.0, \"Danceability\": 0.671, \"Energy\": 0.336, \"Loudness\": -8.494, \"Speechiness\": 0.241, \"Acousticness\": 0.705, \"Liveness\": 0.0577, \"Tempo\": 75.051, \"Duration (ms)\": 212496.0, \"Valence\": 0.518, \"Chord\": \"A#/Bb\"}, {\"Index\": 217, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Shot in the Dark\", \"Streams\": 5173308, \"Artist\": \"John Mayer\", \"Artist Followers\": 5178156.0, \"Song ID\": \"239yM7BAQ2CkNc61ogPGXo\", \"Genre\": \"['neo mellow', 'pop rock', 'singer-songwriter']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 76.0, \"Danceability\": 0.741, \"Energy\": 0.556, \"Loudness\": -9.184, \"Speechiness\": 0.0266, \"Acousticness\": 0.0629, \"Liveness\": 0.103, \"Tempo\": 122.008, \"Duration (ms)\": 249080.0, \"Valence\": 0.587, \"Chord\": \"D\"}, {\"Index\": 218, \"Highest Charting Position\": 71, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Wrecked\", \"Streams\": 5150909, \"Artist\": \"Imagine Dragons\", \"Artist Followers\": 35285425.0, \"Song ID\": \"2d1MywHy6FwKdzxFuSJnwl\", \"Genre\": \"['modern rock', 'pop', 'rock']\", \"Release Date\": \"2021-07-02\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 83.0, \"Danceability\": 0.626, \"Energy\": 0.56, \"Loudness\": -5.82, \"Speechiness\": 0.0288, \"Acousticness\": 0.148, \"Liveness\": 0.109, \"Tempo\": 93.989, \"Duration (ms)\": 244005.0, \"Valence\": 0.229, \"Chord\": \"C\"}, {\"Index\": 219, \"Highest Charting Position\": 79, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Bipolar\", \"Streams\": 5116589, \"Artist\": \"Mc Davi, Mc Pedrinho, Mc Don Juan\", \"Artist Followers\": 2586114.0, \"Song ID\": \"0qxLQ6opocOGyFnlXqJ53x\", \"Genre\": \"['funk carioca', 'funk ostentacao', 'funk paulista']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 84.0, \"Danceability\": 0.601, \"Energy\": 0.36, \"Loudness\": -7.791, \"Speechiness\": 0.0877, \"Acousticness\": 0.586, \"Liveness\": 0.0882, \"Tempo\": 124.993, \"Duration (ms)\": 276480.0, \"Valence\": 0.335, \"Chord\": \"A\"}, {\"Index\": 220, \"Highest Charting Position\": 122, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"His & Hers (feat. Don Toliver, Lil Uzi Vert & Gunna)\", \"Streams\": 5110475, \"Artist\": \"Internet Money\", \"Artist Followers\": 411579.0, \"Song ID\": \"2IePEfMAtqWS6rLXXFZIgI\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-05-14--2021-05-21\", \"Popularity\": 84.0, \"Danceability\": 0.792, \"Energy\": 0.707, \"Loudness\": -5.218, \"Speechiness\": 0.0623, \"Acousticness\": 0.116, \"Liveness\": 0.12, \"Tempo\": 134.997, \"Duration (ms)\": 224042.0, \"Valence\": 0.408, \"Chord\": \"G\"}, {\"Index\": 221, \"Highest Charting Position\": 75, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Follow You\", \"Streams\": 5097187, \"Artist\": \"Imagine Dragons\", \"Artist Followers\": 35285425.0, \"Song ID\": \"7FdUvDkaE24o3FPIWTvzv2\", \"Genre\": \"['modern rock', 'pop', 'rock']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 84.0, \"Danceability\": 0.542, \"Energy\": 0.732, \"Loudness\": -5.956, \"Speechiness\": 0.0521, \"Acousticness\": 0.00209, \"Liveness\": 0.496, \"Tempo\": 124.912, \"Duration (ms)\": 175644.0, \"Valence\": 0.489, \"Chord\": \"A\"}, {\"Index\": 222, \"Highest Charting Position\": 22, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"We're Good\", \"Streams\": 6318660, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"1diS6nkxMQc3wwC4G1j0bh\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 83.0, \"Danceability\": 0.722, \"Energy\": 0.588, \"Loudness\": -5.932, \"Speechiness\": 0.0544, \"Acousticness\": 0.0319, \"Liveness\": 0.183, \"Tempo\": 134.01, \"Duration (ms)\": 165507.0, \"Valence\": 0.59, \"Chord\": \"F#/Gb\"}, {\"Index\": 223, \"Highest Charting Position\": 4, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Life Goes On\", \"Streams\": 6142975, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"249gnXrbfmV8NG6jTEMSwD\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 84.0, \"Danceability\": 0.566, \"Energy\": 0.716, \"Loudness\": -5.733, \"Speechiness\": 0.0424, \"Acousticness\": 0.00691, \"Liveness\": 0.37, \"Tempo\": 81.068, \"Duration (ms)\": 207481.0, \"Valence\": 0.45, \"Chord\": \"C#/Db\"}, {\"Index\": 224, \"Highest Charting Position\": 28, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"911\", \"Streams\": 6111108, \"Artist\": \"Sech\", \"Artist Followers\": 8758283.0, \"Song ID\": \"27RSJHEA99Y0Vsow7nA37A\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2020-05-29--2020-06-05\", \"Popularity\": 89.0, \"Danceability\": 0.816, \"Energy\": 0.71, \"Loudness\": -3.728, \"Speechiness\": 0.0398, \"Acousticness\": 0.165, \"Liveness\": 0.292, \"Tempo\": 93.02, \"Duration (ms)\": 208631.0, \"Valence\": 0.784, \"Chord\": \"G\"}, {\"Index\": 225, \"Highest Charting Position\": 17, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Baila Conmigo (with Rauw Alejandro)\", \"Streams\": 5588217, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28909504.0, \"Song ID\": \"079Ey5uxL04AKPQgVQwx5h\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 84.0, \"Danceability\": 0.823, \"Energy\": 0.544, \"Loudness\": -7.132, \"Speechiness\": 0.0715, \"Acousticness\": 0.0215, \"Liveness\": 0.0966, \"Tempo\": 149.903, \"Duration (ms)\": 186088.0, \"Valence\": 0.664, \"Chord\": \"F\"}, {\"Index\": 226, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"The Jackie (with J. Cole & Lil Tjay)\", \"Streams\": 5454994, \"Artist\": \"Bas\", \"Artist Followers\": 386757.0, \"Song ID\": \"15qKrPi4Kg0z7g9HlwWyeb\", \"Genre\": \"['hip hop', 'pop rap', 'queens hip hop', 'rap', 'sudanese pop', 'underground hip hop']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-09--2021-07-16\", \"Popularity\": 76.0, \"Danceability\": 0.784, \"Energy\": 0.474, \"Loudness\": -6.139, \"Speechiness\": 0.0524, \"Acousticness\": 0.333, \"Liveness\": 0.278, \"Tempo\": 128.012, \"Duration (ms)\": 204434.0, \"Valence\": 0.64, \"Chord\": \"G#/Ab\"}, {\"Index\": 227, \"Highest Charting Position\": 22, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"hope ur ok\", \"Streams\": 5435614, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"1zejeOnykpCoyVSit6Bwp3\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 84.0, \"Danceability\": 0.443, \"Energy\": 0.298, \"Loudness\": -12.181, \"Speechiness\": 0.0644, \"Acousticness\": 0.388, \"Liveness\": 0.103, \"Tempo\": 77.253, \"Duration (ms)\": 209560.0, \"Valence\": 0.172, \"Chord\": \"C\"}, {\"Index\": 228, \"Highest Charting Position\": 169, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Faz Amor Comigo S\\u00f3 Hoje - Ao Vivo\", \"Streams\": 5269757, \"Artist\": \"Israel & Rodolffo, Wesley Safad\\u00e3o\", \"Artist Followers\": 1097789.0, \"Song ID\": \"7Kba4OaxQFQ1zlknQUpNqN\", \"Genre\": \"['sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2021-05-26\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 82.0, \"Danceability\": 0.624, \"Energy\": 0.922, \"Loudness\": -4.628, \"Speechiness\": 0.0439, \"Acousticness\": 0.3, \"Liveness\": 0.112, \"Tempo\": 164.819, \"Duration (ms)\": 148228.0, \"Valence\": 0.884, \"Chord\": \"C#/Db\"}, {\"Index\": 229, \"Highest Charting Position\": 80, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Alcohol-Free\", \"Streams\": 5259503, \"Artist\": \"TWICE\", \"Artist Followers\": 9987114.0, \"Song ID\": \"0BTaaKT4RMbs5M73tOHX5Y\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 82.0, \"Danceability\": 0.688, \"Energy\": 0.909, \"Loudness\": -1.992, \"Speechiness\": 0.0624, \"Acousticness\": 0.0474, \"Liveness\": 0.0674, \"Tempo\": 97.097, \"Duration (ms)\": 210573.0, \"Valence\": 0.702, \"Chord\": \"G#/Ab\"}, {\"Index\": 230, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"WHOLE LOTTA MONEY (feat. Nicki Minaj) - Remix\", \"Streams\": 5186354, \"Artist\": \"BIA\", \"Artist Followers\": 151870.0, \"Song ID\": \"67G6iaOw8DZqp1z8STR89R\", \"Genre\": \"['escape room', 'r&b', 'rap latina', 'trap queen']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-09--2021-07-16\", \"Popularity\": 80.0, \"Danceability\": 0.893, \"Energy\": 0.463, \"Loudness\": -5.301, \"Speechiness\": 0.36, \"Acousticness\": 0.199, \"Liveness\": 0.318, \"Tempo\": 81.026, \"Duration (ms)\": 229601.0, \"Valence\": 0.591, \"Chord\": \"C#/Db\"}, {\"Index\": 231, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Memory\", \"Streams\": 5173178, \"Artist\": \"Kane Brown, blackbear\", \"Artist Followers\": 3507622.0, \"Song ID\": \"34chhNX59Wo9HMFCsI3K8Y\", \"Genre\": \"['contemporary country', 'country road']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-09--2021-07-16\", \"Popularity\": 80.0, \"Danceability\": 0.434, \"Energy\": 0.889, \"Loudness\": -5.684, \"Speechiness\": 0.0509, \"Acousticness\": 0.395, \"Liveness\": 0.273, \"Tempo\": 113.326, \"Duration (ms)\": 153338.0, \"Valence\": 0.845, \"Chord\": \"A\"}, {\"Index\": 232, \"Highest Charting Position\": 183, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Me Fije\", \"Streams\": 5068677, \"Artist\": \"Alex Rose, Rauw Alejandro\", \"Artist Followers\": 2166191.0, \"Song ID\": \"6Et5KimMg3IXwD6lJPGmQw\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2021-03-18\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-05-07--2021-05-14\", \"Popularity\": 83.0, \"Danceability\": 0.76, \"Energy\": 0.674, \"Loudness\": -4.039, \"Speechiness\": 0.0636, \"Acousticness\": 0.396, \"Liveness\": 0.0977, \"Tempo\": 172.024, \"Duration (ms)\": 202307.0, \"Valence\": 0.735, \"Chord\": \"G\"}, {\"Index\": 233, \"Highest Charting Position\": 71, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Volta Beb\\u00ea, Volta Nen\\u00e9m\", \"Streams\": 5041120, \"Artist\": \"Dj Guuga, DJ Ivis\", \"Artist Followers\": 608109.0, \"Song ID\": \"4wQUopWk9Ed7Ng5qpKN5qd\", \"Genre\": \"['funk carioca', 'funk paulista', 'rave funk']\", \"Release Date\": \"2021-03-27\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 79.0, \"Danceability\": 0.583, \"Energy\": 0.918, \"Loudness\": -3.612, \"Speechiness\": 0.0518, \"Acousticness\": 0.288, \"Liveness\": 0.0701, \"Tempo\": 164.081, \"Duration (ms)\": 172973.0, \"Valence\": 0.836, \"Chord\": \"F#/Gb\"}, {\"Index\": 234, \"Highest Charting Position\": 95, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Aloha\", \"Streams\": 5036030, \"Artist\": \"Maluma, Be\\u00e9le, Rauw Alejandro, Mambo Kingz, DJ Luian, Darell\", \"Artist Followers\": 26769304.0, \"Song ID\": \"5RAIMjdrCEjpjaR5tBATXU\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 84.0, \"Danceability\": 0.807, \"Energy\": 0.712, \"Loudness\": -5.757, \"Speechiness\": 0.1, \"Acousticness\": 0.532, \"Liveness\": 0.163, \"Tempo\": 100.004, \"Duration (ms)\": 241659.0, \"Valence\": 0.792, \"Chord\": \"C#/Db\"}, {\"Index\": 235, \"Highest Charting Position\": 184, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Sexo Virtual\", \"Streams\": 4975786, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6080597.0, \"Song ID\": \"0giiXonRhODYy4J1iy4Lb3\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 82.0, \"Danceability\": 0.704, \"Energy\": 0.739, \"Loudness\": -3.286, \"Speechiness\": 0.112, \"Acousticness\": 0.328, \"Liveness\": 0.0856, \"Tempo\": 179.879, \"Duration (ms)\": 208292.0, \"Valence\": 0.425, \"Chord\": \"G#/Ab\"}, {\"Index\": 236, \"Highest Charting Position\": 141, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Closer\", \"Streams\": 4954679, \"Artist\": \"The Chainsmokers, Halsey\", \"Artist Followers\": 18191658.0, \"Song ID\": \"7BKLCZ1jbUBVqRi2FVlTVw\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2016-07-29\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-01--2021-01-08\\n2020-08-14--2020-08-21\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.748, \"Energy\": 0.524, \"Loudness\": -5.599, \"Speechiness\": 0.0338, \"Acousticness\": 0.414, \"Liveness\": 0.111, \"Tempo\": 95.01, \"Duration (ms)\": 244960.0, \"Valence\": 0.661, \"Chord\": \"G#/Ab\"}, {\"Index\": 237, \"Highest Charting Position\": 194, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Wonderwall - Remastered\", \"Streams\": 4938180, \"Artist\": \"Oasis\", \"Artist Followers\": 6475631.0, \"Song ID\": \"7ygpwy2qP3NbrxVkHvUhXY\", \"Genre\": \"['beatlesque', 'britpop', 'madchester', 'permanent wave', 'rock']\", \"Release Date\": \"1995\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-05-28--2021-06-04\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 78.0, \"Danceability\": 0.375, \"Energy\": 0.893, \"Loudness\": -4.097, \"Speechiness\": 0.0406, \"Acousticness\": 0.000509, \"Liveness\": 0.187, \"Tempo\": 174.323, \"Duration (ms)\": 258773.0, \"Valence\": 0.434, \"Chord\": \"D\"}, {\"Index\": 238, \"Highest Charting Position\": 101, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Wasting Time ( feat. Drake )\", \"Streams\": 6731106, \"Artist\": \"Brent Faiyaz\", \"Artist Followers\": 1724414.0, \"Song ID\": \"48WidxP9CqyYtk97pwGZ3c\", \"Genre\": \"['dmv rap', 'pop', 'r&b', 'rap']\", \"Release Date\": \"2021-07-01\", \"Weeks Charted\": \"2021-07-02--2021-07-09\", \"Popularity\": 78.0, \"Danceability\": 0.652, \"Energy\": 0.717, \"Loudness\": -3.751, \"Speechiness\": 0.0581, \"Acousticness\": 0.0694, \"Liveness\": 0.0906, \"Tempo\": 89.982, \"Duration (ms)\": 301304.0, \"Valence\": 0.377, \"Chord\": \"G\"}, {\"Index\": 239, \"Highest Charting Position\": 55, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"I Don't Do Drugs (feat. Ariana Grande)\", \"Streams\": 5912293, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0FFsgUoFibYISzMxuGS61W\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 80.0, \"Danceability\": 0.683, \"Energy\": 0.615, \"Loudness\": -5.737, \"Speechiness\": 0.0966, \"Acousticness\": 0.222, \"Liveness\": 0.154, \"Tempo\": 77.014, \"Duration (ms)\": 188893.0, \"Valence\": 0.45, \"Chord\": \"F\"}, {\"Index\": 240, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Renegade (feat. Taylor Swift)\", \"Streams\": 5876058, \"Artist\": \"Big Red Machine\", \"Artist Followers\": 98503.0, \"Song ID\": \"1aU1wpYBSpP0M6IiihY5Ue\", \"Genre\": \"['eau claire indie', 'folktronica']\", \"Release Date\": \"2021-07-02\", \"Weeks Charted\": \"2021-07-02--2021-07-09\", \"Popularity\": 77.0, \"Danceability\": 0.532, \"Energy\": 0.708, \"Loudness\": -8.121, \"Speechiness\": 0.0505, \"Acousticness\": 0.435, \"Liveness\": 0.107, \"Tempo\": 167.977, \"Duration (ms)\": 254467.0, \"Valence\": 0.586, \"Chord\": \"C\"}, {\"Index\": 241, \"Highest Charting Position\": 40, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"JUGGERNAUT (feat. Lil Uzi Vert & Pharrell Williams)\", \"Streams\": 5392334, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"7z4xW9WY86uH3gd1V9pfCM\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 80.0, \"Danceability\": 0.827, \"Energy\": 0.571, \"Loudness\": -7.949, \"Speechiness\": 0.366, \"Acousticness\": 0.0195, \"Liveness\": 0.166, \"Tempo\": 142.034, \"Duration (ms)\": 146419.0, \"Valence\": 0.62, \"Chord\": \"B\"}, {\"Index\": 242, \"Highest Charting Position\": 152, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"All Eyes On Me\", \"Streams\": 5347263, \"Artist\": \"Bo Burnham\", \"Artist Followers\": 1042079.0, \"Song ID\": \"3rV5y8rcQrwRt9fWGLmjOQ\", \"Genre\": \"['comic']\", \"Release Date\": \"2021-06-10\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 81.0, \"Danceability\": 0.352, \"Energy\": 0.424, \"Loudness\": -10.131, \"Speechiness\": 0.0394, \"Acousticness\": 0.733, \"Liveness\": 0.0664, \"Tempo\": 127.047, \"Duration (ms)\": 302951.0, \"Valence\": 0.141, \"Chord\": \"F#/Gb\"}, {\"Index\": 243, \"Highest Charting Position\": 101, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"EVERY CHANCE I GET (feat. Lil Baby & Lil Durk)\", \"Streams\": 5321544, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6278835.0, \"Song ID\": \"1EJIcDYXwSqipW5dFe4uJz\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 83.0, \"Danceability\": 0.477, \"Energy\": 0.727, \"Loudness\": -4.053, \"Speechiness\": 0.286, \"Acousticness\": 0.000866, \"Liveness\": 0.108, \"Tempo\": 150.062, \"Duration (ms)\": 236524.0, \"Valence\": 0.227, \"Chord\": \"D\"}, {\"Index\": 244, \"Highest Charting Position\": 72, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Dick (feat. Doja Cat)\", \"Streams\": 5258628, \"Artist\": \"StarBoi3\", \"Artist Followers\": 17202.0, \"Song ID\": \"3nY8AqaMNNHHLYV4380ol0\", \"Genre\": \"[]\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 83.0, \"Danceability\": 0.647, \"Energy\": 0.608, \"Loudness\": -6.831, \"Speechiness\": 0.42, \"Acousticness\": 0.13, \"Liveness\": 0.0584, \"Tempo\": 125.994, \"Duration (ms)\": 175238.0, \"Valence\": 0.474, \"Chord\": \"A\"}, {\"Index\": 245, \"Highest Charting Position\": 25, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Solar Power\", \"Streams\": 5234112, \"Artist\": \"Lorde\", \"Artist Followers\": 8083566.0, \"Song ID\": \"3KdoeNlEN0BoAKWzaRLNZa\", \"Genre\": \"['art pop', 'dance pop', 'electropop', 'metropopolis', 'nz pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-06-10\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 81.0, \"Danceability\": 0.735, \"Energy\": 0.47, \"Loudness\": -9.405, \"Speechiness\": 0.1, \"Acousticness\": 0.266, \"Liveness\": 0.32, \"Tempo\": 87.971, \"Duration (ms)\": 192621.0, \"Valence\": 0.897, \"Chord\": \"E\"}, {\"Index\": 246, \"Highest Charting Position\": 4, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Your Power\", \"Streams\": 5135380, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47014200.0, \"Song ID\": \"042Sl6Mn83JHyLEqdK7uI0\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-07-30\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 81.0, \"Danceability\": 0.632, \"Energy\": 0.284, \"Loudness\": -14.025, \"Speechiness\": 0.0801, \"Acousticness\": 0.932, \"Liveness\": 0.233, \"Tempo\": 129.642, \"Duration (ms)\": 245897.0, \"Valence\": 0.208, \"Chord\": \"A\"}, {\"Index\": 247, \"Highest Charting Position\": 189, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Lieben wir\", \"Streams\": 5029898, \"Artist\": \"Shirin David\", \"Artist Followers\": 558345.0, \"Song ID\": \"49gzU1IS1B6P3GATSZ5eCE\", \"Genre\": \"['frauenrap', 'german hip hop', 'german pop']\", \"Release Date\": \"2021-07-01\", \"Weeks Charted\": \"2021-07-02--2021-07-09\", \"Popularity\": 77.0, \"Danceability\": 0.871, \"Energy\": 0.669, \"Loudness\": -7.62, \"Speechiness\": 0.329, \"Acousticness\": 0.0113, \"Liveness\": 0.0795, \"Tempo\": 95.939, \"Duration (ms)\": 155363.0, \"Valence\": 0.806, \"Chord\": \"A#/Bb\"}, {\"Index\": 248, \"Highest Charting Position\": 8, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Whoopty\", \"Streams\": 5013017, \"Artist\": \"CJ\", \"Artist Followers\": 180454.0, \"Song ID\": \"5vGLcdRuSbUhD8ScwsGSdA\", \"Genre\": \"['nyc rap']\", \"Release Date\": \"2020-08-20\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 81.0, \"Danceability\": 0.719, \"Energy\": 0.648, \"Loudness\": -7.6, \"Speechiness\": 0.125, \"Acousticness\": 0.2, \"Liveness\": 0.127, \"Tempo\": 140.201, \"Duration (ms)\": 123263.0, \"Valence\": 0.66, \"Chord\": \"D#/Eb\"}, {\"Index\": 249, \"Highest Charting Position\": 55, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Batom de Cereja - Ao Vivo\", \"Streams\": 5011753, \"Artist\": \"Israel & Rodolffo\", \"Artist Followers\": 1097789.0, \"Song ID\": \"2MZQAvsA7aZDssppBLRxYp\", \"Genre\": \"['sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2021-01-29\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 83.0, \"Danceability\": 0.606, \"Energy\": 0.908, \"Loudness\": -6.201, \"Speechiness\": 0.0565, \"Acousticness\": 0.556, \"Liveness\": 0.19, \"Tempo\": 171.966, \"Duration (ms)\": 140942.0, \"Valence\": 0.798, \"Chord\": \"F#/Gb\"}, {\"Index\": 250, \"Highest Charting Position\": 11, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Prisoner (feat. Dua Lipa)\", \"Streams\": 5005018, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15770302.0, \"Song ID\": \"5JqZ3oqF00jkT81foAFvqg\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 79.0, \"Danceability\": 0.781, \"Energy\": 0.67, \"Loudness\": -3.912, \"Speechiness\": 0.0452, \"Acousticness\": 0.0103, \"Liveness\": 0.0761, \"Tempo\": 127.99, \"Duration (ms)\": 169333.0, \"Valence\": 0.595, \"Chord\": \"D#/Eb\"}, {\"Index\": 251, \"Highest Charting Position\": 136, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Stereo Hearts (feat. Adam Levine)\", \"Streams\": 4992345, \"Artist\": \"Gym Class Heroes\", \"Artist Followers\": 1275345.0, \"Song ID\": \"0qOnSQQF0yzuPWsXrQ9paz\", \"Genre\": \"['dance pop', 'pop rap']\", \"Release Date\": \"2011-11-11\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 82.0, \"Danceability\": 0.646, \"Energy\": 0.795, \"Loudness\": -3.293, \"Speechiness\": 0.0976, \"Acousticness\": 0.0319, \"Liveness\": 0.267, \"Tempo\": 89.99, \"Duration (ms)\": 210960.0, \"Valence\": 0.796, \"Chord\": \"A\"}, {\"Index\": 252, \"Highest Charting Position\": 32, \"Number of Times Charted\": 36, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Reloj\", \"Streams\": 4980155, \"Artist\": \"Rauw Alejandro, Anuel AA\", \"Artist Followers\": 6080597.0, \"Song ID\": \"7r9ZhitdQBONTFOiJW5mr8\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-10-22\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 79.0, \"Danceability\": 0.823, \"Energy\": 0.537, \"Loudness\": -2.639, \"Speechiness\": 0.209, \"Acousticness\": 0.176, \"Liveness\": 0.123, \"Tempo\": 175.946, \"Duration (ms)\": 231595.0, \"Valence\": 0.615, \"Chord\": \"G#/Ab\"}, {\"Index\": 253, \"Highest Charting Position\": 81, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"malibu\", \"Streams\": 4973063, \"Artist\": \"sangiovanni\", \"Artist Followers\": 384097.0, \"Song ID\": \"01hEpx8jnOG4q7nDK14Rhi\", \"Genre\": \"[]\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.733, \"Energy\": 0.736, \"Loudness\": -5.123, \"Speechiness\": 0.111, \"Acousticness\": 0.028, \"Liveness\": 0.131, \"Tempo\": 147.897, \"Duration (ms)\": 166216.0, \"Valence\": 0.669, \"Chord\": \"G\"}, {\"Index\": 254, \"Highest Charting Position\": 101, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Eladio Carrion: Bzrp Music Sessions, Vol. 40\", \"Streams\": 4965913, \"Artist\": \"Bizarrap, Eladio Carrion\", \"Artist Followers\": 3126961.0, \"Song ID\": \"1VauUM5CBX7nkLcgafQL2B\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2021-06-09\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 81.0, \"Danceability\": 0.783, \"Energy\": 0.524, \"Loudness\": -6.455, \"Speechiness\": 0.0554, \"Acousticness\": 0.241, \"Liveness\": 0.271, \"Tempo\": 117.496, \"Duration (ms)\": 164896.0, \"Valence\": 0.839, \"Chord\": \"F\"}, {\"Index\": 255, \"Highest Charting Position\": 117, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Do I Wanna Know?\", \"Streams\": 4938586, \"Artist\": \"Arctic Monkeys\", \"Artist Followers\": 12369079.0, \"Song ID\": \"5FVd6KXrgO9B3JPmC8OPst\", \"Genre\": \"['garage rock', 'permanent wave', 'rock', 'sheffield indie']\", \"Release Date\": \"2013-09-09\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 84.0, \"Danceability\": 0.548, \"Energy\": 0.532, \"Loudness\": -7.596, \"Speechiness\": 0.0323, \"Acousticness\": 0.186, \"Liveness\": 0.217, \"Tempo\": 85.03, \"Duration (ms)\": 272394.0, \"Valence\": 0.405, \"Chord\": \"F\"}, {\"Index\": 256, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"LUMBERJACK\", \"Streams\": 11756283, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"0BiK5BbYNFLb88CCOxBFJe\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 76.0, \"Danceability\": 0.386, \"Energy\": 0.762, \"Loudness\": -6.341, \"Speechiness\": 0.564, \"Acousticness\": 0.122, \"Liveness\": 0.527, \"Tempo\": 170.691, \"Duration (ms)\": 138312.0, \"Valence\": 0.433, \"Chord\": \"A\"}, {\"Index\": 257, \"Highest Charting Position\": 47, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"LEMONHEAD (feat. 42 Dugg)\", \"Streams\": 11380679, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"5fbHRCsGpFIOLRtlhCRFDR\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 78.0, \"Danceability\": 0.62, \"Energy\": 0.586, \"Loudness\": -6.612, \"Speechiness\": 0.212, \"Acousticness\": 0.155, \"Liveness\": 0.535, \"Tempo\": 137.131, \"Duration (ms)\": 130980.0, \"Valence\": 0.487, \"Chord\": \"C#/Db\"}, {\"Index\": 258, \"Highest Charting Position\": 59, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"HOT WIND BLOWS (feat. Lil Wayne)\", \"Streams\": 9889197, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"3JJL91ilRV6fXhKqu0FGXs\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 77.0, \"Danceability\": 0.371, \"Energy\": 0.75, \"Loudness\": -5.382, \"Speechiness\": 0.402, \"Acousticness\": 0.601, \"Liveness\": 0.482, \"Tempo\": 173.456, \"Duration (ms)\": 155293.0, \"Valence\": 0.729, \"Chord\": \"G\"}, {\"Index\": 259, \"Highest Charting Position\": 63, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"CORSO\", \"Streams\": 9503981, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"46oHvXwpEZOFX518we1nJD\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 77.0, \"Danceability\": 0.703, \"Energy\": 0.845, \"Loudness\": -4.851, \"Speechiness\": 0.337, \"Acousticness\": 0.169, \"Liveness\": 0.122, \"Tempo\": 97.672, \"Duration (ms)\": 146482.0, \"Valence\": 0.745, \"Chord\": \"A#/Bb\"}, {\"Index\": 260, \"Highest Charting Position\": 69, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"SWEET / I THOUGHT YOU WANTED TO DANCE (feat. Brent Faiyaz & Fana Hues)\", \"Streams\": 9142721, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"3EG9FJ0ToLfgnc1IG2Z1wz\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 79.0, \"Danceability\": 0.468, \"Energy\": 0.652, \"Loudness\": -4.912, \"Speechiness\": 0.0722, \"Acousticness\": 0.333, \"Liveness\": 0.55, \"Tempo\": 140.223, \"Duration (ms)\": 588139.0, \"Valence\": 0.39, \"Chord\": \"C\"}, {\"Index\": 261, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"SIR BAUDELAIRE (feat. DJ Drama)\", \"Streams\": 8884283, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"4ydmav4vl7hebadtfZtMrg\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 75.0, \"Danceability\": 0.467, \"Energy\": 0.635, \"Loudness\": -6.115, \"Speechiness\": 0.154, \"Acousticness\": 0.314, \"Liveness\": 0.844, \"Tempo\": 127.596, \"Duration (ms)\": 88625.0, \"Valence\": 0.51, \"Chord\": \"G\"}, {\"Index\": 262, \"Highest Charting Position\": 82, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"MASSA\", \"Streams\": 8218423, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"2goHCrsDJaflEwQ930ef0o\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 74.0, \"Danceability\": 0.685, \"Energy\": 0.855, \"Loudness\": -6.724, \"Speechiness\": 0.438, \"Acousticness\": 0.329, \"Liveness\": 0.301, \"Tempo\": 157.181, \"Duration (ms)\": 223719.0, \"Valence\": 0.46, \"Chord\": \"C#/Db\"}, {\"Index\": 263, \"Highest Charting Position\": 85, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"RUNITUP (feat. Teezo Touchdown)\", \"Streams\": 7917707, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"13HsOwrwTA5HgLuoaDHncP\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 75.0, \"Danceability\": 0.665, \"Energy\": 0.469, \"Loudness\": -7.778, \"Speechiness\": 0.13, \"Acousticness\": 0.565, \"Liveness\": 0.219, \"Tempo\": 115.852, \"Duration (ms)\": 229565.0, \"Valence\": 0.142, \"Chord\": \"A#/Bb\"}, {\"Index\": 264, \"Highest Charting Position\": 108, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"MANIFESTO (feat. Domo Genesis)\", \"Streams\": 6988886, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"6qouBO0wJtYc3k7DfKRUBx\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.454, \"Energy\": 0.866, \"Loudness\": -5.348, \"Speechiness\": 0.391, \"Acousticness\": 0.121, \"Liveness\": 0.167, \"Tempo\": 92.463, \"Duration (ms)\": 175123.0, \"Valence\": 0.518, \"Chord\": \"D\"}, {\"Index\": 265, \"Highest Charting Position\": 121, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Get Into It (Yuh)\", \"Streams\": 6503281, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0W6I02J9xcqK8MtSeosEXb\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 80.0, \"Danceability\": 0.912, \"Energy\": 0.655, \"Loudness\": -6.029, \"Speechiness\": 0.162, \"Acousticness\": 0.315, \"Liveness\": 0.0894, \"Tempo\": 91.942, \"Duration (ms)\": 138293.0, \"Valence\": 0.793, \"Chord\": \"G#/Ab\"}, {\"Index\": 266, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"WILSHIRE\", \"Streams\": 6268542, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"1pbbsI2KGPOMu0HmuGccBu\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.555, \"Energy\": 0.712, \"Loudness\": -7.446, \"Speechiness\": 0.323, \"Acousticness\": 0.0451, \"Liveness\": 0.182, \"Tempo\": 78.958, \"Duration (ms)\": 515865.0, \"Valence\": 0.555, \"Chord\": \"C#/Db\"}, {\"Index\": 267, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"RISE! (feat. DAISY WORLD)\", \"Streams\": 6034281, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"4Hta7Oy5W9HD0UgT1P8PPV\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.766, \"Energy\": 0.814, \"Loudness\": -3.367, \"Speechiness\": 0.0733, \"Acousticness\": 0.044, \"Liveness\": 0.195, \"Tempo\": 108.07, \"Duration (ms)\": 203588.0, \"Valence\": 0.481, \"Chord\": \"D\"}, {\"Index\": 268, \"Highest Charting Position\": 165, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Naked\", \"Streams\": 5527865, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0CsR9Y9SnC6ZWmekmVqSHz\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 75.0, \"Danceability\": 0.733, \"Energy\": 0.862, \"Loudness\": -5.736, \"Speechiness\": 0.197, \"Acousticness\": 0.374, \"Liveness\": 0.131, \"Tempo\": 111.076, \"Duration (ms)\": 223560.0, \"Valence\": 0.536, \"Chord\": \"G\"}, {\"Index\": 269, \"Highest Charting Position\": 50, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Having Our Way (feat. Drake)\", \"Streams\": 5424579, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"2NM0qHzx4Ohy8iXHEEgwlO\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 79.0, \"Danceability\": 0.927, \"Energy\": 0.538, \"Loudness\": -3.917, \"Speechiness\": 0.116, \"Acousticness\": 0.0312, \"Liveness\": 0.0945, \"Tempo\": 125.983, \"Duration (ms)\": 278191.0, \"Valence\": 0.221, \"Chord\": \"C#/Db\"}, {\"Index\": 270, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Payday (feat. Young Thug)\", \"Streams\": 5393789, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"2HolBGR6tpiWI80MXoV1dJ\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.619, \"Energy\": 0.707, \"Loudness\": -5.791, \"Speechiness\": 0.0499, \"Acousticness\": 0.0366, \"Liveness\": 0.13, \"Tempo\": 168.995, \"Duration (ms)\": 212947.0, \"Valence\": 0.558, \"Chord\": \"C#/Db\"}, {\"Index\": 271, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Been Like This\", \"Streams\": 5362817, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"7y3xU9vEC1s8DSuuoSYKih\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 74.0, \"Danceability\": 0.678, \"Energy\": 0.531, \"Loudness\": -5.029, \"Speechiness\": 0.0374, \"Acousticness\": 0.126, \"Liveness\": 0.377, \"Tempo\": 99.008, \"Duration (ms)\": 177373.0, \"Valence\": 0.176, \"Chord\": \"A#/Bb\"}, {\"Index\": 272, \"Highest Charting Position\": 138, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"MILLE (feat. Orietta Berti)\", \"Streams\": 5341887, \"Artist\": \"Fedez, Achille Lauro\", \"Artist Followers\": 1650683.0, \"Song ID\": \"6qdMhG7pRFi0csRlFGvLE4\", \"Genre\": \"['italian adult pop', 'italian pop']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 82.0, \"Danceability\": 0.527, \"Energy\": 0.764, \"Loudness\": -4.297, \"Speechiness\": 0.322, \"Acousticness\": 0.016, \"Liveness\": 0.0273, \"Tempo\": 184.339, \"Duration (ms)\": 175924.0, \"Valence\": 0.829, \"Chord\": \"D\"}, {\"Index\": 273, \"Highest Charting Position\": 10, \"Number of Times Charted\": 49, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"UN DIA (ONE DAY) (Feat. Tainy)\", \"Streams\": 5203364, \"Artist\": \"J Balvin, Dua Lipa, Bad Bunny\", \"Artist Followers\": 29051363.0, \"Song ID\": \"0EhpEsp4L0oRGM0vmeaN5e\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 83.0, \"Danceability\": 0.571, \"Energy\": 0.693, \"Loudness\": -8.234, \"Speechiness\": 0.0545, \"Acousticness\": 0.00536, \"Liveness\": 0.173, \"Tempo\": 168.169, \"Duration (ms)\": 232253.0, \"Valence\": 0.393, \"Chord\": \"F#/Gb\"}, {\"Index\": 274, \"Highest Charting Position\": 1, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Savage Love (Laxed - Siren Beat)\", \"Streams\": 5108950, \"Artist\": \"Jawsh 685, Jason Derulo\", \"Artist Followers\": 100604.0, \"Song ID\": \"1xQ6trAsedVPCdbtDAmk0c\", \"Genre\": \"['nz pop']\", \"Release Date\": \"2020-06-11\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 82.0, \"Danceability\": 0.767, \"Energy\": 0.481, \"Loudness\": -8.52, \"Speechiness\": 0.0803, \"Acousticness\": 0.234, \"Liveness\": 0.269, \"Tempo\": 150.076, \"Duration (ms)\": 171375.0, \"Valence\": 0.761, \"Chord\": \"C\"}, {\"Index\": 275, \"Highest Charting Position\": 59, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Poblado\", \"Streams\": 6893939, \"Artist\": \"Crissin, Totoy El Frio, Natan & Shander\", \"Artist Followers\": 29051363.0, \"Song ID\": \"1WedZeiezCmCEOzLwhx0hV\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 89.0, \"Danceability\": 0.813, \"Energy\": 0.809, \"Loudness\": -5.382, \"Speechiness\": 0.0846, \"Acousticness\": 0.102, \"Liveness\": 0.377, \"Tempo\": 93.005, \"Duration (ms)\": 393280.0, \"Valence\": 0.646, \"Chord\": \"D#/Eb\"}, {\"Index\": 276, \"Highest Charting Position\": 17, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Hecha Pa' Mi\", \"Streams\": 6308369, \"Artist\": \"Boza\", \"Artist Followers\": 278679.0, \"Song ID\": \"3VvA1wSxukMLsvXoXtlwWx\", \"Genre\": \"['reggaeton']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 83.0, \"Danceability\": 0.725, \"Energy\": 0.756, \"Loudness\": -5.013, \"Speechiness\": 0.0572, \"Acousticness\": 0.362, \"Liveness\": 0.103, \"Tempo\": 100.07, \"Duration (ms)\": 186133.0, \"Valence\": 0.828, \"Chord\": \"E\"}, {\"Index\": 277, \"Highest Charting Position\": 146, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"working\", \"Streams\": 5666770, \"Artist\": \"Tate McRae, Khalid\", \"Artist Followers\": 1647262.0, \"Song ID\": \"31sSFHIe4NaxltVFOEIcTa\", \"Genre\": \"['alt z', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-06-17\", \"Weeks Charted\": \"2021-06-18--2021-06-25\", \"Popularity\": 80.0, \"Danceability\": 0.783, \"Energy\": 0.435, \"Loudness\": -7.78, \"Speechiness\": 0.0588, \"Acousticness\": 0.282, \"Liveness\": 0.0833, \"Tempo\": 106.974, \"Duration (ms)\": 210220.0, \"Valence\": 0.512, \"Chord\": \"G\"}, {\"Index\": 278, \"Highest Charting Position\": 112, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Petrouchka (feat. PLK)\", \"Streams\": 5511544, \"Artist\": \"Soso Maness\", \"Artist Followers\": 289437.0, \"Song ID\": \"03y045SZqaC94yfXl1cU4E\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais', 'rap marseille']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 79.0, \"Danceability\": 0.624, \"Energy\": 0.802, \"Loudness\": -4.818, \"Speechiness\": 0.311, \"Acousticness\": 0.0597, \"Liveness\": 0.252, \"Tempo\": 133.888, \"Duration (ms)\": 189933.0, \"Valence\": 0.818, \"Chord\": \"F#/Gb\"}, {\"Index\": 279, \"Highest Charting Position\": 11, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"p r i d e . i s . t h e . d e v i l (with Lil Baby)\", \"Streams\": 5430260, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5W8jRrZ6tWrTrqnKRtIQBf\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.861, \"Energy\": 0.656, \"Loudness\": -7.867, \"Speechiness\": 0.425, \"Acousticness\": 0.104, \"Liveness\": 0.0986, \"Tempo\": 88.967, \"Duration (ms)\": 218210.0, \"Valence\": 0.331, \"Chord\": \"E\"}, {\"Index\": 280, \"Highest Charting Position\": 6, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"m y . l i f e (with 21 Savage & Morray)\", \"Streams\": 5246577, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"1D3z6HTiQsNmZxjl7F7eoG\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.597, \"Energy\": 0.587, \"Loudness\": -7.026, \"Speechiness\": 0.137, \"Acousticness\": 0.0622, \"Liveness\": 0.214, \"Tempo\": 140.021, \"Duration (ms)\": 218802.0, \"Valence\": 0.0753, \"Chord\": \"G\"}, {\"Index\": 281, \"Highest Charting Position\": 96, \"Number of Times Charted\": 77, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Jocelyn Flores\", \"Streams\": 5220422, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29539807.0, \"Song ID\": \"7m9OqQk4RVRkw9JJdeAw96\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2017-08-25\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.872, \"Energy\": 0.391, \"Loudness\": -9.144, \"Speechiness\": 0.242, \"Acousticness\": 0.469, \"Liveness\": 0.297, \"Tempo\": 134.021, \"Duration (ms)\": 119133.0, \"Valence\": 0.437, \"Chord\": \"C\"}, {\"Index\": 282, \"Highest Charting Position\": 66, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"No Return (with The Kid LAROI & Lil Durk)\", \"Streams\": 5189427, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"23OYT3SFtoJqhiAUqktbc1\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 80.0, \"Danceability\": 0.479, \"Energy\": 0.645, \"Loudness\": -7.336, \"Speechiness\": 0.302, \"Acousticness\": 0.135, \"Liveness\": 0.0825, \"Tempo\": 155.057, \"Duration (ms)\": 168729.0, \"Valence\": 0.381, \"Chord\": \"F\"}, {\"Index\": 283, \"Highest Charting Position\": 1, \"Number of Times Charted\": 78, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"The Box\", \"Streams\": 5145099, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6603627.0, \"Song ID\": \"0nbXyq5TXYPCO7pr3N8S4I\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.896, \"Energy\": 0.586, \"Loudness\": -6.687, \"Speechiness\": 0.0559, \"Acousticness\": 0.104, \"Liveness\": 0.79, \"Tempo\": 116.971, \"Duration (ms)\": 196653.0, \"Valence\": 0.642, \"Chord\": \"A#/Bb\"}, {\"Index\": 284, \"Highest Charting Position\": 31, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Wellerman - Sea Shanty / 220 KID x Billen Ted Remix\", \"Streams\": 5124606, \"Artist\": \"Nathan Evans\", \"Artist Followers\": 140812.0, \"Song ID\": \"3iw6V4LH7yPj1ESORX9RIN\", \"Genre\": \"[]\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 83.0, \"Danceability\": 0.722, \"Energy\": 0.893, \"Loudness\": -3.255, \"Speechiness\": 0.0475, \"Acousticness\": 0.0441, \"Liveness\": 0.0673, \"Tempo\": 119.932, \"Duration (ms)\": 116750.0, \"Valence\": 0.439, \"Chord\": \"C\"}, {\"Index\": 285, \"Highest Charting Position\": 170, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Can't Hold Us - feat. Ray Dalton\", \"Streams\": 5085147, \"Artist\": \"Macklemore & Ryan Lewis\", \"Artist Followers\": 2562082.0, \"Song ID\": \"3bidbhpOYeV4knp8AIu8Xn\", \"Genre\": \"['modern rock', 'pop rap', 'seattle hip hop']\", \"Release Date\": \"2012-10-09\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.641, \"Energy\": 0.922, \"Loudness\": -4.457, \"Speechiness\": 0.0786, \"Acousticness\": 0.0291, \"Liveness\": 0.0862, \"Tempo\": 146.078, \"Duration (ms)\": 258343.0, \"Valence\": 0.847, \"Chord\": \"D\"}, {\"Index\": 286, \"Highest Charting Position\": 6, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Anyone\", \"Streams\": 5079587, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 1250353.0, \"Song ID\": \"2RwMwWo43LapkA4raptxaB\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-01-31--2020-02-07\", \"Popularity\": 0.0, \"Danceability\": 0.686, \"Energy\": 0.538, \"Loudness\": -8.026, \"Speechiness\": 0.0345, \"Acousticness\": 0.181, \"Liveness\": 0.113, \"Tempo\": 115.884, \"Duration (ms)\": 190779.0, \"Valence\": 0.584, \"Chord\": \"D\"}, {\"Index\": 287, \"Highest Charting Position\": 39, \"Number of Times Charted\": 45, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"my ex's best friend (with blackbear)\", \"Streams\": 5048079, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3864419.0, \"Song ID\": \"7kDUspsoYfLkWnZR7qwHZl\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 83.0, \"Danceability\": 0.731, \"Energy\": 0.675, \"Loudness\": -5.134, \"Speechiness\": 0.0434, \"Acousticness\": 0.00473, \"Liveness\": 0.141, \"Tempo\": 124.939, \"Duration (ms)\": 139461.0, \"Valence\": 0.298, \"Chord\": \"F\"}, {\"Index\": 288, \"Highest Charting Position\": 133, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Just the Way You Are\", \"Streams\": 5043647, \"Artist\": \"Bruno Mars\", \"Artist Followers\": 32574754.0, \"Song ID\": \"7BqBn9nzAq8spo5e7cZ0dJ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2010-10-05\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 80.0, \"Danceability\": 0.637, \"Energy\": 0.843, \"Loudness\": -5.413, \"Speechiness\": 0.0432, \"Acousticness\": 0.0151, \"Liveness\": 0.0876, \"Tempo\": 109.012, \"Duration (ms)\": 220733.0, \"Valence\": 0.434, \"Chord\": \"F\"}, {\"Index\": 289, \"Highest Charting Position\": 17, \"Number of Times Charted\": 78, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"HIGHEST IN THE ROOM\", \"Streams\": 4975720, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17719446.0, \"Song ID\": \"3eekarcy7kvN4yt5ZFzltW\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.598, \"Energy\": 0.427, \"Loudness\": -8.764, \"Speechiness\": 0.0317, \"Acousticness\": 0.0546, \"Liveness\": 0.21, \"Tempo\": 76.469, \"Duration (ms)\": 175721.0, \"Valence\": 0.0605, \"Chord\": \"G\"}, {\"Index\": 290, \"Highest Charting Position\": 7, \"Number of Times Charted\": 65, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Break My Heart\", \"Streams\": 4971176, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"017PF4Q3l4DBUiWoXk4OWT\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 80.0, \"Danceability\": 0.73, \"Energy\": 0.729, \"Loudness\": -3.434, \"Speechiness\": 0.0884, \"Acousticness\": 0.167, \"Liveness\": 0.349, \"Tempo\": 113.011, \"Duration (ms)\": 221820.0, \"Valence\": 0.467, \"Chord\": \"E\"}, {\"Index\": 291, \"Highest Charting Position\": 2, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Laugh Now Cry Later (feat. Lil Durk)\", \"Streams\": 4916860, \"Artist\": \"Drake\", \"Artist Followers\": 56308172.0, \"Song ID\": \"2SAqBLGA283SUiwJ3xOUVI\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 83.0, \"Danceability\": 0.761, \"Energy\": 0.518, \"Loudness\": -8.871, \"Speechiness\": 0.134, \"Acousticness\": 0.244, \"Liveness\": 0.107, \"Tempo\": 133.976, \"Duration (ms)\": 261493.0, \"Valence\": 0.522, \"Chord\": \"C\"}, {\"Index\": 292, \"Highest Charting Position\": 175, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"We Are The People (feat. Bono & The Edge) - Official UEFA EURO 2020 Song\", \"Streams\": 4912036, \"Artist\": \"Martin Garrix\", \"Artist Followers\": 14917926.0, \"Song ID\": \"2iL0W5qi0ivZ9WRXbZ74cS\", \"Genre\": \"['dance pop', 'dutch edm', 'edm', 'pop', 'pop dance', 'progressive house', 'tropical house']\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.66, \"Energy\": 0.733, \"Loudness\": -4.619, \"Speechiness\": 0.0359, \"Acousticness\": 0.248, \"Liveness\": 0.17, \"Tempo\": 119.933, \"Duration (ms)\": 217000.0, \"Valence\": 0.304, \"Chord\": \"C\"}, {\"Index\": 293, \"Highest Charting Position\": 23, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Ella No Es Tuya - Remix\", \"Streams\": 4911162, \"Artist\": \"Rochy RD, Myke Towers, Nicki Nicole\", \"Artist Followers\": 319192.0, \"Song ID\": \"5YYW3yRktprLRr47WK219Y\", \"Genre\": \"['dembow', 'dominican pop', 'rap dominicano', 'trap latino']\", \"Release Date\": \"2021-02-03\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 82.0, \"Danceability\": 0.585, \"Energy\": 0.611, \"Loudness\": -4.132, \"Speechiness\": 0.288, \"Acousticness\": 0.39, \"Liveness\": 0.649, \"Tempo\": 97.041, \"Duration (ms)\": 218107.0, \"Valence\": 0.962, \"Chord\": \"F#/Gb\"}, {\"Index\": 294, \"Highest Charting Position\": 176, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"In the End\", \"Streams\": 4910070, \"Artist\": \"Linkin Park\", \"Artist Followers\": 19584111.0, \"Song ID\": \"60a0Rd6pjrkxjPbaKzXjfq\", \"Genre\": \"['alternative metal', 'nu metal', 'post-grunge', 'rap metal']\", \"Release Date\": \"2000-10-24\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-03-19--2021-03-26\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 83.0, \"Danceability\": 0.556, \"Energy\": 0.864, \"Loudness\": -5.87, \"Speechiness\": 0.0584, \"Acousticness\": 0.00958, \"Liveness\": 0.209, \"Tempo\": 105.143, \"Duration (ms)\": 216880.0, \"Valence\": 0.4, \"Chord\": \"D#/Eb\"}, {\"Index\": 295, \"Highest Charting Position\": 119, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"No Role Modelz\", \"Streams\": 4904401, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"62vpWI1CHwFy7tMIcSStl8\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2014-12-09\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 84.0, \"Danceability\": 0.692, \"Energy\": 0.521, \"Loudness\": -8.465, \"Speechiness\": 0.33, \"Acousticness\": 0.301, \"Liveness\": 0.0565, \"Tempo\": 100.45, \"Duration (ms)\": 292987.0, \"Valence\": 0.463, \"Chord\": \"A#/Bb\"}, {\"Index\": 296, \"Highest Charting Position\": 7, \"Number of Times Charted\": 74, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"SICKO MODE\", \"Streams\": 4898977, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17719446.0, \"Song ID\": \"2xLMifQCjDGFmkHkpNLD9h\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2018-08-03\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.834, \"Energy\": 0.73, \"Loudness\": -3.714, \"Speechiness\": 0.222, \"Acousticness\": 0.00513, \"Liveness\": 0.124, \"Tempo\": 155.008, \"Duration (ms)\": 312820.0, \"Valence\": 0.446, \"Chord\": \"G#/Ab\"}, {\"Index\": 297, \"Highest Charting Position\": 161, \"Number of Times Charted\": 41, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Something Just Like This\", \"Streams\": 4862683, \"Artist\": \"The Chainsmokers, Coldplay\", \"Artist Followers\": 18191658.0, \"Song ID\": \"6RUKPb4LETWmmr3iAEQktW\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2017-04-07\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-02-26--2021-03-05\\n2021-01-01--2021-01-08\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.617, \"Energy\": 0.635, \"Loudness\": -6.769, \"Speechiness\": 0.0317, \"Acousticness\": 0.0498, \"Liveness\": 0.164, \"Tempo\": 103.019, \"Duration (ms)\": 247160.0, \"Valence\": 0.446, \"Chord\": \"B\"}, {\"Index\": 298, \"Highest Charting Position\": 84, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"You\", \"Streams\": 4846549, \"Artist\": \"Regard, Troye Sivan, Tate McRae\", \"Artist Followers\": 152226.0, \"Song ID\": \"2cc8Sw1OnCuA5bV8nqWqpE\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop edm', 'slap house', 'tropical house']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 83.0, \"Danceability\": 0.691, \"Energy\": 0.695, \"Loudness\": -5.6, \"Speechiness\": 0.0367, \"Acousticness\": 0.0592, \"Liveness\": 0.0647, \"Tempo\": 106.064, \"Duration (ms)\": 233386.0, \"Valence\": 0.514, \"Chord\": \"C\"}, {\"Index\": 299, \"Highest Charting Position\": 84, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Straightenin\", \"Streams\": 7615531, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"3X2r2CnHOJeV5YekPTgBnK\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 77.0, \"Danceability\": 0.847, \"Energy\": 0.629, \"Loudness\": -5.81, \"Speechiness\": 0.102, \"Acousticness\": 0.0318, \"Liveness\": 0.152, \"Tempo\": 135.976, \"Duration (ms)\": 255532.0, \"Valence\": 0.109, \"Chord\": \"A\"}, {\"Index\": 300, \"Highest Charting Position\": 71, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"GANG GANG (with Lil Wayne)\", \"Streams\": 7506580, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"4VW44pawoOHPUjlN7DX5vk\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 78.0, \"Danceability\": 0.752, \"Energy\": 0.563, \"Loudness\": -8.066, \"Speechiness\": 0.209, \"Acousticness\": 0.146, \"Liveness\": 0.103, \"Tempo\": 145.05, \"Duration (ms)\": 178776.0, \"Valence\": 0.551, \"Chord\": \"D#/Eb\"}, {\"Index\": 301, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Black Hearted\", \"Streams\": 6989528, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"25qk9xa71F1POdI4vj7rbi\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 75.0, \"Danceability\": 0.506, \"Energy\": 0.563, \"Loudness\": -7.664, \"Speechiness\": 0.411, \"Acousticness\": 0.0326, \"Liveness\": 0.0856, \"Tempo\": 168.146, \"Duration (ms)\": 190509.0, \"Valence\": 0.153, \"Chord\": \"C#/Db\"}, {\"Index\": 302, \"Highest Charting Position\": 124, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Lost\", \"Streams\": 6410263, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32262679.0, \"Song ID\": \"18XlJEroUwFo0tLZxscgXE\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 79.0, \"Danceability\": 0.766, \"Energy\": 0.706, \"Loudness\": -6.553, \"Speechiness\": 0.16, \"Acousticness\": 0.223, \"Liveness\": 0.064, \"Tempo\": 142.989, \"Duration (ms)\": 172598.0, \"Valence\": 0.766, \"Chord\": \"G\"}, {\"Index\": 303, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Avalanche\", \"Streams\": 6323268, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"4KD0lLJ4OGonZhBeKtct9I\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 71.0, \"Danceability\": 0.917, \"Energy\": 0.623, \"Loudness\": -8.231, \"Speechiness\": 0.135, \"Acousticness\": 0.0985, \"Liveness\": 0.0833, \"Tempo\": 126.063, \"Duration (ms)\": 206272.0, \"Valence\": 0.687, \"Chord\": \"C#/Db\"}, {\"Index\": 304, \"Highest Charting Position\": 59, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"My Head & My Heart\", \"Streams\": 5470147, \"Artist\": \"Ava Max\", \"Artist Followers\": 3911473.0, \"Song ID\": \"1KixkQVDUHggZMU9dUobgm\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 83.0, \"Danceability\": 0.614, \"Energy\": 0.934, \"Loudness\": -3.709, \"Speechiness\": 0.07, \"Acousticness\": 0.0697, \"Liveness\": 0.121, \"Tempo\": 116.001, \"Duration (ms)\": 174760.0, \"Valence\": 0.436, \"Chord\": \"A\"}, {\"Index\": 305, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Malibu (feat. Polo G)\", \"Streams\": 5456648, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"3v1zVVdzNVNt7vmI9VG2gq\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 72.0, \"Danceability\": 0.831, \"Energy\": 0.719, \"Loudness\": -6.836, \"Speechiness\": 0.235, \"Acousticness\": 0.514, \"Liveness\": 0.0675, \"Tempo\": 155.038, \"Duration (ms)\": 248652.0, \"Valence\": 0.859, \"Chord\": \"A#/Bb\"}, {\"Index\": 306, \"Highest Charting Position\": 36, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"GIRL LIKE ME\", \"Streams\": 5395181, \"Artist\": \"Black Eyed Peas, Shakira\", \"Artist Followers\": 5963840.0, \"Song ID\": \"1zLBsSVxETQOfINOLYvT5m\", \"Genre\": \"['dance pop', 'pop', 'pop rap']\", \"Release Date\": \"2020-11-02\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\", \"Popularity\": 82.0, \"Danceability\": 0.965, \"Energy\": 0.485, \"Loudness\": -8.784, \"Speechiness\": 0.191, \"Acousticness\": 0.0206, \"Liveness\": 0.0655, \"Tempo\": 124.025, \"Duration (ms)\": 222523.0, \"Valence\": 0.312, \"Chord\": \"D\"}, {\"Index\": 307, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Clueless (with Pop Smoke & Fivio Foreign)\", \"Streams\": 5335308, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"4CPcZHzSvIBM8AKhdHUwnL\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 74.0, \"Danceability\": 0.734, \"Energy\": 0.712, \"Loudness\": -6.217, \"Speechiness\": 0.201, \"Acousticness\": 0.391, \"Liveness\": 0.103, \"Tempo\": 140.369, \"Duration (ms)\": 165405.0, \"Valence\": 0.674, \"Chord\": \"F#/Gb\"}, {\"Index\": 308, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Modern Day\", \"Streams\": 5322745, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"2Igem6Q4sfvXGJ3JkG7Baw\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 78.0, \"Danceability\": 0.87, \"Energy\": 0.629, \"Loudness\": -7.598, \"Speechiness\": 0.279, \"Acousticness\": 0.173, \"Liveness\": 0.101, \"Tempo\": 134.944, \"Duration (ms)\": 241790.0, \"Valence\": 0.512, \"Chord\": \"B\"}, {\"Index\": 309, \"Highest Charting Position\": 2, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Therefore I Am\", \"Streams\": 5265630, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"0aACcc1jEv2C6VSmmJbllJ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 0.0, \"Danceability\": 0.889, \"Energy\": 0.34, \"Loudness\": -7.773, \"Speechiness\": 0.0697, \"Acousticness\": 0.218, \"Liveness\": 0.055, \"Tempo\": 94.009, \"Duration (ms)\": 174321.0, \"Valence\": 0.716, \"Chord\": \"B\"}, {\"Index\": 310, \"Highest Charting Position\": 12, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"TE MUDASTE\", \"Streams\": 5242347, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36142273.0, \"Song ID\": \"5RubKOuDoPn5Kj5TLVxSxY\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 82.0, \"Danceability\": 0.811, \"Energy\": 0.637, \"Loudness\": -4.835, \"Speechiness\": 0.0591, \"Acousticness\": 0.234, \"Liveness\": 0.118, \"Tempo\": 92.025, \"Duration (ms)\": 130014.0, \"Valence\": 0.471, \"Chord\": \"A#/Bb\"}, {\"Index\": 311, \"Highest Charting Position\": 108, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Tipo Gin - Ao Vivo\", \"Streams\": 5155238, \"Artist\": \"MC Kevin o Chris\", \"Artist Followers\": 2753929.0, \"Song ID\": \"4llr8mcoauwrHBtjGb7F9S\", \"Genre\": \"['funk 150 bpm', 'funk carioca']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 81.0, \"Danceability\": 0.75, \"Energy\": 0.668, \"Loudness\": -4.49, \"Speechiness\": 0.061, \"Acousticness\": 0.78, \"Liveness\": 0.338, \"Tempo\": 94.998, \"Duration (ms)\": 159147.0, \"Valence\": 0.786, \"Chord\": \"C\"}, {\"Index\": 312, \"Highest Charting Position\": 39, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Higher Power\", \"Streams\": 5142982, \"Artist\": \"Coldplay\", \"Artist Followers\": 1250353.0, \"Song ID\": \"4rOEoKL0fHrxBMhVljpbGW\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 0.0, \"Danceability\": 0.507, \"Energy\": 0.828, \"Loudness\": -6.023, \"Speechiness\": 0.0449, \"Acousticness\": 0.00711, \"Liveness\": 0.261, \"Tempo\": 178.032, \"Duration (ms)\": 211295.0, \"Valence\": 0.489, \"Chord\": \"A#/Bb\"}, {\"Index\": 313, \"Highest Charting Position\": 54, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"SUN GOES DOWN\", \"Streams\": 5125477, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5473565.0, \"Song ID\": \"34eF4BoV8FPk0uhAAoqU7h\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 80.0, \"Danceability\": 0.551, \"Energy\": 0.636, \"Loudness\": -6.798, \"Speechiness\": 0.054, \"Acousticness\": 0.0837, \"Liveness\": 0.112, \"Tempo\": 174.065, \"Duration (ms)\": 168276.0, \"Valence\": 0.148, \"Chord\": \"D\"}, {\"Index\": 314, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Painting Pictures\", \"Streams\": 5119845, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"25uBGaikHi0DhMiGMfuXYE\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 72.0, \"Danceability\": 0.522, \"Energy\": 0.466, \"Loudness\": -8.05, \"Speechiness\": 0.458, \"Acousticness\": 0.331, \"Liveness\": 0.11, \"Tempo\": 78.43, \"Duration (ms)\": 137692.0, \"Valence\": 0.459, \"Chord\": \"D#/Eb\"}, {\"Index\": 315, \"Highest Charting Position\": 1, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Rain On Me (with Ariana Grande)\", \"Streams\": 5041656, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18572085.0, \"Song ID\": \"24ySl2hOPGCDcxBxFIqWBu\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 79.0, \"Danceability\": 0.672, \"Energy\": 0.855, \"Loudness\": -3.764, \"Speechiness\": 0.0397, \"Acousticness\": 0.021, \"Liveness\": 0.323, \"Tempo\": 123.056, \"Duration (ms)\": 182200.0, \"Valence\": 0.646, \"Chord\": \"A\"}, {\"Index\": 316, \"Highest Charting Position\": 97, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Hats Off (feat. Travis Scott)\", \"Streams\": 7324233, \"Artist\": \"Lil Baby, Lil Durk\", \"Artist Followers\": 7805880.0, \"Song ID\": \"4lUmnwRybYH7mMzf16xB0y\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-06-04--2021-06-11\", \"Popularity\": 81.0, \"Danceability\": 0.596, \"Energy\": 0.65, \"Loudness\": -5.167, \"Speechiness\": 0.337, \"Acousticness\": 0.138, \"Liveness\": 0.14, \"Tempo\": 133.997, \"Duration (ms)\": 257428.0, \"Valence\": 0.188, \"Chord\": \"A\"}, {\"Index\": 317, \"Highest Charting Position\": 117, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Last Train Home\", \"Streams\": 6439718, \"Artist\": \"John Mayer\", \"Artist Followers\": 5178156.0, \"Song ID\": \"0tgBtQ0ISnMQOKorrN9HLX\", \"Genre\": \"['neo mellow', 'pop rock', 'singer-songwriter']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-06-04--2021-06-11\", \"Popularity\": 75.0, \"Danceability\": 0.591, \"Energy\": 0.831, \"Loudness\": -6.612, \"Speechiness\": 0.0355, \"Acousticness\": 0.235, \"Liveness\": 0.0571, \"Tempo\": 93.007, \"Duration (ms)\": 187307.0, \"Valence\": 0.678, \"Chord\": \"E\"}, {\"Index\": 318, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Voice of the Heroes\", \"Streams\": 6249801, \"Artist\": \"Lil Baby, Lil Durk\", \"Artist Followers\": 7805880.0, \"Song ID\": \"4lUmnwRybYH7mMzf16xB0y\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-06-04--2021-06-11\", \"Popularity\": 81.0, \"Danceability\": 0.596, \"Energy\": 0.65, \"Loudness\": -5.167, \"Speechiness\": 0.337, \"Acousticness\": 0.138, \"Liveness\": 0.14, \"Tempo\": 133.997, \"Duration (ms)\": 257428.0, \"Valence\": 0.188, \"Chord\": \"A\"}, {\"Index\": 319, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"0X1=LOVESONG (I Know I Love you)\", \"Streams\": 6040553, \"Artist\": \"TOMORROW X TOGETHER, Seori\", \"Artist Followers\": 4136553.0, \"Song ID\": \"1Z8TPHiKeCUyClxV6WTTIf\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-05-31\", \"Weeks Charted\": \"2021-06-04--2021-06-11\", \"Popularity\": 81.0, \"Danceability\": 0.584, \"Energy\": 0.836, \"Loudness\": -4.925, \"Speechiness\": 0.079, \"Acousticness\": 0.0558, \"Liveness\": 0.0663, \"Tempo\": 104.973, \"Duration (ms)\": 202204.0, \"Valence\": 0.484, \"Chord\": \"C\"}, {\"Index\": 320, \"Highest Charting Position\": 10, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"a m a r i\", \"Streams\": 5645966, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"2cnKST6T9qUo2i907lm8zX\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 79.0, \"Danceability\": 0.725, \"Energy\": 0.713, \"Loudness\": -6.173, \"Speechiness\": 0.187, \"Acousticness\": 0.127, \"Liveness\": 0.617, \"Tempo\": 65.988, \"Duration (ms)\": 148421.0, \"Valence\": 0.207, \"Chord\": \"E\"}, {\"Index\": 321, \"Highest Charting Position\": 72, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"NEVER LEFT\", \"Streams\": 5552212, \"Artist\": \"Lil Tecca\", \"Artist Followers\": 4016497.0, \"Song ID\": \"21UkXrc9kD48rNpTMI2ecz\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2021-05-06\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 82.0, \"Danceability\": 0.807, \"Energy\": 0.659, \"Loudness\": -6.92, \"Speechiness\": 0.332, \"Acousticness\": 0.0224, \"Liveness\": 0.309, \"Tempo\": 82.465, \"Duration (ms)\": 168727.0, \"Valence\": 0.438, \"Chord\": \"B\"}, {\"Index\": 322, \"Highest Charting Position\": 27, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Solid (feat. Drake)\", \"Streams\": 5347781, \"Artist\": \"Young Stoner Life, Young Thug, Gunna\", \"Artist Followers\": 61930.0, \"Song ID\": \"6rTInqW3YECMkQsBEHw4sd\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 82.0, \"Danceability\": 0.887, \"Energy\": 0.485, \"Loudness\": -9.358, \"Speechiness\": 0.2, \"Acousticness\": 0.0392, \"Liveness\": 0.141, \"Tempo\": 125.987, \"Duration (ms)\": 215693.0, \"Valence\": 0.328, \"Chord\": \"B\"}, {\"Index\": 323, \"Highest Charting Position\": 21, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"La Nota\", \"Streams\": 5300884, \"Artist\": \"Manuel Turizo, Rauw Alejandro, Myke Towers\", \"Artist Followers\": 7904381.0, \"Song ID\": \"7ndTONDDRFGiPnnhOzOXxq\", \"Genre\": \"['colombian pop', 'latin', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2020-10-08\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 79.0, \"Danceability\": 0.736, \"Energy\": 0.632, \"Loudness\": -4.939, \"Speechiness\": 0.0648, \"Acousticness\": 0.18, \"Liveness\": 0.349, \"Tempo\": 92.03, \"Duration (ms)\": 216107.0, \"Valence\": 0.503, \"Chord\": \"B\"}, {\"Index\": 324, \"Highest Charting Position\": 47, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Golden\", \"Streams\": 5298893, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16112621.0, \"Song ID\": \"45S5WTQEGOB1VHr1Q4FuPl\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 83.0, \"Danceability\": 0.448, \"Energy\": 0.838, \"Loudness\": -5.257, \"Speechiness\": 0.0557, \"Acousticness\": 0.21, \"Liveness\": 0.131, \"Tempo\": 139.863, \"Duration (ms)\": 208907.0, \"Valence\": 0.254, \"Chord\": \"E\"}, {\"Index\": 325, \"Highest Charting Position\": 127, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"CORALINE\", \"Streams\": 5241813, \"Artist\": \"M\\u00e5neskin\", \"Artist Followers\": 3377762.0, \"Song ID\": \"7HMz8o0m7ASQ3ImFPfhWTY\", \"Genre\": \"['indie rock italiano', 'italian pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\", \"Popularity\": 81.0, \"Danceability\": 0.363, \"Energy\": 0.678, \"Loudness\": -4.939, \"Speechiness\": 0.0995, \"Acousticness\": 0.0299, \"Liveness\": 0.324, \"Tempo\": 162.124, \"Duration (ms)\": 300413.0, \"Valence\": 0.321, \"Chord\": \"D\"}, {\"Index\": 326, \"Highest Charting Position\": 3, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"BICHOTA\", \"Streams\": 5201714, \"Artist\": \"KAROL G\", \"Artist Followers\": 1250353.0, \"Song ID\": \"4nYLZSNXJyPq8Jj3cEdykP\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 0.0, \"Danceability\": 0.863, \"Energy\": 0.666, \"Loudness\": -4.158, \"Speechiness\": 0.152, \"Acousticness\": 0.212, \"Liveness\": 0.103, \"Tempo\": 163.908, \"Duration (ms)\": 178947.0, \"Valence\": 0.838, \"Chord\": \"C#/Db\"}, {\"Index\": 327, \"Highest Charting Position\": 96, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Slumber Party (feat. Princess Nokia)\", \"Streams\": 5113574, \"Artist\": \"Ashnikko\", \"Artist Followers\": 1246335.0, \"Song ID\": \"11ZulcYY4lowvcQm4oe3VJ\", \"Genre\": \"['electropop', 'escape room', 'pop']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 82.0, \"Danceability\": 0.964, \"Energy\": 0.398, \"Loudness\": -8.981, \"Speechiness\": 0.0795, \"Acousticness\": 0.00151, \"Liveness\": 0.101, \"Tempo\": 105.012, \"Duration (ms)\": 178405.0, \"Valence\": 0.563, \"Chord\": \"B\"}, {\"Index\": 328, \"Highest Charting Position\": 170, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Killer (feat. Jack Harlow & Cordae) - Remix\", \"Streams\": 5404939, \"Artist\": \"Eminem\", \"Artist Followers\": 46785561.0, \"Song ID\": \"7zl7kehxesNEo2pYkKXTSe\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-05-28--2021-06-04\", \"Popularity\": 76.0, \"Danceability\": 0.924, \"Energy\": 0.73, \"Loudness\": -6.125, \"Speechiness\": 0.274, \"Acousticness\": 0.0525, \"Liveness\": 0.113, \"Tempo\": 99.01, \"Duration (ms)\": 236666.0, \"Valence\": 0.848, \"Chord\": \"B\"}, {\"Index\": 329, \"Highest Charting Position\": 105, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Liberdade (Quando o Grave Bate Forte)\", \"Streams\": 5378350, \"Artist\": \"Alok, Mc Don Juan, Dj GBR\", \"Artist Followers\": 10334543.0, \"Song ID\": \"2QLbRVzixE282JSQjBz2DG\", \"Genre\": \"['electro house', 'pop nacional', 'slap house']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 80.0, \"Danceability\": 0.81, \"Energy\": 0.789, \"Loudness\": -4.032, \"Speechiness\": 0.0498, \"Acousticness\": 0.0254, \"Liveness\": 0.104, \"Tempo\": 129.988, \"Duration (ms)\": 150462.0, \"Valence\": 0.432, \"Chord\": \"F#/Gb\"}, {\"Index\": 330, \"Highest Charting Position\": 108, \"Number of Times Charted\": 51, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"All Girls Are The Same\", \"Streams\": 5372180, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"4VXIryQMWpIdGgYR4TrjT1\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2018-12-10\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-08--2020-05-15\\n2020-04-24--2020-05-01\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.671, \"Energy\": 0.529, \"Loudness\": -7.226, \"Speechiness\": 0.307, \"Acousticness\": 0.0769, \"Liveness\": 0.0856, \"Tempo\": 161.989, \"Duration (ms)\": 165820.0, \"Valence\": 0.203, \"Chord\": \"C\"}, {\"Index\": 331, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"734\", \"Streams\": 5368759, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"6vB8bdQCCTDDIH8fhRfuXA\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-05-28--2021-06-04\", \"Popularity\": 75.0, \"Danceability\": 0.663, \"Energy\": 0.545, \"Loudness\": -3.93, \"Speechiness\": 0.036, \"Acousticness\": 0.123, \"Liveness\": 0.106, \"Tempo\": 78.452, \"Duration (ms)\": 196147.0, \"Valence\": 0.344, \"Chord\": \"D\"}, {\"Index\": 332, \"Highest Charting Position\": 85, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Boy With Luv (feat. Halsey)\", \"Streams\": 5266625, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"5KawlOMHjWeUjQtnuRs22c\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2019-04-12\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2020-11-20--2020-11-27\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-01-17--2020-01-24\", \"Popularity\": 82.0, \"Danceability\": 0.645, \"Energy\": 0.862, \"Loudness\": -4.757, \"Speechiness\": 0.0965, \"Acousticness\": 0.0923, \"Liveness\": 0.192, \"Tempo\": 119.991, \"Duration (ms)\": 229773.0, \"Valence\": 0.798, \"Chord\": \"B\"}, {\"Index\": 333, \"Highest Charting Position\": 82, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Disco Arranhado - Funk Remix\", \"Streams\": 5207186, \"Artist\": \"Malu, DJ Lucas Beat\", \"Artist Followers\": 74814.0, \"Song ID\": \"2Gjt4rUHBUH0rMKpBg0hF4\", \"Genre\": \"[]\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 80.0, \"Danceability\": 0.747, \"Energy\": 0.725, \"Loudness\": -2.564, \"Speechiness\": 0.363, \"Acousticness\": 0.551, \"Liveness\": 0.0626, \"Tempo\": 129.96, \"Duration (ms)\": 125558.0, \"Valence\": 0.904, \"Chord\": \"D\"}, {\"Index\": 334, \"Highest Charting Position\": 4, \"Number of Times Charted\": 70, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Godzilla (feat. Juice WRLD)\", \"Streams\": 5143522, \"Artist\": \"Eminem\", \"Artist Followers\": 46785561.0, \"Song ID\": \"7FIWs0pqAYbP91WWM0vlTQ\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 83.0, \"Danceability\": 0.808, \"Energy\": 0.745, \"Loudness\": -5.26, \"Speechiness\": 0.342, \"Acousticness\": 0.145, \"Liveness\": 0.292, \"Tempo\": 165.995, \"Duration (ms)\": 210800.0, \"Valence\": 0.829, \"Chord\": \"A#/Bb\"}, {\"Index\": 335, \"Highest Charting Position\": 8, \"Number of Times Charted\": 68, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Blueberry Faygo\", \"Streams\": 5085511, \"Artist\": \"Lil Mosey\", \"Artist Followers\": 3816446.0, \"Song ID\": \"6wJYhPfqk3KGhHRG76WzOh\", \"Genre\": \"['melodic rap', 'rap', 'rap conscient', 'trap', 'vapor trap']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 79.0, \"Danceability\": 0.774, \"Energy\": 0.554, \"Loudness\": -7.909, \"Speechiness\": 0.0383, \"Acousticness\": 0.207, \"Liveness\": 0.132, \"Tempo\": 99.034, \"Duration (ms)\": 162547.0, \"Valence\": 0.349, \"Chord\": \"C\"}, {\"Index\": 336, \"Highest Charting Position\": 129, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Somebody That I Used To Know\", \"Streams\": 5068972, \"Artist\": \"Gotye, Kimbra\", \"Artist Followers\": 2263960.0, \"Song ID\": \"4wCmqSrbyCgxEXROQE6vtV\", \"Genre\": \"['australian pop']\", \"Release Date\": \"2011-01-01\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 76.0, \"Danceability\": 0.864, \"Energy\": 0.495, \"Loudness\": -7.036, \"Speechiness\": 0.037, \"Acousticness\": 0.591, \"Liveness\": 0.0992, \"Tempo\": 129.062, \"Duration (ms)\": 244973.0, \"Valence\": 0.72, \"Chord\": \"C\"}, {\"Index\": 337, \"Highest Charting Position\": 4, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Holy (feat. Chance The Rapper)\", \"Streams\": 5063015, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48504126.0, \"Song ID\": \"5u1n1kITHCxxp8twBcZxWy\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 81.0, \"Danceability\": 0.673, \"Energy\": 0.704, \"Loudness\": -8.056, \"Speechiness\": 0.36, \"Acousticness\": 0.196, \"Liveness\": 0.0898, \"Tempo\": 86.919, \"Duration (ms)\": 212093.0, \"Valence\": 0.372, \"Chord\": \"F#/Gb\"}, {\"Index\": 338, \"Highest Charting Position\": 200, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Vida Louca\", \"Streams\": 5051514, \"Artist\": \"Mc Poze do Rodo, Neo Beats, Mainstreet\", \"Artist Followers\": 448447.0, \"Song ID\": \"7IG7laqVpcvIIULrwWP5SA\", \"Genre\": \"['funk carioca', 'funk ostentacao']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-05-28--2021-06-04\", \"Popularity\": 82.0, \"Danceability\": 0.852, \"Energy\": 0.62, \"Loudness\": -5.79, \"Speechiness\": 0.227, \"Acousticness\": 0.359, \"Liveness\": 0.101, \"Tempo\": 92.464, \"Duration (ms)\": 155676.0, \"Valence\": 0.744, \"Chord\": \"F#/Gb\"}, {\"Index\": 339, \"Highest Charting Position\": 15, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"i n t e r l u d e\", \"Streams\": 7880155, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"08LwMWf5Tcfsd752EPzFV0\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 76.0, \"Danceability\": 0.77, \"Energy\": 0.574, \"Loudness\": -5.525, \"Speechiness\": 0.106, \"Acousticness\": 0.0617, \"Liveness\": 0.104, \"Tempo\": 98.962, \"Duration (ms)\": 133022.0, \"Valence\": 0.104, \"Chord\": \"C#/Db\"}, {\"Index\": 340, \"Highest Charting Position\": 95, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Butter (Instrumental)\", \"Streams\": 7450126, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"2Ol2sv6gePRdJrZC1hDVNY\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 70.0, \"Danceability\": 0.429, \"Energy\": 0.387, \"Loudness\": -7.486, \"Speechiness\": 0.0753, \"Acousticness\": 0.000178, \"Liveness\": 0.142, \"Tempo\": 109.893, \"Duration (ms)\": 162147.0, \"Valence\": 0.41, \"Chord\": \"C#/Db\"}, {\"Index\": 341, \"Highest Charting Position\": 25, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Film out\", \"Streams\": 7198095, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"3UHPGOkUcE4hE7sqBF4Snt\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-04-01\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 81.0, \"Danceability\": 0.499, \"Energy\": 0.709, \"Loudness\": -6.404, \"Speechiness\": 0.134, \"Acousticness\": 0.296, \"Liveness\": 0.331, \"Tempo\": 164.032, \"Duration (ms)\": 214621.0, \"Valence\": 0.314, \"Chord\": \"A#/Bb\"}, {\"Index\": 342, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Voil\\u00e0\", \"Streams\": 6935400, \"Artist\": \"Barbara Pravi\", \"Artist Followers\": 75496.0, \"Song ID\": \"1uAOCTevGnyKIDbgZdOCnE\", \"Genre\": \"['eurovision', 'nouvelle chanson francaise']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 72.0, \"Danceability\": 0.447, \"Energy\": 0.337, \"Loudness\": -8.665, \"Speechiness\": 0.0631, \"Acousticness\": 0.773, \"Liveness\": 0.298, \"Tempo\": 135.379, \"Duration (ms)\": 176816.0, \"Valence\": 0.603, \"Chord\": \"D\"}, {\"Index\": 343, \"Highest Charting Position\": 53, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Shy Away\", \"Streams\": 6634722, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20823062.0, \"Song ID\": \"2nG54Y4a3sH9YpfxMolOyi\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 77.0, \"Danceability\": 0.588, \"Energy\": 0.856, \"Loudness\": -5.242, \"Speechiness\": 0.0316, \"Acousticness\": 0.000818, \"Liveness\": 0.238, \"Tempo\": 96.966, \"Duration (ms)\": 175044.0, \"Valence\": 0.635, \"Chord\": \"A\"}, {\"Index\": 344, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Saturday\", \"Streams\": 6628638, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20823062.0, \"Song ID\": \"60dwJ8dnqZ4WrIdiu7LkNR\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 75.0, \"Danceability\": 0.687, \"Energy\": 0.89, \"Loudness\": -5.99, \"Speechiness\": 0.0344, \"Acousticness\": 0.00396, \"Liveness\": 0.0436, \"Tempo\": 113.06, \"Duration (ms)\": 172232.0, \"Valence\": 0.854, \"Chord\": \"G#/Ab\"}, {\"Index\": 345, \"Highest Charting Position\": 18, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"9 5 . s o u t h\", \"Streams\": 6333126, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5R691ipUYRDYW6ehapjoj6\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 75.0, \"Danceability\": 0.713, \"Energy\": 0.793, \"Loudness\": -5.277, \"Speechiness\": 0.397, \"Acousticness\": 0.271, \"Liveness\": 0.727, \"Tempo\": 71.724, \"Duration (ms)\": 196946.0, \"Valence\": 0.203, \"Chord\": \"D\"}, {\"Index\": 346, \"Highest Charting Position\": 67, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Seeing Green (with Drake & Lil Wayne)\", \"Streams\": 6299936, \"Artist\": \"Nicki Minaj\", \"Artist Followers\": 22161310.0, \"Song ID\": \"1TZv3bujNaYz646eezRE91\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'pop rap', 'post-teen pop', 'queens hip hop']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 77.0, \"Danceability\": 0.573, \"Energy\": 0.867, \"Loudness\": -2.876, \"Speechiness\": 0.168, \"Acousticness\": 0.0853, \"Liveness\": 0.38, \"Tempo\": 74.861, \"Duration (ms)\": 339506.0, \"Valence\": 0.231, \"Chord\": \"F\"}, {\"Index\": 347, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Dark Side\", \"Streams\": 6277641, \"Artist\": \"Blind Channel\", \"Artist Followers\": 121225.0, \"Song ID\": \"1ovFnZv6mUe0LzAbfVqOmh\", \"Genre\": \"['eurovision', 'oulu metal', 'trancecore']\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 72.0, \"Danceability\": 0.571, \"Energy\": 0.955, \"Loudness\": -3.795, \"Speechiness\": 0.105, \"Acousticness\": 0.00254, \"Liveness\": 0.274, \"Tempo\": 98.01, \"Duration (ms)\": 177790.0, \"Valence\": 0.437, \"Chord\": \"G\"}, {\"Index\": 348, \"Highest Charting Position\": 137, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"SHUM\", \"Streams\": 6237019, \"Artist\": \"Go_A\", \"Artist Followers\": 107553.0, \"Song ID\": \"7mEDVrAHDnQJStDo8jKJJm\", \"Genre\": \"['eurovision']\", \"Release Date\": \"2021-03-10\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 75.0, \"Danceability\": 0.527, \"Energy\": 0.737, \"Loudness\": -5.34, \"Speechiness\": 0.0642, \"Acousticness\": 0.05, \"Liveness\": 0.105, \"Tempo\": 116.431, \"Duration (ms)\": 172675.0, \"Valence\": 0.499, \"Chord\": \"E\"}, {\"Index\": 349, \"Highest Charting Position\": 69, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"In the morning\", \"Streams\": 5738325, \"Artist\": \"ITZY\", \"Artist Followers\": 2379448.0, \"Song ID\": \"2QdH0rKlV3d9Y6lWzcnlBH\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 79.0, \"Danceability\": 0.847, \"Energy\": 0.814, \"Loudness\": -4.668, \"Speechiness\": 0.152, \"Acousticness\": 0.0825, \"Liveness\": 0.0948, \"Tempo\": 140.057, \"Duration (ms)\": 172359.0, \"Valence\": 0.711, \"Chord\": \"B\"}, {\"Index\": 350, \"Highest Charting Position\": 27, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"l e t . g o . m y . h a n d (with Bas & 6LACK)\", \"Streams\": 5393643, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"0GAyuCo975IHGxxiLKDufB\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 73.0, \"Danceability\": 0.583, \"Energy\": 0.625, \"Loudness\": -8.011, \"Speechiness\": 0.277, \"Acousticness\": 0.506, \"Liveness\": 0.196, \"Tempo\": 89.812, \"Duration (ms)\": 266291.0, \"Valence\": 0.516, \"Chord\": \"C#/Db\"}, {\"Index\": 351, \"Highest Charting Position\": 2, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"What\\u2019s Next\", \"Streams\": 5335112, \"Artist\": \"Drake\", \"Artist Followers\": 56308172.0, \"Song ID\": \"3aQem4jVGdhtg116TmJnHz\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 81.0, \"Danceability\": 0.781, \"Energy\": 0.594, \"Loudness\": -6.959, \"Speechiness\": 0.0485, \"Acousticness\": 0.0136, \"Liveness\": 0.162, \"Tempo\": 129.895, \"Duration (ms)\": 178154.0, \"Valence\": 0.0628, \"Chord\": \"C\"}, {\"Index\": 352, \"Highest Charting Position\": 154, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Ramen & OJ\", \"Streams\": 5282702, \"Artist\": \"Joyner Lucas, Lil Baby\", \"Artist Followers\": 1725025.0, \"Song ID\": \"4TIqzdAssasqx3DAe6cG9J\", \"Genre\": \"['boston hip hop', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 81.0, \"Danceability\": 0.597, \"Energy\": 0.571, \"Loudness\": -6.205, \"Speechiness\": 0.293, \"Acousticness\": 0.492, \"Liveness\": 0.093, \"Tempo\": 106.196, \"Duration (ms)\": 218448.0, \"Valence\": 0.165, \"Chord\": \"C#/Db\"}, {\"Index\": 353, \"Highest Charting Position\": 91, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Cloud 9\", \"Streams\": 5252767, \"Artist\": \"Beach Bunny\", \"Artist Followers\": 618444.0, \"Song ID\": \"6vFsBXYczYsP0H3lgunZOm\", \"Genre\": \"['bubblegrunge', 'chicago indie', 'indie pop', 'pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 81.0, \"Danceability\": 0.637, \"Energy\": 0.929, \"Loudness\": -3.593, \"Speechiness\": 0.0491, \"Acousticness\": 0.00167, \"Liveness\": 0.344, \"Tempo\": 80.974, \"Duration (ms)\": 147351.0, \"Valence\": 0.902, \"Chord\": \"E\"}, {\"Index\": 354, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Tout l'univers\", \"Streams\": 5174437, \"Artist\": \"Gjon's Tears\", \"Artist Followers\": 32257.0, \"Song ID\": \"3MvY2XbGYFi6p2dgmdcOYG\", \"Genre\": \"[]\", \"Release Date\": \"2021-03-10\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 69.0, \"Danceability\": 0.534, \"Energy\": 0.365, \"Loudness\": -9.187, \"Speechiness\": 0.033, \"Acousticness\": 0.81, \"Liveness\": 0.158, \"Tempo\": 123.466, \"Duration (ms)\": 183707.0, \"Valence\": 0.237, \"Chord\": \"A\"}, {\"Index\": 355, \"Highest Charting Position\": 64, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Headshot (feat. Polo G & Fivio Foreign)\", \"Streams\": 5174298, \"Artist\": \"Lil Tjay\", \"Artist Followers\": 3553442.0, \"Song ID\": \"4eNOLmx8r2IJAVKvBBL1jv\", \"Genre\": \"['brooklyn drill', 'melodic rap', 'nyc rap']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 81.0, \"Danceability\": 0.808, \"Energy\": 0.639, \"Loudness\": -7.266, \"Speechiness\": 0.279, \"Acousticness\": 0.0802, \"Liveness\": 0.15, \"Tempo\": 118.0, \"Duration (ms)\": 144349.0, \"Valence\": 0.395, \"Chord\": \"C#/Db\"}, {\"Index\": 356, \"Highest Charting Position\": 198, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Mask\", \"Streams\": 5156496, \"Artist\": \"Dream\", \"Artist Followers\": 727731.0, \"Song ID\": \"3IxMaULfjq4IT2IN6v54PB\", \"Genre\": \"['dream smp']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 76.0, \"Danceability\": 0.636, \"Energy\": 0.749, \"Loudness\": -4.197, \"Speechiness\": 0.0631, \"Acousticness\": 0.195, \"Liveness\": 0.107, \"Tempo\": 117.904, \"Duration (ms)\": 174936.0, \"Valence\": 0.653, \"Chord\": \"C#/Db\"}, {\"Index\": 357, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"10 Years\", \"Streams\": 5152139, \"Artist\": \"Da\\u00f0i Freyr\", \"Artist Followers\": 169137.0, \"Song ID\": \"4O0LQKVT6hGmVGNwizmydg\", \"Genre\": \"['icelandic pop', 'sunnlensk tonlist']\", \"Release Date\": \"2021-03-13\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 70.0, \"Danceability\": 0.798, \"Energy\": 0.621, \"Loudness\": -6.916, \"Speechiness\": 0.0391, \"Acousticness\": 0.0141, \"Liveness\": 0.0926, \"Tempo\": 123.038, \"Duration (ms)\": 166000.0, \"Valence\": 0.443, \"Chord\": \"D\"}, {\"Index\": 358, \"Highest Charting Position\": 127, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Choker\", \"Streams\": 5150176, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20823062.0, \"Song ID\": \"732E6ibFkQR5lNIPEeiEnx\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-04-30--2021-05-07\", \"Popularity\": 72.0, \"Danceability\": 0.7, \"Energy\": 0.664, \"Loudness\": -8.211, \"Speechiness\": 0.0394, \"Acousticness\": 0.306, \"Liveness\": 0.249, \"Tempo\": 142.009, \"Duration (ms)\": 223066.0, \"Valence\": 0.585, \"Chord\": \"G\"}, {\"Index\": 359, \"Highest Charting Position\": 25, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"a p p l y i n g . p r e s s u r e\", \"Streams\": 15967986, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"1d7q712nXjG98HiwHk7HFS\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 71.0, \"Danceability\": 0.699, \"Energy\": 0.759, \"Loudness\": -5.302, \"Speechiness\": 0.311, \"Acousticness\": 0.0814, \"Liveness\": 0.312, \"Tempo\": 83.092, \"Duration (ms)\": 177337.0, \"Valence\": 0.404, \"Chord\": \"C#/Db\"}, {\"Index\": 360, \"Highest Charting Position\": 30, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"1 0 0 . m i l \\u2018 (with Bas)\", \"Streams\": 15171655, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"4n6NDfYake476trCjJRNl0\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 72.0, \"Danceability\": 0.711, \"Energy\": 0.647, \"Loudness\": -5.667, \"Speechiness\": 0.0822, \"Acousticness\": 0.334, \"Liveness\": 0.312, \"Tempo\": 125.092, \"Duration (ms)\": 163302.0, \"Valence\": 0.227, \"Chord\": \"D\"}, {\"Index\": 361, \"Highest Charting Position\": 32, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"p u n c h i n \\u2018 . t h e . c l o c k\", \"Streams\": 14051831, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"57ZUX6TNyKLBydAdVVd02x\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 70.0, \"Danceability\": 0.769, \"Energy\": 0.74, \"Loudness\": -6.579, \"Speechiness\": 0.378, \"Acousticness\": 0.197, \"Liveness\": 0.171, \"Tempo\": 94.104, \"Duration (ms)\": 112579.0, \"Valence\": 0.692, \"Chord\": \"B\"}, {\"Index\": 362, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"t h e . c l i m b . b a c k\", \"Streams\": 12648655, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5lLNBIyjp72btcnrjBG751\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.618, \"Energy\": 0.632, \"Loudness\": -6.973, \"Speechiness\": 0.346, \"Acousticness\": 0.0526, \"Liveness\": 0.353, \"Tempo\": 81.446, \"Duration (ms)\": 306257.0, \"Valence\": 0.319, \"Chord\": \"B\"}, {\"Index\": 363, \"Highest Charting Position\": 48, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"h u n g e r . o n . h i l l s i d e (with Bas)\", \"Streams\": 11647489, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5BwQjRasNcdRPuVWKcHto2\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 71.0, \"Danceability\": 0.563, \"Energy\": 0.703, \"Loudness\": -5.756, \"Speechiness\": 0.0702, \"Acousticness\": 0.126, \"Liveness\": 0.213, \"Tempo\": 94.983, \"Duration (ms)\": 238972.0, \"Valence\": 0.294, \"Chord\": \"D\"}, {\"Index\": 364, \"Highest Charting Position\": 55, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"c l o s e\", \"Streams\": 10712648, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"1D3z6HTiQsNmZxjl7F7eoG\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.597, \"Energy\": 0.587, \"Loudness\": -7.026, \"Speechiness\": 0.137, \"Acousticness\": 0.0622, \"Liveness\": 0.214, \"Tempo\": 140.021, \"Duration (ms)\": 218802.0, \"Valence\": 0.0753, \"Chord\": \"G\"}, {\"Index\": 365, \"Highest Charting Position\": 34, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"WITHOUT YOU (with Miley Cyrus)\", \"Streams\": 6081034, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2230022.0, \"Song ID\": \"1EHUQesfVKwbthtNcpBi9g\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 81.0, \"Danceability\": 0.655, \"Energy\": 0.469, \"Loudness\": -6.257, \"Speechiness\": 0.0292, \"Acousticness\": 0.173, \"Liveness\": 0.0956, \"Tempo\": 92.56, \"Duration (ms)\": 161385.0, \"Valence\": 0.467, \"Chord\": \"C\"}, {\"Index\": 366, \"Highest Charting Position\": 92, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Snow Tha Product: Bzrp Music Sessions, Vol. 39\", \"Streams\": 5595839, \"Artist\": \"Bizarrap, Snow Tha Product\", \"Artist Followers\": 3126961.0, \"Song ID\": \"3ke6it1vTmHtz2ApcIVUz5\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2021-04-28\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 78.0, \"Danceability\": 0.83, \"Energy\": 0.748, \"Loudness\": -5.362, \"Speechiness\": 0.162, \"Acousticness\": 0.354, \"Liveness\": 0.0992, \"Tempo\": 133.028, \"Duration (ms)\": 177443.0, \"Valence\": 0.523, \"Chord\": \"C#/Db\"}, {\"Index\": 367, \"Highest Charting Position\": 87, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Travesuras - Remix\", \"Streams\": 5518444, \"Artist\": \"Nio Garcia, Casper Magico, Ozuna, Wisin & Yandel, Myke Towers, Flow La Movie\", \"Artist Followers\": 2123734.0, \"Song ID\": \"0VWLId2RwPCno9s1cJm2Vy\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-03-11\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 81.0, \"Danceability\": 0.739, \"Energy\": 0.788, \"Loudness\": -5.198, \"Speechiness\": 0.0731, \"Acousticness\": 0.0513, \"Liveness\": 0.282, \"Tempo\": 175.996, \"Duration (ms)\": 324426.0, \"Valence\": 0.473, \"Chord\": \"C#/Db\"}, {\"Index\": 368, \"Highest Charting Position\": 148, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Bubblegum Bitch\", \"Streams\": 5375782, \"Artist\": \"MARINA\", \"Artist Followers\": 2918229.0, \"Song ID\": \"0ZFBKLOZLIM16RAUb5eomN\", \"Genre\": \"['dance pop', 'electropop', 'metropopolis', 'pop', 'post-teen pop', 'uk alternative pop']\", \"Release Date\": \"2012-04-30\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 73.0, \"Danceability\": 0.495, \"Energy\": 0.856, \"Loudness\": -5.123, \"Speechiness\": 0.0311, \"Acousticness\": 0.000219, \"Liveness\": 0.103, \"Tempo\": 158.024, \"Duration (ms)\": 154667.0, \"Valence\": 0.609, \"Chord\": \"C\"}, {\"Index\": 369, \"Highest Charting Position\": 5, \"Number of Times Charted\": 142, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Falling\", \"Streams\": 5294368, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16112621.0, \"Song ID\": \"1ZMiCix7XSAbfAJlEZWMCp\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.567, \"Energy\": 0.267, \"Loudness\": -6.502, \"Speechiness\": 0.0299, \"Acousticness\": 0.839, \"Liveness\": 0.089, \"Tempo\": 110.011, \"Duration (ms)\": 240133.0, \"Valence\": 0.0592, \"Chord\": \"E\"}, {\"Index\": 370, \"Highest Charting Position\": 182, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Expl\\u00edcito\", \"Streams\": 5278449, \"Artist\": \"Myke Towers\", \"Artist Followers\": 6150675.0, \"Song ID\": \"6qraVL4IJaIj0IuEexYJNa\", \"Genre\": \"['trap latino']\", \"Release Date\": \"2020-12-15\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-03-26--2021-04-02\", \"Popularity\": 81.0, \"Danceability\": 0.828, \"Energy\": 0.83, \"Loudness\": -3.371, \"Speechiness\": 0.047, \"Acousticness\": 0.348, \"Liveness\": 0.0613, \"Tempo\": 95.007, \"Duration (ms)\": 195066.0, \"Valence\": 0.422, \"Chord\": \"D\"}, {\"Index\": 371, \"Highest Charting Position\": 58, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"No Te Enamores - Remix\", \"Streams\": 5218146, \"Artist\": \"Milly, Farruko, Nio Garcia, Jay Wheeler, Amenazzy\", \"Artist Followers\": 22718.0, \"Song ID\": \"2mM3gZ0BbPwPPMelbA8vgt\", \"Genre\": \"['reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 79.0, \"Danceability\": 0.824, \"Energy\": 0.837, \"Loudness\": -4.603, \"Speechiness\": 0.107, \"Acousticness\": 0.573, \"Liveness\": 0.271, \"Tempo\": 100.021, \"Duration (ms)\": 289933.0, \"Valence\": 0.58, \"Chord\": \"F\"}, {\"Index\": 372, \"Highest Charting Position\": 110, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"PROBLEMA\", \"Streams\": 5215973, \"Artist\": \"Daddy Yankee\", \"Artist Followers\": 1250353.0, \"Song ID\": \"7vzPjsX8UzlPKKtV47qGPn\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 0.0, \"Danceability\": 0.773, \"Energy\": 0.8, \"Loudness\": -3.17, \"Speechiness\": 0.0987, \"Acousticness\": 0.0613, \"Liveness\": 0.0327, \"Tempo\": 89.988, \"Duration (ms)\": 184507.0, \"Valence\": 0.842, \"Chord\": \"A#/Bb\"}, {\"Index\": 373, \"Highest Charting Position\": 5, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Lonely (with benny blanco)\", \"Streams\": 5191697, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48504126.0, \"Song ID\": \"4y4spB9m0Q6026KfkAvy9Q\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 80.0, \"Danceability\": 0.631, \"Energy\": 0.239, \"Loudness\": -7.071, \"Speechiness\": 0.0398, \"Acousticness\": 0.864, \"Liveness\": 0.116, \"Tempo\": 79.859, \"Duration (ms)\": 149297.0, \"Valence\": 0.0927, \"Chord\": \"B\"}, {\"Index\": 374, \"Highest Charting Position\": 77, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Cupid's Chokehold / Breakfast in America\", \"Streams\": 5165035, \"Artist\": \"Gym Class Heroes\", \"Artist Followers\": 1275345.0, \"Song ID\": \"2Lhdl74nwwVGOE2Gv35QuK\", \"Genre\": \"['dance pop', 'pop rap']\", \"Release Date\": \"2005-02-22\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 81.0, \"Danceability\": 0.72, \"Energy\": 0.744, \"Loudness\": -6.938, \"Speechiness\": 0.12, \"Acousticness\": 0.237, \"Liveness\": 0.255, \"Tempo\": 78.953, \"Duration (ms)\": 243773.0, \"Valence\": 0.619, \"Chord\": \"C#/Db\"}, {\"Index\": 375, \"Highest Charting Position\": 38, \"Number of Times Charted\": 72, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"If the World Was Ending - feat. Julia Michaels\", \"Streams\": 5127736, \"Artist\": \"JP Saxe\", \"Artist Followers\": 280585.0, \"Song ID\": \"2kJwzbxV2ppxnQoYw4GLBZ\", \"Genre\": \"['alt z', 'canadian contemporary r&b', 'indie cafe pop', 'pop', 'pop rock', 'post-teen pop']\", \"Release Date\": \"2019-10-17\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.464, \"Energy\": 0.473, \"Loudness\": -10.086, \"Speechiness\": 0.129, \"Acousticness\": 0.866, \"Liveness\": 0.109, \"Tempo\": 75.801, \"Duration (ms)\": 208687.0, \"Valence\": 0.604, \"Chord\": \"C#/Db\"}, {\"Index\": 376, \"Highest Charting Position\": 47, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"I DID IT (feat. Post Malone, Megan Thee Stallion, Lil Baby & DaBaby)\", \"Streams\": 7347891, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6278835.0, \"Song ID\": \"20GrahbI4AzAOWxpYfDKkf\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 76.0, \"Danceability\": 0.757, \"Energy\": 0.721, \"Loudness\": -2.906, \"Speechiness\": 0.0691, \"Acousticness\": 0.00196, \"Liveness\": 0.647, \"Tempo\": 124.036, \"Duration (ms)\": 165366.0, \"Valence\": 0.364, \"Chord\": \"E\"}, {\"Index\": 377, \"Highest Charting Position\": 61, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Body\", \"Streams\": 5831357, \"Artist\": \"Russ Millions, Tion Wayne\", \"Artist Followers\": 323203.0, \"Song ID\": \"6uvMKqNlrSvcC4NaKnrwjZ\", \"Genre\": \"['london rap']\", \"Release Date\": \"2021-04-22\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 84.0, \"Danceability\": 0.883, \"Energy\": 0.674, \"Loudness\": -8.043, \"Speechiness\": 0.357, \"Acousticness\": 0.21, \"Liveness\": 0.0678, \"Tempo\": 141.02, \"Duration (ms)\": 278085.0, \"Valence\": 0.73, \"Chord\": \"B\"}, {\"Index\": 378, \"Highest Charting Position\": 10, \"Number of Times Charted\": 69, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"everything i wanted\", \"Streams\": 5448680, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"1OC8hMoqAuWmTWJ4heJNlO\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.704, \"Energy\": 0.225, \"Loudness\": -14.454, \"Speechiness\": 0.0994, \"Acousticness\": 0.901, \"Liveness\": 0.106, \"Tempo\": 120.006, \"Duration (ms)\": 245426.0, \"Valence\": 0.243, \"Chord\": \"F#/Gb\"}, {\"Index\": 379, \"Highest Charting Position\": 169, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"What You Need\", \"Streams\": 5346005, \"Artist\": \"Don Toliver\", \"Artist Followers\": 1605329.0, \"Song ID\": \"6LcX2hBbXaJcK4AuefE936\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2021-05-04\", \"Weeks Charted\": \"2021-05-07--2021-05-14\", \"Popularity\": 76.0, \"Danceability\": 0.664, \"Energy\": 0.655, \"Loudness\": -7.327, \"Speechiness\": 0.0461, \"Acousticness\": 0.059, \"Liveness\": 0.17, \"Tempo\": 129.987, \"Duration (ms)\": 217609.0, \"Valence\": 0.13, \"Chord\": \"A#/Bb\"}, {\"Index\": 380, \"Highest Charting Position\": 115, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"L-Gante: Bzrp Music Sessions, Vol.38\", \"Streams\": 5290877, \"Artist\": \"Bizarrap, L-Gante\", \"Artist Followers\": 3126961.0, \"Song ID\": \"1Crj1zkRMpsEjb9NOR6Zof\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2021-03-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 80.0, \"Danceability\": 0.553, \"Energy\": 0.819, \"Loudness\": -3.083, \"Speechiness\": 0.257, \"Acousticness\": 0.368, \"Liveness\": 0.0915, \"Tempo\": 87.913, \"Duration (ms)\": 192348.0, \"Valence\": 0.761, \"Chord\": \"D\"}, {\"Index\": 381, \"Highest Charting Position\": 19, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"HOLIDAY\", \"Streams\": 5264232, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5473565.0, \"Song ID\": \"6zFMeegAMYQo0mt8rXtrli\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 83.0, \"Danceability\": 0.81, \"Energy\": 0.511, \"Loudness\": -6.924, \"Speechiness\": 0.164, \"Acousticness\": 0.12, \"Liveness\": 0.0832, \"Tempo\": 151.947, \"Duration (ms)\": 154998.0, \"Valence\": 0.837, \"Chord\": \"F\"}, {\"Index\": 382, \"Highest Charting Position\": 71, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"At My Worst\", \"Streams\": 5258000, \"Artist\": \"Pink Sweat$\", \"Artist Followers\": 942628.0, \"Song ID\": \"0ri0Han4IRJhzvERHOZTMr\", \"Genre\": \"['bedroom soul', 'pop']\", \"Release Date\": \"2020-07-17\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 79.0, \"Danceability\": 0.813, \"Energy\": 0.415, \"Loudness\": -5.926, \"Speechiness\": 0.0349, \"Acousticness\": 0.777, \"Liveness\": 0.131, \"Tempo\": 91.921, \"Duration (ms)\": 170345.0, \"Valence\": 0.667, \"Chord\": \"C\"}, {\"Index\": 383, \"Highest Charting Position\": 3, \"Number of Times Charted\": 70, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Life Is Good (feat. Drake)\", \"Streams\": 5241227, \"Artist\": \"Future\", \"Artist Followers\": 10488292.0, \"Song ID\": \"5yY9lUy8nbvjM1Uyo1Uqoc\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 81.0, \"Danceability\": 0.676, \"Energy\": 0.609, \"Loudness\": -5.831, \"Speechiness\": 0.481, \"Acousticness\": 0.0706, \"Liveness\": 0.152, \"Tempo\": 142.037, \"Duration (ms)\": 237735.0, \"Valence\": 0.508, \"Chord\": \"D\"}, {\"Index\": 384, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Extasy\", \"Streams\": 5203700, \"Artist\": \"187 Strassenbande, Bonez MC, Frauenarzt\", \"Artist Followers\": 1223734.0, \"Song ID\": \"79lc69ZXfL4WmJIzVSDmWT\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-05-07--2021-05-14\", \"Popularity\": 67.0, \"Danceability\": 0.863, \"Energy\": 0.739, \"Loudness\": -5.879, \"Speechiness\": 0.153, \"Acousticness\": 0.0289, \"Liveness\": 0.0931, \"Tempo\": 129.964, \"Duration (ms)\": 174021.0, \"Valence\": 0.547, \"Chord\": \"A\"}, {\"Index\": 385, \"Highest Charting Position\": 7, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Wishing Well\", \"Streams\": 5125706, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"2U5WueTLIK5WJLD7mvDODv\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 83.0, \"Danceability\": 0.65, \"Energy\": 0.613, \"Loudness\": -6.13, \"Speechiness\": 0.128, \"Acousticness\": 0.00336, \"Liveness\": 0.267, \"Tempo\": 149.972, \"Duration (ms)\": 194621.0, \"Valence\": 0.0804, \"Chord\": \"A\"}, {\"Index\": 386, \"Highest Charting Position\": 164, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Fan de Tus Fotos\", \"Streams\": 5103863, \"Artist\": \"Nicky Jam, Romeo Santos\", \"Artist Followers\": 14826679.0, \"Song ID\": \"1mauYRwbpoGQX6itP2FAJC\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-02-08\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\", \"Popularity\": 79.0, \"Danceability\": 0.728, \"Energy\": 0.689, \"Loudness\": -5.718, \"Speechiness\": 0.0725, \"Acousticness\": 0.293, \"Liveness\": 0.109, \"Tempo\": 170.089, \"Duration (ms)\": 197647.0, \"Valence\": 0.431, \"Chord\": \"G\"}, {\"Index\": 387, \"Highest Charting Position\": 82, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Tap\\u00e3o Na Raba\", \"Streams\": 5088848, \"Artist\": \"Ra\\u00ed Saia Rodada\", \"Artist Followers\": 1260752.0, \"Song ID\": \"58pgi1RpcU2fVJsxhm7BIr\", \"Genre\": \"['forro']\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 80.0, \"Danceability\": 0.808, \"Energy\": 0.796, \"Loudness\": -3.169, \"Speechiness\": 0.0305, \"Acousticness\": 0.462, \"Liveness\": 0.155, \"Tempo\": 128.048, \"Duration (ms)\": 175047.0, \"Valence\": 0.799, \"Chord\": \"C#/Db\"}, {\"Index\": 388, \"Highest Charting Position\": 66, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Machu Picchu\", \"Streams\": 5062404, \"Artist\": \"Camilo, Evaluna Montaner\", \"Artist Followers\": 10561047.0, \"Song ID\": \"1LXb70u8SLsvBAPWHMCTMe\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2021-03-01\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 76.0, \"Danceability\": 0.788, \"Energy\": 0.789, \"Loudness\": -2.39, \"Speechiness\": 0.124, \"Acousticness\": 0.397, \"Liveness\": 0.226, \"Tempo\": 167.897, \"Duration (ms)\": 179005.0, \"Valence\": 0.867, \"Chord\": \"C\"}, {\"Index\": 389, \"Highest Charting Position\": 4, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Come & Go (with Marshmello)\", \"Streams\": 5037124, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"2Y0wPrPQBrGhoLn14xRYCG\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 83.0, \"Danceability\": 0.625, \"Energy\": 0.814, \"Loudness\": -5.181, \"Speechiness\": 0.0657, \"Acousticness\": 0.0172, \"Liveness\": 0.158, \"Tempo\": 144.991, \"Duration (ms)\": 205485.0, \"Valence\": 0.535, \"Chord\": \"C\"}, {\"Index\": 390, \"Highest Charting Position\": 71, \"Number of Times Charted\": 72, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Robbery\", \"Streams\": 5024884, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"6Hj9jySrnFppAI0sEMCZpJ\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2019-03-08\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.685, \"Energy\": 0.692, \"Loudness\": -5.122, \"Speechiness\": 0.0457, \"Acousticness\": 0.328, \"Liveness\": 0.153, \"Tempo\": 159.966, \"Duration (ms)\": 240051.0, \"Valence\": 0.578, \"Chord\": \"D\"}, {\"Index\": 391, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Paradigmas\", \"Streams\": 5018076, \"Artist\": \"Jorge & Mateus\", \"Artist Followers\": 15013645.0, \"Song ID\": \"17UfXrL7Run3GyZJW4uRjC\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2021-04-22\", \"Weeks Charted\": \"2021-05-07--2021-05-14\", \"Popularity\": 72.0, \"Danceability\": 0.686, \"Energy\": 0.789, \"Loudness\": -4.103, \"Speechiness\": 0.126, \"Acousticness\": 0.322, \"Liveness\": 0.4, \"Tempo\": 157.932, \"Duration (ms)\": 157355.0, \"Valence\": 0.822, \"Chord\": \"C#/Db\"}, {\"Index\": 392, \"Highest Charting Position\": 53, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"SugarCrash!\", \"Streams\": 5018005, \"Artist\": \"ElyOtto\", \"Artist Followers\": 85617.0, \"Song ID\": \"2ePtv8MlBO9nuuXABqAfEX\", \"Genre\": \"['weirdcore']\", \"Release Date\": \"2020-08-25\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 80.0, \"Danceability\": 0.748, \"Energy\": 0.734, \"Loudness\": -6.499, \"Speechiness\": 0.124, \"Acousticness\": 0.524, \"Liveness\": 0.0975, \"Tempo\": 97.753, \"Duration (ms)\": 80081.0, \"Valence\": 0.368, \"Chord\": \"C\"}, {\"Index\": 393, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"durag activity (with Travis Scott)\", \"Streams\": 7939784, \"Artist\": \"Baby Keem\", \"Artist Followers\": 279741.0, \"Song ID\": \"4JJcP0Rv9AgyPD6ZGaC8EE\", \"Genre\": \"['hip hop', 'rap', 'trap', 'underground hip hop']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-04-30--2021-05-07\", \"Popularity\": 75.0, \"Danceability\": 0.89, \"Energy\": 0.701, \"Loudness\": -5.712, \"Speechiness\": 0.342, \"Acousticness\": 0.00306, \"Liveness\": 0.0895, \"Tempo\": 80.462, \"Duration (ms)\": 225020.0, \"Valence\": 0.505, \"Chord\": \"C\"}, {\"Index\": 394, \"Highest Charting Position\": 113, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"love race (feat. Kellin Quinn)\", \"Streams\": 6325080, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3864419.0, \"Song ID\": \"1F9kEuwT29fgqlovIclu81\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2021-04-29\", \"Weeks Charted\": \"2021-04-30--2021-05-07\", \"Popularity\": 76.0, \"Danceability\": 0.517, \"Energy\": 0.848, \"Loudness\": -4.054, \"Speechiness\": 0.0521, \"Acousticness\": 0.00581, \"Liveness\": 0.214, \"Tempo\": 95.906, \"Duration (ms)\": 188779.0, \"Valence\": 0.429, \"Chord\": \"A#/Bb\"}, {\"Index\": 395, \"Highest Charting Position\": 7, \"Number of Times Charted\": 40, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"POPSTAR (feat. Drake)\", \"Streams\": 6127103, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6278835.0, \"Song ID\": \"6EDO9iiTtwNv6waLwa1UUq\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-07-17\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 80.0, \"Danceability\": 0.8, \"Energy\": 0.56, \"Loudness\": -4.818, \"Speechiness\": 0.261, \"Acousticness\": 0.057, \"Liveness\": 0.134, \"Tempo\": 163.071, \"Duration (ms)\": 200221.0, \"Valence\": 0.45, \"Chord\": \"F\"}, {\"Index\": 396, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"LET IT GO (feat. Justin Bieber & 21 Savage)\", \"Streams\": 6083338, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6278835.0, \"Song ID\": \"1cEhrSF6EylAEqdhUGuNpX\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-04-30--2021-05-07\", \"Popularity\": 75.0, \"Danceability\": 0.877, \"Energy\": 0.444, \"Loudness\": -7.547, \"Speechiness\": 0.172, \"Acousticness\": 0.24, \"Liveness\": 0.169, \"Tempo\": 129.06, \"Duration (ms)\": 165527.0, \"Valence\": 0.658, \"Chord\": \"G#/Ab\"}, {\"Index\": 397, \"Highest Charting Position\": 137, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Girl From Rio\", \"Streams\": 5768836, \"Artist\": \"Anitta\", \"Artist Followers\": 10740222.0, \"Song ID\": \"6CF085Ol0cVda1WqelybEQ\", \"Genre\": \"['funk carioca', 'funk pop', 'pagode baiano', 'pop nacional']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-04-30--2021-05-07\", \"Popularity\": 69.0, \"Danceability\": 0.732, \"Energy\": 0.604, \"Loudness\": -7.472, \"Speechiness\": 0.0443, \"Acousticness\": 0.0112, \"Liveness\": 0.219, \"Tempo\": 139.982, \"Duration (ms)\": 195429.0, \"Valence\": 0.732, \"Chord\": \"C\"}, {\"Index\": 398, \"Highest Charting Position\": 10, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"On The Ground\", \"Streams\": 5655879, \"Artist\": \"ROS\\u00c9\", \"Artist Followers\": 1094731.0, \"Song ID\": \"2pn8dNVSpYnAtlKFC8Q0DJ\", \"Genre\": \"[]\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 74.0, \"Danceability\": 0.311, \"Energy\": 0.607, \"Loudness\": -6.578, \"Speechiness\": 0.11, \"Acousticness\": 0.0174, \"Liveness\": 0.131, \"Tempo\": 188.7, \"Duration (ms)\": 168086.0, \"Valence\": 0.286, \"Chord\": \"C#/Db\"}, {\"Index\": 399, \"Highest Charting Position\": 20, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Mr. Perfectly Fine (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5480722, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2CYVETnhM9aytqrazYYwrK\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 74.0, \"Danceability\": 0.66, \"Energy\": 0.817, \"Loudness\": -6.269, \"Speechiness\": 0.0521, \"Acousticness\": 0.162, \"Liveness\": 0.0667, \"Tempo\": 135.942, \"Duration (ms)\": 277592.0, \"Valence\": 0.714, \"Chord\": \"B\"}, {\"Index\": 400, \"Highest Charting Position\": 42, \"Number of Times Charted\": 60, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"when the party's over\", \"Streams\": 5467596, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"5KWwUzVxubgSPmLIUAQhYt\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.484, \"Energy\": 0.103, \"Loudness\": -14.075, \"Speechiness\": 0.0627, \"Acousticness\": 0.979, \"Liveness\": 0.0895, \"Tempo\": 124.011, \"Duration (ms)\": 199931.0, \"Valence\": 0.194, \"Chord\": \"C#/Db\"}, {\"Index\": 401, \"Highest Charting Position\": 63, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Otra Noche Sin Ti\", \"Streams\": 5377794, \"Artist\": \"J Balvin, Khalid\", \"Artist Followers\": 29051363.0, \"Song ID\": \"2CdTLdDjwZdVcm0bresVWx\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 80.0, \"Danceability\": 0.503, \"Energy\": 0.548, \"Loudness\": -7.564, \"Speechiness\": 0.164, \"Acousticness\": 0.0751, \"Liveness\": 0.145, \"Tempo\": 94.036, \"Duration (ms)\": 228920.0, \"Valence\": 0.441, \"Chord\": \"C\"}, {\"Index\": 402, \"Highest Charting Position\": 33, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Met Him Last Night (feat. Ariana Grande)\", \"Streams\": 5200695, \"Artist\": \"Demi Lovato\", \"Artist Followers\": 20331923.0, \"Song ID\": \"0BI0hfbmqybnd3TezrDME3\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 72.0, \"Danceability\": 0.538, \"Energy\": 0.512, \"Loudness\": -4.548, \"Speechiness\": 0.0262, \"Acousticness\": 0.22, \"Liveness\": 0.101, \"Tempo\": 144.978, \"Duration (ms)\": 204632.0, \"Valence\": 0.12, \"Chord\": \"E\"}, {\"Index\": 403, \"Highest Charting Position\": 100, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Back In Blood (feat. Lil Durk)\", \"Streams\": 5198209, \"Artist\": \"Pooh Shiesty\", \"Artist Followers\": 423237.0, \"Song ID\": \"7JuHVG3qQKQKxC4doneXVW\", \"Genre\": \"['memphis hip hop', 'rap', 'southern hip hop', 'tennessee hip hop', 'trap']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 75.0, \"Danceability\": 0.759, \"Energy\": 0.538, \"Loudness\": -8.256, \"Speechiness\": 0.384, \"Acousticness\": 0.151, \"Liveness\": 0.126, \"Tempo\": 146.933, \"Duration (ms)\": 184490.0, \"Valence\": 0.831, \"Chord\": \"G#/Ab\"}, {\"Index\": 404, \"Highest Charting Position\": 94, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Run It Up (feat. Offset & Moneybagg Yo)\", \"Streams\": 5107084, \"Artist\": \"Lil Tjay\", \"Artist Followers\": 3553442.0, \"Song ID\": \"1dg3qy5DjoJodawfOCgrTP\", \"Genre\": \"['brooklyn drill', 'melodic rap', 'nyc rap']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 81.0, \"Danceability\": 0.88, \"Energy\": 0.575, \"Loudness\": -6.091, \"Speechiness\": 0.163, \"Acousticness\": 0.415, \"Liveness\": 0.109, \"Tempo\": 120.031, \"Duration (ms)\": 232048.0, \"Valence\": 0.671, \"Chord\": \"F#/Gb\"}, {\"Index\": 405, \"Highest Charting Position\": 37, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Mi Ni\\u00f1a\", \"Streams\": 5026961, \"Artist\": \"Wisin, Myke Towers, Los Legendarios\", \"Artist Followers\": 6929075.0, \"Song ID\": \"2bgcUk2A3jjKbCJ7KPquTi\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-23\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 79.0, \"Danceability\": 0.823, \"Energy\": 0.821, \"Loudness\": -3.402, \"Speechiness\": 0.166, \"Acousticness\": 0.31, \"Liveness\": 0.143, \"Tempo\": 99.999, \"Duration (ms)\": 213314.0, \"Valence\": 0.791, \"Chord\": \"G#/Ab\"}, {\"Index\": 406, \"Highest Charting Position\": 9, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"As I Am (feat. Khalid)\", \"Streams\": 5896065, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6F2r4HgpJnvKDmkN6JEN6J\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 72.0, \"Danceability\": 0.595, \"Energy\": 0.543, \"Loudness\": -8.149, \"Speechiness\": 0.038, \"Acousticness\": 0.127, \"Liveness\": 0.0975, \"Tempo\": 99.928, \"Duration (ms)\": 174406.0, \"Valence\": 0.109, \"Chord\": \"B\"}, {\"Index\": 407, \"Highest Charting Position\": 150, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Come Through (feat. Chris Brown)\", \"Streams\": 5531998, \"Artist\": \"H.E.R.\", \"Artist Followers\": 4138951.0, \"Song ID\": \"3krZxyBsWEHfEfJegYaWTd\", \"Genre\": \"['alternative r&b', 'dance pop', 'pop', 'r&b']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-04-23--2021-04-30\", \"Popularity\": 74.0, \"Danceability\": 0.615, \"Energy\": 0.422, \"Loudness\": -8.019, \"Speechiness\": 0.0504, \"Acousticness\": 0.604, \"Liveness\": 0.112, \"Tempo\": 135.859, \"Duration (ms)\": 214094.0, \"Valence\": 0.185, \"Chord\": \"F\"}, {\"Index\": 408, \"Highest Charting Position\": 33, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Goosebumps\", \"Streams\": 5496962, \"Artist\": \"HVME\", \"Artist Followers\": 17719446.0, \"Song ID\": \"5uEYRdEIh9Bo4fpjDd4Na9\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 87.0, \"Danceability\": 0.841, \"Energy\": 0.593, \"Loudness\": -7.846, \"Speechiness\": 0.0379, \"Acousticness\": 0.418, \"Liveness\": 0.124, \"Tempo\": 124.917, \"Duration (ms)\": 162803.0, \"Valence\": 0.808, \"Chord\": \"C#/Db\"}, {\"Index\": 409, \"Highest Charting Position\": 18, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Put Your Records On\", \"Streams\": 5181180, \"Artist\": \"Ritt Momney\", \"Artist Followers\": 100463.0, \"Song ID\": \"6AGOKlMZWLCaEJGnaROtF9\", \"Genre\": \"['bedroom pop']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 81.0, \"Danceability\": 0.399, \"Energy\": 0.491, \"Loudness\": -10.778, \"Speechiness\": 0.0538, \"Acousticness\": 0.0563, \"Liveness\": 0.11, \"Tempo\": 91.066, \"Duration (ms)\": 210463.0, \"Valence\": 0.151, \"Chord\": \"F#/Gb\"}, {\"Index\": 410, \"Highest Charting Position\": 137, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Facas - Ao Vivo\", \"Streams\": 5141640, \"Artist\": \"Diego & Victor Hugo, Bruno & Marrone\", \"Artist Followers\": 1585593.0, \"Song ID\": \"1ere9b9vDw2N3m9d4uiXxa\", \"Genre\": \"['sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2020-10-15\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 79.0, \"Danceability\": 0.443, \"Energy\": 0.509, \"Loudness\": -5.995, \"Speechiness\": 0.0536, \"Acousticness\": 0.615, \"Liveness\": 0.472, \"Tempo\": 160.984, \"Duration (ms)\": 196380.0, \"Valence\": 0.69, \"Chord\": \"D\"}, {\"Index\": 411, \"Highest Charting Position\": 62, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Train Wreck\", \"Streams\": 5081800, \"Artist\": \"James Arthur\", \"Artist Followers\": 8446147.0, \"Song ID\": \"55Am8neGJkdj2ADaM3aw5H\", \"Genre\": \"['pop', 'post-teen pop', 'talent show', 'uk pop']\", \"Release Date\": \"2016-10-28\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 82.0, \"Danceability\": 0.311, \"Energy\": 0.485, \"Loudness\": -5.726, \"Speechiness\": 0.0365, \"Acousticness\": 0.701, \"Liveness\": 0.0726, \"Tempo\": 77.355, \"Duration (ms)\": 208827.0, \"Valence\": 0.225, \"Chord\": \"F#/Gb\"}, {\"Index\": 412, \"Highest Charting Position\": 7, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Monster (Shawn Mendes & Justin Bieber)\", \"Streams\": 5069268, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 33893352.0, \"Song ID\": \"2Z8yfpFX0ZMavHkcIeHiO1\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 79.0, \"Danceability\": 0.652, \"Energy\": 0.383, \"Loudness\": -7.076, \"Speechiness\": 0.0516, \"Acousticness\": 0.0676, \"Liveness\": 0.0828, \"Tempo\": 145.765, \"Duration (ms)\": 178994.0, \"Valence\": 0.549, \"Chord\": \"D\"}, {\"Index\": 413, \"Highest Charting Position\": 6, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"In Your Eyes\", \"Streams\": 5054319, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"7szuecWAPwGoV1e5vGu8tl\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 81.0, \"Danceability\": 0.667, \"Energy\": 0.719, \"Loudness\": -5.371, \"Speechiness\": 0.0346, \"Acousticness\": 0.00285, \"Liveness\": 0.0736, \"Tempo\": 100.021, \"Duration (ms)\": 237520.0, \"Valence\": 0.717, \"Chord\": \"G\"}, {\"Index\": 414, \"Highest Charting Position\": 101, \"Number of Times Charted\": 68, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"SAD!\", \"Streams\": 5051338, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"3ee8Jmje8o58CHK66QrVC2\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2018-03-16\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.74, \"Energy\": 0.613, \"Loudness\": -4.88, \"Speechiness\": 0.145, \"Acousticness\": 0.258, \"Liveness\": 0.123, \"Tempo\": 75.023, \"Duration (ms)\": 166606.0, \"Valence\": 0.473, \"Chord\": \"G#/Ab\"}, {\"Index\": 415, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Good Without\", \"Streams\": 4998044, \"Artist\": \"Mimi Webb\", \"Artist Followers\": 130801.0, \"Song ID\": \"15OCqNPYoLziEAsbVnqRj5\", \"Genre\": \"['alt z', 'indie cafe pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-04-23--2021-04-30\", \"Popularity\": 81.0, \"Danceability\": 0.616, \"Energy\": 0.576, \"Loudness\": -5.495, \"Speechiness\": 0.0532, \"Acousticness\": 0.0723, \"Liveness\": 0.375, \"Tempo\": 89.962, \"Duration (ms)\": 182121.0, \"Valence\": 0.269, \"Chord\": \"B\"}, {\"Index\": 416, \"Highest Charting Position\": 19, \"Number of Times Charted\": 66, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"hot girl bummer\", \"Streams\": 4992396, \"Artist\": \"blackbear\", \"Artist Followers\": 4270131.0, \"Song ID\": \"2mt1IqcFyY1zmYZT8Q3xw9\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.782, \"Energy\": 0.559, \"Loudness\": -7.106, \"Speechiness\": 0.0767, \"Acousticness\": 0.125, \"Liveness\": 0.385, \"Tempo\": 129.992, \"Duration (ms)\": 188344.0, \"Valence\": 0.685, \"Chord\": \"F#/Gb\"}, {\"Index\": 417, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"When I Was Your Man\", \"Streams\": 4945935, \"Artist\": \"Bruno Mars\", \"Artist Followers\": 32603394.0, \"Song ID\": \"0nJW01T7XtvILxQgC5J7Wh\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2012-12-07\", \"Weeks Charted\": \"2021-04-23--2021-04-30\", \"Popularity\": 82.0, \"Danceability\": 0.612, \"Energy\": 0.28, \"Loudness\": -8.648, \"Speechiness\": 0.0434, \"Acousticness\": 0.932, \"Liveness\": 0.088, \"Tempo\": 72.795, \"Duration (ms)\": 213827.0, \"Valence\": 0.387, \"Chord\": \"C\"}, {\"Index\": 418, \"Highest Charting Position\": 73, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"LOCATION\", \"Streams\": 4940701, \"Artist\": \"KAROL G, Anuel AA, J Balvin\", \"Artist Followers\": 1250353.0, \"Song ID\": \"1aH3EQY5LTXjRZQLpl1Gby\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 0.0, \"Danceability\": 0.772, \"Energy\": 0.758, \"Loudness\": -3.891, \"Speechiness\": 0.0482, \"Acousticness\": 0.0433, \"Liveness\": 0.295, \"Tempo\": 115.977, \"Duration (ms)\": 265240.0, \"Valence\": 0.654, \"Chord\": \"A\"}, {\"Index\": 419, \"Highest Charting Position\": 177, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Stressed Out\", \"Streams\": 4913147, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20823062.0, \"Song ID\": \"3CRDbSIZ4r5MsZ0YwxuEkn\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2015-05-15\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 83.0, \"Danceability\": 0.734, \"Energy\": 0.637, \"Loudness\": -5.677, \"Speechiness\": 0.141, \"Acousticness\": 0.0462, \"Liveness\": 0.0602, \"Tempo\": 169.977, \"Duration (ms)\": 202333.0, \"Valence\": 0.648, \"Chord\": \"E\"}, {\"Index\": 420, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Ski\", \"Streams\": 7753784, \"Artist\": \"Young Stoner Life, Young Thug, Gunna\", \"Artist Followers\": 61930.0, \"Song ID\": \"6755DFiZ7CWe2WMdTGW5C1\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-04-16--2021-04-23\", \"Popularity\": 78.0, \"Danceability\": 0.953, \"Energy\": 0.621, \"Loudness\": -7.638, \"Speechiness\": 0.221, \"Acousticness\": 0.017, \"Liveness\": 0.0398, \"Tempo\": 123.016, \"Duration (ms)\": 152333.0, \"Valence\": 0.883, \"Chord\": \"G#/Ab\"}, {\"Index\": 421, \"Highest Charting Position\": 75, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Diamonds Dancing (feat. Travis Scott)\", \"Streams\": 7515766, \"Artist\": \"Young Stoner Life, Young Thug, Gunna\", \"Artist Followers\": 61930.0, \"Song ID\": \"7uZqvqXzzYMKrexKxdcGmd\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-04-16--2021-04-23\", \"Popularity\": 69.0, \"Danceability\": 0.851, \"Energy\": 0.703, \"Loudness\": -7.351, \"Speechiness\": 0.303, \"Acousticness\": 0.00949, \"Liveness\": 0.0895, \"Tempo\": 74.017, \"Duration (ms)\": 242600.0, \"Valence\": 0.596, \"Chord\": \"E\"}, {\"Index\": 422, \"Highest Charting Position\": 8, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Love Story (Taylor\\u2019s Version)\", \"Streams\": 6202933, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6YvqWjhGD8mB5QXcbcUKtx\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 73.0, \"Danceability\": 0.627, \"Energy\": 0.792, \"Loudness\": -4.311, \"Speechiness\": 0.031, \"Acousticness\": 0.13, \"Liveness\": 0.0845, \"Tempo\": 119.054, \"Duration (ms)\": 235767.0, \"Valence\": 0.415, \"Chord\": \"D\"}, {\"Index\": 423, \"Highest Charting Position\": 107, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Ele \\u00c9 Ele, Eu Sou Eu\", \"Streams\": 5380517, \"Artist\": \"Wesley Safad\\u00e3o, Os Bar\\u00f5es Da Pisadinha\", \"Artist Followers\": 9907270.0, \"Song ID\": \"7EWXP47VlXKO3r7mNxuWHw\", \"Genre\": \"['forro']\", \"Release Date\": \"2020-11-12\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 73.0, \"Danceability\": 0.758, \"Energy\": 0.763, \"Loudness\": -8.754, \"Speechiness\": 0.0768, \"Acousticness\": 0.23, \"Liveness\": 0.0703, \"Tempo\": 163.946, \"Duration (ms)\": 155210.0, \"Valence\": 0.854, \"Chord\": \"C#/Db\"}, {\"Index\": 424, \"Highest Charting Position\": 186, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Quero Ver \\u00e9 Me Esquecer (feat. Jorge) - Ao Vivo\", \"Streams\": 5159208, \"Artist\": \"Os Bar\\u00f5es Da Pisadinha\", \"Artist Followers\": 4271775.0, \"Song ID\": \"2SUPbyD77tJuOUbqbxct6l\", \"Genre\": \"['forro', 'piseiro']\", \"Release Date\": \"2021-02-19\", \"Weeks Charted\": \"2021-04-16--2021-04-23\", \"Popularity\": 80.0, \"Danceability\": 0.593, \"Energy\": 0.932, \"Loudness\": -2.324, \"Speechiness\": 0.0526, \"Acousticness\": 0.302, \"Liveness\": 0.133, \"Tempo\": 171.977, \"Duration (ms)\": 147876.0, \"Valence\": 0.913, \"Chord\": \"G#/Ab\"}, {\"Index\": 425, \"Highest Charting Position\": 3, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"willow\", \"Streams\": 5016865, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0lx2cLdOt3piJbcaXIV74f\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 79.0, \"Danceability\": 0.392, \"Energy\": 0.574, \"Loudness\": -9.195, \"Speechiness\": 0.17, \"Acousticness\": 0.833, \"Liveness\": 0.145, \"Tempo\": 81.112, \"Duration (ms)\": 214707.0, \"Valence\": 0.529, \"Chord\": \"G\"}, {\"Index\": 426, \"Highest Charting Position\": 104, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Why'd You Only Call Me When You're High?\", \"Streams\": 4976405, \"Artist\": \"Arctic Monkeys\", \"Artist Followers\": 12375514.0, \"Song ID\": \"086myS9r57YsLbJpU0TgK9\", \"Genre\": \"['garage rock', 'permanent wave', 'rock', 'sheffield indie']\", \"Release Date\": \"2013-09-09\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 82.0, \"Danceability\": 0.691, \"Energy\": 0.631, \"Loudness\": -6.478, \"Speechiness\": 0.0368, \"Acousticness\": 0.0483, \"Liveness\": 0.104, \"Tempo\": 92.004, \"Duration (ms)\": 161124.0, \"Valence\": 0.8, \"Chord\": \"D\"}, {\"Index\": 427, \"Highest Charting Position\": 18, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Afterglow\", \"Streams\": 4965330, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 1250353.0, \"Song ID\": \"5dA45onYgYACRp8C5xEOS9\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\", \"Popularity\": 0.0, \"Danceability\": 0.641, \"Energy\": 0.324, \"Loudness\": -5.851, \"Speechiness\": 0.0299, \"Acousticness\": 0.698, \"Liveness\": 0.328, \"Tempo\": 110.184, \"Duration (ms)\": 185487.0, \"Valence\": 0.273, \"Chord\": \"B\"}, {\"Index\": 428, \"Highest Charting Position\": 43, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"LA CANCI\\u00d3N\", \"Streams\": 4959754, \"Artist\": \"J Balvin, Bad Bunny\", \"Artist Followers\": 29051363.0, \"Song ID\": \"0fea68AdmYNygeTGI4RC18\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.754, \"Energy\": 0.646, \"Loudness\": -5.795, \"Speechiness\": 0.317, \"Acousticness\": 0.152, \"Liveness\": 0.108, \"Tempo\": 176.089, \"Duration (ms)\": 242573.0, \"Valence\": 0.429, \"Chord\": \"G\"}, {\"Index\": 429, \"Highest Charting Position\": 52, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"You Belong With Me (Taylor\\u2019s Version)\", \"Streams\": 9872084, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1qrpoAMXodY6895hGKoUpA\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 73.0, \"Danceability\": 0.632, \"Energy\": 0.773, \"Loudness\": -4.856, \"Speechiness\": 0.0346, \"Acousticness\": 0.0623, \"Liveness\": 0.0885, \"Tempo\": 130.033, \"Duration (ms)\": 231124.0, \"Valence\": 0.474, \"Chord\": \"F#/Gb\"}, {\"Index\": 430, \"Highest Charting Position\": 54, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Fearless (Taylor\\u2019s Version)\", \"Streams\": 9676024, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"77sMIMlNaSURUAXq5coCxE\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 69.0, \"Danceability\": 0.569, \"Energy\": 0.741, \"Loudness\": -4.963, \"Speechiness\": 0.0282, \"Acousticness\": 0.0122, \"Liveness\": 0.333, \"Tempo\": 100.118, \"Duration (ms)\": 241592.0, \"Valence\": 0.43, \"Chord\": \"F\"}, {\"Index\": 431, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"X Gon' Give It To Ya\", \"Streams\": 8638360, \"Artist\": \"DMX\", \"Artist Followers\": 2815928.0, \"Song ID\": \"1zzxoZVylsna2BQB65Ppcb\", \"Genre\": \"['east coast hip hop', 'gangster rap', 'hardcore hip hop', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2007-06-12\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 73.0, \"Danceability\": 0.761, \"Energy\": 0.899, \"Loudness\": -3.09, \"Speechiness\": 0.183, \"Acousticness\": 0.0135, \"Liveness\": 0.0719, \"Tempo\": 95.027, \"Duration (ms)\": 217587.0, \"Valence\": 0.673, \"Chord\": \"A#/Bb\"}, {\"Index\": 432, \"Highest Charting Position\": 80, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Fifteen (Taylor\\u2019s Version)\", \"Streams\": 7852063, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2nqio0SfWg6gh2eCtfuMa5\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 66.0, \"Danceability\": 0.559, \"Energy\": 0.646, \"Loudness\": -4.61, \"Speechiness\": 0.0272, \"Acousticness\": 0.116, \"Liveness\": 0.32, \"Tempo\": 95.466, \"Duration (ms)\": 294419.0, \"Valence\": 0.289, \"Chord\": \"G\"}, {\"Index\": 433, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"The Way I Loved You (Taylor\\u2019s Version)\", \"Streams\": 7736262, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"22bPsP2jCgbLUvh82U0Z3M\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 72.0, \"Danceability\": 0.402, \"Energy\": 0.732, \"Loudness\": -4.665, \"Speechiness\": 0.0484, \"Acousticness\": 0.0033, \"Liveness\": 0.108, \"Tempo\": 161.032, \"Duration (ms)\": 243137.0, \"Valence\": 0.472, \"Chord\": \"F\"}, {\"Index\": 434, \"Highest Charting Position\": 51, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"You All Over Me (feat. Maren Morris) (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 7712896, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5pcjystBtalYeqaiXCcgEY\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 65.0, \"Danceability\": 0.589, \"Energy\": 0.496, \"Loudness\": -7.606, \"Speechiness\": 0.0377, \"Acousticness\": 0.818, \"Liveness\": 0.101, \"Tempo\": 142.731, \"Duration (ms)\": 220839.0, \"Valence\": 0.44, \"Chord\": \"D\"}, {\"Index\": 435, \"Highest Charting Position\": 93, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Hey Stephen (Taylor\\u2019s Version)\", \"Streams\": 7385864, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"550erGcdD9n6PnwxrvYqZT\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 66.0, \"Danceability\": 0.788, \"Energy\": 0.571, \"Loudness\": -6.135, \"Speechiness\": 0.0296, \"Acousticness\": 0.106, \"Liveness\": 0.0934, \"Tempo\": 115.99, \"Duration (ms)\": 254255.0, \"Valence\": 0.797, \"Chord\": \"F#/Gb\"}, {\"Index\": 436, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"White Horse (Taylor\\u2019s Version)\", \"Streams\": 7039222, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5YL553x8sHderRBDlm3NM3\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 65.0, \"Danceability\": 0.423, \"Energy\": 0.517, \"Loudness\": -7.377, \"Speechiness\": 0.0486, \"Acousticness\": 0.369, \"Liveness\": 0.177, \"Tempo\": 185.262, \"Duration (ms)\": 234516.0, \"Valence\": 0.366, \"Chord\": \"C\"}, {\"Index\": 437, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Forever & Always (Taylor\\u2019s Version)\", \"Streams\": 6566059, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1msEuwSBneBKpVCZQcFTsU\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 66.0, \"Danceability\": 0.598, \"Energy\": 0.821, \"Loudness\": -4.433, \"Speechiness\": 0.0447, \"Acousticness\": 0.0231, \"Liveness\": 0.143, \"Tempo\": 128.03, \"Duration (ms)\": 225328.0, \"Valence\": 0.673, \"Chord\": \"A#/Bb\"}, {\"Index\": 438, \"Highest Charting Position\": 119, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Breathe (feat. Colbie Caillat) (Taylor\\u2019s Version)\", \"Streams\": 6508683, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7HC7R2D8WjXVcUHJyEGjRs\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 64.0, \"Danceability\": 0.506, \"Energy\": 0.626, \"Loudness\": -6.066, \"Speechiness\": 0.0287, \"Acousticness\": 0.156, \"Liveness\": 0.228, \"Tempo\": 148.035, \"Duration (ms)\": 263377.0, \"Valence\": 0.321, \"Chord\": \"C#/Db\"}, {\"Index\": 439, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Ruff Ryders' Anthem\", \"Streams\": 5988511, \"Artist\": \"DMX\", \"Artist Followers\": 2815928.0, \"Song ID\": \"1BKT2I9x4RGKaKqW4up34s\", \"Genre\": \"['east coast hip hop', 'gangster rap', 'hardcore hip hop', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"1998-05-01\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 72.0, \"Danceability\": 0.88, \"Energy\": 0.577, \"Loudness\": -8.093, \"Speechiness\": 0.302, \"Acousticness\": 0.0564, \"Liveness\": 0.201, \"Tempo\": 90.991, \"Duration (ms)\": 214440.0, \"Valence\": 0.74, \"Chord\": \"A#/Bb\"}, {\"Index\": 440, \"Highest Charting Position\": 146, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"That\\u2019s When (feat. Keith Urban) (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5889939, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7eResoqEJJAVTkQYSqvO3P\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 67.0, \"Danceability\": 0.588, \"Energy\": 0.608, \"Loudness\": -7.062, \"Speechiness\": 0.0365, \"Acousticness\": 0.225, \"Liveness\": 0.092, \"Tempo\": 90.201, \"Duration (ms)\": 189496.0, \"Valence\": 0.508, \"Chord\": \"F\"}, {\"Index\": 441, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Tell Me Why (Taylor\\u2019s Version)\", \"Streams\": 5885151, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0k0vFacOHNuArLWMiH60p7\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 63.0, \"Danceability\": 0.578, \"Energy\": 0.909, \"Loudness\": -3.669, \"Speechiness\": 0.0628, \"Acousticness\": 0.0222, \"Liveness\": 0.333, \"Tempo\": 100.023, \"Duration (ms)\": 200576.0, \"Valence\": 0.541, \"Chord\": \"G\"}, {\"Index\": 442, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"You\\u2019re Not Sorry (Taylor\\u2019s Version)\", \"Streams\": 5860405, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6iiAfo4wTA2CVC3Uwx9uh8\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 64.0, \"Danceability\": 0.506, \"Energy\": 0.444, \"Loudness\": -4.99, \"Speechiness\": 0.0285, \"Acousticness\": 0.0538, \"Liveness\": 0.123, \"Tempo\": 133.873, \"Duration (ms)\": 261843.0, \"Valence\": 0.241, \"Chord\": \"F#/Gb\"}, {\"Index\": 443, \"Highest Charting Position\": 40, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Chica Ideal\", \"Streams\": 5217052, \"Artist\": \"Sebastian Yatra, Guaynaa\", \"Artist Followers\": 1250353.0, \"Song ID\": \"6M3Bdl5UtQtmjnYDW69LZQ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 0.0, \"Danceability\": 0.574, \"Energy\": 0.891, \"Loudness\": -3.665, \"Speechiness\": 0.157, \"Acousticness\": 0.0847, \"Liveness\": 0.16, \"Tempo\": 100.978, \"Duration (ms)\": 183240.0, \"Valence\": 0.707, \"Chord\": \"C\"}, {\"Index\": 444, \"Highest Charting Position\": 15, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Relaci\\u00f3n - Remix\", \"Streams\": 5206614, \"Artist\": \"Sech, Daddy Yankee, J Balvin, ROSAL\\u00cdA, Farruko\", \"Artist Followers\": 8758283.0, \"Song ID\": \"35UUpTmrcFXNIVIN26ujXl\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 80.0, \"Danceability\": 0.793, \"Energy\": 0.771, \"Loudness\": -3.417, \"Speechiness\": 0.0959, \"Acousticness\": 0.0337, \"Liveness\": 0.284, \"Tempo\": 171.943, \"Duration (ms)\": 247308.0, \"Valence\": 0.835, \"Chord\": \"F\"}, {\"Index\": 445, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Don\\u2019t You (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5197564, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"4uuEGH5SVuzkkSFjo2DEiY\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 65.0, \"Danceability\": 0.563, \"Energy\": 0.473, \"Loudness\": -11.548, \"Speechiness\": 0.0503, \"Acousticness\": 0.514, \"Liveness\": 0.109, \"Tempo\": 101.934, \"Duration (ms)\": 208609.0, \"Valence\": 0.405, \"Chord\": \"D#/Eb\"}, {\"Index\": 446, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"We Were Happy (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5189423, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"34V9RiEPe8MNdU32qJsJa1\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 64.0, \"Danceability\": 0.609, \"Energy\": 0.373, \"Loudness\": -8.819, \"Speechiness\": 0.0263, \"Acousticness\": 0.849, \"Liveness\": 0.0779, \"Tempo\": 106.007, \"Duration (ms)\": 244237.0, \"Valence\": 0.13, \"Chord\": \"C\"}, {\"Index\": 447, \"Highest Charting Position\": 153, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"WACHA\", \"Streams\": 5172999, \"Artist\": \"KHEA, Duki\", \"Artist Followers\": 3198705.0, \"Song ID\": \"5RmSunLqeDqNWww8LWhAiK\", \"Genre\": \"['argentine hip hop', 'trap argentino', 'trap latino', 'trap triste']\", \"Release Date\": \"2021-04-01\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 75.0, \"Danceability\": 0.737, \"Energy\": 0.634, \"Loudness\": -4.25, \"Speechiness\": 0.0424, \"Acousticness\": 0.345, \"Liveness\": 0.111, \"Tempo\": 94.927, \"Duration (ms)\": 206360.0, \"Valence\": 0.528, \"Chord\": \"D#/Eb\"}, {\"Index\": 448, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Dancing With The Devil\", \"Streams\": 5836326, \"Artist\": \"Demi Lovato\", \"Artist Followers\": 20338833.0, \"Song ID\": \"2kONpeXXK70YEs7c0UQbmq\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-04-02--2021-04-09\", \"Popularity\": 66.0, \"Danceability\": 0.413, \"Energy\": 0.64, \"Loudness\": -5.811, \"Speechiness\": 0.0427, \"Acousticness\": 0.273, \"Liveness\": 0.11, \"Tempo\": 75.245, \"Duration (ms)\": 243992.0, \"Valence\": 0.149, \"Chord\": \"G#/Ab\"}, {\"Index\": 449, \"Highest Charting Position\": 26, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Gone\", \"Streams\": 5427638, \"Artist\": \"ROS\\u00c9\", \"Artist Followers\": 1099480.0, \"Song ID\": \"2dHoVW9AxJVSRebPRyV2aA\", \"Genre\": \"[]\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 71.0, \"Danceability\": 0.647, \"Energy\": 0.377, \"Loudness\": -6.003, \"Speechiness\": 0.0375, \"Acousticness\": 0.594, \"Liveness\": 0.0768, \"Tempo\": 79.936, \"Duration (ms)\": 207164.0, \"Valence\": 0.653, \"Chord\": \"F#/Gb\"}, {\"Index\": 450, \"Highest Charting Position\": 160, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"What Other People Say\", \"Streams\": 5413003, \"Artist\": \"Sam Fischer, Demi Lovato\", \"Artist Followers\": 122746.0, \"Song ID\": \"2h9TDNEXRhcDIV3fsoEVq9\", \"Genre\": \"['alt z', 'australian pop', 'dance pop', 'indie cafe pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2021-02-04\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\", \"Popularity\": 77.0, \"Danceability\": 0.652, \"Energy\": 0.472, \"Loudness\": -8.084, \"Speechiness\": 0.0399, \"Acousticness\": 0.158, \"Liveness\": 0.121, \"Tempo\": 126.904, \"Duration (ms)\": 194890.0, \"Valence\": 0.24, \"Chord\": \"G\"}, {\"Index\": 451, \"Highest Charting Position\": 88, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Hello (feat. A Boogie Wit da Hoodie)\", \"Streams\": 5323062, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"2r6OAV3WsYtXuXjvJ1lIDi\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-20\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 82.0, \"Danceability\": 0.905, \"Energy\": 0.647, \"Loudness\": -5.065, \"Speechiness\": 0.107, \"Acousticness\": 0.0187, \"Liveness\": 0.282, \"Tempo\": 130.97, \"Duration (ms)\": 190534.0, \"Valence\": 0.367, \"Chord\": \"A#/Bb\"}, {\"Index\": 452, \"Highest Charting Position\": 91, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Hasta Abajo\", \"Streams\": 5269163, \"Artist\": \"Kevin Roldan, Bryant Myers, Lyanno\", \"Artist Followers\": 4026643.0, \"Song ID\": \"4PEfJZpVjdclfzZ9XO8uDw\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'reggaeton colombiano', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 77.0, \"Danceability\": 0.714, \"Energy\": 0.671, \"Loudness\": -5.119, \"Speechiness\": 0.362, \"Acousticness\": 0.289, \"Liveness\": 0.325, \"Tempo\": 169.732, \"Duration (ms)\": 229827.0, \"Valence\": 0.641, \"Chord\": \"F\"}, {\"Index\": 453, \"Highest Charting Position\": 30, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Take You Dancing\", \"Streams\": 5176493, \"Artist\": \"Jason Derulo\", \"Artist Followers\": 9778632.0, \"Song ID\": \"59qrUpoplZxbIZxk6X0Bm3\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2020-07-22\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 82.0, \"Danceability\": 0.789, \"Energy\": 0.711, \"Loudness\": -4.248, \"Speechiness\": 0.041, \"Acousticness\": 0.0332, \"Liveness\": 0.0876, \"Tempo\": 112.985, \"Duration (ms)\": 190306.0, \"Valence\": 0.753, \"Chord\": \"D\"}, {\"Index\": 454, \"Highest Charting Position\": 28, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Unstable (feat. The Kid LAROI)\", \"Streams\": 5137645, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"137mSruegm1u6x9NvwiagR\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 74.0, \"Danceability\": 0.495, \"Energy\": 0.333, \"Loudness\": -10.109, \"Speechiness\": 0.0288, \"Acousticness\": 0.737, \"Liveness\": 0.112, \"Tempo\": 99.757, \"Duration (ms)\": 158324.0, \"Valence\": 0.37, \"Chord\": \"E\"}, {\"Index\": 455, \"Highest Charting Position\": 2, \"Number of Times Charted\": 48, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Stuck with U (with Justin Bieber)\", \"Streams\": 5094660, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"4HBZA5flZLE435QTztThqH\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 84.0, \"Danceability\": 0.597, \"Energy\": 0.45, \"Loudness\": -6.658, \"Speechiness\": 0.0418, \"Acousticness\": 0.223, \"Liveness\": 0.382, \"Tempo\": 178.765, \"Duration (ms)\": 228482.0, \"Valence\": 0.537, \"Chord\": \"G#/Ab\"}, {\"Index\": 456, \"Highest Charting Position\": 120, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Hayloft\", \"Streams\": 5086382, \"Artist\": \"Mother Mother\", \"Artist Followers\": 2110870.0, \"Song ID\": \"2kS6td1yvmpNgZTt1q5pQq\", \"Genre\": \"['indie pop', 'vancouver indie']\", \"Release Date\": \"2008-09-23\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 81.0, \"Danceability\": 0.527, \"Energy\": 0.922, \"Loudness\": -2.666, \"Speechiness\": 0.0728, \"Acousticness\": 0.00475, \"Liveness\": 0.422, \"Tempo\": 95.975, \"Duration (ms)\": 181680.0, \"Valence\": 0.49, \"Chord\": \"A\"}, {\"Index\": 457, \"Highest Charting Position\": 191, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Esquema Preferido (feat. Tarc\\u00edsio do Acordeon)\", \"Streams\": 5078174, \"Artist\": \"DJ Ivis\", \"Artist Followers\": 342930.0, \"Song ID\": \"0e6NlGJxYlHvAN8SKxad7N\", \"Genre\": \"['piseiro']\", \"Release Date\": \"2020-11-26\", \"Weeks Charted\": \"2021-04-02--2021-04-09\", \"Popularity\": 73.0, \"Danceability\": 0.676, \"Energy\": 0.823, \"Loudness\": -4.386, \"Speechiness\": 0.102, \"Acousticness\": 0.242, \"Liveness\": 0.0773, \"Tempo\": 160.013, \"Duration (ms)\": 190680.0, \"Valence\": 0.907, \"Chord\": \"F\"}, {\"Index\": 458, \"Highest Charting Position\": 75, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Adem\\u00e1s de M\\u00ed - Remix\", \"Streams\": 5060336, \"Artist\": \"Rusherking, KHEA, Duki, Maria Becerra, LIT killah, Tiago PZK\", \"Artist Followers\": 301217.0, \"Song ID\": \"7I8L3vYCLThw2FDrE6LuzE\", \"Genre\": \"['trap argentino', 'trap latino', 'trap triste']\", \"Release Date\": \"2021-03-04\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 78.0, \"Danceability\": 0.397, \"Energy\": 0.613, \"Loudness\": -5.077, \"Speechiness\": 0.0549, \"Acousticness\": 0.0396, \"Liveness\": 0.192, \"Tempo\": 78.4, \"Duration (ms)\": 330040.0, \"Valence\": 0.405, \"Chord\": \"F#/Gb\"}, {\"Index\": 459, \"Highest Charting Position\": 193, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Payphone\", \"Streams\": 5052717, \"Artist\": \"Maroon 5, Wiz Khalifa\", \"Artist Followers\": 32279979.0, \"Song ID\": \"1LmN9SSHISbtp9LoaR5ZVJ\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2012-01-01\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 74.0, \"Danceability\": 0.739, \"Energy\": 0.756, \"Loudness\": -4.828, \"Speechiness\": 0.0394, \"Acousticness\": 0.0136, \"Liveness\": 0.37, \"Tempo\": 110.028, \"Duration (ms)\": 231387.0, \"Valence\": 0.523, \"Chord\": \"E\"}, {\"Index\": 460, \"Highest Charting Position\": 50, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Ghost\", \"Streams\": 5013450, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6I3mqTwhRpn34SLVafSH7G\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 71.0, \"Danceability\": 0.601, \"Energy\": 0.741, \"Loudness\": -5.569, \"Speechiness\": 0.0478, \"Acousticness\": 0.185, \"Liveness\": 0.415, \"Tempo\": 153.96, \"Duration (ms)\": 153190.0, \"Valence\": 0.441, \"Chord\": \"D\"}, {\"Index\": 461, \"Highest Charting Position\": 37, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Off My Face\", \"Streams\": 5004111, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"3T03rPwlL8NVk1yIaxeD8U\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 75.0, \"Danceability\": 0.509, \"Energy\": 0.228, \"Loudness\": -8.68, \"Speechiness\": 0.0332, \"Acousticness\": 0.92, \"Liveness\": 0.104, \"Tempo\": 90.674, \"Duration (ms)\": 156468.0, \"Valence\": 0.586, \"Chord\": \"E\"}, {\"Index\": 462, \"Highest Charting Position\": 140, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Whats Poppin (feat. DaBaby, Tory Lanez & Lil Wayne) [Remix] - Bonus Track\", \"Streams\": 4972518, \"Artist\": \"Jack Harlow\", \"Artist Followers\": 1053324.0, \"Song ID\": \"0ZLuW8uOXdFNWcI40C0OC2\", \"Genre\": \"['deep underground hip hop', 'kentucky hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\", \"Popularity\": 73.0, \"Danceability\": 0.904, \"Energy\": 0.723, \"Loudness\": -5.224, \"Speechiness\": 0.26, \"Acousticness\": 0.0631, \"Liveness\": 0.185, \"Tempo\": 145.013, \"Duration (ms)\": 227478.0, \"Valence\": 0.835, \"Chord\": \"B\"}, {\"Index\": 463, \"Highest Charting Position\": 188, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Take on Me\", \"Streams\": 4969662, \"Artist\": \"a-ha\", \"Artist Followers\": 1560784.0, \"Song ID\": \"2WfaOiMkCvy7F5fcp2zZ8L\", \"Genre\": \"['new romantic', 'new wave', 'new wave pop', 'permanent wave', 'soft rock', 'synthpop']\", \"Release Date\": \"1985-06-01\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 84.0, \"Danceability\": 0.573, \"Energy\": 0.902, \"Loudness\": -7.638, \"Speechiness\": 0.054, \"Acousticness\": 0.018, \"Liveness\": 0.0928, \"Tempo\": 84.412, \"Duration (ms)\": 225280.0, \"Valence\": 0.876, \"Chord\": \"F#/Gb\"}, {\"Index\": 464, \"Highest Charting Position\": 45, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"BEB\\u00c9\", \"Streams\": 4967348, \"Artist\": \"Camilo, El Alfa\", \"Artist Followers\": 10580764.0, \"Song ID\": \"7D7EH7MGyNHWSkqrszerI1\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-11-25\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 78.0, \"Danceability\": 0.862, \"Energy\": 0.72, \"Loudness\": -4.048, \"Speechiness\": 0.0379, \"Acousticness\": 0.487, \"Liveness\": 0.0604, \"Tempo\": 129.972, \"Duration (ms)\": 198707.0, \"Valence\": 0.965, \"Chord\": \"E\"}, {\"Index\": 465, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Richer (feat. Polo G)\", \"Streams\": 6292362, \"Artist\": \"Rod Wave\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-03-26--2021-04-02\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 466, \"Highest Charting Position\": 128, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Tu Veneno\", \"Streams\": 6007541, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"5KFHrrBMyGj5MhVbZMM3ts\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 76.0, \"Danceability\": 0.664, \"Energy\": 0.659, \"Loudness\": -4.232, \"Speechiness\": 0.0873, \"Acousticness\": 0.0625, \"Liveness\": 0.0874, \"Tempo\": 175.826, \"Duration (ms)\": 157320.0, \"Valence\": 0.797, \"Chord\": \"A#/Bb\"}, {\"Index\": 467, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Deserve You\", \"Streams\": 5837372, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5NU40QTlXrDUJzDBdv79bg\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 69.0, \"Danceability\": 0.677, \"Energy\": 0.633, \"Loudness\": -7.831, \"Speechiness\": 0.0771, \"Acousticness\": 0.0314, \"Liveness\": 0.112, \"Tempo\": 89.934, \"Duration (ms)\": 187239.0, \"Valence\": 0.409, \"Chord\": \"G\"}, {\"Index\": 468, \"Highest Charting Position\": 44, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"2 Much\", \"Streams\": 5794583, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"0oaY19dUwZimIgzn3ZZLZO\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 70.0, \"Danceability\": 0.583, \"Energy\": 0.444, \"Loudness\": -8.601, \"Speechiness\": 0.0456, \"Acousticness\": 0.593, \"Liveness\": 0.353, \"Tempo\": 119.59, \"Duration (ms)\": 152796.0, \"Valence\": 0.167, \"Chord\": \"A\"}, {\"Index\": 469, \"Highest Charting Position\": 3, \"Number of Times Charted\": 66, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Tusa\", \"Streams\": 5510113, \"Artist\": \"KAROL G, Nicki Minaj\", \"Artist Followers\": 17792779.0, \"Song ID\": \"7k4t7uLgtOxPwTpFmtJNTY\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.803, \"Energy\": 0.715, \"Loudness\": -3.28, \"Speechiness\": 0.298, \"Acousticness\": 0.295, \"Liveness\": 0.0574, \"Tempo\": 101.085, \"Duration (ms)\": 200960.0, \"Valence\": 0.574, \"Chord\": \"D\"}, {\"Index\": 470, \"Highest Charting Position\": 34, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Una Locura\", \"Streams\": 5466954, \"Artist\": \"Ozuna, J Balvin, Chencho Corleone\", \"Artist Followers\": 29238936.0, \"Song ID\": \"5y7DaS3jAc9eZzcSOoUIwU\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 81.0, \"Danceability\": 0.714, \"Energy\": 0.761, \"Loudness\": -4.596, \"Speechiness\": 0.0427, \"Acousticness\": 0.139, \"Liveness\": 0.241, \"Tempo\": 168.022, \"Duration (ms)\": 230693.0, \"Valence\": 0.906, \"Chord\": \"F\"}, {\"Index\": 471, \"Highest Charting Position\": 61, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Loved By You (feat. Burna Boy)\", \"Streams\": 5419040, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2tB9OFgAHjAds3cqquLlvp\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 69.0, \"Danceability\": 0.79, \"Energy\": 0.724, \"Loudness\": -6.972, \"Speechiness\": 0.0852, \"Acousticness\": 0.0696, \"Liveness\": 0.113, \"Tempo\": 101.04, \"Duration (ms)\": 159250.0, \"Valence\": 0.642, \"Chord\": \"C#/Db\"}, {\"Index\": 472, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Girls Like Us\", \"Streams\": 5410730, \"Artist\": \"Zoe Wees\", \"Artist Followers\": 203555.0, \"Song ID\": \"5SFXOMJJ334Wn2PwBHeRZN\", \"Genre\": \"['german pop']\", \"Release Date\": \"2021-01-12\", \"Weeks Charted\": \"2021-03-26--2021-04-02\", \"Popularity\": 78.0, \"Danceability\": 0.444, \"Energy\": 0.648, \"Loudness\": -4.955, \"Speechiness\": 0.0476, \"Acousticness\": 0.288, \"Liveness\": 0.059, \"Tempo\": 125.706, \"Duration (ms)\": 189000.0, \"Valence\": 0.171, \"Chord\": \"C#/Db\"}, {\"Index\": 473, \"Highest Charting Position\": 17, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Lemon Pepper Freestyle (feat. Rick Ross)\", \"Streams\": 5365747, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"4FRW5Nza1Ym91BGV4nFWXI\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 76.0, \"Danceability\": 0.77, \"Energy\": 0.637, \"Loudness\": -5.53, \"Speechiness\": 0.345, \"Acousticness\": 0.103, \"Liveness\": 0.171, \"Tempo\": 94.966, \"Duration (ms)\": 383037.0, \"Valence\": 0.431, \"Chord\": \"C#/Db\"}, {\"Index\": 474, \"Highest Charting Position\": 97, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Esquema Preferido\", \"Streams\": 5356696, \"Artist\": \"DJ Ivis, Tarc\\u00edsio do Acordeon\", \"Artist Followers\": 342930.0, \"Song ID\": \"0e6NlGJxYlHvAN8SKxad7N\", \"Genre\": \"['piseiro']\", \"Release Date\": \"2020-11-26\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 73.0, \"Danceability\": 0.676, \"Energy\": 0.823, \"Loudness\": -4.386, \"Speechiness\": 0.102, \"Acousticness\": 0.242, \"Liveness\": 0.0773, \"Tempo\": 160.013, \"Duration (ms)\": 190680.0, \"Valence\": 0.907, \"Chord\": \"F\"}, {\"Index\": 475, \"Highest Charting Position\": 105, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Love Not War (The Tampa Beat)\", \"Streams\": 5326719, \"Artist\": \"Jason Derulo, Nuka\", \"Artist Followers\": 9778632.0, \"Song ID\": \"4Lt6GXGzYsa1tgkv3nGSTm\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 79.0, \"Danceability\": 0.738, \"Energy\": 0.85, \"Loudness\": -3.049, \"Speechiness\": 0.0642, \"Acousticness\": 0.105, \"Liveness\": 0.23, \"Tempo\": 98.013, \"Duration (ms)\": 192921.0, \"Valence\": 0.865, \"Chord\": \"G#/Ab\"}, {\"Index\": 476, \"Highest Charting Position\": 57, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Die For You (feat. Dominic Fike)\", \"Streams\": 5323412, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"7aely3H8kMj9o0gt6vXHE1\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 67.0, \"Danceability\": 0.728, \"Energy\": 0.629, \"Loudness\": -6.629, \"Speechiness\": 0.0318, \"Acousticness\": 0.00196, \"Liveness\": 0.0847, \"Tempo\": 135.031, \"Duration (ms)\": 198426.0, \"Valence\": 0.71, \"Chord\": \"C#/Db\"}, {\"Index\": 477, \"Highest Charting Position\": 64, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Starboy\", \"Streams\": 5302285, \"Artist\": \"The Weeknd, Daft Punk\", \"Artist Followers\": 35340069.0, \"Song ID\": \"7MXVkk9YMctZqd1Srtv4MB\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2016-11-25\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 83.0, \"Danceability\": 0.679, \"Energy\": 0.587, \"Loudness\": -7.015, \"Speechiness\": 0.276, \"Acousticness\": 0.141, \"Liveness\": 0.137, \"Tempo\": 186.003, \"Duration (ms)\": 230453.0, \"Valence\": 0.486, \"Chord\": \"G\"}, {\"Index\": 478, \"Highest Charting Position\": 22, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"La T\\u00f3xica\", \"Streams\": 5255393, \"Artist\": \"Farruko\", \"Artist Followers\": 10510156.0, \"Song ID\": \"15OjBeqNX3bShsGYQbteRv\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 78.0, \"Danceability\": 0.659, \"Energy\": 0.701, \"Loudness\": -4.107, \"Speechiness\": 0.164, \"Acousticness\": 0.0882, \"Liveness\": 0.0866, \"Tempo\": 91.97, \"Duration (ms)\": 180520.0, \"Valence\": 0.623, \"Chord\": \"A\"}, {\"Index\": 479, \"Highest Charting Position\": 181, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Cora\\u00e7\\u00e3o Na Cama - Ao Vivo\", \"Streams\": 5211351, \"Artist\": \"Hugo & Guilherme\", \"Artist Followers\": 435936.0, \"Song ID\": \"2nZj5YymF54qhAu7RneVP6\", \"Genre\": \"['sertanejo pop']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 77.0, \"Danceability\": 0.764, \"Energy\": 0.794, \"Loudness\": -4.096, \"Speechiness\": 0.0589, \"Acousticness\": 0.663, \"Liveness\": 0.34, \"Tempo\": 110.013, \"Duration (ms)\": 173227.0, \"Valence\": 0.721, \"Chord\": \"G#/Ab\"}, {\"Index\": 480, \"Highest Charting Position\": 60, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Love You Different (feat. BEAM)\", \"Streams\": 10024729, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"27UcQ6dAvQrgH9C880rCM3\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-19--2021-03-26\", \"Popularity\": 66.0, \"Danceability\": 0.759, \"Energy\": 0.584, \"Loudness\": -6.655, \"Speechiness\": 0.06, \"Acousticness\": 0.0652, \"Liveness\": 0.16, \"Tempo\": 127.138, \"Duration (ms)\": 186696.0, \"Valence\": 0.374, \"Chord\": \"G#/Ab\"}, {\"Index\": 481, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Somebody\", \"Streams\": 8912458, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"3rLIv187BhjyweFe89SgLn\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2010-01-01\", \"Weeks Charted\": \"2021-03-19--2021-03-26\", \"Popularity\": 67.0, \"Danceability\": 0.714, \"Energy\": 0.833, \"Loudness\": -5.239, \"Speechiness\": 0.0259, \"Acousticness\": 0.00249, \"Liveness\": 0.298, \"Tempo\": 129.964, \"Duration (ms)\": 220920.0, \"Valence\": 0.663, \"Chord\": \"F\"}, {\"Index\": 482, \"Highest Charting Position\": 152, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"White Dress\", \"Streams\": 5796978, \"Artist\": \"Lana Del Rey\", \"Artist Followers\": 13697048.0, \"Song ID\": \"4Hl9rOqYomojCmxYfr25im\", \"Genre\": \"['art pop', 'pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-19--2021-03-26\", \"Popularity\": 65.0, \"Danceability\": 0.493, \"Energy\": 0.263, \"Loudness\": -12.805, \"Speechiness\": 0.0351, \"Acousticness\": 0.926, \"Liveness\": 0.0879, \"Tempo\": 122.792, \"Duration (ms)\": 333710.0, \"Valence\": 0.158, \"Chord\": \"C\"}, {\"Index\": 483, \"Highest Charting Position\": 82, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Polvo\", \"Streams\": 5528508, \"Artist\": \"Nicky Jam, Myke Towers\", \"Artist Followers\": 14831925.0, \"Song ID\": \"68mrW6gXHgupgSiDHgaDi5\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 76.0, \"Danceability\": 0.763, \"Energy\": 0.621, \"Loudness\": -6.169, \"Speechiness\": 0.066, \"Acousticness\": 0.0105, \"Liveness\": 0.106, \"Tempo\": 82.042, \"Duration (ms)\": 211130.0, \"Valence\": 0.582, \"Chord\": \"B\"}, {\"Index\": 484, \"Highest Charting Position\": 138, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Chemtrails Over The Country Club\", \"Streams\": 5418816, \"Artist\": \"Lana Del Rey\", \"Artist Followers\": 13697048.0, \"Song ID\": \"7bPWdJgx8vek7S5i5yAtvG\", \"Genre\": \"['art pop', 'pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-01-15--2021-01-22\", \"Popularity\": 73.0, \"Danceability\": 0.334, \"Energy\": 0.276, \"Loudness\": -13.125, \"Speechiness\": 0.0643, \"Acousticness\": 0.877, \"Liveness\": 0.113, \"Tempo\": 201.025, \"Duration (ms)\": 271177.0, \"Valence\": 0.429, \"Chord\": \"E\"}, {\"Index\": 485, \"Highest Charting Position\": 37, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Parce (feat. Justin Quiles)\", \"Streams\": 5312876, \"Artist\": \"Maluma, Lenny Tav\\u00e1rez\", \"Artist Followers\": 26769304.0, \"Song ID\": \"4RJz8NfIe09gpKMiRUWKhJ\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 78.0, \"Danceability\": 0.691, \"Energy\": 0.739, \"Loudness\": -3.09, \"Speechiness\": 0.229, \"Acousticness\": 0.422, \"Liveness\": 0.11, \"Tempo\": 83.897, \"Duration (ms)\": 248345.0, \"Valence\": 0.884, \"Chord\": \"F\"}, {\"Index\": 486, \"Highest Charting Position\": 40, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Ropa Cara\", \"Streams\": 5249427, \"Artist\": \"Camilo\", \"Artist Followers\": 10580764.0, \"Song ID\": \"7BIy3EGQhg98CsRdKYHnJC\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2021-01-18\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 73.0, \"Danceability\": 0.813, \"Energy\": 0.526, \"Loudness\": -4.787, \"Speechiness\": 0.125, \"Acousticness\": 0.105, \"Liveness\": 0.11, \"Tempo\": 170.002, \"Duration (ms)\": 163320.0, \"Valence\": 0.608, \"Chord\": \"E\"}, {\"Index\": 487, \"Highest Charting Position\": 25, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Vida de Rico\", \"Streams\": 5189822, \"Artist\": \"Camilo\", \"Artist Followers\": 10580764.0, \"Song ID\": \"73nAK3HgQK8dak83Y2WQ8F\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-09-21\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 79.0, \"Danceability\": 0.824, \"Energy\": 0.457, \"Loudness\": -5.428, \"Speechiness\": 0.0543, \"Acousticness\": 0.167, \"Liveness\": 0.041, \"Tempo\": 87.977, \"Duration (ms)\": 187427.0, \"Valence\": 0.95, \"Chord\": \"F#/Gb\"}, {\"Index\": 488, \"Highest Charting Position\": 182, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Devil Eyes\", \"Streams\": 5098581, \"Artist\": \"Hippie Sabotage\", \"Artist Followers\": 713486.0, \"Song ID\": \"7MiZjKawmXTsTNePyTfPyL\", \"Genre\": \"['edm', 'electronic trap']\", \"Release Date\": \"2016-02-05\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 80.0, \"Danceability\": 0.391, \"Energy\": 0.396, \"Loudness\": -8.621, \"Speechiness\": 0.189, \"Acousticness\": 0.702, \"Liveness\": 0.315, \"Tempo\": 99.112, \"Duration (ms)\": 131272.0, \"Valence\": 0.199, \"Chord\": \"C#/Db\"}, {\"Index\": 489, \"Highest Charting Position\": 141, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Ponte Pa' Mi\", \"Streams\": 5082870, \"Artist\": \"Justin Quiles\", \"Artist Followers\": 2897862.0, \"Song ID\": \"4C6BlqqMwjFzOXzqpTeoWR\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 76.0, \"Danceability\": 0.878, \"Energy\": 0.713, \"Loudness\": -4.566, \"Speechiness\": 0.0948, \"Acousticness\": 0.0581, \"Liveness\": 0.0822, \"Tempo\": 92.028, \"Duration (ms)\": 202373.0, \"Valence\": 0.615, \"Chord\": \"F\"}, {\"Index\": 490, \"Highest Charting Position\": 109, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"D\\u00e1melo To\\u2019 (feat. Myke Towers)\", \"Streams\": 6426522, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"36CiGk9oRdwTnBDMgKEfjl\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 64.0, \"Danceability\": 0.787, \"Energy\": 0.641, \"Loudness\": -7.376, \"Speechiness\": 0.315, \"Acousticness\": 0.101, \"Liveness\": 0.07, \"Tempo\": 182.003, \"Duration (ms)\": 184134.0, \"Valence\": 0.437, \"Chord\": \"G#/Ab\"}, {\"Index\": 491, \"Highest Charting Position\": 121, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Patience (feat. YUNGBLUD & Polo G)\", \"Streams\": 6155698, \"Artist\": \"KSI\", \"Artist Followers\": 2010879.0, \"Song ID\": \"5J5CpT6bgE6KYKk23jgp9W\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 71.0, \"Danceability\": 0.616, \"Energy\": 0.741, \"Loudness\": -4.272, \"Speechiness\": 0.0426, \"Acousticness\": 0.00251, \"Liveness\": 0.307, \"Tempo\": 122.012, \"Duration (ms)\": 181720.0, \"Valence\": 0.431, \"Chord\": \"G\"}, {\"Index\": 492, \"Highest Charting Position\": 56, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Selfish Love (with Selena Gomez)\", \"Streams\": 6020785, \"Artist\": \"DJ Snake\", \"Artist Followers\": 7408249.0, \"Song ID\": \"3XoflnowYPFRPOh3uFvHcm\", \"Genre\": \"['dance pop', 'edm', 'electronic trap', 'pop', 'pop dance']\", \"Release Date\": \"2021-03-04\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 74.0, \"Danceability\": 0.723, \"Energy\": 0.646, \"Loudness\": -7.973, \"Speechiness\": 0.102, \"Acousticness\": 0.0206, \"Liveness\": 0.0994, \"Tempo\": 110.971, \"Duration (ms)\": 168649.0, \"Valence\": 0.443, \"Chord\": \"F\"}, {\"Index\": 493, \"Highest Charting Position\": 12, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Snowman\", \"Streams\": 5454807, \"Artist\": \"Sia\", \"Artist Followers\": 20528724.0, \"Song ID\": \"7uoFMmxln0GPXQ0AcCBXRq\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'pop']\", \"Release Date\": \"2018-11-01\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 77.0, \"Danceability\": 0.716, \"Energy\": 0.512, \"Loudness\": -6.257, \"Speechiness\": 0.0331, \"Acousticness\": 0.483, \"Liveness\": 0.0928, \"Tempo\": 104.957, \"Duration (ms)\": 165907.0, \"Valence\": 0.326, \"Chord\": \"C#/Db\"}, {\"Index\": 494, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"DAYWALKER! (feat. CORPSE)\", \"Streams\": 5439646, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3868320.0, \"Song ID\": \"2NnJpRXIlx35Vij3bPZO0h\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 74.0, \"Danceability\": 0.632, \"Energy\": 0.922, \"Loudness\": -2.173, \"Speechiness\": 0.0794, \"Acousticness\": 0.00558, \"Liveness\": 0.0927, \"Tempo\": 88.972, \"Duration (ms)\": 137747.0, \"Valence\": 0.497, \"Chord\": \"G\"}, {\"Index\": 495, \"Highest Charting Position\": 19, \"Number of Times Charted\": 38, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"La Curiosidad\", \"Streams\": 5198514, \"Artist\": \"Jay Wheeler, DJ Nelson, Myke Towers\", \"Artist Followers\": 1650912.0, \"Song ID\": \"4HYDUMY0xSpeBr0AMY9cUz\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 82.0, \"Danceability\": 0.845, \"Energy\": 0.677, \"Loudness\": -4.798, \"Speechiness\": 0.136, \"Acousticness\": 0.269, \"Liveness\": 0.108, \"Tempo\": 90.013, \"Duration (ms)\": 219048.0, \"Valence\": 0.68, \"Chord\": \"B\"}, {\"Index\": 496, \"Highest Charting Position\": 86, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"All We Got (feat. KIDDO)\", \"Streams\": 5156937, \"Artist\": \"Robin Schulz\", \"Artist Followers\": 2786366.0, \"Song ID\": \"1FP9s72rDYty6mfoOEYKnE\", \"Genre\": \"['dance pop', 'deep euro house', 'deep house', 'edm', 'german dance', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 74.0, \"Danceability\": 0.504, \"Energy\": 0.76, \"Loudness\": -4.246, \"Speechiness\": 0.0426, \"Acousticness\": 0.286, \"Liveness\": 0.151, \"Tempo\": 183.933, \"Duration (ms)\": 190218.0, \"Valence\": 0.64, \"Chord\": \"E\"}, {\"Index\": 497, \"Highest Charting Position\": 6, \"Number of Times Charted\": 60, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Say So\", \"Streams\": 5103528, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"3Dv1eDb0MEgF93GpLXlucZ\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-02-26--2021-03-05\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.787, \"Energy\": 0.673, \"Loudness\": -4.583, \"Speechiness\": 0.159, \"Acousticness\": 0.264, \"Liveness\": 0.0904, \"Tempo\": 110.962, \"Duration (ms)\": 237893.0, \"Valence\": 0.779, \"Chord\": \"B\"}, {\"Index\": 498, \"Highest Charting Position\": 157, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Hope\", \"Streams\": 5085527, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"2ZRo7axmMPeSVUvDbGkJah\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2018-03-16\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 84.0, \"Danceability\": 0.592, \"Energy\": 0.457, \"Loudness\": -6.081, \"Speechiness\": 0.0603, \"Acousticness\": 0.661, \"Liveness\": 0.146, \"Tempo\": 146.04, \"Duration (ms)\": 110886.0, \"Valence\": 0.225, \"Chord\": \"A\"}, {\"Index\": 499, \"Highest Charting Position\": 149, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"The Less I Know The Better\", \"Streams\": 5084635, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"6K4t31amVTZDgR3sKmwUJJ\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2015-07-17\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-01-03--2020-01-10\", \"Popularity\": 84.0, \"Danceability\": 0.64, \"Energy\": 0.74, \"Loudness\": -4.083, \"Speechiness\": 0.0284, \"Acousticness\": 0.0115, \"Liveness\": 0.167, \"Tempo\": 116.879, \"Duration (ms)\": 216320.0, \"Valence\": 0.785, \"Chord\": \"E\"}, {\"Index\": 500, \"Highest Charting Position\": 109, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"I Feel It Coming\", \"Streams\": 5079857, \"Artist\": \"The Weeknd, Daft Punk\", \"Artist Followers\": 35340069.0, \"Song ID\": \"3dhjNA0jGA8vHBQ1VdD6vV\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2016-11-25\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 80.0, \"Danceability\": 0.773, \"Energy\": 0.819, \"Loudness\": -5.946, \"Speechiness\": 0.118, \"Acousticness\": 0.428, \"Liveness\": 0.0679, \"Tempo\": 92.987, \"Duration (ms)\": 269187.0, \"Valence\": 0.585, \"Chord\": \"C\"}, {\"Index\": 501, \"Highest Charting Position\": 12, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Mood Swings (feat. Lil Tjay)\", \"Streams\": 5068349, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"5rZlwNFl01HqLWBQGryKSm\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 82.0, \"Danceability\": 0.48, \"Energy\": 0.602, \"Loudness\": -6.335, \"Speechiness\": 0.368, \"Acousticness\": 0.487, \"Liveness\": 0.0848, \"Tempo\": 179.798, \"Duration (ms)\": 213333.0, \"Valence\": 0.269, \"Chord\": \"A#/Bb\"}, {\"Index\": 502, \"Highest Charting Position\": 123, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Someone To You\", \"Streams\": 5054881, \"Artist\": \"BANNERS\", \"Artist Followers\": 419151.0, \"Song ID\": \"2f0pn9DkEJwAzXApnFh5cr\", \"Genre\": \"['indie cafe pop', 'indie poptimism', 'modern rock', 'pop', 'pop rock']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 79.0, \"Danceability\": 0.52, \"Energy\": 0.903, \"Loudness\": -5.497, \"Speechiness\": 0.042, \"Acousticness\": 0.00517, \"Liveness\": 0.254, \"Tempo\": 74.988, \"Duration (ms)\": 219801.0, \"Valence\": 0.652, \"Chord\": \"D\"}, {\"Index\": 503, \"Highest Charting Position\": 198, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"To the Bone\", \"Streams\": 5052557, \"Artist\": \"Pamungkas\", \"Artist Followers\": 1643882.0, \"Song ID\": \"3pCt2wRdBDa2kCisIdHWgF\", \"Genre\": \"['indonesian pop']\", \"Release Date\": \"2019-06-14\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 81.0, \"Danceability\": 0.668, \"Energy\": 0.727, \"Loudness\": -6.55, \"Speechiness\": 0.027, \"Acousticness\": 0.514, \"Liveness\": 0.1, \"Tempo\": 139.991, \"Duration (ms)\": 344571.0, \"Valence\": 0.939, \"Chord\": \"G\"}, {\"Index\": 504, \"Highest Charting Position\": 4, \"Number of Times Charted\": 38, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"How You Like That\", \"Streams\": 5023592, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"4SFknyjLcyTLJFPKD2m96o\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 79.0, \"Danceability\": 0.812, \"Energy\": 0.761, \"Loudness\": -5.222, \"Speechiness\": 0.0812, \"Acousticness\": 0.0465, \"Liveness\": 0.0601, \"Tempo\": 130.032, \"Duration (ms)\": 182956.0, \"Valence\": 0.344, \"Chord\": \"B\"}, {\"Index\": 505, \"Highest Charting Position\": 200, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"LOST\", \"Streams\": 5013851, \"Artist\": \"NF, Hopsin\", \"Artist Followers\": 5831194.0, \"Song ID\": \"2MZrOmrVxRmmOoFW6dhenG\", \"Genre\": \"['hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2021-03-11\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 66.0, \"Danceability\": 0.637, \"Energy\": 0.912, \"Loudness\": -3.123, \"Speechiness\": 0.308, \"Acousticness\": 0.352, \"Liveness\": 0.0657, \"Tempo\": 116.919, \"Duration (ms)\": 234852.0, \"Valence\": 0.451, \"Chord\": \"F\"}, {\"Index\": 506, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"VOCE\", \"Streams\": 5510906, \"Artist\": \"Madame\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6CAVxdHTkls5loqUmfM52V\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 0.0, \"Danceability\": 0.615, \"Energy\": 0.834, \"Loudness\": -5.471, \"Speechiness\": 0.0667, \"Acousticness\": 0.105, \"Liveness\": 0.157, \"Tempo\": 112.602, \"Duration (ms)\": 211411.0, \"Valence\": 0.341, \"Chord\": \"G#/Ab\"}, {\"Index\": 507, \"Highest Charting Position\": 64, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"AP - Music from the film Boogie\", \"Streams\": 5462333, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"17vGPZ5EsdvtgAOCD4FLWI\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\", \"Popularity\": 75.0, \"Danceability\": 0.751, \"Energy\": 0.744, \"Loudness\": -6.859, \"Speechiness\": 0.177, \"Acousticness\": 0.152, \"Liveness\": 0.252, \"Tempo\": 148.014, \"Duration (ms)\": 171892.0, \"Valence\": 0.634, \"Chord\": \"C#/Db\"}, {\"Index\": 508, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Life's A Mess II (with Clever & Post Malone)\", \"Streams\": 5393459, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4O3RwH1TFG1EjPezLIYehI\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 72.0, \"Danceability\": 0.53, \"Energy\": 0.37, \"Loudness\": -9.989, \"Speechiness\": 0.0279, \"Acousticness\": 0.806, \"Liveness\": 0.112, \"Tempo\": 140.061, \"Duration (ms)\": 206734.0, \"Valence\": 0.701, \"Chord\": \"F#/Gb\"}, {\"Index\": 509, \"Highest Charting Position\": 170, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"CHIAMAMI PER NOME\", \"Streams\": 5321946, \"Artist\": \"Francesca Michielin, Fedez\", \"Artist Followers\": 568711.0, \"Song ID\": \"0ZqHo6eTBHUcOVjZzPvftT\", \"Genre\": \"['italian adult pop', 'italian indie pop', 'italian pop', 'italian pop rock']\", \"Release Date\": \"2021-03-03\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 67.0, \"Danceability\": 0.641, \"Energy\": 0.636, \"Loudness\": -4.318, \"Speechiness\": 0.0414, \"Acousticness\": 0.289, \"Liveness\": 0.125, \"Tempo\": 89.826, \"Duration (ms)\": 222667.0, \"Valence\": 0.285, \"Chord\": \"A#/Bb\"}, {\"Index\": 510, \"Highest Charting Position\": 54, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Antes\", \"Streams\": 5232377, \"Artist\": \"Anuel AA, Ozuna\", \"Artist Followers\": 18306226.0, \"Song ID\": \"73O30uMI7n6DuzBmbtO7kC\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 73.0, \"Danceability\": 0.817, \"Energy\": 0.737, \"Loudness\": -5.453, \"Speechiness\": 0.102, \"Acousticness\": 0.046, \"Liveness\": 0.092, \"Tempo\": 93.985, \"Duration (ms)\": 206587.0, \"Valence\": 0.67, \"Chord\": \"F#/Gb\"}, {\"Index\": 511, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Mona Lisa\", \"Streams\": 5208787, \"Artist\": \"Booba, JSX\", \"Artist Followers\": 2161609.0, \"Song ID\": \"5LYRIyhmlrDAQsYdHEvP0f\", \"Genre\": \"['french hip hop', 'old school rap francais', 'pop urbaine', 'rap conscient']\", \"Release Date\": \"2021-03-04\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 72.0, \"Danceability\": 0.784, \"Energy\": 0.529, \"Loudness\": -7.681, \"Speechiness\": 0.0742, \"Acousticness\": 0.683, \"Liveness\": 0.118, \"Tempo\": 134.041, \"Duration (ms)\": 187362.0, \"Valence\": 0.246, \"Chord\": \"B\"}, {\"Index\": 512, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Real As It Gets (feat. EST Gee)\", \"Streams\": 5170861, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"7eX3um6NpOQKWJMGCi97XD\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2021-03-04\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 74.0, \"Danceability\": 0.779, \"Energy\": 0.705, \"Loudness\": -5.891, \"Speechiness\": 0.163, \"Acousticness\": 0.00471, \"Liveness\": 0.0971, \"Tempo\": 140.005, \"Duration (ms)\": 192804.0, \"Valence\": 0.196, \"Chord\": \"F#/Gb\"}, {\"Index\": 513, \"Highest Charting Position\": 24, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Se Te Nota (with Guaynaa)\", \"Streams\": 5168240, \"Artist\": \"Lele Pons\", \"Artist Followers\": 786461.0, \"Song ID\": \"11EnQRgRMJwMAesfkB5pnu\", \"Genre\": \"['latin pop', 'viral pop']\", \"Release Date\": \"2020-09-02\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 77.0, \"Danceability\": 0.905, \"Energy\": 0.686, \"Loudness\": -3.152, \"Speechiness\": 0.0664, \"Acousticness\": 0.0907, \"Liveness\": 0.266, \"Tempo\": 103.013, \"Duration (ms)\": 155825.0, \"Valence\": 0.963, \"Chord\": \"C\"}, {\"Index\": 514, \"Highest Charting Position\": 91, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Head Shoulders Knees & Toes (feat. Norma Jean Martine)\", \"Streams\": 5093408, \"Artist\": \"Ofenbach, Quarterhead\", \"Artist Followers\": 432511.0, \"Song ID\": \"6i7zAdNhzUN2k1HcrBxPHG\", \"Genre\": \"['edm', 'new french touch', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 79.0, \"Danceability\": 0.798, \"Energy\": 0.828, \"Loudness\": -5.36, \"Speechiness\": 0.193, \"Acousticness\": 0.0247, \"Liveness\": 0.121, \"Tempo\": 124.962, \"Duration (ms)\": 156960.0, \"Valence\": 0.6, \"Chord\": \"D\"}, {\"Index\": 515, \"Highest Charting Position\": 152, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Star Shopping\", \"Streams\": 5073657, \"Artist\": \"Lil Peep\", \"Artist Followers\": 7535054.0, \"Song ID\": \"30bqVoKjX479ab90a8Pafp\", \"Genre\": \"['emo rap', 'lgbtq+ hip hop']\", \"Release Date\": \"2015\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 82.0, \"Danceability\": 0.585, \"Energy\": 0.471, \"Loudness\": -9.934, \"Speechiness\": 0.0616, \"Acousticness\": 0.0967, \"Liveness\": 0.115, \"Tempo\": 93.099, \"Duration (ms)\": 142000.0, \"Valence\": 0.323, \"Chord\": \"E\"}, {\"Index\": 516, \"Highest Charting Position\": 61, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Electric Love\", \"Streams\": 5060903, \"Artist\": \"B\\u00d8RNS\", \"Artist Followers\": 1027085.0, \"Song ID\": \"2GiJYvgVaD2HtM8GqD9EgQ\", \"Genre\": \"['modern alternative rock', 'modern rock', 'pop']\", \"Release Date\": \"2015-10-16\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 83.0, \"Danceability\": 0.611, \"Energy\": 0.797, \"Loudness\": -7.627, \"Speechiness\": 0.0533, \"Acousticness\": 0.00543, \"Liveness\": 0.26, \"Tempo\": 120.041, \"Duration (ms)\": 218107.0, \"Valence\": 0.518, \"Chord\": \"F#/Gb\"}, {\"Index\": 517, \"Highest Charting Position\": 112, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Maniac\", \"Streams\": 5044929, \"Artist\": \"Conan Gray\", \"Artist Followers\": 3799104.0, \"Song ID\": \"6KfoDhO4XUWSbnyKjNp9c4\", \"Genre\": \"['alt z', 'bedroom pop', 'electropop', 'indie pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.628, \"Energy\": 0.639, \"Loudness\": -5.46, \"Speechiness\": 0.0435, \"Acousticness\": 0.00162, \"Liveness\": 0.354, \"Tempo\": 108.045, \"Duration (ms)\": 185773.0, \"Valence\": 0.493, \"Chord\": \"G#/Ab\"}, {\"Index\": 518, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Only Wanna Be With You - Pok\\u00e9mon 25 Version\", \"Streams\": 7464020, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"3SawmGBjjq8EOYZJV11cJm\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2021-02-25\", \"Weeks Charted\": \"2021-02-26--2021-03-05\", \"Popularity\": 72.0, \"Danceability\": 0.47, \"Energy\": 0.709, \"Loudness\": -4.563, \"Speechiness\": 0.0299, \"Acousticness\": 0.00124, \"Liveness\": 0.302, \"Tempo\": 98.036, \"Duration (ms)\": 241360.0, \"Valence\": 0.247, \"Chord\": \"G\"}, {\"Index\": 519, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"test drive\", \"Streams\": 6591829, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3eZYOQO4UzKrUDYDghtnFw\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-02-19\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 71.0, \"Danceability\": 0.698, \"Energy\": 0.708, \"Loudness\": -4.943, \"Speechiness\": 0.0454, \"Acousticness\": 0.0251, \"Liveness\": 0.124, \"Tempo\": 115.036, \"Duration (ms)\": 122174.0, \"Valence\": 0.322, \"Chord\": \"A\"}, {\"Index\": 520, \"Highest Charting Position\": 42, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"T\\u00fa Me Dejaste De Querer\", \"Streams\": 5874460, \"Artist\": \"C. Tangana, Ni\\u00f1o de Elche, La H\\u00fangara\", \"Artist Followers\": 1453875.0, \"Song ID\": \"5ddFjrPG8NgQQ6xlOQIVd2\", \"Genre\": \"['urbano espanol']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 75.0, \"Danceability\": 0.823, \"Energy\": 0.723, \"Loudness\": -4.778, \"Speechiness\": 0.229, \"Acousticness\": 0.311, \"Liveness\": 0.0998, \"Tempo\": 83.97, \"Duration (ms)\": 198493.0, \"Valence\": 0.505, \"Chord\": \"E\"}, {\"Index\": 521, \"Highest Charting Position\": 46, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"SO DONE\", \"Streams\": 5440707, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"5psEZhQu6lukjhavJo4AbC\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-10-23\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 74.0, \"Danceability\": 0.719, \"Energy\": 0.598, \"Loudness\": -6.254, \"Speechiness\": 0.077, \"Acousticness\": 0.232, \"Liveness\": 0.115, \"Tempo\": 142.592, \"Duration (ms)\": 126521.0, \"Valence\": 0.303, \"Chord\": \"A\"}, {\"Index\": 522, \"Highest Charting Position\": 35, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Jeans\", \"Streams\": 5145966, \"Artist\": \"Justin Quiles\", \"Artist Followers\": 2897862.0, \"Song ID\": \"3GtnId3Cm1Xa6joCj08nzW\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 75.0, \"Danceability\": 0.807, \"Energy\": 0.656, \"Loudness\": -4.395, \"Speechiness\": 0.105, \"Acousticness\": 0.0165, \"Liveness\": 0.0693, \"Tempo\": 83.943, \"Duration (ms)\": 185840.0, \"Valence\": 0.89, \"Chord\": \"D#/Eb\"}, {\"Index\": 523, \"Highest Charting Position\": 2, \"Number of Times Charted\": 61, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"ROXANNE\", \"Streams\": 5124742, \"Artist\": \"Arizona Zervas\", \"Artist Followers\": 621200.0, \"Song ID\": \"696DnlkuDOXcMAnKlTgXXK\", \"Genre\": \"['pop rap', 'rhode island rap']\", \"Release Date\": \"2019-10-10\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.621, \"Energy\": 0.601, \"Loudness\": -5.616, \"Speechiness\": 0.148, \"Acousticness\": 0.0522, \"Liveness\": 0.46, \"Tempo\": 116.735, \"Duration (ms)\": 163636.0, \"Valence\": 0.457, \"Chord\": \"F#/Gb\"}, {\"Index\": 524, \"Highest Charting Position\": 83, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"rockstar (feat. 21 Savage)\", \"Streams\": 5115990, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"0e7ipj03S05BNilyu5bRzt\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2018-04-27\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-01-29--2021-02-05\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.585, \"Energy\": 0.52, \"Loudness\": -6.136, \"Speechiness\": 0.0712, \"Acousticness\": 0.124, \"Liveness\": 0.131, \"Tempo\": 159.801, \"Duration (ms)\": 218147.0, \"Valence\": 0.129, \"Chord\": \"F\"}, {\"Index\": 525, \"Highest Charting Position\": 185, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"P\\u00e1rteme La Cara\", \"Streams\": 5079580, \"Artist\": \"C. Tangana, Ed Maverick\", \"Artist Followers\": 1453875.0, \"Song ID\": \"5gEUDNQvoQjdjklrwPdGwD\", \"Genre\": \"['urbano espanol']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-02-26--2021-03-05\", \"Popularity\": 70.0, \"Danceability\": 0.761, \"Energy\": 0.296, \"Loudness\": -10.22, \"Speechiness\": 0.0484, \"Acousticness\": 0.551, \"Liveness\": 0.134, \"Tempo\": 127.938, \"Duration (ms)\": 167867.0, \"Valence\": 0.579, \"Chord\": \"C\"}, {\"Index\": 526, \"Highest Charting Position\": 80, \"Number of Times Charted\": 57, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Without Me\", \"Streams\": 5016283, \"Artist\": \"Halsey\", \"Artist Followers\": 15663384.0, \"Song ID\": \"5p7ujcrUXASCNwRaWNHR1C\", \"Genre\": \"['dance pop', 'electropop', 'etherpop', 'indie poptimism', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-10-04\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.752, \"Energy\": 0.488, \"Loudness\": -7.05, \"Speechiness\": 0.0705, \"Acousticness\": 0.297, \"Liveness\": 0.0936, \"Tempo\": 136.041, \"Duration (ms)\": 201661.0, \"Valence\": 0.533, \"Chord\": \"F#/Gb\"}, {\"Index\": 527, \"Highest Charting Position\": 33, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"BOOKER T\", \"Streams\": 4995965, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"26w9NTiE9NGjW1ZvIOd1So\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 77.0, \"Danceability\": 0.883, \"Energy\": 0.6, \"Loudness\": -7.188, \"Speechiness\": 0.37, \"Acousticness\": 0.114, \"Liveness\": 0.0931, \"Tempo\": 113.903, \"Duration (ms)\": 156430.0, \"Valence\": 0.691, \"Chord\": \"G\"}, {\"Index\": 528, \"Highest Charting Position\": 5, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Intentions (feat. Quavo)\", \"Streams\": 4994138, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"4umIPjkehX1r7uhmGvXiSV\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 77.0, \"Danceability\": 0.806, \"Energy\": 0.546, \"Loudness\": -6.637, \"Speechiness\": 0.0575, \"Acousticness\": 0.3, \"Liveness\": 0.102, \"Tempo\": 147.986, \"Duration (ms)\": 212867.0, \"Valence\": 0.874, \"Chord\": \"A\"}, {\"Index\": 529, \"Highest Charting Position\": 49, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Sofia\", \"Streams\": 4982892, \"Artist\": \"Clairo\", \"Artist Followers\": 2722638.0, \"Song ID\": \"7B3z0ySL9Rr0XvZEAjWZzM\", \"Genre\": \"['bedroom pop', 'indie pop', 'pop']\", \"Release Date\": \"2019-08-02\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 81.0, \"Danceability\": 0.744, \"Energy\": 0.619, \"Loudness\": -9.805, \"Speechiness\": 0.039, \"Acousticness\": 0.598, \"Liveness\": 0.231, \"Tempo\": 112.997, \"Duration (ms)\": 188387.0, \"Valence\": 0.641, \"Chord\": \"C\"}, {\"Index\": 530, \"Highest Charting Position\": 176, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Photograph\", \"Streams\": 4974880, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"1HNkqx9Ahdgi1Ixy2xkKkL\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2014-06-21\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-02-07--2020-02-14\\n2020-01-03--2020-01-10\", \"Popularity\": 83.0, \"Danceability\": 0.614, \"Energy\": 0.379, \"Loudness\": -10.48, \"Speechiness\": 0.0476, \"Acousticness\": 0.607, \"Liveness\": 0.0986, \"Tempo\": 107.989, \"Duration (ms)\": 258987.0, \"Valence\": 0.201, \"Chord\": \"E\"}, {\"Index\": 531, \"Highest Charting Position\": 20, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"34+35 Remix (feat. Doja Cat, Megan Thee Stallion) - Remix\", \"Streams\": 6162453, \"Artist\": \"Ariana Grande\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 532, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"Madonna\", \"Streams\": 5936752, \"Artist\": \"Bausa, Apache 207\", \"Artist Followers\": 961181.0, \"Song ID\": \"6a3kNt1UlUOapDKmEr3JzZ\", \"Genre\": \"['german hip hop', 'german pop']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-02-19--2021-02-26\", \"Popularity\": 68.0, \"Danceability\": 0.806, \"Energy\": 0.565, \"Loudness\": -8.96, \"Speechiness\": 0.113, \"Acousticness\": 0.47, \"Liveness\": 0.0824, \"Tempo\": 116.963, \"Duration (ms)\": 195734.0, \"Valence\": 0.311, \"Chord\": \"B\"}, {\"Index\": 533, \"Highest Charting Position\": 144, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"CLOUDS\", \"Streams\": 5897983, \"Artist\": \"NF\", \"Artist Followers\": 5831194.0, \"Song ID\": \"5UMMPHPp6vRP6ghPpSUOzp\", \"Genre\": \"['hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2021-02-18\", \"Weeks Charted\": \"2021-02-19--2021-02-26\", \"Popularity\": 69.0, \"Danceability\": 0.793, \"Energy\": 0.65, \"Loudness\": -3.944, \"Speechiness\": 0.397, \"Acousticness\": 0.371, \"Liveness\": 0.854, \"Tempo\": 128.111, \"Duration (ms)\": 243750.0, \"Valence\": 0.809, \"Chord\": \"C#/Db\"}, {\"Index\": 534, \"Highest Charting Position\": 12, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Wonder\", \"Streams\": 5535339, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 1251372.0, \"Song ID\": \"7jjS2fSD9zuzbEHeVEFJ2w\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 0.0, \"Danceability\": 0.333, \"Energy\": 0.637, \"Loudness\": -4.904, \"Speechiness\": 0.0581, \"Acousticness\": 0.131, \"Liveness\": 0.149, \"Tempo\": 139.898, \"Duration (ms)\": 172693.0, \"Valence\": 0.132, \"Chord\": \"C#/Db\"}, {\"Index\": 535, \"Highest Charting Position\": 50, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Skin\", \"Streams\": 5497942, \"Artist\": \"Sabrina Carpenter\", \"Artist Followers\": 3689546.0, \"Song ID\": \"03B2SfXuvDh1m9F4tqrX07\", \"Genre\": \"['alt z', 'dance pop', 'electropop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 76.0, \"Danceability\": 0.557, \"Energy\": 0.457, \"Loudness\": -5.372, \"Speechiness\": 0.0335, \"Acousticness\": 0.428, \"Liveness\": 0.0567, \"Tempo\": 105.918, \"Duration (ms)\": 177500.0, \"Valence\": 0.328, \"Chord\": \"G\"}, {\"Index\": 536, \"Highest Charting Position\": 62, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Tyler Herro\", \"Streams\": 5168107, \"Artist\": \"Jack Harlow\", \"Artist Followers\": 1053324.0, \"Song ID\": \"4DuUwzP4ALMqpquHU0ltAB\", \"Genre\": \"['deep underground hip hop', 'kentucky hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-10-22\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 76.0, \"Danceability\": 0.794, \"Energy\": 0.756, \"Loudness\": -7.16, \"Speechiness\": 0.136, \"Acousticness\": 0.11, \"Liveness\": 0.247, \"Tempo\": 123.066, \"Duration (ms)\": 156498.0, \"Valence\": 0.775, \"Chord\": \"F\"}, {\"Index\": 537, \"Highest Charting Position\": 173, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Remember That Night?\", \"Streams\": 5116325, \"Artist\": \"Sara Kays\", \"Artist Followers\": 251549.0, \"Song ID\": \"1nYzjrdVQ8RpF93M0jPFW7\", \"Genre\": \"['alt z', 'indie cafe pop', 'modern indie pop', 'pop', 'social media pop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 78.0, \"Danceability\": 0.679, \"Energy\": 0.61, \"Loudness\": -10.936, \"Speechiness\": 0.0305, \"Acousticness\": 0.585, \"Liveness\": 0.156, \"Tempo\": 123.978, \"Duration (ms)\": 227186.0, \"Valence\": 0.554, \"Chord\": \"G\"}, {\"Index\": 538, \"Highest Charting Position\": 128, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Lifestyle (feat. Adam Levine)\", \"Streams\": 5059891, \"Artist\": \"Jason Derulo, Maroon 5\", \"Artist Followers\": 9778632.0, \"Song ID\": \"0osvOdeD3YXZiWkT8MKolJ\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 78.0, \"Danceability\": 0.749, \"Energy\": 0.674, \"Loudness\": -5.128, \"Speechiness\": 0.0366, \"Acousticness\": 0.0209, \"Liveness\": 0.169, \"Tempo\": 123.055, \"Duration (ms)\": 153865.0, \"Valence\": 0.711, \"Chord\": \"A#/Bb\"}, {\"Index\": 539, \"Highest Charting Position\": 177, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Fly Away\", \"Streams\": 5053713, \"Artist\": \"Tones And I\", \"Artist Followers\": 2820477.0, \"Song ID\": \"5ri4zqtWhG07hIuNNDWP76\", \"Genre\": \"['australian pop', 'pop']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 79.0, \"Danceability\": 0.806, \"Energy\": 0.513, \"Loudness\": -6.208, \"Speechiness\": 0.0685, \"Acousticness\": 0.217, \"Liveness\": 0.217, \"Tempo\": 124.988, \"Duration (ms)\": 178157.0, \"Valence\": 0.503, \"Chord\": \"E\"}, {\"Index\": 540, \"Highest Charting Position\": 37, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Despeinada\", \"Streams\": 5004462, \"Artist\": \"Ozuna, Camilo\", \"Artist Followers\": 29238936.0, \"Song ID\": \"0JAZWvvqttGFm4UMDsPQXC\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 75.0, \"Danceability\": 0.734, \"Energy\": 0.775, \"Loudness\": -3.855, \"Speechiness\": 0.0614, \"Acousticness\": 0.186, \"Liveness\": 0.123, \"Tempo\": 166.039, \"Duration (ms)\": 224187.0, \"Valence\": 0.72, \"Chord\": \"G#/Ab\"}, {\"Index\": 541, \"Highest Charting Position\": 14, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"motive (with Doja Cat)\", \"Streams\": 4986037, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"5GkQIP5mWPi4KZLLXeuFTT\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 80.0, \"Danceability\": 0.789, \"Energy\": 0.742, \"Loudness\": -5.664, \"Speechiness\": 0.0652, \"Acousticness\": 0.0681, \"Liveness\": 0.166, \"Tempo\": 116.965, \"Duration (ms)\": 167990.0, \"Valence\": 0.661, \"Chord\": \"A#/Bb\"}, {\"Index\": 542, \"Highest Charting Position\": 28, \"Number of Times Charted\": 57, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"I Don't Care (with Justin Bieber)\", \"Streams\": 4984399, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"3HVWdVOQ0ZA45FuZGSfvns\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-05-10\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.798, \"Energy\": 0.675, \"Loudness\": -5.041, \"Speechiness\": 0.0442, \"Acousticness\": 0.0912, \"Liveness\": 0.0894, \"Tempo\": 101.956, \"Duration (ms)\": 219947.0, \"Valence\": 0.842, \"Chord\": \"F#/Gb\"}, {\"Index\": 543, \"Highest Charting Position\": 14, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Ay, DiOs M\\u00edo!\", \"Streams\": 5344862, \"Artist\": \"KAROL G\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3PF1mUoD0NgK4ykdt5sk3g\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 0.0, \"Danceability\": 0.715, \"Energy\": 0.706, \"Loudness\": -4.423, \"Speechiness\": 0.195, \"Acousticness\": 0.496, \"Liveness\": 0.106, \"Tempo\": 179.997, \"Duration (ms)\": 189840.0, \"Valence\": 0.522, \"Chord\": \"B\"}, {\"Index\": 544, \"Highest Charting Position\": 83, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Nathy Peluso: Bzrp Music Sessions, Vol. 36\", \"Streams\": 5232509, \"Artist\": \"Bizarrap, Nathy Peluso\", \"Artist Followers\": 3134041.0, \"Song ID\": \"78SeXVRJ7KCqVmOwTiFjnI\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 77.0, \"Danceability\": 0.65, \"Energy\": 0.655, \"Loudness\": -3.71, \"Speechiness\": 0.405, \"Acousticness\": 0.25, \"Liveness\": 0.0691, \"Tempo\": 94.059, \"Duration (ms)\": 171215.0, \"Valence\": 0.735, \"Chord\": \"C#/Db\"}, {\"Index\": 545, \"Highest Charting Position\": 17, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Haw\\u00e1i - Remix\", \"Streams\": 5163323, \"Artist\": \"Maluma, The Weeknd\", \"Artist Followers\": 26784251.0, \"Song ID\": \"0GzuHFG4Ql6DoyxFRnIk3F\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-11-05\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 77.0, \"Danceability\": 0.766, \"Energy\": 0.788, \"Loudness\": -3.128, \"Speechiness\": 0.312, \"Acousticness\": 0.105, \"Liveness\": 0.142, \"Tempo\": 179.984, \"Duration (ms)\": 200482.0, \"Valence\": 0.609, \"Chord\": \"F#/Gb\"}, {\"Index\": 546, \"Highest Charting Position\": 22, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Tattoo - Remix with Camilo\", \"Streams\": 5120753, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6096559.0, \"Song ID\": \"4ZRrLHqzhGRXYj2qcB4s5S\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-07-09\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 78.0, \"Danceability\": 0.848, \"Energy\": 0.637, \"Loudness\": -5.132, \"Speechiness\": 0.156, \"Acousticness\": 0.0413, \"Liveness\": 0.0521, \"Tempo\": 96.988, \"Duration (ms)\": 222680.0, \"Valence\": 0.698, \"Chord\": \"A\"}, {\"Index\": 547, \"Highest Charting Position\": 151, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Meia Noite (Voc\\u00ea tem meu Whatsapp)\", \"Streams\": 5044252, \"Artist\": \"Tarc\\u00edsio do Acordeon\", \"Artist Followers\": 1200248.0, \"Song ID\": \"6sPBi0qLI6KM3yXX56NxsA\", \"Genre\": \"[]\", \"Release Date\": \"2020-12-17\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 67.0, \"Danceability\": 0.709, \"Energy\": 0.816, \"Loudness\": -4.787, \"Speechiness\": 0.0346, \"Acousticness\": 0.685, \"Liveness\": 0.146, \"Tempo\": 150.06, \"Duration (ms)\": 237900.0, \"Valence\": 0.921, \"Chord\": \"B\"}, {\"Index\": 548, \"Highest Charting Position\": 143, \"Number of Times Charted\": 42, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Moonlight\", \"Streams\": 5003825, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"0JP9xo3adEtGSdUEISiszL\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2018-03-16\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2020-09-18--2020-09-25\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.921, \"Energy\": 0.537, \"Loudness\": -5.723, \"Speechiness\": 0.0804, \"Acousticness\": 0.556, \"Liveness\": 0.102, \"Tempo\": 128.009, \"Duration (ms)\": 135090.0, \"Valence\": 0.711, \"Chord\": \"A\"}, {\"Index\": 549, \"Highest Charting Position\": 182, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Thinking out Loud\", \"Streams\": 4995623, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"34gCuhDGsG4bRPIf9bb02f\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2014-06-21\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 82.0, \"Danceability\": 0.781, \"Energy\": 0.445, \"Loudness\": -6.061, \"Speechiness\": 0.0295, \"Acousticness\": 0.474, \"Liveness\": 0.184, \"Tempo\": 78.998, \"Duration (ms)\": 281560.0, \"Valence\": 0.591, \"Chord\": \"D\"}, {\"Index\": 550, \"Highest Charting Position\": 2, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Toosie Slide\", \"Streams\": 4966878, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"127QTOFJsJQp5LbJbu3A1y\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 78.0, \"Danceability\": 0.834, \"Energy\": 0.454, \"Loudness\": -9.75, \"Speechiness\": 0.201, \"Acousticness\": 0.321, \"Liveness\": 0.114, \"Tempo\": 81.618, \"Duration (ms)\": 247059.0, \"Valence\": 0.837, \"Chord\": \"C#/Db\"}, {\"Index\": 551, \"Highest Charting Position\": 167, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Earned It (Fifty Shades Of Grey)\", \"Streams\": 4929647, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"4frLb7nWtsz2ymBE6k2GRP\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2015-08-28\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 69.0, \"Danceability\": 0.659, \"Energy\": 0.291, \"Loudness\": -8.275, \"Speechiness\": 0.0348, \"Acousticness\": 0.405, \"Liveness\": 0.0771, \"Tempo\": 119.829, \"Duration (ms)\": 277680.0, \"Valence\": 0.406, \"Chord\": \"D\"}, {\"Index\": 552, \"Highest Charting Position\": 9, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"ily (i love you baby) (feat. Emilee)\", \"Streams\": 4908929, \"Artist\": \"Surf Mesa\", \"Artist Followers\": 132855.0, \"Song ID\": \"62aP9fBQKYKxi7PDXwcUAS\", \"Genre\": \"['tropical house']\", \"Release Date\": \"2019-11-26\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 81.0, \"Danceability\": 0.674, \"Energy\": 0.774, \"Loudness\": -7.567, \"Speechiness\": 0.0892, \"Acousticness\": 0.0686, \"Liveness\": 0.393, \"Tempo\": 112.05, \"Duration (ms)\": 176547.0, \"Valence\": 0.33, \"Chord\": \"B\"}, {\"Index\": 553, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Wonderwall\", \"Streams\": 4902737, \"Artist\": \"Oasis\", \"Artist Followers\": 6478565.0, \"Song ID\": \"7ygpwy2qP3NbrxVkHvUhXY\", \"Genre\": \"['beatlesque', 'britpop', 'madchester', 'permanent wave', 'rock']\", \"Release Date\": \"1995\", \"Weeks Charted\": \"2021-02-12--2021-02-19\", \"Popularity\": 78.0, \"Danceability\": 0.375, \"Energy\": 0.893, \"Loudness\": -4.097, \"Speechiness\": 0.0406, \"Acousticness\": 0.000509, \"Liveness\": 0.187, \"Tempo\": 174.323, \"Duration (ms)\": 258773.0, \"Valence\": 0.434, \"Chord\": \"D\"}, {\"Index\": 554, \"Highest Charting Position\": 181, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Everybody Dies In Their Nightmares\", \"Streams\": 4847224, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"3GVkPk8mqxz0itaAriG1L7\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2017-08-25\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\", \"Popularity\": 83.0, \"Danceability\": 0.734, \"Energy\": 0.57, \"Loudness\": -7.066, \"Speechiness\": 0.133, \"Acousticness\": 0.847, \"Liveness\": 0.112, \"Tempo\": 129.953, \"Duration (ms)\": 95467.0, \"Valence\": 0.689, \"Chord\": \"G\"}, {\"Index\": 555, \"Highest Charting Position\": 27, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Bad Boy (with Young Thug)\", \"Streams\": 6011642, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"43CIWpJaJHRcI4mUSjqgc2\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 76.0, \"Danceability\": 0.697, \"Energy\": 0.674, \"Loudness\": -6.326, \"Speechiness\": 0.0533, \"Acousticness\": 0.00215, \"Liveness\": 0.138, \"Tempo\": 81.535, \"Duration (ms)\": 157355.0, \"Valence\": 0.198, \"Chord\": \"C#/Db\"}, {\"Index\": 556, \"Highest Charting Position\": 19, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Lo Vas A Olvidar (with ROSAL\\u00cdA)\", \"Streams\": 5963380, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"0psS4i5YooJrXfDnGvWRLi\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 68.0, \"Danceability\": 0.343, \"Energy\": 0.243, \"Loudness\": -14.66, \"Speechiness\": 0.0777, \"Acousticness\": 0.721, \"Liveness\": 0.0668, \"Tempo\": 135.154, \"Duration (ms)\": 203464.0, \"Valence\": 0.032, \"Chord\": \"E\"}, {\"Index\": 557, \"Highest Charting Position\": 152, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Floating Through Space\", \"Streams\": 5579697, \"Artist\": \"Sia, David Guetta\", \"Artist Followers\": 20528724.0, \"Song ID\": \"2AceGjiX9isUbXmMZa0Dl1\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'pop']\", \"Release Date\": \"2021-02-04\", \"Weeks Charted\": \"2021-02-05--2021-02-12\", \"Popularity\": 78.0, \"Danceability\": 0.575, \"Energy\": 0.844, \"Loudness\": -4.89, \"Speechiness\": 0.072, \"Acousticness\": 0.00172, \"Liveness\": 0.114, \"Tempo\": 104.914, \"Duration (ms)\": 177801.0, \"Valence\": 0.277, \"Chord\": \"F#/Gb\"}, {\"Index\": 558, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Can't Feel My Face\", \"Streams\": 5479407, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"22VdIZQfgXJea34mQxlt81\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2015-08-28\", \"Weeks Charted\": \"2021-02-05--2021-02-12\", \"Popularity\": 80.0, \"Danceability\": 0.705, \"Energy\": 0.769, \"Loudness\": -5.526, \"Speechiness\": 0.0425, \"Acousticness\": 0.113, \"Liveness\": 0.105, \"Tempo\": 107.949, \"Duration (ms)\": 213520.0, \"Valence\": 0.583, \"Chord\": \"A\"}, {\"Index\": 559, \"Highest Charting Position\": 89, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"You (with Marshmello & Vance Joy)\", \"Streams\": 5342938, \"Artist\": \"benny blanco\", \"Artist Followers\": 804613.0, \"Song ID\": \"1GkHyypTFkUf0QQKwYoXH4\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2021-01-29\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 73.0, \"Danceability\": 0.668, \"Energy\": 0.563, \"Loudness\": -6.433, \"Speechiness\": 0.0522, \"Acousticness\": 0.0493, \"Liveness\": 0.119, \"Tempo\": 103.116, \"Duration (ms)\": 169632.0, \"Valence\": 0.305, \"Chord\": \"B\"}, {\"Index\": 560, \"Highest Charting Position\": 168, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Call Out My Name\", \"Streams\": 5233359, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"09mEdoA6zrmBPgTEN5qXmN\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2018-03-30\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\", \"Popularity\": 80.0, \"Danceability\": 0.461, \"Energy\": 0.593, \"Loudness\": -4.954, \"Speechiness\": 0.0356, \"Acousticness\": 0.17, \"Liveness\": 0.307, \"Tempo\": 134.17, \"Duration (ms)\": 228373.0, \"Valence\": 0.175, \"Chord\": \"C#/Db\"}, {\"Index\": 561, \"Highest Charting Position\": 14, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Midnight Sky\", \"Streams\": 5208100, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"27ycaQnQAxaPiyeg3nr2aB\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 76.0, \"Danceability\": 0.705, \"Energy\": 0.814, \"Loudness\": -5.466, \"Speechiness\": 0.0346, \"Acousticness\": 0.00115, \"Liveness\": 0.203, \"Tempo\": 110.0, \"Duration (ms)\": 223279.0, \"Valence\": 0.259, \"Chord\": \"E\"}, {\"Index\": 562, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Pressure (feat. Tove Lo)\", \"Streams\": 5197587, \"Artist\": \"Martin Garrix\", \"Artist Followers\": 14921269.0, \"Song ID\": \"4ga4WvRNhMsIL38pkBbnIN\", \"Genre\": \"['dance pop', 'dutch edm', 'edm', 'pop', 'pop dance', 'progressive house', 'tropical house']\", \"Release Date\": \"2021-02-05\", \"Weeks Charted\": \"2021-02-05--2021-02-12\", \"Popularity\": 76.0, \"Danceability\": 0.859, \"Energy\": 0.558, \"Loudness\": -8.991, \"Speechiness\": 0.0902, \"Acousticness\": 0.659, \"Liveness\": 0.124, \"Tempo\": 114.978, \"Duration (ms)\": 144391.0, \"Valence\": 0.357, \"Chord\": \"G\"}, {\"Index\": 563, \"Highest Charting Position\": 140, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Can You Feel My Heart\", \"Streams\": 5092250, \"Artist\": \"Bring Me The Horizon\", \"Artist Followers\": 3912138.0, \"Song ID\": \"0WSa1sucoNRcEeULlZVQXj\", \"Genre\": \"['melodic metalcore', 'metalcore', 'rock', 'uk metalcore']\", \"Release Date\": \"2013-04-01\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 77.0, \"Danceability\": 0.15, \"Energy\": 0.859, \"Loudness\": -2.827, \"Speechiness\": 0.0595, \"Acousticness\": 0.00201, \"Liveness\": 0.387, \"Tempo\": 170.527, \"Duration (ms)\": 228147.0, \"Valence\": 0.354, \"Chord\": \"E\"}, {\"Index\": 564, \"Highest Charting Position\": 167, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Agua de Jamaica\", \"Streams\": 5072462, \"Artist\": \"Maluma\", \"Artist Followers\": 26784251.0, \"Song ID\": \"41BzKiCrKpUQHS3TP0jmdr\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-01-28\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 75.0, \"Danceability\": 0.664, \"Energy\": 0.665, \"Loudness\": -3.616, \"Speechiness\": 0.0879, \"Acousticness\": 0.123, \"Liveness\": 0.411, \"Tempo\": 173.961, \"Duration (ms)\": 176970.0, \"Valence\": 0.726, \"Chord\": \"A#/Bb\"}, {\"Index\": 565, \"Highest Charting Position\": 162, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Mds\", \"Streams\": 5046418, \"Artist\": \"Kawe, Mc Lele JP\", \"Artist Followers\": 444736.0, \"Song ID\": \"0QglpM23kl9ldvVdoYNZwF\", \"Genre\": \"['brazilian hip hop', 'funk ostentacao']\", \"Release Date\": \"2020-05-19\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 72.0, \"Danceability\": 0.885, \"Energy\": 0.561, \"Loudness\": -5.331, \"Speechiness\": 0.249, \"Acousticness\": 0.261, \"Liveness\": 0.121, \"Tempo\": 140.02, \"Duration (ms)\": 125143.0, \"Valence\": 0.644, \"Chord\": \"F#/Gb\"}, {\"Index\": 566, \"Highest Charting Position\": 18, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Heartless\", \"Streams\": 4995578, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"6bnF93Rx87YqUBLSgjiMU8\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.537, \"Energy\": 0.746, \"Loudness\": -5.507, \"Speechiness\": 0.15, \"Acousticness\": 0.0236, \"Liveness\": 0.156, \"Tempo\": 170.062, \"Duration (ms)\": 198267.0, \"Valence\": 0.252, \"Chord\": \"A#/Bb\"}, {\"Index\": 567, \"Highest Charting Position\": 20, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"pov\", \"Streams\": 4906738, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3UoULw70kMsiVXxW0L3A33\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 79.0, \"Danceability\": 0.487, \"Energy\": 0.534, \"Loudness\": -5.664, \"Speechiness\": 0.0555, \"Acousticness\": 0.36, \"Liveness\": 0.1, \"Tempo\": 131.798, \"Duration (ms)\": 201882.0, \"Valence\": 0.173, \"Chord\": \"C\"}, {\"Index\": 568, \"Highest Charting Position\": 138, \"Number of Times Charted\": 49, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Be Alright\", \"Streams\": 4900492, \"Artist\": \"Dean Lewis\", \"Artist Followers\": 1692635.0, \"Song ID\": \"3EPXxR3ImUwfayaurPi3cm\", \"Genre\": \"['australian pop', 'indie cafe pop', 'pop', 'pop rock', 'post-teen pop']\", \"Release Date\": \"2018-06-29\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.553, \"Energy\": 0.586, \"Loudness\": -6.319, \"Speechiness\": 0.0362, \"Acousticness\": 0.697, \"Liveness\": 0.0813, \"Tempo\": 126.684, \"Duration (ms)\": 196373.0, \"Valence\": 0.443, \"Chord\": \"B\"}, {\"Index\": 569, \"Highest Charting Position\": 174, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Cry Baby (feat. DaBaby)\", \"Streams\": 4884711, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"4aarlAfLKVCTxUDNgbwhjH\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 76.0, \"Danceability\": 0.957, \"Energy\": 0.437, \"Loudness\": -7.882, \"Speechiness\": 0.359, \"Acousticness\": 0.00402, \"Liveness\": 0.219, \"Tempo\": 130.058, \"Duration (ms)\": 137984.0, \"Valence\": 0.616, \"Chord\": \"B\"}, {\"Index\": 570, \"Highest Charting Position\": 47, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Mi Cuarto\", \"Streams\": 4873380, \"Artist\": \"Jerry Di\", \"Artist Followers\": 149682.0, \"Song ID\": \"6fmQjRuo7XvRFCK2qex5hQ\", \"Genre\": \"['cubaton', 'dominican pop', 'pop venezolano', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 76.0, \"Danceability\": 0.854, \"Energy\": 0.525, \"Loudness\": -4.426, \"Speechiness\": 0.214, \"Acousticness\": 0.819, \"Liveness\": 0.146, \"Tempo\": 97.054, \"Duration (ms)\": 197587.0, \"Valence\": 0.63, \"Chord\": \"C#/Db\"}, {\"Index\": 571, \"Highest Charting Position\": 99, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Ohne Dich\", \"Streams\": 5487774, \"Artist\": \"KASIMIR1441, badm\\u00f3mzjay, WILDBWOYS\", \"Artist Followers\": 197320.0, \"Song ID\": \"4hSJUp6k7QeHLxU32MrLIU\", \"Genre\": \"['german alternative rap', 'german hip hop', 'german trap', 'tekk']\", \"Release Date\": \"2021-01-14\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 70.0, \"Danceability\": 0.807, \"Energy\": 0.535, \"Loudness\": -6.519, \"Speechiness\": 0.349, \"Acousticness\": 0.191, \"Liveness\": 0.125, \"Tempo\": 156.013, \"Duration (ms)\": 125720.0, \"Valence\": 0.925, \"Chord\": \"B\"}, {\"Index\": 572, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Gravity (feat. Tyler, The Creator)\", \"Streams\": 5136895, \"Artist\": \"Brent Faiyaz, DJ Dahi\", \"Artist Followers\": 1726216.0, \"Song ID\": \"6u3CPnFMKANYgfdiifFOiJ\", \"Genre\": \"['dmv rap', 'pop', 'r&b', 'rap']\", \"Release Date\": \"2021-01-29\", \"Weeks Charted\": \"2021-01-29--2021-02-05\", \"Popularity\": 76.0, \"Danceability\": 0.539, \"Energy\": 0.615, \"Loudness\": -8.746, \"Speechiness\": 0.252, \"Acousticness\": 0.173, \"Liveness\": 0.144, \"Tempo\": 163.924, \"Duration (ms)\": 214693.0, \"Valence\": 0.493, \"Chord\": \"C#/Db\"}, {\"Index\": 573, \"Highest Charting Position\": 55, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Vibez\", \"Streams\": 5071718, \"Artist\": \"ZAYN\", \"Artist Followers\": 16655692.0, \"Song ID\": \"709F3MwiVvLD0LQXeKs5Cz\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 69.0, \"Danceability\": 0.635, \"Energy\": 0.659, \"Loudness\": -7.499, \"Speechiness\": 0.116, \"Acousticness\": 0.242, \"Liveness\": 0.105, \"Tempo\": 96.855, \"Duration (ms)\": 163127.0, \"Valence\": 0.34, \"Chord\": \"G\"}, {\"Index\": 574, \"Highest Charting Position\": 103, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"All I Want - From \\\"High School Musical: The Musical: The Series\\\"\", \"Streams\": 5052801, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6313514.0, \"Song ID\": \"4Yxc55NX3tAXC2mHRAhtcW\", \"Genre\": \"['pop']\", \"Release Date\": \"2019-11-27\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 76.0, \"Danceability\": 0.376, \"Energy\": 0.43, \"Loudness\": -6.585, \"Speechiness\": 0.0328, \"Acousticness\": 0.0902, \"Liveness\": 0.0912, \"Tempo\": 77.599, \"Duration (ms)\": 177323.0, \"Valence\": 0.129, \"Chord\": \"C\"}, {\"Index\": 575, \"Highest Charting Position\": 45, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Daisy\", \"Streams\": 5030670, \"Artist\": \"Ashnikko\", \"Artist Followers\": 1248499.0, \"Song ID\": \"0AUvWawuP0ibk4SQ3sIZjk\", \"Genre\": \"['electropop', 'escape room', 'pop']\", \"Release Date\": \"2020-07-09\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 76.0, \"Danceability\": 0.834, \"Energy\": 0.663, \"Loudness\": -6.143, \"Speechiness\": 0.133, \"Acousticness\": 0.235, \"Liveness\": 0.372, \"Tempo\": 121.876, \"Duration (ms)\": 146523.0, \"Valence\": 0.774, \"Chord\": \"G#/Ab\"}, {\"Index\": 576, \"Highest Charting Position\": 83, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Wasted On You\", \"Streams\": 4948563, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"3cBsEDNhFI9E82vPj3kvi3\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 76.0, \"Danceability\": 0.505, \"Energy\": 0.657, \"Loudness\": -5.24, \"Speechiness\": 0.0318, \"Acousticness\": 0.373, \"Liveness\": 0.126, \"Tempo\": 196.0, \"Duration (ms)\": 178520.0, \"Valence\": 0.252, \"Chord\": \"B\"}, {\"Index\": 577, \"Highest Charting Position\": 13, \"Number of Times Charted\": 38, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"La Jeepeta - Remix\", \"Streams\": 4942545, \"Artist\": \"Nio Garcia, Anuel AA, Myke Towers, Brray, Juanka\", \"Artist Followers\": 2127531.0, \"Song ID\": \"1mohfLaTJtB2RplHLQVM70\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 75.0, \"Danceability\": 0.815, \"Energy\": 0.715, \"Loudness\": -4.65, \"Speechiness\": 0.207, \"Acousticness\": 0.3, \"Liveness\": 0.091, \"Tempo\": 176.007, \"Duration (ms)\": 345241.0, \"Valence\": 0.786, \"Chord\": \"E\"}, {\"Index\": 578, \"Highest Charting Position\": 137, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Los Dioses\", \"Streams\": 5929507, \"Artist\": \"Anuel AA, Ozuna\", \"Artist Followers\": 18306226.0, \"Song ID\": \"73O30uMI7n6DuzBmbtO7kC\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-01-22--2021-01-29\", \"Popularity\": 73.0, \"Danceability\": 0.817, \"Energy\": 0.737, \"Loudness\": -5.453, \"Speechiness\": 0.102, \"Acousticness\": 0.046, \"Liveness\": 0.092, \"Tempo\": 93.985, \"Duration (ms)\": 206587.0, \"Valence\": 0.67, \"Chord\": \"F#/Gb\"}, {\"Index\": 579, \"Highest Charting Position\": 132, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Si Me Tomo Una Cerveza\", \"Streams\": 5427534, \"Artist\": \"Migrantes, Alico\", \"Artist Followers\": 114348.0, \"Song ID\": \"3lCbsHaN1wCxyDzcNN2x4N\", \"Genre\": \"['cumbia pop']\", \"Release Date\": \"2020-11-07\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 74.0, \"Danceability\": 0.72, \"Energy\": 0.613, \"Loudness\": -6.899, \"Speechiness\": 0.0572, \"Acousticness\": 0.185, \"Liveness\": 0.155, \"Tempo\": 84.974, \"Duration (ms)\": 182199.0, \"Valence\": 0.857, \"Chord\": \"C#/Db\"}, {\"Index\": 580, \"Highest Charting Position\": 90, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Somebody\\u2019s Problem\", \"Streams\": 5332437, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"0SErdEdRcVX1uJCf1eTGYH\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2020-11-20--2020-11-27\", \"Popularity\": 70.0, \"Danceability\": 0.657, \"Energy\": 0.54, \"Loudness\": -7.675, \"Speechiness\": 0.0287, \"Acousticness\": 0.662, \"Liveness\": 0.123, \"Tempo\": 136.97, \"Duration (ms)\": 161773.0, \"Valence\": 0.625, \"Chord\": \"F\"}, {\"Index\": 581, \"Highest Charting Position\": 66, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"De Una Vez\", \"Streams\": 5186567, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"1v3lhrZEsOcazqR2QIyyRu\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 70.0, \"Danceability\": 0.659, \"Energy\": 0.479, \"Loudness\": -6.79, \"Speechiness\": 0.2, \"Acousticness\": 0.152, \"Liveness\": 0.268, \"Tempo\": 163.882, \"Duration (ms)\": 155956.0, \"Valence\": 0.0395, \"Chord\": \"B\"}, {\"Index\": 582, \"Highest Charting Position\": 121, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Way Out (feat. Big Sean)\", \"Streams\": 4962949, \"Artist\": \"Jack Harlow\", \"Artist Followers\": 1053324.0, \"Song ID\": \"6rLi6PyWXu1rPlShuIZpj6\", \"Genre\": \"['deep underground hip hop', 'kentucky hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-09\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 72.0, \"Danceability\": 0.945, \"Energy\": 0.582, \"Loudness\": -8.357, \"Speechiness\": 0.0719, \"Acousticness\": 0.114, \"Liveness\": 0.103, \"Tempo\": 108.025, \"Duration (ms)\": 168906.0, \"Valence\": 0.907, \"Chord\": \"B\"}, {\"Index\": 583, \"Highest Charting Position\": 42, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Diamonds\", \"Streams\": 4931163, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"5hvwx5i67IwnCkjl9VHkNv\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-09-17\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 77.0, \"Danceability\": 0.653, \"Energy\": 0.667, \"Loudness\": -6.764, \"Speechiness\": 0.0423, \"Acousticness\": 0.154, \"Liveness\": 0.107, \"Tempo\": 104.181, \"Duration (ms)\": 213869.0, \"Valence\": 0.556, \"Chord\": \"A#/Bb\"}, {\"Index\": 584, \"Highest Charting Position\": 190, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Dancing in My Room\", \"Streams\": 4914093, \"Artist\": \"347aidan\", \"Artist Followers\": 211500.0, \"Song ID\": \"6Pgmqg15yVexuOgtzuxwoX\", \"Genre\": \"['sad rap']\", \"Release Date\": \"2020-10-26\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\", \"Popularity\": 79.0, \"Danceability\": 0.98, \"Energy\": 0.413, \"Loudness\": -11.052, \"Speechiness\": 0.101, \"Acousticness\": 0.671, \"Liveness\": 0.17, \"Tempo\": 119.993, \"Duration (ms)\": 180139.0, \"Valence\": 0.764, \"Chord\": \"G#/Ab\"}, {\"Index\": 585, \"Highest Charting Position\": 116, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"De Cora <3\", \"Streams\": 4864544, \"Artist\": \"Rauw Alejandro, J Balvin\", \"Artist Followers\": 6096559.0, \"Song ID\": \"22Sh5dlwbERqJAq1fZk5b2\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 73.0, \"Danceability\": 0.811, \"Energy\": 0.683, \"Loudness\": -2.028, \"Speechiness\": 0.241, \"Acousticness\": 0.46, \"Liveness\": 0.128, \"Tempo\": 176.037, \"Duration (ms)\": 190101.0, \"Valence\": 0.571, \"Chord\": \"B\"}, {\"Index\": 586, \"Highest Charting Position\": 10, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"champagne problems\", \"Streams\": 4848954, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0sY6ZUTh4yoctD8VIXz339\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 75.0, \"Danceability\": 0.462, \"Energy\": 0.24, \"Loudness\": -12.077, \"Speechiness\": 0.0377, \"Acousticness\": 0.92, \"Liveness\": 0.113, \"Tempo\": 171.319, \"Duration (ms)\": 244000.0, \"Valence\": 0.32, \"Chord\": \"C\"}, {\"Index\": 587, \"Highest Charting Position\": 37, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Go Crazy\", \"Streams\": 4833081, \"Artist\": \"Chris Brown, Young Thug\", \"Artist Followers\": 14073083.0, \"Song ID\": \"1IIKrJVP1C9N7iPtG6eOsK\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'r&b', 'rap']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 80.0, \"Danceability\": 0.755, \"Energy\": 0.578, \"Loudness\": -8.932, \"Speechiness\": 0.145, \"Acousticness\": 0.316, \"Liveness\": 0.25, \"Tempo\": 94.148, \"Duration (ms)\": 176960.0, \"Valence\": 0.581, \"Chord\": \"C\"}, {\"Index\": 588, \"Highest Charting Position\": 73, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Reminds Me Of You\", \"Streams\": 5942551, \"Artist\": \"Juice WRLD, The Kid LAROI\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5YSHygGN9D0mID1NsVd5my\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-12-08\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 75.0, \"Danceability\": 0.613, \"Energy\": 0.631, \"Loudness\": -6.965, \"Speechiness\": 0.12, \"Acousticness\": 0.0663, \"Liveness\": 0.169, \"Tempo\": 149.992, \"Duration (ms)\": 158033.0, \"Valence\": 0.33, \"Chord\": \"E\"}, {\"Index\": 589, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Don't Play\", \"Streams\": 5119828, \"Artist\": \"Anne-Marie, KSI, Digital Farm Animals\", \"Artist Followers\": 8153871.0, \"Song ID\": \"4I5bvu2KDsrCg0EWHIcvul\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-01-15--2021-01-22\", \"Popularity\": 73.0, \"Danceability\": 0.695, \"Energy\": 0.784, \"Loudness\": -6.564, \"Speechiness\": 0.0402, \"Acousticness\": 0.0889, \"Liveness\": 0.0843, \"Tempo\": 128.031, \"Duration (ms)\": 188581.0, \"Valence\": 0.52, \"Chord\": \"F#/Gb\"}, {\"Index\": 590, \"Highest Charting Position\": 108, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"MODO TURBO\", \"Streams\": 4983557, \"Artist\": \"Lu\\u00edsa Sonza, Pabllo Vittar, Anitta\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5217tPOJfhVUY8q9TCKHO1\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-11\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 1.0, \"Danceability\": 0.655, \"Energy\": 0.726, \"Loudness\": -7.628, \"Speechiness\": 0.0796, \"Acousticness\": 0.334, \"Liveness\": 0.232, \"Tempo\": 160.064, \"Duration (ms)\": 150260.0, \"Valence\": 0.766, \"Chord\": \"A#/Bb\"}, {\"Index\": 591, \"Highest Charting Position\": 191, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Buss It\", \"Streams\": 4915403, \"Artist\": \"Erica Banks\", \"Artist Followers\": 41551.0, \"Song ID\": \"25j0Sape7qZbq6ZPLFefTT\", \"Genre\": \"['trap queen']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2021-01-15--2021-01-22\", \"Popularity\": 72.0, \"Danceability\": 0.956, \"Energy\": 0.502, \"Loudness\": -5.995, \"Speechiness\": 0.213, \"Acousticness\": 0.0593, \"Liveness\": 0.238, \"Tempo\": 110.003, \"Duration (ms)\": 187000.0, \"Valence\": 0.795, \"Chord\": \"A\"}, {\"Index\": 592, \"Highest Charting Position\": 41, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Kings & Queens\", \"Streams\": 4855690, \"Artist\": \"Ava Max\", \"Artist Followers\": 3916979.0, \"Song ID\": \"7a53HqqArd4b9NF4XAmlbI\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 82.0, \"Danceability\": 0.637, \"Energy\": 0.69, \"Loudness\": -4.057, \"Speechiness\": 0.0405, \"Acousticness\": 0.00786, \"Liveness\": 0.124, \"Tempo\": 129.857, \"Duration (ms)\": 162399.0, \"Valence\": 0.457, \"Chord\": \"C#/Db\"}, {\"Index\": 593, \"Highest Charting Position\": 6, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Lovesick Girls\", \"Streams\": 4796365, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"4Ws314Ylb27BVsvlZOy30C\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 75.0, \"Danceability\": 0.654, \"Energy\": 0.707, \"Loudness\": -5.661, \"Speechiness\": 0.0664, \"Acousticness\": 0.00559, \"Liveness\": 0.0873, \"Tempo\": 127.97, \"Duration (ms)\": 194765.0, \"Valence\": 0.448, \"Chord\": \"F#/Gb\"}, {\"Index\": 594, \"Highest Charting Position\": 17, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Caramelo\", \"Streams\": 4790233, \"Artist\": \"Ozuna\", \"Artist Followers\": 29238936.0, \"Song ID\": \"3gD4J3RUHy4OUuZ3qAiaiG\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-06-11\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 74.0, \"Danceability\": 0.728, \"Energy\": 0.806, \"Loudness\": -3.766, \"Speechiness\": 0.0623, \"Acousticness\": 0.0531, \"Liveness\": 0.153, \"Tempo\": 168.084, \"Duration (ms)\": 217547.0, \"Valence\": 0.698, \"Chord\": \"F#/Gb\"}, {\"Index\": 595, \"Highest Charting Position\": 67, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Deep End\", \"Streams\": 5622565, \"Artist\": \"Foushe\\u00e9\", \"Artist Followers\": 411262.0, \"Song ID\": \"2AlYncTpVHKwHb55F9lF6O\", \"Genre\": \"['brooklyn drill', 'nyc rap']\", \"Release Date\": \"2020-06-05\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 72.0, \"Danceability\": 0.868, \"Energy\": 0.479, \"Loudness\": -6.687, \"Speechiness\": 0.445, \"Acousticness\": 0.703, \"Liveness\": 0.102, \"Tempo\": 133.928, \"Duration (ms)\": 115200.0, \"Valence\": 0.776, \"Chord\": \"E\"}, {\"Index\": 596, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Sand In My Boots\", \"Streams\": 5446609, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"0uRrG2jRR5tuifsYIJHEao\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\", \"Popularity\": 75.0, \"Danceability\": 0.403, \"Energy\": 0.537, \"Loudness\": -6.628, \"Speechiness\": 0.031, \"Acousticness\": 0.59, \"Liveness\": 0.112, \"Tempo\": 69.877, \"Duration (ms)\": 202133.0, \"Valence\": 0.414, \"Chord\": \"D#/Eb\"}, {\"Index\": 597, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"865\", \"Streams\": 5160123, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"0sKEilrw1GrBlG6qsTCrP4\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\", \"Popularity\": 70.0, \"Danceability\": 0.532, \"Energy\": 0.584, \"Loudness\": -5.254, \"Speechiness\": 0.0248, \"Acousticness\": 0.723, \"Liveness\": 0.101, \"Tempo\": 88.003, \"Duration (ms)\": 190680.0, \"Valence\": 0.367, \"Chord\": \"G#/Ab\"}, {\"Index\": 598, \"Highest Charting Position\": 53, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"7 Summers\", \"Streams\": 5064504, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"4obHzpwGrjoTuZh2DItEMZ\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2020-09-11--2020-09-18\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 73.0, \"Danceability\": 0.466, \"Energy\": 0.786, \"Loudness\": -5.13, \"Speechiness\": 0.0328, \"Acousticness\": 0.417, \"Liveness\": 0.125, \"Tempo\": 203.903, \"Duration (ms)\": 210507.0, \"Valence\": 0.571, \"Chord\": \"C\"}, {\"Index\": 599, \"Highest Charting Position\": 21, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"HACIENDO QUE ME AMAS\", \"Streams\": 4935633, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"26QApq0cuO9brJigr0C0W4\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 78.0, \"Danceability\": 0.584, \"Energy\": 0.411, \"Loudness\": -7.147, \"Speechiness\": 0.0838, \"Acousticness\": 0.869, \"Liveness\": 0.0955, \"Tempo\": 169.934, \"Duration (ms)\": 217769.0, \"Valence\": 0.412, \"Chord\": \"A#/Bb\"}, {\"Index\": 600, \"Highest Charting Position\": 65, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"La Luz\", \"Streams\": 4906324, \"Artist\": \"Sech, J Balvin\", \"Artist Followers\": 8766508.0, \"Song ID\": \"5zj8WNkBrEzlI5FKeYV4ol\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-10-31\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 70.0, \"Danceability\": 0.665, \"Energy\": 0.697, \"Loudness\": -4.819, \"Speechiness\": 0.154, \"Acousticness\": 0.427, \"Liveness\": 0.599, \"Tempo\": 94.053, \"Duration (ms)\": 216747.0, \"Valence\": 0.556, \"Chord\": \"A\"}, {\"Index\": 601, \"Highest Charting Position\": 17, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"The Woo (feat. 50 Cent & Roddy Ricch)\", \"Streams\": 4892682, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"1H7KnK26kc1YyellpbINEn\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 79.0, \"Danceability\": 0.49, \"Energy\": 0.618, \"Loudness\": -5.655, \"Speechiness\": 0.104, \"Acousticness\": 0.0221, \"Liveness\": 0.259, \"Tempo\": 99.7, \"Duration (ms)\": 201600.0, \"Valence\": 0.286, \"Chord\": \"C#/Db\"}, {\"Index\": 602, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"More Than My Hometown\", \"Streams\": 4879971, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"5OELUCYgOHKFAvCERnAvfS\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\", \"Popularity\": 75.0, \"Danceability\": 0.62, \"Energy\": 0.869, \"Loudness\": -5.479, \"Speechiness\": 0.0462, \"Acousticness\": 0.615, \"Liveness\": 0.131, \"Tempo\": 126.019, \"Duration (ms)\": 216573.0, \"Valence\": 0.597, \"Chord\": \"F#/Gb\"}, {\"Index\": 603, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Warning\", \"Streams\": 4860714, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"64SCQtbRtmO28ks1QhS3w5\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\", \"Popularity\": 68.0, \"Danceability\": 0.633, \"Energy\": 0.664, \"Loudness\": -5.037, \"Speechiness\": 0.0294, \"Acousticness\": 0.46, \"Liveness\": 0.108, \"Tempo\": 115.058, \"Duration (ms)\": 156747.0, \"Valence\": 0.268, \"Chord\": \"A#/Bb\"}, {\"Index\": 604, \"Highest Charting Position\": 117, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Recairei - Ao Vivo\", \"Streams\": 4815342, \"Artist\": \"Os Bar\\u00f5es Da Pisadinha\", \"Artist Followers\": 4281787.0, \"Song ID\": \"71FrGl0XcpL3VId65tB5mg\", \"Genre\": \"['forro', 'piseiro']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-27--2020-12-04\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 69.0, \"Danceability\": 0.582, \"Energy\": 0.937, \"Loudness\": -2.118, \"Speechiness\": 0.0858, \"Acousticness\": 0.449, \"Liveness\": 0.684, \"Tempo\": 168.096, \"Duration (ms)\": 166838.0, \"Valence\": 0.939, \"Chord\": \"A#/Bb\"}, {\"Index\": 605, \"Highest Charting Position\": 5, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Ice Cream (with Selena Gomez)\", \"Streams\": 4812765, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"4JUPEh2DVSXFGExu4Uxevz\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 71.0, \"Danceability\": 0.79, \"Energy\": 0.701, \"Loudness\": -4.81, \"Speechiness\": 0.365, \"Acousticness\": 0.0317, \"Liveness\": 0.0311, \"Tempo\": 159.972, \"Duration (ms)\": 177813.0, \"Valence\": 0.91, \"Chord\": \"A\"}, {\"Index\": 606, \"Highest Charting Position\": 22, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Be Kind (with Halsey)\", \"Streams\": 4790427, \"Artist\": \"Marshmello\", \"Artist Followers\": 31552500.0, \"Song ID\": \"3Z8FwOEN59mRMxDCtb8N0A\", \"Genre\": \"['brostep', 'edm', 'pop', 'pop dance', 'progressive electro house']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 80.0, \"Danceability\": 0.63, \"Energy\": 0.633, \"Loudness\": -7.088, \"Speechiness\": 0.0457, \"Acousticness\": 0.00776, \"Liveness\": 0.0541, \"Tempo\": 93.995, \"Duration (ms)\": 172762.0, \"Valence\": 0.452, \"Chord\": \"E\"}, {\"Index\": 607, \"Highest Charting Position\": 76, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Fever\", \"Streams\": 4769618, \"Artist\": \"Dua Lipa, Ang\\u00e8le\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3wJVBz7gvGTwTWVAxFa6ny\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-10-29\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 73.0, \"Danceability\": 0.868, \"Energy\": 0.693, \"Loudness\": -7.052, \"Speechiness\": 0.181, \"Acousticness\": 0.0597, \"Liveness\": 0.106, \"Tempo\": 114.999, \"Duration (ms)\": 156911.0, \"Valence\": 0.396, \"Chord\": \"F#/Gb\"}, {\"Index\": 608, \"Highest Charting Position\": 141, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Angst\", \"Streams\": 5317174, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"5yUzqd3H7cmJ1no6B4uTzu\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2021-01-01\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.599, \"Energy\": 0.79, \"Loudness\": -4.352, \"Speechiness\": 0.386, \"Acousticness\": 0.0213, \"Liveness\": 0.0778, \"Tempo\": 100.119, \"Duration (ms)\": 201501.0, \"Valence\": 0.528, \"Chord\": \"A\"}, {\"Index\": 609, \"Highest Charting Position\": 15, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"no body, no crime (feat. HAIM)\", \"Streams\": 4986214, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3RaT22zZsxVYxxKR7TAaYF\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 68.0, \"Danceability\": 0.546, \"Energy\": 0.613, \"Loudness\": -7.589, \"Speechiness\": 0.0264, \"Acousticness\": 0.418, \"Liveness\": 0.103, \"Tempo\": 79.015, \"Duration (ms)\": 215627.0, \"Valence\": 0.535, \"Chord\": \"G\"}, {\"Index\": 610, \"Highest Charting Position\": 13, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Sunday Best\", \"Streams\": 4858392, \"Artist\": \"Surfaces\", \"Artist Followers\": 724903.0, \"Song ID\": \"1Cv1YLb4q0RzL6pybtaMLo\", \"Genre\": \"['bedroom soul', 'pop']\", \"Release Date\": \"2019-01-06\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 80.0, \"Danceability\": 0.878, \"Energy\": 0.525, \"Loudness\": -6.832, \"Speechiness\": 0.0578, \"Acousticness\": 0.183, \"Liveness\": 0.0714, \"Tempo\": 112.022, \"Duration (ms)\": 158571.0, \"Valence\": 0.694, \"Chord\": \"F\"}, {\"Index\": 611, \"Highest Charting Position\": 171, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Amor ou o Litr\\u00e3o\", \"Streams\": 4848222, \"Artist\": \"Petter Ferraz, Menor Nico\", \"Artist Followers\": 14122.0, \"Song ID\": \"7qmnP8Woc47dLSrMD5MxL1\", \"Genre\": \"[]\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 66.0, \"Danceability\": 0.934, \"Energy\": 0.707, \"Loudness\": -4.214, \"Speechiness\": 0.0646, \"Acousticness\": 0.437, \"Liveness\": 0.0628, \"Tempo\": 138.023, \"Duration (ms)\": 173913.0, \"Valence\": 0.961, \"Chord\": \"A\"}, {\"Index\": 612, \"Highest Charting Position\": 66, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Happier\", \"Streams\": 4655272, \"Artist\": \"Marshmello, Bastille\", \"Artist Followers\": 31552500.0, \"Song ID\": \"2dpaYNEQHiRxtZbfNsse99\", \"Genre\": \"['brostep', 'edm', 'pop', 'pop dance', 'progressive electro house']\", \"Release Date\": \"2018-08-17\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-11-13--2020-11-20\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.687, \"Energy\": 0.792, \"Loudness\": -2.749, \"Speechiness\": 0.0452, \"Acousticness\": 0.191, \"Liveness\": 0.167, \"Tempo\": 100.015, \"Duration (ms)\": 214290.0, \"Valence\": 0.671, \"Chord\": \"F\"}, {\"Index\": 613, \"Highest Charting Position\": 138, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Don't Stop Me Now - Remastered 2011\", \"Streams\": 4630572, \"Artist\": \"Queen\", \"Artist Followers\": 35910149.0, \"Song ID\": \"7hQJA50XrCWABAu5v6QZ4i\", \"Genre\": \"['classic rock', 'glam rock', 'rock']\", \"Release Date\": \"1978-11-10\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-15--2020-05-22\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.563, \"Energy\": 0.865, \"Loudness\": -5.277, \"Speechiness\": 0.16, \"Acousticness\": 0.0472, \"Liveness\": 0.77, \"Tempo\": 156.271, \"Duration (ms)\": 209413.0, \"Valence\": 0.601, \"Chord\": \"F\"}, {\"Index\": 614, \"Highest Charting Position\": 61, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Azul\", \"Streams\": 4606011, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"2lCkncy6bIB0LTMT7kvrD1\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 77.0, \"Danceability\": 0.843, \"Energy\": 0.836, \"Loudness\": -2.474, \"Speechiness\": 0.0695, \"Acousticness\": 0.0816, \"Liveness\": 0.0532, \"Tempo\": 94.018, \"Duration (ms)\": 205933.0, \"Valence\": 0.65, \"Chord\": \"B\"}, {\"Index\": 615, \"Highest Charting Position\": 183, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Basta Voc\\u00ea Me Ligar - Ao Vivo\", \"Streams\": 4580123, \"Artist\": \"Os Bar\\u00f5es Da Pisadinha, Xand Avi\\u00e3o\", \"Artist Followers\": 4281787.0, \"Song ID\": \"3AV1KI22k1jGMz792lDrj1\", \"Genre\": \"['forro', 'piseiro']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 68.0, \"Danceability\": 0.599, \"Energy\": 0.914, \"Loudness\": -2.415, \"Speechiness\": 0.0629, \"Acousticness\": 0.5, \"Liveness\": 0.694, \"Tempo\": 168.008, \"Duration (ms)\": 182977.0, \"Valence\": 0.831, \"Chord\": \"F\"}, {\"Index\": 616, \"Highest Charting Position\": 49, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Tequila Shots\", \"Streams\": 4540781, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"30KctD1WsHKTIYczXjip5a\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 74.0, \"Danceability\": 0.712, \"Energy\": 0.556, \"Loudness\": -7.214, \"Speechiness\": 0.0531, \"Acousticness\": 0.084, \"Liveness\": 0.527, \"Tempo\": 90.494, \"Duration (ms)\": 193293.0, \"Valence\": 0.22, \"Chord\": \"F\"}, {\"Index\": 617, \"Highest Charting Position\": 27, \"Number of Times Charted\": 45, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Lose Control\", \"Streams\": 4516053, \"Artist\": \"MEDUZA, Becky Hill, Goodboys\", \"Artist Followers\": 441714.0, \"Song ID\": \"7CHi4DtfK4heMlQaudCuHK\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop house', 'tropical house']\", \"Release Date\": \"2019-10-11\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.598, \"Energy\": 0.526, \"Loudness\": -8.659, \"Speechiness\": 0.0415, \"Acousticness\": 0.129, \"Liveness\": 0.14, \"Tempo\": 123.935, \"Duration (ms)\": 168387.0, \"Valence\": 0.529, \"Chord\": \"A#/Bb\"}, {\"Index\": 618, \"Highest Charting Position\": 68, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"I CAN'T STOP ME\", \"Streams\": 4504304, \"Artist\": \"TWICE\", \"Artist Followers\": 9998991.0, \"Song ID\": \"37ZtpRBkHcaq6hHy0X98zn\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-26\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 76.0, \"Danceability\": 0.657, \"Energy\": 0.88, \"Loudness\": -3.672, \"Speechiness\": 0.102, \"Acousticness\": 0.121, \"Liveness\": 0.463, \"Tempo\": 150.084, \"Duration (ms)\": 205493.0, \"Valence\": 0.769, \"Chord\": \"A#/Bb\"}, {\"Index\": 619, \"Highest Charting Position\": 158, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"E-GIRLS ARE RUINING MY LIFE!\", \"Streams\": 4488125, \"Artist\": \"CORPSE, Savage Ga$p\", \"Artist Followers\": 1777797.0, \"Song ID\": \"7bCfHiRcfUjG0YVVNUL7Ve\", \"Genre\": \"['dream smp', 'viral rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 77.0, \"Danceability\": 0.614, \"Energy\": 0.937, \"Loudness\": -7.443, \"Speechiness\": 0.115, \"Acousticness\": 0.00161, \"Liveness\": 0.103, \"Tempo\": 84.98, \"Duration (ms)\": 105176.0, \"Valence\": 0.386, \"Chord\": \"C#/Db\"}, {\"Index\": 620, \"Highest Charting Position\": 1, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"All I Want for Christmas Is You\", \"Streams\": 23235257, \"Artist\": \"Mariah Carey\", \"Artist Followers\": 6931357.0, \"Song ID\": \"0bYg9bo50gSsH3LtXe2SQn\", \"Genre\": \"['dance pop', 'pop', 'r&b', 'urban contemporary']\", \"Release Date\": \"1994-11-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2019-12-27--2020-01-03\", \"Popularity\": 65.0, \"Danceability\": 0.336, \"Energy\": 0.627, \"Loudness\": -7.463, \"Speechiness\": 0.0384, \"Acousticness\": 0.164, \"Liveness\": 0.0708, \"Tempo\": 150.273, \"Duration (ms)\": 241107.0, \"Valence\": 0.35, \"Chord\": \"G\"}, {\"Index\": 621, \"Highest Charting Position\": 2, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Last Christmas\", \"Streams\": 20709328, \"Artist\": \"Wham!\", \"Artist Followers\": 1631876.0, \"Song ID\": \"2FRnf9qhLbvw8fu4IBXx78\", \"Genre\": \"['disco', 'europop', 'new romantic', 'new wave', 'new wave pop', 'soft rock', 'synthpop']\", \"Release Date\": \"1984-11-29\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 63.0, \"Danceability\": 0.735, \"Energy\": 0.478, \"Loudness\": -12.472, \"Speechiness\": 0.0293, \"Acousticness\": 0.189, \"Liveness\": 0.355, \"Tempo\": 107.682, \"Duration (ms)\": 262960.0, \"Valence\": 0.947, \"Chord\": \"D\"}, {\"Index\": 622, \"Highest Charting Position\": 3, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Tell Me\", \"Streams\": 16657592, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"0lizgQ7Qw35od7CYaoMBZb\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2014-11-24\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 61.0, \"Danceability\": 0.525, \"Energy\": 0.621, \"Loudness\": -7.364, \"Speechiness\": 0.116, \"Acousticness\": 0.0489, \"Liveness\": 0.294, \"Tempo\": 191.9, \"Duration (ms)\": 204093.0, \"Valence\": 0.591, \"Chord\": \"G\"}, {\"Index\": 623, \"Highest Charting Position\": 5, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Rockin' Around The Christmas Tree\", \"Streams\": 16613649, \"Artist\": \"Brenda Lee\", \"Artist Followers\": 222627.0, \"Song ID\": \"2EjXfH91m7f8HiJN1yQg97\", \"Genre\": \"['adult standards', 'brill building pop', 'easy listening', 'lounge', 'rockabilly', 'vocal jazz']\", \"Release Date\": \"1964-10-19\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 58.0, \"Danceability\": 0.589, \"Energy\": 0.472, \"Loudness\": -8.749, \"Speechiness\": 0.0502, \"Acousticness\": 0.614, \"Liveness\": 0.505, \"Tempo\": 67.196, \"Duration (ms)\": 126267.0, \"Valence\": 0.898, \"Chord\": \"G#/Ab\"}, {\"Index\": 624, \"Highest Charting Position\": 7, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Jingle Bell Rock\", \"Streams\": 16527404, \"Artist\": \"Bobby Helms\", \"Artist Followers\": 20637.0, \"Song ID\": \"7vQbuQcyTflfCIOu3Uzzya\", \"Genre\": \"[]\", \"Release Date\": \"1957-12-02\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 56.0, \"Danceability\": 0.754, \"Energy\": 0.424, \"Loudness\": -8.463, \"Speechiness\": 0.0363, \"Acousticness\": 0.643, \"Liveness\": 0.0652, \"Tempo\": 119.705, \"Duration (ms)\": 130973.0, \"Valence\": 0.806, \"Chord\": \"D\"}, {\"Index\": 625, \"Highest Charting Position\": 6, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"It's Beginning to Look a Lot like Christmas\", \"Streams\": 15424001, \"Artist\": \"Michael Bubl\\u00e9\", \"Artist Followers\": 4702232.0, \"Song ID\": \"5a1iz510sv2W9Dt1MvFd5R\", \"Genre\": \"['adult standards', 'canadian pop', 'jazz pop', 'lounge']\", \"Release Date\": \"2012-11-09\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 55.0, \"Danceability\": 0.339, \"Energy\": 0.214, \"Loudness\": -11.714, \"Speechiness\": 0.0375, \"Acousticness\": 0.908, \"Liveness\": 0.341, \"Tempo\": 94.775, \"Duration (ms)\": 206640.0, \"Valence\": 0.363, \"Chord\": \"E\"}, {\"Index\": 626, \"Highest Charting Position\": 8, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"It's the Most Wonderful Time of the Year\", \"Streams\": 14582001, \"Artist\": \"Andy Williams\", \"Artist Followers\": 369548.0, \"Song ID\": \"5hslUAKq9I9CG2bAulFkHN\", \"Genre\": \"['adult standards', 'brill building pop', 'easy listening', 'lounge', 'mellow gold', 'vocal jazz']\", \"Release Date\": \"1963-11-24\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 55.0, \"Danceability\": 0.24, \"Energy\": 0.598, \"Loudness\": -8.435, \"Speechiness\": 0.0369, \"Acousticness\": 0.766, \"Liveness\": 0.117, \"Tempo\": 201.629, \"Duration (ms)\": 151933.0, \"Valence\": 0.776, \"Chord\": \"G\"}, {\"Index\": 627, \"Highest Charting Position\": 9, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Underneath the Tree\", \"Streams\": 12266990, \"Artist\": \"Kelly Clarkson\", \"Artist Followers\": 7869617.0, \"Song ID\": \"3YZE5qDV7u1ZD1gZc47ZeR\", \"Genre\": \"['dance pop', 'neo mellow', 'pop', 'pop rock', 'post-teen pop', 'talent show']\", \"Release Date\": \"2013-10-29\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 49.0, \"Danceability\": 0.509, \"Energy\": 0.812, \"Loudness\": -5.439, \"Speechiness\": 0.0537, \"Acousticness\": 0.00128, \"Liveness\": 0.214, \"Tempo\": 159.878, \"Duration (ms)\": 229640.0, \"Valence\": 0.689, \"Chord\": \"G#/Ab\"}, {\"Index\": 628, \"Highest Charting Position\": 14, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Feliz Navidad\", \"Streams\": 11664490, \"Artist\": \"Jos\\u00e9 Feliciano\", \"Artist Followers\": 239129.0, \"Song ID\": \"0oPdaY4dXtc3ZsaG17V972\", \"Genre\": \"['latin pop', 'puerto rican pop']\", \"Release Date\": \"2002-09-24\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 49.0, \"Danceability\": 0.513, \"Energy\": 0.831, \"Loudness\": -9.004, \"Speechiness\": 0.0383, \"Acousticness\": 0.55, \"Liveness\": 0.336, \"Tempo\": 148.837, \"Duration (ms)\": 182067.0, \"Valence\": 0.963, \"Chord\": \"D\"}, {\"Index\": 629, \"Highest Charting Position\": 11, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Let It Snow! Let It Snow! Let It Snow!\", \"Streams\": 10884855, \"Artist\": \"Dean Martin\", \"Artist Followers\": 1139096.0, \"Song ID\": \"2uFaJJtFpPDc5Pa95XzTvg\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"1959-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 54.0, \"Danceability\": 0.451, \"Energy\": 0.24, \"Loudness\": -14.014, \"Speechiness\": 0.0351, \"Acousticness\": 0.912, \"Liveness\": 0.175, \"Tempo\": 134.009, \"Duration (ms)\": 117147.0, \"Valence\": 0.701, \"Chord\": \"C#/Db\"}, {\"Index\": 630, \"Highest Charting Position\": 19, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Let It Snow! Let It Snow! Let It Snow! (with The B. Swanson Quartet)\", \"Streams\": 10787165, \"Artist\": \"Frank Sinatra\", \"Artist Followers\": 4953667.0, \"Song ID\": \"4kKdvXD0ez7jp1296JmAts\", \"Genre\": \"['adult standards', 'easy listening', 'lounge']\", \"Release Date\": \"1994-11-08\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 53.0, \"Danceability\": 0.652, \"Energy\": 0.259, \"Loudness\": -13.336, \"Speechiness\": 0.0595, \"Acousticness\": 0.903, \"Liveness\": 0.362, \"Tempo\": 142.169, \"Duration (ms)\": 155453.0, \"Valence\": 0.836, \"Chord\": \"D\"}, {\"Index\": 631, \"Highest Charting Position\": 15, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Mistletoe\", \"Streams\": 10609206, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"7xapw9Oy21WpfEcib2ErSA\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2011-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 59.0, \"Danceability\": 0.657, \"Energy\": 0.56, \"Loudness\": -9.049, \"Speechiness\": 0.0467, \"Acousticness\": 0.498, \"Liveness\": 0.0794, \"Tempo\": 161.993, \"Duration (ms)\": 182947.0, \"Valence\": 0.854, \"Chord\": \"F#/Gb\"}, {\"Index\": 632, \"Highest Charting Position\": 16, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Sleigh Ride\", \"Streams\": 10508459, \"Artist\": \"The Ronettes\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5ASM6Qjiav2xPe7gRkQMsQ\", \"Genre\": \"[]\", \"Release Date\": \"1963\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 50.0, \"Danceability\": 0.529, \"Energy\": 0.772, \"Loudness\": -7.013, \"Speechiness\": 0.0287, \"Acousticness\": 0.403, \"Liveness\": 0.316, \"Tempo\": 91.751, \"Duration (ms)\": 181267.0, \"Valence\": 0.853, \"Chord\": \"D\"}, {\"Index\": 633, \"Highest Charting Position\": 17, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Do They Know It's Christmas? - 1984 Version\", \"Streams\": 10476212, \"Artist\": \"Band Aid\", \"Artist Followers\": 4883.0, \"Song ID\": \"0247StOpd3AkeBQzANX4Zf\", \"Genre\": \"['musical advocacy']\", \"Release Date\": \"2004-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 51.0, \"Danceability\": 0.599, \"Energy\": 0.642, \"Loudness\": -6.936, \"Speechiness\": 0.0363, \"Acousticness\": 0.164, \"Liveness\": 0.0992, \"Tempo\": 115.412, \"Duration (ms)\": 222533.0, \"Valence\": 0.349, \"Chord\": \"C\"}, {\"Index\": 634, \"Highest Charting Position\": 23, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Wonderful Christmastime - Edited Version / Remastered 2011\", \"Streams\": 9882989, \"Artist\": \"Paul McCartney\", \"Artist Followers\": 3609658.0, \"Song ID\": \"1SV1fxF65n9NhRHp3KlBuu\", \"Genre\": \"['album rock', 'art rock', 'beatlesque', 'classic rock', 'mellow gold', 'rock', 'soft rock']\", \"Release Date\": \"1980-05-16\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 51.0, \"Danceability\": 0.774, \"Energy\": 0.511, \"Loudness\": -8.914, \"Speechiness\": 0.0319, \"Acousticness\": 0.322, \"Liveness\": 0.0672, \"Tempo\": 94.736, \"Duration (ms)\": 227653.0, \"Valence\": 0.771, \"Chord\": \"B\"}, {\"Index\": 635, \"Highest Charting Position\": 21, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Holly Jolly Christmas\", \"Streams\": 9852792, \"Artist\": \"Michael Bubl\\u00e9\", \"Artist Followers\": 4702232.0, \"Song ID\": \"5PuKlCjfEVIXl0ZBp5ZW9g\", \"Genre\": \"['adult standards', 'canadian pop', 'jazz pop', 'lounge']\", \"Release Date\": \"2012-11-09\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 48.0, \"Danceability\": 0.647, \"Energy\": 0.465, \"Loudness\": -8.308, \"Speechiness\": 0.0428, \"Acousticness\": 0.865, \"Liveness\": 0.0882, \"Tempo\": 151.251, \"Duration (ms)\": 119787.0, \"Valence\": 0.699, \"Chord\": \"G\"}, {\"Index\": 636, \"Highest Charting Position\": 24, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Happy Xmas (War Is Over) - Remastered 2010\", \"Streams\": 9509781, \"Artist\": \"John Lennon, Yoko Ono\", \"Artist Followers\": 4313100.0, \"Song ID\": \"27RYrbL6S02LNVhDWVl38b\", \"Genre\": \"['album rock', 'art rock', 'beatlesque', 'classic rock', 'folk rock', 'mellow gold', 'rock']\", \"Release Date\": \"2010-10-05\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 53.0, \"Danceability\": 0.321, \"Energy\": 0.64, \"Loudness\": -10.023, \"Speechiness\": 0.0324, \"Acousticness\": 0.28, \"Liveness\": 0.718, \"Tempo\": 146.172, \"Duration (ms)\": 214333.0, \"Valence\": 0.414, \"Chord\": \"D\"}, {\"Index\": 637, \"Highest Charting Position\": 22, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Driving Home for Christmas - 2019 Remaster\", \"Streams\": 8804531, \"Artist\": \"Chris Rea\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 638, \"Highest Charting Position\": 32, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"The Christmas Song (Merry Christmas To You)\", \"Streams\": 8478518, \"Artist\": \"Nat King Cole\", \"Artist Followers\": 1634288.0, \"Song ID\": \"4PS1e8f2LvuTFgUs1Cn3ON\", \"Genre\": \"['adult standards', 'lounge', 'soul', 'vocal jazz']\", \"Release Date\": \"1962\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 53.0, \"Danceability\": 0.319, \"Energy\": 0.21, \"Loudness\": -15.231, \"Speechiness\": 0.0341, \"Acousticness\": 0.92, \"Liveness\": 0.138, \"Tempo\": 78.696, \"Duration (ms)\": 192160.0, \"Valence\": 0.209, \"Chord\": \"C#/Db\"}, {\"Index\": 639, \"Highest Charting Position\": 39, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"White Christmas\", \"Streams\": 7045348, \"Artist\": \"Bing Crosby, Ken Darby Singers, John Scott Trotter & His Orchestra\", \"Artist Followers\": 359973.0, \"Song ID\": \"4so0Wek9Ig1p6CRCHuINwW\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'swing', 'vocal jazz']\", \"Release Date\": \"1942-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 51.0, \"Danceability\": 0.317, \"Energy\": 0.158, \"Loudness\": -16.485, \"Speechiness\": 0.0381, \"Acousticness\": 0.673, \"Liveness\": 0.338, \"Tempo\": 130.503, \"Duration (ms)\": 177480.0, \"Valence\": 0.247, \"Chord\": \"A\"}, {\"Index\": 640, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Slay3r\", \"Streams\": 6912271, \"Artist\": \"Playboi Carti\", \"Artist Followers\": 4958353.0, \"Song ID\": \"1eMNW1HQjF1dbb4GtnmpaX\", \"Genre\": \"['atl hip hop', 'plugg', 'rap', 'trap']\", \"Release Date\": \"2020-12-25\", \"Weeks Charted\": \"2020-12-25--2021-01-01\", \"Popularity\": 63.0, \"Danceability\": 0.885, \"Energy\": 0.661, \"Loudness\": -5.062, \"Speechiness\": 0.141, \"Acousticness\": 0.165, \"Liveness\": 0.334, \"Tempo\": 140.028, \"Duration (ms)\": 164591.0, \"Valence\": 0.436, \"Chord\": \"E\"}, {\"Index\": 641, \"Highest Charting Position\": 42, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"A Holly Jolly Christmas - Single Version\", \"Streams\": 6716353, \"Artist\": \"Burl Ives\", \"Artist Followers\": 58479.0, \"Song ID\": \"77khP2fIVhSW23NwxrRluh\", \"Genre\": \"['adult standards', 'american folk revival']\", \"Release Date\": \"1965-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 49.0, \"Danceability\": 0.683, \"Energy\": 0.375, \"Loudness\": -13.056, \"Speechiness\": 0.0303, \"Acousticness\": 0.579, \"Liveness\": 0.076, \"Tempo\": 140.467, \"Duration (ms)\": 135533.0, \"Valence\": 0.888, \"Chord\": \"C\"}, {\"Index\": 642, \"Highest Charting Position\": 47, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Fairytale of New York (feat. Kirsty MacColl)\", \"Streams\": 6404964, \"Artist\": \"The Pogues\", \"Artist Followers\": 382997.0, \"Song ID\": \"3VTNVsTTu05dmTsVFrmGpK\", \"Genre\": \"['celtic', 'celtic punk', 'celtic rock', 'folk punk', 'irish folk', 'punk']\", \"Release Date\": \"1988-09-05\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 55.0, \"Danceability\": 0.271, \"Energy\": 0.551, \"Loudness\": -7.48, \"Speechiness\": 0.0457, \"Acousticness\": 0.582, \"Liveness\": 0.256, \"Tempo\": 78.111, \"Duration (ms)\": 272467.0, \"Valence\": 0.428, \"Chord\": \"D\"}, {\"Index\": 643, \"Highest Charting Position\": 38, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Merry Christmas Everyone\", \"Streams\": 6052105, \"Artist\": \"Shakin' Stevens\", \"Artist Followers\": 99249.0, \"Song ID\": \"2TE4xW3ImvpltVU0cPcKUn\", \"Genre\": \"['classic uk pop', 'new wave pop', 'rock-and-roll', 'rockabilly', 'soft rock']\", \"Release Date\": \"1991-11-25\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 47.0, \"Danceability\": 0.534, \"Energy\": 0.904, \"Loudness\": -3.315, \"Speechiness\": 0.0369, \"Acousticness\": 0.129, \"Liveness\": 0.128, \"Tempo\": 202.899, \"Duration (ms)\": 220160.0, \"Valence\": 0.96, \"Chord\": \"A\"}, {\"Index\": 644, \"Highest Charting Position\": 62, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Blue Christmas\", \"Streams\": 6007011, \"Artist\": \"Elvis Presley\", \"Artist Followers\": 5698788.0, \"Song ID\": \"3QiAAp20rPC3dcAtKtMaqQ\", \"Genre\": \"['rock-and-roll', 'rockabilly']\", \"Release Date\": \"1957-10-15\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 49.0, \"Danceability\": 0.465, \"Energy\": 0.27, \"Loudness\": -16.661, \"Speechiness\": 0.0425, \"Acousticness\": 0.9, \"Liveness\": 0.145, \"Tempo\": 94.518, \"Duration (ms)\": 129173.0, \"Valence\": 0.58, \"Chord\": \"E\"}, {\"Index\": 645, \"Highest Charting Position\": 65, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Run Rudolph Run - Single Version\", \"Streams\": 5802508, \"Artist\": \"Chuck Berry\", \"Artist Followers\": 1251372.0, \"Song ID\": \"47CIT5hMphuMQkpeyfGQTL\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 0.0, \"Danceability\": 0.647, \"Energy\": 0.876, \"Loudness\": -5.662, \"Speechiness\": 0.185, \"Acousticness\": 0.881, \"Liveness\": 0.26, \"Tempo\": 151.925, \"Duration (ms)\": 162897.0, \"Valence\": 0.949, \"Chord\": \"A#/Bb\"}, {\"Index\": 646, \"Highest Charting Position\": 59, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Claus Is Coming To Town\", \"Streams\": 5801639, \"Artist\": \"The Jackson 5\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5Gz7EYD7JAmItA7FbhKgKb\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 0.0, \"Danceability\": 0.691, \"Energy\": 0.776, \"Loudness\": -4.177, \"Speechiness\": 0.0341, \"Acousticness\": 0.458, \"Liveness\": 0.33, \"Tempo\": 146.861, \"Duration (ms)\": 144080.0, \"Valence\": 0.961, \"Chord\": \"C\"}, {\"Index\": 647, \"Highest Charting Position\": 52, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Baby\", \"Streams\": 5687085, \"Artist\": \"Kylie Minogue\", \"Artist Followers\": 1324920.0, \"Song ID\": \"0cM5URUqqQTpJWonmdzF1J\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'electropop', 'eurodance', 'europop', 'new wave pop', 'pop']\", \"Release Date\": \"2010-11-30\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 42.0, \"Danceability\": 0.685, \"Energy\": 0.391, \"Loudness\": -7.183, \"Speechiness\": 0.0435, \"Acousticness\": 0.744, \"Liveness\": 0.142, \"Tempo\": 87.101, \"Duration (ms)\": 202547.0, \"Valence\": 0.443, \"Chord\": \"C#/Db\"}, {\"Index\": 648, \"Highest Charting Position\": 60, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"It's Beginning to Look a Lot Like Christmas (with Mitchell Ayres & His Orchestra)\", \"Streams\": 5422082, \"Artist\": \"Perry Como, The Fontane Sisters\", \"Artist Followers\": 336373.0, \"Song ID\": \"2pXpURmn6zC5ZYDMms6fwa\", \"Genre\": \"['adult standards', 'brill building pop', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"1999-08-20\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 49.0, \"Danceability\": 0.724, \"Energy\": 0.276, \"Loudness\": -12.25, \"Speechiness\": 0.0599, \"Acousticness\": 0.76, \"Liveness\": 0.116, \"Tempo\": 112.874, \"Duration (ms)\": 155933.0, \"Valence\": 0.718, \"Chord\": \"G\"}, {\"Index\": 649, \"Highest Charting Position\": 69, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas (Baby Please Come Home)\", \"Streams\": 5394054, \"Artist\": \"Darlene Love\", \"Artist Followers\": 1251372.0, \"Song ID\": \"46pF1zFimM582ss1PrMy68\", \"Genre\": \"[]\", \"Release Date\": \"1963\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-12-04--2020-12-11\", \"Popularity\": 45.0, \"Danceability\": 0.325, \"Energy\": 0.759, \"Loudness\": -7.146, \"Speechiness\": 0.053, \"Acousticness\": 0.395, \"Liveness\": 0.0773, \"Tempo\": 126.627, \"Duration (ms)\": 166453.0, \"Valence\": 0.36, \"Chord\": \"G#/Ab\"}, {\"Index\": 650, \"Highest Charting Position\": 66, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Step Into Christmas\", \"Streams\": 5353591, \"Artist\": \"Elton John\", \"Artist Followers\": 7504724.0, \"Song ID\": \"6sBWmE23q6xQHlnEZ8jYPT\", \"Genre\": \"['glam rock', 'mellow gold', 'piano rock']\", \"Release Date\": \"1973-10-05\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 43.0, \"Danceability\": 0.526, \"Energy\": 0.925, \"Loudness\": -5.584, \"Speechiness\": 0.0363, \"Acousticness\": 0.102, \"Liveness\": 0.305, \"Tempo\": 140.308, \"Duration (ms)\": 272394.0, \"Valence\": 0.819, \"Chord\": \"D\"}, {\"Index\": 651, \"Highest Charting Position\": 54, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Show Out (with Skepta & Pop Smoke)\", \"Streams\": 5209372, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"5CFJRZRq6sdKKtRwNPWbYv\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 76.0, \"Danceability\": 0.619, \"Energy\": 0.589, \"Loudness\": -6.531, \"Speechiness\": 0.124, \"Acousticness\": 0.43, \"Liveness\": 0.378, \"Tempo\": 143.896, \"Duration (ms)\": 174960.0, \"Valence\": 0.158, \"Chord\": \"C#/Db\"}, {\"Index\": 652, \"Highest Charting Position\": 166, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Investe Em Mim\", \"Streams\": 5191001, \"Artist\": \"Jonas Esticado\", \"Artist Followers\": 1293055.0, \"Song ID\": \"15k1TDabqSEmyXOwMq9RM7\", \"Genre\": \"['forro', 'sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 72.0, \"Danceability\": 0.632, \"Energy\": 0.953, \"Loudness\": -1.283, \"Speechiness\": 0.0325, \"Acousticness\": 0.317, \"Liveness\": 0.125, \"Tempo\": 160.061, \"Duration (ms)\": 186533.0, \"Valence\": 0.798, \"Chord\": \"A\"}, {\"Index\": 653, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Lance Individual\", \"Streams\": 5152906, \"Artist\": \"Jorge & Mateus\", \"Artist Followers\": 15019109.0, \"Song ID\": \"7GLWWrk1YlkPYqJK3ynIA0\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-12-25--2021-01-01\", \"Popularity\": 72.0, \"Danceability\": 0.752, \"Energy\": 0.62, \"Loudness\": -5.536, \"Speechiness\": 0.0509, \"Acousticness\": 0.309, \"Liveness\": 0.075, \"Tempo\": 117.399, \"Duration (ms)\": 164459.0, \"Valence\": 0.962, \"Chord\": \"F\"}, {\"Index\": 654, \"Highest Charting Position\": 71, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Jingle Bell Rock - Daryl's Version\", \"Streams\": 10522305, \"Artist\": \"Daryl Hall & John Oates\", \"Artist Followers\": 1549216.0, \"Song ID\": \"6pVW5LRWgeLaHudxauOTJU\", \"Genre\": \"['album rock', 'classic rock', 'mellow gold', 'rock', 'soft rock', 'yacht rock']\", \"Release Date\": \"1983-11-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 43.0, \"Danceability\": 0.666, \"Energy\": 0.841, \"Loudness\": -3.592, \"Speechiness\": 0.0312, \"Acousticness\": 0.613, \"Liveness\": 0.113, \"Tempo\": 128.706, \"Duration (ms)\": 126360.0, \"Valence\": 0.84, \"Chord\": \"D\"}, {\"Index\": 655, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Thank God It's Christmas - Non-Album Single\", \"Streams\": 10509961, \"Artist\": \"Queen\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 656, \"Highest Charting Position\": 74, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas Lights\", \"Streams\": 10455065, \"Artist\": \"Coldplay\", \"Artist Followers\": 31161671.0, \"Song ID\": \"4QVdnpSO5JGMFOEl6ys4RQ\", \"Genre\": \"['permanent wave', 'pop']\", \"Release Date\": \"2016-12-16\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 53.0, \"Danceability\": 0.295, \"Energy\": 0.496, \"Loudness\": -9.478, \"Speechiness\": 0.0327, \"Acousticness\": 0.207, \"Liveness\": 0.858, \"Tempo\": 132.062, \"Duration (ms)\": 268521.0, \"Valence\": 0.224, \"Chord\": \"G\"}, {\"Index\": 657, \"Highest Charting Position\": 83, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Have Yourself A Merry Little Christmas\", \"Streams\": 9548924, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"1Qi2wh8fFgDV7tl4Sj3f2K\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2014-12-05\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 46.0, \"Danceability\": 0.438, \"Energy\": 0.178, \"Loudness\": -9.402, \"Speechiness\": 0.0414, \"Acousticness\": 0.957, \"Liveness\": 0.316, \"Tempo\": 75.248, \"Duration (ms)\": 170964.0, \"Valence\": 0.344, \"Chord\": \"F\"}, {\"Index\": 658, \"Highest Charting Position\": 85, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa's Coming for Us\", \"Streams\": 9474711, \"Artist\": \"Sia\", \"Artist Followers\": 20528724.0, \"Song ID\": \"1N1ZpYUJc9fwrqk53FGgWv\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'pop']\", \"Release Date\": \"2018-11-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 49.0, \"Danceability\": 0.547, \"Energy\": 0.814, \"Loudness\": -6.191, \"Speechiness\": 0.12, \"Acousticness\": 0.0215, \"Liveness\": 0.0475, \"Tempo\": 92.986, \"Duration (ms)\": 205267.0, \"Valence\": 0.724, \"Chord\": \"C#/Db\"}, {\"Index\": 659, \"Highest Charting Position\": 86, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"My Only Wish (This Year)\", \"Streams\": 9457199, \"Artist\": \"Britney Spears\", \"Artist Followers\": 9470311.0, \"Song ID\": \"0YWUHZPJVg4iujddsJDwhM\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2000-11-14\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-04--2020-12-11\", \"Popularity\": 43.0, \"Danceability\": 0.669, \"Energy\": 0.843, \"Loudness\": -3.766, \"Speechiness\": 0.0268, \"Acousticness\": 0.169, \"Liveness\": 0.195, \"Tempo\": 147.08, \"Duration (ms)\": 255400.0, \"Valence\": 0.702, \"Chord\": \"C\"}, {\"Index\": 660, \"Highest Charting Position\": 89, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Baby, It's Cold Outside (feat. Meghan Trainor)\", \"Streams\": 9270017, \"Artist\": \"Brett Eldredge\", \"Artist Followers\": 1298537.0, \"Song ID\": \"5Q2P43CJra0uRAogjHyJDK\", \"Genre\": \"['contemporary country', 'country', 'country road', 'modern country rock']\", \"Release Date\": \"2016-10-28\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 44.0, \"Danceability\": 0.583, \"Energy\": 0.572, \"Loudness\": -4.776, \"Speechiness\": 0.0366, \"Acousticness\": 0.738, \"Liveness\": 0.266, \"Tempo\": 113.998, \"Duration (ms)\": 173560.0, \"Valence\": 0.684, \"Chord\": \"C#/Db\"}, {\"Index\": 661, \"Highest Charting Position\": 92, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Like It's Christmas\", \"Streams\": 9167304, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"1OjmlSFuzYflWjSMTCyTJv\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-04--2020-12-11\", \"Popularity\": 47.0, \"Danceability\": 0.725, \"Energy\": 0.571, \"Loudness\": -6.007, \"Speechiness\": 0.102, \"Acousticness\": 0.0183, \"Liveness\": 0.0519, \"Tempo\": 146.035, \"Duration (ms)\": 200880.0, \"Valence\": 0.61, \"Chord\": \"C#/Db\"}, {\"Index\": 662, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas Without You\", \"Streams\": 8813922, \"Artist\": \"Ava Max\", \"Artist Followers\": 3916979.0, \"Song ID\": \"1QLZKzC2pjP4ySf4ALrNhm\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-10-15\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 45.0, \"Danceability\": 0.654, \"Energy\": 0.596, \"Loudness\": -4.68, \"Speechiness\": 0.0458, \"Acousticness\": 0.424, \"Liveness\": 0.11, \"Tempo\": 118.078, \"Duration (ms)\": 169245.0, \"Valence\": 0.382, \"Chord\": \"C#/Db\"}, {\"Index\": 663, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"You Make It Feel Like Christmas (feat. Blake Shelton)\", \"Streams\": 8696354, \"Artist\": \"Gwen Stefani\", \"Artist Followers\": 4805333.0, \"Song ID\": \"2OQ6a4CfUeYskpTTgyawyJ\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'post-teen pop', 'urban contemporary']\", \"Release Date\": \"2017-10-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.635, \"Energy\": 0.87, \"Loudness\": -4.291, \"Speechiness\": 0.04, \"Acousticness\": 0.0156, \"Liveness\": 0.118, \"Tempo\": 93.0, \"Duration (ms)\": 156773.0, \"Valence\": 0.912, \"Chord\": \"D\"}, {\"Index\": 664, \"Highest Charting Position\": 107, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Gnat\", \"Streams\": 8614955, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"6cS9PmLky2NhLOhpIsUlow\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 70.0, \"Danceability\": 0.835, \"Energy\": 0.869, \"Loudness\": -4.582, \"Speechiness\": 0.27, \"Acousticness\": 0.248, \"Liveness\": 0.462, \"Tempo\": 140.945, \"Duration (ms)\": 224656.0, \"Valence\": 0.82, \"Chord\": \"A#/Bb\"}, {\"Index\": 665, \"Highest Charting Position\": 111, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Joy To The World\", \"Streams\": 8387899, \"Artist\": \"Nat King Cole\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5oWFPbd340pwiXKMO1CQRy\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 0.0, \"Danceability\": 0.59, \"Energy\": 0.305, \"Loudness\": -12.955, \"Speechiness\": 0.032, \"Acousticness\": 0.894, \"Liveness\": 0.14, \"Tempo\": 102.103, \"Duration (ms)\": 86760.0, \"Valence\": 0.545, \"Chord\": \"A#/Bb\"}, {\"Index\": 666, \"Highest Charting Position\": 117, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Claus Is Coming to Town\", \"Streams\": 8177832, \"Artist\": \"Michael Bubl\\u00e9\", \"Artist Followers\": 4702232.0, \"Song ID\": \"1RMDXedcRno6rDBCbNHDJf\", \"Genre\": \"['adult standards', 'canadian pop', 'jazz pop', 'lounge']\", \"Release Date\": \"2012-11-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.594, \"Energy\": 0.389, \"Loudness\": -7.109, \"Speechiness\": 0.0517, \"Acousticness\": 0.785, \"Liveness\": 0.0313, \"Tempo\": 122.331, \"Duration (ms)\": 171093.0, \"Valence\": 0.396, \"Chord\": \"A#/Bb\"}, {\"Index\": 667, \"Highest Charting Position\": 119, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Baby It's Cold Outside (duet with Michael Bubl\\u00e9)\", \"Streams\": 8160534, \"Artist\": \"Idina Menzel\", \"Artist Followers\": 353571.0, \"Song ID\": \"0Ie5uiv54KgCr7P4sYDTHl\", \"Genre\": \"['hollywood', 'show tunes']\", \"Release Date\": \"2014-10-10\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 47.0, \"Danceability\": 0.553, \"Energy\": 0.476, \"Loudness\": -8.869, \"Speechiness\": 0.0649, \"Acousticness\": 0.647, \"Liveness\": 0.281, \"Tempo\": 113.401, \"Duration (ms)\": 166147.0, \"Valence\": 0.558, \"Chord\": \"C\"}, {\"Index\": 668, \"Highest Charting Position\": 22, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"\\u2018tis the damn season\", \"Streams\": 8115520, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7dW84mWkdWE5a6lFWxJCBG\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.575, \"Energy\": 0.434, \"Loudness\": -8.193, \"Speechiness\": 0.0312, \"Acousticness\": 0.735, \"Liveness\": 0.105, \"Tempo\": 145.916, \"Duration (ms)\": 229840.0, \"Valence\": 0.348, \"Chord\": \"F\"}, {\"Index\": 669, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"I Saw Mommy Kissing Santa Claus\", \"Streams\": 8064361, \"Artist\": \"The Jackson 5\", \"Artist Followers\": 1151360.0, \"Song ID\": \"15sxLiiChE5dCW3Y756oas\", \"Genre\": \"['motown', 'soul']\", \"Release Date\": \"1970-10-15\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.583, \"Energy\": 0.712, \"Loudness\": -8.222, \"Speechiness\": 0.0538, \"Acousticness\": 0.263, \"Liveness\": 0.817, \"Tempo\": 128.897, \"Duration (ms)\": 181267.0, \"Valence\": 0.614, \"Chord\": \"D#/Eb\"}, {\"Index\": 670, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Baby (with Henri Ren\\u00e9 & His Orchestra)\", \"Streams\": 8022773, \"Artist\": \"Eartha Kitt, Henri Rene & His Orchestra\", \"Artist Followers\": 127251.0, \"Song ID\": \"1foCxQtxBweJtZmdxhEHVO\", \"Genre\": \"['adult standards', 'lounge', 'torch song', 'vocal jazz']\", \"Release Date\": \"2002\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.7, \"Energy\": 0.139, \"Loudness\": -12.346, \"Speechiness\": 0.0607, \"Acousticness\": 0.902, \"Liveness\": 0.185, \"Tempo\": 84.485, \"Duration (ms)\": 206067.0, \"Valence\": 0.49, \"Chord\": \"G#/Ab\"}, {\"Index\": 671, \"Highest Charting Position\": 127, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Carol of the Bells\", \"Streams\": 7993078, \"Artist\": \"Mykola Dmytrovych Leontovych, John Williams\", \"Artist Followers\": 1024868.0, \"Song ID\": \"4tHqQMWSqmL6YjXwsqthDI\", \"Genre\": \"['soundtrack']\", \"Release Date\": \"1990\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 51.0, \"Danceability\": 0.418, \"Energy\": 0.106, \"Loudness\": -22.507, \"Speechiness\": 0.0448, \"Acousticness\": 0.994, \"Liveness\": 0.179, \"Tempo\": 46.718, \"Duration (ms)\": 85267.0, \"Valence\": 0.8, \"Chord\": \"G#/Ab\"}, {\"Index\": 672, \"Highest Charting Position\": 19, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"gold rush\", \"Streams\": 7901968, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5BK0uqwY9DNfZ630STAEaq\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 70.0, \"Danceability\": 0.512, \"Energy\": 0.462, \"Loudness\": -10.491, \"Speechiness\": 0.0408, \"Acousticness\": 0.83, \"Liveness\": 0.121, \"Tempo\": 112.05, \"Duration (ms)\": 185320.0, \"Valence\": 0.353, \"Chord\": \"A\"}, {\"Index\": 673, \"Highest Charting Position\": 133, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"What Christmas Means To Me\", \"Streams\": 7792643, \"Artist\": \"Stevie Wonder\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6Wn9zkkbWdK42uXCcADkRq\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 0.0, \"Danceability\": 0.545, \"Energy\": 0.7, \"Loudness\": -6.961, \"Speechiness\": 0.0323, \"Acousticness\": 0.0982, \"Liveness\": 0.1, \"Tempo\": 83.506, \"Duration (ms)\": 148147.0, \"Valence\": 0.799, \"Chord\": \"F\"}, {\"Index\": 674, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"The Christmas Song (Shawn Mendes & Camila Cabello)\", \"Streams\": 7536851, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 33893352.0, \"Song ID\": \"0fwxmtpxpMmEMphmJbCAEx\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2020-12-07\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 42.0, \"Danceability\": 0.341, \"Energy\": 0.181, \"Loudness\": -12.073, \"Speechiness\": 0.0366, \"Acousticness\": 0.888, \"Liveness\": 0.137, \"Tempo\": 83.608, \"Duration (ms)\": 196254.0, \"Valence\": 0.212, \"Chord\": \"D\"}, {\"Index\": 675, \"Highest Charting Position\": 144, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Baby, It's Cold Outside\", \"Streams\": 7367482, \"Artist\": \"Dean Martin\", \"Artist Followers\": 1139096.0, \"Song ID\": \"4MrfQL4TYQXJBlZYpAHTuE\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"1959-01-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.469, \"Energy\": 0.196, \"Loudness\": -16.093, \"Speechiness\": 0.0571, \"Acousticness\": 0.882, \"Liveness\": 0.0513, \"Tempo\": 130.036, \"Duration (ms)\": 143733.0, \"Valence\": 0.537, \"Chord\": \"C\"}, {\"Index\": 676, \"Highest Charting Position\": 145, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Claus Is Comin' to Town - Live at C.W. Post College, Greenvale, NY - December 1975\", \"Streams\": 7363913, \"Artist\": \"Bruce Springsteen\", \"Artist Followers\": 4224071.0, \"Song ID\": \"6s2wpWPFPAgKg2LXxi1Oee\", \"Genre\": \"['classic rock', 'heartland rock', 'mellow gold', 'permanent wave', 'rock', 'singer-songwriter']\", \"Release Date\": \"1981\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.357, \"Energy\": 0.668, \"Loudness\": -8.444, \"Speechiness\": 0.0479, \"Acousticness\": 0.362, \"Liveness\": 0.727, \"Tempo\": 139.986, \"Duration (ms)\": 267600.0, \"Valence\": 0.407, \"Chord\": \"C\"}, {\"Index\": 677, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"One More Sleep\", \"Streams\": 7350024, \"Artist\": \"Leona Lewis\", \"Artist Followers\": 2877234.0, \"Song ID\": \"78pn8k7RogKo2oxl0DyX6d\", \"Genre\": \"['british soul', 'dance pop', 'europop', 'pop', 'post-teen pop', 'talent show']\", \"Release Date\": \"2013-12-02\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 42.0, \"Danceability\": 0.638, \"Energy\": 0.813, \"Loudness\": -3.849, \"Speechiness\": 0.0362, \"Acousticness\": 0.464, \"Liveness\": 0.344, \"Tempo\": 112.986, \"Duration (ms)\": 239587.0, \"Valence\": 0.754, \"Chord\": \"B\"}, {\"Index\": 678, \"Highest Charting Position\": 149, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Little Saint Nick - 1991 Remix\", \"Streams\": 7301381, \"Artist\": \"The Beach Boys\", \"Artist Followers\": 1251372.0, \"Song ID\": \"63Lk6VuXdj7S58R3wLdv9r\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 0.0, \"Danceability\": 0.602, \"Energy\": 0.553, \"Loudness\": -9.336, \"Speechiness\": 0.0328, \"Acousticness\": 0.108, \"Liveness\": 0.0512, \"Tempo\": 130.594, \"Duration (ms)\": 118840.0, \"Valence\": 0.971, \"Chord\": \"B\"}, {\"Index\": 679, \"Highest Charting Position\": 150, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Naughty List (with Dixie)\", \"Streams\": 7299201, \"Artist\": \"Liam Payne\", \"Artist Followers\": 8037861.0, \"Song ID\": \"2Y0ktCGrGoGcQFXsGztvhi\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 51.0, \"Danceability\": 0.619, \"Energy\": 0.771, \"Loudness\": -2.204, \"Speechiness\": 0.0601, \"Acousticness\": 0.0318, \"Liveness\": 0.114, \"Tempo\": 81.966, \"Duration (ms)\": 154747.0, \"Valence\": 0.704, \"Chord\": \"A\"}, {\"Index\": 680, \"Highest Charting Position\": 152, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"I'll Be Home\", \"Streams\": 7281773, \"Artist\": \"Meghan Trainor\", \"Artist Followers\": 10606572.0, \"Song ID\": \"0lTurWECr2XL607eJAj1A3\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2015-01-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 45.0, \"Danceability\": 0.542, \"Energy\": 0.37, \"Loudness\": -7.779, \"Speechiness\": 0.0257, \"Acousticness\": 0.318, \"Liveness\": 0.108, \"Tempo\": 84.796, \"Duration (ms)\": 219653.0, \"Valence\": 0.289, \"Chord\": \"D\"}, {\"Index\": 681, \"Highest Charting Position\": 156, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Rudolph The Red-Nosed Reindeer\", \"Streams\": 7227612, \"Artist\": \"Dean Martin\", \"Artist Followers\": 1139096.0, \"Song ID\": \"2L9QLAhrvtP4EYg1lY0Tnw\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"1959-01-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.478, \"Energy\": 0.201, \"Loudness\": -16.768, \"Speechiness\": 0.0332, \"Acousticness\": 0.919, \"Liveness\": 0.0854, \"Tempo\": 136.471, \"Duration (ms)\": 135760.0, \"Valence\": 0.857, \"Chord\": \"G\"}, {\"Index\": 682, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Mistletoe And Holly - Remastered 1999\", \"Streams\": 7225080, \"Artist\": \"Frank Sinatra\", \"Artist Followers\": 4953667.0, \"Song ID\": \"7faDzZnZYqTyYThx2sbHVQ\", \"Genre\": \"['adult standards', 'easy listening', 'lounge']\", \"Release Date\": \"1957-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 38.0, \"Danceability\": 0.607, \"Energy\": 0.103, \"Loudness\": -14.405, \"Speechiness\": 0.0404, \"Acousticness\": 0.804, \"Liveness\": 0.076, \"Tempo\": 110.378, \"Duration (ms)\": 136427.0, \"Valence\": 0.341, \"Chord\": \"A\"}, {\"Index\": 683, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Jingle Bells - Remastered 1999\", \"Streams\": 7182262, \"Artist\": \"Frank Sinatra\", \"Artist Followers\": 4953667.0, \"Song ID\": \"4HEOgBHRCExyYVeTyrXsnL\", \"Genre\": \"['adult standards', 'easy listening', 'lounge']\", \"Release Date\": \"1957-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 36.0, \"Danceability\": 0.512, \"Energy\": 0.339, \"Loudness\": -13.119, \"Speechiness\": 0.0498, \"Acousticness\": 0.727, \"Liveness\": 0.0977, \"Tempo\": 174.609, \"Duration (ms)\": 120693.0, \"Valence\": 0.951, \"Chord\": \"G#/Ab\"}, {\"Index\": 684, \"Highest Charting Position\": 160, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Oh Santa! (feat. Ariana Grande & Jennifer Hudson)\", \"Streams\": 7170169, \"Artist\": \"Mariah Carey\", \"Artist Followers\": 6931357.0, \"Song ID\": \"1Ri9P0ZPrqr6h0REDRdJBd\", \"Genre\": \"['dance pop', 'pop', 'r&b', 'urban contemporary']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 47.0, \"Danceability\": 0.648, \"Energy\": 0.938, \"Loudness\": -3.298, \"Speechiness\": 0.115, \"Acousticness\": 0.0339, \"Liveness\": 0.0564, \"Tempo\": 78.496, \"Duration (ms)\": 200467.0, \"Valence\": 0.849, \"Chord\": \"C#/Db\"}, {\"Index\": 685, \"Highest Charting Position\": 161, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Do You Hear What I Hear? - Remastered 2006\", \"Streams\": 7149158, \"Artist\": \"Bing Crosby\", \"Artist Followers\": 359973.0, \"Song ID\": \"5aDoUmxBsbdpS16alksb5Z\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'swing', 'vocal jazz']\", \"Release Date\": \"2006-01-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.566, \"Energy\": 0.246, \"Loudness\": -15.499, \"Speechiness\": 0.0276, \"Acousticness\": 0.813, \"Liveness\": 0.195, \"Tempo\": 101.529, \"Duration (ms)\": 165667.0, \"Valence\": 0.412, \"Chord\": \"A#/Bb\"}, {\"Index\": 686, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Hallelujah\", \"Streams\": 6985392, \"Artist\": \"Pentatonix\", \"Artist Followers\": 3083825.0, \"Song ID\": \"0HZk0QsXPhMNAWNDR3rYE8\", \"Genre\": \"['a cappella']\", \"Release Date\": \"2017-12-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 60.0, \"Danceability\": 0.364, \"Energy\": 0.378, \"Loudness\": -7.381, \"Speechiness\": 0.0331, \"Acousticness\": 0.47, \"Liveness\": 0.339, \"Tempo\": 89.918, \"Duration (ms)\": 268960.0, \"Valence\": 0.366, \"Chord\": \"G\"}, {\"Index\": 687, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"This Christmas\", \"Streams\": 6809438, \"Artist\": \"Donny Hathaway\", \"Artist Followers\": 424935.0, \"Song ID\": \"38xhBO2AKrJnjdjVnhJES6\", \"Genre\": \"['chicago soul', 'classic soul', 'funk', 'motown', 'neo soul', 'quiet storm', 'soul', 'southern soul']\", \"Release Date\": \"1990-04-03\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 42.0, \"Danceability\": 0.634, \"Energy\": 0.645, \"Loudness\": -9.2, \"Speechiness\": 0.0376, \"Acousticness\": 0.292, \"Liveness\": 0.246, \"Tempo\": 93.047, \"Duration (ms)\": 231173.0, \"Valence\": 0.677, \"Chord\": \"F\"}, {\"Index\": 688, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Winter Wonderland\", \"Streams\": 6680928, \"Artist\": \"Tony Bennett\", \"Artist Followers\": 659472.0, \"Song ID\": \"6kkJlaBYdyFcwCg67hW40t\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"2014-12-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 29.0, \"Danceability\": 0.604, \"Energy\": 0.497, \"Loudness\": -6.676, \"Speechiness\": 0.0319, \"Acousticness\": 0.727, \"Liveness\": 0.102, \"Tempo\": 126.011, \"Duration (ms)\": 149307.0, \"Valence\": 0.72, \"Chord\": \"C#/Db\"}, {\"Index\": 689, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas Tree Farm\", \"Streams\": 6657404, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2mvabkN1i2gLnGAPUVdwek\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 52.0, \"Danceability\": 0.598, \"Energy\": 0.68, \"Loudness\": -4.505, \"Speechiness\": 0.0331, \"Acousticness\": 0.06, \"Liveness\": 0.324, \"Tempo\": 134.002, \"Duration (ms)\": 228027.0, \"Valence\": 0.437, \"Chord\": \"G\"}, {\"Index\": 690, \"Highest Charting Position\": 182, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Cozy Little Christmas\", \"Streams\": 6652130, \"Artist\": \"Katy Perry\", \"Artist Followers\": 18936929.0, \"Song ID\": \"02FaKXXL7KUtRc7K0k54tL\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-11-15\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.774, \"Energy\": 0.608, \"Loudness\": -6.264, \"Speechiness\": 0.128, \"Acousticness\": 0.128, \"Liveness\": 0.0895, \"Tempo\": 137.494, \"Duration (ms)\": 182521.0, \"Valence\": 0.56, \"Chord\": \"G\"}, {\"Index\": 691, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Merry Christmas, Happy Holidays\", \"Streams\": 6635128, \"Artist\": \"*NSYNC\", \"Artist Followers\": 1564750.0, \"Song ID\": \"4v9WbaxW8HdjqfUiWYWsII\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"1998-10-30\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.643, \"Energy\": 0.939, \"Loudness\": -3.967, \"Speechiness\": 0.0463, \"Acousticness\": 0.104, \"Liveness\": 0.881, \"Tempo\": 104.999, \"Duration (ms)\": 255307.0, \"Valence\": 0.756, \"Chord\": \"F\"}, {\"Index\": 692, \"Highest Charting Position\": 24, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"tolerate it\", \"Streams\": 6635109, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0PurA4JVJ8YQgSVopY8fn6\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 67.0, \"Danceability\": 0.316, \"Energy\": 0.361, \"Loudness\": -10.381, \"Speechiness\": 0.0488, \"Acousticness\": 0.878, \"Liveness\": 0.0797, \"Tempo\": 74.952, \"Duration (ms)\": 245440.0, \"Valence\": 0.221, \"Chord\": \"A\"}, {\"Index\": 693, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Please Come Home for Christmas - 2013 Remaster\", \"Streams\": 6400108, \"Artist\": \"Eagles\", \"Artist Followers\": 6896776.0, \"Song ID\": \"3QIoEi8Enr9uHffwInGIsC\", \"Genre\": \"['album rock', 'classic rock', 'country rock', 'folk rock', 'heartland rock', 'mellow gold', 'rock', 'soft rock', 'yacht rock']\", \"Release Date\": \"1994\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.612, \"Energy\": 0.289, \"Loudness\": -11.568, \"Speechiness\": 0.0421, \"Acousticness\": 0.599, \"Liveness\": 0.0561, \"Tempo\": 183.18, \"Duration (ms)\": 177440.0, \"Valence\": 0.466, \"Chord\": \"A\"}, {\"Index\": 694, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"My Kind Of Present\", \"Streams\": 6278993, \"Artist\": \"Meghan Trainor\", \"Artist Followers\": 10606572.0, \"Song ID\": \"2rkb8ijsPapKDMEh0cSe8I\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.485, \"Energy\": 0.444, \"Loudness\": -6.232, \"Speechiness\": 0.195, \"Acousticness\": 0.373, \"Liveness\": 0.0969, \"Tempo\": 179.967, \"Duration (ms)\": 161013.0, \"Valence\": 0.777, \"Chord\": \"C#/Db\"}, {\"Index\": 695, \"Highest Charting Position\": 28, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"happiness\", \"Streams\": 16213589, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"73YUReisjb3A9ActdLLjJQ\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 65.0, \"Danceability\": 0.559, \"Energy\": 0.334, \"Loudness\": -10.733, \"Speechiness\": 0.0376, \"Acousticness\": 0.87, \"Liveness\": 0.114, \"Tempo\": 122.079, \"Duration (ms)\": 315147.0, \"Valence\": 0.211, \"Chord\": \"B\"}, {\"Index\": 696, \"Highest Charting Position\": 34, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"ivy\", \"Streams\": 14519547, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"19CSr8rwW05VJL2F91KFNK\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.515, \"Energy\": 0.545, \"Loudness\": -9.277, \"Speechiness\": 0.0353, \"Acousticness\": 0.855, \"Liveness\": 0.0921, \"Tempo\": 88.856, \"Duration (ms)\": 260440.0, \"Valence\": 0.535, \"Chord\": \"D\"}, {\"Index\": 697, \"Highest Charting Position\": 38, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"dorothea\", \"Streams\": 14392788, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"670fUmXf4KQekzbEgaXyPA\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.605, \"Energy\": 0.488, \"Loudness\": -8.322, \"Speechiness\": 0.0264, \"Acousticness\": 0.696, \"Liveness\": 0.129, \"Tempo\": 119.966, \"Duration (ms)\": 225880.0, \"Valence\": 0.354, \"Chord\": \"E\"}, {\"Index\": 698, \"Highest Charting Position\": 39, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"coney island (feat. The National)\", \"Streams\": 14385703, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3k7ne7VmH43ZPWxPdvPUgR\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.537, \"Energy\": 0.537, \"Loudness\": -11.266, \"Speechiness\": 0.0617, \"Acousticness\": 0.819, \"Liveness\": 0.142, \"Tempo\": 107.895, \"Duration (ms)\": 275320.0, \"Valence\": 0.292, \"Chord\": \"G#/Ab\"}, {\"Index\": 699, \"Highest Charting Position\": 43, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"evermore (feat. Bon Iver)\", \"Streams\": 13810722, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3O5osWf1rSoKMwe6E9ZaXP\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.39, \"Energy\": 0.27, \"Loudness\": -10.673, \"Speechiness\": 0.0308, \"Acousticness\": 0.937, \"Liveness\": 0.111, \"Tempo\": 125.177, \"Duration (ms)\": 304107.0, \"Valence\": 0.32, \"Chord\": \"C#/Db\"}, {\"Index\": 700, \"Highest Charting Position\": 45, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"long story short\", \"Streams\": 13583538, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2o2sgVJIgFXk8GQjWTgI6U\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.546, \"Energy\": 0.73, \"Loudness\": -7.704, \"Speechiness\": 0.0417, \"Acousticness\": 0.66, \"Liveness\": 0.0972, \"Tempo\": 157.895, \"Duration (ms)\": 215920.0, \"Valence\": 0.573, \"Chord\": \"C\"}, {\"Index\": 701, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"cowboy like me\", \"Streams\": 12782098, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1XjHRolIXL2M1EEOUsGGR4\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.604, \"Energy\": 0.517, \"Loudness\": -9.014, \"Speechiness\": 0.0347, \"Acousticness\": 0.768, \"Liveness\": 0.123, \"Tempo\": 127.967, \"Duration (ms)\": 275040.0, \"Valence\": 0.511, \"Chord\": \"C\"}, {\"Index\": 702, \"Highest Charting Position\": 57, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"marjorie\", \"Streams\": 12234761, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"12ntTeqEeTg7GAVpe8Mhpl\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.535, \"Energy\": 0.561, \"Loudness\": -11.609, \"Speechiness\": 0.0484, \"Acousticness\": 0.876, \"Liveness\": 0.115, \"Tempo\": 96.103, \"Duration (ms)\": 257773.0, \"Valence\": 0.287, \"Chord\": \"F\"}, {\"Index\": 703, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"closure\", \"Streams\": 11245393, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"35rdVq36LMHQX0Suw9a6tK\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 62.0, \"Danceability\": 0.689, \"Energy\": 0.704, \"Loudness\": -10.813, \"Speechiness\": 0.245, \"Acousticness\": 0.835, \"Liveness\": 0.134, \"Tempo\": 151.884, \"Duration (ms)\": 180653.0, \"Valence\": 0.92, \"Chord\": \"A\"}, {\"Index\": 704, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"She Knows This\", \"Streams\": 10561183, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"1xzUQMiCoY5pdego0pHMeV\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.39, \"Energy\": 0.724, \"Loudness\": -7.607, \"Speechiness\": 0.0889, \"Acousticness\": 0.162, \"Liveness\": 0.393, \"Tempo\": 165.945, \"Duration (ms)\": 216560.0, \"Valence\": 0.312, \"Chord\": \"F#/Gb\"}, {\"Index\": 705, \"Highest Charting Position\": 97, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Another Day\", \"Streams\": 8901697, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"6myUpr3GDR80Dg3zqNTmmG\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 63.0, \"Danceability\": 0.646, \"Energy\": 0.758, \"Loudness\": -7.75, \"Speechiness\": 0.0708, \"Acousticness\": 0.556, \"Liveness\": 0.335, \"Tempo\": 172.995, \"Duration (ms)\": 199787.0, \"Valence\": 0.0642, \"Chord\": \"E\"}, {\"Index\": 706, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Solo Dolo, Pt. III\", \"Streams\": 7655623, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"27oVCAziETRbNuo5A8LNpg\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 61.0, \"Danceability\": 0.589, \"Energy\": 0.727, \"Loudness\": -6.907, \"Speechiness\": 0.0866, \"Acousticness\": 0.239, \"Liveness\": 0.164, \"Tempo\": 152.058, \"Duration (ms)\": 242267.0, \"Valence\": 0.52, \"Chord\": \"A#/Bb\"}, {\"Index\": 707, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Dive\", \"Streams\": 7524738, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"7Hc3YL8oDiAzbiAW32KXrw\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 60.0, \"Danceability\": 0.64, \"Energy\": 0.621, \"Loudness\": -8.269, \"Speechiness\": 0.0679, \"Acousticness\": 0.67, \"Liveness\": 0.36, \"Tempo\": 123.105, \"Duration (ms)\": 148707.0, \"Valence\": 0.332, \"Chord\": \"A\"}, {\"Index\": 708, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Heaven On Earth\", \"Streams\": 7117347, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"2koUj1Fn5TKFEkChSmBPIb\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 59.0, \"Danceability\": 0.786, \"Energy\": 0.61, \"Loudness\": -6.736, \"Speechiness\": 0.0558, \"Acousticness\": 0.379, \"Liveness\": 0.0765, \"Tempo\": 130.036, \"Duration (ms)\": 201093.0, \"Valence\": 0.228, \"Chord\": \"C\"}, {\"Index\": 709, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Sad People\", \"Streams\": 6865689, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"4nuAslShoN77tq12fzwjUq\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 62.0, \"Danceability\": 0.636, \"Energy\": 0.647, \"Loudness\": -6.971, \"Speechiness\": 0.0381, \"Acousticness\": 0.247, \"Liveness\": 0.113, \"Tempo\": 158.073, \"Duration (ms)\": 176027.0, \"Valence\": 0.416, \"Chord\": \"F\"}, {\"Index\": 710, \"Highest Charting Position\": 152, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Damaged\", \"Streams\": 6763705, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"2n7Ao4nyESBa5ti8gcAbBt\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 57.0, \"Danceability\": 0.625, \"Energy\": 0.581, \"Loudness\": -7.1, \"Speechiness\": 0.0316, \"Acousticness\": 0.553, \"Liveness\": 0.254, \"Tempo\": 142.04, \"Duration (ms)\": 150853.0, \"Valence\": 0.267, \"Chord\": \"G#/Ab\"}, {\"Index\": 711, \"Highest Charting Position\": 17, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"YO VISTO AS\\u00cd\", \"Streams\": 6388079, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5fROvzNghPid8mbKNDYvpJ\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 73.0, \"Danceability\": 0.688, \"Energy\": 0.881, \"Loudness\": -4.889, \"Speechiness\": 0.0474, \"Acousticness\": 0.0947, \"Liveness\": 0.0804, \"Tempo\": 123.013, \"Duration (ms)\": 191526.0, \"Valence\": 0.677, \"Chord\": \"G\"}, {\"Index\": 712, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Beautiful Trip\", \"Streams\": 6108393, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"4IIuCotvqijraSdnVLaFnM\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 54.0, \"Danceability\": 0.331, \"Energy\": 0.513, \"Loudness\": -15.392, \"Speechiness\": 0.632, \"Acousticness\": 0.972, \"Liveness\": 0.882, \"Tempo\": 133.971, \"Duration (ms)\": 37013.0, \"Valence\": 0.42, \"Chord\": \"B\"}, {\"Index\": 713, \"Highest Charting Position\": 185, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"The Void\", \"Streams\": 6068816, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"2yg7MXp8nSPaf61HVkhEr3\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 61.0, \"Danceability\": 0.464, \"Energy\": 0.459, \"Loudness\": -8.736, \"Speechiness\": 0.0314, \"Acousticness\": 0.365, \"Liveness\": 0.117, \"Tempo\": 142.017, \"Duration (ms)\": 325413.0, \"Valence\": 0.0786, \"Chord\": \"G\"}, {\"Index\": 714, \"Highest Charting Position\": 1, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"cardigan\", \"Streams\": 5845457, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"4R2kfaDFhslZEMJqAFNpdd\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-12-11--2020-12-18\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 79.0, \"Danceability\": 0.613, \"Energy\": 0.581, \"Loudness\": -8.588, \"Speechiness\": 0.0424, \"Acousticness\": 0.537, \"Liveness\": 0.25, \"Tempo\": 130.033, \"Duration (ms)\": 239560.0, \"Valence\": 0.551, \"Chord\": \"C\"}, {\"Index\": 715, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Real Shit (with benny blanco)\", \"Streams\": 9325928, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"3uVPLtkmDu8pDkYEAVqbgS\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-12-02\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 70.0, \"Danceability\": 0.703, \"Energy\": 0.703, \"Loudness\": -4.672, \"Speechiness\": 0.133, \"Acousticness\": 0.605, \"Liveness\": 0.12, \"Tempo\": 76.017, \"Duration (ms)\": 183783.0, \"Valence\": 0.697, \"Chord\": \"C#/Db\"}, {\"Index\": 716, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Teach Me How To Love\", \"Streams\": 7932101, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 33893352.0, \"Song ID\": \"5LZtB6nxvjIhUoElp3Zqk0\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 68.0, \"Danceability\": 0.592, \"Energy\": 0.885, \"Loudness\": -4.944, \"Speechiness\": 0.0807, \"Acousticness\": 0.0505, \"Liveness\": 0.0843, \"Tempo\": 98.991, \"Duration (ms)\": 202357.0, \"Valence\": 0.731, \"Chord\": \"A\"}, {\"Index\": 717, \"Highest Charting Position\": 138, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Blinding Lights (with ROSAL\\u00cdA) - Remix\", \"Streams\": 6653913, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"7MXgrcOQAJ5VwSNUL0lDd3\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 64.0, \"Danceability\": 0.49, \"Energy\": 0.694, \"Loudness\": -5.793, \"Speechiness\": 0.0618, \"Acousticness\": 0.0133, \"Liveness\": 0.0946, \"Tempo\": 170.903, \"Duration (ms)\": 216123.0, \"Valence\": 0.249, \"Chord\": \"F\"}, {\"Index\": 718, \"Highest Charting Position\": 15, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"WHATS POPPIN (feat. DaBaby, Tory Lanez & Lil Wayne) - Remix\", \"Streams\": 6567755, \"Artist\": \"Tory Lanez, Jack Harlow\", \"Artist Followers\": 3828418.0, \"Song ID\": \"2MbdDtCv5LUVjYy9RuGTgC\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-06-24\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 80.0, \"Danceability\": 0.904, \"Energy\": 0.723, \"Loudness\": -5.224, \"Speechiness\": 0.26, \"Acousticness\": 0.0631, \"Liveness\": 0.185, \"Tempo\": 145.013, \"Duration (ms)\": 227478.0, \"Valence\": 0.835, \"Chord\": \"B\"}, {\"Index\": 719, \"Highest Charting Position\": 29, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"TE DESEO LO MEJOR\", \"Streams\": 6204228, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"23XjN1s3DZC8Q9ZwuorYY4\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.763, \"Energy\": 0.597, \"Loudness\": -5.054, \"Speechiness\": 0.0416, \"Acousticness\": 0.158, \"Liveness\": 0.111, \"Tempo\": 126.054, \"Duration (ms)\": 139576.0, \"Valence\": 0.194, \"Chord\": \"C#/Db\"}, {\"Index\": 720, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Errbody\", \"Streams\": 5929516, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"6eVxH9Kyanzrw636zJRPcw\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-12-03\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 68.0, \"Danceability\": 0.887, \"Energy\": 0.606, \"Loudness\": -6.572, \"Speechiness\": 0.324, \"Acousticness\": 0.000407, \"Liveness\": 0.151, \"Tempo\": 139.995, \"Duration (ms)\": 210699.0, \"Valence\": 0.272, \"Chord\": \"D\"}, {\"Index\": 721, \"Highest Charting Position\": 86, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"Angels Like You\", \"Streams\": 5884221, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"1daDRI9ahBonbWD8YcxOIB\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 77.0, \"Danceability\": 0.672, \"Energy\": 0.642, \"Loudness\": -4.035, \"Speechiness\": 0.0313, \"Acousticness\": 0.0981, \"Liveness\": 0.1, \"Tempo\": 121.981, \"Duration (ms)\": 196453.0, \"Valence\": 0.494, \"Chord\": \"F\"}, {\"Index\": 722, \"Highest Charting Position\": 18, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Blue & Grey\", \"Streams\": 5698275, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"0n2moJpAEWHwaPYYjkzMDl\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 77.0, \"Danceability\": 0.547, \"Energy\": 0.605, \"Loudness\": -6.755, \"Speechiness\": 0.0415, \"Acousticness\": 0.42, \"Liveness\": 0.125, \"Tempo\": 121.953, \"Duration (ms)\": 254950.0, \"Valence\": 0.364, \"Chord\": \"G#/Ab\"}, {\"Index\": 723, \"Highest Charting Position\": 46, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Mad at Disney\", \"Streams\": 5436450, \"Artist\": \"salem ilese\", \"Artist Followers\": 133998.0, \"Song ID\": \"7aGyRfJWtLqgJaZoG9lJhE\", \"Genre\": \"['alt z', 'modern indie pop', 'social media pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 76.0, \"Danceability\": 0.738, \"Energy\": 0.621, \"Loudness\": -7.313, \"Speechiness\": 0.0486, \"Acousticness\": 0.424, \"Liveness\": 0.692, \"Tempo\": 113.968, \"Duration (ms)\": 136839.0, \"Valence\": 0.715, \"Chord\": \"C\"}, {\"Index\": 724, \"Highest Charting Position\": 9, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Safaera\", \"Streams\": 5390363, \"Artist\": \"Bad Bunny, Jowell & Randy, \\u00d1engo Flow\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2DEZmgHKAvm41k4J3R2E9Y\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 79.0, \"Danceability\": 0.607, \"Energy\": 0.829, \"Loudness\": -4.074, \"Speechiness\": 0.379, \"Acousticness\": 0.0103, \"Liveness\": 0.107, \"Tempo\": 96.172, \"Duration (ms)\": 295177.0, \"Valence\": 0.685, \"Chord\": \"D\"}, {\"Index\": 725, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"LA DROGA\", \"Streams\": 5375449, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"67ACYA3UI6QMNtHX6b34wX\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.643, \"Energy\": 0.727, \"Loudness\": -5.506, \"Speechiness\": 0.0389, \"Acousticness\": 0.0439, \"Liveness\": 0.123, \"Tempo\": 90.019, \"Duration (ms)\": 162299.0, \"Valence\": 0.295, \"Chord\": \"C#/Db\"}, {\"Index\": 726, \"Highest Charting Position\": 60, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"GO (feat. Juice WRLD)\", \"Streams\": 5370330, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"2rPHUAeUPbNgTmK18FPTiZ\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-06--2020-11-13\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 78.0, \"Danceability\": 0.487, \"Energy\": 0.74, \"Loudness\": -4.973, \"Speechiness\": 0.0944, \"Acousticness\": 0.157, \"Liveness\": 0.612, \"Tempo\": 73.779, \"Duration (ms)\": 181688.0, \"Valence\": 0.522, \"Chord\": \"F#/Gb\"}, {\"Index\": 727, \"Highest Charting Position\": 180, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"Jenny (I Wanna Ruin Our Friendship)\", \"Streams\": 5364223, \"Artist\": \"Studio Killers\", \"Artist Followers\": 181236.0, \"Song ID\": \"4JLBDUYSaOMPYND0iWeSWQ\", \"Genre\": \"[]\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 72.0, \"Danceability\": 0.668, \"Energy\": 0.798, \"Loudness\": -5.701, \"Speechiness\": 0.0334, \"Acousticness\": 0.00305, \"Liveness\": 0.277, \"Tempo\": 133.928, \"Duration (ms)\": 215280.0, \"Valence\": 0.575, \"Chord\": \"B\"}, {\"Index\": 728, \"Highest Charting Position\": 35, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Mood (Remix) feat. Justin Bieber, J Balvin & iann dior\", \"Streams\": 5314734, \"Artist\": \"24kGoldn\", \"Artist Followers\": 1276406.0, \"Song ID\": \"6FuGJB290AQMAHTfjOYVaK\", \"Genre\": \"['cali rap']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 77.0, \"Danceability\": 0.721, \"Energy\": 0.745, \"Loudness\": -3.508, \"Speechiness\": 0.0366, \"Acousticness\": 0.151, \"Liveness\": 0.372, \"Tempo\": 90.988, \"Duration (ms)\": 192745.0, \"Valence\": 0.699, \"Chord\": \"G\"}, {\"Index\": 729, \"Highest Charting Position\": 41, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"HOY COBR\\u00c9\", \"Streams\": 12914431, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0tjZv2hChdHZCW1zFXpy1J\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.86, \"Energy\": 0.725, \"Loudness\": -6.7, \"Speechiness\": 0.249, \"Acousticness\": 0.0464, \"Liveness\": 0.0994, \"Tempo\": 145.001, \"Duration (ms)\": 162151.0, \"Valence\": 0.375, \"Chord\": \"B\"}, {\"Index\": 730, \"Highest Charting Position\": 44, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"MALDITA POBREZA\", \"Streams\": 12660806, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0Lsis3LB0XAK6XlTHXaJk2\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 67.0, \"Danceability\": 0.762, \"Energy\": 0.861, \"Loudness\": -4.075, \"Speechiness\": 0.0652, \"Acousticness\": 0.139, \"Liveness\": 0.0956, \"Tempo\": 133.037, \"Duration (ms)\": 213609.0, \"Valence\": 0.588, \"Chord\": \"E\"}, {\"Index\": 731, \"Highest Charting Position\": 48, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"EL MUNDO ES M\\u00cdO\", \"Streams\": 12507010, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"36DHxTW2xdr9GG15T9oK9L\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 67.0, \"Danceability\": 0.716, \"Energy\": 0.522, \"Loudness\": -6.834, \"Speechiness\": 0.0582, \"Acousticness\": 0.166, \"Liveness\": 0.113, \"Tempo\": 76.993, \"Duration (ms)\": 165199.0, \"Valence\": 0.224, \"Chord\": \"F\"}, {\"Index\": 732, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"ANTES QUE SE ACABE\", \"Streams\": 11298839, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"7kjEqI6eZ7YlFrGhxixnlN\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 76.0, \"Danceability\": 0.693, \"Energy\": 0.549, \"Loudness\": -6.098, \"Speechiness\": 0.0577, \"Acousticness\": 0.505, \"Liveness\": 0.324, \"Tempo\": 139.988, \"Duration (ms)\": 221187.0, \"Valence\": 0.473, \"Chord\": \"D\"}, {\"Index\": 733, \"Highest Charting Position\": 59, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"SORRY PAPI\", \"Streams\": 11066606, \"Artist\": \"Bad Bunny, ABRA\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5jZ32WOU7sqzDYbzINwMUk\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.612, \"Energy\": 0.561, \"Loudness\": -6.054, \"Speechiness\": 0.0851, \"Acousticness\": 0.0601, \"Liveness\": 0.145, \"Tempo\": 191.911, \"Duration (ms)\": 163053.0, \"Valence\": 0.393, \"Chord\": \"C#/Db\"}, {\"Index\": 734, \"Highest Charting Position\": 63, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"120\", \"Streams\": 10957181, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3KJ3opyV29269SXkPrc19l\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 72.0, \"Danceability\": 0.636, \"Energy\": 0.656, \"Loudness\": -5.542, \"Speechiness\": 0.0676, \"Acousticness\": 0.451, \"Liveness\": 0.287, \"Tempo\": 171.918, \"Duration (ms)\": 151506.0, \"Valence\": 0.439, \"Chord\": \"D\"}, {\"Index\": 735, \"Highest Charting Position\": 66, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"TRELLAS\", \"Streams\": 10733416, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"09WAnxdBuebQopKhJT3oZS\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 66.0, \"Danceability\": 0.43, \"Energy\": 0.412, \"Loudness\": -5.372, \"Speechiness\": 0.0281, \"Acousticness\": 0.2, \"Liveness\": 0.324, \"Tempo\": 90.872, \"Duration (ms)\": 157673.0, \"Valence\": 0.0508, \"Chord\": \"D\"}, {\"Index\": 736, \"Highest Charting Position\": 83, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"Wonderful Christmastime [Edited Version] - Remastered 2011 / Edited Version\", \"Streams\": 9624871, \"Artist\": \"Paul McCartney\", \"Artist Followers\": 3609658.0, \"Song ID\": \"1SV1fxF65n9NhRHp3KlBuu\", \"Genre\": \"['album rock', 'art rock', 'beatlesque', 'classic rock', 'mellow gold', 'rock', 'soft rock']\", \"Release Date\": \"1980-05-16\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 51.0, \"Danceability\": 0.774, \"Energy\": 0.511, \"Loudness\": -8.914, \"Speechiness\": 0.0319, \"Acousticness\": 0.322, \"Liveness\": 0.0672, \"Tempo\": 94.736, \"Duration (ms)\": 227653.0, \"Valence\": 0.771, \"Chord\": \"B\"}, {\"Index\": 737, \"Highest Charting Position\": 16, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Fly To My Room\", \"Streams\": 8413330, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3QH8rQGNFX8VLbCgZ7uPTS\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 76.0, \"Danceability\": 0.764, \"Energy\": 0.526, \"Loudness\": -7.355, \"Speechiness\": 0.212, \"Acousticness\": 0.0484, \"Liveness\": 0.0718, \"Tempo\": 114.91, \"Duration (ms)\": 222243.0, \"Valence\": 0.588, \"Chord\": \"B\"}, {\"Index\": 738, \"Highest Charting Position\": 24, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Telepathy\", \"Streams\": 7703744, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"2FVpOsjT1iquZ3SpCjZ9Ne\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 77.0, \"Danceability\": 0.787, \"Energy\": 0.669, \"Loudness\": -4.333, \"Speechiness\": 0.0428, \"Acousticness\": 0.00782, \"Liveness\": 0.123, \"Tempo\": 104.994, \"Duration (ms)\": 202313.0, \"Valence\": 0.57, \"Chord\": \"F\"}, {\"Index\": 739, \"Highest Charting Position\": 26, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Dis-ease\", \"Streams\": 7165808, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"54DmTIv86D3sYdiawjULQ0\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 75.0, \"Danceability\": 0.731, \"Energy\": 0.845, \"Loudness\": -5.352, \"Speechiness\": 0.132, \"Acousticness\": 0.0132, \"Liveness\": 0.0782, \"Tempo\": 101.085, \"Duration (ms)\": 239722.0, \"Valence\": 0.484, \"Chord\": \"G#/Ab\"}, {\"Index\": 740, \"Highest Charting Position\": 27, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Stay\", \"Streams\": 7010227, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3ndCsZfq8OVwwkz9mmZvUz\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 76.0, \"Danceability\": 0.582, \"Energy\": 0.693, \"Loudness\": -5.048, \"Speechiness\": 0.0465, \"Acousticness\": 0.114, \"Liveness\": 0.13, \"Tempo\": 125.904, \"Duration (ms)\": 204800.0, \"Valence\": 0.341, \"Chord\": \"F#/Gb\"}, {\"Index\": 741, \"Highest Charting Position\": 151, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Heart Of Glass (Live from the iHeart Festival)\", \"Streams\": 6006877, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"5i7ThJfYLAzp2DyZuFpF6j\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-09-29\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 71.0, \"Danceability\": 0.58, \"Energy\": 0.908, \"Loudness\": -5.303, \"Speechiness\": 0.0341, \"Acousticness\": 0.000335, \"Liveness\": 0.087, \"Tempo\": 115.016, \"Duration (ms)\": 213672.0, \"Valence\": 0.427, \"Chord\": \"E\"}, {\"Index\": 742, \"Highest Charting Position\": 171, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"CANTARES DE NAVIDAD\", \"Streams\": 5842320, \"Artist\": \"Trio Vegabaje\\u00f1o\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2Iv6YBslkxslMJQsxshZh5\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 56.0, \"Danceability\": 0.764, \"Energy\": 0.523, \"Loudness\": -7.371, \"Speechiness\": 0.0406, \"Acousticness\": 0.777, \"Liveness\": 0.352, \"Tempo\": 118.671, \"Duration (ms)\": 199720.0, \"Valence\": 0.962, \"Chord\": \"D\"}, {\"Index\": 743, \"Highest Charting Position\": 172, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"Plastic Hearts\", \"Streams\": 5816739, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"6qCsKKS7Ol63SJW3LOIX5R\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 74.0, \"Danceability\": 0.551, \"Energy\": 0.756, \"Loudness\": -4.948, \"Speechiness\": 0.0652, \"Acousticness\": 0.0511, \"Liveness\": 0.0765, \"Tempo\": 175.984, \"Duration (ms)\": 205733.0, \"Valence\": 0.618, \"Chord\": \"D\"}, {\"Index\": 744, \"Highest Charting Position\": 63, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"C\\u00d3MO SE SIENTE - Remix\", \"Streams\": 5463964, \"Artist\": \"Jhay Cortez, Bad Bunny\", \"Artist Followers\": 2435159.0, \"Song ID\": \"2tFwfmceQa1Y6nRPhYbEtC\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-09\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 81.0, \"Danceability\": 0.807, \"Energy\": 0.606, \"Loudness\": -8.871, \"Speechiness\": 0.088, \"Acousticness\": 0.0946, \"Liveness\": 0.119, \"Tempo\": 92.988, \"Duration (ms)\": 227520.0, \"Valence\": 0.304, \"Chord\": \"D#/Eb\"}, {\"Index\": 745, \"Highest Charting Position\": 78, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Skit\", \"Streams\": 8392247, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4GVwjLRT7oSsKby7Vy8EHr\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 60.0, \"Danceability\": 0.703, \"Energy\": 0.321, \"Loudness\": -13.135, \"Speechiness\": 0.884, \"Acousticness\": 0.864, \"Liveness\": 0.908, \"Tempo\": 114.822, \"Duration (ms)\": 179548.0, \"Valence\": 0.544, \"Chord\": \"E\"}, {\"Index\": 746, \"Highest Charting Position\": 105, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Baby (with J Balvin)\", \"Streams\": 7276896, \"Artist\": \"Sfera Ebbasta\", \"Artist Followers\": 4430628.0, \"Song ID\": \"3eblNP3Zd5b5J3JaOckl8Y\", \"Genre\": \"['italian hip hop', 'italian pop', 'trap italiana']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 69.0, \"Danceability\": 0.755, \"Energy\": 0.882, \"Loudness\": -1.957, \"Speechiness\": 0.0532, \"Acousticness\": 0.125, \"Liveness\": 0.103, \"Tempo\": 99.984, \"Duration (ms)\": 193555.0, \"Valence\": 0.606, \"Chord\": \"A#/Bb\"}, {\"Index\": 747, \"Highest Charting Position\": 82, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Tick Tock (feat. 24kGoldn)\", \"Streams\": 6241923, \"Artist\": \"Clean Bandit, Mabel\", \"Artist Followers\": 4431309.0, \"Song ID\": \"27u7t9d7ZQoyjsCROHuZJ3\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk dance', 'uk funky']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 78.0, \"Danceability\": 0.779, \"Energy\": 0.705, \"Loudness\": -3.895, \"Speechiness\": 0.0344, \"Acousticness\": 0.369, \"Liveness\": 0.124, \"Tempo\": 101.022, \"Duration (ms)\": 178374.0, \"Valence\": 0.946, \"Chord\": \"C\"}, {\"Index\": 748, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Dime C\\u00f3mo Quieres\", \"Streams\": 6152821, \"Artist\": \"Christian Nodal, \\u00c1ngela Aguilar\", \"Artist Followers\": 8123757.0, \"Song ID\": \"4jcxBTrNvyqMJdMDyyjdYV\", \"Genre\": \"['mariachi', 'nuevo regional mexicano', 'ranchera', 'regional mexican']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 75.0, \"Danceability\": 0.839, \"Energy\": 0.667, \"Loudness\": -3.961, \"Speechiness\": 0.031, \"Acousticness\": 0.322, \"Liveness\": 0.244, \"Tempo\": 124.889, \"Duration (ms)\": 171360.0, \"Valence\": 0.878, \"Chord\": \"B\"}, {\"Index\": 749, \"Highest Charting Position\": 162, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Tik Tok (feat. Marracash & Gu\\u00e8 Pequeno)\", \"Streams\": 5504912, \"Artist\": \"Sfera Ebbasta\", \"Artist Followers\": 4430628.0, \"Song ID\": \"3tkYK45AZC0PqJ7MSe6IyJ\", \"Genre\": \"['italian hip hop', 'italian pop', 'trap italiana']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 59.0, \"Danceability\": 0.723, \"Energy\": 0.673, \"Loudness\": -7.636, \"Speechiness\": 0.137, \"Acousticness\": 0.0985, \"Liveness\": 0.323, \"Tempo\": 120.046, \"Duration (ms)\": 230389.0, \"Valence\": 0.302, \"Chord\": \"A\"}, {\"Index\": 750, \"Highest Charting Position\": 88, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Jerusalema (feat. Nomcebo Zikode)\", \"Streams\": 5362508, \"Artist\": \"Master KG\", \"Artist Followers\": 247480.0, \"Song ID\": \"2MlOUXmcofMackX3bxfSwi\", \"Genre\": \"['south african house']\", \"Release Date\": \"2020-01-24\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 78.0, \"Danceability\": 0.88, \"Energy\": 0.483, \"Loudness\": -7.012, \"Speechiness\": 0.0505, \"Acousticness\": 0.0185, \"Liveness\": 0.0607, \"Tempo\": 124.009, \"Duration (ms)\": 342613.0, \"Valence\": 0.827, \"Chord\": \"C#/Db\"}, {\"Index\": 751, \"Highest Charting Position\": 19, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Agua (with J Balvin) - Music From \\\"Sponge On The Run\\\" Movie\", \"Streams\": 5358940, \"Artist\": \"Tainy\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 752, \"Highest Charting Position\": 174, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Abracadabra (feat. Future)\", \"Streams\": 5263469, \"Artist\": \"Sfera Ebbasta\", \"Artist Followers\": 4430628.0, \"Song ID\": \"2GuLouaDNgLGxdJoe0vYf6\", \"Genre\": \"['italian hip hop', 'italian pop', 'trap italiana']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 55.0, \"Danceability\": 0.846, \"Energy\": 0.681, \"Loudness\": -7.091, \"Speechiness\": 0.174, \"Acousticness\": 0.0461, \"Liveness\": 0.112, \"Tempo\": 131.988, \"Duration (ms)\": 192965.0, \"Valence\": 0.809, \"Chord\": \"F\"}, {\"Index\": 753, \"Highest Charting Position\": 36, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Djadja (feat. Maluma) - Remix\", \"Streams\": 5203423, \"Artist\": \"Aya Nakamura\", \"Artist Followers\": 2953525.0, \"Song ID\": \"6AzKhCHOms83jvNVLsz0Bt\", \"Genre\": \"['basshall', 'francoton']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 72.0, \"Danceability\": 0.791, \"Energy\": 0.682, \"Loudness\": -7.328, \"Speechiness\": 0.158, \"Acousticness\": 0.175, \"Liveness\": 0.0926, \"Tempo\": 98.031, \"Duration (ms)\": 166851.0, \"Valence\": 0.672, \"Chord\": \"F\"}, {\"Index\": 754, \"Highest Charting Position\": 140, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"ALWAYS DO\", \"Streams\": 5196635, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"3QCU8BT0zDS9LPVfEhRFEE\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 76.0, \"Danceability\": 0.762, \"Energy\": 0.426, \"Loudness\": -6.865, \"Speechiness\": 0.113, \"Acousticness\": 0.0442, \"Liveness\": 0.0858, \"Tempo\": 167.827, \"Duration (ms)\": 151705.0, \"Valence\": 0.582, \"Chord\": \"G#/Ab\"}, {\"Index\": 755, \"Highest Charting Position\": 7, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Smile (with The Weeknd)\", \"Streams\": 5164187, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"6wQlQrTY5mVS8EGaFZVwVF\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 75.0, \"Danceability\": 0.694, \"Energy\": 0.685, \"Loudness\": -6.535, \"Speechiness\": 0.133, \"Acousticness\": 0.224, \"Liveness\": 0.124, \"Tempo\": 158.831, \"Duration (ms)\": 196180.0, \"Valence\": 0.306, \"Chord\": \"F#/Gb\"}, {\"Index\": 756, \"Highest Charting Position\": 22, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Pretty Savage\", \"Streams\": 5039047, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"1XnpzbOGptRwfJhZgLbmSr\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 75.0, \"Danceability\": 0.701, \"Energy\": 0.556, \"Loudness\": -7.42, \"Speechiness\": 0.0414, \"Acousticness\": 0.00886, \"Liveness\": 0.106, \"Tempo\": 152.045, \"Duration (ms)\": 201122.0, \"Valence\": 0.333, \"Chord\": \"A\"}, {\"Index\": 757, \"Highest Charting Position\": 41, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Savage Love (Laxed \\u2013 Siren Beat) [BTS Remix]\", \"Streams\": 4995203, \"Artist\": \"Jawsh 685, Jason Derulo\", \"Artist Followers\": 100635.0, \"Song ID\": \"4TgxFMOn5yoESW6zCidCXL\", \"Genre\": \"['nz pop']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 76.0, \"Danceability\": 0.758, \"Energy\": 0.598, \"Loudness\": -5.695, \"Speechiness\": 0.0868, \"Acousticness\": 0.16, \"Liveness\": 0.295, \"Tempo\": 149.836, \"Duration (ms)\": 184905.0, \"Valence\": 0.658, \"Chord\": \"C\"}, {\"Index\": 758, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Mirrors\", \"Streams\": 4988571, \"Artist\": \"Justin Timberlake\", \"Artist Followers\": 11034144.0, \"Song ID\": \"4rHZZAmHpZrA3iH5zx8frV\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2013-03-15\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 78.0, \"Danceability\": 0.574, \"Energy\": 0.512, \"Loudness\": -6.664, \"Speechiness\": 0.0503, \"Acousticness\": 0.234, \"Liveness\": 0.0946, \"Tempo\": 76.899, \"Duration (ms)\": 484147.0, \"Valence\": 0.512, \"Chord\": \"F\"}, {\"Index\": 759, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Hollywood (feat. Diplo)\", \"Streams\": 4920218, \"Artist\": \"Sfera Ebbasta\", \"Artist Followers\": 4430628.0, \"Song ID\": \"0WXU7I74NEN1DMLIT406Wx\", \"Genre\": \"['italian hip hop', 'italian pop', 'trap italiana']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 63.0, \"Danceability\": 0.848, \"Energy\": 0.708, \"Loudness\": -6.336, \"Speechiness\": 0.0366, \"Acousticness\": 0.153, \"Liveness\": 0.0948, \"Tempo\": 137.973, \"Duration (ms)\": 191869.0, \"Valence\": 0.926, \"Chord\": \"D\"}, {\"Index\": 760, \"Highest Charting Position\": 24, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Runnin\", \"Streams\": 4914682, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"5SWnsxjhdcEDc7LJjq9UHk\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 78.0, \"Danceability\": 0.819, \"Energy\": 0.626, \"Loudness\": -4.574, \"Speechiness\": 0.202, \"Acousticness\": 0.00748, \"Liveness\": 0.167, \"Tempo\": 143.01, \"Duration (ms)\": 195906.0, \"Valence\": 0.415, \"Chord\": \"A#/Bb\"}, {\"Index\": 761, \"Highest Charting Position\": 105, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Are You Bored Yet? (feat. Clairo)\", \"Streams\": 4911995, \"Artist\": \"Wallows\", \"Artist Followers\": 1963296.0, \"Song ID\": \"57RA3JGafJm5zRtKJiKPIm\", \"Genre\": \"['indie pop', 'modern rock', 'pop', 'rock']\", \"Release Date\": \"2019-03-22\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 81.0, \"Danceability\": 0.682, \"Energy\": 0.683, \"Loudness\": -6.444, \"Speechiness\": 0.0287, \"Acousticness\": 0.156, \"Liveness\": 0.273, \"Tempo\": 120.023, \"Duration (ms)\": 178000.0, \"Valence\": 0.64, \"Chord\": \"G#/Ab\"}, {\"Index\": 762, \"Highest Charting Position\": 44, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"10,000 Hours (with Justin Bieber)\", \"Streams\": 4911749, \"Artist\": \"Dan + Shay\", \"Artist Followers\": 2334615.0, \"Song ID\": \"2wrJq5XKLnmhRXHIAf9xBa\", \"Genre\": \"['contemporary country', 'country', 'pop']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.654, \"Energy\": 0.63, \"Loudness\": -4.644, \"Speechiness\": 0.0259, \"Acousticness\": 0.153, \"Liveness\": 0.111, \"Tempo\": 89.991, \"Duration (ms)\": 167693.0, \"Valence\": 0.43, \"Chord\": \"A#/Bb\"}, {\"Index\": 763, \"Highest Charting Position\": 87, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"You Got It\", \"Streams\": 4907925, \"Artist\": \"Vedo\", \"Artist Followers\": 260236.0, \"Song ID\": \"4lsHZ92XCFOQfzJFBTluk8\", \"Genre\": \"['pop r&b', 'r&b']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 79.0, \"Danceability\": 0.762, \"Energy\": 0.433, \"Loudness\": -8.937, \"Speechiness\": 0.187, \"Acousticness\": 0.143, \"Liveness\": 0.118, \"Tempo\": 122.074, \"Duration (ms)\": 203145.0, \"Valence\": 0.394, \"Chord\": \"F\"}, {\"Index\": 764, \"Highest Charting Position\": 129, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Qui\\u00e9reme Mientras Se Pueda\", \"Streams\": 4899440, \"Artist\": \"Manuel Turizo\", \"Artist Followers\": 7909963.0, \"Song ID\": \"34LI7rwi9H8w2S5KTHnv1M\", \"Genre\": \"['colombian pop', 'latin', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 74.0, \"Danceability\": 0.793, \"Energy\": 0.782, \"Loudness\": -3.945, \"Speechiness\": 0.0582, \"Acousticness\": 0.447, \"Liveness\": 0.124, \"Tempo\": 143.86, \"Duration (ms)\": 191945.0, \"Valence\": 0.81, \"Chord\": \"E\"}, {\"Index\": 765, \"Highest Charting Position\": 9, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Party Girl\", \"Streams\": 4878286, \"Artist\": \"StaySolidRocky\", \"Artist Followers\": 150587.0, \"Song ID\": \"5RqR4ZCCKJDcBLIn4sih9l\", \"Genre\": \"['melodic rap']\", \"Release Date\": \"2020-04-21\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 77.0, \"Danceability\": 0.728, \"Energy\": 0.431, \"Loudness\": -9.966, \"Speechiness\": 0.0622, \"Acousticness\": 0.749, \"Liveness\": 0.0996, \"Tempo\": 130.022, \"Duration (ms)\": 147800.0, \"Valence\": 0.629, \"Chord\": \"F#/Gb\"}, {\"Index\": 766, \"Highest Charting Position\": 95, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Drankin N Smokin\", \"Streams\": 7292247, \"Artist\": \"Future, Lil Uzi Vert\", \"Artist Followers\": 10491105.0, \"Song ID\": \"0k7wmahjkn389wAZdz19Cv\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-11-13--2020-11-20\", \"Popularity\": 78.0, \"Danceability\": 0.752, \"Energy\": 0.658, \"Loudness\": -6.297, \"Speechiness\": 0.342, \"Acousticness\": 0.0421, \"Liveness\": 0.0927, \"Tempo\": 151.951, \"Duration (ms)\": 213520.0, \"Valence\": 0.387, \"Chord\": \"C\"}, {\"Index\": 767, \"Highest Charting Position\": 86, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Be Like That - feat. Swae Lee & Khalid\", \"Streams\": 5929062, \"Artist\": \"Kane Brown\", \"Artist Followers\": 3509653.0, \"Song ID\": \"5f1joOtoMeyppIcJGZQvqJ\", \"Genre\": \"['contemporary country', 'country road']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 79.0, \"Danceability\": 0.727, \"Energy\": 0.626, \"Loudness\": -8.415, \"Speechiness\": 0.0726, \"Acousticness\": 0.0469, \"Liveness\": 0.126, \"Tempo\": 86.97, \"Duration (ms)\": 191406.0, \"Valence\": 0.322, \"Chord\": \"G\"}, {\"Index\": 768, \"Highest Charting Position\": 74, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"MORE\", \"Streams\": 5602168, \"Artist\": \"K/DA, Madison Beer, (G)I-DLE, Lexie Liu, Jaira Burns, Seraphine, League of Legends\", \"Artist Followers\": 1245965.0, \"Song ID\": \"6juLaduD4STCUDWT0AYun4\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2020-10-28\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 73.0, \"Danceability\": 0.66, \"Energy\": 0.787, \"Loudness\": -4.592, \"Speechiness\": 0.032, \"Acousticness\": 0.00257, \"Liveness\": 0.323, \"Tempo\": 142.018, \"Duration (ms)\": 217088.0, \"Valence\": 0.199, \"Chord\": \"C#/Db\"}, {\"Index\": 769, \"Highest Charting Position\": 140, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Enchule\", \"Streams\": 5561227, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6096559.0, \"Song ID\": \"3ThrfRAmijYU098H9q9tAs\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 70.0, \"Danceability\": 0.763, \"Energy\": 0.666, \"Loudness\": -3.316, \"Speechiness\": 0.194, \"Acousticness\": 0.153, \"Liveness\": 0.301, \"Tempo\": 90.086, \"Duration (ms)\": 185719.0, \"Valence\": 0.587, \"Chord\": \"G\"}, {\"Index\": 770, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Stripes Like Burberry\", \"Streams\": 5445204, \"Artist\": \"Future, Lil Uzi Vert\", \"Artist Followers\": 10491105.0, \"Song ID\": \"6lt8iodSkYWEV0ifKCSlfg\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-11-13--2020-11-20\", \"Popularity\": 56.0, \"Danceability\": 0.758, \"Energy\": 0.574, \"Loudness\": -7.833, \"Speechiness\": 0.217, \"Acousticness\": 0.216, \"Liveness\": 0.144, \"Tempo\": 144.081, \"Duration (ms)\": 274313.0, \"Valence\": 0.706, \"Chord\": \"A\"}, {\"Index\": 771, \"Highest Charting Position\": 117, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Papi Chulo\", \"Streams\": 5361669, \"Artist\": \"Octavian, Skepta\", \"Artist Followers\": 213344.0, \"Song ID\": \"6Juv5N0dNU1imms9c9u1dA\", \"Genre\": \"['afroswing', 'london rap', 'uk alternative hip hop', 'uk hip hop']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 73.0, \"Danceability\": 0.866, \"Energy\": 0.563, \"Loudness\": -6.964, \"Speechiness\": 0.108, \"Acousticness\": 0.185, \"Liveness\": 0.0889, \"Tempo\": 127.954, \"Duration (ms)\": 161668.0, \"Valence\": 0.307, \"Chord\": \"B\"}, {\"Index\": 772, \"Highest Charting Position\": 20, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"off the table (with The Weeknd)\", \"Streams\": 5308945, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"7E1jVNoWuemqUryI4FxsVD\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 67.0, \"Danceability\": 0.411, \"Energy\": 0.522, \"Loudness\": -7.295, \"Speechiness\": 0.0981, \"Acousticness\": 0.519, \"Liveness\": 0.398, \"Tempo\": 88.332, \"Duration (ms)\": 239949.0, \"Valence\": 0.382, \"Chord\": \"C\"}, {\"Index\": 773, \"Highest Charting Position\": 52, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Spicy (feat. Post Malone)\", \"Streams\": 5303146, \"Artist\": \"Ty Dolla $ign\", \"Artist Followers\": 3866304.0, \"Song ID\": \"5IUtvfNvOyVYZUa6AJFrnP\", \"Genre\": \"['hip hop', 'pop', 'pop rap', 'r&b', 'southern hip hop', 'trap', 'trap soul']\", \"Release Date\": \"2020-10-23\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 80.0, \"Danceability\": 0.782, \"Energy\": 0.51, \"Loudness\": -5.724, \"Speechiness\": 0.0419, \"Acousticness\": 0.143, \"Liveness\": 0.115, \"Tempo\": 99.993, \"Duration (ms)\": 143375.0, \"Valence\": 0.118, \"Chord\": \"E\"}, {\"Index\": 774, \"Highest Charting Position\": 124, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Sweet Melody\", \"Streams\": 5201322, \"Artist\": \"Little Mix\", \"Artist Followers\": 9398941.0, \"Song ID\": \"76Tuo484SLohJakHLnGI3B\", \"Genre\": \"['dance pop', 'girl group', 'pop', 'post-teen pop', 'talent show', 'uk pop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\", \"Popularity\": 73.0, \"Danceability\": 0.448, \"Energy\": 0.824, \"Loudness\": -4.249, \"Speechiness\": 0.057, \"Acousticness\": 0.0739, \"Liveness\": 0.113, \"Tempo\": 119.965, \"Duration (ms)\": 213693.0, \"Valence\": 0.419, \"Chord\": \"F\"}, {\"Index\": 775, \"Highest Charting Position\": 144, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Blueberry Eyes (feat. SUGA of BTS)\", \"Streams\": 5158896, \"Artist\": \"MAX\", \"Artist Followers\": 689627.0, \"Song ID\": \"5dn6QANKbf76pANGjMBida\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'pop rap', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2020-09-15\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 72.0, \"Danceability\": 0.746, \"Energy\": 0.611, \"Loudness\": -7.034, \"Speechiness\": 0.101, \"Acousticness\": 0.454, \"Liveness\": 0.133, \"Tempo\": 149.967, \"Duration (ms)\": 172245.0, \"Valence\": 0.411, \"Chord\": \"C\"}, {\"Index\": 776, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"That\\u2019s It\", \"Streams\": 5151014, \"Artist\": \"Future, Lil Uzi Vert\", \"Artist Followers\": 10491105.0, \"Song ID\": \"5n6gBhdEjCuj3obgCoTEFD\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-11-13--2020-11-20\", \"Popularity\": 64.0, \"Danceability\": 0.94, \"Energy\": 0.532, \"Loudness\": -5.998, \"Speechiness\": 0.358, \"Acousticness\": 0.12, \"Liveness\": 0.0925, \"Tempo\": 123.043, \"Duration (ms)\": 228796.0, \"Valence\": 0.599, \"Chord\": \"B\"}, {\"Index\": 777, \"Highest Charting Position\": 157, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Promiscuous\", \"Streams\": 5083648, \"Artist\": \"Nelly Furtado, Timbaland\", \"Artist Followers\": 2688557.0, \"Song ID\": \"2gam98EZKrF9XuOkU13ApN\", \"Genre\": \"['canadian latin', 'canadian pop', 'dance pop', 'pop', 'pop rap']\", \"Release Date\": \"2006-01-01\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 82.0, \"Danceability\": 0.808, \"Energy\": 0.97, \"Loudness\": -6.098, \"Speechiness\": 0.0506, \"Acousticness\": 0.0569, \"Liveness\": 0.154, \"Tempo\": 114.328, \"Duration (ms)\": 242293.0, \"Valence\": 0.868, \"Chord\": \"A#/Bb\"}, {\"Index\": 778, \"Highest Charting Position\": 22, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"GREECE (feat. Drake)\", \"Streams\": 5043665, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6281829.0, \"Song ID\": \"35RJhm1pEovTBwnNR0zWad\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-07-16\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 77.0, \"Danceability\": 0.695, \"Energy\": 0.343, \"Loudness\": -10.798, \"Speechiness\": 0.0432, \"Acousticness\": 0.0743, \"Liveness\": 0.107, \"Tempo\": 85.84, \"Duration (ms)\": 218902.0, \"Valence\": 0.229, \"Chord\": \"F\"}, {\"Index\": 779, \"Highest Charting Position\": 25, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"just like magic\", \"Streams\": 4980571, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"7Dx9Z6Aon1qPS2N0rHSWTe\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 69.0, \"Danceability\": 0.719, \"Energy\": 0.607, \"Loudness\": -5.156, \"Speechiness\": 0.165, \"Acousticness\": 0.08, \"Liveness\": 0.125, \"Tempo\": 128.006, \"Duration (ms)\": 149900.0, \"Valence\": 0.464, \"Chord\": \"G#/Ab\"}, {\"Index\": 780, \"Highest Charting Position\": 53, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Still Don't Know My Name\", \"Streams\": 4926802, \"Artist\": \"Labrinth\", \"Artist Followers\": 1685215.0, \"Song ID\": \"6N22FZs2ZhPBYi3b9XPajV\", \"Genre\": \"['indie poptimism', 'pop']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 80.0, \"Danceability\": 0.316, \"Energy\": 0.63, \"Loudness\": -5.963, \"Speechiness\": 0.117, \"Acousticness\": 0.471, \"Liveness\": 0.205, \"Tempo\": 89.643, \"Duration (ms)\": 153294.0, \"Valence\": 0.313, \"Chord\": \"F\"}, {\"Index\": 781, \"Highest Charting Position\": 32, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Hasta Que Dios Diga\", \"Streams\": 4899099, \"Artist\": \"Anuel AA, Bad Bunny\", \"Artist Followers\": 18306226.0, \"Song ID\": \"06s3QtMJVXw1AJX3UfvZG1\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 76.0, \"Danceability\": 0.691, \"Energy\": 0.765, \"Loudness\": -4.727, \"Speechiness\": 0.111, \"Acousticness\": 0.464, \"Liveness\": 0.203, \"Tempo\": 174.021, \"Duration (ms)\": 246000.0, \"Valence\": 0.855, \"Chord\": \"G#/Ab\"}, {\"Index\": 782, \"Highest Charting Position\": 102, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Get You The Moon (feat. Sn\\u00f8w)\", \"Streams\": 4872409, \"Artist\": \"Kina\", \"Artist Followers\": 661863.0, \"Song ID\": \"4ZLzoOkj0MPWrTLvooIuaa\", \"Genre\": \"['sad rap']\", \"Release Date\": \"2018-10-08\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.498, \"Energy\": 0.235, \"Loudness\": -16.541, \"Speechiness\": 0.188, \"Acousticness\": 0.72, \"Liveness\": 0.144, \"Tempo\": 118.917, \"Duration (ms)\": 179080.0, \"Valence\": 0.0895, \"Chord\": \"C#/Db\"}, {\"Index\": 783, \"Highest Charting Position\": 162, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Moonwalking in Calabasas (feat. Blueface) - Remix\", \"Streams\": 4863053, \"Artist\": \"DDG\", \"Artist Followers\": 486194.0, \"Song ID\": \"7o4gBbTM6UBLkOYPw9xMCz\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2020-12-02\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 74.0, \"Danceability\": 0.928, \"Energy\": 0.341, \"Loudness\": -10.196, \"Speechiness\": 0.103, \"Acousticness\": 0.0614, \"Liveness\": 0.162, \"Tempo\": 129.966, \"Duration (ms)\": 170233.0, \"Valence\": 0.745, \"Chord\": \"B\"}, {\"Index\": 784, \"Highest Charting Position\": 29, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Forever After All\", \"Streams\": 4746415, \"Artist\": \"Luke Combs\", \"Artist Followers\": 5371000.0, \"Song ID\": \"6IBcOGPsniK3Pso1wHIhew\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2020-10-23\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 80.0, \"Danceability\": 0.487, \"Energy\": 0.65, \"Loudness\": -5.195, \"Speechiness\": 0.0253, \"Acousticness\": 0.191, \"Liveness\": 0.0933, \"Tempo\": 151.964, \"Duration (ms)\": 232533.0, \"Valence\": 0.456, \"Chord\": \"C\"}, {\"Index\": 785, \"Highest Charting Position\": 76, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Lean (feat. Towy, Osquel, Beltito & Sammy & Falsetto)\", \"Streams\": 4739241, \"Artist\": \"Super Yei, Jone Quest\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 786, \"Highest Charting Position\": 156, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"SLOW DANCING IN THE DARK\", \"Streams\": 4732343, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"0rKtyWc8bvkriBthvHKY8d\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2018-10-26\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-05-08--2020-05-15\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.515, \"Energy\": 0.479, \"Loudness\": -7.458, \"Speechiness\": 0.0261, \"Acousticness\": 0.544, \"Liveness\": 0.191, \"Tempo\": 88.964, \"Duration (ms)\": 209274.0, \"Valence\": 0.284, \"Chord\": \"D#/Eb\"}, {\"Index\": 787, \"Highest Charting Position\": 92, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Don Don\", \"Streams\": 4731423, \"Artist\": \"Daddy Yankee, Anuel AA, Kendo Kaponi\", \"Artist Followers\": 23936368.0, \"Song ID\": \"3kml9ZdpT7UYk1ugkjqOzt\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-11\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 69.0, \"Danceability\": 0.838, \"Energy\": 0.819, \"Loudness\": -4.681, \"Speechiness\": 0.211, \"Acousticness\": 0.285, \"Liveness\": 0.224, \"Tempo\": 105.027, \"Duration (ms)\": 275893.0, \"Valence\": 0.656, \"Chord\": \"F\"}, {\"Index\": 788, \"Highest Charting Position\": 5, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"my future\", \"Streams\": 4721082, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"3YUMWmx8EJq0DurfuIwoGh\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-07-30\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 80.0, \"Danceability\": 0.456, \"Energy\": 0.285, \"Loudness\": -10.755, \"Speechiness\": 0.0979, \"Acousticness\": 0.814, \"Liveness\": 0.307, \"Tempo\": 104.89, \"Duration (ms)\": 210005.0, \"Valence\": 0.0809, \"Chord\": \"G#/Ab\"}, {\"Index\": 789, \"Highest Charting Position\": 163, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Nada\", \"Streams\": 4713873, \"Artist\": \"Cali Y El Dandee, Danna Paola\", \"Artist Followers\": 3152313.0, \"Song ID\": \"4K8cyoCDovlc4FvtUr2Hfx\", \"Genre\": \"['champeta', 'colombian pop', 'electro latino', 'latin', 'latin pop', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 76.0, \"Danceability\": 0.684, \"Energy\": 0.808, \"Loudness\": -2.737, \"Speechiness\": 0.061, \"Acousticness\": 0.0518, \"Liveness\": 0.0858, \"Tempo\": 173.905, \"Duration (ms)\": 174027.0, \"Valence\": 0.712, \"Chord\": \"C\"}, {\"Index\": 790, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"safety net (feat. Ty Dolla $ign)\", \"Streams\": 5798744, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"14gkWVFMwdxBMyqBw1wmIg\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 70.0, \"Danceability\": 0.552, \"Energy\": 0.599, \"Loudness\": -5.75, \"Speechiness\": 0.0404, \"Acousticness\": 0.0703, \"Liveness\": 0.0986, \"Tempo\": 161.884, \"Duration (ms)\": 208457.0, \"Valence\": 0.0916, \"Chord\": \"C#/Db\"}, {\"Index\": 791, \"Highest Charting Position\": 31, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"shut up\", \"Streams\": 5282490, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3ko9jEHNt4O5fjKN65ULJp\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 63.0, \"Danceability\": 0.499, \"Energy\": 0.462, \"Loudness\": -5.308, \"Speechiness\": 0.0312, \"Acousticness\": 0.801, \"Liveness\": 0.0946, \"Tempo\": 127.698, \"Duration (ms)\": 157710.0, \"Valence\": 0.599, \"Chord\": \"C\"}, {\"Index\": 792, \"Highest Charting Position\": 42, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"nasty\", \"Streams\": 5249342, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"0sci7ppTZFm4mjcH3nu8yO\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 69.0, \"Danceability\": 0.772, \"Energy\": 0.506, \"Loudness\": -6.558, \"Speechiness\": 0.139, \"Acousticness\": 0.0814, \"Liveness\": 0.182, \"Tempo\": 127.894, \"Duration (ms)\": 200733.0, \"Valence\": 0.456, \"Chord\": \"F#/Gb\"}, {\"Index\": 793, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"TRAGIC (feat. Youngboy Never Broke Again & Internet Money)\", \"Streams\": 5226940, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"13EW51DKru044OJDJ9Bm8o\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-11-06--2020-11-13\", \"Popularity\": 76.0, \"Danceability\": 0.779, \"Energy\": 0.642, \"Loudness\": -6.321, \"Speechiness\": 0.116, \"Acousticness\": 0.0383, \"Liveness\": 0.2, \"Tempo\": 82.363, \"Duration (ms)\": 153147.0, \"Valence\": 0.388, \"Chord\": \"G#/Ab\"}, {\"Index\": 794, \"Highest Charting Position\": 49, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Ayer Me Llam\\u00f3 Mi Ex (feat. Lenny Santos)\", \"Streams\": 5220504, \"Artist\": \"KHEA\", \"Artist Followers\": 3198705.0, \"Song ID\": \"6C6mUonH6MNdSg5pw7kOc9\", \"Genre\": \"['argentine hip hop', 'trap argentino', 'trap latino', 'trap triste']\", \"Release Date\": \"2020-08-20\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 71.0, \"Danceability\": 0.752, \"Energy\": 0.716, \"Loudness\": -5.2, \"Speechiness\": 0.0325, \"Acousticness\": 0.254, \"Liveness\": 0.243, \"Tempo\": 117.007, \"Duration (ms)\": 206760.0, \"Valence\": 0.553, \"Chord\": \"A#/Bb\"}, {\"Index\": 795, \"Highest Charting Position\": 119, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Madrid (feat. Myke Towers)\", \"Streams\": 5064484, \"Artist\": \"Maluma\", \"Artist Followers\": 26784251.0, \"Song ID\": \"19OXtYzrJyCrQvTbfukt4H\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 73.0, \"Danceability\": 0.764, \"Energy\": 0.741, \"Loudness\": -3.617, \"Speechiness\": 0.101, \"Acousticness\": 0.239, \"Liveness\": 0.107, \"Tempo\": 170.081, \"Duration (ms)\": 198570.0, \"Valence\": 0.802, \"Chord\": \"A\"}, {\"Index\": 796, \"Highest Charting Position\": 85, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Caramelo - Remix\", \"Streams\": 5033798, \"Artist\": \"Ozuna, KAROL G, Myke Towers\", \"Artist Followers\": 29238936.0, \"Song ID\": \"2uu2aGqA2UblCg581Q7l1g\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-08-17\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 72.0, \"Danceability\": 0.754, \"Energy\": 0.796, \"Loudness\": -3.743, \"Speechiness\": 0.139, \"Acousticness\": 0.062, \"Liveness\": 0.204, \"Tempo\": 168.045, \"Duration (ms)\": 233160.0, \"Valence\": 0.62, \"Chord\": \"D#/Eb\"}, {\"Index\": 797, \"Highest Charting Position\": 25, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Mr. Right Now (feat. Drake)\", \"Streams\": 4951481, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"4Q34FP1AT7GEl9oLgNtiWj\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 75.0, \"Danceability\": 0.647, \"Energy\": 0.667, \"Loudness\": -5.563, \"Speechiness\": 0.304, \"Acousticness\": 0.231, \"Liveness\": 0.133, \"Tempo\": 172.08, \"Duration (ms)\": 193839.0, \"Valence\": 0.704, \"Chord\": \"F\"}, {\"Index\": 798, \"Highest Charting Position\": 41, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Got It On Me\", \"Streams\": 4924030, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"25zlnOAzbVoOzIeXSvQFf1\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 78.0, \"Danceability\": 0.688, \"Energy\": 0.647, \"Loudness\": -7.258, \"Speechiness\": 0.19, \"Acousticness\": 0.00815, \"Liveness\": 0.095, \"Tempo\": 88.834, \"Duration (ms)\": 164580.0, \"Valence\": 0.195, \"Chord\": \"D\"}, {\"Index\": 799, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"my hair\", \"Streams\": 4896521, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"6u7gmPOz7pzzaeR9xSBpsR\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 66.0, \"Danceability\": 0.686, \"Energy\": 0.526, \"Loudness\": -6.842, \"Speechiness\": 0.0374, \"Acousticness\": 0.0815, \"Liveness\": 0.144, \"Tempo\": 92.013, \"Duration (ms)\": 158436.0, \"Valence\": 0.372, \"Chord\": \"C\"}, {\"Index\": 800, \"Highest Charting Position\": 59, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"obvious\", \"Streams\": 4865084, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"0q85C1JiECyYIQthz1posA\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 65.0, \"Danceability\": 0.624, \"Energy\": 0.672, \"Loudness\": -5.334, \"Speechiness\": 0.106, \"Acousticness\": 0.0967, \"Liveness\": 0.155, \"Tempo\": 159.852, \"Duration (ms)\": 146959.0, \"Valence\": 0.26, \"Chord\": \"C\"}, {\"Index\": 801, \"Highest Charting Position\": 30, \"Number of Times Charted\": 45, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Beautiful People (feat. Khalid)\", \"Streams\": 4813796, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"4evmHXcjt3bTUHD1cvny97\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.64, \"Energy\": 0.648, \"Loudness\": -8.113, \"Speechiness\": 0.187, \"Acousticness\": 0.124, \"Liveness\": 0.0802, \"Tempo\": 92.977, \"Duration (ms)\": 197867.0, \"Valence\": 0.548, \"Chord\": \"F\"}, {\"Index\": 802, \"Highest Charting Position\": 29, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Favorito\", \"Streams\": 4787127, \"Artist\": \"Camilo\", \"Artist Followers\": 10580764.0, \"Song ID\": \"0Snbzbd74RLfL0i4nn1vU5\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-26\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 73.0, \"Danceability\": 0.611, \"Energy\": 0.851, \"Loudness\": -2.982, \"Speechiness\": 0.0598, \"Acousticness\": 0.229, \"Liveness\": 0.232, \"Tempo\": 178.032, \"Duration (ms)\": 211613.0, \"Valence\": 0.823, \"Chord\": \"A\"}, {\"Index\": 803, \"Highest Charting Position\": 42, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"After Party\", \"Streams\": 4784580, \"Artist\": \"Don Toliver\", \"Artist Followers\": 1606884.0, \"Song ID\": \"527k23H0A4Q0UJN3vGs0Da\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 80.0, \"Danceability\": 0.629, \"Energy\": 0.692, \"Loudness\": -8.045, \"Speechiness\": 0.0376, \"Acousticness\": 0.00981, \"Liveness\": 0.603, \"Tempo\": 162.948, \"Duration (ms)\": 167916.0, \"Valence\": 0.453, \"Chord\": \"F\"}, {\"Index\": 804, \"Highest Charting Position\": 14, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Rojo\", \"Streams\": 4773792, \"Artist\": \"J Balvin\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3zR9JVqHsILrkNyCOqA6jM\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 0.0, \"Danceability\": 0.652, \"Energy\": 0.595, \"Loudness\": -4.04, \"Speechiness\": 0.117, \"Acousticness\": 0.15, \"Liveness\": 0.0836, \"Tempo\": 172.277, \"Duration (ms)\": 151147.0, \"Valence\": 0.421, \"Chord\": \"B\"}, {\"Index\": 805, \"Highest Charting Position\": 51, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"six thirty\", \"Streams\": 10941573, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"2IKJtXeR5UsaUjZB46fTOK\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 63.0, \"Danceability\": 0.739, \"Energy\": 0.516, \"Loudness\": -7.154, \"Speechiness\": 0.0539, \"Acousticness\": 0.67, \"Liveness\": 0.151, \"Tempo\": 120.109, \"Duration (ms)\": 183874.0, \"Valence\": 0.434, \"Chord\": \"C\"}, {\"Index\": 806, \"Highest Charting Position\": 65, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"love language\", \"Streams\": 9399230, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"6NYtLvyThMT0oALFdJFdzq\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 62.0, \"Danceability\": 0.688, \"Energy\": 0.573, \"Loudness\": -5.03, \"Speechiness\": 0.208, \"Acousticness\": 0.0686, \"Liveness\": 0.0749, \"Tempo\": 110.034, \"Duration (ms)\": 179861.0, \"Valence\": 0.553, \"Chord\": \"A#/Bb\"}, {\"Index\": 807, \"Highest Charting Position\": 66, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"west side\", \"Streams\": 9397167, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"1whfVLMKWqAX3uk97VXsNN\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 62.0, \"Danceability\": 0.688, \"Energy\": 0.455, \"Loudness\": -8.632, \"Speechiness\": 0.199, \"Acousticness\": 0.186, \"Liveness\": 0.0794, \"Tempo\": 87.865, \"Duration (ms)\": 132279.0, \"Valence\": 0.557, \"Chord\": \"B\"}, {\"Index\": 808, \"Highest Charting Position\": 146, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Thriller\", \"Streams\": 5605234, \"Artist\": \"Michael Jackson\", \"Artist Followers\": 19345579.0, \"Song ID\": \"7azo4rpSUh8nXgtonC6Pkq\", \"Genre\": \"['pop', 'r&b', 'soul']\", \"Release Date\": \"2017-09-27\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 68.0, \"Danceability\": 0.764, \"Energy\": 0.887, \"Loudness\": -3.726, \"Speechiness\": 0.0744, \"Acousticness\": 0.0816, \"Liveness\": 0.847, \"Tempo\": 118.427, \"Duration (ms)\": 358053.0, \"Valence\": 0.72, \"Chord\": \"B\"}, {\"Index\": 809, \"Highest Charting Position\": 105, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Dancing With A Stranger (with Normani)\", \"Streams\": 5229835, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"6Qs4SXO9dwPj5GKvVOv8Ki\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2019-01-11\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.741, \"Energy\": 0.52, \"Loudness\": -7.513, \"Speechiness\": 0.0656, \"Acousticness\": 0.45, \"Liveness\": 0.222, \"Tempo\": 102.998, \"Duration (ms)\": 171030.0, \"Valence\": 0.347, \"Chord\": \"G#/Ab\"}, {\"Index\": 810, \"Highest Charting Position\": 91, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Angeklagt\", \"Streams\": 5226264, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"5eu4Lxm5TlI0tKSTTDWJAT\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-10-29\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 60.0, \"Danceability\": 0.658, \"Energy\": 0.624, \"Loudness\": -9.155, \"Speechiness\": 0.0915, \"Acousticness\": 0.171, \"Liveness\": 0.116, \"Tempo\": 181.942, \"Duration (ms)\": 168991.0, \"Valence\": 0.314, \"Chord\": \"C#/Db\"}, {\"Index\": 811, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Kids Again\", \"Streams\": 5103194, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"1ABS9lKaZ1uXkXCqr9zFO7\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 62.0, \"Danceability\": 0.666, \"Energy\": 0.726, \"Loudness\": -2.998, \"Speechiness\": 0.0262, \"Acousticness\": 0.486, \"Liveness\": 0.0892, \"Tempo\": 128.044, \"Duration (ms)\": 207528.0, \"Valence\": 0.468, \"Chord\": \"B\"}, {\"Index\": 812, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Highway to Hell\", \"Streams\": 5096618, \"Artist\": \"AC/DC\", \"Artist Followers\": 20110171.0, \"Song ID\": \"2zYzyRzz6pRmhPzyfMEC8s\", \"Genre\": \"['australian rock', 'hard rock', 'rock']\", \"Release Date\": \"1979-07-27\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 83.0, \"Danceability\": 0.574, \"Energy\": 0.913, \"Loudness\": -4.793, \"Speechiness\": 0.133, \"Acousticness\": 0.061, \"Liveness\": 0.156, \"Tempo\": 115.728, \"Duration (ms)\": 208400.0, \"Valence\": 0.423, \"Chord\": \"F#/Gb\"}, {\"Index\": 813, \"Highest Charting Position\": 38, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Me Gusta (with Cardi B & Myke Towers)\", \"Streams\": 4914412, \"Artist\": \"Anitta\", \"Artist Followers\": 10741972.0, \"Song ID\": \"7e1VoRlNumuEkXlITMHKLE\", \"Genre\": \"['funk carioca', 'funk pop', 'pagode baiano', 'pop nacional']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 72.0, \"Danceability\": 0.91, \"Energy\": 0.604, \"Loudness\": -4.392, \"Speechiness\": 0.082, \"Acousticness\": 0.448, \"Liveness\": 0.0863, \"Tempo\": 110.075, \"Duration (ms)\": 180788.0, \"Valence\": 0.807, \"Chord\": \"F#/Gb\"}, {\"Index\": 814, \"Highest Charting Position\": 133, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"24 (feat. Lil Baby)\", \"Streams\": 4904772, \"Artist\": \"Money Man\", \"Artist Followers\": 345027.0, \"Song ID\": \"0xUvi7wldroBzaZCengPa5\", \"Genre\": \"['memphis hip hop', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 74.0, \"Danceability\": 0.868, \"Energy\": 0.638, \"Loudness\": -7.746, \"Speechiness\": 0.0736, \"Acousticness\": 0.146, \"Liveness\": 0.0931, \"Tempo\": 126.03, \"Duration (ms)\": 182857.0, \"Valence\": 0.459, \"Chord\": \"D\"}, {\"Index\": 815, \"Highest Charting Position\": 23, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Relaci\\u00f3n\", \"Streams\": 4825749, \"Artist\": \"Sech\", \"Artist Followers\": 8766508.0, \"Song ID\": \"35UUpTmrcFXNIVIN26ujXl\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-04-10--2020-04-17\", \"Popularity\": 80.0, \"Danceability\": 0.793, \"Energy\": 0.771, \"Loudness\": -3.417, \"Speechiness\": 0.0959, \"Acousticness\": 0.0337, \"Liveness\": 0.284, \"Tempo\": 171.943, \"Duration (ms)\": 247308.0, \"Valence\": 0.835, \"Chord\": \"F\"}, {\"Index\": 816, \"Highest Charting Position\": 14, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"FRANCHISE (feat. Young Thug & M.I.A.)\", \"Streams\": 4821213, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"4jVBIpuOiMj1crqd8LoCrJ\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 74.0, \"Danceability\": 0.835, \"Energy\": 0.699, \"Loudness\": -5.405, \"Speechiness\": 0.277, \"Acousticness\": 0.00671, \"Liveness\": 0.195, \"Tempo\": 154.981, \"Duration (ms)\": 202795.0, \"Valence\": 0.547, \"Chord\": \"G#/Ab\"}, {\"Index\": 817, \"Highest Charting Position\": 11, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Bet You Wanna (feat. Cardi B)\", \"Streams\": 6846771, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"7iAgNZdotu40NwtoIWJHFe\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 67.0, \"Danceability\": 0.653, \"Energy\": 0.662, \"Loudness\": -6.168, \"Speechiness\": 0.162, \"Acousticness\": 0.00465, \"Liveness\": 0.0626, \"Tempo\": 111.712, \"Duration (ms)\": 161168.0, \"Valence\": 0.674, \"Chord\": \"G\"}, {\"Index\": 818, \"Highest Charting Position\": 82, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Wolves (feat. Post Malone)\", \"Streams\": 5547002, \"Artist\": \"Big Sean\", \"Artist Followers\": 8673345.0, \"Song ID\": \"33gwZOGJWEZ7dRWPqPxBEZ\", \"Genre\": \"['detroit hip hop', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 79.0, \"Danceability\": 0.724, \"Energy\": 0.675, \"Loudness\": -5.267, \"Speechiness\": 0.0867, \"Acousticness\": 0.0978, \"Liveness\": 0.351, \"Tempo\": 160.048, \"Duration (ms)\": 199758.0, \"Valence\": 0.325, \"Chord\": \"D\"}, {\"Index\": 819, \"Highest Charting Position\": 88, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"thank u, next\", \"Streams\": 5079328, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3e9HZxeyfWwjeyPAMmWSSQ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-02-08\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.717, \"Energy\": 0.653, \"Loudness\": -5.634, \"Speechiness\": 0.0658, \"Acousticness\": 0.229, \"Liveness\": 0.101, \"Tempo\": 106.966, \"Duration (ms)\": 207320.0, \"Valence\": 0.412, \"Chord\": \"C#/Db\"}, {\"Index\": 820, \"Highest Charting Position\": 19, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"MAMACITA\", \"Streams\": 5016343, \"Artist\": \"Black Eyed Peas, Ozuna, J. Rey Soul\", \"Artist Followers\": 5966748.0, \"Song ID\": \"14wf185UxfNbSy8dwt4r4q\", \"Genre\": \"['dance pop', 'pop', 'pop rap']\", \"Release Date\": \"2020-04-10\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 74.0, \"Danceability\": 0.894, \"Energy\": 0.635, \"Loudness\": -6.929, \"Speechiness\": 0.0473, \"Acousticness\": 0.193, \"Liveness\": 0.0823, \"Tempo\": 105.013, \"Duration (ms)\": 249143.0, \"Valence\": 0.428, \"Chord\": \"D\"}, {\"Index\": 821, \"Highest Charting Position\": 137, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Fake\", \"Streams\": 5010179, \"Artist\": \"Lauv, Conan Gray\", \"Artist Followers\": 4442273.0, \"Song ID\": \"4Gt2kh3QbAGU6yquOWn4aW\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-13\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 73.0, \"Danceability\": 0.703, \"Energy\": 0.657, \"Loudness\": -5.363, \"Speechiness\": 0.0783, \"Acousticness\": 0.139, \"Liveness\": 0.093, \"Tempo\": 82.96, \"Duration (ms)\": 146375.0, \"Valence\": 0.455, \"Chord\": \"E\"}, {\"Index\": 822, \"Highest Charting Position\": 56, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"OK Not To Be OK\", \"Streams\": 4980744, \"Artist\": \"Marshmello, Demi Lovato\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6PiO7fUEPKnJfaCQbPrIyg\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 0.0, \"Danceability\": 0.743, \"Energy\": 0.837, \"Loudness\": -5.025, \"Speechiness\": 0.0649, \"Acousticness\": 0.0172, \"Liveness\": 0.0743, \"Tempo\": 103.072, \"Duration (ms)\": 159863.0, \"Valence\": 0.263, \"Chord\": \"C#/Db\"}, {\"Index\": 823, \"Highest Charting Position\": 1, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"THE SCOTTS\", \"Streams\": 4941592, \"Artist\": \"THE SCOTTS, Travis Scott, Kid Cudi\", \"Artist Followers\": 179193.0, \"Song ID\": \"39Yp9wwQiSRIDOvrVg7mbk\", \"Genre\": \"['pop rap']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 79.0, \"Danceability\": 0.716, \"Energy\": 0.537, \"Loudness\": -7.648, \"Speechiness\": 0.0514, \"Acousticness\": 0.233, \"Liveness\": 0.157, \"Tempo\": 129.979, \"Duration (ms)\": 165978.0, \"Valence\": 0.28, \"Chord\": \"C\"}, {\"Index\": 824, \"Highest Charting Position\": 37, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Mamichula - con Nicki Nicole\", \"Streams\": 4817969, \"Artist\": \"Trueno, Bizarrap, Taiu, TATOOL\", \"Artist Followers\": 2172969.0, \"Song ID\": \"0TUW9faHNaBmi89wsYGp9y\", \"Genre\": \"['argentine hip hop', 'trap argentino', 'trap latino']\", \"Release Date\": \"2020-07-23\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 75.0, \"Danceability\": 0.696, \"Energy\": 0.678, \"Loudness\": -5.893, \"Speechiness\": 0.0735, \"Acousticness\": 0.582, \"Liveness\": 0.134, \"Tempo\": 91.985, \"Duration (ms)\": 219202.0, \"Valence\": 0.346, \"Chord\": \"E\"}, {\"Index\": 825, \"Highest Charting Position\": 172, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Let Her Go\", \"Streams\": 4765198, \"Artist\": \"Passenger\", \"Artist Followers\": 2819406.0, \"Song ID\": \"0JmiBCpWc1IAc0et7Xm7FL\", \"Genre\": \"['folk-pop', 'neo mellow', 'pop', 'pop rock']\", \"Release Date\": \"2013-02-17\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 75.0, \"Danceability\": 0.479, \"Energy\": 0.545, \"Loudness\": -7.346, \"Speechiness\": 0.0688, \"Acousticness\": 0.365, \"Liveness\": 0.0963, \"Tempo\": 74.897, \"Duration (ms)\": 252733.0, \"Valence\": 0.243, \"Chord\": \"G\"}, {\"Index\": 826, \"Highest Charting Position\": 26, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Play Date\", \"Streams\": 4745568, \"Artist\": \"Melanie Martinez\", \"Artist Followers\": 10925614.0, \"Song ID\": \"4DpNNXFMMxQEKl7r0ykkWA\", \"Genre\": \"['alt z', 'electropop', 'modern rock', 'pop']\", \"Release Date\": \"2015-08-14\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 80.0, \"Danceability\": 0.68, \"Energy\": 0.729, \"Loudness\": -5.077, \"Speechiness\": 0.0475, \"Acousticness\": 0.612, \"Liveness\": 0.224, \"Tempo\": 123.97, \"Duration (ms)\": 179867.0, \"Valence\": 0.446, \"Chord\": \"F\"}, {\"Index\": 827, \"Highest Charting Position\": 32, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Lose Somebody\", \"Streams\": 4709053, \"Artist\": \"Kygo, OneRepublic\", \"Artist Followers\": 7593792.0, \"Song ID\": \"1sgDyuLooyvEML4oHspNza\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 75.0, \"Danceability\": 0.58, \"Energy\": 0.586, \"Loudness\": -6.883, \"Speechiness\": 0.0357, \"Acousticness\": 0.344, \"Liveness\": 0.0755, \"Tempo\": 147.988, \"Duration (ms)\": 199549.0, \"Valence\": 0.507, \"Chord\": \"C#/Db\"}, {\"Index\": 828, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Someone Like You\", \"Streams\": 4703672, \"Artist\": \"Adele\", \"Artist Followers\": 28335338.0, \"Song ID\": \"1zwMYTA5nlNjZxYrvBB2pV\", \"Genre\": \"['british soul', 'pop', 'pop soul', 'uk pop']\", \"Release Date\": \"2011-01-24\", \"Weeks Charted\": \"2020-10-23--2020-10-30\", \"Popularity\": 77.0, \"Danceability\": 0.556, \"Energy\": 0.319, \"Loudness\": -8.251, \"Speechiness\": 0.0281, \"Acousticness\": 0.893, \"Liveness\": 0.0996, \"Tempo\": 135.187, \"Duration (ms)\": 285240.0, \"Valence\": 0.294, \"Chord\": \"A\"}, {\"Index\": 829, \"Highest Charting Position\": 73, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"It's You\", \"Streams\": 4674658, \"Artist\": \"Ali Gatie\", \"Artist Followers\": 1758300.0, \"Song ID\": \"5DqdesEfbRyOlSS3Tf6c29\", \"Genre\": \"['canadian hip hop', 'pop']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.732, \"Energy\": 0.463, \"Loudness\": -6.972, \"Speechiness\": 0.0287, \"Acousticness\": 0.374, \"Liveness\": 0.194, \"Tempo\": 95.971, \"Duration (ms)\": 212607.0, \"Valence\": 0.397, \"Chord\": \"B\"}, {\"Index\": 830, \"Highest Charting Position\": 68, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Stunnin' (feat. Harm Franklin)\", \"Streams\": 5183246, \"Artist\": \"Curtis Waters\", \"Artist Followers\": 68875.0, \"Song ID\": \"2JSmxLqt8h7ZpJJkfuLJvK\", \"Genre\": \"[]\", \"Release Date\": \"2020-10-09\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 68.0, \"Danceability\": 0.885, \"Energy\": 0.685, \"Loudness\": -6.429, \"Speechiness\": 0.0627, \"Acousticness\": 0.33, \"Liveness\": 0.148, \"Tempo\": 99.954, \"Duration (ms)\": 144000.0, \"Valence\": 0.937, \"Chord\": \"B\"}, {\"Index\": 831, \"Highest Charting Position\": 35, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Love To Hate Me\", \"Streams\": 5125708, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"7iKDsPfLT0d5mu2htfMKBZ\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 69.0, \"Danceability\": 0.686, \"Energy\": 0.64, \"Loudness\": -5.491, \"Speechiness\": 0.159, \"Acousticness\": 0.0334, \"Liveness\": 0.0801, \"Tempo\": 162.225, \"Duration (ms)\": 171798.0, \"Valence\": 0.597, \"Chord\": \"G#/Ab\"}, {\"Index\": 832, \"Highest Charting Position\": 165, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Hate The Way (feat. blackbear)\", \"Streams\": 5116071, \"Artist\": \"G-Eazy\", \"Artist Followers\": 4894656.0, \"Song ID\": \"3QGppKBPd9gHOgHJzRbVIw\", \"Genre\": \"['hip hop', 'indie pop rap', 'oakland hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2020-10-16--2020-10-23\", \"Popularity\": 68.0, \"Danceability\": 0.569, \"Energy\": 0.865, \"Loudness\": -3.844, \"Speechiness\": 0.266, \"Acousticness\": 0.0673, \"Liveness\": 0.312, \"Tempo\": 82.011, \"Duration (ms)\": 214363.0, \"Valence\": 0.361, \"Chord\": \"E\"}, {\"Index\": 833, \"Highest Charting Position\": 89, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Bande organis\\u00e9e\", \"Streams\": 5112572, \"Artist\": \"13 Organis\\u00e9, SCH, Kofs, Jul, Naps, Soso Maness, Elams, Solda, Houari\", \"Artist Followers\": 249910.0, \"Song ID\": \"205HNJ73cgpC0LAOnuQiWT\", \"Genre\": \"['french hip hop', 'pop urbaine', 'rap francais', 'rap marseille']\", \"Release Date\": \"2020-08-15\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 72.0, \"Danceability\": 0.901, \"Energy\": 0.939, \"Loudness\": -2.762, \"Speechiness\": 0.274, \"Acousticness\": 0.117, \"Liveness\": 0.0643, \"Tempo\": 142.948, \"Duration (ms)\": 356347.0, \"Valence\": 0.805, \"Chord\": \"F#/Gb\"}, {\"Index\": 834, \"Highest Charting Position\": 32, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Crazy Over You\", \"Streams\": 5056387, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"7qq0EOPW4RRlqdvMBmdd73\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 68.0, \"Danceability\": 0.804, \"Energy\": 0.633, \"Loudness\": -6.186, \"Speechiness\": 0.0612, \"Acousticness\": 0.0371, \"Liveness\": 0.102, \"Tempo\": 115.002, \"Duration (ms)\": 163946.0, \"Valence\": 0.67, \"Chord\": \"E\"}, {\"Index\": 835, \"Highest Charting Position\": 109, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Baby, I'm Jealous (feat. Doja Cat)\", \"Streams\": 4870203, \"Artist\": \"Bebe Rexha\", \"Artist Followers\": 6569150.0, \"Song ID\": \"2fTdRdN73RgIgcUZN33dvt\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-09\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 69.0, \"Danceability\": 0.737, \"Energy\": 0.867, \"Loudness\": -2.259, \"Speechiness\": 0.0458, \"Acousticness\": 0.0398, \"Liveness\": 0.32, \"Tempo\": 98.05, \"Duration (ms)\": 175873.0, \"Valence\": 0.506, \"Chord\": \"B\"}, {\"Index\": 836, \"Highest Charting Position\": 15, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"TKN (feat. Travis Scott)\", \"Streams\": 4752289, \"Artist\": \"ROSAL\\u00cdA\", \"Artist Followers\": 4769627.0, \"Song ID\": \"4w47S36wQGBhGg073q3nt7\", \"Genre\": \"['r&b en espanol']\", \"Release Date\": \"2020-05-28\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 75.0, \"Danceability\": 0.776, \"Energy\": 0.509, \"Loudness\": -6.266, \"Speechiness\": 0.467, \"Acousticness\": 0.192, \"Liveness\": 0.115, \"Tempo\": 94.634, \"Duration (ms)\": 129371.0, \"Valence\": 0.485, \"Chord\": \"C\"}, {\"Index\": 837, \"Highest Charting Position\": 135, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"El Mismo Aire - con Pablo Albor\\u00e1n\", \"Streams\": 4705484, \"Artist\": \"Camilo\", \"Artist Followers\": 10580764.0, \"Song ID\": \"5EbtodsuLbxrFDH6j5avVS\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-06-10\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 75.0, \"Danceability\": 0.483, \"Energy\": 0.492, \"Loudness\": -6.591, \"Speechiness\": 0.295, \"Acousticness\": 0.603, \"Liveness\": 0.323, \"Tempo\": 144.511, \"Duration (ms)\": 188213.0, \"Valence\": 0.66, \"Chord\": \"C\"}, {\"Index\": 838, \"Highest Charting Position\": 18, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Yo Perreo Sola\", \"Streams\": 4680447, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0SqqAgdovOE24BzxIClpjw\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 78.0, \"Danceability\": 0.86, \"Energy\": 0.758, \"Loudness\": -5.16, \"Speechiness\": 0.0695, \"Acousticness\": 0.021, \"Liveness\": 0.344, \"Tempo\": 97.014, \"Duration (ms)\": 172127.0, \"Valence\": 0.453, \"Chord\": \"B\"}, {\"Index\": 839, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Let Me Love You Like A Woman\", \"Streams\": 4665053, \"Artist\": \"Lana Del Rey\", \"Artist Followers\": 13697048.0, \"Song ID\": \"1gxdWpeOUBpvB908fiZs4D\", \"Genre\": \"['art pop', 'pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2020-10-16--2020-10-23\", \"Popularity\": 67.0, \"Danceability\": 0.303, \"Energy\": 0.249, \"Loudness\": -11.715, \"Speechiness\": 0.111, \"Acousticness\": 0.97, \"Liveness\": 0.117, \"Tempo\": 66.932, \"Duration (ms)\": 200661.0, \"Valence\": 0.131, \"Chord\": \"C\"}, {\"Index\": 840, \"Highest Charting Position\": 69, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"DOLLAZ ON MY HEAD (feat. Young Thug)\", \"Streams\": 4652712, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"3nS9a01VvXHQriLqJYwRqG\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 76.0, \"Danceability\": 0.825, \"Energy\": 0.458, \"Loudness\": -7.47, \"Speechiness\": 0.0577, \"Acousticness\": 0.114, \"Liveness\": 0.102, \"Tempo\": 145.115, \"Duration (ms)\": 197760.0, \"Valence\": 0.161, \"Chord\": \"C\"}, {\"Index\": 841, \"Highest Charting Position\": 54, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Eleg\\u00ed (feat. D\\u00edmelo Flow)\", \"Streams\": 4607003, \"Artist\": \"Rauw Alejandro, Dalex, Lenny Tav\\u00e1rez\", \"Artist Followers\": 6096559.0, \"Song ID\": \"50ZC4PM7hywH27RcCfViau\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-03-26\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 75.0, \"Danceability\": 0.824, \"Energy\": 0.631, \"Loudness\": -2.791, \"Speechiness\": 0.0809, \"Acousticness\": 0.237, \"Liveness\": 0.0531, \"Tempo\": 171.965, \"Duration (ms)\": 197721.0, \"Valence\": 0.678, \"Chord\": \"C\"}, {\"Index\": 842, \"Highest Charting Position\": 77, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"July\", \"Streams\": 4598766, \"Artist\": \"Noah Cyrus\", \"Artist Followers\": 891555.0, \"Song ID\": \"6J2LdBN97cDWn0MLxYh9HB\", \"Genre\": \"['alt z', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.708, \"Energy\": 0.186, \"Loudness\": -8.953, \"Speechiness\": 0.042, \"Acousticness\": 0.868, \"Liveness\": 0.0779, \"Tempo\": 72.541, \"Duration (ms)\": 156106.0, \"Valence\": 0.322, \"Chord\": \"A\"}, {\"Index\": 843, \"Highest Charting Position\": 93, \"Number of Times Charted\": 38, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Bruises\", \"Streams\": 4560503, \"Artist\": \"Lewis Capaldi\", \"Artist Followers\": 8388838.0, \"Song ID\": \"4Of7rzpRpV1mWRbhp5rAqG\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.736, \"Energy\": 0.308, \"Loudness\": -7.83, \"Speechiness\": 0.0677, \"Acousticness\": 0.946, \"Liveness\": 0.186, \"Tempo\": 111.202, \"Duration (ms)\": 220492.0, \"Valence\": 0.361, \"Chord\": \"E\"}, {\"Index\": 844, \"Highest Charting Position\": 46, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"You Never Know\", \"Streams\": 5304382, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"3b7trEcKoglybN5MxGuSaw\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2021-08-03\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 54.0, \"Danceability\": 0.535, \"Energy\": 0.434, \"Loudness\": -5.768, \"Speechiness\": 0.0505, \"Acousticness\": 0.405, \"Liveness\": 0.253, \"Tempo\": 144.497, \"Duration (ms)\": 229236.0, \"Valence\": 0.271, \"Chord\": \"F\"}, {\"Index\": 845, \"Highest Charting Position\": 12, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Supalonely\", \"Streams\": 5089970, \"Artist\": \"BENEE, Gus Dapperton\", \"Artist Followers\": 638337.0, \"Song ID\": \"4nK5YrxbMGZstTLbvj6Gxw\", \"Genre\": \"['alt z', 'nz pop', 'pop']\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 77.0, \"Danceability\": 0.863, \"Energy\": 0.631, \"Loudness\": -4.689, \"Speechiness\": 0.0534, \"Acousticness\": 0.305, \"Liveness\": 0.123, \"Tempo\": 128.977, \"Duration (ms)\": 223480.0, \"Valence\": 0.817, \"Chord\": \"G\"}, {\"Index\": 846, \"Highest Charting Position\": 53, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Glock In My Lap\", \"Streams\": 4947593, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"6pcywuOeGGWeOQzdUyti6k\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 69.0, \"Danceability\": 0.847, \"Energy\": 0.733, \"Loudness\": -6.439, \"Speechiness\": 0.16, \"Acousticness\": 0.00574, \"Liveness\": 0.151, \"Tempo\": 130.029, \"Duration (ms)\": 193591.0, \"Valence\": 0.202, \"Chord\": \"A#/Bb\"}, {\"Index\": 847, \"Highest Charting Position\": 49, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Better\", \"Streams\": 4933462, \"Artist\": \"ZAYN\", \"Artist Followers\": 16655692.0, \"Song ID\": \"1dLXLETYiZohIZWnse4ypG\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-01-03--2020-01-10\", \"Popularity\": 68.0, \"Danceability\": 0.637, \"Energy\": 0.418, \"Loudness\": -7.137, \"Speechiness\": 0.301, \"Acousticness\": 0.353, \"Liveness\": 0.131, \"Tempo\": 84.295, \"Duration (ms)\": 174517.0, \"Valence\": 0.0807, \"Chord\": \"D\"}, {\"Index\": 848, \"Highest Charting Position\": 59, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"forget me too (feat. Halsey)\", \"Streams\": 4751756, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3868320.0, \"Song ID\": \"1VSuFS7PahCN3SWbOcQ98m\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 78.0, \"Danceability\": 0.654, \"Energy\": 0.875, \"Loudness\": -4.845, \"Speechiness\": 0.0744, \"Acousticness\": 0.000417, \"Liveness\": 0.194, \"Tempo\": 99.975, \"Duration (ms)\": 171621.0, \"Valence\": 0.522, \"Chord\": \"C#/Db\"}, {\"Index\": 849, \"Highest Charting Position\": 110, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Oh Juliana\", \"Streams\": 4751064, \"Artist\": \"Niack\", \"Artist Followers\": 352402.0, \"Song ID\": \"4xWzZmX4K1yyrdtRfbUvjt\", \"Genre\": \"['funk carioca']\", \"Release Date\": \"2020-06-30\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 66.0, \"Danceability\": 0.799, \"Energy\": 0.568, \"Loudness\": -3.089, \"Speechiness\": 0.25, \"Acousticness\": 0.387, \"Liveness\": 0.0892, \"Tempo\": 129.63, \"Duration (ms)\": 153078.0, \"Valence\": 0.963, \"Chord\": \"F#/Gb\"}, {\"Index\": 850, \"Highest Charting Position\": 81, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"PORFA Remix ( Feat. Maluma, Nicky Jam, Sech) - Remix\", \"Streams\": 4727923, \"Artist\": \"Feid, J Balvin, Justin Quiles\", \"Artist Followers\": 613348.0, \"Song ID\": \"7lUdbnz7wsv3C9zzf4WHl9\", \"Genre\": \"['colombian pop', 'latin', 'pop reggaeton', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 70.0, \"Danceability\": 0.793, \"Energy\": 0.737, \"Loudness\": -4.731, \"Speechiness\": 0.0785, \"Acousticness\": 0.0765, \"Liveness\": 0.0747, \"Tempo\": 167.969, \"Duration (ms)\": 333800.0, \"Valence\": 0.697, \"Chord\": \"F#/Gb\"}, {\"Index\": 851, \"Highest Charting Position\": 108, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"No Guidance (feat. Drake)\", \"Streams\": 4641393, \"Artist\": \"Chris Brown\", \"Artist Followers\": 14073083.0, \"Song ID\": \"6XHVuErjQ4XNm6nDPVCxVX\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'r&b', 'rap']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.696, \"Energy\": 0.454, \"Loudness\": -6.756, \"Speechiness\": 0.153, \"Acousticness\": 0.123, \"Liveness\": 0.155, \"Tempo\": 92.928, \"Duration (ms)\": 260640.0, \"Valence\": 0.136, \"Chord\": \"C#/Db\"}, {\"Index\": 852, \"Highest Charting Position\": 65, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Rich Nigga Shit (feat. Young Thug)\", \"Streams\": 9129562, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"3ruoIF2UnoXdzK8mR61ebq\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 73.0, \"Danceability\": 0.825, \"Energy\": 0.733, \"Loudness\": -5.625, \"Speechiness\": 0.0969, \"Acousticness\": 0.349, \"Liveness\": 0.112, \"Tempo\": 97.974, \"Duration (ms)\": 190331.0, \"Valence\": 0.62, \"Chord\": \"C#/Db\"}, {\"Index\": 853, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Many Men\", \"Streams\": 8675173, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"3CDVMejYHnB1SkEEx0T1N4\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 65.0, \"Danceability\": 0.635, \"Energy\": 0.793, \"Loudness\": -4.333, \"Speechiness\": 0.0322, \"Acousticness\": 0.000647, \"Liveness\": 0.113, \"Tempo\": 77.594, \"Duration (ms)\": 201856.0, \"Valence\": 0.281, \"Chord\": \"A#/Bb\"}, {\"Index\": 854, \"Highest Charting Position\": 77, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Slidin\", \"Streams\": 8243488, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"7fxSLnklnayJNBIKntXedZ\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 64.0, \"Danceability\": 0.774, \"Energy\": 0.706, \"Loudness\": -6.494, \"Speechiness\": 0.355, \"Acousticness\": 0.00163, \"Liveness\": 0.104, \"Tempo\": 152.891, \"Duration (ms)\": 185037.0, \"Valence\": 0.382, \"Chord\": \"D\"}, {\"Index\": 855, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Outta Time (feat. Drake)\", \"Streams\": 7762934, \"Artist\": \"Bryson Tiller\", \"Artist Followers\": 5019909.0, \"Song ID\": \"4SCnCPOUOUXUmCX2uHb3r7\", \"Genre\": \"['kentucky hip hop', 'pop', 'pop rap', 'r&b', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 68.0, \"Danceability\": 0.714, \"Energy\": 0.582, \"Loudness\": -7.272, \"Speechiness\": 0.0808, \"Acousticness\": 0.0129, \"Liveness\": 0.0774, \"Tempo\": 92.819, \"Duration (ms)\": 198822.0, \"Valence\": 0.338, \"Chord\": \"F\"}, {\"Index\": 856, \"Highest Charting Position\": 131, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"My Dawg\", \"Streams\": 6029118, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"42Tohunwlh34o0mgxYx5iq\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 60.0, \"Danceability\": 0.831, \"Energy\": 0.532, \"Loudness\": -5.319, \"Speechiness\": 0.301, \"Acousticness\": 0.0652, \"Liveness\": 0.464, \"Tempo\": 140.105, \"Duration (ms)\": 181716.0, \"Valence\": 0.364, \"Chord\": \"C\"}, {\"Index\": 857, \"Highest Charting Position\": 138, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Snitches & Rats (feat. Young Nudy)\", \"Streams\": 5846760, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"3WaDoMDQRqDdgtCDLxanpN\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 57.0, \"Danceability\": 0.821, \"Energy\": 0.671, \"Loudness\": -5.893, \"Speechiness\": 0.18, \"Acousticness\": 0.00843, \"Liveness\": 0.0972, \"Tempo\": 145.953, \"Duration (ms)\": 187773.0, \"Valence\": 0.494, \"Chord\": \"A\"}, {\"Index\": 858, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Brand New Draco\", \"Streams\": 5841110, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"4V9ynsDPwHtdItksqjuRu0\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 63.0, \"Danceability\": 0.697, \"Energy\": 0.709, \"Loudness\": -6.642, \"Speechiness\": 0.298, \"Acousticness\": 0.041, \"Liveness\": 0.0886, \"Tempo\": 155.023, \"Duration (ms)\": 202420.0, \"Valence\": 0.439, \"Chord\": \"B\"}, {\"Index\": 859, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Lemonade (Feat. Roddy Ricch & Don Toliver) [Remix]\", \"Streams\": 5550390, \"Artist\": \"Internet Money\", \"Artist Followers\": 412466.0, \"Song ID\": \"5sBplhIrmzA4kQGyIOpmDf\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-09-30\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 69.0, \"Danceability\": 0.832, \"Energy\": 0.549, \"Loudness\": -8.259, \"Speechiness\": 0.0602, \"Acousticness\": 0.168, \"Liveness\": 0.11, \"Tempo\": 140.045, \"Duration (ms)\": 181496.0, \"Valence\": 0.384, \"Chord\": \"C#/Db\"}, {\"Index\": 860, \"Highest Charting Position\": 77, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Your Man\", \"Streams\": 5233336, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"6Vgtvd7I5yopJdBuxqjBd2\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-24\", \"Weeks Charted\": \"2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 68.0, \"Danceability\": 0.785, \"Energy\": 0.818, \"Loudness\": -8.711, \"Speechiness\": 0.099, \"Acousticness\": 0.624, \"Liveness\": 0.149, \"Tempo\": 117.98, \"Duration (ms)\": 163759.0, \"Valence\": 0.0503, \"Chord\": \"G\"}, {\"Index\": 861, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"No Opp Left Behind\", \"Streams\": 5154955, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"50I7FNN2rl2rWiNwGxS146\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 61.0, \"Danceability\": 0.823, \"Energy\": 0.703, \"Loudness\": -2.691, \"Speechiness\": 0.298, \"Acousticness\": 0.0161, \"Liveness\": 0.294, \"Tempo\": 178.043, \"Duration (ms)\": 194214.0, \"Valence\": 0.26, \"Chord\": \"G#/Ab\"}, {\"Index\": 862, \"Highest Charting Position\": 106, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Lets Link\", \"Streams\": 5109038, \"Artist\": \"WhoHeem\", \"Artist Followers\": 25417.0, \"Song ID\": \"6fMzgFFGzWCwiHMzDzNpp5\", \"Genre\": \"['viral rap']\", \"Release Date\": \"2020-08-20\", \"Weeks Charted\": \"2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 61.0, \"Danceability\": 0.839, \"Energy\": 0.683, \"Loudness\": -9.232, \"Speechiness\": 0.165, \"Acousticness\": 0.00667, \"Liveness\": 0.241, \"Tempo\": 120.003, \"Duration (ms)\": 159955.0, \"Valence\": 0.522, \"Chord\": \"A#/Bb\"}, {\"Index\": 863, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"RIP Luv\", \"Streams\": 4915080, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"1wGnp7ejkCuXRsehXx0PNP\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 62.0, \"Danceability\": 0.63, \"Energy\": 0.399, \"Loudness\": -9.869, \"Speechiness\": 0.178, \"Acousticness\": 0.105, \"Liveness\": 0.234, \"Tempo\": 183.016, \"Duration (ms)\": 214192.0, \"Valence\": 0.0657, \"Chord\": \"F\"}, {\"Index\": 864, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Steppin On Niggas\", \"Streams\": 4853661, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"7FtZFla3ZH6PqsAJ9MvVCM\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 57.0, \"Danceability\": 0.849, \"Energy\": 0.635, \"Loudness\": -4.068, \"Speechiness\": 0.254, \"Acousticness\": 0.000608, \"Liveness\": 0.062, \"Tempo\": 89.484, \"Duration (ms)\": 140833.0, \"Valence\": 0.798, \"Chord\": \"G\"}, {\"Index\": 865, \"Highest Charting Position\": 58, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Gimme Love\", \"Streams\": 7471309, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"2hfoyc7ve6xM4ZEiNIiU1B\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-04-16\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 69.0, \"Danceability\": 0.482, \"Energy\": 0.631, \"Loudness\": -6.917, \"Speechiness\": 0.0986, \"Acousticness\": 0.696, \"Liveness\": 0.209, \"Tempo\": 126.576, \"Duration (ms)\": 214558.0, \"Valence\": 0.0743, \"Chord\": \"F\"}, {\"Index\": 866, \"Highest Charting Position\": 97, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Ew\", \"Streams\": 6936305, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"7xcUWyLh6fIMsYjoVI7NnZ\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 67.0, \"Danceability\": 0.48, \"Energy\": 0.373, \"Loudness\": -9.297, \"Speechiness\": 0.0278, \"Acousticness\": 0.804, \"Liveness\": 0.12, \"Tempo\": 114.078, \"Duration (ms)\": 207710.0, \"Valence\": 0.0376, \"Chord\": \"A#/Bb\"}, {\"Index\": 867, \"Highest Charting Position\": 99, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Daylight\", \"Streams\": 6819838, \"Artist\": \"Joji, Diplo\", \"Artist Followers\": 4759367.0, \"Song ID\": \"6Ed1q0X8oSKSm4IIhiQbYg\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-08-06\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-08-07--2020-08-14\", \"Popularity\": 72.0, \"Danceability\": 0.528, \"Energy\": 0.749, \"Loudness\": -7.571, \"Speechiness\": 0.0479, \"Acousticness\": 0.00488, \"Liveness\": 0.0949, \"Tempo\": 163.944, \"Duration (ms)\": 163906.0, \"Valence\": 0.729, \"Chord\": \"G\"}, {\"Index\": 868, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Epidemic\", \"Streams\": 6292620, \"Artist\": \"Polo G\", \"Artist Followers\": 4849204.0, \"Song ID\": \"170DNUSnQRp1tGpppF26pA\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 71.0, \"Danceability\": 0.616, \"Energy\": 0.617, \"Loudness\": -8.431, \"Speechiness\": 0.52, \"Acousticness\": 0.128, \"Liveness\": 0.177, \"Tempo\": 175.929, \"Duration (ms)\": 177273.0, \"Valence\": 0.476, \"Chord\": \"C#/Db\"}, {\"Index\": 869, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"bloody valentine\", \"Streams\": 6032935, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3868320.0, \"Song ID\": \"6mADjHs6FXdroPzEGW6KVJ\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 77.0, \"Danceability\": 0.533, \"Energy\": 0.858, \"Loudness\": -4.212, \"Speechiness\": 0.0766, \"Acousticness\": 0.00021, \"Liveness\": 0.148, \"Tempo\": 160.057, \"Duration (ms)\": 205159.0, \"Valence\": 0.506, \"Chord\": \"D\"}, {\"Index\": 870, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"MODUS\", \"Streams\": 6013371, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"5SjtAe7xzUgHDtNTmt8zS7\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 66.0, \"Danceability\": 0.738, \"Energy\": 0.533, \"Loudness\": -7.617, \"Speechiness\": 0.0492, \"Acousticness\": 0.183, \"Liveness\": 0.115, \"Tempo\": 132.008, \"Duration (ms)\": 207265.0, \"Valence\": 0.262, \"Chord\": \"G\"}, {\"Index\": 871, \"Highest Charting Position\": 145, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Tick Tock\", \"Streams\": 5547939, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"5E7p95xh9Ul4vZp4LEoJwi\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 65.0, \"Danceability\": 0.781, \"Energy\": 0.613, \"Loudness\": -5.582, \"Speechiness\": 0.0524, \"Acousticness\": 0.0399, \"Liveness\": 0.0976, \"Tempo\": 80.53, \"Duration (ms)\": 132215.0, \"Valence\": 0.613, \"Chord\": \"E\"}, {\"Index\": 872, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Sanctuary\", \"Streams\": 5482390, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"3xaugmCyXrVkrDTXbFkMW3\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2019-06-14\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 69.0, \"Danceability\": 0.552, \"Energy\": 0.65, \"Loudness\": -7.199, \"Speechiness\": 0.128, \"Acousticness\": 0.422, \"Liveness\": 0.372, \"Tempo\": 167.788, \"Duration (ms)\": 180019.0, \"Valence\": 0.316, \"Chord\": \"C#/Db\"}, {\"Index\": 873, \"Highest Charting Position\": 112, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"feel something\", \"Streams\": 5463424, \"Artist\": \"Bea Miller\", \"Artist Followers\": 2396662.0, \"Song ID\": \"7JDWhC422Gtk1Bq0mL3OTC\", \"Genre\": \"['alt z', 'dance pop', 'electropop', 'indie cafe pop', 'indie poptimism', 'modern rock', 'pop', 'pop rap', 'post-teen pop', 'talent show']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 75.0, \"Danceability\": 0.74, \"Energy\": 0.415, \"Loudness\": -8.914, \"Speechiness\": 0.0707, \"Acousticness\": 0.242, \"Liveness\": 0.319, \"Tempo\": 136.029, \"Duration (ms)\": 180161.0, \"Valence\": 0.156, \"Chord\": \"C\"}, {\"Index\": 874, \"Highest Charting Position\": 86, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Tap In\", \"Streams\": 5220309, \"Artist\": \"Saweetie\", \"Artist Followers\": 1255573.0, \"Song ID\": \"4Hpib09wXgD84w4uwTPnYD\", \"Genre\": \"['cali rap', 'dance pop', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-06-17\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 73.0, \"Danceability\": 0.954, \"Energy\": 0.696, \"Loudness\": -7.117, \"Speechiness\": 0.204, \"Acousticness\": 0.00576, \"Liveness\": 0.0754, \"Tempo\": 100.036, \"Duration (ms)\": 139413.0, \"Valence\": 0.432, \"Chord\": \"A#/Bb\"}, {\"Index\": 875, \"Highest Charting Position\": 171, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Pretty Boy (feat. Lil Yachty)\", \"Streams\": 5141212, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"0f1G5SHFoFC9lO03gHCGVS\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 66.0, \"Danceability\": 0.656, \"Energy\": 0.776, \"Loudness\": -6.184, \"Speechiness\": 0.0672, \"Acousticness\": 0.16, \"Liveness\": 0.372, \"Tempo\": 156.049, \"Duration (ms)\": 156759.0, \"Valence\": 0.638, \"Chord\": \"F#/Gb\"}, {\"Index\": 876, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Afterthought\", \"Streams\": 4977405, \"Artist\": \"Joji, BENEE\", \"Artist Followers\": 4759367.0, \"Song ID\": \"6zvqq50PL7io0rprbkrYc9\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 67.0, \"Danceability\": 0.668, \"Energy\": 0.547, \"Loudness\": -8.024, \"Speechiness\": 0.0353, \"Acousticness\": 0.398, \"Liveness\": 0.0931, \"Tempo\": 83.5, \"Duration (ms)\": 194871.0, \"Valence\": 0.192, \"Chord\": \"C#/Db\"}, {\"Index\": 877, \"Highest Charting Position\": 164, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"+Linda\", \"Streams\": 4964708, \"Artist\": \"Dalex\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-08-28--2020-09-04\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 878, \"Highest Charting Position\": 24, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Over Now (with The Weeknd)\", \"Streams\": 4867620, \"Artist\": \"Calvin Harris\", \"Artist Followers\": 21946934.0, \"Song ID\": \"58AGoOGbwsQMhBbH0eFLRR\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'house', 'pop', 'progressive house', 'uk dance']\", \"Release Date\": \"2020-08-28\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 72.0, \"Danceability\": 0.612, \"Energy\": 0.884, \"Loudness\": -4.113, \"Speechiness\": 0.0454, \"Acousticness\": 0.0759, \"Liveness\": 0.247, \"Tempo\": 178.043, \"Duration (ms)\": 210795.0, \"Valence\": 0.679, \"Chord\": \"E\"}, {\"Index\": 879, \"Highest Charting Position\": 14, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Hate The Other Side (with Marshmello & The Kid Laroi)\", \"Streams\": 4851997, \"Artist\": \"Juice WRLD, Polo G\", \"Artist Followers\": 19102888.0, \"Song ID\": \"0ada5XsQGLPUVbmTCkAP49\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 78.0, \"Danceability\": 0.701, \"Energy\": 0.65, \"Loudness\": -6.313, \"Speechiness\": 0.104, \"Acousticness\": 0.291, \"Liveness\": 0.112, \"Tempo\": 90.003, \"Duration (ms)\": 160212.0, \"Valence\": 0.647, \"Chord\": \"F#/Gb\"}, {\"Index\": 880, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"drunk face\", \"Streams\": 4834258, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3868320.0, \"Song ID\": \"3k0YJnqMKRZb8swo86vCkq\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 72.0, \"Danceability\": 0.691, \"Energy\": 0.77, \"Loudness\": -4.578, \"Speechiness\": 0.0367, \"Acousticness\": 0.0282, \"Liveness\": 0.497, \"Tempo\": 90.024, \"Duration (ms)\": 143901.0, \"Valence\": 0.344, \"Chord\": \"G\"}, {\"Index\": 881, \"Highest Charting Position\": 76, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Tak Tiki Tak\", \"Streams\": 4761286, \"Artist\": \"Harry Nach\", \"Artist Followers\": 134339.0, \"Song ID\": \"7gwwt1IaAWwmB7af0AcuBM\", \"Genre\": \"['trap chileno', 'trap latino']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\", \"Popularity\": 71.0, \"Danceability\": 0.801, \"Energy\": 0.579, \"Loudness\": -4.78, \"Speechiness\": 0.0813, \"Acousticness\": 0.333, \"Liveness\": 0.172, \"Tempo\": 99.994, \"Duration (ms)\": 212406.0, \"Valence\": 0.231, \"Chord\": \"B\"}, {\"Index\": 882, \"Highest Charting Position\": 26, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"WHATS POPPIN\", \"Streams\": 4745752, \"Artist\": \"Jack Harlow\", \"Artist Followers\": 3828418.0, \"Song ID\": \"2MbdDtCv5LUVjYy9RuGTgC\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-06-24\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 80.0, \"Danceability\": 0.904, \"Energy\": 0.723, \"Loudness\": -5.224, \"Speechiness\": 0.26, \"Acousticness\": 0.0631, \"Liveness\": 0.185, \"Tempo\": 145.013, \"Duration (ms)\": 227478.0, \"Valence\": 0.835, \"Chord\": \"B\"}, {\"Index\": 883, \"Highest Charting Position\": 143, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Money Trees\", \"Streams\": 4632724, \"Artist\": \"Kendrick Lamar, Jay Rock\", \"Artist Followers\": 17931101.0, \"Song ID\": \"2HbKqm4o0w5wEeEFXm2sD4\", \"Genre\": \"['conscious hip hop', 'hip hop', 'rap', 'west coast rap']\", \"Release Date\": \"2012\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 75.0, \"Danceability\": 0.716, \"Energy\": 0.531, \"Loudness\": -7.355, \"Speechiness\": 0.122, \"Acousticness\": 0.0703, \"Liveness\": 0.224, \"Tempo\": 71.994, \"Duration (ms)\": 386907.0, \"Valence\": 0.344, \"Chord\": \"G\"}, {\"Index\": 884, \"Highest Charting Position\": 65, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Blastoff (feat. Juice Wrld & Trippie Redd)\", \"Streams\": 4628159, \"Artist\": \"Internet Money, Diplo\", \"Artist Followers\": 412466.0, \"Song ID\": \"2rFsFjq0D9JAmc0APpCO6P\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-08-29\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 70.0, \"Danceability\": 0.761, \"Energy\": 0.517, \"Loudness\": -6.916, \"Speechiness\": 0.0927, \"Acousticness\": 0.114, \"Liveness\": 0.157, \"Tempo\": 147.912, \"Duration (ms)\": 174730.0, \"Valence\": 0.46, \"Chord\": \"F\"}, {\"Index\": 885, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"September\", \"Streams\": 5329256, \"Artist\": \"Earth, Wind & Fire\", \"Artist Followers\": 3008916.0, \"Song ID\": \"2grjqo0Frpf2okIBiifQKs\", \"Genre\": \"['disco', 'funk', 'jazz funk', 'motown', 'quiet storm', 'soul']\", \"Release Date\": \"1978-11-23\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 80.0, \"Danceability\": 0.697, \"Energy\": 0.832, \"Loudness\": -7.264, \"Speechiness\": 0.0298, \"Acousticness\": 0.168, \"Liveness\": 0.269, \"Tempo\": 125.926, \"Duration (ms)\": 215093.0, \"Valence\": 0.979, \"Chord\": \"A\"}, {\"Index\": 886, \"Highest Charting Position\": 64, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Secrets\", \"Streams\": 5178107, \"Artist\": \"Regard, RAYE\", \"Artist Followers\": 152237.0, \"Song ID\": \"66W1rVTnEv86dIkFhoiElg\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop edm', 'slap house', 'tropical house']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 78.0, \"Danceability\": 0.848, \"Energy\": 0.768, \"Loudness\": -5.386, \"Speechiness\": 0.0373, \"Acousticness\": 0.0412, \"Liveness\": 0.195, \"Tempo\": 118.961, \"Duration (ms)\": 176767.0, \"Valence\": 0.777, \"Chord\": \"F#/Gb\"}, {\"Index\": 887, \"Highest Charting Position\": 150, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"21\", \"Streams\": 5151406, \"Artist\": \"Polo G\", \"Artist Followers\": 4849204.0, \"Song ID\": \"3JKgcAa7r07ocVWcV8bS0H\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 80.0, \"Danceability\": 0.783, \"Energy\": 0.479, \"Loudness\": -10.646, \"Speechiness\": 0.541, \"Acousticness\": 0.149, \"Liveness\": 0.101, \"Tempo\": 176.027, \"Duration (ms)\": 163798.0, \"Valence\": 0.533, \"Chord\": \"G\"}, {\"Index\": 888, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"BXL ZOO\", \"Streams\": 5101640, \"Artist\": \"Damso, Hamza\", \"Artist Followers\": 3071170.0, \"Song ID\": \"1VBt9dPtYfLnVeKaa6CQPr\", \"Genre\": \"['belgian hip hop', 'french hip hop', 'pop urbaine', 'rap belge', 'rap conscient']\", \"Release Date\": \"2021-04-28\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 62.0, \"Danceability\": 0.745, \"Energy\": 0.656, \"Loudness\": -6.829, \"Speechiness\": 0.203, \"Acousticness\": 0.0604, \"Liveness\": 0.11, \"Tempo\": 137.997, \"Duration (ms)\": 201333.0, \"Valence\": 0.405, \"Chord\": \"B\"}, {\"Index\": 889, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"DEUX TOILES DE MER\", \"Streams\": 5094137, \"Artist\": \"Damso\", \"Artist Followers\": 3071170.0, \"Song ID\": \"6vw0mOQ5vm3C5RPm7Rvl2w\", \"Genre\": \"['belgian hip hop', 'french hip hop', 'pop urbaine', 'rap belge', 'rap conscient']\", \"Release Date\": \"2021-04-28\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 62.0, \"Danceability\": 0.521, \"Energy\": 0.39, \"Loudness\": -9.726, \"Speechiness\": 0.128, \"Acousticness\": 0.582, \"Liveness\": 0.112, \"Tempo\": 104.106, \"Duration (ms)\": 315640.0, \"Valence\": 0.157, \"Chord\": \"G#/Ab\"}, {\"Index\": 890, \"Highest Charting Position\": 4, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"exile (feat. Bon Iver)\", \"Streams\": 4924533, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"4pvb0WLRcMtbPGmtejJJ6y\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 77.0, \"Danceability\": 0.298, \"Energy\": 0.38, \"Loudness\": -8.426, \"Speechiness\": 0.0287, \"Acousticness\": 0.778, \"Liveness\": 0.11, \"Tempo\": 75.602, \"Duration (ms)\": 285634.0, \"Valence\": 0.152, \"Chord\": \"F#/Gb\"}, {\"Index\": 891, \"Highest Charting Position\": 10, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Righteous\", \"Streams\": 4819362, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5dOxHHMOFAbG3VH23t0xNm\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 78.0, \"Danceability\": 0.706, \"Energy\": 0.625, \"Loudness\": -7.426, \"Speechiness\": 0.0314, \"Acousticness\": 0.0417, \"Liveness\": 0.129, \"Tempo\": 142.948, \"Duration (ms)\": 242181.0, \"Valence\": 0.225, \"Chord\": \"C\"}, {\"Index\": 892, \"Highest Charting Position\": 9, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Conversations\", \"Streams\": 4805366, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4K06PO78fW4mnBVenxGNob\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 75.0, \"Danceability\": 0.747, \"Energy\": 0.622, \"Loudness\": -5.825, \"Speechiness\": 0.0838, \"Acousticness\": 0.176, \"Liveness\": 0.151, \"Tempo\": 159.93, \"Duration (ms)\": 181661.0, \"Valence\": 0.57, \"Chord\": \"B\"}, {\"Index\": 893, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Dolly (with Lil Uzi Vert)\", \"Streams\": 4800543, \"Artist\": \"Lil Tecca\", \"Artist Followers\": 4022792.0, \"Song ID\": \"77Xwqkw7VrV8E5FCq9JhO8\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 63.0, \"Danceability\": 0.664, \"Energy\": 0.586, \"Loudness\": -7.813, \"Speechiness\": 0.238, \"Acousticness\": 0.212, \"Liveness\": 0.216, \"Tempo\": 88.502, \"Duration (ms)\": 179813.0, \"Valence\": 0.589, \"Chord\": \"G\"}, {\"Index\": 894, \"Highest Charting Position\": 23, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Chicago Freestyle (feat. Giveon)\", \"Streams\": 4799038, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"4wVOKKEHUJxHCFFNUWDn0B\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 80.0, \"Danceability\": 0.735, \"Energy\": 0.449, \"Loudness\": -7.507, \"Speechiness\": 0.347, \"Acousticness\": 0.629, \"Liveness\": 0.113, \"Tempo\": 122.947, \"Duration (ms)\": 220488.0, \"Valence\": 0.0397, \"Chord\": \"A#/Bb\"}, {\"Index\": 895, \"Highest Charting Position\": 4, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"GOOBA\", \"Streams\": 4690955, \"Artist\": \"6ix9ine\", \"Artist Followers\": 6514102.0, \"Song ID\": \"4NhDYoQTYCdWHTvlbGVgwo\", \"Genre\": \"['emo rap', 'rap']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 70.0, \"Danceability\": 0.611, \"Energy\": 0.688, \"Loudness\": -5.688, \"Speechiness\": 0.341, \"Acousticness\": 0.0264, \"Liveness\": 0.251, \"Tempo\": 178.462, \"Duration (ms)\": 132303.0, \"Valence\": 0.393, \"Chord\": \"C#/Db\"}, {\"Index\": 896, \"Highest Charting Position\": 12, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Physical\", \"Streams\": 4599807, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3AzjcOeAmA57TIOr9zF1ZW\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 77.0, \"Danceability\": 0.647, \"Energy\": 0.844, \"Loudness\": -3.756, \"Speechiness\": 0.0457, \"Acousticness\": 0.0137, \"Liveness\": 0.102, \"Tempo\": 146.967, \"Duration (ms)\": 193829.0, \"Valence\": 0.746, \"Chord\": \"C\"}, {\"Index\": 897, \"Highest Charting Position\": 194, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Hot Stuff\", \"Streams\": 4569978, \"Artist\": \"Kygo, Donna Summer\", \"Artist Followers\": 7593792.0, \"Song ID\": \"00ETaeHUQ6lops3oWU1Wrt\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 71.0, \"Danceability\": 0.681, \"Energy\": 0.773, \"Loudness\": -5.749, \"Speechiness\": 0.148, \"Acousticness\": 0.019, \"Liveness\": 0.11, \"Tempo\": 119.961, \"Duration (ms)\": 199008.0, \"Valence\": 0.429, \"Chord\": \"F\"}, {\"Index\": 898, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Who's Laughing Now\", \"Streams\": 4526982, \"Artist\": \"Ava Max\", \"Artist Followers\": 3916979.0, \"Song ID\": \"1Pmp486RrLRkaEkE3HFHXP\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 73.0, \"Danceability\": 0.648, \"Energy\": 0.641, \"Loudness\": -5.521, \"Speechiness\": 0.0389, \"Acousticness\": 0.00565, \"Liveness\": 0.109, \"Tempo\": 184.021, \"Duration (ms)\": 180348.0, \"Valence\": 0.505, \"Chord\": \"G\"}, {\"Index\": 899, \"Highest Charting Position\": 91, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Sweet but Psycho\", \"Streams\": 4502853, \"Artist\": \"Ava Max\", \"Artist Followers\": 3916979.0, \"Song ID\": \"7DnAm9FOTWE3cUvso43HhI\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.72, \"Energy\": 0.706, \"Loudness\": -4.719, \"Speechiness\": 0.0473, \"Acousticness\": 0.0684, \"Liveness\": 0.166, \"Tempo\": 133.002, \"Duration (ms)\": 187436.0, \"Valence\": 0.62, \"Chord\": \"C#/Db\"}, {\"Index\": 900, \"Highest Charting Position\": 83, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Del Mar\", \"Streams\": 5698099, \"Artist\": \"Ozuna, Doja Cat, Sia\", \"Artist Followers\": 29238936.0, \"Song ID\": \"5cpJFiNwYyWwFLH0V6B3N8\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 79.0, \"Danceability\": 0.759, \"Energy\": 0.636, \"Loudness\": -5.585, \"Speechiness\": 0.0369, \"Acousticness\": 0.0224, \"Liveness\": 0.166, \"Tempo\": 109.976, \"Duration (ms)\": 214507.0, \"Valence\": 0.536, \"Chord\": \"F#/Gb\"}, {\"Index\": 901, \"Highest Charting Position\": 72, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Hit Different\", \"Streams\": 5049863, \"Artist\": \"SZA, The Neptunes, Pharrell Williams, Ty Dolla $ign\", \"Artist Followers\": 5888533.0, \"Song ID\": \"7Bar1kLTmsRmH6FCKKMEyU\", \"Genre\": \"['pop', 'pop rap', 'r&b']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 74.0, \"Danceability\": 0.679, \"Energy\": 0.516, \"Loudness\": -6.371, \"Speechiness\": 0.0452, \"Acousticness\": 0.199, \"Liveness\": 0.0965, \"Tempo\": 120.074, \"Duration (ms)\": 202008.0, \"Valence\": 0.716, \"Chord\": \"C\"}, {\"Index\": 902, \"Highest Charting Position\": 65, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Nobody's Love\", \"Streams\": 4957966, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32279979.0, \"Song ID\": \"2ST72jD2KVe7f3fbcGyX1b\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 73.0, \"Danceability\": 0.485, \"Energy\": 0.567, \"Loudness\": -6.456, \"Speechiness\": 0.0388, \"Acousticness\": 0.316, \"Liveness\": 0.0949, \"Tempo\": 93.676, \"Duration (ms)\": 211254.0, \"Valence\": 0.157, \"Chord\": \"C#/Db\"}, {\"Index\": 903, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"M\\u00e1quina do Tempo\", \"Streams\": 4938139, \"Artist\": \"Matu\\u00ea\", \"Artist Followers\": 3263283.0, \"Song ID\": \"5oI9blwsXC8AkTWw6wASY8\", \"Genre\": \"['r&b brasileiro', 'rap cearense', 'trap brasileiro']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-09-11--2020-09-18\", \"Popularity\": 70.0, \"Danceability\": 0.629, \"Energy\": 0.727, \"Loudness\": -4.387, \"Speechiness\": 0.0499, \"Acousticness\": 0.0647, \"Liveness\": 0.138, \"Tempo\": 149.978, \"Duration (ms)\": 230400.0, \"Valence\": 0.132, \"Chord\": \"E\"}, {\"Index\": 904, \"Highest Charting Position\": 112, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Fuckst mich nur ab\", \"Streams\": 4898520, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"0y8mJFmm4ogCHnfe0oTuT6\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 63.0, \"Danceability\": 0.817, \"Energy\": 0.468, \"Loudness\": -10.945, \"Speechiness\": 0.287, \"Acousticness\": 0.233, \"Liveness\": 0.0905, \"Tempo\": 104.875, \"Duration (ms)\": 182931.0, \"Valence\": 0.237, \"Chord\": \"C#/Db\"}, {\"Index\": 905, \"Highest Charting Position\": 122, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Jangueo\", \"Streams\": 4877753, \"Artist\": \"Alex Rose, Rafa Pab\\u00f6n\", \"Artist Followers\": 2168452.0, \"Song ID\": \"1bRpSCFv6P2OUhciByeRYR\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 74.0, \"Danceability\": 0.861, \"Energy\": 0.678, \"Loudness\": -4.157, \"Speechiness\": 0.0536, \"Acousticness\": 0.253, \"Liveness\": 0.106, \"Tempo\": 103.994, \"Duration (ms)\": 259600.0, \"Valence\": 0.723, \"Chord\": \"G#/Ab\"}, {\"Index\": 906, \"Highest Charting Position\": 68, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"We Paid (feat. 42 Dugg)\", \"Streams\": 4776686, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"6gxKUmycQX7uyMwJcweFjp\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 76.0, \"Danceability\": 0.926, \"Energy\": 0.542, \"Loudness\": -5.064, \"Speechiness\": 0.293, \"Acousticness\": 0.135, \"Liveness\": 0.0877, \"Tempo\": 135.14, \"Duration (ms)\": 181929.0, \"Valence\": 0.564, \"Chord\": \"C#/Db\"}, {\"Index\": 907, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Ihr Hobby\", \"Streams\": 4723116, \"Artist\": \"Bonez MC, Maxwell\", \"Artist Followers\": 1683006.0, \"Song ID\": \"4aZfvvgfoSfmSZpfwQYzC0\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-09-11--2020-09-18\", \"Popularity\": 59.0, \"Danceability\": 0.774, \"Energy\": 0.814, \"Loudness\": -6.145, \"Speechiness\": 0.0584, \"Acousticness\": 0.204, \"Liveness\": 0.118, \"Tempo\": 109.019, \"Duration (ms)\": 185330.0, \"Valence\": 0.254, \"Chord\": \"A#/Bb\"}, {\"Index\": 908, \"Highest Charting Position\": 150, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"When I Look At You\", \"Streams\": 4652583, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"7ywzEdEuVG1lsjsRCGJfLy\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2009-01-01\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 63.0, \"Danceability\": 0.459, \"Energy\": 0.545, \"Loudness\": -4.874, \"Speechiness\": 0.0282, \"Acousticness\": 0.142, \"Liveness\": 0.105, \"Tempo\": 137.941, \"Duration (ms)\": 248587.0, \"Valence\": 0.194, \"Chord\": \"F#/Gb\"}, {\"Index\": 909, \"Highest Charting Position\": 21, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Boss Bitch\", \"Streams\": 4620838, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"78qd8dvwea0Gosb6Fe6j3k\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-01-23\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 81.0, \"Danceability\": 0.707, \"Energy\": 0.955, \"Loudness\": -4.593, \"Speechiness\": 0.222, \"Acousticness\": 0.127, \"Liveness\": 0.202, \"Tempo\": 125.989, \"Duration (ms)\": 134240.0, \"Valence\": 0.575, \"Chord\": \"A#/Bb\"}, {\"Index\": 910, \"Highest Charting Position\": 142, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Ain't It Different (feat. AJ Tracey & Stormzy)\", \"Streams\": 4602336, \"Artist\": \"Headie One\", \"Artist Followers\": 328877.0, \"Song ID\": \"6NJfIydBMYrXvlaXsFxmc8\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2020-08-20\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 69.0, \"Danceability\": 0.767, \"Energy\": 0.569, \"Loudness\": -6.805, \"Speechiness\": 0.216, \"Acousticness\": 0.00988, \"Liveness\": 0.109, \"Tempo\": 77.052, \"Duration (ms)\": 196363.0, \"Valence\": 0.524, \"Chord\": \"E\"}, {\"Index\": 911, \"Highest Charting Position\": 75, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Some Say - Felix Jaehn Remix\", \"Streams\": 4598325, \"Artist\": \"Nea\", \"Artist Followers\": 38111.0, \"Song ID\": \"7C1trmcQQ5n5RNy4l6ziCv\", \"Genre\": \"['scandipop', 'swedish pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 77.0, \"Danceability\": 0.682, \"Energy\": 0.7, \"Loudness\": -5.591, \"Speechiness\": 0.0397, \"Acousticness\": 0.406, \"Liveness\": 0.174, \"Tempo\": 120.03, \"Duration (ms)\": 186878.0, \"Valence\": 0.637, \"Chord\": \"F#/Gb\"}, {\"Index\": 912, \"Highest Charting Position\": 13, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Savage Remix (feat. Beyonc\\u00e9)\", \"Streams\": 4568308, \"Artist\": \"Beyonc\\u00e9, Megan Thee Stallion\", \"Artist Followers\": 28335112.0, \"Song ID\": \"5v4GgrXPMghOnBBLmveLac\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'r&b']\", \"Release Date\": \"2020-04-29\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 73.0, \"Danceability\": 0.822, \"Energy\": 0.743, \"Loudness\": -4.772, \"Speechiness\": 0.28, \"Acousticness\": 0.016, \"Liveness\": 0.127, \"Tempo\": 84.459, \"Duration (ms)\": 242001.0, \"Valence\": 0.636, \"Chord\": \"A#/Bb\"}, {\"Index\": 913, \"Highest Charting Position\": 115, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Lithuania (feat. Travis Scott)\", \"Streams\": 5949270, \"Artist\": \"Big Sean\", \"Artist Followers\": 8673345.0, \"Song ID\": \"4VLTxHOyFX5FRtkpsFm5Pc\", \"Genre\": \"['detroit hip hop', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-09-04--2020-09-11\", \"Popularity\": 62.0, \"Danceability\": 0.676, \"Energy\": 0.82, \"Loudness\": -5.217, \"Speechiness\": 0.0554, \"Acousticness\": 0.0493, \"Liveness\": 0.615, \"Tempo\": 152.028, \"Duration (ms)\": 199250.0, \"Valence\": 0.618, \"Chord\": \"G\"}, {\"Index\": 914, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Tap In (feat. Post Malone, DaBaby & Jack Harlow)\", \"Streams\": 5117128, \"Artist\": \"Saweetie\", \"Artist Followers\": 1255573.0, \"Song ID\": \"5woaU1FNkqCwg6WzWiQPW5\", \"Genre\": \"['cali rap', 'dance pop', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-08-28\", \"Weeks Charted\": \"2020-09-04--2020-09-11\", \"Popularity\": 64.0, \"Danceability\": 0.948, \"Energy\": 0.63, \"Loudness\": -7.011, \"Speechiness\": 0.219, \"Acousticness\": 0.00647, \"Liveness\": 0.0737, \"Tempo\": 100.032, \"Duration (ms)\": 253569.0, \"Valence\": 0.425, \"Chord\": \"C#/Db\"}, {\"Index\": 915, \"Highest Charting Position\": 91, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Not Shy\", \"Streams\": 4982232, \"Artist\": \"ITZY\", \"Artist Followers\": 2384076.0, \"Song ID\": \"4ecVWqbtW6phQGpZMAyqIU\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2020-08-17\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 73.0, \"Danceability\": 0.776, \"Energy\": 0.911, \"Loudness\": -3.08, \"Speechiness\": 0.131, \"Acousticness\": 0.155, \"Liveness\": 0.268, \"Tempo\": 101.027, \"Duration (ms)\": 177728.0, \"Valence\": 0.56, \"Chord\": \"D\"}, {\"Index\": 916, \"Highest Charting Position\": 71, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"The Plan - From the Motion Picture \\\"TENET\\\"\", \"Streams\": 4876238, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"551xyaSJsg8hILXFq9JdST\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2020-08-22\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 67.0, \"Danceability\": 0.433, \"Energy\": 0.443, \"Loudness\": -10.568, \"Speechiness\": 0.0361, \"Acousticness\": 0.0922, \"Liveness\": 0.117, \"Tempo\": 79.903, \"Duration (ms)\": 185851.0, \"Valence\": 0.0363, \"Chord\": \"C#/Db\"}, {\"Index\": 917, \"Highest Charting Position\": 152, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"ADMV\", \"Streams\": 4737291, \"Artist\": \"Maluma\", \"Artist Followers\": 26784251.0, \"Song ID\": \"3eJMSq78dDaFb7VvhNFnq6\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-04-23\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 72.0, \"Danceability\": 0.565, \"Energy\": 0.39, \"Loudness\": -4.959, \"Speechiness\": 0.0556, \"Acousticness\": 0.817, \"Liveness\": 0.126, \"Tempo\": 163.781, \"Duration (ms)\": 193700.0, \"Valence\": 0.708, \"Chord\": \"A\"}, {\"Index\": 918, \"Highest Charting Position\": 122, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Alane\", \"Streams\": 4668193, \"Artist\": \"Robin Schulz, Wes\", \"Artist Followers\": 2786366.0, \"Song ID\": \"2u6Jm2klS4yvAlbSHlxUwI\", \"Genre\": \"['dance pop', 'deep euro house', 'deep house', 'edm', 'german dance', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 67.0, \"Danceability\": 0.581, \"Energy\": 0.799, \"Loudness\": -6.66, \"Speechiness\": 0.164, \"Acousticness\": 0.0419, \"Liveness\": 0.11, \"Tempo\": 124.002, \"Duration (ms)\": 175016.0, \"Valence\": 0.662, \"Chord\": \"D#/Eb\"}, {\"Index\": 919, \"Highest Charting Position\": 82, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"THE BADDEST\", \"Streams\": 4642057, \"Artist\": \"K/DA, (G)I-DLE, Wolftyla, Bea Miller, League of Legends\", \"Artist Followers\": 1245965.0, \"Song ID\": \"2V4Fx72svQRxrFvNT1eq5f\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2020-08-27\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 70.0, \"Danceability\": 0.676, \"Energy\": 0.857, \"Loudness\": -4.368, \"Speechiness\": 0.0438, \"Acousticness\": 0.0215, \"Liveness\": 0.254, \"Tempo\": 149.981, \"Duration (ms)\": 162600.0, \"Valence\": 0.717, \"Chord\": \"A#/Bb\"}, {\"Index\": 920, \"Highest Charting Position\": 112, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Desce Pro Play (PA PA PA)\", \"Streams\": 4615520, \"Artist\": \"Mc Zaac, Anitta, Tyga\", \"Artist Followers\": 1555628.0, \"Song ID\": \"4zGtfOglDBfVUypabBwIjQ\", \"Genre\": \"['funk carioca', 'funk pop']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 68.0, \"Danceability\": 0.935, \"Energy\": 0.71, \"Loudness\": -5.085, \"Speechiness\": 0.158, \"Acousticness\": 0.0769, \"Liveness\": 0.173, \"Tempo\": 100.009, \"Duration (ms)\": 168507.0, \"Valence\": 0.635, \"Chord\": \"B\"}, {\"Index\": 921, \"Highest Charting Position\": 103, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Mariposa\", \"Streams\": 4593366, \"Artist\": \"Peach Tree Rascals\", \"Artist Followers\": 177972.0, \"Song ID\": \"4ja2gzrNh9VNigzoXfmbwD\", \"Genre\": \"['alternative r&b', 'chill r&b', 'indie r&b', 'pop']\", \"Release Date\": \"2019-08-28\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 76.0, \"Danceability\": 0.676, \"Energy\": 0.525, \"Loudness\": -5.88, \"Speechiness\": 0.028, \"Acousticness\": 0.617, \"Liveness\": 0.356, \"Tempo\": 112.011, \"Duration (ms)\": 210000.0, \"Valence\": 0.421, \"Chord\": \"A\"}, {\"Index\": 922, \"Highest Charting Position\": 5, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"the 1\", \"Streams\": 4587573, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0Jlcvv8IykzHaSmj49uNW8\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 75.0, \"Danceability\": 0.777, \"Energy\": 0.357, \"Loudness\": -6.942, \"Speechiness\": 0.0522, \"Acousticness\": 0.757, \"Liveness\": 0.108, \"Tempo\": 139.883, \"Duration (ms)\": 210252.0, \"Valence\": 0.172, \"Chord\": \"C\"}, {\"Index\": 923, \"Highest Charting Position\": 11, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"RITMO (Bad Boys For Life)\", \"Streams\": 4585895, \"Artist\": \"Black Eyed Peas, J Balvin\", \"Artist Followers\": 5966748.0, \"Song ID\": \"6cy3ki60hLwimwIje7tALf\", \"Genre\": \"['dance pop', 'pop', 'pop rap']\", \"Release Date\": \"2019-10-12\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.721, \"Energy\": 0.716, \"Loudness\": -7.037, \"Speechiness\": 0.0657, \"Acousticness\": 0.0334, \"Liveness\": 0.237, \"Tempo\": 104.994, \"Duration (ms)\": 221714.0, \"Valence\": 0.667, \"Chord\": \"A#/Bb\"}, {\"Index\": 924, \"Highest Charting Position\": 134, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Unterwegs\", \"Streams\": 4572706, \"Artist\": \"KitschKrieg, Jamule, SFR\", \"Artist Followers\": 166517.0, \"Song ID\": \"7mrWTjhYctgEQb0lJKrVWy\", \"Genre\": \"['german hip hop', 'german pop', 'hamburg hip hop']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 68.0, \"Danceability\": 0.88, \"Energy\": 0.607, \"Loudness\": -7.067, \"Speechiness\": 0.0777, \"Acousticness\": 0.195, \"Liveness\": 0.15, \"Tempo\": 126.039, \"Duration (ms)\": 233905.0, \"Valence\": 0.823, \"Chord\": \"F#/Gb\"}, {\"Index\": 925, \"Highest Charting Position\": 86, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"What's Love Got to Do with It\", \"Streams\": 4538382, \"Artist\": \"Kygo, Tina Turner\", \"Artist Followers\": 7593792.0, \"Song ID\": \"3Be7CLdHZpyzsVijme39cW\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-07-17\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 74.0, \"Danceability\": 0.75, \"Energy\": 0.664, \"Loudness\": -5.908, \"Speechiness\": 0.154, \"Acousticness\": 0.275, \"Liveness\": 0.0632, \"Tempo\": 105.023, \"Duration (ms)\": 208156.0, \"Valence\": 0.617, \"Chord\": \"G#/Ab\"}, {\"Index\": 926, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Cry About It Later\", \"Streams\": 5306994, \"Artist\": \"Katy Perry\", \"Artist Followers\": 18936929.0, \"Song ID\": \"43WYPxyEfIxlIjNlxQGYzc\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2020-08-28--2020-09-04\", \"Popularity\": 67.0, \"Danceability\": 0.676, \"Energy\": 0.794, \"Loudness\": -4.78, \"Speechiness\": 0.0366, \"Acousticness\": 0.0513, \"Liveness\": 0.0723, \"Tempo\": 125.957, \"Duration (ms)\": 159286.0, \"Valence\": 0.161, \"Chord\": \"D\"}, {\"Index\": 927, \"Highest Charting Position\": 71, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Banana (feat. Shaggy) - DJ FLe - Minisiren Remix\", \"Streams\": 4624448, \"Artist\": \"Conkarah\", \"Artist Followers\": 67074.0, \"Song ID\": \"0dZpw3h6KZhcHec61qwevZ\", \"Genre\": \"['jawaiian']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 70.0, \"Danceability\": 0.824, \"Energy\": 0.854, \"Loudness\": -5.312, \"Speechiness\": 0.177, \"Acousticness\": 0.016, \"Liveness\": 0.117, \"Tempo\": 95.114, \"Duration (ms)\": 210329.0, \"Valence\": 0.896, \"Chord\": \"G#/Ab\"}, {\"Index\": 928, \"Highest Charting Position\": 185, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Gifted (feat. Roddy Ricch)\", \"Streams\": 4609169, \"Artist\": \"Cordae\", \"Artist Followers\": 1492551.0, \"Song ID\": \"0mb3uDw5vfFUcZfJYFOMRu\", \"Genre\": \"['dmv rap', 'hip hop', 'pop rap', 'rap', 'trap', 'underground hip hop', 'vapor trap']\", \"Release Date\": \"2020-08-27\", \"Weeks Charted\": \"2020-08-28--2020-09-04\", \"Popularity\": 65.0, \"Danceability\": 0.653, \"Energy\": 0.603, \"Loudness\": -5.697, \"Speechiness\": 0.171, \"Acousticness\": 0.175, \"Liveness\": 0.18, \"Tempo\": 151.016, \"Duration (ms)\": 168477.0, \"Valence\": 0.551, \"Chord\": \"F\"}, {\"Index\": 929, \"Highest Charting Position\": 27, \"Number of Times Charted\": 36, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"OUT WEST (feat. Young Thug)\", \"Streams\": 4597001, \"Artist\": \"JACKBOYS, Travis Scott\", \"Artist Followers\": 437907.0, \"Song ID\": \"6gi6y1xwmVszDWkUqab1qw\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.802, \"Energy\": 0.591, \"Loudness\": -4.895, \"Speechiness\": 0.225, \"Acousticness\": 0.0104, \"Liveness\": 0.196, \"Tempo\": 139.864, \"Duration (ms)\": 157712.0, \"Valence\": 0.309, \"Chord\": \"G#/Ab\"}, {\"Index\": 930, \"Highest Charting Position\": 174, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Anaranjado\", \"Streams\": 4575403, \"Artist\": \"Jowell & Randy, J Balvin\", \"Artist Followers\": 2919696.0, \"Song ID\": \"5iw28wvyHgj4ppOu5AdcEU\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-07-16\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 66.0, \"Danceability\": 0.763, \"Energy\": 0.58, \"Loudness\": -6.196, \"Speechiness\": 0.144, \"Acousticness\": 0.0466, \"Liveness\": 0.154, \"Tempo\": 175.937, \"Duration (ms)\": 212011.0, \"Valence\": 0.608, \"Chord\": \"G#/Ab\"}, {\"Index\": 931, \"Highest Charting Position\": 111, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Reggaetonera\", \"Streams\": 4564331, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"6yVkakCN460KOVol9ZazjH\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-05-29--2020-06-05\", \"Popularity\": 69.0, \"Danceability\": 0.694, \"Energy\": 0.796, \"Loudness\": -4.164, \"Speechiness\": 0.0565, \"Acousticness\": 0.48, \"Liveness\": 0.108, \"Tempo\": 93.064, \"Duration (ms)\": 212312.0, \"Valence\": 0.515, \"Chord\": \"F#/Gb\"}, {\"Index\": 932, \"Highest Charting Position\": 5, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Sour Candy (with BLACKPINK)\", \"Streams\": 4556900, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"6R6ZoHTypt5lt68MWbzZXv\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-28\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 70.0, \"Danceability\": 0.752, \"Energy\": 0.87, \"Loudness\": -3.812, \"Speechiness\": 0.0623, \"Acousticness\": 0.0604, \"Liveness\": 0.489, \"Tempo\": 120.006, \"Duration (ms)\": 157707.0, \"Valence\": 0.784, \"Chord\": \"A\"}, {\"Index\": 933, \"Highest Charting Position\": 113, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Rags2Riches 2 (feat. Lil Baby)\", \"Streams\": 4547965, \"Artist\": \"Rod Wave\", \"Artist Followers\": 2203386.0, \"Song ID\": \"40TPiJpvwGIyvPjJMDTKfy\", \"Genre\": \"['florida rap']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 60.0, \"Danceability\": 0.874, \"Energy\": 0.443, \"Loudness\": -9.628, \"Speechiness\": 0.241, \"Acousticness\": 0.147, \"Liveness\": 0.124, \"Tempo\": 118.004, \"Duration (ms)\": 235988.0, \"Valence\": 0.298, \"Chord\": \"F\"}, {\"Index\": 934, \"Highest Charting Position\": 31, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Bandit (with YoungBoy Never Broke Again)\", \"Streams\": 4514763, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"6Gg1gjgKi2AK4e0qzsR7sd\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.474, \"Energy\": 0.631, \"Loudness\": -5.884, \"Speechiness\": 0.343, \"Acousticness\": 0.0687, \"Liveness\": 0.132, \"Tempo\": 180.051, \"Duration (ms)\": 189323.0, \"Valence\": 0.425, \"Chord\": \"F\"}, {\"Index\": 935, \"Highest Charting Position\": 117, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"PAM\", \"Streams\": 4501441, \"Artist\": \"Justin Quiles, Daddy Yankee, El Alfa\", \"Artist Followers\": 2897862.0, \"Song ID\": \"0eeKDrQxjqNl5bX5VCHDcn\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 73.0, \"Danceability\": 0.889, \"Energy\": 0.863, \"Loudness\": -3.011, \"Speechiness\": 0.0757, \"Acousticness\": 0.289, \"Liveness\": 0.0798, \"Tempo\": 112.953, \"Duration (ms)\": 201000.0, \"Valence\": 0.776, \"Chord\": \"B\"}, {\"Index\": 936, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Lemonade\", \"Streams\": 11373347, \"Artist\": \"Internet Money, Gunna, Don Toliver, NAV\", \"Artist Followers\": 412466.0, \"Song ID\": \"02kDW379Yfd5PzW5A6vuGt\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 82.0, \"Danceability\": 0.799, \"Energy\": 0.66, \"Loudness\": -6.153, \"Speechiness\": 0.079, \"Acousticness\": 0.256, \"Liveness\": 0.111, \"Tempo\": 140.04, \"Duration (ms)\": 195429.0, \"Valence\": 0.471, \"Chord\": \"C#/Db\"}, {\"Index\": 937, \"Highest Charting Position\": 145, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Fr\\u00fchst\\u00fcck in Paris\", \"Streams\": 5440253, \"Artist\": \"Capital Bra, Cro\", \"Artist Followers\": 4093115.0, \"Song ID\": \"1ddbNJwDjjmCYz1GFGYnsw\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-09-17\", \"Weeks Charted\": \"2020-08-21--2020-08-28\", \"Popularity\": 56.0, \"Danceability\": 0.744, \"Energy\": 0.644, \"Loudness\": -5.562, \"Speechiness\": 0.0641, \"Acousticness\": 0.229, \"Liveness\": 0.204, \"Tempo\": 96.852, \"Duration (ms)\": 151360.0, \"Valence\": 0.577, \"Chord\": \"G#/Ab\"}, {\"Index\": 938, \"Highest Charting Position\": 22, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"ON\", \"Streams\": 5391018, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"2QyuXBcV1LJ2rq01KhreMF\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 77.0, \"Danceability\": 0.583, \"Energy\": 0.817, \"Loudness\": -5.146, \"Speechiness\": 0.0987, \"Acousticness\": 0.118, \"Liveness\": 0.338, \"Tempo\": 105.936, \"Duration (ms)\": 246381.0, \"Valence\": 0.438, \"Chord\": \"A\"}, {\"Index\": 939, \"Highest Charting Position\": 106, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"My Oasis (feat. Burna Boy)\", \"Streams\": 4887204, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"2KoHxhRyWxJzA0VafWd5Nk\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-07-30\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 69.0, \"Danceability\": 0.691, \"Energy\": 0.474, \"Loudness\": -8.742, \"Speechiness\": 0.0583, \"Acousticness\": 0.569, \"Liveness\": 0.099, \"Tempo\": 143.783, \"Duration (ms)\": 179917.0, \"Valence\": 0.381, \"Chord\": \"A#/Bb\"}, {\"Index\": 940, \"Highest Charting Position\": 8, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Life's A Mess (feat. Halsey)\", \"Streams\": 4883202, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5wWAwzGp2OaaoIkwcz6wZs\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 74.0, \"Danceability\": 0.63, \"Energy\": 0.446, \"Loudness\": -8.9, \"Speechiness\": 0.0351, \"Acousticness\": 0.337, \"Liveness\": 0.166, \"Tempo\": 143.078, \"Duration (ms)\": 202193.0, \"Valence\": 0.177, \"Chord\": \"C#/Db\"}, {\"Index\": 941, \"Highest Charting Position\": 56, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"PORFA\", \"Streams\": 4702117, \"Artist\": \"Feid, Justin Quiles\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5PwAiSk3ufe0YwOHRFPHEG\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 0.0, \"Danceability\": 0.843, \"Energy\": 0.549, \"Loudness\": -8.018, \"Speechiness\": 0.164, \"Acousticness\": 0.0948, \"Liveness\": 0.155, \"Tempo\": 83.982, \"Duration (ms)\": 233000.0, \"Valence\": 0.542, \"Chord\": \"F#/Gb\"}, {\"Index\": 942, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"2012\", \"Streams\": 4685894, \"Artist\": \"Bausa, Juju\", \"Artist Followers\": 961181.0, \"Song ID\": \"6bM4daGlfZHtKMQp8tEqVz\", \"Genre\": \"['german hip hop', 'german pop']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-08-21--2020-08-28\", \"Popularity\": 62.0, \"Danceability\": 0.805, \"Energy\": 0.619, \"Loudness\": -7.907, \"Speechiness\": 0.0771, \"Acousticness\": 0.218, \"Liveness\": 0.114, \"Tempo\": 98.995, \"Duration (ms)\": 170200.0, \"Valence\": 0.476, \"Chord\": \"F\"}, {\"Index\": 943, \"Highest Charting Position\": 11, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"august\", \"Streams\": 4586236, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3hUxzQpSfdDqwM3ZTFQY0K\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 76.0, \"Danceability\": 0.532, \"Energy\": 0.623, \"Loudness\": -9.208, \"Speechiness\": 0.0331, \"Acousticness\": 0.538, \"Liveness\": 0.0925, \"Tempo\": 89.937, \"Duration (ms)\": 261923.0, \"Valence\": 0.403, \"Chord\": \"F\"}, {\"Index\": 944, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"if i were u (with Lauv)\", \"Streams\": 4561189, \"Artist\": \"blackbear\", \"Artist Followers\": 4272745.0, \"Song ID\": \"0CF1RH8dQKuK2lQPSQw2lZ\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2020-08-19\", \"Weeks Charted\": \"2020-08-21--2020-08-28\", \"Popularity\": 64.0, \"Danceability\": 0.666, \"Energy\": 0.628, \"Loudness\": -5.613, \"Speechiness\": 0.0623, \"Acousticness\": 0.144, \"Liveness\": 0.189, \"Tempo\": 82.992, \"Duration (ms)\": 186468.0, \"Valence\": 0.767, \"Chord\": \"G#/Ab\"}, {\"Index\": 945, \"Highest Charting Position\": 37, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Ballin' (with Roddy Ricch)\", \"Streams\": 4436934, \"Artist\": \"Mustard\", \"Artist Followers\": 881797.0, \"Song ID\": \"3QzAOrNlsabgbMwlZt7TAY\", \"Genre\": \"['cali rap', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.809, \"Energy\": 0.545, \"Loudness\": -6.678, \"Speechiness\": 0.0735, \"Acousticness\": 0.392, \"Liveness\": 0.151, \"Tempo\": 97.008, \"Duration (ms)\": 180435.0, \"Valence\": 0.244, \"Chord\": \"G\"}, {\"Index\": 946, \"Highest Charting Position\": 72, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Stay Gold\", \"Streams\": 4405338, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3Ys2PYl1wyPKQIwyqhP9cQ\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-07-14\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-07-10--2020-07-17\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 73.0, \"Danceability\": 0.723, \"Energy\": 0.634, \"Loudness\": -5.415, \"Speechiness\": 0.0542, \"Acousticness\": 0.0892, \"Liveness\": 0.0787, \"Tempo\": 129.017, \"Duration (ms)\": 243267.0, \"Valence\": 0.582, \"Chord\": \"C#/Db\"}, {\"Index\": 947, \"Highest Charting Position\": 186, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"I'm Yours\", \"Streams\": 4391666, \"Artist\": \"Jason Mraz\", \"Artist Followers\": 6167871.0, \"Song ID\": \"1EzrEOXmMH3G43AXT1y7pA\", \"Genre\": \"['acoustic pop', 'neo mellow', 'pop', 'pop rock']\", \"Release Date\": \"2008-05-12\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\", \"Popularity\": 80.0, \"Danceability\": 0.686, \"Energy\": 0.457, \"Loudness\": -8.322, \"Speechiness\": 0.0468, \"Acousticness\": 0.595, \"Liveness\": 0.105, \"Tempo\": 150.953, \"Duration (ms)\": 242187.0, \"Valence\": 0.718, \"Chord\": \"B\"}, {\"Index\": 948, \"Highest Charting Position\": 136, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Youngblood\", \"Streams\": 4390823, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"2iUXsYOEPhVqEBwsqP70rE\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-06-15\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.596, \"Energy\": 0.854, \"Loudness\": -5.114, \"Speechiness\": 0.463, \"Acousticness\": 0.0169, \"Liveness\": 0.124, \"Tempo\": 120.274, \"Duration (ms)\": 203418.0, \"Valence\": 0.152, \"Chord\": \"G\"}, {\"Index\": 949, \"Highest Charting Position\": 8, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"the last great american dynasty\", \"Streams\": 4389670, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2Eeur20xVqfUoM3Q7EFPFt\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.686, \"Energy\": 0.662, \"Loudness\": -8.505, \"Speechiness\": 0.0413, \"Acousticness\": 0.467, \"Liveness\": 0.109, \"Tempo\": 147.922, \"Duration (ms)\": 230999.0, \"Valence\": 0.706, \"Chord\": \"G\"}, {\"Index\": 950, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Levitating (feat. Madonna and Missy Elliott) [The Blessed Madonna Remix]\", \"Streams\": 5254969, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"0pk1hxhJLBSZZ5RKBhcwOa\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-08-13\", \"Weeks Charted\": \"2020-08-14--2020-08-21\", \"Popularity\": 62.0, \"Danceability\": 0.808, \"Energy\": 0.655, \"Loudness\": -7.34, \"Speechiness\": 0.139, \"Acousticness\": 0.0373, \"Liveness\": 0.208, \"Tempo\": 116.029, \"Duration (ms)\": 250280.0, \"Valence\": 0.56, \"Chord\": \"B\"}, {\"Index\": 951, \"Highest Charting Position\": 10, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"my tears ricochet\", \"Streams\": 5111416, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1MgV7FIyNxIG7WzMRJV5HC\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.456, \"Energy\": 0.263, \"Loudness\": -10.63, \"Speechiness\": 0.0332, \"Acousticness\": 0.806, \"Liveness\": 0.0749, \"Tempo\": 129.86, \"Duration (ms)\": 255894.0, \"Valence\": 0.111, \"Chord\": \"C\"}, {\"Index\": 952, \"Highest Charting Position\": 59, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Rags2Riches (feat. ATR Son Son)\", \"Streams\": 4737306, \"Artist\": \"Rod Wave\", \"Artist Followers\": 2203386.0, \"Song ID\": \"0qg0GJp7HSewRCVPP4fKGk\", \"Genre\": \"['florida rap']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 55.0, \"Danceability\": 0.904, \"Energy\": 0.26, \"Loudness\": -17.57, \"Speechiness\": 0.101, \"Acousticness\": 0.277, \"Liveness\": 0.121, \"Tempo\": 117.967, \"Duration (ms)\": 167147.0, \"Valence\": 0.231, \"Chord\": \"F\"}, {\"Index\": 953, \"Highest Charting Position\": 79, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Flex (feat. Juice WRLD)\", \"Streams\": 4664281, \"Artist\": \"Polo G\", \"Artist Followers\": 4849204.0, \"Song ID\": \"2QqJTIlGKRLJC3onkavYEz\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 76.0, \"Danceability\": 0.752, \"Energy\": 0.673, \"Loudness\": -5.792, \"Speechiness\": 0.153, \"Acousticness\": 0.0538, \"Liveness\": 0.133, \"Tempo\": 164.009, \"Duration (ms)\": 163902.0, \"Valence\": 0.35, \"Chord\": \"A#/Bb\"}, {\"Index\": 954, \"Highest Charting Position\": 77, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Rover (feat. DTG)\", \"Streams\": 4488631, \"Artist\": \"S1mba\", \"Artist Followers\": 46992.0, \"Song ID\": \"4slSrbTK1sNK4I1mDYEthf\", \"Genre\": \"['afroswing', 'social media pop']\", \"Release Date\": \"2020-03-04\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 73.0, \"Danceability\": 0.613, \"Energy\": 0.624, \"Loudness\": -6.66, \"Speechiness\": 0.206, \"Acousticness\": 0.496, \"Liveness\": 0.283, \"Tempo\": 62.948, \"Duration (ms)\": 167917.0, \"Valence\": 0.804, \"Chord\": \"B\"}, {\"Index\": 955, \"Highest Charting Position\": 74, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Only You Freestyle\", \"Streams\": 4480780, \"Artist\": \"Headie One, Drake\", \"Artist Followers\": 328877.0, \"Song ID\": \"4OENnoidV0h8gJV6bhrw7r\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2020-07-20\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 68.0, \"Danceability\": 0.68, \"Energy\": 0.826, \"Loudness\": -2.561, \"Speechiness\": 0.27, \"Acousticness\": 0.562, \"Liveness\": 0.254, \"Tempo\": 146.95, \"Duration (ms)\": 248937.0, \"Valence\": 0.804, \"Chord\": \"F\"}, {\"Index\": 956, \"Highest Charting Position\": 55, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Hallucinate\", \"Streams\": 4472669, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"1nYeVF5vIBxMxfPoL0SIWg\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 72.0, \"Danceability\": 0.627, \"Energy\": 0.69, \"Loudness\": -5.396, \"Speechiness\": 0.139, \"Acousticness\": 0.033, \"Liveness\": 0.0742, \"Tempo\": 122.053, \"Duration (ms)\": 208505.0, \"Valence\": 0.627, \"Chord\": \"A#/Bb\"}, {\"Index\": 957, \"Highest Charting Position\": 100, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"El Efecto\", \"Streams\": 4466143, \"Artist\": \"Rauw Alejandro, Chencho Corleone\", \"Artist Followers\": 6096559.0, \"Song ID\": \"4SJHHpKhcuXwDsCsPqshXj\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2019-03-15\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 76.0, \"Danceability\": 0.849, \"Energy\": 0.781, \"Loudness\": -4.635, \"Speechiness\": 0.159, \"Acousticness\": 0.406, \"Liveness\": 0.0801, \"Tempo\": 84.041, \"Duration (ms)\": 217143.0, \"Valence\": 0.893, \"Chord\": \"C\"}, {\"Index\": 958, \"Highest Charting Position\": 176, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Co\\u00f1o\", \"Streams\": 4462411, \"Artist\": \"Jason Derulo, Puri, Jhorrmountain\", \"Artist Followers\": 9778632.0, \"Song ID\": \"5DV4ZSCqbFv74ui3ZhimXo\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 69.0, \"Danceability\": 0.899, \"Energy\": 0.528, \"Loudness\": -5.442, \"Speechiness\": 0.181, \"Acousticness\": 0.000554, \"Liveness\": 0.105, \"Tempo\": 100.037, \"Duration (ms)\": 111852.0, \"Valence\": 0.456, \"Chord\": \"A\"}, {\"Index\": 959, \"Highest Charting Position\": 126, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Jolie nana\", \"Streams\": 4449437, \"Artist\": \"Aya Nakamura\", \"Artist Followers\": 2953525.0, \"Song ID\": \"65RWVU6N81CeH65nu52K1U\", \"Genre\": \"['basshall', 'francoton']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 69.0, \"Danceability\": 0.813, \"Energy\": 0.64, \"Loudness\": -5.908, \"Speechiness\": 0.272, \"Acousticness\": 0.269, \"Liveness\": 0.131, \"Tempo\": 92.989, \"Duration (ms)\": 147076.0, \"Valence\": 0.488, \"Chord\": \"D\"}, {\"Index\": 960, \"Highest Charting Position\": 189, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Lovefool\", \"Streams\": 4439790, \"Artist\": \"twocolors\", \"Artist Followers\": 36369.0, \"Song ID\": \"51Of5p3lKZeOg6itfs4og4\", \"Genre\": \"['edm', 'pop dance', 'pop edm', 'tropical house']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 79.0, \"Danceability\": 0.677, \"Energy\": 0.766, \"Loudness\": -6.896, \"Speechiness\": 0.0568, \"Acousticness\": 0.0219, \"Liveness\": 0.129, \"Tempo\": 123.062, \"Duration (ms)\": 190488.0, \"Valence\": 0.198, \"Chord\": \"F#/Gb\"}, {\"Index\": 961, \"Highest Charting Position\": 17, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"invisible string\", \"Streams\": 4424118, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6VsvKPJ4xjVNKpI8VVZ3SV\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.653, \"Energy\": 0.452, \"Loudness\": -11.143, \"Speechiness\": 0.055, \"Acousticness\": 0.838, \"Liveness\": 0.108, \"Tempo\": 83.433, \"Duration (ms)\": 252881.0, \"Valence\": 0.45, \"Chord\": \"E\"}, {\"Index\": 962, \"Highest Charting Position\": 118, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Higher Love\", \"Streams\": 4392936, \"Artist\": \"Kygo, Whitney Houston\", \"Artist Followers\": 7593792.0, \"Song ID\": \"6oJ6le65B3SEqPwMRNXWjY\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.693, \"Energy\": 0.678, \"Loudness\": -7.159, \"Speechiness\": 0.0324, \"Acousticness\": 0.0151, \"Liveness\": 0.101, \"Tempo\": 103.952, \"Duration (ms)\": 228267.0, \"Valence\": 0.404, \"Chord\": \"G#/Ab\"}, {\"Index\": 963, \"Highest Charting Position\": 185, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Como Llora\", \"Streams\": 4380308, \"Artist\": \"Juanfran\", \"Artist Followers\": 117894.0, \"Song ID\": \"52zq2a71SGs3f1vJuv59ui\", \"Genre\": \"['dominican pop', 'pop reggaeton', 'urbano espanol']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 67.0, \"Danceability\": 0.827, \"Energy\": 0.629, \"Loudness\": -3.966, \"Speechiness\": 0.185, \"Acousticness\": 0.183, \"Liveness\": 0.084, \"Tempo\": 88.064, \"Duration (ms)\": 187500.0, \"Valence\": 0.486, \"Chord\": \"F#/Gb\"}, {\"Index\": 964, \"Highest Charting Position\": 50, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Walk Em Down (feat. Roddy Ricch)\", \"Streams\": 4371370, \"Artist\": \"NLE Choppa\", \"Artist Followers\": 6608815.0, \"Song ID\": \"4cSSL3YafYjM3yjgFO1vJg\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 74.0, \"Danceability\": 0.867, \"Energy\": 0.744, \"Loudness\": -5.171, \"Speechiness\": 0.227, \"Acousticness\": 0.268, \"Liveness\": 0.0713, \"Tempo\": 84.005, \"Duration (ms)\": 173288.0, \"Valence\": 0.645, \"Chord\": \"D\"}, {\"Index\": 965, \"Highest Charting Position\": 74, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Wow.\", \"Streams\": 4351784, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"7xQAfvXzm3AkraOtGPWIZg\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.829, \"Energy\": 0.539, \"Loudness\": -7.359, \"Speechiness\": 0.208, \"Acousticness\": 0.136, \"Liveness\": 0.103, \"Tempo\": 99.96, \"Duration (ms)\": 149547.0, \"Valence\": 0.388, \"Chord\": \"B\"}, {\"Index\": 966, \"Highest Charting Position\": 13, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"mirrorball\", \"Streams\": 5564072, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0ZNU020wNYvgW84iljPkPP\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.553, \"Energy\": 0.413, \"Loudness\": -10.037, \"Speechiness\": 0.0334, \"Acousticness\": 0.687, \"Liveness\": 0.0594, \"Tempo\": 110.107, \"Duration (ms)\": 208978.0, \"Valence\": 0.379, \"Chord\": \"D\"}, {\"Index\": 967, \"Highest Charting Position\": 15, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"seven\", \"Streams\": 5459423, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6KJqZcs9XDgVck7Lg9QOTC\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 69.0, \"Danceability\": 0.596, \"Energy\": 0.488, \"Loudness\": -10.769, \"Speechiness\": 0.0274, \"Acousticness\": 0.9, \"Liveness\": 0.091, \"Tempo\": 94.926, \"Duration (ms)\": 208907.0, \"Valence\": 0.415, \"Chord\": \"E\"}, {\"Index\": 968, \"Highest Charting Position\": 18, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"this is me trying\", \"Streams\": 5128412, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7kt9e9LFSpN1zQtYEl19o1\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.515, \"Energy\": 0.476, \"Loudness\": -9.843, \"Speechiness\": 0.0328, \"Acousticness\": 0.314, \"Liveness\": 0.171, \"Tempo\": 135.886, \"Duration (ms)\": 195097.0, \"Valence\": 0.412, \"Chord\": \"A\"}, {\"Index\": 969, \"Highest Charting Position\": 24, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"betty\", \"Streams\": 5112180, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5kI4eCXXzyuIUXjQra0Cxi\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.593, \"Energy\": 0.377, \"Loudness\": -8.761, \"Speechiness\": 0.0253, \"Acousticness\": 0.6, \"Liveness\": 0.0976, \"Tempo\": 95.939, \"Duration (ms)\": 294521.0, \"Valence\": 0.502, \"Chord\": \"C\"}, {\"Index\": 970, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"BLIND (feat. Young Thug)\", \"Streams\": 5074613, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"2T5NBwKRySiCR78vVk08vr\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-08-04\", \"Weeks Charted\": \"2020-08-07--2020-08-14\", \"Popularity\": 69.0, \"Danceability\": 0.709, \"Energy\": 0.679, \"Loudness\": -6.503, \"Speechiness\": 0.346, \"Acousticness\": 0.0115, \"Liveness\": 0.0971, \"Tempo\": 162.973, \"Duration (ms)\": 153467.0, \"Valence\": 0.754, \"Chord\": \"B\"}, {\"Index\": 971, \"Highest Charting Position\": 20, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"illicit affairs\", \"Streams\": 5053658, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2NmsngXHeC1GQ9wWrzhOMf\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.559, \"Energy\": 0.31, \"Loudness\": -10.445, \"Speechiness\": 0.0338, \"Acousticness\": 0.881, \"Liveness\": 0.106, \"Tempo\": 119.845, \"Duration (ms)\": 190898.0, \"Valence\": 0.46, \"Chord\": \"A#/Bb\"}, {\"Index\": 972, \"Highest Charting Position\": 170, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Freak\", \"Streams\": 4736059, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"3aA6xB0tOilDDX17fIJ0Bl\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2020-08-07--2020-08-14\", \"Popularity\": 75.0, \"Danceability\": 0.688, \"Energy\": 0.716, \"Loudness\": -5.702, \"Speechiness\": 0.0385, \"Acousticness\": 0.0969, \"Liveness\": 0.0989, \"Tempo\": 116.912, \"Duration (ms)\": 284480.0, \"Valence\": 0.373, \"Chord\": \"G\"}, {\"Index\": 973, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"PUNANI\", \"Streams\": 4625985, \"Artist\": \"6ix9ine\", \"Artist Followers\": 6514102.0, \"Song ID\": \"41xKiK40e7MFu1bqcGSz1d\", \"Genre\": \"['emo rap', 'rap']\", \"Release Date\": \"2020-08-02\", \"Weeks Charted\": \"2020-08-07--2020-08-14\", \"Popularity\": 58.0, \"Danceability\": 0.841, \"Energy\": 0.541, \"Loudness\": -7.121, \"Speechiness\": 0.229, \"Acousticness\": 0.0186, \"Liveness\": 0.123, \"Tempo\": 97.961, \"Duration (ms)\": 115255.0, \"Valence\": 0.42, \"Chord\": \"A\"}, {\"Index\": 974, \"Highest Charting Position\": 50, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Bl\\u00e4ulich\", \"Streams\": 4599408, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"2WRTnY0slmFgWcrmEr8dPj\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 60.0, \"Danceability\": 0.79, \"Energy\": 0.704, \"Loudness\": -7.935, \"Speechiness\": 0.417, \"Acousticness\": 0.069, \"Liveness\": 0.113, \"Tempo\": 154.007, \"Duration (ms)\": 196213.0, \"Valence\": 0.212, \"Chord\": \"A#/Bb\"}, {\"Index\": 975, \"Highest Charting Position\": 170, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Never Let Me Down\", \"Streams\": 4522005, \"Artist\": \"VIZE, Tom Gregory\", \"Artist Followers\": 141016.0, \"Song ID\": \"3bXiWZWR3CoZbhcsqfsMNa\", \"Genre\": \"['dance pop', 'german dance', 'pop dance', 'slap house', 'tropical house']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 61.0, \"Danceability\": 0.758, \"Energy\": 0.848, \"Loudness\": -3.84, \"Speechiness\": 0.0457, \"Acousticness\": 0.21, \"Liveness\": 0.114, \"Tempo\": 127.96, \"Duration (ms)\": 153149.0, \"Valence\": 0.706, \"Chord\": \"A#/Bb\"}, {\"Index\": 976, \"Highest Charting Position\": 16, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Savage\", \"Streams\": 4510218, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"55CHeLEfn5iJ0IIkgaa4si\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 75.0, \"Danceability\": 0.843, \"Energy\": 0.741, \"Loudness\": -5.609, \"Speechiness\": 0.334, \"Acousticness\": 0.0252, \"Liveness\": 0.096, \"Tempo\": 168.983, \"Duration (ms)\": 155497.0, \"Valence\": 0.68, \"Chord\": \"B\"}, {\"Index\": 977, \"Highest Charting Position\": 29, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"mad woman\", \"Streams\": 6796343, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2QDyYdZyhlP2fp79KZX8Bi\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 67.0, \"Danceability\": 0.592, \"Energy\": 0.699, \"Loudness\": -8.995, \"Speechiness\": 0.0471, \"Acousticness\": 0.655, \"Liveness\": 0.114, \"Tempo\": 141.916, \"Duration (ms)\": 237258.0, \"Valence\": 0.506, \"Chord\": \"D#/Eb\"}, {\"Index\": 978, \"Highest Charting Position\": 33, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"epiphany\", \"Streams\": 6085522, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"08fa9LFcFBTcilB3iq2e2A\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 66.0, \"Danceability\": 0.354, \"Energy\": 0.267, \"Loudness\": -13.69, \"Speechiness\": 0.0281, \"Acousticness\": 0.731, \"Liveness\": 0.0858, \"Tempo\": 94.219, \"Duration (ms)\": 289749.0, \"Valence\": 0.113, \"Chord\": \"C#/Db\"}, {\"Index\": 979, \"Highest Charting Position\": 41, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"peace\", \"Streams\": 5943851, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7MbT4I8qGntX4fMdqMQgke\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 67.0, \"Danceability\": 0.647, \"Energy\": 0.272, \"Loudness\": -12.906, \"Speechiness\": 0.0916, \"Acousticness\": 0.918, \"Liveness\": 0.0918, \"Tempo\": 150.044, \"Duration (ms)\": 234000.0, \"Valence\": 0.339, \"Chord\": \"F\"}, {\"Index\": 980, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Move Ya Hips (feat. Nicki Minaj & MadeinTYO)\", \"Streams\": 5768616, \"Artist\": \"A$AP Ferg\", \"Artist Followers\": 3037935.0, \"Song ID\": \"13v5IXnvO2BccWwOx5rb4s\", \"Genre\": \"['hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap', 'underground hip hop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 61.0, \"Danceability\": 0.808, \"Energy\": 0.676, \"Loudness\": -4.902, \"Speechiness\": 0.223, \"Acousticness\": 0.0618, \"Liveness\": 0.11, \"Tempo\": 144.018, \"Duration (ms)\": 144973.0, \"Valence\": 0.0763, \"Chord\": \"E\"}, {\"Index\": 981, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Sie ruft\", \"Streams\": 5752169, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"4CyCHkhRsDXUeP5K4Y3xjU\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 59.0, \"Danceability\": 0.819, \"Energy\": 0.507, \"Loudness\": -7.336, \"Speechiness\": 0.0881, \"Acousticness\": 0.482, \"Liveness\": 0.105, \"Tempo\": 130.009, \"Duration (ms)\": 152013.0, \"Valence\": 0.634, \"Chord\": \"C#/Db\"}, {\"Index\": 982, \"Highest Charting Position\": 144, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Tilidin Weg\", \"Streams\": 5674945, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"7idxewQZ24F0gQy2EWE6Ug\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 60.0, \"Danceability\": 0.882, \"Energy\": 0.526, \"Loudness\": -8.553, \"Speechiness\": 0.237, \"Acousticness\": 0.118, \"Liveness\": 0.0835, \"Tempo\": 109.075, \"Duration (ms)\": 180950.0, \"Valence\": 0.182, \"Chord\": \"A#/Bb\"}, {\"Index\": 983, \"Highest Charting Position\": 149, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Over Your Head\", \"Streams\": 5534361, \"Artist\": \"Future, Lil Uzi Vert\", \"Artist Followers\": 10491105.0, \"Song ID\": \"0Tcw8w9pvPrZoORgxsNASW\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 59.0, \"Danceability\": 0.773, \"Energy\": 0.742, \"Loudness\": -5.453, \"Speechiness\": 0.162, \"Acousticness\": 0.00198, \"Liveness\": 0.558, \"Tempo\": 148.949, \"Duration (ms)\": 186843.0, \"Valence\": 0.35, \"Chord\": \"F\"}, {\"Index\": 984, \"Highest Charting Position\": 47, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"hoax\", \"Streams\": 5375944, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6MWoRt97mnSTXZhu3ggi9C\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 66.0, \"Danceability\": 0.662, \"Energy\": 0.181, \"Loudness\": -15.065, \"Speechiness\": 0.0415, \"Acousticness\": 0.966, \"Liveness\": 0.133, \"Tempo\": 118.819, \"Duration (ms)\": 220043.0, \"Valence\": 0.429, \"Chord\": \"G#/Ab\"}, {\"Index\": 985, \"Highest Charting Position\": 25, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Blood On My Jeans\", \"Streams\": 4978899, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"0fCwrjKfWxF3xQhZrYUw4T\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 73.0, \"Danceability\": 0.868, \"Energy\": 0.55, \"Loudness\": -6.417, \"Speechiness\": 0.226, \"Acousticness\": 0.183, \"Liveness\": 0.109, \"Tempo\": 117.943, \"Duration (ms)\": 154767.0, \"Valence\": 0.464, \"Chord\": \"F#/Gb\"}, {\"Index\": 986, \"Highest Charting Position\": 171, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Narrow Road (feat. Lil Baby)\", \"Streams\": 4828004, \"Artist\": \"NLE Choppa\", \"Artist Followers\": 3372385.0, \"Song ID\": \"3GZd1aDsgKL71Kt3VIp0hc\", \"Genre\": \"['memphis hip hop']\", \"Release Date\": \"2020-07-30\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 64.0, \"Danceability\": 0.614, \"Energy\": 0.553, \"Loudness\": -8.225, \"Speechiness\": 0.169, \"Acousticness\": 0.0306, \"Liveness\": 0.203, \"Tempo\": 159.999, \"Duration (ms)\": 240297.0, \"Valence\": 0.161, \"Chord\": \"G\"}, {\"Index\": 987, \"Highest Charting Position\": 26, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Amarillo\", \"Streams\": 4695091, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"6zEgnpM0qYmHLDnh8WPejL\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 73.0, \"Danceability\": 0.641, \"Energy\": 0.857, \"Loudness\": -5.725, \"Speechiness\": 0.301, \"Acousticness\": 0.013, \"Liveness\": 0.0695, \"Tempo\": 122.728, \"Duration (ms)\": 157733.0, \"Valence\": 0.961, \"Chord\": \"C#/Db\"}, {\"Index\": 988, \"Highest Charting Position\": 179, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Singapur\", \"Streams\": 4661170, \"Artist\": \"El Alfa, Chael Produciendo\", \"Artist Followers\": 1779640.0, \"Song ID\": \"4QfZYDhGZc0T2RDvGiI69E\", \"Genre\": \"['dembow', 'latin', 'rap dominicano', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 69.0, \"Danceability\": 0.853, \"Energy\": 0.909, \"Loudness\": -2.473, \"Speechiness\": 0.229, \"Acousticness\": 0.0522, \"Liveness\": 0.129, \"Tempo\": 112.987, \"Duration (ms)\": 178407.0, \"Valence\": 0.803, \"Chord\": \"G\"}, {\"Index\": 989, \"Highest Charting Position\": 42, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Tattoo\", \"Streams\": 4588064, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6096559.0, \"Song ID\": \"4ZRrLHqzhGRXYj2qcB4s5S\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-07-09\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 78.0, \"Danceability\": 0.848, \"Energy\": 0.637, \"Loudness\": -5.132, \"Speechiness\": 0.156, \"Acousticness\": 0.0413, \"Liveness\": 0.0521, \"Tempo\": 96.988, \"Duration (ms)\": 222680.0, \"Valence\": 0.698, \"Chord\": \"A\"}, {\"Index\": 990, \"Highest Charting Position\": 86, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Ego Death (feat. Kanye West, FKA twigs & Skrillex)\", \"Streams\": 4583475, \"Artist\": \"Ty Dolla $ign\", \"Artist Followers\": 3866304.0, \"Song ID\": \"3Q5cLvkKsHJvYltf8k7HkO\", \"Genre\": \"['hip hop', 'pop', 'pop rap', 'r&b', 'southern hip hop', 'trap', 'trap soul']\", \"Release Date\": \"2020-10-22\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 71.0, \"Danceability\": 0.818, \"Energy\": 0.598, \"Loudness\": -5.948, \"Speechiness\": 0.113, \"Acousticness\": 0.0573, \"Liveness\": 0.634, \"Tempo\": 111.052, \"Duration (ms)\": 231618.0, \"Valence\": 0.331, \"Chord\": \"A#/Bb\"}, {\"Index\": 991, \"Highest Charting Position\": 33, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Morado\", \"Streams\": 4561936, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"3mQ6SLdxxaL52Yte7KF2Ks\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-01-09\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 71.0, \"Danceability\": 0.881, \"Energy\": 0.696, \"Loudness\": -3.838, \"Speechiness\": 0.0797, \"Acousticness\": 0.137, \"Liveness\": 0.0927, \"Tempo\": 97.002, \"Duration (ms)\": 200667.0, \"Valence\": 0.781, \"Chord\": \"B\"}, {\"Index\": 992, \"Highest Charting Position\": 101, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"ocean eyes\", \"Streams\": 4476954, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6pFTDHGJtKOxrQ85xRZ8Ue\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 1.0, \"Danceability\": 0.358, \"Energy\": 0.372, \"Loudness\": -7.664, \"Speechiness\": 0.0464, \"Acousticness\": 0.81, \"Liveness\": 0.0877, \"Tempo\": 144.833, \"Duration (ms)\": 200387.0, \"Valence\": 0.16, \"Chord\": \"E\"}, {\"Index\": 993, \"Highest Charting Position\": 82, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Lion King On Ice\", \"Streams\": 8293983, \"Artist\": \"J. Cole\", \"Artist Followers\": 14103694.0, \"Song ID\": \"1ZvBVbsaNqHEP6ymXaPGlj\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2020-07-22\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 64.0, \"Danceability\": 0.732, \"Energy\": 0.663, \"Loudness\": -7.616, \"Speechiness\": 0.192, \"Acousticness\": 0.0819, \"Liveness\": 0.115, \"Tempo\": 139.964, \"Duration (ms)\": 210587.0, \"Valence\": 0.227, \"Chord\": \"F#/Gb\"}, {\"Index\": 994, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Andere Welt\", \"Streams\": 5600868, \"Artist\": \"Capital Bra, Clueso, KC Rebell\", \"Artist Followers\": 4093115.0, \"Song ID\": \"5PAAUJTKLT0nCmHUlLdPXb\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-07-23\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 60.0, \"Danceability\": 0.692, \"Energy\": 0.764, \"Loudness\": -5.233, \"Speechiness\": 0.113, \"Acousticness\": 0.574, \"Liveness\": 0.106, \"Tempo\": 84.029, \"Duration (ms)\": 189686.0, \"Valence\": 0.564, \"Chord\": \"F\"}, {\"Index\": 995, \"Highest Charting Position\": 163, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"TELL ME WHY\", \"Streams\": 5056986, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"3jlxX3VXPiY3lvBBbppQD3\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.6, \"Energy\": 0.723, \"Loudness\": -4.928, \"Speechiness\": 0.158, \"Acousticness\": 0.109, \"Liveness\": 0.167, \"Tempo\": 149.881, \"Duration (ms)\": 195268.0, \"Valence\": 0.463, \"Chord\": \"F#/Gb\"}, {\"Index\": 996, \"Highest Charting Position\": 37, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Stay High\", \"Streams\": 5047752, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"21CkzgKCBCq5V4XKjiGSIj\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 75.0, \"Danceability\": 0.745, \"Energy\": 0.5, \"Loudness\": -6.184, \"Speechiness\": 0.135, \"Acousticness\": 0.439, \"Liveness\": 0.0943, \"Tempo\": 76.968, \"Duration (ms)\": 168685.0, \"Valence\": 0.433, \"Chord\": \"G#/Ab\"}, {\"Index\": 997, \"Highest Charting Position\": 161, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"What Makes You Beautiful\", \"Streams\": 4966428, \"Artist\": \"One Direction\", \"Artist Followers\": 22536304.0, \"Song ID\": \"4cluDES4hQEUhmXj6TXkSo\", \"Genre\": \"['boy band', 'pop', 'post-teen pop', 'talent show']\", \"Release Date\": \"2012-05-25\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 82.0, \"Danceability\": 0.726, \"Energy\": 0.787, \"Loudness\": -2.494, \"Speechiness\": 0.0737, \"Acousticness\": 0.009, \"Liveness\": 0.0596, \"Tempo\": 124.99, \"Duration (ms)\": 199987.0, \"Valence\": 0.888, \"Chord\": \"E\"}, {\"Index\": 998, \"Highest Charting Position\": 174, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Shit Changed\", \"Streams\": 4823401, \"Artist\": \"Ufo361, Sonus030\", \"Artist Followers\": 1700759.0, \"Song ID\": \"6du77YHyGWoFjbuHCFBHU3\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 52.0, \"Danceability\": 0.824, \"Energy\": 0.528, \"Loudness\": -9.236, \"Speechiness\": 0.175, \"Acousticness\": 0.144, \"Liveness\": 0.104, \"Tempo\": 157.005, \"Duration (ms)\": 183839.0, \"Valence\": 0.32, \"Chord\": \"A\"}, {\"Index\": 999, \"Highest Charting Position\": 35, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Tell Me U Luv Me (with Trippie Redd)\", \"Streams\": 4798078, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5JAYDuLRkODlVt6dgoalKk\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 72.0, \"Danceability\": 0.66, \"Energy\": 0.76, \"Loudness\": -5.726, \"Speechiness\": 0.0787, \"Acousticness\": 0.291, \"Liveness\": 0.632, \"Tempo\": 127.984, \"Duration (ms)\": 180129.0, \"Valence\": 0.394, \"Chord\": \"D\"}, {\"Index\": 1000, \"Highest Charting Position\": 27, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Bad Energy\", \"Streams\": 4761155, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"7d94IqWX2UmSKMGUYSGFJG\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 72.0, \"Danceability\": 0.654, \"Energy\": 0.452, \"Loudness\": -6.36, \"Speechiness\": 0.0439, \"Acousticness\": 0.17, \"Liveness\": 0.114, \"Tempo\": 138.034, \"Duration (ms)\": 186749.0, \"Valence\": 0.532, \"Chord\": \"G\"}, {\"Index\": 1001, \"Highest Charting Position\": 24, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Titanic\", \"Streams\": 4687464, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"1YM6c2sxbf2Jacl9IFgn4I\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 71.0, \"Danceability\": 0.567, \"Energy\": 0.545, \"Loudness\": -6.668, \"Speechiness\": 0.0448, \"Acousticness\": 0.168, \"Liveness\": 0.112, \"Tempo\": 174.146, \"Duration (ms)\": 176650.0, \"Valence\": 0.234, \"Chord\": \"C#/Db\"}, {\"Index\": 1002, \"Highest Charting Position\": 31, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Skechers\", \"Streams\": 4669248, \"Artist\": \"DripReport\", \"Artist Followers\": 92356.0, \"Song ID\": \"2alc8VZAzDgdAsL2QMk3hu\", \"Genre\": \"['viral rap']\", \"Release Date\": \"2020-01-12\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 73.0, \"Danceability\": 0.903, \"Energy\": 0.327, \"Loudness\": -9.727, \"Speechiness\": 0.0877, \"Acousticness\": 0.26, \"Liveness\": 0.108, \"Tempo\": 100.008, \"Duration (ms)\": 106000.0, \"Valence\": 0.274, \"Chord\": \"C#/Db\"}, {\"Index\": 1003, \"Highest Charting Position\": 47, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"The Bigger Picture\", \"Streams\": 4629083, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"44gRhRi2OhEf7moAUj6MD1\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 70.0, \"Danceability\": 0.59, \"Energy\": 0.618, \"Loudness\": -5.756, \"Speechiness\": 0.334, \"Acousticness\": 0.0127, \"Liveness\": 0.244, \"Tempo\": 96.459, \"Duration (ms)\": 252729.0, \"Valence\": 0.153, \"Chord\": \"C#/Db\"}, {\"Index\": 1004, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Story of My Life\", \"Streams\": 4628772, \"Artist\": \"One Direction\", \"Artist Followers\": 22536304.0, \"Song ID\": \"4nVBt6MZDDP6tRVdQTgxJg\", \"Genre\": \"['boy band', 'pop', 'post-teen pop', 'talent show']\", \"Release Date\": \"2013-11-25\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 81.0, \"Danceability\": 0.6, \"Energy\": 0.663, \"Loudness\": -5.802, \"Speechiness\": 0.0477, \"Acousticness\": 0.225, \"Liveness\": 0.119, \"Tempo\": 121.07, \"Duration (ms)\": 245493.0, \"Valence\": 0.286, \"Chord\": \"D#/Eb\"}, {\"Index\": 1005, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Hit My Line\", \"Streams\": 4621205, \"Artist\": \"Logic\", \"Artist Followers\": 5449291.0, \"Song ID\": \"24FR8mXTaiGZPrxnkf1kcP\", \"Genre\": \"['conscious hip hop', 'dmv rap', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 60.0, \"Danceability\": 0.62, \"Energy\": 0.786, \"Loudness\": -5.22, \"Speechiness\": 0.167, \"Acousticness\": 0.143, \"Liveness\": 0.46, \"Tempo\": 164.057, \"Duration (ms)\": 265191.0, \"Valence\": 0.679, \"Chord\": \"A\"}, {\"Index\": 1006, \"Highest Charting Position\": 10, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Party Girl (Remix)\", \"Streams\": 15129295, \"Artist\": \"StaySolidRocky, Lil Uzi Vert\", \"Artist Followers\": 150587.0, \"Song ID\": \"0XkmeG97T4mtYlWRJcrxec\", \"Genre\": \"['melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 62.0, \"Danceability\": 0.752, \"Energy\": 0.375, \"Loudness\": -10.157, \"Speechiness\": 0.204, \"Acousticness\": 0.533, \"Liveness\": 0.175, \"Tempo\": 129.995, \"Duration (ms)\": 147673.0, \"Valence\": 0.591, \"Chord\": \"F#/Gb\"}, {\"Index\": 1007, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Up Up And Away\", \"Streams\": 6229316, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"7pbg3ABlAZv2NiIdKbBBFm\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 72.0, \"Danceability\": 0.661, \"Energy\": 0.665, \"Loudness\": -6.356, \"Speechiness\": 0.053, \"Acousticness\": 0.538, \"Liveness\": 0.0981, \"Tempo\": 75.059, \"Duration (ms)\": 147548.0, \"Valence\": 0.486, \"Chord\": \"E\"}, {\"Index\": 1008, \"Highest Charting Position\": 46, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Man Of The Year\", \"Streams\": 6223001, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"7AvprzMsRJpybaalckaT8c\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 73.0, \"Danceability\": 0.621, \"Energy\": 0.695, \"Loudness\": -5.124, \"Speechiness\": 0.0911, \"Acousticness\": 0.00584, \"Liveness\": 0.086, \"Tempo\": 173.966, \"Duration (ms)\": 136408.0, \"Valence\": 0.298, \"Chord\": \"E\"}, {\"Index\": 1009, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Fighting Demons\", \"Streams\": 5946573, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"0440JCJyIAmINA8KcYgFb5\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 70.0, \"Danceability\": 0.707, \"Energy\": 0.67, \"Loudness\": -6.328, \"Speechiness\": 0.257, \"Acousticness\": 0.0813, \"Liveness\": 0.098, \"Tempo\": 163.099, \"Duration (ms)\": 200629.0, \"Valence\": 0.235, \"Chord\": \"G\"}, {\"Index\": 1010, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Can't Die\", \"Streams\": 5777859, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4PPLJAEYBSOcnzr9TZoqf9\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 71.0, \"Danceability\": 0.652, \"Energy\": 0.671, \"Loudness\": -5.89, \"Speechiness\": 0.0756, \"Acousticness\": 0.0222, \"Liveness\": 0.107, \"Tempo\": 84.008, \"Duration (ms)\": 182922.0, \"Valence\": 0.274, \"Chord\": \"D\"}, {\"Index\": 1011, \"Highest Charting Position\": 44, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Screw Juice\", \"Streams\": 5394197, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4F6YLjakjqWFTgC5qfEwPQ\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 69.0, \"Danceability\": 0.595, \"Energy\": 0.528, \"Loudness\": -7.371, \"Speechiness\": 0.0935, \"Acousticness\": 0.082, \"Liveness\": 0.142, \"Tempo\": 150.075, \"Duration (ms)\": 179464.0, \"Valence\": 0.515, \"Chord\": \"F\"}, {\"Index\": 1012, \"Highest Charting Position\": 129, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Past Life (with Selena Gomez)\", \"Streams\": 5228433, \"Artist\": \"Trevor Daniel\", \"Artist Followers\": 632097.0, \"Song ID\": \"7MN8RYSofZsFROBlEOAzXq\", \"Genre\": \"['alternative r&b', 'melodic rap', 'pop rap']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 47.0, \"Danceability\": 0.575, \"Energy\": 0.543, \"Loudness\": -5.062, \"Speechiness\": 0.0529, \"Acousticness\": 0.102, \"Liveness\": 0.176, \"Tempo\": 159.905, \"Duration (ms)\": 186480.0, \"Valence\": 0.283, \"Chord\": \"D#/Eb\"}, {\"Index\": 1013, \"Highest Charting Position\": 45, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"I Want It\", \"Streams\": 5137482, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"2SVx3uds6jTWALFxevIWMA\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 69.0, \"Danceability\": 0.288, \"Energy\": 0.638, \"Loudness\": -6.935, \"Speechiness\": 0.0779, \"Acousticness\": 0.133, \"Liveness\": 0.14, \"Tempo\": 66.424, \"Duration (ms)\": 173114.0, \"Valence\": 0.147, \"Chord\": \"E\"}, {\"Index\": 1014, \"Highest Charting Position\": 56, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Ransom\", \"Streams\": 5097394, \"Artist\": \"Lil Tecca\", \"Artist Followers\": 4022792.0, \"Song ID\": \"1lOe9qE0vR9zwWQAOk6CoO\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-08-30\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.745, \"Energy\": 0.642, \"Loudness\": -6.257, \"Speechiness\": 0.287, \"Acousticness\": 0.0204, \"Liveness\": 0.0658, \"Tempo\": 179.974, \"Duration (ms)\": 131240.0, \"Valence\": 0.226, \"Chord\": \"G\"}, {\"Index\": 1015, \"Highest Charting Position\": 49, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Diosa\", \"Streams\": 4868180, \"Artist\": \"Myke Towers\", \"Artist Followers\": 6161098.0, \"Song ID\": \"3JHpk0DOTOzyh0777JFAky\", \"Genre\": \"['trap latino']\", \"Release Date\": \"2020-01-24\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 74.0, \"Danceability\": 0.801, \"Energy\": 0.745, \"Loudness\": -3.733, \"Speechiness\": 0.063, \"Acousticness\": 0.398, \"Liveness\": 0.153, \"Tempo\": 104.965, \"Duration (ms)\": 214013.0, \"Valence\": 0.245, \"Chord\": \"F#/Gb\"}, {\"Index\": 1016, \"Highest Charting Position\": 169, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Never Know (feat. SHIRIN DAVID)\", \"Streams\": 4803071, \"Artist\": \"Luciano\", \"Artist Followers\": 942380.0, \"Song ID\": \"5Hkj1XjMJv5QCGc9NwZm6z\", \"Genre\": \"['german drill', 'german hip hop']\", \"Release Date\": \"2020-07-16\", \"Weeks Charted\": \"2020-07-17--2020-07-24\", \"Popularity\": 60.0, \"Danceability\": 0.874, \"Energy\": 0.542, \"Loudness\": -7.064, \"Speechiness\": 0.344, \"Acousticness\": 0.0621, \"Liveness\": 0.181, \"Tempo\": 142.016, \"Duration (ms)\": 196933.0, \"Valence\": 0.481, \"Chord\": \"A#/Bb\"}, {\"Index\": 1017, \"Highest Charting Position\": 5, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"La Dif\\u00edcil\", \"Streams\": 4727554, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"6NfrH0ANGmgBXyxgV2PeXt\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 78.0, \"Danceability\": 0.685, \"Energy\": 0.848, \"Loudness\": -4.561, \"Speechiness\": 0.0858, \"Acousticness\": 0.0861, \"Liveness\": 0.0783, \"Tempo\": 179.87, \"Duration (ms)\": 163084.0, \"Valence\": 0.761, \"Chord\": \"G#/Ab\"}, {\"Index\": 1018, \"Highest Charting Position\": 20, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"TROLLZ (with Nicki Minaj)\", \"Streams\": 4700152, \"Artist\": \"6ix9ine\", \"Artist Followers\": 6514102.0, \"Song ID\": \"3dVvWnj4D8JGkKvo6Hucso\", \"Genre\": \"['emo rap', 'rap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 65.0, \"Danceability\": 0.744, \"Energy\": 0.422, \"Loudness\": -8.946, \"Speechiness\": 0.294, \"Acousticness\": 0.0319, \"Liveness\": 0.11, \"Tempo\": 180.006, \"Duration (ms)\": 202667.0, \"Valence\": 0.493, \"Chord\": \"C#/Db\"}, {\"Index\": 1019, \"Highest Charting Position\": 44, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Old Town Road - Remix\", \"Streams\": 4643817, \"Artist\": \"Lil Nas X, Billy Ray Cyrus\", \"Artist Followers\": 5488666.0, \"Song ID\": \"2YpeDb67231RjR0MgVLzsG\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.878, \"Energy\": 0.619, \"Loudness\": -5.56, \"Speechiness\": 0.102, \"Acousticness\": 0.0533, \"Liveness\": 0.113, \"Tempo\": 136.041, \"Duration (ms)\": 157067.0, \"Valence\": 0.639, \"Chord\": \"F#/Gb\"}, {\"Index\": 1020, \"Highest Charting Position\": 67, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"The Adventures of Moon Man & Slim Shady (with Eminem)\", \"Streams\": 4639929, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"38iBrrbbXyWaSPkmuDNgjZ\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 67.0, \"Danceability\": 0.88, \"Energy\": 0.787, \"Loudness\": -5.189, \"Speechiness\": 0.118, \"Acousticness\": 0.226, \"Liveness\": 0.12, \"Tempo\": 113.018, \"Duration (ms)\": 264834.0, \"Valence\": 0.588, \"Chord\": \"G#/Ab\"}, {\"Index\": 1021, \"Highest Charting Position\": 25, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"China\", \"Streams\": 4627026, \"Artist\": \"Anuel AA, Daddy Yankee, KAROL G, Ozuna, J Balvin\", \"Artist Followers\": 18306226.0, \"Song ID\": \"2ksOAxtIxY8yElEWw8RhgK\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2019-07-19\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.786, \"Energy\": 0.808, \"Loudness\": -3.702, \"Speechiness\": 0.0882, \"Acousticness\": 0.0846, \"Liveness\": 0.0822, \"Tempo\": 105.027, \"Duration (ms)\": 301714.0, \"Valence\": 0.609, \"Chord\": \"G\"}, {\"Index\": 1022, \"Highest Charting Position\": 29, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Hola - Remix\", \"Streams\": 4617726, \"Artist\": \"Dalex, Lenny Tav\\u00e1rez, Chencho Corleone, Juhn, D\\u00edmelo Flow\", \"Artist Followers\": 3600989.0, \"Song ID\": \"5stPVcRqb4qixbafP9e8lt\", \"Genre\": \"['latin', 'r&b en espanol', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-01\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.654, \"Energy\": 0.672, \"Loudness\": -5.98, \"Speechiness\": 0.311, \"Acousticness\": 0.471, \"Liveness\": 0.0781, \"Tempo\": 181.857, \"Duration (ms)\": 249520.0, \"Valence\": 0.343, \"Chord\": \"C\"}, {\"Index\": 1023, \"Highest Charting Position\": 6, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Ignorantes\", \"Streams\": 4613982, \"Artist\": \"Bad Bunny, Sech\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3wYRLYuO1M88d8woWUIxct\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 74.0, \"Danceability\": 0.85, \"Energy\": 0.536, \"Loudness\": -5.161, \"Speechiness\": 0.0599, \"Acousticness\": 0.267, \"Liveness\": 0.0996, \"Tempo\": 96.029, \"Duration (ms)\": 210607.0, \"Valence\": 0.505, \"Chord\": \"C#/Db\"}, {\"Index\": 1024, \"Highest Charting Position\": 2, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Yummy\", \"Streams\": 4599349, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"41L3O37CECZt3N7ziG2z7l\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-03\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 72.0, \"Danceability\": 0.687, \"Energy\": 0.514, \"Loudness\": -6.612, \"Speechiness\": 0.0897, \"Acousticness\": 0.366, \"Liveness\": 0.116, \"Tempo\": 145.921, \"Duration (ms)\": 210427.0, \"Valence\": 0.494, \"Chord\": \"A\"}, {\"Index\": 1025, \"Highest Charting Position\": 29, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"High Fashion (feat. Mustard)\", \"Streams\": 4592772, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6608815.0, \"Song ID\": \"07KXEDMj78x68D884wgVEm\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 77.0, \"Danceability\": 0.831, \"Energy\": 0.499, \"Loudness\": -8.442, \"Speechiness\": 0.114, \"Acousticness\": 0.269, \"Liveness\": 0.3, \"Tempo\": 97.956, \"Duration (ms)\": 220487.0, \"Valence\": 0.511, \"Chord\": \"B\"}, {\"Index\": 1026, \"Highest Charting Position\": 69, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Like That (feat. Gucci Mane)\", \"Streams\": 4565377, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"4EivmOT13NMpNSfTKn9p4s\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 77.0, \"Danceability\": 0.879, \"Energy\": 0.498, \"Loudness\": -6.027, \"Speechiness\": 0.18, \"Acousticness\": 0.239, \"Liveness\": 0.0967, \"Tempo\": 106.044, \"Duration (ms)\": 163173.0, \"Valence\": 0.405, \"Chord\": \"E\"}, {\"Index\": 1027, \"Highest Charting Position\": 132, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Goodbyes (feat. Young Thug)\", \"Streams\": 4527742, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"0t3ZvGKlmYmVsDzBJAXK8C\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 78.0, \"Danceability\": 0.548, \"Energy\": 0.653, \"Loudness\": -3.875, \"Speechiness\": 0.081, \"Acousticness\": 0.456, \"Liveness\": 0.103, \"Tempo\": 150.068, \"Duration (ms)\": 174853.0, \"Valence\": 0.163, \"Chord\": \"F\"}, {\"Index\": 1028, \"Highest Charting Position\": 23, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"BOP\", \"Streams\": 4496450, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"6Ozh9Ok6h4Oi1wUSLtBseN\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.769, \"Energy\": 0.787, \"Loudness\": -3.909, \"Speechiness\": 0.367, \"Acousticness\": 0.189, \"Liveness\": 0.129, \"Tempo\": 126.77, \"Duration (ms)\": 159715.0, \"Valence\": 0.836, \"Chord\": \"B\"}, {\"Index\": 1029, \"Highest Charting Position\": 21, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Sigues Con El\", \"Streams\": 4485060, \"Artist\": \"D\\u00edmelo Flow, Arcangel, Sech\", \"Artist Followers\": 231580.0, \"Song ID\": \"7sQKy5vlPQllr0k9IjYJv3\", \"Genre\": \"['latin', 'perreo', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.883, \"Energy\": 0.668, \"Loudness\": -2.957, \"Speechiness\": 0.113, \"Acousticness\": 0.11, \"Liveness\": 0.0734, \"Tempo\": 87.972, \"Duration (ms)\": 226533.0, \"Valence\": 0.676, \"Chord\": \"A\"}, {\"Index\": 1030, \"Highest Charting Position\": 78, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Anxiety - Intro\", \"Streams\": 8449557, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"02XcRGWPkvomFvzTamEKHg\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 60.0, \"Danceability\": 0.307, \"Energy\": 0.528, \"Loudness\": -11.337, \"Speechiness\": 0.108, \"Acousticness\": 0.972, \"Liveness\": 0.222, \"Tempo\": 174.795, \"Duration (ms)\": 70395.0, \"Valence\": 0.58, \"Chord\": \"B\"}, {\"Index\": 1031, \"Highest Charting Position\": 112, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Juice WRLD Speaks From Heaven - Outro\", \"Streams\": 6682917, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"1OjiYjgPZyxS0AiXiSnuYI\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 59.0, \"Danceability\": 0.392, \"Energy\": 0.373, \"Loudness\": -14.097, \"Speechiness\": 0.0968, \"Acousticness\": 0.991, \"Liveness\": 0.545, \"Tempo\": 121.678, \"Duration (ms)\": 30583.0, \"Valence\": 0.519, \"Chord\": \"C\"}, {\"Index\": 1032, \"Highest Charting Position\": 113, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"The Man, The Myth, The Legend - Interlude\", \"Streams\": 6640728, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4sjdZEEQvR1sXrRNSuBfbA\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 58.0, \"Danceability\": 0.667, \"Energy\": 0.447, \"Loudness\": -14.625, \"Speechiness\": 0.761, \"Acousticness\": 0.916, \"Liveness\": 0.612, \"Tempo\": 83.534, \"Duration (ms)\": 136545.0, \"Valence\": 0.829, \"Chord\": \"D\"}, {\"Index\": 1033, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Tiefschwarz (feat. Samra)\", \"Streams\": 5867111, \"Artist\": \"Kontra K\", \"Artist Followers\": 1818624.0, \"Song ID\": \"7jMMoHhgq6iwVT5ykyxsJt\", \"Genre\": \"['christlicher rap', 'german hip hop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 62.0, \"Danceability\": 0.751, \"Energy\": 0.783, \"Loudness\": -5.926, \"Speechiness\": 0.22, \"Acousticness\": 0.0715, \"Liveness\": 0.114, \"Tempo\": 94.003, \"Duration (ms)\": 189739.0, \"Valence\": 0.379, \"Chord\": \"G\"}, {\"Index\": 1034, \"Highest Charting Position\": 57, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Wash Us In The Blood\", \"Streams\": 5586085, \"Artist\": \"Kanye West, Travis Scott\", \"Artist Followers\": 14624703.0, \"Song ID\": \"7mEUjhl6aTztdHCrxoTgBG\", \"Genre\": \"['chicago rap', 'rap']\", \"Release Date\": \"2020-06-30\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 64.0, \"Danceability\": 0.67, \"Energy\": 0.847, \"Loudness\": -4.85, \"Speechiness\": 0.409, \"Acousticness\": 0.184, \"Liveness\": 0.304, \"Tempo\": 137.22, \"Duration (ms)\": 189827.0, \"Valence\": 0.381, \"Chord\": \"A#/Bb\"}, {\"Index\": 1035, \"Highest Charting Position\": 53, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Gangstas\", \"Streams\": 5104422, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"1hg3RlqFZXJb5YgRoK9qmF\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 71.0, \"Danceability\": 0.548, \"Energy\": 0.506, \"Loudness\": -7.434, \"Speechiness\": 0.102, \"Acousticness\": 0.203, \"Liveness\": 0.0788, \"Tempo\": 119.987, \"Duration (ms)\": 160000.0, \"Valence\": 0.557, \"Chord\": \"E\"}, {\"Index\": 1036, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Monster\", \"Streams\": 5030481, \"Artist\": \"Red Velvet - IRENE & SEULGI\", \"Artist Followers\": 383695.0, \"Song ID\": \"6c1QaQHdDhtFMfUkhueuXK\", \"Genre\": \"['k-pop']\", \"Release Date\": \"2020-07-06\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 70.0, \"Danceability\": 0.631, \"Energy\": 0.748, \"Loudness\": -2.569, \"Speechiness\": 0.0488, \"Acousticness\": 0.212, \"Liveness\": 0.537, \"Tempo\": 115.665, \"Duration (ms)\": 178413.0, \"Valence\": 0.351, \"Chord\": \"E\"}, {\"Index\": 1037, \"Highest Charting Position\": 139, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"YAYA\", \"Streams\": 4729070, \"Artist\": \"6ix9ine\", \"Artist Followers\": 6514102.0, \"Song ID\": \"6EfBMJQwe2xLgldra6DaYp\", \"Genre\": \"['emo rap', 'rap']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 60.0, \"Danceability\": 0.672, \"Energy\": 0.733, \"Loudness\": -5.377, \"Speechiness\": 0.0566, \"Acousticness\": 0.00289, \"Liveness\": 0.199, \"Tempo\": 105.043, \"Duration (ms)\": 149857.0, \"Valence\": 0.354, \"Chord\": \"B\"}, {\"Index\": 1038, \"Highest Charting Position\": 174, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Narcos\", \"Streams\": 4633313, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"7mcdgAXmb35dakBnfDIv3q\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 68.0, \"Danceability\": 0.614, \"Energy\": 0.746, \"Loudness\": -3.527, \"Speechiness\": 0.196, \"Acousticness\": 0.347, \"Liveness\": 0.0874, \"Tempo\": 168.072, \"Duration (ms)\": 259250.0, \"Valence\": 0.601, \"Chord\": \"A#/Bb\"}, {\"Index\": 1039, \"Highest Charting Position\": 105, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"This City\", \"Streams\": 4597406, \"Artist\": \"Sam Fischer\", \"Artist Followers\": 122883.0, \"Song ID\": \"3H3r2nKWa3Yk5gt8xgmsEt\", \"Genre\": \"['alt z', 'australian pop', 'dance pop', 'indie cafe pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2019-12-11\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 80.0, \"Danceability\": 0.605, \"Energy\": 0.377, \"Loudness\": -6.213, \"Speechiness\": 0.0443, \"Acousticness\": 0.733, \"Liveness\": 0.0808, \"Tempo\": 73.877, \"Duration (ms)\": 194853.0, \"Valence\": 0.519, \"Chord\": \"B\"}, {\"Index\": 1040, \"Highest Charting Position\": 64, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Make It Rain (feat. Rowdy Rebel)\", \"Streams\": 4594248, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"71d7LaAgPcNcUopu3OzmP7\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 62.0, \"Danceability\": 0.5, \"Energy\": 0.767, \"Loudness\": -4.105, \"Speechiness\": 0.403, \"Acousticness\": 0.162, \"Liveness\": 0.385, \"Tempo\": 159.477, \"Duration (ms)\": 202443.0, \"Valence\": 0.58, \"Chord\": \"C#/Db\"}, {\"Index\": 1041, \"Highest Charting Position\": 46, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lalala\", \"Streams\": 4541965, \"Artist\": \"Y2K, bbno$\", \"Artist Followers\": 268766.0, \"Song ID\": \"51Fjme0JiitpyXKuyQiCDo\", \"Genre\": \"['pop rap']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.843, \"Energy\": 0.39, \"Loudness\": -7.899, \"Speechiness\": 0.0846, \"Acousticness\": 0.178, \"Liveness\": 0.137, \"Tempo\": 129.972, \"Duration (ms)\": 160627.0, \"Valence\": 0.495, \"Chord\": \"D\"}, {\"Index\": 1042, \"Highest Charting Position\": 79, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Something Special\", \"Streams\": 4535580, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"5kkaSMcf4BFlhRRICCKZb6\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 72.0, \"Danceability\": 0.739, \"Energy\": 0.616, \"Loudness\": -6.963, \"Speechiness\": 0.0338, \"Acousticness\": 0.252, \"Liveness\": 0.101, \"Tempo\": 91.071, \"Duration (ms)\": 158466.0, \"Valence\": 0.654, \"Chord\": \"G\"}, {\"Index\": 1043, \"Highest Charting Position\": 58, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Aim For The Moon (feat. Quavo)\", \"Streams\": 9011502, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"6O7fPYTsb2mY0PiFt2ymDB\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 67.0, \"Danceability\": 0.713, \"Energy\": 0.605, \"Loudness\": -7.487, \"Speechiness\": 0.107, \"Acousticness\": 0.497, \"Liveness\": 0.115, \"Tempo\": 142.025, \"Duration (ms)\": 175756.0, \"Valence\": 0.432, \"Chord\": \"B\"}, {\"Index\": 1044, \"Highest Charting Position\": 63, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"44 BullDog\", \"Streams\": 8443771, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"7sjFIZ1g5QLJLGja3k592K\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 66.0, \"Danceability\": 0.8, \"Energy\": 0.564, \"Loudness\": -5.817, \"Speechiness\": 0.4, \"Acousticness\": 0.0287, \"Liveness\": 0.112, \"Tempo\": 139.989, \"Duration (ms)\": 150857.0, \"Valence\": 0.318, \"Chord\": \"G#/Ab\"}, {\"Index\": 1045, \"Highest Charting Position\": 88, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Creature (feat. Swae Lee)\", \"Streams\": 7308690, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"3eV2WT9YhfzkxbufnBF8wK\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 66.0, \"Danceability\": 0.794, \"Energy\": 0.717, \"Loudness\": -5.73, \"Speechiness\": 0.251, \"Acousticness\": 0.0511, \"Liveness\": 0.195, \"Tempo\": 141.881, \"Duration (ms)\": 202816.0, \"Valence\": 0.372, \"Chord\": \"G\"}, {\"Index\": 1046, \"Highest Charting Position\": 95, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Yea Yea\", \"Streams\": 7112419, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"0bjgQ24UZGwKikldIyEOgf\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 63.0, \"Danceability\": 0.717, \"Energy\": 0.474, \"Loudness\": -8.383, \"Speechiness\": 0.403, \"Acousticness\": 0.0509, \"Liveness\": 0.139, \"Tempo\": 123.906, \"Duration (ms)\": 185804.0, \"Valence\": 0.448, \"Chord\": \"F\"}, {\"Index\": 1047, \"Highest Charting Position\": 100, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Enjoy Yourself (feat. Karol G)\", \"Streams\": 6620040, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"3NWrHCwvyII4fTx05PN3IO\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 70.0, \"Danceability\": 0.764, \"Energy\": 0.676, \"Loudness\": -6.761, \"Speechiness\": 0.0927, \"Acousticness\": 0.389, \"Liveness\": 0.215, \"Tempo\": 97.02, \"Duration (ms)\": 197938.0, \"Valence\": 0.461, \"Chord\": \"B\"}, {\"Index\": 1048, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Bad Bitch From Tokyo (Intro)\", \"Streams\": 6144736, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"4OGIeHtYhRTJ8iW21UUyZW\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 59.0, \"Danceability\": 0.645, \"Energy\": 0.64, \"Loudness\": -6.871, \"Speechiness\": 0.179, \"Acousticness\": 0.395, \"Liveness\": 0.286, \"Tempo\": 140.248, \"Duration (ms)\": 48000.0, \"Valence\": 0.674, \"Chord\": \"A#/Bb\"}, {\"Index\": 1049, \"Highest Charting Position\": 117, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Snitching (feat. Quavo & Future)\", \"Streams\": 6102253, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"2FhEj9lvEIaJihjFprRrGt\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 59.0, \"Danceability\": 0.944, \"Energy\": 0.579, \"Loudness\": -4.961, \"Speechiness\": 0.191, \"Acousticness\": 0.0381, \"Liveness\": 0.253, \"Tempo\": 135.033, \"Duration (ms)\": 259346.0, \"Valence\": 0.769, \"Chord\": \"G#/Ab\"}, {\"Index\": 1050, \"Highest Charting Position\": 121, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"West Coast Shit (feat. Tyga & Quavo)\", \"Streams\": 5931242, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"1JDhNQ0oOT7XpclZn3aQ8F\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 61.0, \"Danceability\": 0.831, \"Energy\": 0.762, \"Loudness\": -5.656, \"Speechiness\": 0.207, \"Acousticness\": 0.0885, \"Liveness\": 0.107, \"Tempo\": 99.999, \"Duration (ms)\": 192000.0, \"Valence\": 0.495, \"Chord\": \"B\"}, {\"Index\": 1051, \"Highest Charting Position\": 72, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Deep End Freestyle\", \"Streams\": 5280810, \"Artist\": \"Sleepy Hallow, Foushe\\u00e9\", \"Artist Followers\": 411262.0, \"Song ID\": \"2AlYncTpVHKwHb55F9lF6O\", \"Genre\": \"['brooklyn drill', 'nyc rap']\", \"Release Date\": \"2020-06-05\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 72.0, \"Danceability\": 0.868, \"Energy\": 0.479, \"Loudness\": -6.687, \"Speechiness\": 0.445, \"Acousticness\": 0.703, \"Liveness\": 0.102, \"Tempo\": 133.928, \"Duration (ms)\": 115200.0, \"Valence\": 0.776, \"Chord\": \"E\"}, {\"Index\": 1052, \"Highest Charting Position\": 56, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Tommy Lee (feat. Post Malone)\", \"Streams\": 5031845, \"Artist\": \"Tyla Yaweh\", \"Artist Followers\": 359133.0, \"Song ID\": \"5QZKcQDp0tCcvMdyqEciBV\", \"Genre\": \"['cali rap', 'melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 73.0, \"Danceability\": 0.457, \"Energy\": 0.621, \"Loudness\": -5.923, \"Speechiness\": 0.138, \"Acousticness\": 0.218, \"Liveness\": 0.0944, \"Tempo\": 85.359, \"Duration (ms)\": 224638.0, \"Valence\": 0.634, \"Chord\": \"A#/Bb\"}, {\"Index\": 1053, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Tunnel Vision (Outro)\", \"Streams\": 4907751, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"2SxR5RitJdsG6wINvJLBSD\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 60.0, \"Danceability\": 0.718, \"Energy\": 0.66, \"Loudness\": -7.39, \"Speechiness\": 0.325, \"Acousticness\": 0.363, \"Liveness\": 0.159, \"Tempo\": 142.879, \"Duration (ms)\": 132587.0, \"Valence\": 0.659, \"Chord\": \"D\"}, {\"Index\": 1054, \"Highest Charting Position\": 7, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Si Veo a Tu Mam\\u00e1\", \"Streams\": 4638728, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"41wtwzCZkXwpnakmwJ239F\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 80.0, \"Danceability\": 0.9, \"Energy\": 0.603, \"Loudness\": -5.313, \"Speechiness\": 0.0646, \"Acousticness\": 0.402, \"Liveness\": 0.134, \"Tempo\": 129.928, \"Duration (ms)\": 170972.0, \"Valence\": 0.824, \"Chord\": \"D\"}, {\"Index\": 1055, \"Highest Charting Position\": 177, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Prospect (ft. Lil Baby)\", \"Streams\": 4571916, \"Artist\": \"iann dior\", \"Artist Followers\": 1276292.0, \"Song ID\": \"4iHSE5R1U8jf84tRn52xRt\", \"Genre\": \"['melodic rap', 'pop rap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 68.0, \"Danceability\": 0.816, \"Energy\": 0.579, \"Loudness\": -6.097, \"Speechiness\": 0.0867, \"Acousticness\": 0.203, \"Liveness\": 0.127, \"Tempo\": 120.078, \"Duration (ms)\": 226314.0, \"Valence\": 0.43, \"Chord\": \"C#/Db\"}, {\"Index\": 1056, \"Highest Charting Position\": 55, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"No Me Conoce - Remix\", \"Streams\": 4501188, \"Artist\": \"Jhay Cortez, J Balvin, Bad Bunny\", \"Artist Followers\": 2435159.0, \"Song ID\": \"4R8BJggjosTswLxtkw8V7P\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-05-24\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.806, \"Energy\": 0.786, \"Loudness\": -3.831, \"Speechiness\": 0.0741, \"Acousticness\": 0.145, \"Liveness\": 0.0935, \"Tempo\": 91.973, \"Duration (ms)\": 309120.0, \"Valence\": 0.58, \"Chord\": \"A#/Bb\"}, {\"Index\": 1057, \"Highest Charting Position\": 189, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"El Manual\", \"Streams\": 4470597, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"7kOf0qHO4Rcwk6QJifZDRJ\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 67.0, \"Danceability\": 0.843, \"Energy\": 0.845, \"Loudness\": -2.344, \"Speechiness\": 0.0503, \"Acousticness\": 0.35, \"Liveness\": 0.0527, \"Tempo\": 126.989, \"Duration (ms)\": 210624.0, \"Valence\": 0.898, \"Chord\": \"C\"}, {\"Index\": 1058, \"Highest Charting Position\": 181, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Thunder\", \"Streams\": 4468668, \"Artist\": \"Imagine Dragons\", \"Artist Followers\": 35299488.0, \"Song ID\": \"1zB4vmk8tFRmM9UULNzbLB\", \"Genre\": \"['modern rock', 'pop', 'rock']\", \"Release Date\": \"2017-06-23\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-05--2020-06-12\\n2020-02-07--2020-02-14\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.605, \"Energy\": 0.822, \"Loudness\": -4.833, \"Speechiness\": 0.0438, \"Acousticness\": 0.00671, \"Liveness\": 0.147, \"Tempo\": 167.997, \"Duration (ms)\": 187147.0, \"Valence\": 0.288, \"Chord\": \"C\"}, {\"Index\": 1059, \"Highest Charting Position\": 158, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"El Efecto - Remix\", \"Streams\": 4433384, \"Artist\": \"Rauw Alejandro, Chencho Corleone, KEVVO, Bryant Myers, Lyanno, Dalex\", \"Artist Followers\": 6096559.0, \"Song ID\": \"74j34STf8L6uADnTN69ohv\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 73.0, \"Danceability\": 0.771, \"Energy\": 0.769, \"Loudness\": -3.504, \"Speechiness\": 0.0694, \"Acousticness\": 0.18, \"Liveness\": 0.345, \"Tempo\": 167.969, \"Duration (ms)\": 289899.0, \"Valence\": 0.931, \"Chord\": \"C\"}, {\"Index\": 1060, \"Highest Charting Position\": 122, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Better Now\", \"Streams\": 4431571, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"7dt6x5M1jzdTEt8oCbisTK\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2018-04-27\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.68, \"Energy\": 0.578, \"Loudness\": -5.804, \"Speechiness\": 0.04, \"Acousticness\": 0.331, \"Liveness\": 0.135, \"Tempo\": 145.038, \"Duration (ms)\": 231267.0, \"Valence\": 0.341, \"Chord\": \"A#/Bb\"}, {\"Index\": 1061, \"Highest Charting Position\": 185, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Don't Stop Believin'\", \"Streams\": 4394985, \"Artist\": \"Journey\", \"Artist Followers\": 3731820.0, \"Song ID\": \"4bHsxqR3GMrXTxEPLuK5ue\", \"Genre\": \"['album rock', 'classic rock', 'hard rock', 'mellow gold', 'rock', 'soft rock']\", \"Release Date\": \"1981\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-19--2020-06-26\", \"Popularity\": 81.0, \"Danceability\": 0.5, \"Energy\": 0.748, \"Loudness\": -9.072, \"Speechiness\": 0.0363, \"Acousticness\": 0.127, \"Liveness\": 0.447, \"Tempo\": 118.852, \"Duration (ms)\": 250987.0, \"Valence\": 0.514, \"Chord\": \"E\"}, {\"Index\": 1062, \"Highest Charting Position\": 90, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"BLACK PARADE\", \"Streams\": 5474807, \"Artist\": \"Beyonc\\u00e9\", \"Artist Followers\": 28335112.0, \"Song ID\": \"2qzUpSVI4NnPyWxbXwumTj\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'r&b']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 61.0, \"Danceability\": 0.824, \"Energy\": 0.555, \"Loudness\": -5.817, \"Speechiness\": 0.05, \"Acousticness\": 0.00337, \"Liveness\": 0.217, \"Tempo\": 120.002, \"Duration (ms)\": 281273.0, \"Valence\": 0.0611, \"Chord\": \"C#/Db\"}, {\"Index\": 1063, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"XXL\", \"Streams\": 5415994, \"Artist\": \"Miksu / Macloud, Summer Cem, Luciano, Jamule\", \"Artist Followers\": 30683.0, \"Song ID\": \"0p3euGPg5LgFeQGC7bBFuR\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 64.0, \"Danceability\": 0.798, \"Energy\": 0.527, \"Loudness\": -7.671, \"Speechiness\": 0.0447, \"Acousticness\": 0.227, \"Liveness\": 0.108, \"Tempo\": 114.008, \"Duration (ms)\": 166173.0, \"Valence\": 0.548, \"Chord\": \"F\"}, {\"Index\": 1064, \"Highest Charting Position\": 70, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Salt\", \"Streams\": 4874960, \"Artist\": \"Ava Max\", \"Artist Followers\": 1251372.0, \"Song ID\": \"2o2p9xH3bkSDLcp6phIF4J\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 1.0, \"Danceability\": 0.693, \"Energy\": 0.835, \"Loudness\": -3.242, \"Speechiness\": 0.0624, \"Acousticness\": 0.131, \"Liveness\": 0.073, \"Tempo\": 128.052, \"Duration (ms)\": 180283.0, \"Valence\": 0.744, \"Chord\": \"F#/Gb\"}, {\"Index\": 1065, \"Highest Charting Position\": 52, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Daisies\", \"Streams\": 4838067, \"Artist\": \"Katy Perry\", \"Artist Followers\": 18936929.0, \"Song ID\": \"4uqh9bualXNHXXwO2wPorc\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 68.0, \"Danceability\": 0.639, \"Energy\": 0.546, \"Loudness\": -5.382, \"Speechiness\": 0.0407, \"Acousticness\": 0.0837, \"Liveness\": 0.122, \"Tempo\": 122.179, \"Duration (ms)\": 173124.0, \"Valence\": 0.149, \"Chord\": \"C#/Db\"}, {\"Index\": 1066, \"Highest Charting Position\": 142, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Emotionally Scarred\", \"Streams\": 4633237, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"7ge7BHazYbVKi8qyZUX1Bm\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 71.0, \"Danceability\": 0.585, \"Energy\": 0.641, \"Loudness\": -4.269, \"Speechiness\": 0.133, \"Acousticness\": 0.0286, \"Liveness\": 0.316, \"Tempo\": 88.284, \"Duration (ms)\": 197530.0, \"Valence\": 0.266, \"Chord\": \"F#/Gb\"}, {\"Index\": 1067, \"Highest Charting Position\": 32, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Myron\", \"Streams\": 4593309, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"56uXDJRCuoS7abX3SkzHKQ\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 76.0, \"Danceability\": 0.771, \"Energy\": 0.654, \"Loudness\": -6.976, \"Speechiness\": 0.298, \"Acousticness\": 0.055, \"Liveness\": 0.214, \"Tempo\": 155.047, \"Duration (ms)\": 224955.0, \"Valence\": 0.573, \"Chord\": \"G#/Ab\"}, {\"Index\": 1068, \"Highest Charting Position\": 67, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"MORE & MORE\", \"Streams\": 4592745, \"Artist\": \"TWICE\", \"Artist Followers\": 9998991.0, \"Song ID\": \"3omvXShuRPM3zbDpWYqf5g\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-06-01\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 70.0, \"Danceability\": 0.739, \"Energy\": 0.841, \"Loudness\": -4.162, \"Speechiness\": 0.06, \"Acousticness\": 0.0312, \"Liveness\": 0.173, \"Tempo\": 106.99, \"Duration (ms)\": 199653.0, \"Valence\": 0.562, \"Chord\": \"F\"}, {\"Index\": 1069, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Girls in the Hood\", \"Streams\": 4577209, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"6WbTTAGKrQtCQvmc5BuYfh\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 72.0, \"Danceability\": 0.821, \"Energy\": 0.863, \"Loudness\": -3.159, \"Speechiness\": 0.353, \"Acousticness\": 0.00824, \"Liveness\": 0.0377, \"Tempo\": 180.013, \"Duration (ms)\": 154324.0, \"Valence\": 0.874, \"Chord\": \"F#/Gb\"}, {\"Index\": 1070, \"Highest Charting Position\": 169, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Parasite Eve\", \"Streams\": 4545883, \"Artist\": \"Bring Me The Horizon\", \"Artist Followers\": 3912138.0, \"Song ID\": \"5OxclJsdFESni44YlpNpkR\", \"Genre\": \"['melodic metalcore', 'metalcore', 'rock', 'uk metalcore']\", \"Release Date\": \"2020-06-25\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 67.0, \"Danceability\": 0.589, \"Energy\": 0.797, \"Loudness\": -5.464, \"Speechiness\": 0.15, \"Acousticness\": 0.0289, \"Liveness\": 0.383, \"Tempo\": 102.489, \"Duration (ms)\": 291813.0, \"Valence\": 0.232, \"Chord\": \"A\"}, {\"Index\": 1071, \"Highest Charting Position\": 78, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Sucker\", \"Streams\": 4543863, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"22vgEDb5hykfaTwLuskFGD\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-06-07\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.842, \"Energy\": 0.734, \"Loudness\": -5.065, \"Speechiness\": 0.0588, \"Acousticness\": 0.0427, \"Liveness\": 0.106, \"Tempo\": 137.958, \"Duration (ms)\": 181027.0, \"Valence\": 0.952, \"Chord\": \"C#/Db\"}, {\"Index\": 1072, \"Highest Charting Position\": 147, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"I Like Me Better\", \"Streams\": 4430642, \"Artist\": \"Lauv\", \"Artist Followers\": 4442273.0, \"Song ID\": \"2P91MQbaiQOfbiz9VqhqKQ\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-05-31\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.752, \"Energy\": 0.505, \"Loudness\": -7.621, \"Speechiness\": 0.253, \"Acousticness\": 0.535, \"Liveness\": 0.104, \"Tempo\": 91.97, \"Duration (ms)\": 197437.0, \"Valence\": 0.419, \"Chord\": \"A\"}, {\"Index\": 1073, \"Highest Charting Position\": 116, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"High Hopes\", \"Streams\": 4426791, \"Artist\": \"Panic! At The Disco\", \"Artist Followers\": 10850424.0, \"Song ID\": \"1rqqCSm0Qe4I9rUvWncaom\", \"Genre\": \"['modern rock']\", \"Release Date\": \"2018-06-22\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.579, \"Energy\": 0.904, \"Loudness\": -2.729, \"Speechiness\": 0.0618, \"Acousticness\": 0.193, \"Liveness\": 0.064, \"Tempo\": 82.014, \"Duration (ms)\": 190947.0, \"Valence\": 0.681, \"Chord\": \"F\"}, {\"Index\": 1074, \"Highest Charting Position\": 88, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Money In The Grave (Drake ft. Rick Ross)\", \"Streams\": 4403348, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5ry2OE6R2zPQFDO85XkgRb\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2019-06-15\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.831, \"Energy\": 0.502, \"Loudness\": -4.045, \"Speechiness\": 0.046, \"Acousticness\": 0.101, \"Liveness\": 0.122, \"Tempo\": 100.541, \"Duration (ms)\": 205427.0, \"Valence\": 0.101, \"Chord\": \"A#/Bb\"}, {\"Index\": 1075, \"Highest Charting Position\": 25, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Say So (feat. Nicki Minaj)\", \"Streams\": 4385148, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"11VApNQCWLJdzxWrlmwzUa\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 69.0, \"Danceability\": 0.856, \"Energy\": 0.641, \"Loudness\": -4.64, \"Speechiness\": 0.204, \"Acousticness\": 0.119, \"Liveness\": 0.427, \"Tempo\": 111.004, \"Duration (ms)\": 206221.0, \"Valence\": 0.745, \"Chord\": \"B\"}, {\"Index\": 1076, \"Highest Charting Position\": 189, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Karaoke\", \"Streams\": 4374448, \"Artist\": \"Boomdabash, Alessandra Amoroso\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3n6TeHSnNhDe991nJS2S90\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-10\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 0.0, \"Danceability\": 0.929, \"Energy\": 0.625, \"Loudness\": -5.728, \"Speechiness\": 0.14, \"Acousticness\": 0.289, \"Liveness\": 0.386, \"Tempo\": 122.03, \"Duration (ms)\": 156493.0, \"Valence\": 0.578, \"Chord\": \"C#/Db\"}, {\"Index\": 1077, \"Highest Charting Position\": 36, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Know Your Worth\", \"Streams\": 4374392, \"Artist\": \"Khalid, Disclosure\", \"Artist Followers\": 14190858.0, \"Song ID\": \"0TrPqhAMoaKUFLR7iYDokf\", \"Genre\": \"['pop']\", \"Release Date\": \"2020-02-04\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 76.0, \"Danceability\": 0.79, \"Energy\": 0.694, \"Loudness\": -7.726, \"Speechiness\": 0.0708, \"Acousticness\": 0.145, \"Liveness\": 0.281, \"Tempo\": 103.007, \"Duration (ms)\": 181436.0, \"Valence\": 0.508, \"Chord\": \"A\"}, {\"Index\": 1078, \"Highest Charting Position\": 26, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"No Idea\", \"Streams\": 4369849, \"Artist\": \"Don Toliver\", \"Artist Followers\": 1606884.0, \"Song ID\": \"7AzlLxHn24DxjgQX73F9fU\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.652, \"Energy\": 0.631, \"Loudness\": -5.718, \"Speechiness\": 0.0893, \"Acousticness\": 0.524, \"Liveness\": 0.165, \"Tempo\": 127.998, \"Duration (ms)\": 154424.0, \"Valence\": 0.35, \"Chord\": \"F#/Gb\"}, {\"Index\": 1079, \"Highest Charting Position\": 145, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Airwaves\", \"Streams\": 4352767, \"Artist\": \"Pashanim\", \"Artist Followers\": 208926.0, \"Song ID\": \"5CqkgDH8QZjSqqI3HmYxDD\", \"Genre\": \"['german alternative rap', 'german drill', 'german hip hop', 'german trap']\", \"Release Date\": \"2020-05-14\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 71.0, \"Danceability\": 0.885, \"Energy\": 0.578, \"Loudness\": -7.416, \"Speechiness\": 0.0783, \"Acousticness\": 0.0739, \"Liveness\": 0.102, \"Tempo\": 131.999, \"Duration (ms)\": 178933.0, \"Valence\": 0.388, \"Chord\": \"F\"}, {\"Index\": 1080, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Kill This Love\", \"Streams\": 4341050, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"6hvczQ05jc1yGlp9zhb95V\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2019-04-05\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 76.0, \"Danceability\": 0.763, \"Energy\": 0.835, \"Loudness\": -5.234, \"Speechiness\": 0.191, \"Acousticness\": 0.323, \"Liveness\": 0.225, \"Tempo\": 131.875, \"Duration (ms)\": 191050.0, \"Valence\": 0.645, \"Chord\": \"D\"}, {\"Index\": 1081, \"Highest Charting Position\": 68, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lights Up\", \"Streams\": 4325411, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16127908.0, \"Song ID\": \"4jAIqgrPjKLTY9Gbez25Qb\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.575, \"Energy\": 0.621, \"Loudness\": -8.165, \"Speechiness\": 0.032, \"Acousticness\": 0.0392, \"Liveness\": 0.141, \"Tempo\": 101.987, \"Duration (ms)\": 172213.0, \"Valence\": 0.27, \"Chord\": \"A#/Bb\"}, {\"Index\": 1082, \"Highest Charting Position\": 14, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Lose You To Love Me\", \"Streams\": 4322088, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4l0Mvzj72xxOpRrp6h8nHi\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.488, \"Energy\": 0.343, \"Loudness\": -8.985, \"Speechiness\": 0.0436, \"Acousticness\": 0.556, \"Liveness\": 0.21, \"Tempo\": 102.819, \"Duration (ms)\": 206459.0, \"Valence\": 0.0978, \"Chord\": \"E\"}, {\"Index\": 1083, \"Highest Charting Position\": 94, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Girls Like You (feat. Cardi B)\", \"Streams\": 4318772, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32279979.0, \"Song ID\": \"6V1bu6o1Yo5ZXnsCJU8Ovk\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2018-06-15\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.851, \"Energy\": 0.541, \"Loudness\": -6.825, \"Speechiness\": 0.0505, \"Acousticness\": 0.568, \"Liveness\": 0.13, \"Tempo\": 124.959, \"Duration (ms)\": 235545.0, \"Valence\": 0.448, \"Chord\": \"C\"}, {\"Index\": 1084, \"Highest Charting Position\": 47, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"PA' ROMPERLA\", \"Streams\": 4312675, \"Artist\": \"Bad Bunny, Don Omar\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5XqCz18k96K8tx6DAYM97i\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 72.0, \"Danceability\": 0.772, \"Energy\": 0.83, \"Loudness\": -5.019, \"Speechiness\": 0.0599, \"Acousticness\": 0.016, \"Liveness\": 0.0843, \"Tempo\": 94.011, \"Duration (ms)\": 194200.0, \"Valence\": 0.697, \"Chord\": \"G\"}, {\"Index\": 1085, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"VACATION\", \"Streams\": 6883487, \"Artist\": \"Tyga\", \"Artist Followers\": 6298789.0, \"Song ID\": \"6q2uIyLqASSpv2SIv2ehWK\", \"Genre\": \"['dance pop', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 51.0, \"Danceability\": 0.821, \"Energy\": 0.61, \"Loudness\": -6.22, \"Speechiness\": 0.0959, \"Acousticness\": 0.0247, \"Liveness\": 0.185, \"Tempo\": 110.973, \"Duration (ms)\": 192936.0, \"Valence\": 0.47, \"Chord\": \"C#/Db\"}, {\"Index\": 1086, \"Highest Charting Position\": 86, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Big Body Benz\", \"Streams\": 6707101, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"2WOJ7D52Ng3myrKlEf4Azj\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-06-18\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 61.0, \"Danceability\": 0.884, \"Energy\": 0.451, \"Loudness\": -8.969, \"Speechiness\": 0.393, \"Acousticness\": 0.0731, \"Liveness\": 0.268, \"Tempo\": 94.024, \"Duration (ms)\": 148284.0, \"Valence\": 0.311, \"Chord\": \"A\"}, {\"Index\": 1087, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Ich wei\\u00df nicht mal wie sie hei\\u00dft\", \"Streams\": 5827600, \"Artist\": \"Capital Bra, Bozza\", \"Artist Followers\": 4093115.0, \"Song ID\": \"4KfL3Ne8bc9bC2PUB8QGwA\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-06-18\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 57.0, \"Danceability\": 0.498, \"Energy\": 0.836, \"Loudness\": -3.905, \"Speechiness\": 0.184, \"Acousticness\": 0.525, \"Liveness\": 0.0994, \"Tempo\": 199.846, \"Duration (ms)\": 168750.0, \"Valence\": 0.609, \"Chord\": \"A#/Bb\"}, {\"Index\": 1088, \"Highest Charting Position\": 101, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"F\\u00fatbol & Rumba (feat. Enrique Iglesias)\", \"Streams\": 5124116, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"2hDe0Ls5mVqs1XJqv7sbcM\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 67.0, \"Danceability\": 0.735, \"Energy\": 0.916, \"Loudness\": -2.082, \"Speechiness\": 0.117, \"Acousticness\": 0.397, \"Liveness\": 0.0918, \"Tempo\": 167.994, \"Duration (ms)\": 221429.0, \"Valence\": 0.691, \"Chord\": \"D\"}, {\"Index\": 1089, \"Highest Charting Position\": 131, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Bleed\", \"Streams\": 5095478, \"Artist\": \"A Boogie Wit da Hoodie\", \"Artist Followers\": 5865895.0, \"Song ID\": \"5XzombolzpiaOSTdj1W0VS\", \"Genre\": \"['melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 61.0, \"Danceability\": 0.698, \"Energy\": 0.572, \"Loudness\": -7.735, \"Speechiness\": 0.198, \"Acousticness\": 0.135, \"Liveness\": 0.154, \"Tempo\": 71.446, \"Duration (ms)\": 176959.0, \"Valence\": 0.391, \"Chord\": \"D\"}, {\"Index\": 1090, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Snow On Tha Bluff\", \"Streams\": 5060764, \"Artist\": \"J. Cole\", \"Artist Followers\": 14103694.0, \"Song ID\": \"1oOEkBNp4zWnkD7nWjJdog\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2020-06-16\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 66.0, \"Danceability\": 0.586, \"Energy\": 0.512, \"Loudness\": -8.819, \"Speechiness\": 0.0668, \"Acousticness\": 0.723, \"Liveness\": 0.119, \"Tempo\": 75.857, \"Duration (ms)\": 235480.0, \"Valence\": 0.235, \"Chord\": \"G#/Ab\"}, {\"Index\": 1091, \"Highest Charting Position\": 113, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Djomb - Bien ou quoi\", \"Streams\": 4924714, \"Artist\": \"Bosh\", \"Artist Followers\": 300500.0, \"Song ID\": \"0KBwGCY9RYD9t2zjeW4h48\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 64.0, \"Danceability\": 0.945, \"Energy\": 0.676, \"Loudness\": -6.6, \"Speechiness\": 0.207, \"Acousticness\": 0.172, \"Liveness\": 0.322, \"Tempo\": 123.109, \"Duration (ms)\": 141893.0, \"Valence\": 0.631, \"Chord\": \"C#/Db\"}, {\"Index\": 1092, \"Highest Charting Position\": 84, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"In Your Eyes (feat. Alida)\", \"Streams\": 4654587, \"Artist\": \"Alida, Robin Schulz\", \"Artist Followers\": 2786366.0, \"Song ID\": \"61ZM92T2zaXIVsqncThQzC\", \"Genre\": \"['dance pop', 'deep euro house', 'deep house', 'edm', 'german dance', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 71.0, \"Danceability\": 0.57, \"Energy\": 0.672, \"Loudness\": -5.888, \"Speechiness\": 0.0716, \"Acousticness\": 0.172, \"Liveness\": 0.0768, \"Tempo\": 120.018, \"Duration (ms)\": 208222.0, \"Valence\": 0.461, \"Chord\": \"G#/Ab\"}, {\"Index\": 1093, \"Highest Charting Position\": 13, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Stupid Love\", \"Streams\": 4609858, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 1251372.0, \"Song ID\": \"1zPwSOUc5MPtPg8EgXAGKU\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-08\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 0.0, \"Danceability\": 0.68, \"Energy\": 0.825, \"Loudness\": -4.296, \"Speechiness\": 0.0702, \"Acousticness\": 0.00173, \"Liveness\": 0.27, \"Tempo\": 117.987, \"Duration (ms)\": 193533.0, \"Valence\": 0.784, \"Chord\": \"G#/Ab\"}, {\"Index\": 1094, \"Highest Charting Position\": 93, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Shotta Flow 5\", \"Streams\": 4513982, \"Artist\": \"NLE Choppa\", \"Artist Followers\": 3372385.0, \"Song ID\": \"1orjH4IkSH9VrWmRCToKV8\", \"Genre\": \"['memphis hip hop']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 62.0, \"Danceability\": 0.806, \"Energy\": 0.749, \"Loudness\": -5.268, \"Speechiness\": 0.328, \"Acousticness\": 0.0838, \"Liveness\": 0.0621, \"Tempo\": 140.032, \"Duration (ms)\": 145167.0, \"Valence\": 0.77, \"Chord\": \"C#/Db\"}, {\"Index\": 1095, \"Highest Charting Position\": 145, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"IDK You Yet\", \"Streams\": 4473413, \"Artist\": \"Alexander 23\", \"Artist Followers\": 207170.0, \"Song ID\": \"0j1Ia2lQWrcXrQZI4AdJlk\", \"Genre\": \"['alt z', 'indie cafe pop', 'pop', 'post-teen pop', 'social media pop']\", \"Release Date\": \"2020-06-23\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 79.0, \"Danceability\": 0.648, \"Energy\": 0.308, \"Loudness\": -11.729, \"Speechiness\": 0.04, \"Acousticness\": 0.886, \"Liveness\": 0.124, \"Tempo\": 76.997, \"Duration (ms)\": 184638.0, \"Valence\": 0.198, \"Chord\": \"C#/Db\"}, {\"Index\": 1096, \"Highest Charting Position\": 75, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Piece Of Your Heart\", \"Streams\": 4422905, \"Artist\": \"MEDUZA, Goodboys\", \"Artist Followers\": 441714.0, \"Song ID\": \"1DFD5Fotzgn6yYXkYsKiGs\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop house', 'tropical house']\", \"Release Date\": \"2019-02-01\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.677, \"Energy\": 0.744, \"Loudness\": -6.806, \"Speechiness\": 0.0295, \"Acousticness\": 0.0404, \"Liveness\": 0.074, \"Tempo\": 124.08, \"Duration (ms)\": 152913.0, \"Valence\": 0.631, \"Chord\": \"A#/Bb\"}, {\"Index\": 1097, \"Highest Charting Position\": 129, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Na Raba Toma Tap\\u00e3o\", \"Streams\": 4396629, \"Artist\": \"Niack\", \"Artist Followers\": 352402.0, \"Song ID\": \"0AGS6ZRgzobrazmCi6pYMe\", \"Genre\": \"['funk carioca']\", \"Release Date\": \"2020-06-06\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 61.0, \"Danceability\": 0.962, \"Energy\": 0.787, \"Loudness\": 1.509, \"Speechiness\": 0.0554, \"Acousticness\": 0.666, \"Liveness\": 0.176, \"Tempo\": 130.003, \"Duration (ms)\": 165231.0, \"Valence\": 0.968, \"Chord\": \"D#/Eb\"}, {\"Index\": 1098, \"Highest Charting Position\": 14, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"La Santa\", \"Streams\": 4384527, \"Artist\": \"Bad Bunny, Daddy Yankee\", \"Artist Followers\": 36177712.0, \"Song ID\": \"69vlMrzHwATKzupwNcUPyK\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 79.0, \"Danceability\": 0.744, \"Energy\": 0.868, \"Loudness\": -4.524, \"Speechiness\": 0.047, \"Acousticness\": 0.0326, \"Liveness\": 0.0822, \"Tempo\": 93.037, \"Duration (ms)\": 206420.0, \"Valence\": 0.586, \"Chord\": \"C#/Db\"}, {\"Index\": 1099, \"Highest Charting Position\": 125, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Make You Mine\", \"Streams\": 4356213, \"Artist\": \"PUBLIC\", \"Artist Followers\": 165504.0, \"Song ID\": \"5iFwAOB2TFkPJk8sMlxP8g\", \"Genre\": \"['indie rockism']\", \"Release Date\": \"2019-08-09\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 77.0, \"Danceability\": 0.606, \"Energy\": 0.799, \"Loudness\": -4.452, \"Speechiness\": 0.0261, \"Acousticness\": 0.0128, \"Liveness\": 0.15, \"Tempo\": 103.014, \"Duration (ms)\": 232907.0, \"Valence\": 0.638, \"Chord\": \"A\"}, {\"Index\": 1100, \"Highest Charting Position\": 76, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"ROCKSTAR (feat. Roddy Ricch) - BLM REMIX\", \"Streams\": 7353153, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"4Aykm3xrOFSHrAnv80KUhh\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 62.0, \"Danceability\": 0.747, \"Energy\": 0.689, \"Loudness\": -7.246, \"Speechiness\": 0.242, \"Acousticness\": 0.197, \"Liveness\": 0.0884, \"Tempo\": 89.901, \"Duration (ms)\": 204547.0, \"Valence\": 0.75, \"Chord\": \"B\"}, {\"Index\": 1101, \"Highest Charting Position\": 97, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Make It Rain\", \"Streams\": 6042929, \"Artist\": \"Pop Smoke, Rowdy Rebel\", \"Artist Followers\": 6852509.0, \"Song ID\": \"4TgHt7vKCimpywaiKfl0uj\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 64.0, \"Danceability\": 0.54, \"Energy\": 0.77, \"Loudness\": -3.981, \"Speechiness\": 0.389, \"Acousticness\": 0.194, \"Liveness\": 0.372, \"Tempo\": 159.494, \"Duration (ms)\": 204000.0, \"Valence\": 0.565, \"Chord\": \"C#/Db\"}, {\"Index\": 1102, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"M' Manc (con Geolier & Sfera Ebbasta)\", \"Streams\": 5171235, \"Artist\": \"Shablo\", \"Artist Followers\": 40045.0, \"Song ID\": \"0MLu1cFYL4ikdRTdasCQT9\", \"Genre\": \"['italian hip hop']\", \"Release Date\": \"2020-06-11\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 66.0, \"Danceability\": 0.703, \"Energy\": 0.704, \"Loudness\": -6.117, \"Speechiness\": 0.0641, \"Acousticness\": 0.048, \"Liveness\": 0.41, \"Tempo\": 139.933, \"Duration (ms)\": 180000.0, \"Valence\": 0.725, \"Chord\": \"F#/Gb\"}, {\"Index\": 1103, \"Highest Charting Position\": 143, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Emotions 2.0\", \"Streams\": 5113459, \"Artist\": \"Ufo361, C\\u00c9LINE\", \"Artist Followers\": 1700759.0, \"Song ID\": \"3yZCjDTxzZxx1kll1sRjGc\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 65.0, \"Danceability\": 0.788, \"Energy\": 0.491, \"Loudness\": -9.884, \"Speechiness\": 0.109, \"Acousticness\": 0.386, \"Liveness\": 0.107, \"Tempo\": 98.543, \"Duration (ms)\": 146028.0, \"Valence\": 0.271, \"Chord\": \"G#/Ab\"}, {\"Index\": 1104, \"Highest Charting Position\": 21, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"P2\", \"Streams\": 4769996, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"3kW4z2pIj5VY5fLjBrMRL5\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 73.0, \"Danceability\": 0.775, \"Energy\": 0.72, \"Loudness\": -5.353, \"Speechiness\": 0.193, \"Acousticness\": 0.0236, \"Liveness\": 0.114, \"Tempo\": 155.086, \"Duration (ms)\": 234627.0, \"Valence\": 0.49, \"Chord\": \"B\"}, {\"Index\": 1105, \"Highest Charting Position\": 79, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Selfish\", \"Streams\": 4754830, \"Artist\": \"Madison Beer\", \"Artist Followers\": 3370013.0, \"Song ID\": \"4PV0uE5pZSh44E3NqNNDEH\", \"Genre\": \"['alt z', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 70.0, \"Danceability\": 0.375, \"Energy\": 0.461, \"Loudness\": -6.202, \"Speechiness\": 0.0279, \"Acousticness\": 0.627, \"Liveness\": 0.386, \"Tempo\": 75.217, \"Duration (ms)\": 223270.0, \"Valence\": 0.233, \"Chord\": \"A\"}, {\"Index\": 1106, \"Highest Charting Position\": 154, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Surrender\", \"Streams\": 4627942, \"Artist\": \"Natalie Taylor\", \"Artist Followers\": 120208.0, \"Song ID\": \"0ecC8p17cDNlxHXkuYqeR6\", \"Genre\": \"[]\", \"Release Date\": \"2019-10-29\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 76.0, \"Danceability\": 0.39, \"Energy\": 0.448, \"Loudness\": -8.57, \"Speechiness\": 0.0276, \"Acousticness\": 0.8, \"Liveness\": 0.107, \"Tempo\": 144.89, \"Duration (ms)\": 183103.0, \"Valence\": 0.077, \"Chord\": \"F\"}, {\"Index\": 1107, \"Highest Charting Position\": 86, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Turks (with Gunna & ft. Travis Scott)\", \"Streams\": 4623279, \"Artist\": \"NAV\", \"Artist Followers\": 2613211.0, \"Song ID\": \"7IMwEtpAiJanqF6vQteZN2\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'hip hop', 'melodic rap', 'pop rap', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 67.0, \"Danceability\": 0.894, \"Energy\": 0.618, \"Loudness\": -4.356, \"Speechiness\": 0.129, \"Acousticness\": 0.0808, \"Liveness\": 0.558, \"Tempo\": 119.1, \"Duration (ms)\": 161320.0, \"Valence\": 0.379, \"Chord\": \"G\"}, {\"Index\": 1108, \"Highest Charting Position\": 48, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"BYE ME FUI\", \"Streams\": 4567732, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0FktnzDqjClqU6iqOZVEs2\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 72.0, \"Danceability\": 0.712, \"Energy\": 0.599, \"Loudness\": -6.342, \"Speechiness\": 0.112, \"Acousticness\": 0.412, \"Liveness\": 0.103, \"Tempo\": 179.788, \"Duration (ms)\": 178000.0, \"Valence\": 0.588, \"Chord\": \"F\"}, {\"Index\": 1109, \"Highest Charting Position\": 15, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Vete\", \"Streams\": 4486408, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5DxXgozhkPLgrbKFY91w0c\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-21\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.886, \"Energy\": 0.672, \"Loudness\": -4.394, \"Speechiness\": 0.188, \"Acousticness\": 0.0363, \"Liveness\": 0.101, \"Tempo\": 91.976, \"Duration (ms)\": 192024.0, \"Valence\": 0.526, \"Chord\": \"C#/Db\"}, {\"Index\": 1110, \"Highest Charting Position\": 43, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Like It Is\", \"Streams\": 4463865, \"Artist\": \"Kygo, Zara Larsson, Tyga\", \"Artist Followers\": 7593792.0, \"Song ID\": \"3frUvGrmGcay91lvFbOgsN\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 68.0, \"Danceability\": 0.794, \"Energy\": 0.728, \"Loudness\": -6.759, \"Speechiness\": 0.114, \"Acousticness\": 0.121, \"Liveness\": 0.227, \"Tempo\": 105.024, \"Duration (ms)\": 183067.0, \"Valence\": 0.36, \"Chord\": \"C#/Db\"}, {\"Index\": 1111, \"Highest Charting Position\": 15, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"My Oh My (feat. DaBaby)\", \"Streams\": 4413457, \"Artist\": \"Camila Cabello\", \"Artist Followers\": 22698747.0, \"Song ID\": \"3yOlyBJuViE2YSGn3nVE1K\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.724, \"Energy\": 0.491, \"Loudness\": -6.024, \"Speechiness\": 0.0296, \"Acousticness\": 0.018, \"Liveness\": 0.0887, \"Tempo\": 105.046, \"Duration (ms)\": 170746.0, \"Valence\": 0.383, \"Chord\": \"G#/Ab\"}, {\"Index\": 1112, \"Highest Charting Position\": 161, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Let Me Down Slowly\", \"Streams\": 4393932, \"Artist\": \"Alec Benjamin\", \"Artist Followers\": 2808285.0, \"Song ID\": \"2qxmye6gAegTMjLKEBoR3d\", \"Genre\": \"['alt z', 'electropop', 'pop']\", \"Release Date\": \"2018-11-16\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.652, \"Energy\": 0.557, \"Loudness\": -5.714, \"Speechiness\": 0.0318, \"Acousticness\": 0.74, \"Liveness\": 0.124, \"Tempo\": 150.073, \"Duration (ms)\": 169354.0, \"Valence\": 0.483, \"Chord\": \"C#/Db\"}, {\"Index\": 1113, \"Highest Charting Position\": 22, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"BELIEVE IT\", \"Streams\": 4361970, \"Artist\": \"PARTYNEXTDOOR, Rihanna\", \"Artist Followers\": 3129968.0, \"Song ID\": \"4HDCLYli2SUdkq9OjmvhSD\", \"Genre\": \"['pop', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap', 'urban contemporary']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 74.0, \"Danceability\": 0.43, \"Energy\": 0.7, \"Loudness\": -5.35, \"Speechiness\": 0.264, \"Acousticness\": 0.0902, \"Liveness\": 0.216, \"Tempo\": 158.373, \"Duration (ms)\": 183219.0, \"Valence\": 0.731, \"Chord\": \"F#/Gb\"}, {\"Index\": 1114, \"Highest Charting Position\": 86, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Boot\", \"Streams\": 6375562, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"12KENAKQY5JvAsRURN7TzB\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2020-06-05--2020-06-12\", \"Popularity\": 54.0, \"Danceability\": 0.534, \"Energy\": 0.565, \"Loudness\": -7.546, \"Speechiness\": 0.307, \"Acousticness\": 0.0627, \"Liveness\": 0.112, \"Tempo\": 194.034, \"Duration (ms)\": 193360.0, \"Valence\": 0.529, \"Chord\": \"G#/Ab\"}, {\"Index\": 1115, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Riot\", \"Streams\": 5163633, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"4aOOExMBUyxKnEYb39SrTg\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2020-06-01\", \"Weeks Charted\": \"2020-06-05--2020-06-12\", \"Popularity\": 70.0, \"Danceability\": 0.509, \"Energy\": 0.542, \"Loudness\": -8.027, \"Speechiness\": 0.442, \"Acousticness\": 0.019, \"Liveness\": 0.23, \"Tempo\": 97.767, \"Duration (ms)\": 78681.0, \"Valence\": 0.151, \"Chord\": \"D#/Eb\"}, {\"Index\": 1116, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"VALLA NEIN (feat. Luciano)\", \"Streams\": 5029858, \"Artist\": \"KC Rebell, Summer Cem\", \"Artist Followers\": 1101597.0, \"Song ID\": \"2rxxXYtTIFKyrhJpofeoIX\", \"Genre\": \"['german drill', 'german hip hop']\", \"Release Date\": \"2020-06-05\", \"Weeks Charted\": \"2020-06-05--2020-06-12\", \"Popularity\": 55.0, \"Danceability\": 0.761, \"Energy\": 0.657, \"Loudness\": -7.246, \"Speechiness\": 0.138, \"Acousticness\": 0.114, \"Liveness\": 0.356, \"Tempo\": 135.909, \"Duration (ms)\": 182040.0, \"Valence\": 0.589, \"Chord\": \"A#/Bb\"}, {\"Index\": 1117, \"Highest Charting Position\": 27, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"I\\u2019m Ready (with Demi Lovato)\", \"Streams\": 4764355, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"1fipvP2zmef6vN2IwXfJhY\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-04-16\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 68.0, \"Danceability\": 0.501, \"Energy\": 0.674, \"Loudness\": -6.363, \"Speechiness\": 0.0408, \"Acousticness\": 0.00346, \"Liveness\": 0.282, \"Tempo\": 155.051, \"Duration (ms)\": 200838.0, \"Valence\": 0.152, \"Chord\": \"F\"}, {\"Index\": 1118, \"Highest Charting Position\": 63, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"This Is America\", \"Streams\": 4727415, \"Artist\": \"Childish Gambino\", \"Artist Followers\": 8099554.0, \"Song ID\": \"0b9oOr2ZgvyQu88wzixux9\", \"Genre\": \"['atl hip hop', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2018-05-06\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 71.0, \"Danceability\": 0.854, \"Energy\": 0.463, \"Loudness\": -6.159, \"Speechiness\": 0.137, \"Acousticness\": 0.117, \"Liveness\": 0.354, \"Tempo\": 120.024, \"Duration (ms)\": 225773.0, \"Valence\": 0.549, \"Chord\": \"F\"}, {\"Index\": 1119, \"Highest Charting Position\": 33, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Fantasias\", \"Streams\": 4432324, \"Artist\": \"Rauw Alejandro, Farruko\", \"Artist Followers\": 6096559.0, \"Song ID\": \"6mAN61JH0dzyZpWslS11jy\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2019-08-29\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.879, \"Energy\": 0.703, \"Loudness\": -4.219, \"Speechiness\": 0.0701, \"Acousticness\": 0.143, \"Liveness\": 0.0569, \"Tempo\": 94.004, \"Duration (ms)\": 199711.0, \"Valence\": 0.788, \"Chord\": \"C#/Db\"}, {\"Index\": 1120, \"Highest Charting Position\": 60, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"BAD CON NICKY\", \"Streams\": 4432210, \"Artist\": \"Bad Bunny, Nicky Jam\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5bmSver2b3ZXyuyLKtgnFI\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 71.0, \"Danceability\": 0.59, \"Energy\": 0.729, \"Loudness\": -4.95, \"Speechiness\": 0.0893, \"Acousticness\": 0.321, \"Liveness\": 0.659, \"Tempo\": 93.094, \"Duration (ms)\": 202240.0, \"Valence\": 0.712, \"Chord\": \"G\"}, {\"Index\": 1121, \"Highest Charting Position\": 145, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"If I Can't Have You\", \"Streams\": 4364166, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 33893352.0, \"Song ID\": \"6LsAAHotRLMOHfCsSfYCsz\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2019-05-03\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.692, \"Energy\": 0.809, \"Loudness\": -4.198, \"Speechiness\": 0.0602, \"Acousticness\": 0.524, \"Liveness\": 0.147, \"Tempo\": 123.911, \"Duration (ms)\": 190800.0, \"Valence\": 0.864, \"Chord\": \"D\"}, {\"Index\": 1122, \"Highest Charting Position\": 27, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"What A Man Gotta Do\", \"Streams\": 4360660, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"4wNIkl5XGiAACjFBlDWuSd\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 77.0, \"Danceability\": 0.852, \"Energy\": 0.698, \"Loudness\": -7.206, \"Speechiness\": 0.0629, \"Acousticness\": 0.00839, \"Liveness\": 0.0773, \"Tempo\": 113.039, \"Duration (ms)\": 180645.0, \"Valence\": 0.324, \"Chord\": \"A\"}, {\"Index\": 1123, \"Highest Charting Position\": 50, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Callaita\", \"Streams\": 4350496, \"Artist\": \"Bad Bunny, Tainy\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2TH65lNHgvLxCKXM3apjxI\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-05-31\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.61, \"Energy\": 0.624, \"Loudness\": -4.773, \"Speechiness\": 0.309, \"Acousticness\": 0.6, \"Liveness\": 0.243, \"Tempo\": 176.169, \"Duration (ms)\": 250534.0, \"Valence\": 0.244, \"Chord\": \"D\"}, {\"Index\": 1124, \"Highest Charting Position\": 51, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Solitaires (feat. Travis Scott)\", \"Streams\": 4334669, \"Artist\": \"Future\", \"Artist Followers\": 10491105.0, \"Song ID\": \"4kfeRwpq5KUaqTkgi4TbDF\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 67.0, \"Danceability\": 0.691, \"Energy\": 0.632, \"Loudness\": -7.598, \"Speechiness\": 0.0513, \"Acousticness\": 0.122, \"Liveness\": 0.0646, \"Tempo\": 169.982, \"Duration (ms)\": 205666.0, \"Valence\": 0.488, \"Chord\": \"C#/Db\"}, {\"Index\": 1125, \"Highest Charting Position\": 137, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"XO Tour Llif3\", \"Streams\": 4314080, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7GX5flRQZVHRAGd6B4TmDO\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2017-08-25\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-08--2020-05-15\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 82.0, \"Danceability\": 0.732, \"Energy\": 0.75, \"Loudness\": -6.366, \"Speechiness\": 0.231, \"Acousticness\": 0.00264, \"Liveness\": 0.109, \"Tempo\": 155.096, \"Duration (ms)\": 182707.0, \"Valence\": 0.401, \"Chord\": \"B\"}, {\"Index\": 1126, \"Highest Charting Position\": 189, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"changes\", \"Streams\": 4299334, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"7AFASza1mXqntmGtbxXprO\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2018-03-16\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 81.0, \"Danceability\": 0.669, \"Energy\": 0.308, \"Loudness\": -10.068, \"Speechiness\": 0.029, \"Acousticness\": 0.883, \"Liveness\": 0.0984, \"Tempo\": 64.934, \"Duration (ms)\": 121887.0, \"Valence\": 0.52, \"Chord\": \"B\"}, {\"Index\": 1127, \"Highest Charting Position\": 66, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Suicidal (Remix) [feat. Juice WRLD]\", \"Streams\": 4296154, \"Artist\": \"YNW Melly\", \"Artist Followers\": 6332535.0, \"Song ID\": \"4S2uhQE8L9V6p7rj7SiauJ\", \"Genre\": \"['melodic rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 76.0, \"Danceability\": 0.655, \"Energy\": 0.441, \"Loudness\": -5.245, \"Speechiness\": 0.0629, \"Acousticness\": 0.474, \"Liveness\": 0.099, \"Tempo\": 139.957, \"Duration (ms)\": 225857.0, \"Valence\": 0.273, \"Chord\": \"A\"}, {\"Index\": 1128, \"Highest Charting Position\": 30, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Level of Concern\", \"Streams\": 4252898, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20829526.0, \"Song ID\": \"6xZ4Q2k2ompmDppyeESIY8\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 72.0, \"Danceability\": 0.754, \"Energy\": 0.583, \"Loudness\": -7.34, \"Speechiness\": 0.0432, \"Acousticness\": 0.32, \"Liveness\": 0.144, \"Tempo\": 122.012, \"Duration (ms)\": 220051.0, \"Valence\": 0.77, \"Chord\": \"E\"}, {\"Index\": 1129, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Alice\", \"Streams\": 10342277, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"41A89rj3GoMG6ktN37L7PG\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 64.0, \"Danceability\": 0.723, \"Energy\": 0.88, \"Loudness\": -4.287, \"Speechiness\": 0.038, \"Acousticness\": 0.00334, \"Liveness\": 0.0632, \"Tempo\": 123.036, \"Duration (ms)\": 177600.0, \"Valence\": 0.323, \"Chord\": \"B\"}, {\"Index\": 1130, \"Highest Charting Position\": 58, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Free Woman\", \"Streams\": 9266945, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"4L6ihclQPu1hqP9r3WNJjQ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 63.0, \"Danceability\": 0.731, \"Energy\": 0.927, \"Loudness\": -3.634, \"Speechiness\": 0.0781, \"Acousticness\": 0.0228, \"Liveness\": 0.187, \"Tempo\": 119.006, \"Duration (ms)\": 191467.0, \"Valence\": 0.478, \"Chord\": \"C\"}, {\"Index\": 1131, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Fun Tonight\", \"Streams\": 7907329, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"6hyQVqfHFvsJDjcmj4qrHf\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.645, \"Energy\": 0.923, \"Loudness\": -4.262, \"Speechiness\": 0.0725, \"Acousticness\": 0.364, \"Liveness\": 0.14, \"Tempo\": 117.945, \"Duration (ms)\": 173427.0, \"Valence\": 0.323, \"Chord\": \"B\"}, {\"Index\": 1132, \"Highest Charting Position\": 75, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Sine From Above (with Elton John)\", \"Streams\": 7734309, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"0zzsyWc45eUcSjw4FNHxeN\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 60.0, \"Danceability\": 0.642, \"Energy\": 0.792, \"Loudness\": -5.746, \"Speechiness\": 0.0488, \"Acousticness\": 0.158, \"Liveness\": 0.68, \"Tempo\": 122.965, \"Duration (ms)\": 244880.0, \"Valence\": 0.0903, \"Chord\": \"C\"}, {\"Index\": 1133, \"Highest Charting Position\": 77, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Enigma\", \"Streams\": 7695566, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"7JDbfYUHjDzQPFSDh5lzGs\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 59.0, \"Danceability\": 0.669, \"Energy\": 0.804, \"Loudness\": -4.035, \"Speechiness\": 0.036, \"Acousticness\": 0.0306, \"Liveness\": 0.694, \"Tempo\": 116.001, \"Duration (ms)\": 179760.0, \"Valence\": 0.184, \"Chord\": \"C\"}, {\"Index\": 1134, \"Highest Charting Position\": 79, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Replay\", \"Streams\": 7479618, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"7sKbyYeJnITO1Eh9xd0lKd\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 63.0, \"Danceability\": 0.658, \"Energy\": 0.878, \"Loudness\": -3.875, \"Speechiness\": 0.123, \"Acousticness\": 0.00792, \"Liveness\": 0.944, \"Tempo\": 122.015, \"Duration (ms)\": 186653.0, \"Valence\": 0.683, \"Chord\": \"C#/Db\"}, {\"Index\": 1135, \"Highest Charting Position\": 80, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Plastic Doll\", \"Streams\": 7451452, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"3CidPLqWXqgesJlwYVJZdy\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.743, \"Energy\": 0.853, \"Loudness\": -4.842, \"Speechiness\": 0.04, \"Acousticness\": 0.0019, \"Liveness\": 0.0872, \"Tempo\": 121.028, \"Duration (ms)\": 221667.0, \"Valence\": 0.422, \"Chord\": \"C\"}, {\"Index\": 1136, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Chromatica II\", \"Streams\": 7136521, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"0oQc0F6KUE7QY7k5TU6bic\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.184, \"Energy\": 0.297, \"Loudness\": -14.534, \"Speechiness\": 0.0359, \"Acousticness\": 0.473, \"Liveness\": 0.527, \"Tempo\": 75.824, \"Duration (ms)\": 41867.0, \"Valence\": 0.113, \"Chord\": \"D\"}, {\"Index\": 1137, \"Highest Charting Position\": 91, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Babylon\", \"Streams\": 6996402, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"5DttNeiizFqWUON9hZBqTY\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 61.0, \"Danceability\": 0.698, \"Energy\": 0.799, \"Loudness\": -4.372, \"Speechiness\": 0.0342, \"Acousticness\": 0.0129, \"Liveness\": 0.215, \"Tempo\": 115.957, \"Duration (ms)\": 161733.0, \"Valence\": 0.351, \"Chord\": \"D\"}, {\"Index\": 1138, \"Highest Charting Position\": 93, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Chromatica I\", \"Streams\": 6630385, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"0oQc0F6KUE7QY7k5TU6bic\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.184, \"Energy\": 0.297, \"Loudness\": -14.534, \"Speechiness\": 0.0359, \"Acousticness\": 0.473, \"Liveness\": 0.527, \"Tempo\": 75.824, \"Duration (ms)\": 41867.0, \"Valence\": 0.113, \"Chord\": \"D\"}, {\"Index\": 1139, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"1000 Doves\", \"Streams\": 6069544, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"62hTXlVQacy3pjBW4ntRPl\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.668, \"Energy\": 0.826, \"Loudness\": -4.466, \"Speechiness\": 0.0383, \"Acousticness\": 0.0236, \"Liveness\": 0.474, \"Tempo\": 122.973, \"Duration (ms)\": 215480.0, \"Valence\": 0.388, \"Chord\": \"A\"}, {\"Index\": 1140, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Broken Glass\", \"Streams\": 5867930, \"Artist\": \"Kygo, Kim Petras\", \"Artist Followers\": 7593792.0, \"Song ID\": \"78ldtCaBRJVp2i91B715L0\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 66.0, \"Danceability\": 0.526, \"Energy\": 0.633, \"Loudness\": -7.002, \"Speechiness\": 0.134, \"Acousticness\": 0.372, \"Liveness\": 0.129, \"Tempo\": 171.044, \"Duration (ms)\": 203947.0, \"Valence\": 0.272, \"Chord\": \"G\"}, {\"Index\": 1141, \"Highest Charting Position\": 131, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"In meinem Benz\", \"Streams\": 5494500, \"Artist\": \"AK AUSSERKONTROLLE, Bonez MC\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 1142, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"FLY\", \"Streams\": 4681054, \"Artist\": \"KC Rebell, Summer Cem\", \"Artist Followers\": 1101597.0, \"Song ID\": \"1WoM4mof0Nl1xPtwf6h6ow\", \"Genre\": \"['german drill', 'german hip hop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 59.0, \"Danceability\": 0.835, \"Energy\": 0.596, \"Loudness\": -6.637, \"Speechiness\": 0.297, \"Acousticness\": 0.137, \"Liveness\": 0.164, \"Tempo\": 100.706, \"Duration (ms)\": 174893.0, \"Valence\": 0.897, \"Chord\": \"F\"}, {\"Index\": 1143, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"SKRR\", \"Streams\": 4629320, \"Artist\": \"KALIM, Ufo361\", \"Artist Followers\": 218931.0, \"Song ID\": \"2J0adlQth373uw9y0yqWAz\", \"Genre\": \"['german hip hop', 'german trap', 'german underground rap', 'hamburg hip hop']\", \"Release Date\": \"2020-09-24\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 60.0, \"Danceability\": 0.803, \"Energy\": 0.649, \"Loudness\": -6.599, \"Speechiness\": 0.132, \"Acousticness\": 0.163, \"Liveness\": 0.152, \"Tempo\": 125.038, \"Duration (ms)\": 119040.0, \"Valence\": 0.584, \"Chord\": \"A#/Bb\"}, {\"Index\": 1144, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"T.D (Lil Yachty & Tierra Whack feat. A$AP Rocky & Tyler, The Creator)\", \"Streams\": 4601709, \"Artist\": \"Lil Yachty\", \"Artist Followers\": 7358720.0, \"Song ID\": \"0gO3E51A3fqp0ypJ26QbVP\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap', 'underground hip hop', 'viral rap']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 66.0, \"Danceability\": 0.784, \"Energy\": 0.632, \"Loudness\": -6.083, \"Speechiness\": 0.347, \"Acousticness\": 0.156, \"Liveness\": 0.605, \"Tempo\": 124.603, \"Duration (ms)\": 232839.0, \"Valence\": 0.746, \"Chord\": \"A#/Bb\"}, {\"Index\": 1145, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Oprah's Bank Account (Lil Yachty & DaBaby feat. Drake)\", \"Streams\": 4598294, \"Artist\": \"Lil Yachty\", \"Artist Followers\": 7358720.0, \"Song ID\": \"7wsmIIm0xWmtP7TmACXkJn\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap', 'underground hip hop', 'viral rap']\", \"Release Date\": \"2020-03-09\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 69.0, \"Danceability\": 0.836, \"Energy\": 0.617, \"Loudness\": -4.363, \"Speechiness\": 0.0534, \"Acousticness\": 0.17, \"Liveness\": 0.319, \"Tempo\": 138.066, \"Duration (ms)\": 206702.0, \"Valence\": 0.866, \"Chord\": \"C\"}, {\"Index\": 1146, \"Highest Charting Position\": 78, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Roadrunner\", \"Streams\": 4596162, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"0atjNG0rNW2m6zPaiK4Co7\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 64.0, \"Danceability\": 0.804, \"Energy\": 0.606, \"Loudness\": -9.045, \"Speechiness\": 0.242, \"Acousticness\": 0.137, \"Liveness\": 0.111, \"Tempo\": 99.024, \"Duration (ms)\": 149028.0, \"Valence\": 0.247, \"Chord\": \"G\"}, {\"Index\": 1147, \"Highest Charting Position\": 99, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Freedom\", \"Streams\": 4573723, \"Artist\": \"Kygo, Zak Abel\", \"Artist Followers\": 7593792.0, \"Song ID\": \"5Gj1wG8b12VQdEd3hUuSwo\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-05-29--2020-06-05\\n2020-04-17--2020-04-24\", \"Popularity\": 72.0, \"Danceability\": 0.715, \"Energy\": 0.635, \"Loudness\": -6.591, \"Speechiness\": 0.0791, \"Acousticness\": 0.127, \"Liveness\": 0.0862, \"Tempo\": 112.887, \"Duration (ms)\": 198635.0, \"Valence\": 0.39, \"Chord\": \"G\"}, {\"Index\": 1148, \"Highest Charting Position\": 45, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Fame\", \"Streams\": 4556947, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"3goH7O78TLkV9RhCAyM4AT\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 62.0, \"Danceability\": 0.811, \"Energy\": 0.645, \"Loudness\": -8.008, \"Speechiness\": 0.104, \"Acousticness\": 0.184, \"Liveness\": 0.103, \"Tempo\": 129.967, \"Duration (ms)\": 173761.0, \"Valence\": 0.474, \"Chord\": \"C#/Db\"}, {\"Index\": 1149, \"Highest Charting Position\": 55, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Daechwita\", \"Streams\": 8908179, \"Artist\": \"Agust D\", \"Artist Followers\": 5564366.0, \"Song ID\": \"0H4ugk6rhnXmTl47ayy9O5\", \"Genre\": \"['k-rap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 77.0, \"Danceability\": 0.65, \"Energy\": 0.827, \"Loudness\": -4.014, \"Speechiness\": 0.0599, \"Acousticness\": 0.0229, \"Liveness\": 0.121, \"Tempo\": 144.995, \"Duration (ms)\": 225668.0, \"Valence\": 0.223, \"Chord\": \"G#/Ab\"}, {\"Index\": 1150, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"COOLER THAN A BITCH (feat. Roddy Ricch)\", \"Streams\": 6642144, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"5LHHKZOwV8XW4LJP2C64mw\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 67.0, \"Danceability\": 0.837, \"Energy\": 0.586, \"Loudness\": -8.521, \"Speechiness\": 0.0807, \"Acousticness\": 0.281, \"Liveness\": 0.134, \"Tempo\": 117.066, \"Duration (ms)\": 197000.0, \"Valence\": 0.618, \"Chord\": \"B\"}, {\"Index\": 1151, \"Highest Charting Position\": 90, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"In Your Eyes (with Doja Cat) - Remix\", \"Streams\": 6511008, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"0UnTaVkntyh3vqvLEvbpQx\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-05-21\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 67.0, \"Danceability\": 0.679, \"Energy\": 0.731, \"Loudness\": -5.522, \"Speechiness\": 0.0319, \"Acousticness\": 0.00518, \"Liveness\": 0.0614, \"Tempo\": 99.984, \"Duration (ms)\": 237912.0, \"Valence\": 0.727, \"Chord\": \"G\"}, {\"Index\": 1152, \"Highest Charting Position\": 92, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"WUNNA\", \"Streams\": 6384306, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"0y7Ao3CVJsyKFmqdjutiIF\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 60.0, \"Danceability\": 0.89, \"Energy\": 0.455, \"Loudness\": -9.0, \"Speechiness\": 0.255, \"Acousticness\": 0.0217, \"Liveness\": 0.11, \"Tempo\": 148.009, \"Duration (ms)\": 158240.0, \"Valence\": 0.313, \"Chord\": \"C\"}, {\"Index\": 1153, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Komm Komm\", \"Streams\": 5552890, \"Artist\": \"Capital Bra\", \"Artist Followers\": 4093115.0, \"Song ID\": \"3US6RbELvvrPw3DcvtJmis\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-05-21\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 53.0, \"Danceability\": 0.485, \"Energy\": 0.793, \"Loudness\": -3.836, \"Speechiness\": 0.426, \"Acousticness\": 0.251, \"Liveness\": 0.146, \"Tempo\": 87.629, \"Duration (ms)\": 160667.0, \"Valence\": 0.371, \"Chord\": \"B\"}, {\"Index\": 1154, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"TOP FLOOR (feat. Travis Scott)\", \"Streams\": 5193309, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"4YhJ3a6kBPGJWX4Ek77sDd\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 63.0, \"Danceability\": 0.823, \"Energy\": 0.504, \"Loudness\": -8.65, \"Speechiness\": 0.16, \"Acousticness\": 0.206, \"Liveness\": 0.417, \"Tempo\": 112.985, \"Duration (ms)\": 169907.0, \"Valence\": 0.481, \"Chord\": \"G#/Ab\"}, {\"Index\": 1155, \"Highest Charting Position\": 54, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Goodbyes (Feat. Young Thug)\", \"Streams\": 5134161, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"0t3ZvGKlmYmVsDzBJAXK8C\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.548, \"Energy\": 0.653, \"Loudness\": -3.875, \"Speechiness\": 0.081, \"Acousticness\": 0.456, \"Liveness\": 0.103, \"Tempo\": 150.068, \"Duration (ms)\": 174853.0, \"Valence\": 0.163, \"Chord\": \"F\"}, {\"Index\": 1156, \"Highest Charting Position\": 59, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"CANCI\\u00d3N CON YANDEL\", \"Streams\": 5132247, \"Artist\": \"Yandel, Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3pm4XtcsRIFFtH2UErk62R\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 76.0, \"Danceability\": 0.75, \"Energy\": 0.741, \"Loudness\": -4.43, \"Speechiness\": 0.402, \"Acousticness\": 0.447, \"Liveness\": 0.121, \"Tempo\": 79.968, \"Duration (ms)\": 209180.0, \"Valence\": 0.495, \"Chord\": \"A\"}, {\"Index\": 1157, \"Highest Charting Position\": 92, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"X (with KAROL G)\", \"Streams\": 5018592, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"77fvnWALKJR0ws1VUx09CY\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 70.0, \"Danceability\": 0.715, \"Energy\": 0.827, \"Loudness\": -5.09, \"Speechiness\": 0.0617, \"Acousticness\": 0.0485, \"Liveness\": 0.321, \"Tempo\": 117.977, \"Duration (ms)\": 185277.0, \"Valence\": 0.75, \"Chord\": \"E\"}, {\"Index\": 1158, \"Highest Charting Position\": 56, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"M\\u00c1S DE UNA CITA\", \"Streams\": 4987116, \"Artist\": \"Bad Bunny, Zion & Lennox\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4EJHKSnHENfjOxXWryyNtL\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 67.0, \"Danceability\": 0.865, \"Energy\": 0.5, \"Loudness\": -10.805, \"Speechiness\": 0.0861, \"Acousticness\": 0.0122, \"Liveness\": 0.098, \"Tempo\": 92.976, \"Duration (ms)\": 183520.0, \"Valence\": 0.317, \"Chord\": \"F\"}, {\"Index\": 1159, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Together\", \"Streams\": 4861870, \"Artist\": \"Sia\", \"Artist Followers\": 20528724.0, \"Song ID\": \"5id3Rqn7SPj1LX4FfY4nGz\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'pop']\", \"Release Date\": \"2020-05-20\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 71.0, \"Danceability\": 0.521, \"Energy\": 0.877, \"Loudness\": -5.444, \"Speechiness\": 0.0683, \"Acousticness\": 0.0132, \"Liveness\": 0.0929, \"Tempo\": 180.007, \"Duration (ms)\": 205208.0, \"Valence\": 0.199, \"Chord\": \"G\"}, {\"Index\": 1160, \"Highest Charting Position\": 62, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"eight(Prod.&Feat. SUGA of BTS)\", \"Streams\": 4764954, \"Artist\": \"IU\", \"Artist Followers\": 4939593.0, \"Song ID\": \"0pYacDCZuRhcrwGUA5nTBe\", \"Genre\": \"['k-pop']\", \"Release Date\": \"2020-05-06\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 75.0, \"Danceability\": 0.676, \"Energy\": 0.869, \"Loudness\": -1.573, \"Speechiness\": 0.0423, \"Acousticness\": 0.115, \"Liveness\": 0.132, \"Tempo\": 120.029, \"Duration (ms)\": 167573.0, \"Valence\": 0.594, \"Chord\": \"C#/Db\"}, {\"Index\": 1161, \"Highest Charting Position\": 16, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"You should be sad\", \"Streams\": 4761908, \"Artist\": \"Halsey\", \"Artist Followers\": 15663384.0, \"Song ID\": \"7lidXGPXPYLNThITAOTlkK\", \"Genre\": \"['dance pop', 'electropop', 'etherpop', 'indie poptimism', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 76.0, \"Danceability\": 0.591, \"Energy\": 0.585, \"Loudness\": -6.35, \"Speechiness\": 0.0277, \"Acousticness\": 0.143, \"Liveness\": 0.109, \"Tempo\": 110.94, \"Duration (ms)\": 205473.0, \"Valence\": 0.324, \"Chord\": \"D\"}, {\"Index\": 1162, \"Highest Charting Position\": 54, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"CITY OF ANGELS\", \"Streams\": 4645541, \"Artist\": \"24kGoldn\", \"Artist Followers\": 1276406.0, \"Song ID\": \"6ap9lSRJ0iLriGLqoJ44cq\", \"Genre\": \"['cali rap']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 76.0, \"Danceability\": 0.686, \"Energy\": 0.541, \"Loudness\": -4.993, \"Speechiness\": 0.0493, \"Acousticness\": 0.042, \"Liveness\": 0.0675, \"Tempo\": 120.082, \"Duration (ms)\": 112493.0, \"Valence\": 0.724, \"Chord\": \"C\"}, {\"Index\": 1163, \"Highest Charting Position\": 98, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Astronomia\", \"Streams\": 4642284, \"Artist\": \"Vicetone, Tony Igy\", \"Artist Followers\": 378114.0, \"Song ID\": \"3hWfKBt3n7j1xqIy6LA5ve\", \"Genre\": \"['edm', 'electro house', 'pop dance', 'pop edm', 'progressive electro house', 'tropical house']\", \"Release Date\": \"2016-09-16\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 71.0, \"Danceability\": 0.653, \"Energy\": 0.945, \"Loudness\": -2.634, \"Speechiness\": 0.096, \"Acousticness\": 0.00561, \"Liveness\": 0.439, \"Tempo\": 126.093, \"Duration (ms)\": 198095.0, \"Valence\": 0.326, \"Chord\": \"F\"}, {\"Index\": 1164, \"Highest Charting Position\": 7, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"After Hours\", \"Streams\": 4559855, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"2p8IUWQDrpjuFltbdgLOag\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 75.0, \"Danceability\": 0.664, \"Energy\": 0.572, \"Loudness\": -6.099, \"Speechiness\": 0.0305, \"Acousticness\": 0.0811, \"Liveness\": 0.121, \"Tempo\": 108.959, \"Duration (ms)\": 361027.0, \"Valence\": 0.143, \"Chord\": \"F\"}, {\"Index\": 1165, \"Highest Charting Position\": 51, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"BUTTERFLY EFFECT\", \"Streams\": 4537762, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"2cYqizR4lgvp4Qu6IQ3qGN\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2018-08-03\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 79.0, \"Danceability\": 0.763, \"Energy\": 0.628, \"Loudness\": -5.85, \"Speechiness\": 0.05, \"Acousticness\": 0.0531, \"Liveness\": 0.114, \"Tempo\": 140.958, \"Duration (ms)\": 190557.0, \"Valence\": 0.193, \"Chord\": \"B\"}, {\"Index\": 1166, \"Highest Charting Position\": 74, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Never Seen the Rain\", \"Streams\": 4473968, \"Artist\": \"Tones And I\", \"Artist Followers\": 1251372.0, \"Song ID\": \"1xUCDewhwnORlcFflAgml0\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.742, \"Energy\": 0.464, \"Loudness\": -5.624, \"Speechiness\": 0.0318, \"Acousticness\": 0.425, \"Liveness\": 0.284, \"Tempo\": 92.107, \"Duration (ms)\": 200742.0, \"Valence\": 0.281, \"Chord\": \"F#/Gb\"}, {\"Index\": 1167, \"Highest Charting Position\": 120, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Sigues Con El - Remix\", \"Streams\": 4440738, \"Artist\": \"Arcangel, Sech, Romeo Santos\", \"Artist Followers\": 6671084.0, \"Song ID\": \"4Pu0a2TuHOYtI4CCE3HEXI\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-04-10\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 69.0, \"Danceability\": 0.747, \"Energy\": 0.693, \"Loudness\": -2.97, \"Speechiness\": 0.298, \"Acousticness\": 0.102, \"Liveness\": 0.0872, \"Tempo\": 175.994, \"Duration (ms)\": 189567.0, \"Valence\": 0.736, \"Chord\": \"C#/Db\"}, {\"Index\": 1168, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"ANGELS & DEMONS\", \"Streams\": 4435538, \"Artist\": \"jxdn\", \"Artist Followers\": 799682.0, \"Song ID\": \"3mkz6eI4Sram8UhO3teU76\", \"Genre\": \"[]\", \"Release Date\": \"2021-07-02\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 72.0, \"Danceability\": 0.554, \"Energy\": 0.8, \"Loudness\": -3.936, \"Speechiness\": 0.0395, \"Acousticness\": 0.119, \"Liveness\": 0.629, \"Tempo\": 115.056, \"Duration (ms)\": 160120.0, \"Valence\": 0.463, \"Chord\": \"G#/Ab\"}, {\"Index\": 1169, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Conf\\u00eda\", \"Streams\": 4419295, \"Artist\": \"Sech, Daddy Yankee\", \"Artist Followers\": 8766508.0, \"Song ID\": \"5kbps8unnGH4raN5WduZuq\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-21\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 62.0, \"Danceability\": 0.722, \"Energy\": 0.757, \"Loudness\": -3.592, \"Speechiness\": 0.0782, \"Acousticness\": 0.17, \"Liveness\": 0.0657, \"Tempo\": 167.987, \"Duration (ms)\": 202308.0, \"Valence\": 0.763, \"Chord\": \"C\"}, {\"Index\": 1170, \"Highest Charting Position\": 44, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Mu\\u00e9velo\", \"Streams\": 4407165, \"Artist\": \"Nicky Jam, Daddy Yankee\", \"Artist Followers\": 14831925.0, \"Song ID\": \"4VgYtXCVJ7IbWAZ5ryfvEQ\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-01-08\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 72.0, \"Danceability\": 0.594, \"Energy\": 0.808, \"Loudness\": -2.409, \"Speechiness\": 0.0489, \"Acousticness\": 0.415, \"Liveness\": 0.565, \"Tempo\": 188.09, \"Duration (ms)\": 194892.0, \"Valence\": 0.919, \"Chord\": \"G\"}, {\"Index\": 1171, \"Highest Charting Position\": 105, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"All Bad (feat. Lil Uzi Vert)\", \"Streams\": 6194224, \"Artist\": \"Future\", \"Artist Followers\": 10491105.0, \"Song ID\": \"021lWIHJrURZrmvYQ1xcM8\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 60.0, \"Danceability\": 0.931, \"Energy\": 0.667, \"Loudness\": -7.043, \"Speechiness\": 0.318, \"Acousticness\": 0.0144, \"Liveness\": 0.15, \"Tempo\": 142.039, \"Duration (ms)\": 207739.0, \"Valence\": 0.667, \"Chord\": \"F#/Gb\"}, {\"Index\": 1172, \"Highest Charting Position\": 12, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Pain 1993 (with Playboi Carti)\", \"Streams\": 6085143, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"6Kj17Afjo1OKJYpf5VzCeo\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 67.0, \"Danceability\": 0.825, \"Energy\": 0.373, \"Loudness\": -5.532, \"Speechiness\": 0.108, \"Acousticness\": 0.163, \"Liveness\": 0.368, \"Tempo\": 77.271, \"Duration (ms)\": 149078.0, \"Valence\": 0.12, \"Chord\": \"F\"}, {\"Index\": 1173, \"Highest Charting Position\": 110, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Trillionaire (feat. Youngboy Never Broke Again)\", \"Streams\": 6057848, \"Artist\": \"Future\", \"Artist Followers\": 10491105.0, \"Song ID\": \"740kQ8xwSGloumdiKR5Cwz\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 61.0, \"Danceability\": 0.768, \"Energy\": 0.526, \"Loudness\": -7.182, \"Speechiness\": 0.209, \"Acousticness\": 0.237, \"Liveness\": 0.139, \"Tempo\": 139.999, \"Duration (ms)\": 167552.0, \"Valence\": 0.473, \"Chord\": \"C\"}, {\"Index\": 1174, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Go Stupid\", \"Streams\": 5464816, \"Artist\": \"Polo G, Stunna 4 Vegas, NLE Choppa, Mike WiLL Made-It\", \"Artist Followers\": 4849204.0, \"Song ID\": \"4PklAHGXT5ityno3IA8SKd\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 74.0, \"Danceability\": 0.92, \"Energy\": 0.833, \"Loudness\": -3.18, \"Speechiness\": 0.253, \"Acousticness\": 0.0277, \"Liveness\": 0.0596, \"Tempo\": 141.034, \"Duration (ms)\": 165726.0, \"Valence\": 0.645, \"Chord\": \"C#/Db\"}, {\"Index\": 1175, \"Highest Charting Position\": 149, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"A Gente Fez Amor - Ao Vivo\", \"Streams\": 5006457, \"Artist\": \"Gusttavo Lima\", \"Artist Followers\": 12981319.0, \"Song ID\": \"3tv697PZNnaQN0Mn2zGhS5\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2019-12-05\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-02-07--2020-02-14\\n2020-01-03--2020-01-10\", \"Popularity\": 66.0, \"Danceability\": 0.794, \"Energy\": 0.937, \"Loudness\": -2.44, \"Speechiness\": 0.0336, \"Acousticness\": 0.366, \"Liveness\": 0.962, \"Tempo\": 134.012, \"Duration (ms)\": 237517.0, \"Valence\": 0.826, \"Chord\": \"G#/Ab\"}, {\"Index\": 1176, \"Highest Charting Position\": 173, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Racks 2 Skinny\", \"Streams\": 4729629, \"Artist\": \"Migos\", \"Artist Followers\": 11692972.0, \"Song ID\": \"568OIKgeHyGRD3uWR44JbO\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-11\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 61.0, \"Danceability\": 0.814, \"Energy\": 0.584, \"Loudness\": -5.425, \"Speechiness\": 0.0819, \"Acousticness\": 0.00839, \"Liveness\": 0.0646, \"Tempo\": 141.016, \"Duration (ms)\": 178025.0, \"Valence\": 0.405, \"Chord\": \"C#/Db\"}, {\"Index\": 1177, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Be Something (feat. Lil Baby)\", \"Streams\": 4687909, \"Artist\": \"Polo G\", \"Artist Followers\": 4849204.0, \"Song ID\": \"65jw6GhwQW3Db55PxlPEpS\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 69.0, \"Danceability\": 0.829, \"Energy\": 0.52, \"Loudness\": -10.34, \"Speechiness\": 0.294, \"Acousticness\": 0.0232, \"Liveness\": 0.134, \"Tempo\": 136.103, \"Duration (ms)\": 194118.0, \"Valence\": 0.248, \"Chord\": \"G#/Ab\"}, {\"Index\": 1178, \"Highest Charting Position\": 82, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"BENDICIONES\", \"Streams\": 4639997, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2CoMYp2uIKsT09nreEZnZn\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 67.0, \"Danceability\": 0.828, \"Energy\": 0.581, \"Loudness\": -9.909, \"Speechiness\": 0.0725, \"Acousticness\": 0.0378, \"Liveness\": 0.103, \"Tempo\": 143.995, \"Duration (ms)\": 155060.0, \"Valence\": 0.843, \"Chord\": \"B\"}, {\"Index\": 1179, \"Highest Charting Position\": 126, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"PTSD\", \"Streams\": 4500903, \"Artist\": \"G Herbo, Juice WRLD, Lil Uzi Vert, Chance the Rapper\", \"Artist Followers\": 1253138.0, \"Song ID\": \"1C8ux1YWLMHCenYJFiIV4Z\", \"Genre\": \"['chicago drill', 'chicago rap', 'drill', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-02-28--2020-03-06\", \"Popularity\": 76.0, \"Danceability\": 0.883, \"Energy\": 0.808, \"Loudness\": -3.158, \"Speechiness\": 0.182, \"Acousticness\": 0.0313, \"Liveness\": 0.207, \"Tempo\": 119.01, \"Duration (ms)\": 232065.0, \"Valence\": 0.806, \"Chord\": \"C#/Db\"}, {\"Index\": 1180, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Excitement\", \"Streams\": 4416484, \"Artist\": \"Trippie Redd, PARTYNEXTDOOR\", \"Artist Followers\": 6434201.0, \"Song ID\": \"7FullO2NDkyvxLuxYVKINa\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 69.0, \"Danceability\": 0.443, \"Energy\": 0.536, \"Loudness\": -8.187, \"Speechiness\": 0.0378, \"Acousticness\": 0.0194, \"Liveness\": 0.1, \"Tempo\": 121.967, \"Duration (ms)\": 283285.0, \"Valence\": 0.0391, \"Chord\": \"E\"}, {\"Index\": 1181, \"Highest Charting Position\": 131, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Can We Kiss Forever?\", \"Streams\": 4397385, \"Artist\": \"Kina, Adriana Proenza\", \"Artist Followers\": 661863.0, \"Song ID\": \"58wyJLv6yH1La9NIZPl3ne\", \"Genre\": \"['sad rap']\", \"Release Date\": \"2018-08-31\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.522, \"Energy\": 0.128, \"Loudness\": -18.717, \"Speechiness\": 0.0357, \"Acousticness\": 0.894, \"Liveness\": 0.0941, \"Tempo\": 109.986, \"Duration (ms)\": 187932.0, \"Valence\": 0.124, \"Chord\": \"E\"}, {\"Index\": 1182, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"SI ELLA SALE\", \"Streams\": 7055918, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"1zaDh3qaGSeSmulNyWlUxm\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 63.0, \"Danceability\": 0.869, \"Energy\": 0.727, \"Loudness\": -7.397, \"Speechiness\": 0.123, \"Acousticness\": 0.0589, \"Liveness\": 0.107, \"Tempo\": 147.967, \"Duration (ms)\": 143240.0, \"Valence\": 0.92, \"Chord\": \"G\"}, {\"Index\": 1183, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"RONCA FREESTYLE\", \"Streams\": 5784075, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3XZeOzJ9tqnu58YP6cqApI\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 64.0, \"Danceability\": 0.856, \"Energy\": 0.656, \"Loudness\": -6.483, \"Speechiness\": 0.131, \"Acousticness\": 0.165, \"Liveness\": 0.0998, \"Tempo\": 90.041, \"Duration (ms)\": 150060.0, \"Valence\": 0.586, \"Chord\": \"F\"}, {\"Index\": 1184, \"Highest Charting Position\": 130, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Zoo York (feat. Fivio Foreign & Pop Smoke)\", \"Streams\": 5368705, \"Artist\": \"Lil Tjay\", \"Artist Followers\": 3559267.0, \"Song ID\": \"3Ddny34bFoYBb8dIGq5lwp\", \"Genre\": \"['brooklyn drill', 'melodic rap', 'nyc rap']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 70.0, \"Danceability\": 0.565, \"Energy\": 0.569, \"Loudness\": -6.084, \"Speechiness\": 0.379, \"Acousticness\": 0.0352, \"Liveness\": 0.106, \"Tempo\": 92.466, \"Duration (ms)\": 214825.0, \"Valence\": 0.303, \"Chord\": \"F#/Gb\"}, {\"Index\": 1185, \"Highest Charting Position\": 131, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"EN CASITA\", \"Streams\": 5364262, \"Artist\": \"Bad Bunny, Gabriela\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2DhNdoHxavs7Qtf5MnhZD0\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 62.0, \"Danceability\": 0.779, \"Energy\": 0.764, \"Loudness\": -8.217, \"Speechiness\": 0.0938, \"Acousticness\": 0.221, \"Liveness\": 0.0909, \"Tempo\": 158.093, \"Duration (ms)\": 176440.0, \"Valence\": 0.675, \"Chord\": \"C\"}, {\"Index\": 1186, \"Highest Charting Position\": 71, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Qu\\u00e9 Maldici\\u00f3n\", \"Streams\": 4971559, \"Artist\": \"Banda MS de Sergio Liz\\u00e1rraga, Snoop Dogg\", \"Artist Followers\": 12140496.0, \"Song ID\": \"2RxC2peY3FtrurYmbbmanr\", \"Genre\": \"['banda', 'corrido', 'norteno', 'regional mexican']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 69.0, \"Danceability\": 0.755, \"Energy\": 0.531, \"Loudness\": -8.051, \"Speechiness\": 0.196, \"Acousticness\": 0.213, \"Liveness\": 0.13, \"Tempo\": 177.951, \"Duration (ms)\": 203360.0, \"Valence\": 0.683, \"Chord\": \"A\"}, {\"Index\": 1187, \"Highest Charting Position\": 69, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Nicht verdient\", \"Streams\": 4912914, \"Artist\": \"Capital Bra, Loredana\", \"Artist Followers\": 4093115.0, \"Song ID\": \"7v8OynJxOxHoeS5C2UA9Y7\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-04-29\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 58.0, \"Danceability\": 0.719, \"Energy\": 0.65, \"Loudness\": -7.274, \"Speechiness\": 0.232, \"Acousticness\": 0.381, \"Liveness\": 0.167, \"Tempo\": 77.981, \"Duration (ms)\": 176953.0, \"Valence\": 0.488, \"Chord\": \"B\"}, {\"Index\": 1188, \"Highest Charting Position\": 52, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"A Tu Merced\", \"Streams\": 4909499, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4r9jkMEnArtWGH2rL2FZl0\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 82.0, \"Danceability\": 0.86, \"Energy\": 0.791, \"Loudness\": -4.784, \"Speechiness\": 0.0568, \"Acousticness\": 0.169, \"Liveness\": 0.106, \"Tempo\": 92.023, \"Duration (ms)\": 175918.0, \"Valence\": 0.887, \"Chord\": \"C\"}, {\"Index\": 1189, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Demons (feat. Fivio Foreign & Sosa Geek)\", \"Streams\": 4766829, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"05aZ9sAU1YXndHv0FMi9iW\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 63.0, \"Danceability\": 0.543, \"Energy\": 0.766, \"Loudness\": -3.387, \"Speechiness\": 0.343, \"Acousticness\": 0.423, \"Liveness\": 0.155, \"Tempo\": 106.869, \"Duration (ms)\": 204805.0, \"Valence\": 0.729, \"Chord\": \"C\"}, {\"Index\": 1190, \"Highest Charting Position\": 42, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Moral of the Story\", \"Streams\": 4609358, \"Artist\": \"Ashe\", \"Artist Followers\": 644479.0, \"Song ID\": \"2nC3QhMI9reBIOWutbU3Tj\", \"Genre\": \"['alt z', 'electropop', 'indie pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-02-14\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 75.0, \"Danceability\": 0.572, \"Energy\": 0.406, \"Loudness\": -8.624, \"Speechiness\": 0.0427, \"Acousticness\": 0.587, \"Liveness\": 0.102, \"Tempo\": 119.812, \"Duration (ms)\": 201084.0, \"Valence\": 0.265, \"Chord\": \"A#/Bb\"}, {\"Index\": 1191, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Can I\", \"Streams\": 4603243, \"Artist\": \"Kehlani\", \"Artist Followers\": 4894562.0, \"Song ID\": \"0uDdI4fAXCuNhQbmxENdsO\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop', 'r&b']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 68.0, \"Danceability\": 0.574, \"Energy\": 0.791, \"Loudness\": -3.752, \"Speechiness\": 0.11, \"Acousticness\": 0.419, \"Liveness\": 0.0982, \"Tempo\": 119.537, \"Duration (ms)\": 167810.0, \"Valence\": 0.612, \"Chord\": \"C#/Db\"}, {\"Index\": 1192, \"Highest Charting Position\": 46, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"STARGAZING\", \"Streams\": 4499820, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"7wBJfHzpfI3032CSD7CE2m\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2018-08-03\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 76.0, \"Danceability\": 0.487, \"Energy\": 0.789, \"Loudness\": -3.69, \"Speechiness\": 0.044, \"Acousticness\": 0.00947, \"Liveness\": 0.189, \"Tempo\": 150.007, \"Duration (ms)\": 270715.0, \"Valence\": 0.0564, \"Chord\": \"G#/Ab\"}, {\"Index\": 1193, \"Highest Charting Position\": 124, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Eastside (with Halsey & Khalid)\", \"Streams\": 4397708, \"Artist\": \"benny blanco\", \"Artist Followers\": 804613.0, \"Song ID\": \"0d2iYfpKoM0QCKvcLCkBao\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2018-07-12\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.56, \"Energy\": 0.68, \"Loudness\": -7.648, \"Speechiness\": 0.321, \"Acousticness\": 0.555, \"Liveness\": 0.116, \"Tempo\": 89.391, \"Duration (ms)\": 173800.0, \"Valence\": 0.319, \"Chord\": \"F#/Gb\"}, {\"Index\": 1194, \"Highest Charting Position\": 23, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Suicidal\", \"Streams\": 4320116, \"Artist\": \"YNW Melly\", \"Artist Followers\": 6332535.0, \"Song ID\": \"4S2uhQE8L9V6p7rj7SiauJ\", \"Genre\": \"['melodic rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.655, \"Energy\": 0.441, \"Loudness\": -5.245, \"Speechiness\": 0.0629, \"Acousticness\": 0.474, \"Liveness\": 0.099, \"Tempo\": 139.957, \"Duration (ms)\": 225857.0, \"Valence\": 0.273, \"Chord\": \"A\"}, {\"Index\": 1195, \"Highest Charting Position\": 39, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"How Do You Sleep?\", \"Streams\": 4313625, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"6b2RcmUt1g9N9mQ3CbjX2Y\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2019-07-19\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.477, \"Energy\": 0.682, \"Loudness\": -4.931, \"Speechiness\": 0.0925, \"Acousticness\": 0.153, \"Liveness\": 0.0763, \"Tempo\": 110.567, \"Duration (ms)\": 202205.0, \"Valence\": 0.345, \"Chord\": \"C#/Db\"}, {\"Index\": 1196, \"Highest Charting Position\": 4, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"No Time To Die\", \"Streams\": 4293009, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"73SpzrcaHk0RQPFP73vqVR\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2020-02-13\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 75.0, \"Danceability\": 0.38, \"Energy\": 0.219, \"Loudness\": -13.273, \"Speechiness\": 0.0358, \"Acousticness\": 0.917, \"Liveness\": 0.0827, \"Tempo\": 73.537, \"Duration (ms)\": 242265.0, \"Valence\": 0.0517, \"Chord\": \"E\"}, {\"Index\": 1197, \"Highest Charting Position\": 46, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"D4L\", \"Streams\": 10537097, \"Artist\": \"Future, Drake, Young Thug\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5fHrHoJKfCgBd35zwIBmUK\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 63.0, \"Danceability\": 0.718, \"Energy\": 0.706, \"Loudness\": -5.709, \"Speechiness\": 0.06, \"Acousticness\": 0.0128, \"Liveness\": 0.352, \"Tempo\": 170.004, \"Duration (ms)\": 189176.0, \"Valence\": 0.815, \"Chord\": \"C#/Db\"}, {\"Index\": 1198, \"Highest Charting Position\": 51, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Time Flies\", \"Streams\": 9904749, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5H4mXWKcicuLKDn4Jy0sK7\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 71.0, \"Danceability\": 0.864, \"Energy\": 0.477, \"Loudness\": -5.786, \"Speechiness\": 0.224, \"Acousticness\": 0.201, \"Liveness\": 0.182, \"Tempo\": 86.46, \"Duration (ms)\": 192932.0, \"Valence\": 0.5, \"Chord\": \"A#/Bb\"}, {\"Index\": 1199, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Desires (with Future)\", \"Streams\": 9628215, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"7eYAHC0RbBF9eaqWzT34Aq\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.812, \"Energy\": 0.506, \"Loudness\": -7.706, \"Speechiness\": 0.116, \"Acousticness\": 0.281, \"Liveness\": 0.325, \"Tempo\": 145.074, \"Duration (ms)\": 237946.0, \"Valence\": 0.554, \"Chord\": \"F\"}, {\"Index\": 1200, \"Highest Charting Position\": 55, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Not You Too (feat. Chris Brown)\", \"Streams\": 9284383, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"3Q4gttWQ6hxqWOa3tHoTNi\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.458, \"Energy\": 0.452, \"Loudness\": -9.299, \"Speechiness\": 0.047, \"Acousticness\": 0.342, \"Liveness\": 0.0703, \"Tempo\": 86.318, \"Duration (ms)\": 269680.0, \"Valence\": 0.316, \"Chord\": \"A\"}, {\"Index\": 1201, \"Highest Charting Position\": 67, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Landed\", \"Streams\": 8355036, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"3KixNgUEaDtrKJVzdqjU5q\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 60.0, \"Danceability\": 0.881, \"Energy\": 0.636, \"Loudness\": -4.629, \"Speechiness\": 0.287, \"Acousticness\": 0.00606, \"Liveness\": 0.111, \"Tempo\": 163.949, \"Duration (ms)\": 152195.0, \"Valence\": 0.715, \"Chord\": \"G\"}, {\"Index\": 1202, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"When To Say When\", \"Streams\": 8304928, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5TCBWmEBrin7etRa4Lswr1\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 60.0, \"Danceability\": 0.41, \"Energy\": 0.82, \"Loudness\": -6.808, \"Speechiness\": 0.533, \"Acousticness\": 0.252, \"Liveness\": 0.538, \"Tempo\": 170.718, \"Duration (ms)\": 223124.0, \"Valence\": 0.526, \"Chord\": \"C#/Db\"}, {\"Index\": 1203, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Deep Pockets\", \"Streams\": 8285754, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"3IvMYBE7A3c7to1aEcfFJk\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 58.0, \"Danceability\": 0.473, \"Energy\": 0.824, \"Loudness\": -3.68, \"Speechiness\": 0.163, \"Acousticness\": 0.482, \"Liveness\": 0.605, \"Tempo\": 77.888, \"Duration (ms)\": 222929.0, \"Valence\": 0.374, \"Chord\": \"G\"}, {\"Index\": 1204, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"War\", \"Streams\": 7821869, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"1I55Ea0zVoSKs6MqW7DQ3i\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.749, \"Energy\": 0.792, \"Loudness\": -4.151, \"Speechiness\": 0.0826, \"Acousticness\": 0.292, \"Liveness\": 0.109, \"Tempo\": 144.064, \"Duration (ms)\": 180000.0, \"Valence\": 0.239, \"Chord\": \"A#/Bb\"}, {\"Index\": 1205, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"From Florida With Love\", \"Streams\": 7216610, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"0YkUwXxnTkeJBvt5upeEtP\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.787, \"Energy\": 0.477, \"Loudness\": -7.837, \"Speechiness\": 0.199, \"Acousticness\": 0.768, \"Liveness\": 0.104, \"Tempo\": 80.506, \"Duration (ms)\": 234783.0, \"Valence\": 0.476, \"Chord\": \"F#/Gb\"}, {\"Index\": 1206, \"Highest Charting Position\": 89, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Losses\", \"Streams\": 6894756, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"6fLVTVaHWaEfVKfEgbkf4D\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 57.0, \"Danceability\": 0.551, \"Energy\": 0.57, \"Loudness\": -7.385, \"Speechiness\": 0.351, \"Acousticness\": 0.28, \"Liveness\": 0.424, \"Tempo\": 85.687, \"Duration (ms)\": 271184.0, \"Valence\": 0.505, \"Chord\": \"C#/Db\"}, {\"Index\": 1207, \"Highest Charting Position\": 25, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Turks (feat. Travis Scott)\", \"Streams\": 5594561, \"Artist\": \"NAV, Gunna\", \"Artist Followers\": 2613211.0, \"Song ID\": \"0lSZh5W0wDeurkGzLYY6hf\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'hip hop', 'melodic rap', 'pop rap', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 70.0, \"Danceability\": 0.893, \"Energy\": 0.618, \"Loudness\": -4.425, \"Speechiness\": 0.112, \"Acousticness\": 0.0827, \"Liveness\": 0.542, \"Tempo\": 119.099, \"Duration (ms)\": 161377.0, \"Valence\": 0.389, \"Chord\": \"G\"}, {\"Index\": 1208, \"Highest Charting Position\": 40, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Boyfriend\", \"Streams\": 5236730, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4QnC1bIaMSfDQvF4XDhV5M\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 62.0, \"Danceability\": 0.811, \"Energy\": 0.512, \"Loudness\": -6.381, \"Speechiness\": 0.17, \"Acousticness\": 0.218, \"Liveness\": 0.0768, \"Tempo\": 92.046, \"Duration (ms)\": 161188.0, \"Valence\": 0.346, \"Chord\": \"D\"}, {\"Index\": 1209, \"Highest Charting Position\": 29, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"What If I Told You That I Love You\", \"Streams\": 5234645, \"Artist\": \"Ali Gatie\", \"Artist Followers\": 1758300.0, \"Song ID\": \"6USdi8uX5GNAPYziFhisHb\", \"Genre\": \"['canadian hip hop', 'pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 69.0, \"Danceability\": 0.596, \"Energy\": 0.366, \"Loudness\": -11.144, \"Speechiness\": 0.115, \"Acousticness\": 0.63, \"Liveness\": 0.0554, \"Tempo\": 84.394, \"Duration (ms)\": 193668.0, \"Valence\": 0.229, \"Chord\": \"G\"}, {\"Index\": 1210, \"Highest Charting Position\": 85, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Emotions\", \"Streams\": 4901960, \"Artist\": \"Ufo361\", \"Artist Followers\": 1700759.0, \"Song ID\": \"3yZCjDTxzZxx1kll1sRjGc\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 65.0, \"Danceability\": 0.788, \"Energy\": 0.491, \"Loudness\": -9.884, \"Speechiness\": 0.109, \"Acousticness\": 0.386, \"Liveness\": 0.107, \"Tempo\": 98.543, \"Duration (ms)\": 146028.0, \"Valence\": 0.271, \"Chord\": \"G#/Ab\"}, {\"Index\": 1211, \"Highest Charting Position\": 32, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"FIND MY WAY\", \"Streams\": 4753495, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"1gVCEnryJhkdQcuC0Kbvor\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 66.0, \"Danceability\": 0.836, \"Energy\": 0.624, \"Loudness\": -6.75, \"Speechiness\": 0.184, \"Acousticness\": 0.187, \"Liveness\": 0.138, \"Tempo\": 103.0, \"Duration (ms)\": 139890.0, \"Valence\": 0.7, \"Chord\": \"E\"}, {\"Index\": 1212, \"Highest Charting Position\": 37, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Keii\", \"Streams\": 4687605, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"5eEQCfq7MXQr6aHLNRUZLs\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 67.0, \"Danceability\": 0.708, \"Energy\": 0.797, \"Loudness\": -3.095, \"Speechiness\": 0.0391, \"Acousticness\": 0.4, \"Liveness\": 0.096, \"Tempo\": 88.015, \"Duration (ms)\": 210000.0, \"Valence\": 0.51, \"Chord\": \"C\"}, {\"Index\": 1213, \"Highest Charting Position\": 130, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"God's Plan\", \"Streams\": 4565400, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"6DCZcSspjsKoFjzjrWoCdn\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2018-06-29\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.754, \"Energy\": 0.449, \"Loudness\": -9.211, \"Speechiness\": 0.109, \"Acousticness\": 0.0332, \"Liveness\": 0.552, \"Tempo\": 77.169, \"Duration (ms)\": 198973.0, \"Valence\": 0.357, \"Chord\": \"G\"}, {\"Index\": 1214, \"Highest Charting Position\": 103, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Por Primera Vez\", \"Streams\": 4478685, \"Artist\": \"Camilo, Evaluna Montaner\", \"Artist Followers\": 10580764.0, \"Song ID\": \"0gWbAFRcUyZKdfUxEOuOiD\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-09\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 70.0, \"Danceability\": 0.716, \"Energy\": 0.588, \"Loudness\": -3.952, \"Speechiness\": 0.116, \"Acousticness\": 0.152, \"Liveness\": 0.0847, \"Tempo\": 165.896, \"Duration (ms)\": 183547.0, \"Valence\": 0.707, \"Chord\": \"C#/Db\"}, {\"Index\": 1215, \"Highest Charting Position\": 32, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"@ MEH\", \"Streams\": 4420187, \"Artist\": \"Playboi Carti\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5rffvRUaCvkPnkwMVcQYgZ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 1.0, \"Danceability\": 0.877, \"Energy\": 0.492, \"Loudness\": -8.11, \"Speechiness\": 0.153, \"Acousticness\": 0.0136, \"Liveness\": 0.0678, \"Tempo\": 151.042, \"Duration (ms)\": 166799.0, \"Valence\": 0.4, \"Chord\": \"B\"}, {\"Index\": 1216, \"Highest Charting Position\": 109, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Broke In A Minute\", \"Streams\": 4402281, \"Artist\": \"Tory Lanez\", \"Artist Followers\": 3828418.0, \"Song ID\": \"4xqIYGwwZTEem9U8A42SPF\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-04-10\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-02-07--2020-02-14\", \"Popularity\": 75.0, \"Danceability\": 0.929, \"Energy\": 0.7, \"Loudness\": -5.595, \"Speechiness\": 0.0906, \"Acousticness\": 0.144, \"Liveness\": 0.349, \"Tempo\": 120.009, \"Duration (ms)\": 132024.0, \"Valence\": 0.802, \"Chord\": \"C\"}, {\"Index\": 1217, \"Highest Charting Position\": 139, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Fantasias - Remix\", \"Streams\": 4401019, \"Artist\": \"Rauw Alejandro, Anuel AA, Natti Natasha, Farruko, Lunay\", \"Artist Followers\": 6096559.0, \"Song ID\": \"0A37XY67wSdGqkGjtfW6aV\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 70.0, \"Danceability\": 0.816, \"Energy\": 0.72, \"Loudness\": -4.454, \"Speechiness\": 0.0684, \"Acousticness\": 0.206, \"Liveness\": 0.277, \"Tempo\": 94.004, \"Duration (ms)\": 267242.0, \"Valence\": 0.78, \"Chord\": \"C#/Db\"}, {\"Index\": 1218, \"Highest Charting Position\": 38, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"SUGAR\", \"Streams\": 4362442, \"Artist\": \"BROCKHAMPTON\", \"Artist Followers\": 1836564.0, \"Song ID\": \"6U0FIYXCQ3TGrk4tFpLrEA\", \"Genre\": \"['boy band', 'hip hop', 'rap']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 75.0, \"Danceability\": 0.453, \"Energy\": 0.538, \"Loudness\": -8.212, \"Speechiness\": 0.0638, \"Acousticness\": 0.449, \"Liveness\": 0.19, \"Tempo\": 122.973, \"Duration (ms)\": 204533.0, \"Valence\": 0.516, \"Chord\": \"C#/Db\"}, {\"Index\": 1219, \"Highest Charting Position\": 112, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"90-60-111\", \"Streams\": 5750861, \"Artist\": \"Shirin David\", \"Artist Followers\": 559215.0, \"Song ID\": \"3ZdDYeaZzeYnrP4crgXzPk\", \"Genre\": \"['frauenrap', 'german hip hop', 'german pop']\", \"Release Date\": \"2020-04-23\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 64.0, \"Danceability\": 0.8, \"Energy\": 0.628, \"Loudness\": -6.615, \"Speechiness\": 0.285, \"Acousticness\": 0.103, \"Liveness\": 0.391, \"Tempo\": 143.979, \"Duration (ms)\": 141387.0, \"Valence\": 0.745, \"Chord\": \"D\"}, {\"Index\": 1220, \"Highest Charting Position\": 115, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"YOSEMITE\", \"Streams\": 5686981, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"7lAK3oHbfEnvUQWosrMMpR\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2018-08-03\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 75.0, \"Danceability\": 0.785, \"Energy\": 0.554, \"Loudness\": -6.571, \"Speechiness\": 0.0409, \"Acousticness\": 0.283, \"Liveness\": 0.116, \"Tempo\": 128.047, \"Duration (ms)\": 150043.0, \"Valence\": 0.144, \"Chord\": \"C\"}, {\"Index\": 1221, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Houdini (feat. Swarmz & Tion Wayne)\", \"Streams\": 4914429, \"Artist\": \"KSI\", \"Artist Followers\": 2010879.0, \"Song ID\": \"3lay6f81Lhy0qp2Uvp4cNJ\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 58.0, \"Danceability\": 0.572, \"Energy\": 0.519, \"Loudness\": -8.054, \"Speechiness\": 0.243, \"Acousticness\": 0.000415, \"Liveness\": 0.129, \"Tempo\": 100.453, \"Duration (ms)\": 169355.0, \"Valence\": 0.704, \"Chord\": \"A#/Bb\"}, {\"Index\": 1222, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Sasuke\", \"Streams\": 4701551, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"0ROE31C8Wu4neZoR9stM9e\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 56.0, \"Danceability\": 0.859, \"Energy\": 0.477, \"Loudness\": -6.116, \"Speechiness\": 0.428, \"Acousticness\": 0.00414, \"Liveness\": 0.0819, \"Tempo\": 145.979, \"Duration (ms)\": 251336.0, \"Valence\": 0.153, \"Chord\": \"C#/Db\"}, {\"Index\": 1223, \"Highest Charting Position\": 47, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Me Gusta\", \"Streams\": 4440661, \"Artist\": \"Shakira, Anuel AA\", \"Artist Followers\": 22136717.0, \"Song ID\": \"5Xhqh4lwJPtMUTsdBztN1a\", \"Genre\": \"['colombian pop', 'dance pop', 'latin', 'latin pop', 'pop']\", \"Release Date\": \"2020-01-13\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 72.0, \"Danceability\": 0.775, \"Energy\": 0.696, \"Loudness\": -5.184, \"Speechiness\": 0.0681, \"Acousticness\": 0.0559, \"Liveness\": 0.157, \"Tempo\": 92.007, \"Duration (ms)\": 190570.0, \"Valence\": 0.775, \"Chord\": \"C#/Db\"}, {\"Index\": 1224, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"If You\\u2019re Too Shy (Let Me Know) - Edit\", \"Streams\": 4429092, \"Artist\": \"The 1975\", \"Artist Followers\": 5044278.0, \"Song ID\": \"3iEqGBZ2wcpVzhiAcwXVC6\", \"Genre\": \"['modern alternative rock', 'modern rock', 'pop', 'rock']\", \"Release Date\": \"2020-04-23\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 59.0, \"Danceability\": 0.651, \"Energy\": 0.806, \"Loudness\": -4.842, \"Speechiness\": 0.0311, \"Acousticness\": 0.00399, \"Liveness\": 0.0927, \"Tempo\": 125.641, \"Duration (ms)\": 239877.0, \"Valence\": 0.386, \"Chord\": \"D\"}, {\"Index\": 1225, \"Highest Charting Position\": 80, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Alone, Pt. II\", \"Streams\": 4395061, \"Artist\": \"Alan Walker, Ava Max\", \"Artist Followers\": 29679430.0, \"Song ID\": \"0bMbDctzMmTyK2j74j3nF3\", \"Genre\": \"['electro house']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.67, \"Energy\": 0.668, \"Loudness\": -4.306, \"Speechiness\": 0.0422, \"Acousticness\": 0.536, \"Liveness\": 0.133, \"Tempo\": 88.033, \"Duration (ms)\": 179053.0, \"Valence\": 0.608, \"Chord\": \"D#/Eb\"}, {\"Index\": 1226, \"Highest Charting Position\": 97, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Tutu\", \"Streams\": 4393037, \"Artist\": \"Camilo, Pedro Cap\\u00f3\", \"Artist Followers\": 10580764.0, \"Song ID\": \"1nocRtwyNPVtGcIJqfgdzZ\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2019-08-09\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.731, \"Energy\": 0.832, \"Loudness\": -2.592, \"Speechiness\": 0.0503, \"Acousticness\": 0.273, \"Liveness\": 0.0665, \"Tempo\": 146.013, \"Duration (ms)\": 178613.0, \"Valence\": 0.94, \"Chord\": \"A\"}, {\"Index\": 1227, \"Highest Charting Position\": 85, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Hate Me (with Juice WRLD)\", \"Streams\": 4367368, \"Artist\": \"Ellie Goulding\", \"Artist Followers\": 9747805.0, \"Song ID\": \"6kls8cSlUyHW2BUOkDJIZE\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'indietronica', 'metropopolis', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2019-06-26\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.657, \"Energy\": 0.768, \"Loudness\": -4.628, \"Speechiness\": 0.0507, \"Acousticness\": 0.108, \"Liveness\": 0.144, \"Tempo\": 75.025, \"Duration (ms)\": 186223.0, \"Valence\": 0.759, \"Chord\": \"G#/Ab\"}, {\"Index\": 1228, \"Highest Charting Position\": 109, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Still Be Friends (feat. Tory Lanez & Tyga)\", \"Streams\": 4299422, \"Artist\": \"G-Eazy\", \"Artist Followers\": 4894656.0, \"Song ID\": \"0JjM9bKm4wrwohMslcm892\", \"Genre\": \"['hip hop', 'indie pop rap', 'oakland hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 76.0, \"Danceability\": 0.803, \"Energy\": 0.759, \"Loudness\": -4.692, \"Speechiness\": 0.0494, \"Acousticness\": 0.00509, \"Liveness\": 0.0921, \"Tempo\": 104.0, \"Duration (ms)\": 213308.0, \"Valence\": 0.284, \"Chord\": \"G\"}, {\"Index\": 1229, \"Highest Charting Position\": 74, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Blanco\", \"Streams\": 4214147, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"2rc7BkzO8qepMFAxHtOrXc\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.87, \"Energy\": 0.706, \"Loudness\": -5.395, \"Speechiness\": 0.126, \"Acousticness\": 0.0253, \"Liveness\": 0.0872, \"Tempo\": 100.013, \"Duration (ms)\": 145800.0, \"Valence\": 0.593, \"Chord\": \"A\"}, {\"Index\": 1230, \"Highest Charting Position\": 78, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"PICK UP (feat. Quavo)\", \"Streams\": 7065060, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"5gNOINI5dXZVom2b36LMOd\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 65.0, \"Danceability\": 0.915, \"Energy\": 0.612, \"Loudness\": -4.535, \"Speechiness\": 0.407, \"Acousticness\": 0.0944, \"Liveness\": 0.115, \"Tempo\": 129.93, \"Duration (ms)\": 118547.0, \"Valence\": 0.758, \"Chord\": \"C#/Db\"}, {\"Index\": 1231, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"JUMP (feat. YoungBoy Never Broke Again)\", \"Streams\": 6033348, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"0oT9ElXYSxvnOOagP9efDq\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 62.0, \"Danceability\": 0.896, \"Energy\": 0.72, \"Loudness\": -6.262, \"Speechiness\": 0.355, \"Acousticness\": 0.169, \"Liveness\": 0.252, \"Tempo\": 140.1, \"Duration (ms)\": 212093.0, \"Valence\": 0.966, \"Chord\": \"C\"}, {\"Index\": 1232, \"Highest Charting Position\": 156, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"LIGHTSKIN SH*T (feat. Future & jetsonmade)\", \"Streams\": 4861875, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"16oi4OiKmkO51l60F5R9kR\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 56.0, \"Danceability\": 0.932, \"Energy\": 0.578, \"Loudness\": -4.478, \"Speechiness\": 0.366, \"Acousticness\": 0.115, \"Liveness\": 0.115, \"Tempo\": 129.991, \"Duration (ms)\": 111173.0, \"Valence\": 0.623, \"Chord\": \"A\"}, {\"Index\": 1233, \"Highest Charting Position\": 16, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"That Way - Bonus Track\", \"Streams\": 4825741, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2ajzBr7vwHTEBeqDzcsNRC\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.712, \"Energy\": 0.598, \"Loudness\": -5.368, \"Speechiness\": 0.0388, \"Acousticness\": 0.0546, \"Liveness\": 0.154, \"Tempo\": 130.007, \"Duration (ms)\": 212354.0, \"Valence\": 0.504, \"Chord\": \"G\"}, {\"Index\": 1234, \"Highest Charting Position\": 162, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"No Me Ame\", \"Streams\": 4822090, \"Artist\": \"Rvssian, Anuel AA, Juice WRLD\", \"Artist Followers\": 1397067.0, \"Song ID\": \"2AuWgceaQyfMoI3EGavwGb\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 64.0, \"Danceability\": 0.68, \"Energy\": 0.766, \"Loudness\": -4.799, \"Speechiness\": 0.0923, \"Acousticness\": 0.0411, \"Liveness\": 0.116, \"Tempo\": 160.095, \"Duration (ms)\": 180000.0, \"Valence\": 0.28, \"Chord\": \"B\"}, {\"Index\": 1235, \"Highest Charting Position\": 80, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"I'll Wait\", \"Streams\": 4674532, \"Artist\": \"Kygo, Sasha Alex Sloan\", \"Artist Followers\": 7593792.0, \"Song ID\": \"6Q3K9gVUZRMZqZKrXovbM2\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 70.0, \"Danceability\": 0.611, \"Energy\": 0.651, \"Loudness\": -6.973, \"Speechiness\": 0.0589, \"Acousticness\": 0.144, \"Liveness\": 0.105, \"Tempo\": 122.983, \"Duration (ms)\": 215361.0, \"Valence\": 0.351, \"Chord\": \"C#/Db\"}, {\"Index\": 1236, \"Highest Charting Position\": 63, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Oprah\\u2019s Bank Account (Lil Yachty & DaBaby feat. Drake)\", \"Streams\": 4618744, \"Artist\": \"Lil Yachty\", \"Artist Followers\": 7358720.0, \"Song ID\": \"7wsmIIm0xWmtP7TmACXkJn\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap', 'underground hip hop', 'viral rap']\", \"Release Date\": \"2020-03-09\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 69.0, \"Danceability\": 0.836, \"Energy\": 0.617, \"Loudness\": -4.363, \"Speechiness\": 0.0534, \"Acousticness\": 0.17, \"Liveness\": 0.319, \"Tempo\": 138.066, \"Duration (ms)\": 206702.0, \"Valence\": 0.866, \"Chord\": \"C\"}, {\"Index\": 1237, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"BLAME IT ON BABY\", \"Streams\": 4616034, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"0jWm0VyD8p3MrSInczpows\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 57.0, \"Danceability\": 0.875, \"Energy\": 0.687, \"Loudness\": -5.734, \"Speechiness\": 0.387, \"Acousticness\": 0.236, \"Liveness\": 0.141, \"Tempo\": 109.791, \"Duration (ms)\": 125907.0, \"Valence\": 0.864, \"Chord\": \"A\"}, {\"Index\": 1238, \"Highest Charting Position\": 128, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Follow\", \"Streams\": 4593449, \"Artist\": \"KAROL G, Anuel AA\", \"Artist Followers\": 17792779.0, \"Song ID\": \"2w1rq80FIrbxeJy9WYURxw\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-04-01\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 63.0, \"Danceability\": 0.735, \"Energy\": 0.787, \"Loudness\": -4.375, \"Speechiness\": 0.16, \"Acousticness\": 0.667, \"Liveness\": 0.0721, \"Tempo\": 168.997, \"Duration (ms)\": 203093.0, \"Valence\": 0.455, \"Chord\": \"G\"}, {\"Index\": 1239, \"Highest Charting Position\": 156, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"3 Nights\", \"Streams\": 4411998, \"Artist\": \"Dominic Fike\", \"Artist Followers\": 554042.0, \"Song ID\": \"1tNJrcVe6gwLEiZCtprs1u\", \"Genre\": \"['alternative pop rock', 'pop']\", \"Release Date\": \"2018-10-16\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.815, \"Energy\": 0.518, \"Loudness\": -6.594, \"Speechiness\": 0.0897, \"Acousticness\": 0.223, \"Liveness\": 0.104, \"Tempo\": 151.891, \"Duration (ms)\": 177667.0, \"Valence\": 0.877, \"Chord\": \"G\"}, {\"Index\": 1240, \"Highest Charting Position\": 163, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"The Take (feat. Chris Brown)\", \"Streams\": 4394195, \"Artist\": \"Tory Lanez\", \"Artist Followers\": 3828418.0, \"Song ID\": \"0Odu228D0yGcFySGuxU4rY\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 73.0, \"Danceability\": 0.464, \"Energy\": 0.547, \"Loudness\": -8.137, \"Speechiness\": 0.339, \"Acousticness\": 0.0511, \"Liveness\": 0.155, \"Tempo\": 67.003, \"Duration (ms)\": 221492.0, \"Valence\": 0.423, \"Chord\": \"G\"}, {\"Index\": 1241, \"Highest Charting Position\": 101, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Stupid Again\", \"Streams\": 5938996, \"Artist\": \"Tory Lanez\", \"Artist Followers\": 3828418.0, \"Song ID\": \"1fPnUpoXCpD2NDI4vPVeLw\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-04-10\", \"Weeks Charted\": \"2020-04-10--2020-04-17\", \"Popularity\": 66.0, \"Danceability\": 0.775, \"Energy\": 0.823, \"Loudness\": -4.941, \"Speechiness\": 0.0635, \"Acousticness\": 0.0881, \"Liveness\": 0.309, \"Tempo\": 120.059, \"Duration (ms)\": 174848.0, \"Valence\": 0.65, \"Chord\": \"F\"}, {\"Index\": 1242, \"Highest Charting Position\": 127, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Shotz Fired\", \"Streams\": 5291167, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"0dy5NFDnx5fuZvE8ZXEX35\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-04-10--2020-04-17\", \"Popularity\": 59.0, \"Danceability\": 0.839, \"Energy\": 0.594, \"Loudness\": -9.087, \"Speechiness\": 0.139, \"Acousticness\": 0.249, \"Liveness\": 0.165, \"Tempo\": 76.007, \"Duration (ms)\": 179844.0, \"Valence\": 0.58, \"Chord\": \"C\"}, {\"Index\": 1243, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"BaeBae\", \"Streams\": 5290730, \"Artist\": \"Samra\", \"Artist Followers\": 1045091.0, \"Song ID\": \"1yYBOIXO2H9LDqEPui42GM\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-04-10--2020-04-17\", \"Popularity\": 57.0, \"Danceability\": 0.628, \"Energy\": 0.712, \"Loudness\": -4.864, \"Speechiness\": 0.156, \"Acousticness\": 0.282, \"Liveness\": 0.156, \"Tempo\": 86.627, \"Duration (ms)\": 167827.0, \"Valence\": 0.45, \"Chord\": \"E\"}, {\"Index\": 1244, \"Highest Charting Position\": 30, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"To Die For\", \"Streams\": 4527835, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"2ZTYlnhhV1UAReg7wIGolx\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 70.0, \"Danceability\": 0.483, \"Energy\": 0.361, \"Loudness\": -7.889, \"Speechiness\": 0.0738, \"Acousticness\": 0.832, \"Liveness\": 0.098, \"Tempo\": 171.649, \"Duration (ms)\": 193795.0, \"Valence\": 0.307, \"Chord\": \"C\"}, {\"Index\": 1245, \"Highest Charting Position\": 86, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"WANNABE\", \"Streams\": 4383521, \"Artist\": \"ITZY\", \"Artist Followers\": 2384076.0, \"Song ID\": \"6tCssnvTUREcperDOUTqvA\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2020-03-09\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 75.0, \"Danceability\": 0.809, \"Energy\": 0.911, \"Loudness\": -4.41, \"Speechiness\": 0.0617, \"Acousticness\": 0.00795, \"Liveness\": 0.181, \"Tempo\": 122.035, \"Duration (ms)\": 191242.0, \"Valence\": 0.64, \"Chord\": \"F#/Gb\"}, {\"Index\": 1246, \"Highest Charting Position\": 152, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Takeaway\", \"Streams\": 4359727, \"Artist\": \"The Chainsmokers, ILLENIUM, Lennon Stella\", \"Artist Followers\": 18195884.0, \"Song ID\": \"3g0mEQx3NTanacLseoP0Gw\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.528, \"Energy\": 0.511, \"Loudness\": -8.144, \"Speechiness\": 0.0324, \"Acousticness\": 0.126, \"Liveness\": 0.101, \"Tempo\": 100.1, \"Duration (ms)\": 209880.0, \"Valence\": 0.351, \"Chord\": \"D#/Eb\"}, {\"Index\": 1247, \"Highest Charting Position\": 190, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Heart On Ice\", \"Streams\": 4324610, \"Artist\": \"Rod Wave\", \"Artist Followers\": 2203386.0, \"Song ID\": \"6fWa5CRgy0z30OeGZyMBvD\", \"Genre\": \"['florida rap']\", \"Release Date\": \"2019-06-14\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 70.0, \"Danceability\": 0.733, \"Energy\": 0.389, \"Loudness\": -8.468, \"Speechiness\": 0.0738, \"Acousticness\": 0.0513, \"Liveness\": 0.141, \"Tempo\": 157.878, \"Duration (ms)\": 159670.0, \"Valence\": 0.244, \"Chord\": \"A#/Bb\"}, {\"Index\": 1248, \"Highest Charting Position\": 194, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"La Cama - Remix\", \"Streams\": 4261965, \"Artist\": \"Lunay, Myke Towers, Ozuna, Chencho Corleone, Rauw Alejandro\", \"Artist Followers\": 4963516.0, \"Song ID\": \"2tGENA8xef0wABdHvyXwv9\", \"Genre\": \"['latin', 'latin pop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 69.0, \"Danceability\": 0.737, \"Energy\": 0.832, \"Loudness\": -2.622, \"Speechiness\": 0.0798, \"Acousticness\": 0.12, \"Liveness\": 0.255, \"Tempo\": 173.986, \"Duration (ms)\": 330240.0, \"Valence\": 0.865, \"Chord\": \"D\"}, {\"Index\": 1249, \"Highest Charting Position\": 105, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Go Stupid (feat. NLE Choppa & Mike WiLL Made-It)\", \"Streams\": 4244510, \"Artist\": \"Polo G, Stunna 4 Vegas\", \"Artist Followers\": 4849204.0, \"Song ID\": \"0L8OsjxbagaGkJI0PezdRg\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 41.0, \"Danceability\": 0.922, \"Energy\": 0.813, \"Loudness\": -3.268, \"Speechiness\": 0.251, \"Acousticness\": 0.0198, \"Liveness\": 0.0539, \"Tempo\": 141.087, \"Duration (ms)\": 165726.0, \"Valence\": 0.724, \"Chord\": \"C#/Db\"}, {\"Index\": 1250, \"Highest Charting Position\": 192, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Cradles\", \"Streams\": 4218201, \"Artist\": \"Sub Urban\", \"Artist Followers\": 908351.0, \"Song ID\": \"1y4jsQt7MjnZhiD1L6qFBC\", \"Genre\": \"['modern indie pop']\", \"Release Date\": \"2019-01-04\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 73.0, \"Danceability\": 0.534, \"Energy\": 0.589, \"Loudness\": -1.865, \"Speechiness\": 0.325, \"Acousticness\": 0.256, \"Liveness\": 0.176, \"Tempo\": 78.616, \"Duration (ms)\": 209829.0, \"Valence\": 0.632, \"Chord\": \"C#/Db\"}, {\"Index\": 1251, \"Highest Charting Position\": 117, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Good as Hell (feat. Ariana Grande)\", \"Streams\": 4176083, \"Artist\": \"Lizzo\", \"Artist Followers\": 3991674.0, \"Song ID\": \"07Oz5StQ7GRoygNLaXs2pd\", \"Genre\": \"['dance pop', 'escape room', 'minnesota hip hop', 'pop', 'pop rap', 'post-teen pop', 'trap queen']\", \"Release Date\": \"2016\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 71.0, \"Danceability\": 0.668, \"Energy\": 0.892, \"Loudness\": -3.001, \"Speechiness\": 0.0645, \"Acousticness\": 0.298, \"Liveness\": 0.735, \"Tempo\": 95.927, \"Duration (ms)\": 159011.0, \"Valence\": 0.478, \"Chord\": \"F\"}, {\"Index\": 1252, \"Highest Charting Position\": 15, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Forever (feat. Post Malone & Clever)\", \"Streams\": 6517807, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2ZlCGeK30BLRNSPC832pNZ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 68.0, \"Danceability\": 0.825, \"Energy\": 0.483, \"Loudness\": -5.746, \"Speechiness\": 0.08, \"Acousticness\": 0.538, \"Liveness\": 0.204, \"Tempo\": 139.98, \"Duration (ms)\": 219933.0, \"Valence\": 0.892, \"Chord\": \"G#/Ab\"}, {\"Index\": 1253, \"Highest Charting Position\": 46, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"I Love Me\", \"Streams\": 5449099, \"Artist\": \"Demi Lovato\", \"Artist Followers\": 20338833.0, \"Song ID\": \"2IHLaN6wwYKQ3S24NsQqpA\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.664, \"Energy\": 0.561, \"Loudness\": -7.031, \"Speechiness\": 0.0495, \"Acousticness\": 0.00261, \"Liveness\": 0.0764, \"Tempo\": 150.093, \"Duration (ms)\": 203672.0, \"Valence\": 0.713, \"Chord\": \"F#/Gb\"}, {\"Index\": 1254, \"Highest Charting Position\": 103, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Old Me\", \"Streams\": 4724056, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"58qO4dGa5SgNdtvqvpewyz\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 67.0, \"Danceability\": 0.722, \"Energy\": 0.62, \"Loudness\": -3.639, \"Speechiness\": 0.0483, \"Acousticness\": 0.313, \"Liveness\": 0.26, \"Tempo\": 127.978, \"Duration (ms)\": 186786.0, \"Valence\": 0.474, \"Chord\": \"C\"}, {\"Index\": 1255, \"Highest Charting Position\": 29, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Pero Ya No\", \"Streams\": 4666658, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"75pQqzwgCjUOSSy5CpmAjy\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 72.0, \"Danceability\": 0.882, \"Energy\": 0.612, \"Loudness\": -6.103, \"Speechiness\": 0.118, \"Acousticness\": 0.0475, \"Liveness\": 0.182, \"Tempo\": 147.982, \"Duration (ms)\": 160638.0, \"Valence\": 0.742, \"Chord\": \"E\"}, {\"Index\": 1256, \"Highest Charting Position\": 24, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Hardest To Love\", \"Streams\": 4553544, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"6kWxIqQDsKFYCJGbU4AjCX\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.467, \"Energy\": 0.608, \"Loudness\": -7.847, \"Speechiness\": 0.0707, \"Acousticness\": 0.0909, \"Liveness\": 0.125, \"Tempo\": 80.957, \"Duration (ms)\": 211400.0, \"Valence\": 0.108, \"Chord\": \"A#/Bb\"}, {\"Index\": 1257, \"Highest Charting Position\": 191, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"BRABA\", \"Streams\": 4452819, \"Artist\": \"Lu\\u00edsa Sonza\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6DEEuFNv0K3aJtFYZag8gv\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-11\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 0.0, \"Danceability\": 0.812, \"Energy\": 0.689, \"Loudness\": -5.113, \"Speechiness\": 0.0619, \"Acousticness\": 0.181, \"Liveness\": 0.0784, \"Tempo\": 144.011, \"Duration (ms)\": 129782.0, \"Valence\": 0.663, \"Chord\": \"C\"}, {\"Index\": 1258, \"Highest Charting Position\": 77, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Woah\", \"Streams\": 4425610, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"598yNsG1JFrGd4n2kMoz7F\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 69.0, \"Danceability\": 0.882, \"Energy\": 0.602, \"Loudness\": -5.554, \"Speechiness\": 0.245, \"Acousticness\": 0.0177, \"Liveness\": 0.178, \"Tempo\": 142.959, \"Duration (ms)\": 183011.0, \"Valence\": 0.43, \"Chord\": \"B\"}, {\"Index\": 1259, \"Highest Charting Position\": 69, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Pretty Please\", \"Streams\": 4305034, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"6DXZiYUbrYgrVIhfX3U9Z2\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 67.0, \"Danceability\": 0.906, \"Energy\": 0.474, \"Loudness\": -6.124, \"Speechiness\": 0.194, \"Acousticness\": 0.0311, \"Liveness\": 0.286, \"Tempo\": 106.976, \"Duration (ms)\": 194607.0, \"Valence\": 0.656, \"Chord\": \"C#/Db\"}, {\"Index\": 1260, \"Highest Charting Position\": 170, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"I.F.L.Y.\", \"Streams\": 4284951, \"Artist\": \"Bazzi\", \"Artist Followers\": 4421378.0, \"Song ID\": \"4a6q8CR2hzLk2plDkSxkfD\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-08-09\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-13--2020-03-20\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 76.0, \"Danceability\": 0.812, \"Energy\": 0.519, \"Loudness\": -4.823, \"Speechiness\": 0.0385, \"Acousticness\": 0.379, \"Liveness\": 0.13, \"Tempo\": 104.954, \"Duration (ms)\": 165714.0, \"Valence\": 0.554, \"Chord\": \"D\"}, {\"Index\": 1261, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Cool\", \"Streams\": 8136247, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"4Ulqu89XempybuL8ApUeqL\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.469, \"Energy\": 0.785, \"Loudness\": -4.015, \"Speechiness\": 0.0664, \"Acousticness\": 0.133, \"Liveness\": 0.0931, \"Tempo\": 89.719, \"Duration (ms)\": 209583.0, \"Valence\": 0.79, \"Chord\": \"F\"}, {\"Index\": 1262, \"Highest Charting Position\": 71, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Future Nostalgia\", \"Streams\": 8091754, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3iYNJX4FTRGlfMQySjlGNr\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.875, \"Energy\": 0.813, \"Loudness\": -4.502, \"Speechiness\": 0.0579, \"Acousticness\": 0.00618, \"Liveness\": 0.321, \"Tempo\": 114.993, \"Duration (ms)\": 184882.0, \"Valence\": 0.859, \"Chord\": \"G\"}, {\"Index\": 1263, \"Highest Charting Position\": 92, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Good In Bed\", \"Streams\": 6802068, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3pyodt4pb554dMz8fCv7oi\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 64.0, \"Danceability\": 0.68, \"Energy\": 0.701, \"Loudness\": -5.001, \"Speechiness\": 0.0917, \"Acousticness\": 0.138, \"Liveness\": 0.168, \"Tempo\": 94.06, \"Duration (ms)\": 218754.0, \"Valence\": 0.649, \"Chord\": \"F\"}, {\"Index\": 1264, \"Highest Charting Position\": 27, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Scared To Live\", \"Streams\": 6566099, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"4BGZF4oLbTL0pWm7C18pbv\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 66.0, \"Danceability\": 0.504, \"Energy\": 0.498, \"Loudness\": -8.24, \"Speechiness\": 0.0499, \"Acousticness\": 0.131, \"Liveness\": 0.0929, \"Tempo\": 87.221, \"Duration (ms)\": 191307.0, \"Valence\": 0.196, \"Chord\": \"C\"}, {\"Index\": 1265, \"Highest Charting Position\": 21, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Alone Again\", \"Streams\": 6055294, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"6b5P51m8xx2XA6U7sdNZ5E\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 66.0, \"Danceability\": 0.218, \"Energy\": 0.652, \"Loudness\": -7.953, \"Speechiness\": 0.0641, \"Acousticness\": 0.033, \"Liveness\": 0.172, \"Tempo\": 65.375, \"Duration (ms)\": 250053.0, \"Valence\": 0.0599, \"Chord\": \"E\"}, {\"Index\": 1266, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Boys Will Be Boys\", \"Streams\": 6015914, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"4szI7zRh7kLApCSqiB6R7b\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 63.0, \"Danceability\": 0.768, \"Energy\": 0.486, \"Loudness\": -5.954, \"Speechiness\": 0.0353, \"Acousticness\": 0.408, \"Liveness\": 0.098, \"Tempo\": 125.021, \"Duration (ms)\": 166266.0, \"Valence\": 0.519, \"Chord\": \"D#/Eb\"}, {\"Index\": 1267, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Auto Blu\", \"Streams\": 5995116, \"Artist\": \"Shiva, Eiffel 65\", \"Artist Followers\": 561372.0, \"Song ID\": \"5swpvba5YLqVDy1nbzUdog\", \"Genre\": \"['italian hip hop', 'trap italiana']\", \"Release Date\": \"2020-03-26\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 56.0, \"Danceability\": 0.82, \"Energy\": 0.783, \"Loudness\": -6.146, \"Speechiness\": 0.0621, \"Acousticness\": 0.0158, \"Liveness\": 0.0938, \"Tempo\": 130.015, \"Duration (ms)\": 166087.0, \"Valence\": 0.653, \"Chord\": \"F\"}, {\"Index\": 1268, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Du bist mein\", \"Streams\": 5878493, \"Artist\": \"Zuna, Loredana, SRNO\", \"Artist Followers\": 900975.0, \"Song ID\": \"719aY5gAzJbx2PHjyalZQu\", \"Genre\": \"['albanian hip hop', 'german hip hop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 54.0, \"Danceability\": 0.761, \"Energy\": 0.556, \"Loudness\": -6.943, \"Speechiness\": 0.364, \"Acousticness\": 0.138, \"Liveness\": 0.0976, \"Tempo\": 187.81, \"Duration (ms)\": 160357.0, \"Valence\": 0.521, \"Chord\": \"C#/Db\"}, {\"Index\": 1269, \"Highest Charting Position\": 28, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Too Late\", \"Streams\": 5867746, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"2K9Ovn1o2bTGqbsABGC6m3\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.638, \"Energy\": 0.863, \"Loudness\": -5.221, \"Speechiness\": 0.132, \"Acousticness\": 0.052, \"Liveness\": 0.685, \"Tempo\": 120.077, \"Duration (ms)\": 239973.0, \"Valence\": 0.226, \"Chord\": \"E\"}, {\"Index\": 1270, \"Highest Charting Position\": 136, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Wildflower\", \"Streams\": 5791343, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"6qlcjGJPTZEwR8nf2nSe9C\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.644, \"Energy\": 0.768, \"Loudness\": -4.316, \"Speechiness\": 0.0455, \"Acousticness\": 0.174, \"Liveness\": 0.469, \"Tempo\": 108.992, \"Duration (ms)\": 220536.0, \"Valence\": 0.598, \"Chord\": \"F#/Gb\"}, {\"Index\": 1271, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Faith\", \"Streams\": 5730081, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"3orEOtd8CPL8GFlpRpKuoE\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.375, \"Energy\": 0.605, \"Loudness\": -7.268, \"Speechiness\": 0.0729, \"Acousticness\": 0.612, \"Liveness\": 0.147, \"Tempo\": 175.946, \"Duration (ms)\": 283227.0, \"Valence\": 0.128, \"Chord\": \"C\"}, {\"Index\": 1272, \"Highest Charting Position\": 35, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Snowchild\", \"Streams\": 5423997, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"3WlbeuhfRSqU7ylK2Ui5U7\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 66.0, \"Danceability\": 0.55, \"Energy\": 0.611, \"Loudness\": -7.475, \"Speechiness\": 0.137, \"Acousticness\": 0.162, \"Liveness\": 0.121, \"Tempo\": 148.062, \"Duration (ms)\": 247187.0, \"Valence\": 0.243, \"Chord\": \"C\"}, {\"Index\": 1273, \"Highest Charting Position\": 37, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Escape From LA\", \"Streams\": 5307288, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"1sOW4PuG5X3Ie3EXUhAopJ\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.404, \"Energy\": 0.524, \"Loudness\": -8.996, \"Speechiness\": 0.0593, \"Acousticness\": 0.0456, \"Liveness\": 0.199, \"Tempo\": 145.74, \"Duration (ms)\": 355960.0, \"Valence\": 0.168, \"Chord\": \"F\"}, {\"Index\": 1274, \"Highest Charting Position\": 161, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Allein sein\", \"Streams\": 5119993, \"Artist\": \"Ufo361\", \"Artist Followers\": 1700759.0, \"Song ID\": \"2TrhpvxwuF6hrboTdRXwnS\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 54.0, \"Danceability\": 0.774, \"Energy\": 0.588, \"Loudness\": -8.529, \"Speechiness\": 0.225, \"Acousticness\": 0.0386, \"Liveness\": 0.258, \"Tempo\": 75.978, \"Duration (ms)\": 147353.0, \"Valence\": 0.392, \"Chord\": \"C#/Db\"}, {\"Index\": 1275, \"Highest Charting Position\": 44, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Bichiyal\", \"Streams\": 4946613, \"Artist\": \"Bad Bunny, Yaviah\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4j4w4CXm6BSr0s25wAWrrX\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 75.0, \"Danceability\": 0.737, \"Energy\": 0.766, \"Loudness\": -4.242, \"Speechiness\": 0.0458, \"Acousticness\": 0.31, \"Liveness\": 0.114, \"Tempo\": 93.956, \"Duration (ms)\": 196500.0, \"Valence\": 0.662, \"Chord\": \"A#/Bb\"}, {\"Index\": 1276, \"Highest Charting Position\": 85, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Medusa\", \"Streams\": 4901559, \"Artist\": \"Jhay Cortez, Anuel AA, J Balvin\", \"Artist Followers\": 2435159.0, \"Song ID\": \"3qM0vBxIe4VUbK0Z0smuVP\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-05\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 70.0, \"Danceability\": 0.886, \"Energy\": 0.604, \"Loudness\": -7.293, \"Speechiness\": 0.208, \"Acousticness\": 0.194, \"Liveness\": 0.107, \"Tempo\": 98.023, \"Duration (ms)\": 305333.0, \"Valence\": 0.383, \"Chord\": \"C\"}, {\"Index\": 1277, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Break Up Song\", \"Streams\": 4593343, \"Artist\": \"Little Mix\", \"Artist Followers\": 9398941.0, \"Song ID\": \"5HArmECc1y0lCHKVKDKXa4\", \"Genre\": \"['dance pop', 'girl group', 'pop', 'post-teen pop', 'talent show', 'uk pop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.631, \"Energy\": 0.75, \"Loudness\": -5.416, \"Speechiness\": 0.0394, \"Acousticness\": 0.00388, \"Liveness\": 0.286, \"Tempo\": 90.019, \"Duration (ms)\": 200293.0, \"Valence\": 0.593, \"Chord\": \"F\"}, {\"Index\": 1278, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Teeth\", \"Streams\": 4571612, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"26wLOs3ZuHJa2Ihhx6QIE6\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 78.0, \"Danceability\": 0.749, \"Energy\": 0.461, \"Loudness\": -2.961, \"Speechiness\": 0.0416, \"Acousticness\": 0.0516, \"Liveness\": 0.0738, \"Tempo\": 139.02, \"Duration (ms)\": 204887.0, \"Valence\": 0.42, \"Chord\": \"A#/Bb\"}, {\"Index\": 1279, \"Highest Charting Position\": 51, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Repeat After Me (Interlude)\", \"Streams\": 10058303, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"40U8d12pC5UHqmHwXjHjjl\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 63.0, \"Danceability\": 0.555, \"Energy\": 0.619, \"Loudness\": -7.918, \"Speechiness\": 0.0314, \"Acousticness\": 0.0323, \"Liveness\": 0.0917, \"Tempo\": 95.032, \"Duration (ms)\": 195813.0, \"Valence\": 0.141, \"Chord\": \"C\"}, {\"Index\": 1280, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Until I Bleed Out\", \"Streams\": 9132077, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"2BcnxwxBuar5wjCaLqm5N3\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 63.0, \"Danceability\": 0.245, \"Energy\": 0.394, \"Loudness\": -9.887, \"Speechiness\": 0.0374, \"Acousticness\": 0.423, \"Liveness\": 0.093, \"Tempo\": 115.233, \"Duration (ms)\": 190173.0, \"Valence\": 0.148, \"Chord\": \"C\"}, {\"Index\": 1281, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Rosa\", \"Streams\": 7564893, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"464uJVLmr0fDJGXOnciaDe\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 64.0, \"Danceability\": 0.651, \"Energy\": 0.561, \"Loudness\": -5.715, \"Speechiness\": 0.25, \"Acousticness\": 0.25, \"Liveness\": 0.435, \"Tempo\": 175.992, \"Duration (ms)\": 189827.0, \"Valence\": 0.369, \"Chord\": \"A\"}, {\"Index\": 1282, \"Highest Charting Position\": 88, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Gris\", \"Streams\": 7514854, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"1syf62zw48zu4FrPwMtDHk\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 65.0, \"Danceability\": 0.849, \"Energy\": 0.709, \"Loudness\": -4.717, \"Speechiness\": 0.0794, \"Acousticness\": 0.229, \"Liveness\": 0.329, \"Tempo\": 93.06, \"Duration (ms)\": 176627.0, \"Valence\": 0.916, \"Chord\": \"F#/Gb\"}, {\"Index\": 1283, \"Highest Charting Position\": 103, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Negro\", \"Streams\": 6651425, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"2hsA9YWuF3C9Gosi4dpjJN\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.795, \"Energy\": 0.911, \"Loudness\": -2.228, \"Speechiness\": 0.0875, \"Acousticness\": 0.0157, \"Liveness\": 0.131, \"Tempo\": 164.081, \"Duration (ms)\": 182093.0, \"Valence\": 0.8, \"Chord\": \"C\"}, {\"Index\": 1284, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Verde\", \"Streams\": 5745393, \"Artist\": \"J Balvin, Sky Rompiendo\", \"Artist Followers\": 29067437.0, \"Song ID\": \"3HTbI3yUJQw3fP0Po8qLcD\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 63.0, \"Danceability\": 0.828, \"Energy\": 0.738, \"Loudness\": -4.295, \"Speechiness\": 0.0516, \"Acousticness\": 0.0381, \"Liveness\": 0.0917, \"Tempo\": 94.995, \"Duration (ms)\": 142547.0, \"Valence\": 0.818, \"Chord\": \"G#/Ab\"}, {\"Index\": 1285, \"Highest Charting Position\": 15, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Baby Pluto\", \"Streams\": 5600261, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7hav1MHURQf5SAoPk0egqh\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 69.0, \"Danceability\": 0.772, \"Energy\": 0.634, \"Loudness\": -6.101, \"Speechiness\": 0.212, \"Acousticness\": 0.135, \"Liveness\": 0.432, \"Tempo\": 160.052, \"Duration (ms)\": 210261.0, \"Valence\": 0.671, \"Chord\": \"A#/Bb\"}, {\"Index\": 1286, \"Highest Charting Position\": 31, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Lo Mein\", \"Streams\": 5231134, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"6CUP2khYzdphXebxVTfPE3\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.855, \"Energy\": 0.676, \"Loudness\": -5.736, \"Speechiness\": 0.325, \"Acousticness\": 0.0888, \"Liveness\": 0.144, \"Tempo\": 133.082, \"Duration (ms)\": 195299.0, \"Valence\": 0.509, \"Chord\": \"C#/Db\"}, {\"Index\": 1287, \"Highest Charting Position\": 113, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"No Judgement\", \"Streams\": 5082563, \"Artist\": \"Niall Horan\", \"Artist Followers\": 7564659.0, \"Song ID\": \"5IUOU5xkzGHsRFOYNu3GSK\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 65.0, \"Danceability\": 0.723, \"Energy\": 0.726, \"Loudness\": -3.835, \"Speechiness\": 0.0472, \"Acousticness\": 0.0564, \"Liveness\": 0.057, \"Tempo\": 100.051, \"Duration (ms)\": 176283.0, \"Valence\": 0.962, \"Chord\": \"C#/Db\"}, {\"Index\": 1288, \"Highest Charting Position\": 57, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Futsal Shuffle 2020 - Bonus Track\", \"Streams\": 5068849, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2fOlBMkWR7lXJfqp5VTbDG\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 63.0, \"Danceability\": 0.879, \"Energy\": 0.448, \"Loudness\": -8.57, \"Speechiness\": 0.222, \"Acousticness\": 0.0346, \"Liveness\": 0.224, \"Tempo\": 136.985, \"Duration (ms)\": 198913.0, \"Valence\": 0.278, \"Chord\": \"G\"}, {\"Index\": 1289, \"Highest Charting Position\": 163, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Arco\\u00edris\", \"Streams\": 5044774, \"Artist\": \"J Balvin, Mr Eazi\", \"Artist Followers\": 29067437.0, \"Song ID\": \"5zzbORcD0GwLY0wQHP1Xs1\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 62.0, \"Danceability\": 0.731, \"Energy\": 0.787, \"Loudness\": -5.26, \"Speechiness\": 0.0721, \"Acousticness\": 0.0853, \"Liveness\": 0.316, \"Tempo\": 92.971, \"Duration (ms)\": 186693.0, \"Valence\": 0.393, \"Chord\": \"E\"}, {\"Index\": 1290, \"Highest Charting Position\": 65, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"TOES (feat. Lil Baby & Moneybagg Yo)\", \"Streams\": 4878903, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"2FvD20Z8aoWIePi7PoN8sG\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 73.0, \"Danceability\": 0.816, \"Energy\": 0.582, \"Loudness\": -4.141, \"Speechiness\": 0.341, \"Acousticness\": 0.0794, \"Liveness\": 0.0916, \"Tempo\": 160.004, \"Duration (ms)\": 136366.0, \"Valence\": 0.542, \"Chord\": \"G#/Ab\"}, {\"Index\": 1291, \"Highest Charting Position\": 42, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Feel Me\", \"Streams\": 4765672, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"6XXYdF6pJR1K3wKvuxmu7n\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 63.0, \"Danceability\": 0.71, \"Energy\": 0.808, \"Loudness\": -6.703, \"Speechiness\": 0.0433, \"Acousticness\": 0.44, \"Liveness\": 0.0734, \"Tempo\": 99.989, \"Duration (ms)\": 226003.0, \"Valence\": 0.392, \"Chord\": \"D\"}, {\"Index\": 1292, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"H <3 T E L\", \"Streams\": 4701388, \"Artist\": \"Dardan, Monet192\", \"Artist Followers\": 861082.0, \"Song ID\": \"3S1NOXjDr2A4xXXsWo8kLr\", \"Genre\": \"['albanian hip hop', 'german hip hop']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 34.0, \"Danceability\": 0.726, \"Energy\": 0.646, \"Loudness\": -6.9, \"Speechiness\": 0.0977, \"Acousticness\": 0.0495, \"Liveness\": 0.112, \"Tempo\": 134.999, \"Duration (ms)\": 163253.0, \"Valence\": 0.58, \"Chord\": \"C#/Db\"}, {\"Index\": 1293, \"Highest Charting Position\": 63, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"25/8\", \"Streams\": 4684378, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4NqQaovM14WR2hNPMFxgjb\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 71.0, \"Danceability\": 0.761, \"Energy\": 0.732, \"Loudness\": -5.469, \"Speechiness\": 0.0549, \"Acousticness\": 0.092, \"Liveness\": 0.0716, \"Tempo\": 151.982, \"Duration (ms)\": 243276.0, \"Valence\": 0.542, \"Chord\": \"E\"}, {\"Index\": 1294, \"Highest Charting Position\": 81, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Se Me Olvid\\u00f3\", \"Streams\": 4591194, \"Artist\": \"Christian Nodal\", \"Artist Followers\": 8123757.0, \"Song ID\": \"7paFC3FEu1WtPVP4Do6VZN\", \"Genre\": \"['mariachi', 'nuevo regional mexicano', 'ranchera', 'regional mexican']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 71.0, \"Danceability\": 0.65, \"Energy\": 0.558, \"Loudness\": -3.082, \"Speechiness\": 0.0309, \"Acousticness\": 0.368, \"Liveness\": 0.303, \"Tempo\": 141.82, \"Duration (ms)\": 159533.0, \"Valence\": 0.725, \"Chord\": \"C\"}, {\"Index\": 1295, \"Highest Charting Position\": 130, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"B.S. (feat. H.E.R.)\", \"Streams\": 4557817, \"Artist\": \"Jhen\\u00e9 Aiko\", \"Artist Followers\": 4720858.0, \"Song ID\": \"63wx9vdskaXbYxyDx4oJCZ\", \"Genre\": \"['alternative r&b', 'dance pop', 'pop', 'pop rap', 'r&b', 'urban contemporary']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 72.0, \"Danceability\": 0.617, \"Energy\": 0.525, \"Loudness\": -10.426, \"Speechiness\": 0.12, \"Acousticness\": 0.554, \"Liveness\": 0.135, \"Tempo\": 135.781, \"Duration (ms)\": 212867.0, \"Valence\": 0.377, \"Chord\": \"G#/Ab\"}, {\"Index\": 1296, \"Highest Charting Position\": 45, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Soli\\u00e1\", \"Streams\": 4516243, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"7sOfmPd18RWp3FoCzpa7Kw\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 72.0, \"Danceability\": 0.71, \"Energy\": 0.81, \"Loudness\": -5.507, \"Speechiness\": 0.0854, \"Acousticness\": 0.117, \"Liveness\": 0.154, \"Tempo\": 92.041, \"Duration (ms)\": 159282.0, \"Valence\": 0.184, \"Chord\": \"D\"}, {\"Index\": 1297, \"Highest Charting Position\": 55, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Est\\u00e1 Cabr\\u00f3n Ser Yo\", \"Streams\": 4438261, \"Artist\": \"Bad Bunny, Anuel AA\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4saHEjXw7O1NXJOzBkUKKG\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.81, \"Energy\": 0.854, \"Loudness\": -3.999, \"Speechiness\": 0.254, \"Acousticness\": 0.0732, \"Liveness\": 0.123, \"Tempo\": 154.083, \"Duration (ms)\": 227939.0, \"Valence\": 0.879, \"Chord\": \"A#/Bb\"}, {\"Index\": 1298, \"Highest Charting Position\": 61, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Bean (Kobe) [feat. Chief Keef]\", \"Streams\": 9039518, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"0IpnZchq8ek2A6pGEP2Qb1\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 67.0, \"Danceability\": 0.733, \"Energy\": 0.567, \"Loudness\": -6.718, \"Speechiness\": 0.319, \"Acousticness\": 0.0129, \"Liveness\": 0.382, \"Tempo\": 75.491, \"Duration (ms)\": 238816.0, \"Valence\": 0.319, \"Chord\": \"C\"}, {\"Index\": 1299, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Yessirskiii\", \"Streams\": 8374259, \"Artist\": \"Lil Uzi Vert, 21 Savage\", \"Artist Followers\": 11821805.0, \"Song ID\": \"59JWp4PjZ9TRM8cmtaDYB1\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 70.0, \"Danceability\": 0.895, \"Energy\": 0.739, \"Loudness\": -6.633, \"Speechiness\": 0.283, \"Acousticness\": 0.0183, \"Liveness\": 0.102, \"Tempo\": 140.007, \"Duration (ms)\": 219340.0, \"Valence\": 0.763, \"Chord\": \"G#/Ab\"}, {\"Index\": 1300, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Cardigan\", \"Streams\": 6586204, \"Artist\": \"Don Toliver\", \"Artist Followers\": 1606884.0, \"Song ID\": \"0Li1OuXXfi7950ilZUFGkF\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 70.0, \"Danceability\": 0.747, \"Energy\": 0.497, \"Loudness\": -6.542, \"Speechiness\": 0.0401, \"Acousticness\": 0.248, \"Liveness\": 0.138, \"Tempo\": 142.046, \"Duration (ms)\": 158709.0, \"Valence\": 0.0663, \"Chord\": \"E\"}, {\"Index\": 1301, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Silly Watch\", \"Streams\": 6442451, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"5egD7A5x9AHdVO2fMo3Wbo\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 65.0, \"Danceability\": 0.903, \"Energy\": 0.535, \"Loudness\": -6.238, \"Speechiness\": 0.286, \"Acousticness\": 0.0298, \"Liveness\": 0.0851, \"Tempo\": 130.117, \"Duration (ms)\": 195692.0, \"Valence\": 0.157, \"Chord\": \"G#/Ab\"}, {\"Index\": 1302, \"Highest Charting Position\": 70, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Hablamos Ma\\u00f1ana\", \"Streams\": 6105711, \"Artist\": \"Bad Bunny, Duki, Pablo Chill-E\", \"Artist Followers\": 36177712.0, \"Song ID\": \"1V8XneTrX6kKeoxYbk4x6h\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.683, \"Energy\": 0.677, \"Loudness\": -4.496, \"Speechiness\": 0.0469, \"Acousticness\": 0.0869, \"Liveness\": 0.0998, \"Tempo\": 156.019, \"Duration (ms)\": 240253.0, \"Valence\": 0.514, \"Chord\": \"C#/Db\"}, {\"Index\": 1303, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Lotus\", \"Streams\": 6017103, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4SnlSaLJJ7reJMCHM5YUuX\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 58.0, \"Danceability\": 0.802, \"Energy\": 0.748, \"Loudness\": -5.708, \"Speechiness\": 0.207, \"Acousticness\": 0.24, \"Liveness\": 0.165, \"Tempo\": 150.063, \"Duration (ms)\": 193861.0, \"Valence\": 0.516, \"Chord\": \"G#/Ab\"}, {\"Index\": 1304, \"Highest Charting Position\": 126, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Lettre \\u00e0 une femme\", \"Streams\": 5895243, \"Artist\": \"Ninho\", \"Artist Followers\": 4764552.0, \"Song ID\": \"10rwyGbKAWZ8JZbL7uHl28\", \"Genre\": \"['french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2020-03-07\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 54.0, \"Danceability\": 0.487, \"Energy\": 0.398, \"Loudness\": -9.901, \"Speechiness\": 0.0697, \"Acousticness\": 0.835, \"Liveness\": 0.12, \"Tempo\": 149.367, \"Duration (ms)\": 157766.0, \"Valence\": 0.905, \"Chord\": \"C#/Db\"}, {\"Index\": 1305, \"Highest Charting Position\": 57, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Que Malo\", \"Streams\": 5544180, \"Artist\": \"Bad Bunny, \\u00d1engo Flow\", \"Artist Followers\": 36177712.0, \"Song ID\": \"53v2u51nq3CxiKUNphRzP1\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.802, \"Energy\": 0.787, \"Loudness\": -6.181, \"Speechiness\": 0.0599, \"Acousticness\": 0.0832, \"Liveness\": 0.153, \"Tempo\": 94.026, \"Duration (ms)\": 167975.0, \"Valence\": 0.446, \"Chord\": \"G\"}, {\"Index\": 1306, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Leaders (feat. NAV)\", \"Streams\": 5496780, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4D7NrSeqkTarBrJ80b2sBc\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 60.0, \"Danceability\": 0.95, \"Energy\": 0.654, \"Loudness\": -5.895, \"Speechiness\": 0.307, \"Acousticness\": 0.0744, \"Liveness\": 0.138, \"Tempo\": 132.936, \"Duration (ms)\": 194844.0, \"Valence\": 0.886, \"Chord\": \"C\"}, {\"Index\": 1307, \"Highest Charting Position\": 149, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Strawberry Peels (feat. Young Thug & Gunna)\", \"Streams\": 5468083, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4lAQfuREAHG8IC0PiiigBt\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 59.0, \"Danceability\": 0.862, \"Energy\": 0.65, \"Loudness\": -6.978, \"Speechiness\": 0.355, \"Acousticness\": 0.0207, \"Liveness\": 0.568, \"Tempo\": 131.194, \"Duration (ms)\": 115350.0, \"Valence\": 0.658, \"Chord\": \"A#/Bb\"}, {\"Index\": 1308, \"Highest Charting Position\": 60, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"La Zona\", \"Streams\": 5440382, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5kqNIqFjijuzvVLhuY9B8j\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.762, \"Energy\": 0.801, \"Loudness\": -3.661, \"Speechiness\": 0.0409, \"Acousticness\": 0.2, \"Liveness\": 0.254, \"Tempo\": 93.992, \"Duration (ms)\": 136893.0, \"Valence\": 0.81, \"Chord\": \"C#/Db\"}, {\"Index\": 1309, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Wassup (feat. Future)\", \"Streams\": 5415044, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"19Ec2gbNtQTE44IizcPjtD\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 57.0, \"Danceability\": 0.762, \"Energy\": 0.622, \"Loudness\": -6.293, \"Speechiness\": 0.223, \"Acousticness\": 0.352, \"Liveness\": 0.145, \"Tempo\": 130.019, \"Duration (ms)\": 193314.0, \"Valence\": 0.626, \"Chord\": \"F\"}, {\"Index\": 1310, \"Highest Charting Position\": 69, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Una Vez\", \"Streams\": 5411302, \"Artist\": \"Bad Bunny, Mora\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5J7teKIJGtqVypgYI6sqXj\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 77.0, \"Danceability\": 0.55, \"Energy\": 0.598, \"Loudness\": -5.402, \"Speechiness\": 0.0831, \"Acousticness\": 0.132, \"Liveness\": 0.0955, \"Tempo\": 83.836, \"Duration (ms)\": 232496.0, \"Valence\": 0.543, \"Chord\": \"B\"}, {\"Index\": 1311, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Moon Relate\", \"Streams\": 5324545, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4sWGHlZGM1XA7TyWdtBAbA\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 58.0, \"Danceability\": 0.867, \"Energy\": 0.768, \"Loudness\": -3.73, \"Speechiness\": 0.0791, \"Acousticness\": 0.18, \"Liveness\": 0.254, \"Tempo\": 102.021, \"Duration (ms)\": 181826.0, \"Valence\": 0.34, \"Chord\": \"G\"}, {\"Index\": 1312, \"Highest Charting Position\": 163, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Black And White\", \"Streams\": 5204120, \"Artist\": \"Niall Horan\", \"Artist Followers\": 7564659.0, \"Song ID\": \"7rpNuuoMbid56XkDsx2FjE\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 75.0, \"Danceability\": 0.443, \"Energy\": 0.582, \"Loudness\": -6.02, \"Speechiness\": 0.0482, \"Acousticness\": 0.0301, \"Liveness\": 0.127, \"Tempo\": 147.589, \"Duration (ms)\": 193090.0, \"Valence\": 0.239, \"Chord\": \"D\"}, {\"Index\": 1313, \"Highest Charting Position\": 81, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"The Other Side (from Trolls World Tour)\", \"Streams\": 5193927, \"Artist\": \"SZA, Justin Timberlake\", \"Artist Followers\": 5888533.0, \"Song ID\": \"463PQggkmk5tTw8ug0ahOX\", \"Genre\": \"['pop', 'pop rap', 'r&b']\", \"Release Date\": \"2020-02-26\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 68.0, \"Danceability\": 0.76, \"Energy\": 0.607, \"Loudness\": -6.274, \"Speechiness\": 0.0964, \"Acousticness\": 0.00277, \"Liveness\": 0.132, \"Tempo\": 105.979, \"Duration (ms)\": 188187.0, \"Valence\": 0.709, \"Chord\": \"G\"}, {\"Index\": 1314, \"Highest Charting Position\": 53, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Whine Up\", \"Streams\": 5130783, \"Artist\": \"Nicky Jam, Anuel AA\", \"Artist Followers\": 14831925.0, \"Song ID\": \"2pWOMNQJW3g2zmGjP0Vkb0\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-01\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.817, \"Energy\": 0.665, \"Loudness\": -6.224, \"Speechiness\": 0.0758, \"Acousticness\": 0.0549, \"Liveness\": 0.103, \"Tempo\": 104.957, \"Duration (ms)\": 215460.0, \"Valence\": 0.662, \"Chord\": \"A\"}, {\"Index\": 1315, \"Highest Charting Position\": 37, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Ayy Macarena\", \"Streams\": 5046905, \"Artist\": \"Tyga\", \"Artist Followers\": 6298789.0, \"Song ID\": \"6LcauUZjF1eXQrgqMUecHX\", \"Genre\": \"['dance pop', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2019-11-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.816, \"Energy\": 0.629, \"Loudness\": -5.568, \"Speechiness\": 0.226, \"Acousticness\": 0.133, \"Liveness\": 0.0692, \"Tempo\": 96.493, \"Duration (ms)\": 131607.0, \"Valence\": 0.714, \"Chord\": \"D\"}, {\"Index\": 1316, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Trap This Way (This Way)\", \"Streams\": 5043990, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7vTspUAmMKFkUpKL9HLZNL\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 59.0, \"Danceability\": 0.71, \"Energy\": 0.586, \"Loudness\": -5.331, \"Speechiness\": 0.381, \"Acousticness\": 0.248, \"Liveness\": 0.193, \"Tempo\": 175.987, \"Duration (ms)\": 185439.0, \"Valence\": 0.207, \"Chord\": \"D\"}, {\"Index\": 1317, \"Highest Charting Position\": 113, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Who (feat. BTS)\", \"Streams\": 5004752, \"Artist\": \"Lauv\", \"Artist Followers\": 4442273.0, \"Song ID\": \"2qG81jL9UIP54uS8gYyP4k\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 74.0, \"Danceability\": 0.632, \"Energy\": 0.345, \"Loudness\": -8.0, \"Speechiness\": 0.0349, \"Acousticness\": 0.551, \"Liveness\": 0.104, \"Tempo\": 141.641, \"Duration (ms)\": 180413.0, \"Valence\": 0.0818, \"Chord\": \"B\"}, {\"Index\": 1318, \"Highest Charting Position\": 51, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Homecoming\", \"Streams\": 4988839, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"6vxU64pcIuQ38O015Zy4qj\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 63.0, \"Danceability\": 0.929, \"Energy\": 0.563, \"Loudness\": -7.428, \"Speechiness\": 0.49, \"Acousticness\": 0.000592, \"Liveness\": 0.244, \"Tempo\": 129.957, \"Duration (ms)\": 213885.0, \"Valence\": 0.353, \"Chord\": \"A\"}, {\"Index\": 1319, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Got The Guap (feat. Young Thug)\", \"Streams\": 4946997, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"1HF6P40Z7nfExGaB1Gk99v\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 58.0, \"Danceability\": 0.837, \"Energy\": 0.601, \"Loudness\": -5.628, \"Speechiness\": 0.198, \"Acousticness\": 0.21, \"Liveness\": 0.0928, \"Tempo\": 142.977, \"Duration (ms)\": 176756.0, \"Valence\": 0.749, \"Chord\": \"G#/Ab\"}, {\"Index\": 1320, \"Highest Charting Position\": 53, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Prices\", \"Streams\": 4898167, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4YcWzLSnGqLjSCycuSMHnn\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 65.0, \"Danceability\": 0.786, \"Energy\": 0.683, \"Loudness\": -5.397, \"Speechiness\": 0.205, \"Acousticness\": 0.173, \"Liveness\": 0.706, \"Tempo\": 126.002, \"Duration (ms)\": 233333.0, \"Valence\": 0.57, \"Chord\": \"G\"}, {\"Index\": 1321, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"I Can Show You\", \"Streams\": 4831405, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"0AhJag7VI8uFf3mJFsTwvf\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 57.0, \"Danceability\": 0.817, \"Energy\": 0.656, \"Loudness\": -7.086, \"Speechiness\": 0.277, \"Acousticness\": 0.051, \"Liveness\": 0.115, \"Tempo\": 139.915, \"Duration (ms)\": 120076.0, \"Valence\": 0.314, \"Chord\": \"A#/Bb\"}, {\"Index\": 1322, \"Highest Charting Position\": 52, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"I'm Sorry\", \"Streams\": 4818039, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"1xcOYJxDa5pObgxY1r0I9c\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 60.0, \"Danceability\": 0.858, \"Energy\": 0.547, \"Loudness\": -5.822, \"Speechiness\": 0.29, \"Acousticness\": 0.213, \"Liveness\": 0.104, \"Tempo\": 128.02, \"Duration (ms)\": 211883.0, \"Valence\": 0.303, \"Chord\": \"C#/Db\"}, {\"Index\": 1323, \"Highest Charting Position\": 19, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Black Swan\", \"Streams\": 4802069, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3bkkMZEAhx7rTVz1C0itRQ\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 70.0, \"Danceability\": 0.719, \"Energy\": 0.758, \"Loudness\": -5.167, \"Speechiness\": 0.0851, \"Acousticness\": 0.137, \"Liveness\": 0.129, \"Tempo\": 147.023, \"Duration (ms)\": 198261.0, \"Valence\": 0.49, \"Chord\": \"D\"}, {\"Index\": 1324, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Bad Child\", \"Streams\": 4787180, \"Artist\": \"Tones And I\", \"Artist Followers\": 1251372.0, \"Song ID\": \"2hBeHlR2d7wFJVLcj2fivL\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 0.0, \"Danceability\": 0.756, \"Energy\": 0.553, \"Loudness\": -4.24, \"Speechiness\": 0.0343, \"Acousticness\": 0.404, \"Liveness\": 0.158, \"Tempo\": 117.992, \"Duration (ms)\": 221467.0, \"Valence\": 0.597, \"Chord\": \"F#/Gb\"}, {\"Index\": 1325, \"Highest Charting Position\": 61, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Adicto (with Anuel AA & Ozuna)\", \"Streams\": 4785720, \"Artist\": \"Tainy\", \"Artist Followers\": 509411.0, \"Song ID\": \"3jbT1Y5MoPwEIpZndDDwVq\", \"Genre\": \"['latin', 'latin hip hop', 'latin pop', 'pop reggaeton', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-08-22\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.734, \"Energy\": 0.836, \"Loudness\": -4.803, \"Speechiness\": 0.0735, \"Acousticness\": 0.017, \"Liveness\": 0.179, \"Tempo\": 80.002, \"Duration (ms)\": 270741.0, \"Valence\": 0.623, \"Chord\": \"A#/Bb\"}, {\"Index\": 1326, \"Highest Charting Position\": 66, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"<3\", \"Streams\": 4755477, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4MZSqgwlE71CWZ6qQ3gkKm\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.631, \"Energy\": 0.665, \"Loudness\": -7.589, \"Speechiness\": 0.229, \"Acousticness\": 0.602, \"Liveness\": 0.152, \"Tempo\": 80.353, \"Duration (ms)\": 157967.0, \"Valence\": 0.634, \"Chord\": \"A#/Bb\"}, {\"Index\": 1327, \"Highest Charting Position\": 198, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Bad Girls, Good Vibes\", \"Streams\": 4752181, \"Artist\": \"Ufo361\", \"Artist Followers\": 1700759.0, \"Song ID\": \"7IxGslFZA5QhgXbUsDmcjf\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 53.0, \"Danceability\": 0.826, \"Energy\": 0.368, \"Loudness\": -12.761, \"Speechiness\": 0.133, \"Acousticness\": 0.516, \"Liveness\": 0.0914, \"Tempo\": 127.977, \"Duration (ms)\": 107446.0, \"Valence\": 0.158, \"Chord\": \"G\"}, {\"Index\": 1328, \"Highest Charting Position\": 120, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Liberdade Provis\\u00f3ria - Ao Vivo\", \"Streams\": 4730891, \"Artist\": \"Henrique & Juliano\", \"Artist Followers\": 13312073.0, \"Song ID\": \"3Ghyp3X5Ua9ypHnBIgOObI\", \"Genre\": \"['sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 58.0, \"Danceability\": 0.668, \"Energy\": 0.684, \"Loudness\": -5.937, \"Speechiness\": 0.0527, \"Acousticness\": 0.627, \"Liveness\": 0.923, \"Tempo\": 108.138, \"Duration (ms)\": 187986.0, \"Valence\": 0.7, \"Chord\": \"C#/Db\"}, {\"Index\": 1329, \"Highest Charting Position\": 60, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"POP\", \"Streams\": 10484727, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"1jDbQz6tr52WgScCTXMnaN\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 58.0, \"Danceability\": 0.741, \"Energy\": 0.599, \"Loudness\": -6.672, \"Speechiness\": 0.419, \"Acousticness\": 0.00961, \"Liveness\": 0.785, \"Tempo\": 139.891, \"Duration (ms)\": 227474.0, \"Valence\": 0.276, \"Chord\": \"C#/Db\"}, {\"Index\": 1330, \"Highest Charting Position\": 61, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Celebration Station\", \"Streams\": 10396969, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"25B5fGr9K0VdZJiRFsnMO4\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 61.0, \"Danceability\": 0.748, \"Energy\": 0.771, \"Loudness\": -4.156, \"Speechiness\": 0.15, \"Acousticness\": 0.101, \"Liveness\": 0.135, \"Tempo\": 142.086, \"Duration (ms)\": 195058.0, \"Valence\": 0.792, \"Chord\": \"F#/Gb\"}, {\"Index\": 1331, \"Highest Charting Position\": 64, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Bigger Than Life\", \"Streams\": 9974143, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2oHDJHNondITqbl8xZ9vPn\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 62.0, \"Danceability\": 0.776, \"Energy\": 0.752, \"Loudness\": -4.711, \"Speechiness\": 0.193, \"Acousticness\": 0.325, \"Liveness\": 0.33, \"Tempo\": 140.013, \"Duration (ms)\": 192705.0, \"Valence\": 0.716, \"Chord\": \"G#/Ab\"}, {\"Index\": 1332, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Venetia\", \"Streams\": 9824605, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"3BYIzNZ3t9lRQCACXSMLrT\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 63.0, \"Danceability\": 0.775, \"Energy\": 0.757, \"Loudness\": -4.139, \"Speechiness\": 0.175, \"Acousticness\": 0.162, \"Liveness\": 0.148, \"Tempo\": 142.933, \"Duration (ms)\": 188800.0, \"Valence\": 0.562, \"Chord\": \"A\"}, {\"Index\": 1333, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"You Better Move\", \"Streams\": 9533898, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"6YAxCn4juTWn5hWl2hzHGw\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 60.0, \"Danceability\": 0.842, \"Energy\": 0.556, \"Loudness\": -6.793, \"Speechiness\": 0.442, \"Acousticness\": 0.159, \"Liveness\": 0.204, \"Tempo\": 118.836, \"Duration (ms)\": 196639.0, \"Valence\": 0.306, \"Chord\": \"G#/Ab\"}, {\"Index\": 1334, \"Highest Charting Position\": 93, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Chrome Heart Tags\", \"Streams\": 8219307, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"46mT9NR7N9Zf5MolcrBgE3\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 57.0, \"Danceability\": 0.702, \"Energy\": 0.768, \"Loudness\": -4.055, \"Speechiness\": 0.0669, \"Acousticness\": 0.541, \"Liveness\": 0.105, \"Tempo\": 70.056, \"Duration (ms)\": 212821.0, \"Valence\": 0.574, \"Chord\": \"C\"}, {\"Index\": 1335, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Bust Me\", \"Streams\": 7828045, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4wBcaYqLPm7EtDVoJQORU4\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 57.0, \"Danceability\": 0.734, \"Energy\": 0.703, \"Loudness\": -6.256, \"Speechiness\": 0.355, \"Acousticness\": 0.237, \"Liveness\": 0.413, \"Tempo\": 151.923, \"Duration (ms)\": 194452.0, \"Valence\": 0.608, \"Chord\": \"B\"}, {\"Index\": 1336, \"Highest Charting Position\": 46, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Ren\\u00e9\", \"Streams\": 7240117, \"Artist\": \"Residente\", \"Artist Followers\": 878491.0, \"Song ID\": \"6gm12xlADJwiBbHIKBXzGW\", \"Genre\": \"['venezuelan hip hop']\", \"Release Date\": \"2020-02-27\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 65.0, \"Danceability\": 0.486, \"Energy\": 0.388, \"Loudness\": -9.326, \"Speechiness\": 0.126, \"Acousticness\": 0.435, \"Liveness\": 0.196, \"Tempo\": 90.471, \"Duration (ms)\": 457592.0, \"Valence\": 0.467, \"Chord\": \"C\"}, {\"Index\": 1337, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Secure The Bag\", \"Streams\": 7053947, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7gHZGXSJzM29WA384suYY2\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 57.0, \"Danceability\": 0.803, \"Energy\": 0.719, \"Loudness\": -4.485, \"Speechiness\": 0.392, \"Acousticness\": 0.344, \"Liveness\": 0.425, \"Tempo\": 129.945, \"Duration (ms)\": 238425.0, \"Valence\": 0.549, \"Chord\": \"C\"}, {\"Index\": 1338, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Urgency (feat. Syd)\", \"Streams\": 6224412, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"5KlPy74NOEAt8jC3FYURnQ\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 53.0, \"Danceability\": 0.619, \"Energy\": 0.784, \"Loudness\": -6.11, \"Speechiness\": 0.123, \"Acousticness\": 0.0326, \"Liveness\": 0.315, \"Tempo\": 156.035, \"Duration (ms)\": 181161.0, \"Valence\": 0.471, \"Chord\": \"C#/Db\"}, {\"Index\": 1339, \"Highest Charting Position\": 34, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"ON (Feat. Sia)\", \"Streams\": 6219276, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3IB5qOeMayvpOdHxYCL5tZ\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 64.0, \"Danceability\": 0.591, \"Energy\": 0.848, \"Loudness\": -4.397, \"Speechiness\": 0.0828, \"Acousticness\": 0.137, \"Liveness\": 0.372, \"Tempo\": 105.922, \"Duration (ms)\": 246816.0, \"Valence\": 0.386, \"Chord\": \"A\"}, {\"Index\": 1340, \"Highest Charting Position\": 99, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"P FKN R\", \"Streams\": 6041127, \"Artist\": \"Bad Bunny, Kendo Kaponi, Arcangel\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0fgsKar6uBO08vzHXkTjWi\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 66.0, \"Danceability\": 0.82, \"Energy\": 0.635, \"Loudness\": -5.749, \"Speechiness\": 0.0772, \"Acousticness\": 0.409, \"Liveness\": 0.244, \"Tempo\": 101.024, \"Duration (ms)\": 258280.0, \"Valence\": 0.528, \"Chord\": \"F\"}, {\"Index\": 1341, \"Highest Charting Position\": 108, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Modern Loneliness\", \"Streams\": 6020508, \"Artist\": \"Lauv\", \"Artist Followers\": 4442273.0, \"Song ID\": \"1eyek0KJEh2v5HQ9uQSybb\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 68.0, \"Danceability\": 0.702, \"Energy\": 0.508, \"Loudness\": -7.105, \"Speechiness\": 0.035, \"Acousticness\": 0.144, \"Liveness\": 0.108, \"Tempo\": 82.008, \"Duration (ms)\": 252337.0, \"Valence\": 0.143, \"Chord\": \"G#/Ab\"}, {\"Index\": 1342, \"Highest Charting Position\": 65, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Heatin Up (feat. Gunna)\", \"Streams\": 6004839, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"7KSSdFCBHCfq4KPzz78ghk\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 66.0, \"Danceability\": 0.788, \"Energy\": 0.436, \"Loudness\": -9.435, \"Speechiness\": 0.364, \"Acousticness\": 0.0611, \"Liveness\": 0.0979, \"Tempo\": 129.847, \"Duration (ms)\": 177314.0, \"Valence\": 0.341, \"Chord\": \"C#/Db\"}, {\"Index\": 1343, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"SKYBOX\", \"Streams\": 5846484, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"7GwYENSg87oERcW0Wacd6m\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 59.0, \"Danceability\": 0.779, \"Energy\": 0.707, \"Loudness\": -6.527, \"Speechiness\": 0.16, \"Acousticness\": 0.0991, \"Liveness\": 0.0934, \"Tempo\": 140.894, \"Duration (ms)\": 178097.0, \"Valence\": 0.343, \"Chord\": \"C#/Db\"}, {\"Index\": 1344, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Young & Alive\", \"Streams\": 5578323, \"Artist\": \"Bazzi\", \"Artist Followers\": 4421378.0, \"Song ID\": \"5RsKelNxucrDxgMbZ3vd3W\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-05\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 71.0, \"Danceability\": 0.716, \"Energy\": 0.563, \"Loudness\": -5.486, \"Speechiness\": 0.0425, \"Acousticness\": 0.326, \"Liveness\": 0.119, \"Tempo\": 86.005, \"Duration (ms)\": 160465.0, \"Valence\": 0.495, \"Chord\": \"D#/Eb\"}, {\"Index\": 1345, \"Highest Charting Position\": 169, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"i'm so tired...\", \"Streams\": 5547770, \"Artist\": \"Lauv, Troye Sivan\", \"Artist Followers\": 4442273.0, \"Song ID\": \"4vjpLMyL3ZO6aphdYr8XYw\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-01-03--2020-01-10\", \"Popularity\": 77.0, \"Danceability\": 0.599, \"Energy\": 0.733, \"Loudness\": -7.058, \"Speechiness\": 0.203, \"Acousticness\": 0.176, \"Liveness\": 0.242, \"Tempo\": 102.211, \"Duration (ms)\": 162583.0, \"Valence\": 0.534, \"Chord\": \"B\"}, {\"Index\": 1346, \"Highest Charting Position\": 53, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Numbers (feat. Roddy Ricch, Gunna and London On Da Track)\", \"Streams\": 5487069, \"Artist\": \"A Boogie Wit da Hoodie\", \"Artist Followers\": 5865895.0, \"Song ID\": \"733c1CWmIGymoQXdp7Us88\", \"Genre\": \"['melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 68.0, \"Danceability\": 0.819, \"Energy\": 0.654, \"Loudness\": -6.665, \"Speechiness\": 0.136, \"Acousticness\": 0.517, \"Liveness\": 0.0996, \"Tempo\": 133.503, \"Duration (ms)\": 188563.0, \"Valence\": 0.455, \"Chord\": \"B\"}, {\"Index\": 1347, \"Highest Charting Position\": 105, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Girl\", \"Streams\": 5434180, \"Artist\": \"Myke Towers\", \"Artist Followers\": 6161098.0, \"Song ID\": \"43NqTeL8pgBxKHPMiJKUP5\", \"Genre\": \"['trap latino']\", \"Release Date\": \"2020-01-24\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 72.0, \"Danceability\": 0.733, \"Energy\": 0.708, \"Loudness\": -4.957, \"Speechiness\": 0.0937, \"Acousticness\": 0.0325, \"Liveness\": 0.324, \"Tempo\": 93.021, \"Duration (ms)\": 186427.0, \"Valence\": 0.694, \"Chord\": \"F#/Gb\"}, {\"Index\": 1348, \"Highest Charting Position\": 104, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Puesto Pa' Guerrial\", \"Streams\": 5359969, \"Artist\": \"Bad Bunny, Myke Towers\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5gCg2qMPzKkW4jS4dBKdDs\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 64.0, \"Danceability\": 0.867, \"Energy\": 0.686, \"Loudness\": -5.342, \"Speechiness\": 0.221, \"Acousticness\": 0.311, \"Liveness\": 0.1, \"Tempo\": 139.968, \"Duration (ms)\": 190207.0, \"Valence\": 0.658, \"Chord\": \"E\"}, {\"Index\": 1349, \"Highest Charting Position\": 114, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Definitivamente\", \"Streams\": 5325447, \"Artist\": \"Daddy Yankee, Sech\", \"Artist Followers\": 23936368.0, \"Song ID\": \"113PlnpZbHd3WIqeYjhZWv\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 66.0, \"Danceability\": 0.813, \"Energy\": 0.764, \"Loudness\": -3.39, \"Speechiness\": 0.105, \"Acousticness\": 0.586, \"Liveness\": 0.253, \"Tempo\": 100.047, \"Duration (ms)\": 217773.0, \"Valence\": 0.429, \"Chord\": \"G#/Ab\"}, {\"Index\": 1350, \"Highest Charting Position\": 41, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"South of the Border (feat. Camila Cabello & Cardi B)\", \"Streams\": 5315827, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"4vUmTMuQqjdnvlZmAH61Qk\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-07-12\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.857, \"Energy\": 0.621, \"Loudness\": -6.376, \"Speechiness\": 0.0825, \"Acousticness\": 0.148, \"Liveness\": 0.0865, \"Tempo\": 97.989, \"Duration (ms)\": 204467.0, \"Valence\": 0.668, \"Chord\": \"A\"}, {\"Index\": 1351, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"I Fall Apart\", \"Streams\": 5251918, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"75ZvA4QfFiZvzhj2xkaWAh\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2016-12-09\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 80.0, \"Danceability\": 0.556, \"Energy\": 0.538, \"Loudness\": -5.408, \"Speechiness\": 0.0382, \"Acousticness\": 0.0689, \"Liveness\": 0.196, \"Tempo\": 143.95, \"Duration (ms)\": 223347.0, \"Valence\": 0.291, \"Chord\": \"G#/Ab\"}, {\"Index\": 1352, \"Highest Charting Position\": 191, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"fuck, i'm lonely (with Anne-Marie)\", \"Streams\": 5226991, \"Artist\": \"Lauv\", \"Artist Followers\": 4442273.0, \"Song ID\": \"09PGubKAMryhOWv1LHpCYz\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 74.0, \"Danceability\": 0.806, \"Energy\": 0.558, \"Loudness\": -6.46, \"Speechiness\": 0.0683, \"Acousticness\": 0.482, \"Liveness\": 0.0618, \"Tempo\": 95.016, \"Duration (ms)\": 198973.0, \"Valence\": 0.678, \"Chord\": \"A\"}, {\"Index\": 1353, \"Highest Charting Position\": 78, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Aventura\", \"Streams\": 5206102, \"Artist\": \"Lunay, Ozuna, Anuel AA\", \"Artist Followers\": 4963516.0, \"Song ID\": \"37zdqI4r1gswIzczSBkRon\", \"Genre\": \"['latin', 'latin pop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-10-25\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.729, \"Energy\": 0.726, \"Loudness\": -3.208, \"Speechiness\": 0.0422, \"Acousticness\": 0.223, \"Liveness\": 0.101, \"Tempo\": 92.025, \"Duration (ms)\": 217130.0, \"Valence\": 0.876, \"Chord\": \"F\"}, {\"Index\": 1354, \"Highest Charting Position\": 12, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Rare\", \"Streams\": 5195842, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"7HMmFQsKsljwTw8bS7lu19\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 68.0, \"Danceability\": 0.838, \"Energy\": 0.545, \"Loudness\": -6.713, \"Speechiness\": 0.0706, \"Acousticness\": 0.208, \"Liveness\": 0.103, \"Tempo\": 114.998, \"Duration (ms)\": 220590.0, \"Valence\": 0.631, \"Chord\": \"F\"}, {\"Index\": 1355, \"Highest Charting Position\": 69, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"VIBEZ\", \"Streams\": 5121486, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"0fySG6A6qLE8IvDpayb5bM\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.768, \"Energy\": 0.652, \"Loudness\": -2.708, \"Speechiness\": 0.307, \"Acousticness\": 0.113, \"Liveness\": 0.107, \"Tempo\": 154.187, \"Duration (ms)\": 144935.0, \"Valence\": 0.777, \"Chord\": \"C#/Db\"}, {\"Index\": 1356, \"Highest Charting Position\": 69, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Mean It\", \"Streams\": 5110064, \"Artist\": \"Lauv, LANY\", \"Artist Followers\": 4442273.0, \"Song ID\": \"3uc8AGNL0KbvISIrjnfRvN\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.746, \"Energy\": 0.45, \"Loudness\": -8.543, \"Speechiness\": 0.0872, \"Acousticness\": 0.0407, \"Liveness\": 0.172, \"Tempo\": 95.998, \"Duration (ms)\": 232853.0, \"Valence\": 0.336, \"Chord\": \"G\"}, {\"Index\": 1357, \"Highest Charting Position\": 49, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"That Way\", \"Streams\": 12059592, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"5raTDhlbxFDnpn89bxArdH\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-01\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 67.0, \"Danceability\": 0.719, \"Energy\": 0.611, \"Loudness\": -5.01, \"Speechiness\": 0.0403, \"Acousticness\": 0.0582, \"Liveness\": 0.155, \"Tempo\": 129.962, \"Duration (ms)\": 212354.0, \"Valence\": 0.489, \"Chord\": \"G\"}, {\"Index\": 1358, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Live Off My Closet (feat. Future)\", \"Streams\": 7410327, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"6AyWdCtEn1DdxjnxPeojR2\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 59.0, \"Danceability\": 0.807, \"Energy\": 0.678, \"Loudness\": -3.244, \"Speechiness\": 0.177, \"Acousticness\": 0.0345, \"Liveness\": 0.0986, \"Tempo\": 147.004, \"Duration (ms)\": 173061.0, \"Valence\": 0.21, \"Chord\": \"F#/Gb\"}, {\"Index\": 1359, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Commercial (feat. Lil Uzi Vert)\", \"Streams\": 6540577, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"3tDqEKKUs6gf8zMvSuLyLA\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 67.0, \"Danceability\": 0.892, \"Energy\": 0.486, \"Loudness\": -8.637, \"Speechiness\": 0.384, \"Acousticness\": 0.048, \"Liveness\": 0.146, \"Tempo\": 120.998, \"Duration (ms)\": 214215.0, \"Valence\": 0.535, \"Chord\": \"B\"}, {\"Index\": 1360, \"Highest Charting Position\": 75, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Sum 2 Prove\", \"Streams\": 6497610, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"2u3EyuCqqV31woqGvO9LBz\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 71.0, \"Danceability\": 0.823, \"Energy\": 0.552, \"Loudness\": -7.57, \"Speechiness\": 0.324, \"Acousticness\": 0.0174, \"Liveness\": 0.122, \"Tempo\": 124.038, \"Duration (ms)\": 205760.0, \"Valence\": 0.418, \"Chord\": \"E\"}, {\"Index\": 1361, \"Highest Charting Position\": 47, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Filter\", \"Streams\": 5913946, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"0ono6UCNVZ1XqOm6j78Blu\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 79.0, \"Danceability\": 0.781, \"Energy\": 0.762, \"Loudness\": -5.188, \"Speechiness\": 0.0626, \"Acousticness\": 0.0222, \"Liveness\": 0.121, \"Tempo\": 110.042, \"Duration (ms)\": 180221.0, \"Valence\": 0.86, \"Chord\": \"A#/Bb\"}, {\"Index\": 1362, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Matrix\", \"Streams\": 5724739, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"7ygVaACDENw4PgLbN1awFE\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-02-24\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 55.0, \"Danceability\": 0.789, \"Energy\": 0.509, \"Loudness\": -8.766, \"Speechiness\": 0.291, \"Acousticness\": 0.768, \"Liveness\": 0.272, \"Tempo\": 114.957, \"Duration (ms)\": 183793.0, \"Valence\": 0.418, \"Chord\": \"A\"}, {\"Index\": 1363, \"Highest Charting Position\": 91, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Bellaquita - Remix\", \"Streams\": 5676621, \"Artist\": \"Dalex, Lenny Tav\\u00e1rez, Anitta, Natti Natasha, Farruko, Justin Quiles\", \"Artist Followers\": 3600989.0, \"Song ID\": \"1Xnn1TPyr5h0hpRAT4B4EA\", \"Genre\": \"['latin', 'r&b en espanol', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.795, \"Energy\": 0.715, \"Loudness\": -3.582, \"Speechiness\": 0.0838, \"Acousticness\": 0.141, \"Liveness\": 0.179, \"Tempo\": 165.941, \"Duration (ms)\": 304733.0, \"Valence\": 0.758, \"Chord\": \"C#/Db\"}, {\"Index\": 1364, \"Highest Charting Position\": 139, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Infeliz\", \"Streams\": 5490386, \"Artist\": \"Arcangel, Bad Bunny\", \"Artist Followers\": 6671084.0, \"Song ID\": \"4z6wo6PJG4Fve45OXK6D9m\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-12-20\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 72.0, \"Danceability\": 0.713, \"Energy\": 0.798, \"Loudness\": -3.147, \"Speechiness\": 0.219, \"Acousticness\": 0.366, \"Liveness\": 0.246, \"Tempo\": 176.073, \"Duration (ms)\": 221103.0, \"Valence\": 0.721, \"Chord\": \"C#/Db\"}, {\"Index\": 1365, \"Highest Charting Position\": 60, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Que Tire Pa Lante\", \"Streams\": 5436773, \"Artist\": \"Daddy Yankee\", \"Artist Followers\": 23936368.0, \"Song ID\": \"6RyaV7owmVU6fzEPE17sF1\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-10-18\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.658, \"Energy\": 0.901, \"Loudness\": -2.814, \"Speechiness\": 0.0357, \"Acousticness\": 0.0478, \"Liveness\": 0.12, \"Tempo\": 93.979, \"Duration (ms)\": 210520.0, \"Valence\": 0.708, \"Chord\": \"G\"}, {\"Index\": 1366, \"Highest Charting Position\": 32, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Futsal Shuffle 2020\", \"Streams\": 5386512, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2Ec33AVlkTTq8BHFgBTdQs\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-12\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.881, \"Energy\": 0.457, \"Loudness\": -8.191, \"Speechiness\": 0.156, \"Acousticness\": 0.0327, \"Liveness\": 0.231, \"Tempo\": 136.97, \"Duration (ms)\": 198913.0, \"Valence\": 0.296, \"Chord\": \"G\"}, {\"Index\": 1367, \"Highest Charting Position\": 123, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"GOODMORNINGTOKYO!\", \"Streams\": 5286044, \"Artist\": \"TOKYO\\u2019S REVENGE\", \"Artist Followers\": 313480.0, \"Song ID\": \"0Q2n5yzl2XRqYbV77tZNYp\", \"Genre\": \"['meme rap', 'sad rap', 'vapor trap', 'viral rap']\", \"Release Date\": \"2019-10-18\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 74.0, \"Danceability\": 0.907, \"Energy\": 0.539, \"Loudness\": -7.782, \"Speechiness\": 0.36, \"Acousticness\": 0.0408, \"Liveness\": 0.253, \"Tempo\": 124.918, \"Duration (ms)\": 150115.0, \"Valence\": 0.664, \"Chord\": \"E\"}, {\"Index\": 1368, \"Highest Charting Position\": 58, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Own It (feat. Ed Sheeran & Burna Boy)\", \"Streams\": 5273046, \"Artist\": \"Stormzy\", \"Artist Followers\": 2317758.0, \"Song ID\": \"4QPEwDdOMhY7rNS05mTyMR\", \"Genre\": \"['grime', 'uk hip hop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.817, \"Energy\": 0.781, \"Loudness\": -4.178, \"Speechiness\": 0.112, \"Acousticness\": 0.00838, \"Liveness\": 0.123, \"Tempo\": 104.0, \"Duration (ms)\": 216707.0, \"Valence\": 0.359, \"Chord\": \"G\"}, {\"Index\": 1369, \"Highest Charting Position\": 128, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Life Is Good (feat. Drake, DaBaby & Lil Baby) - Remix\", \"Streams\": 5260351, \"Artist\": \"Future\", \"Artist Followers\": 10491105.0, \"Song ID\": \"4iiWcajF1fEUpwcUewc464\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-02-15\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 61.0, \"Danceability\": 0.81, \"Energy\": 0.566, \"Loudness\": -8.33, \"Speechiness\": 0.433, \"Acousticness\": 0.107, \"Liveness\": 0.122, \"Tempo\": 142.069, \"Duration (ms)\": 315346.0, \"Valence\": 0.582, \"Chord\": \"F\"}, {\"Index\": 1370, \"Highest Charting Position\": 58, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"My Time\", \"Streams\": 5212053, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4vTgx6h4seHvkuFh84JXYP\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 74.0, \"Danceability\": 0.674, \"Energy\": 0.64, \"Loudness\": -5.139, \"Speechiness\": 0.0339, \"Acousticness\": 0.151, \"Liveness\": 0.0925, \"Tempo\": 99.908, \"Duration (ms)\": 234458.0, \"Valence\": 0.664, \"Chord\": \"C\"}, {\"Index\": 1371, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"100k Cash\", \"Streams\": 5192813, \"Artist\": \"Capital Bra, Samra\", \"Artist Followers\": 4093115.0, \"Song ID\": \"033if6Adj8fwBYsQzHOfQ8\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-02-27\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 52.0, \"Danceability\": 0.701, \"Energy\": 0.714, \"Loudness\": -5.906, \"Speechiness\": 0.524, \"Acousticness\": 0.289, \"Liveness\": 0.0883, \"Tempo\": 86.91, \"Duration (ms)\": 173353.0, \"Valence\": 0.604, \"Chord\": \"A#/Bb\"}, {\"Index\": 1372, \"Highest Charting Position\": 185, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Drown (feat. Clinton Kane)\", \"Streams\": 5186141, \"Artist\": \"Martin Garrix\", \"Artist Followers\": 14921269.0, \"Song ID\": \"4RVtBlHFKj51Ipvpfv5ER4\", \"Genre\": \"['dance pop', 'dutch edm', 'edm', 'pop', 'pop dance', 'progressive house', 'tropical house']\", \"Release Date\": \"2020-02-27\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 74.0, \"Danceability\": 0.573, \"Energy\": 0.739, \"Loudness\": -5.455, \"Speechiness\": 0.0581, \"Acousticness\": 0.212, \"Liveness\": 0.175, \"Tempo\": 120.077, \"Duration (ms)\": 174062.0, \"Valence\": 0.363, \"Chord\": \"A\"}, {\"Index\": 1373, \"Highest Charting Position\": 103, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"me & ur ghost\", \"Streams\": 5184069, \"Artist\": \"blackbear\", \"Artist Followers\": 4272745.0, \"Song ID\": \"38KsRHYE10bG0paU78gL9r\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 71.0, \"Danceability\": 0.742, \"Energy\": 0.679, \"Loudness\": -4.594, \"Speechiness\": 0.0259, \"Acousticness\": 0.0488, \"Liveness\": 0.0754, \"Tempo\": 100.041, \"Duration (ms)\": 201398.0, \"Valence\": 0.856, \"Chord\": \"G\"}, {\"Index\": 1374, \"Highest Charting Position\": 146, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"QUE PRETENDES\", \"Streams\": 5141047, \"Artist\": \"J Balvin, Bad Bunny\", \"Artist Followers\": 29067437.0, \"Song ID\": \"25ZAibhr3bdlMCLmubZDVt\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.639, \"Energy\": 0.791, \"Loudness\": -4.443, \"Speechiness\": 0.253, \"Acousticness\": 0.0275, \"Liveness\": 0.362, \"Tempo\": 92.603, \"Duration (ms)\": 222347.0, \"Valence\": 0.939, \"Chord\": \"A#/Bb\"}, {\"Index\": 1375, \"Highest Charting Position\": 140, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"You Need To Calm Down\", \"Streams\": 5115153, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6RRNNciQGZEXnqk8SQ9yv5\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.771, \"Energy\": 0.671, \"Loudness\": -5.617, \"Speechiness\": 0.0553, \"Acousticness\": 0.00929, \"Liveness\": 0.0637, \"Tempo\": 85.026, \"Duration (ms)\": 171360.0, \"Valence\": 0.714, \"Chord\": \"D\"}, {\"Index\": 1376, \"Highest Charting Position\": 90, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Quizas\", \"Streams\": 5112244, \"Artist\": \"Rich Music LTD, Sech, Dalex, Justin Quiles, Lenny Tav\\u00e1rez, Feid, Wisin, Zion\", \"Artist Followers\": 206225.0, \"Song ID\": \"5Id5B3dxJZhPcV9GzgYZZe\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-10-11\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.727, \"Energy\": 0.815, \"Loudness\": -2.454, \"Speechiness\": 0.153, \"Acousticness\": 0.0258, \"Liveness\": 0.231, \"Tempo\": 176.075, \"Duration (ms)\": 216067.0, \"Valence\": 0.677, \"Chord\": \"D#/Eb\"}, {\"Index\": 1377, \"Highest Charting Position\": 106, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Soltera - Remix\", \"Streams\": 5078459, \"Artist\": \"Lunay, Daddy Yankee, Bad Bunny\", \"Artist Followers\": 4963516.0, \"Song ID\": \"1c0hsvHLELX6y8qymnpLKL\", \"Genre\": \"['latin', 'latin pop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-05-10\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.795, \"Energy\": 0.783, \"Loudness\": -4.271, \"Speechiness\": 0.0432, \"Acousticness\": 0.361, \"Liveness\": 0.437, \"Tempo\": 92.01, \"Duration (ms)\": 266087.0, \"Valence\": 0.799, \"Chord\": \"F\"}, {\"Index\": 1378, \"Highest Charting Position\": 46, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Trampoline (with ZAYN)\", \"Streams\": 5075520, \"Artist\": \"SHAED\", \"Artist Followers\": 139434.0, \"Song ID\": \"1iQDltZqI7BXnHrFy4Qo1k\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-09-26\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 73.0, \"Danceability\": 0.619, \"Energy\": 0.459, \"Loudness\": -5.782, \"Speechiness\": 0.0334, \"Acousticness\": 0.56, \"Liveness\": 0.137, \"Tempo\": 126.803, \"Duration (ms)\": 184280.0, \"Valence\": 0.498, \"Chord\": \"G\"}, {\"Index\": 1379, \"Highest Charting Position\": 82, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Truth Hurts\", \"Streams\": 5024683, \"Artist\": \"Lizzo\", \"Artist Followers\": 3991674.0, \"Song ID\": \"3HWzoMvoF3TQfYg4UPszDq\", \"Genre\": \"['dance pop', 'escape room', 'minnesota hip hop', 'pop', 'pop rap', 'post-teen pop', 'trap queen']\", \"Release Date\": \"2019-04-19\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.715, \"Energy\": 0.624, \"Loudness\": -3.046, \"Speechiness\": 0.114, \"Acousticness\": 0.11, \"Liveness\": 0.123, \"Tempo\": 158.087, \"Duration (ms)\": 173325.0, \"Valence\": 0.412, \"Chord\": \"E\"}, {\"Index\": 1380, \"Highest Charting Position\": 91, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"bury a friend\", \"Streams\": 5020303, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"7p6ZK1vOxKELFwlDfwkJCp\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 1.0, \"Danceability\": 0.887, \"Energy\": 0.388, \"Loudness\": -14.505, \"Speechiness\": 0.349, \"Acousticness\": 0.739, \"Liveness\": 0.106, \"Tempo\": 120.035, \"Duration (ms)\": 193143.0, \"Valence\": 0.205, \"Chord\": \"G#/Ab\"}, {\"Index\": 1381, \"Highest Charting Position\": 54, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Louder than bombs\", \"Streams\": 10016907, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3op7HNwLli54MBjFGzIlZO\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.643, \"Energy\": 0.667, \"Loudness\": -6.993, \"Speechiness\": 0.152, \"Acousticness\": 0.0433, \"Liveness\": 0.0904, \"Tempo\": 145.999, \"Duration (ms)\": 217404.0, \"Valence\": 0.485, \"Chord\": \"C\"}, {\"Index\": 1382, \"Highest Charting Position\": 56, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"UGH!\", \"Streams\": 9991177, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"1aKuG1GG76xPLUkjBbQo3W\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.72, \"Energy\": 0.824, \"Loudness\": -5.086, \"Speechiness\": 0.128, \"Acousticness\": 0.0394, \"Liveness\": 0.0509, \"Tempo\": 165.998, \"Duration (ms)\": 225012.0, \"Valence\": 0.333, \"Chord\": \"A#/Bb\"}, {\"Index\": 1383, \"Highest Charting Position\": 67, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"00:00 (Zero O\\u2019Clock)\", \"Streams\": 9372219, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4AlihYDqxXshKhvh5tnMfP\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.566, \"Energy\": 0.548, \"Loudness\": -6.456, \"Speechiness\": 0.0579, \"Acousticness\": 0.0802, \"Liveness\": 0.11, \"Tempo\": 157.999, \"Duration (ms)\": 250296.0, \"Valence\": 0.196, \"Chord\": \"C#/Db\"}, {\"Index\": 1384, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Friends\", \"Streams\": 8822365, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"7w05lsU2VLSeiT8Nukrv5M\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.55, \"Energy\": 0.747, \"Loudness\": -5.211, \"Speechiness\": 0.0407, \"Acousticness\": 0.0668, \"Liveness\": 0.0536, \"Tempo\": 79.98, \"Duration (ms)\": 199339.0, \"Valence\": 0.648, \"Chord\": \"C#/Db\"}, {\"Index\": 1385, \"Highest Charting Position\": 75, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"We are Bulletproof : the Eternal\", \"Streams\": 8516710, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"44WLOqH7QayQOQdeUHeKUK\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.526, \"Energy\": 0.575, \"Loudness\": -5.215, \"Speechiness\": 0.0309, \"Acousticness\": 0.225, \"Liveness\": 0.108, \"Tempo\": 84.047, \"Duration (ms)\": 261543.0, \"Valence\": 0.19, \"Chord\": \"A\"}, {\"Index\": 1386, \"Highest Charting Position\": 79, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Inner Child\", \"Streams\": 8312399, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4BKOjYosPhw334moS3wlbO\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 71.0, \"Danceability\": 0.589, \"Energy\": 0.696, \"Loudness\": -7.981, \"Speechiness\": 0.0725, \"Acousticness\": 0.017, \"Liveness\": 0.0808, \"Tempo\": 134.953, \"Duration (ms)\": 233266.0, \"Valence\": 0.332, \"Chord\": \"B\"}, {\"Index\": 1387, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Moon\", \"Streams\": 7850129, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"1xfXXujIlLZAx5wpu46Nyk\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.703, \"Energy\": 0.646, \"Loudness\": -6.658, \"Speechiness\": 0.0596, \"Acousticness\": 0.0104, \"Liveness\": 0.191, \"Tempo\": 141.87, \"Duration (ms)\": 208590.0, \"Valence\": 0.64, \"Chord\": \"F#/Gb\"}, {\"Index\": 1388, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Outro : Ego\", \"Streams\": 6857808, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3r9FFjLrAIQjoR8pSHVPC9\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 69.0, \"Danceability\": 0.808, \"Energy\": 0.903, \"Loudness\": -3.106, \"Speechiness\": 0.0958, \"Acousticness\": 0.0121, \"Liveness\": 0.0993, \"Tempo\": 116.988, \"Duration (ms)\": 196199.0, \"Valence\": 0.473, \"Chord\": \"C\"}, {\"Index\": 1389, \"Highest Charting Position\": 109, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Interlude : Shadow\", \"Streams\": 6655856, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"2Nib4r0saYQf2pUV4RFDhl\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 68.0, \"Danceability\": 0.385, \"Energy\": 0.798, \"Loudness\": -6.439, \"Speechiness\": 0.483, \"Acousticness\": 0.115, \"Liveness\": 0.181, \"Tempo\": 149.756, \"Duration (ms)\": 259821.0, \"Valence\": 0.141, \"Chord\": \"A\"}, {\"Index\": 1390, \"Highest Charting Position\": 120, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Respect\", \"Streams\": 6373954, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"37TSJmYKLxXmx8OehFpqMN\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 67.0, \"Danceability\": 0.661, \"Energy\": 0.84, \"Loudness\": -4.805, \"Speechiness\": 0.116, \"Acousticness\": 0.00485, \"Liveness\": 0.287, \"Tempo\": 91.457, \"Duration (ms)\": 237540.0, \"Valence\": 0.524, \"Chord\": \"C\"}, {\"Index\": 1391, \"Highest Charting Position\": 154, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Tudo Ok\", \"Streams\": 5510844, \"Artist\": \"Thiaguinho MT, Mila, JS o M\\u00e3o de Ouro\", \"Artist Followers\": 28017.0, \"Song ID\": \"4HUZBG98TYbxSR9V1V2DWS\", \"Genre\": \"['brega funk', 'funk carioca']\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 57.0, \"Danceability\": 0.814, \"Energy\": 0.755, \"Loudness\": -6.164, \"Speechiness\": 0.0942, \"Acousticness\": 0.239, \"Liveness\": 0.306, \"Tempo\": 79.976, \"Duration (ms)\": 178500.0, \"Valence\": 0.963, \"Chord\": \"B\"}, {\"Index\": 1392, \"Highest Charting Position\": 128, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Perreo en La Luna\", \"Streams\": 5135469, \"Artist\": \"Rich Music LTD, Sech, Dalex, Justin Quiles, Lenny Tav\\u00e1rez, Feid\", \"Artist Followers\": 206225.0, \"Song ID\": \"0RDgqtvOHLwcI6yz9bjsZV\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-10-11\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.711, \"Energy\": 0.757, \"Loudness\": -4.188, \"Speechiness\": 0.29, \"Acousticness\": 0.268, \"Liveness\": 0.367, \"Tempo\": 174.013, \"Duration (ms)\": 218587.0, \"Valence\": 0.724, \"Chord\": \"C#/Db\"}, {\"Index\": 1393, \"Highest Charting Position\": 129, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Lose Yourself - From \\\"8 Mile\\\" Soundtrack\", \"Streams\": 5118004, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5Z01UMMf7V1o0MzF86s6WJ\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2005-12-06\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 75.0, \"Danceability\": 0.692, \"Energy\": 0.744, \"Loudness\": -4.565, \"Speechiness\": 0.257, \"Acousticness\": 0.00868, \"Liveness\": 0.359, \"Tempo\": 171.374, \"Duration (ms)\": 326467.0, \"Valence\": 0.0612, \"Chord\": \"D\"}, {\"Index\": 1394, \"Highest Charting Position\": 118, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"all the good girls go to hell\", \"Streams\": 5074485, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"6IRdLKIyS4p7XNiP8r6rsx\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-03-29\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.726, \"Energy\": 0.444, \"Loudness\": -8.922, \"Speechiness\": 0.372, \"Acousticness\": 0.283, \"Liveness\": 0.177, \"Tempo\": 185.044, \"Duration (ms)\": 168840.0, \"Valence\": 0.569, \"Chord\": \"G#/Ab\"}, {\"Index\": 1395, \"Highest Charting Position\": 155, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"SENTAD\\u00c3O\", \"Streams\": 5013019, \"Artist\": \"PEDRO SAMPAIO, Felipe Original, JS o M\\u00e3o de Ouro\", \"Artist Followers\": 1050520.0, \"Song ID\": \"4lKuzrdZrJuCAedbIslF3A\", \"Genre\": \"['funk carioca']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2019-12-27--2020-01-03\", \"Popularity\": 64.0, \"Danceability\": 0.68, \"Energy\": 0.869, \"Loudness\": -1.94, \"Speechiness\": 0.0589, \"Acousticness\": 0.178, \"Liveness\": 0.223, \"Tempo\": 173.997, \"Duration (ms)\": 143448.0, \"Valence\": 0.924, \"Chord\": \"F#/Gb\"}, {\"Index\": 1396, \"Highest Charting Position\": 182, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Lottery (Renegade)\", \"Streams\": 4994448, \"Artist\": \"K CAMP\", \"Artist Followers\": 1347589.0, \"Song ID\": \"4dZTZbmJBCCofAExHwefda\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'pop r&b', 'pop rap', 'r&b', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 61.0, \"Danceability\": 0.915, \"Energy\": 0.556, \"Loudness\": -8.601, \"Speechiness\": 0.216, \"Acousticness\": 0.0145, \"Liveness\": 0.0733, \"Tempo\": 148.964, \"Duration (ms)\": 170947.0, \"Valence\": 0.67, \"Chord\": \"C#/Db\"}, {\"Index\": 1397, \"Highest Charting Position\": 104, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Si Te Vas\", \"Streams\": 4954292, \"Artist\": \"Sech, Ozuna\", \"Artist Followers\": 8766508.0, \"Song ID\": \"6Y4PDQv4XjYjHLeLmvyOt0\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-09-26\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.73, \"Energy\": 0.644, \"Loudness\": -4.124, \"Speechiness\": 0.132, \"Acousticness\": 0.0933, \"Liveness\": 0.143, \"Tempo\": 174.101, \"Duration (ms)\": 204907.0, \"Valence\": 0.554, \"Chord\": \"C\"}, {\"Index\": 1398, \"Highest Charting Position\": 121, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Que Calor (with J Balvin & El Alfa)\", \"Streams\": 4950254, \"Artist\": \"Major Lazer, Diplo\", \"Artist Followers\": 6223652.0, \"Song ID\": \"3iQGDAAKMrlJarnaYNgnSE\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'moombahton', 'pop', 'pop dance', 'pop rap']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 29.0, \"Danceability\": 0.873, \"Energy\": 0.656, \"Loudness\": -6.043, \"Speechiness\": 0.068, \"Acousticness\": 0.00477, \"Liveness\": 0.0726, \"Tempo\": 125.982, \"Duration (ms)\": 206811.0, \"Valence\": 0.546, \"Chord\": \"G#/Ab\"}, {\"Index\": 1399, \"Highest Charting Position\": 186, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Rich Rich\", \"Streams\": 4938864, \"Artist\": \"Ufo361\", \"Artist Followers\": 1700759.0, \"Song ID\": \"2QfmSvSMwTXcvlIkU0w1Yk\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 50.0, \"Danceability\": 0.548, \"Energy\": 0.648, \"Loudness\": -4.796, \"Speechiness\": 0.292, \"Acousticness\": 0.0842, \"Liveness\": 0.123, \"Tempo\": 141.937, \"Duration (ms)\": 204319.0, \"Valence\": 0.232, \"Chord\": \"E\"}, {\"Index\": 1400, \"Highest Charting Position\": 86, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Indeciso\", \"Streams\": 4897374, \"Artist\": \"Reik, J Balvin, Lalo Ebratt\", \"Artist Followers\": 1251372.0, \"Song ID\": \"0FnPT2g07W4aXuHjniC1of\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.738, \"Energy\": 0.748, \"Loudness\": -4.902, \"Speechiness\": 0.0453, \"Acousticness\": 0.182, \"Liveness\": 0.109, \"Tempo\": 94.949, \"Duration (ms)\": 217253.0, \"Valence\": 0.896, \"Chord\": \"C\"}, {\"Index\": 1401, \"Highest Charting Position\": 148, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"i love you\", \"Streams\": 4863910, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"0np7TYPZSum9xTxe9QTr21\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-03--2020-01-10\", \"Popularity\": 2.0, \"Danceability\": 0.42, \"Energy\": 0.131, \"Loudness\": -18.435, \"Speechiness\": 0.0382, \"Acousticness\": 0.953, \"Liveness\": 0.109, \"Tempo\": 137.421, \"Duration (ms)\": 291796.0, \"Valence\": 0.12, \"Chord\": \"C\"}, {\"Index\": 1402, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Mejor\", \"Streams\": 4851895, \"Artist\": \"Dalex, Sech\", \"Artist Followers\": 3600989.0, \"Song ID\": \"6C1jKbkCUgFws7M0M4oGCB\", \"Genre\": \"['latin', 'r&b en espanol', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 63.0, \"Danceability\": 0.524, \"Energy\": 0.577, \"Loudness\": -4.501, \"Speechiness\": 0.18, \"Acousticness\": 0.185, \"Liveness\": 0.103, \"Tempo\": 175.396, \"Duration (ms)\": 201361.0, \"Valence\": 0.19, \"Chord\": \"D\"}, {\"Index\": 1403, \"Highest Charting Position\": 57, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Give No Fxk\", \"Streams\": 9652399, \"Artist\": \"Migos, Travis Scott, Young Thug\", \"Artist Followers\": 11692972.0, \"Song ID\": \"6ZelF5APDN5r6XnFqcnvWR\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 59.0, \"Danceability\": 0.904, \"Energy\": 0.627, \"Loudness\": -5.608, \"Speechiness\": 0.222, \"Acousticness\": 0.0303, \"Liveness\": 0.0923, \"Tempo\": 145.976, \"Duration (ms)\": 224243.0, \"Valence\": 0.236, \"Chord\": \"C#/Db\"}, {\"Index\": 1404, \"Highest Charting Position\": 61, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Come Around Me\", \"Streams\": 9533583, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2o9LAypwGH4ctV0i9boo6d\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 66.0, \"Danceability\": 0.648, \"Energy\": 0.681, \"Loudness\": -8.389, \"Speechiness\": 0.0378, \"Acousticness\": 0.263, \"Liveness\": 0.0971, \"Tempo\": 157.941, \"Duration (ms)\": 200773.0, \"Valence\": 0.767, \"Chord\": \"D\"}, {\"Index\": 1405, \"Highest Charting Position\": 64, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Habitual\", \"Streams\": 9120086, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"40qyPyljksBEqlNw5sW37T\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 62.0, \"Danceability\": 0.764, \"Energy\": 0.443, \"Loudness\": -6.625, \"Speechiness\": 0.0439, \"Acousticness\": 0.52, \"Liveness\": 0.0749, \"Tempo\": 138.999, \"Duration (ms)\": 168200.0, \"Valence\": 0.63, \"Chord\": \"E\"}, {\"Index\": 1406, \"Highest Charting Position\": 65, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"All Around Me\", \"Streams\": 9010535, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5Py8zRKGkZvgHniVVtvNCN\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 63.0, \"Danceability\": 0.566, \"Energy\": 0.438, \"Loudness\": -7.564, \"Speechiness\": 0.0367, \"Acousticness\": 0.809, \"Liveness\": 0.212, \"Tempo\": 117.127, \"Duration (ms)\": 136907.0, \"Valence\": 0.692, \"Chord\": \"C\"}, {\"Index\": 1407, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Get Me (feat. Kehlani)\", \"Streams\": 8362828, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5VwwpU7KsLhgfbMEecedhJ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 61.0, \"Danceability\": 0.832, \"Energy\": 0.508, \"Loudness\": -6.913, \"Speechiness\": 0.149, \"Acousticness\": 0.0492, \"Liveness\": 0.107, \"Tempo\": 109.352, \"Duration (ms)\": 185427.0, \"Valence\": 0.75, \"Chord\": \"F#/Gb\"}, {\"Index\": 1408, \"Highest Charting Position\": 79, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Second Emotion (feat. Travis Scott)\", \"Streams\": 8109572, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"1PnAx788sAvcI3ZxTlEyX8\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 61.0, \"Danceability\": 0.796, \"Energy\": 0.777, \"Loudness\": -6.112, \"Speechiness\": 0.0567, \"Acousticness\": 0.0276, \"Liveness\": 0.095, \"Tempo\": 141.97, \"Duration (ms)\": 202720.0, \"Valence\": 0.96, \"Chord\": \"B\"}, {\"Index\": 1409, \"Highest Charting Position\": 85, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Running Over (feat. Lil Dicky)\", \"Streams\": 7493188, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"75nKBP8jQu681pTNCtrEnn\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.774, \"Energy\": 0.603, \"Loudness\": -7.319, \"Speechiness\": 0.0591, \"Acousticness\": 0.438, \"Liveness\": 0.0869, \"Tempo\": 149.982, \"Duration (ms)\": 179627.0, \"Valence\": 0.977, \"Chord\": \"B\"}, {\"Index\": 1410, \"Highest Charting Position\": 86, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Available\", \"Streams\": 7473249, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"1b6tPXXCV2fSNtR3SKWUQA\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.702, \"Energy\": 0.608, \"Loudness\": -6.843, \"Speechiness\": 0.0359, \"Acousticness\": 0.0736, \"Liveness\": 0.129, \"Tempo\": 75.012, \"Duration (ms)\": 195333.0, \"Valence\": 0.597, \"Chord\": \"D#/Eb\"}, {\"Index\": 1411, \"Highest Charting Position\": 96, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Breathe Deeper\", \"Streams\": 7142364, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"3LbZIhU0smEU5SUnxod4j4\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 66.0, \"Danceability\": 0.664, \"Energy\": 0.848, \"Loudness\": -4.51, \"Speechiness\": 0.0322, \"Acousticness\": 0.0245, \"Liveness\": 0.172, \"Tempo\": 104.998, \"Duration (ms)\": 372867.0, \"Valence\": 0.502, \"Chord\": \"B\"}, {\"Index\": 1412, \"Highest Charting Position\": 103, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Changes\", \"Streams\": 6865229, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"521Os1SMlxmsoevsqyjNmJ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 62.0, \"Danceability\": 0.485, \"Energy\": 0.412, \"Loudness\": -7.766, \"Speechiness\": 0.042, \"Acousticness\": 0.738, \"Liveness\": 0.12, \"Tempo\": 64.062, \"Duration (ms)\": 135493.0, \"Valence\": 0.612, \"Chord\": \"A\"}, {\"Index\": 1413, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Confirmation\", \"Streams\": 6520106, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"60brXKLTC15vK0av5gIldm\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.438, \"Energy\": 0.315, \"Loudness\": -8.186, \"Speechiness\": 0.0375, \"Acousticness\": 0.608, \"Liveness\": 0.151, \"Tempo\": 190.064, \"Duration (ms)\": 170587.0, \"Valence\": 0.449, \"Chord\": \"G#/Ab\"}, {\"Index\": 1414, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Mios mit Bars\", \"Streams\": 6341141, \"Artist\": \"Luciano\", \"Artist Followers\": 942380.0, \"Song ID\": \"7Ek9e3eIuktIFjpDRQfmHE\", \"Genre\": \"['german drill', 'german hip hop']\", \"Release Date\": \"2020-02-13\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 57.0, \"Danceability\": 0.677, \"Energy\": 0.633, \"Loudness\": -7.353, \"Speechiness\": 0.0467, \"Acousticness\": 0.111, \"Liveness\": 0.217, \"Tempo\": 145.012, \"Duration (ms)\": 232147.0, \"Valence\": 0.404, \"Chord\": \"A\"}, {\"Index\": 1415, \"Highest Charting Position\": 135, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"E.T.A.\", \"Streams\": 6008945, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6PzOPrXx8tJEqace76yrv2\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.465, \"Energy\": 0.494, \"Loudness\": -7.595, \"Speechiness\": 0.066, \"Acousticness\": 0.49, \"Liveness\": 0.127, \"Tempo\": 127.298, \"Duration (ms)\": 176733.0, \"Valence\": 0.457, \"Chord\": \"E\"}, {\"Index\": 1416, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Borderline\", \"Streams\": 5921044, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"5hM5arv9KDbCHS0k9uqwjr\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 77.0, \"Danceability\": 0.621, \"Energy\": 0.873, \"Loudness\": -3.067, \"Speechiness\": 0.0369, \"Acousticness\": 0.0406, \"Liveness\": 0.0824, \"Tempo\": 97.96, \"Duration (ms)\": 237800.0, \"Valence\": 0.873, \"Chord\": \"F\"}, {\"Index\": 1417, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Take It Out On Me\", \"Streams\": 5858768, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"39nTNk5MfyiiRupTwn1iyC\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 54.0, \"Danceability\": 0.772, \"Energy\": 0.616, \"Loudness\": -4.673, \"Speechiness\": 0.102, \"Acousticness\": 0.00337, \"Liveness\": 0.104, \"Tempo\": 129.967, \"Duration (ms)\": 178013.0, \"Valence\": 0.279, \"Chord\": \"G\"}, {\"Index\": 1418, \"Highest Charting Position\": 67, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"No Shame\", \"Streams\": 5835260, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"5EbidH3lGB30WuDsoR4km6\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 62.0, \"Danceability\": 0.576, \"Energy\": 0.807, \"Loudness\": -3.019, \"Speechiness\": 0.0374, \"Acousticness\": 0.0185, \"Liveness\": 0.0963, \"Tempo\": 90.932, \"Duration (ms)\": 192737.0, \"Valence\": 0.479, \"Chord\": \"G\"}, {\"Index\": 1419, \"Highest Charting Position\": 160, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Might Not Give Up (feat. Young Thug)\", \"Streams\": 5503902, \"Artist\": \"A Boogie Wit da Hoodie\", \"Artist Followers\": 5865895.0, \"Song ID\": \"4l2rsMfr20dj6nf6i6F3Y8\", \"Genre\": \"['melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 57.0, \"Danceability\": 0.687, \"Energy\": 0.592, \"Loudness\": -6.378, \"Speechiness\": 0.224, \"Acousticness\": 0.203, \"Liveness\": 0.279, \"Tempo\": 178.83, \"Duration (ms)\": 225266.0, \"Valence\": 0.246, \"Chord\": \"D\"}, {\"Index\": 1420, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"That's What Love Is\", \"Streams\": 5440037, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2hLu8L8SNfCN4yKyPdX0h3\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 59.0, \"Danceability\": 0.639, \"Energy\": 0.437, \"Loudness\": -6.959, \"Speechiness\": 0.0355, \"Acousticness\": 0.692, \"Liveness\": 0.12, \"Tempo\": 147.575, \"Duration (ms)\": 165120.0, \"Valence\": 0.751, \"Chord\": \"A\"}, {\"Index\": 1421, \"Highest Charting Position\": 80, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Forever Yours - Avicii Tribute\", \"Streams\": 5421905, \"Artist\": \"Kygo, Sandro Cavazza\", \"Artist Followers\": 1251372.0, \"Song ID\": \"418ohXmKnlngIosIn6gG0H\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-10\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 15.0, \"Danceability\": 0.53, \"Energy\": 0.612, \"Loudness\": -8.794, \"Speechiness\": 0.0518, \"Acousticness\": 0.253, \"Liveness\": 0.246, \"Tempo\": 119.255, \"Duration (ms)\": 193847.0, \"Valence\": 0.433, \"Chord\": \"A#/Bb\"}, {\"Index\": 1422, \"Highest Charting Position\": 68, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Baby\", \"Streams\": 5376451, \"Artist\": \"Joker Bra, VIZE\", \"Artist Followers\": 191521.0, \"Song ID\": \"1V7JaMp11LKGwKiVmSetf0\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-01-30\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 63.0, \"Danceability\": 0.771, \"Energy\": 0.921, \"Loudness\": -4.228, \"Speechiness\": 0.109, \"Acousticness\": 0.166, \"Liveness\": 0.119, \"Tempo\": 128.021, \"Duration (ms)\": 148125.0, \"Valence\": 0.56, \"Chord\": \"C#/Db\"}, {\"Index\": 1423, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"One More Year\", \"Streams\": 5279739, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"5ozqshq2dtU7SYCpCBu0NE\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 56.0, \"Danceability\": 0.602, \"Energy\": 0.88, \"Loudness\": -5.414, \"Speechiness\": 0.0354, \"Acousticness\": 0.057, \"Liveness\": 0.284, \"Tempo\": 114.009, \"Duration (ms)\": 324013.0, \"Valence\": 0.493, \"Chord\": \"C#/Db\"}, {\"Index\": 1424, \"Highest Charting Position\": 14, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Good News\", \"Streams\": 5210780, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"1DWZUa5Mzf2BwzpHtgbHPY\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 75.0, \"Danceability\": 0.794, \"Energy\": 0.32, \"Loudness\": -12.92, \"Speechiness\": 0.173, \"Acousticness\": 0.853, \"Liveness\": 0.112, \"Tempo\": 174.088, \"Duration (ms)\": 342040.0, \"Valence\": 0.241, \"Chord\": \"C#/Db\"}, {\"Index\": 1425, \"Highest Charting Position\": 141, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"wish you were gay\", \"Streams\": 5187997, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"3Fj47GNK2kUF0uaEDgXLaD\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-03-29\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.853, \"Energy\": 0.351, \"Loudness\": -10.198, \"Speechiness\": 0.241, \"Acousticness\": 0.39, \"Liveness\": 0.752, \"Tempo\": 118.028, \"Duration (ms)\": 221543.0, \"Valence\": 0.282, \"Chord\": \"G\"}, {\"Index\": 1426, \"Highest Charting Position\": 61, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Only The Young - Featured in Miss Americana\", \"Streams\": 5111068, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2slqvGLwzZZYsT4K4Y1GBC\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 63.0, \"Danceability\": 0.56, \"Energy\": 0.78, \"Loudness\": -4.895, \"Speechiness\": 0.0517, \"Acousticness\": 0.00244, \"Liveness\": 0.0714, \"Tempo\": 93.516, \"Duration (ms)\": 157507.0, \"Valence\": 0.602, \"Chord\": \"F\"}, {\"Index\": 1427, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Lost In Yesterday\", \"Streams\": 5096624, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"5JWPUEov2wlX7c0jhYZpeB\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 69.0, \"Danceability\": 0.569, \"Energy\": 0.84, \"Loudness\": -4.123, \"Speechiness\": 0.118, \"Acousticness\": 0.0295, \"Liveness\": 0.0995, \"Tempo\": 183.059, \"Duration (ms)\": 249587.0, \"Valence\": 0.749, \"Chord\": \"C#/Db\"}, {\"Index\": 1428, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"At Least For Now\", \"Streams\": 5033764, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6VLkgf5YmLixsabdqiCVGU\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 54.0, \"Danceability\": 0.375, \"Energy\": 0.304, \"Loudness\": -9.897, \"Speechiness\": 0.0325, \"Acousticness\": 0.683, \"Liveness\": 0.196, \"Tempo\": 83.832, \"Duration (ms)\": 149653.0, \"Valence\": 0.295, \"Chord\": \"A\"}, {\"Index\": 1429, \"Highest Charting Position\": 167, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"you should see me in a crown\", \"Streams\": 4988054, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6WbvBhwCaUuYHcHGEuVgqo\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 0.0, \"Danceability\": 0.683, \"Energy\": 0.534, \"Loudness\": -10.348, \"Speechiness\": 0.189, \"Acousticness\": 0.519, \"Liveness\": 0.148, \"Tempo\": 150.469, \"Duration (ms)\": 180567.0, \"Valence\": 0.284, \"Chord\": \"E\"}, {\"Index\": 1430, \"Highest Charting Position\": 186, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Too Good At Goodbyes\", \"Streams\": 4984764, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"3VlbOrM6nYPprVvzBZllE5\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2017-11-03\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 72.0, \"Danceability\": 0.681, \"Energy\": 0.372, \"Loudness\": -8.237, \"Speechiness\": 0.0432, \"Acousticness\": 0.64, \"Liveness\": 0.169, \"Tempo\": 91.873, \"Duration (ms)\": 201000.0, \"Valence\": 0.476, \"Chord\": \"F\"}, {\"Index\": 1431, \"Highest Charting Position\": 7, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Intentions\", \"Streams\": 28509534, \"Artist\": \"Justin Bieber, Quavo\", \"Artist Followers\": 48544923.0, \"Song ID\": \"4umIPjkehX1r7uhmGvXiSV\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-07--2020-02-14\", \"Popularity\": 77.0, \"Danceability\": 0.806, \"Energy\": 0.546, \"Loudness\": -6.637, \"Speechiness\": 0.0575, \"Acousticness\": 0.3, \"Liveness\": 0.102, \"Tempo\": 147.986, \"Duration (ms)\": 212867.0, \"Valence\": 0.874, \"Chord\": \"A\"}, {\"Index\": 1432, \"Highest Charting Position\": 105, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Yikes\", \"Streams\": 6561188, \"Artist\": \"Nicki Minaj\", \"Artist Followers\": 22170982.0, \"Song ID\": \"75dLEqanQTupF3dtP9exT5\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'pop rap', 'post-teen pop', 'queens hip hop']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-02-07--2020-02-14\", \"Popularity\": 70.0, \"Danceability\": 0.911, \"Energy\": 0.637, \"Loudness\": -8.381, \"Speechiness\": 0.447, \"Acousticness\": 0.0409, \"Liveness\": 0.238, \"Tempo\": 149.996, \"Duration (ms)\": 156882.0, \"Valence\": 0.66, \"Chord\": \"G#/Ab\"}, {\"Index\": 1433, \"Highest Charting Position\": 66, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Yellow Hearts\", \"Streams\": 6554824, \"Artist\": \"Ant Saunders\", \"Artist Followers\": 82522.0, \"Song ID\": \"2W4yABdLc4Jnds67Poi5Nl\", \"Genre\": \"['chill r&b', 'pop']\", \"Release Date\": \"2019-06-18\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.866, \"Energy\": 0.438, \"Loudness\": -8.943, \"Speechiness\": 0.0719, \"Acousticness\": 0.177, \"Liveness\": 0.0743, \"Tempo\": 129.039, \"Duration (ms)\": 223258.0, \"Valence\": 0.695, \"Chord\": \"G\"}, {\"Index\": 1434, \"Highest Charting Position\": 120, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Birthday\", \"Streams\": 6207326, \"Artist\": \"Anne-Marie\", \"Artist Followers\": 8153871.0, \"Song ID\": \"5hff5RQeE84pznOt8WEWeO\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-02-07--2020-02-14\", \"Popularity\": 65.0, \"Danceability\": 0.609, \"Energy\": 0.785, \"Loudness\": -3.32, \"Speechiness\": 0.0891, \"Acousticness\": 0.0502, \"Liveness\": 0.171, \"Tempo\": 151.995, \"Duration (ms)\": 181467.0, \"Valence\": 0.756, \"Chord\": \"B\"}, {\"Index\": 1435, \"Highest Charting Position\": 16, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"HIGHEST IN THE ROOM (feat. ROSAL\\u00cdA & Lil Baby) - REMIX\", \"Streams\": 6107499, \"Artist\": \"Travis Scott\", \"Artist Followers\": 437907.0, \"Song ID\": \"7h0d2h0fUmzbs7zeFigJPn\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.559, \"Energy\": 0.491, \"Loudness\": -6.406, \"Speechiness\": 0.0346, \"Acousticness\": 0.0567, \"Liveness\": 0.0992, \"Tempo\": 153.131, \"Duration (ms)\": 244874.0, \"Valence\": 0.114, \"Chord\": \"D\"}, {\"Index\": 1436, \"Highest Charting Position\": 65, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Good as Hell (feat. Ariana Grande) - Remix\", \"Streams\": 6066001, \"Artist\": \"Lizzo\", \"Artist Followers\": 3991674.0, \"Song ID\": \"07Oz5StQ7GRoygNLaXs2pd\", \"Genre\": \"['dance pop', 'escape room', 'minnesota hip hop', 'pop', 'pop rap', 'post-teen pop', 'trap queen']\", \"Release Date\": \"2016\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.668, \"Energy\": 0.892, \"Loudness\": -3.001, \"Speechiness\": 0.0645, \"Acousticness\": 0.298, \"Liveness\": 0.735, \"Tempo\": 95.927, \"Duration (ms)\": 159011.0, \"Valence\": 0.478, \"Chord\": \"F\"}, {\"Index\": 1437, \"Highest Charting Position\": 70, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"I Do It (ft. Big Sean, Lil Baby)\", \"Streams\": 5561205, \"Artist\": \"Lil Wayne\", \"Artist Followers\": 10710088.0, \"Song ID\": \"1bRO28yzxgO3y3UmNR29TZ\", \"Genre\": \"['hip hop', 'new orleans rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 60.0, \"Danceability\": 0.804, \"Energy\": 0.528, \"Loudness\": -3.231, \"Speechiness\": 0.378, \"Acousticness\": 0.125, \"Liveness\": 0.41, \"Tempo\": 138.005, \"Duration (ms)\": 184440.0, \"Valence\": 0.321, \"Chord\": \"C#/Db\"}, {\"Index\": 1438, \"Highest Charting Position\": 45, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Get Me\", \"Streams\": 5236560, \"Artist\": \"Justin Bieber, Kehlani\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5VwwpU7KsLhgfbMEecedhJ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 61.0, \"Danceability\": 0.832, \"Energy\": 0.508, \"Loudness\": -6.913, \"Speechiness\": 0.149, \"Acousticness\": 0.0492, \"Liveness\": 0.107, \"Tempo\": 109.352, \"Duration (ms)\": 185427.0, \"Valence\": 0.75, \"Chord\": \"F#/Gb\"}, {\"Index\": 1439, \"Highest Charting Position\": 95, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Yo x Ti, Tu x Mi\", \"Streams\": 5202210, \"Artist\": \"ROSAL\\u00cdA, Ozuna\", \"Artist Followers\": 4769627.0, \"Song ID\": \"7BlBVFwvbWvcwNcUarQmjk\", \"Genre\": \"['r&b en espanol']\", \"Release Date\": \"2019-08-15\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.78, \"Energy\": 0.759, \"Loudness\": -3.292, \"Speechiness\": 0.225, \"Acousticness\": 0.462, \"Liveness\": 0.143, \"Tempo\": 91.952, \"Duration (ms)\": 201040.0, \"Valence\": 0.579, \"Chord\": \"C#/Db\"}, {\"Index\": 1440, \"Highest Charting Position\": 161, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"DJ No Pare (feat. Zion, Dalex, Lenny Tav\\u00e1rez) - Remix\", \"Streams\": 5148516, \"Artist\": \"Justin Quiles, Natti Natasha, Farruko\", \"Artist Followers\": 2897862.0, \"Song ID\": \"1ndyl3wJCFs872XZ3ztPk6\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.743, \"Energy\": 0.709, \"Loudness\": -3.922, \"Speechiness\": 0.0879, \"Acousticness\": 0.0451, \"Liveness\": 0.0809, \"Tempo\": 170.001, \"Duration (ms)\": 258600.0, \"Valence\": 0.831, \"Chord\": \"D#/Eb\"}, {\"Index\": 1441, \"Highest Charting Position\": 160, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"EARFQUAKE\", \"Streams\": 5079657, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6782693.0, \"Song ID\": \"5hVghJ4KaYES3BFUATCYn0\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 79.0, \"Danceability\": 0.554, \"Energy\": 0.498, \"Loudness\": -8.866, \"Speechiness\": 0.0685, \"Acousticness\": 0.23, \"Liveness\": 0.795, \"Tempo\": 79.635, \"Duration (ms)\": 190067.0, \"Valence\": 0.413, \"Chord\": \"A\"}, {\"Index\": 1442, \"Highest Charting Position\": 157, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Pa' Olvidarme De Ella\", \"Streams\": 5066711, \"Artist\": \"Piso 21, Christian Nodal\", \"Artist Followers\": 7226268.0, \"Song ID\": \"1cVlW9WQiGlFdWUXFdFZGh\", \"Genre\": \"['colombian pop', 'latin', 'latin pop', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.728, \"Energy\": 0.542, \"Loudness\": -5.195, \"Speechiness\": 0.0514, \"Acousticness\": 0.259, \"Liveness\": 0.136, \"Tempo\": 90.016, \"Duration (ms)\": 227234.0, \"Valence\": 0.637, \"Chord\": \"C\"}, {\"Index\": 1443, \"Highest Charting Position\": 89, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Loco Contigo (feat. J. Balvin & Tyga)\", \"Streams\": 5013732, \"Artist\": \"DJ Snake, J Balvin\", \"Artist Followers\": 7408249.0, \"Song ID\": \"6osaMSJh9NguagEDQcZaKx\", \"Genre\": \"['dance pop', 'edm', 'electronic trap', 'pop', 'pop dance']\", \"Release Date\": \"2019-07-25\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.694, \"Energy\": 0.758, \"Loudness\": -2.986, \"Speechiness\": 0.218, \"Acousticness\": 0.278, \"Liveness\": 0.102, \"Tempo\": 192.091, \"Duration (ms)\": 185195.0, \"Valence\": 0.371, \"Chord\": \"B\"}, {\"Index\": 1444, \"Highest Charting Position\": 54, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Psycho\", \"Streams\": 4991751, \"Artist\": \"Red Velvet\", \"Artist Followers\": 5688315.0, \"Song ID\": \"3CYH422oy1cZNoo0GTG1TK\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2019-12-23\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.664, \"Energy\": 0.666, \"Loudness\": -2.203, \"Speechiness\": 0.0446, \"Acousticness\": 0.193, \"Liveness\": 0.0854, \"Tempo\": 139.987, \"Duration (ms)\": 210560.0, \"Valence\": 0.405, \"Chord\": \"G#/Ab\"}, {\"Index\": 1445, \"Highest Charting Position\": 113, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Suge\", \"Streams\": 4986299, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"2gwkD6igEhQbDQegRCcdoB\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-03-01\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.876, \"Energy\": 0.662, \"Loudness\": -6.482, \"Speechiness\": 0.426, \"Acousticness\": 0.0608, \"Liveness\": 0.127, \"Tempo\": 75.445, \"Duration (ms)\": 163320.0, \"Valence\": 0.844, \"Chord\": \"D\"}, {\"Index\": 1446, \"Highest Charting Position\": 101, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Con Altura\", \"Streams\": 4961249, \"Artist\": \"ROSAL\\u00cdA, J Balvin, El Guincho\", \"Artist Followers\": 4769627.0, \"Song ID\": \"2qG5sZ7Si6sdK74qLxedYM\", \"Genre\": \"['r&b en espanol']\", \"Release Date\": \"2019-03-28\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.882, \"Energy\": 0.689, \"Loudness\": -4.027, \"Speechiness\": 0.124, \"Acousticness\": 0.39, \"Liveness\": 0.0501, \"Tempo\": 97.963, \"Duration (ms)\": 161627.0, \"Valence\": 0.746, \"Chord\": \"F#/Gb\"}, {\"Index\": 1447, \"Highest Charting Position\": 140, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Only Human\", \"Streams\": 4953866, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"0DiDStADDVh3SvAsoJAFMk\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-06-07\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.795, \"Energy\": 0.496, \"Loudness\": -5.883, \"Speechiness\": 0.0722, \"Acousticness\": 0.108, \"Liveness\": 0.0645, \"Tempo\": 94.01, \"Duration (ms)\": 183000.0, \"Valence\": 0.874, \"Chord\": \"C\"}, {\"Index\": 1448, \"Highest Charting Position\": 51, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Eleven\", \"Streams\": 4947780, \"Artist\": \"Khalid\", \"Artist Followers\": 14190858.0, \"Song ID\": \"18O00Y7yrkJ0pRXm1n21Og\", \"Genre\": \"['pop']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 68.0, \"Danceability\": 0.679, \"Energy\": 0.408, \"Loudness\": -9.754, \"Speechiness\": 0.0882, \"Acousticness\": 0.133, \"Liveness\": 0.23, \"Tempo\": 129.079, \"Duration (ms)\": 206080.0, \"Valence\": 0.151, \"Chord\": \"E\"}, {\"Index\": 1449, \"Highest Charting Position\": 135, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Talk (feat. Disclosure)\", \"Streams\": 4940984, \"Artist\": \"Khalid\", \"Artist Followers\": 14190858.0, \"Song ID\": \"6TqXcAFInzjp0bODyvrWEq\", \"Genre\": \"['pop']\", \"Release Date\": \"2019-04-05\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.9, \"Energy\": 0.4, \"Loudness\": -8.575, \"Speechiness\": 0.127, \"Acousticness\": 0.0516, \"Liveness\": 0.0599, \"Tempo\": 135.984, \"Duration (ms)\": 197573.0, \"Valence\": 0.346, \"Chord\": \"C\"}, {\"Index\": 1450, \"Highest Charting Position\": 117, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Hot (Remix) [feat. Gunna and Travis Scott]\", \"Streams\": 4905155, \"Artist\": \"Travis Scott, Young Thug\", \"Artist Followers\": 3337982.0, \"Song ID\": \"56AMYGJzxBO6p8v0wEe9de\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-11-01\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.845, \"Energy\": 0.631, \"Loudness\": -8.206, \"Speechiness\": 0.216, \"Acousticness\": 0.188, \"Liveness\": 0.0806, \"Tempo\": 111.983, \"Duration (ms)\": 279907.0, \"Valence\": 0.545, \"Chord\": \"G\"}, {\"Index\": 1451, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Weiss\", \"Streams\": 4872077, \"Artist\": \"Samra\", \"Artist Followers\": 1045091.0, \"Song ID\": \"38YP1STiBe3AZevFFJILf4\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-02-07--2020-02-14\", \"Popularity\": 56.0, \"Danceability\": 0.6, \"Energy\": 0.525, \"Loudness\": -6.585, \"Speechiness\": 0.423, \"Acousticness\": 0.393, \"Liveness\": 0.111, \"Tempo\": 96.989, \"Duration (ms)\": 162702.0, \"Valence\": 0.436, \"Chord\": \"D\"}, {\"Index\": 1452, \"Highest Charting Position\": 105, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Con Calma\", \"Streams\": 4861378, \"Artist\": \"Daddy Yankee, Snow\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3GIhMWNecxw8GyCFwviF6v\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 3.0, \"Danceability\": 0.737, \"Energy\": 0.86, \"Loudness\": -2.652, \"Speechiness\": 0.0594, \"Acousticness\": 0.11, \"Liveness\": 0.0574, \"Tempo\": 93.989, \"Duration (ms)\": 193227.0, \"Valence\": 0.656, \"Chord\": \"G#/Ab\"}, {\"Index\": 1453, \"Highest Charting Position\": 148, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"MIDDLE CHILD\", \"Streams\": 4836113, \"Artist\": \"J. Cole\", \"Artist Followers\": 14103694.0, \"Song ID\": \"2JvzF1RMd7lE3KmFlsyZD8\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2019-01-23\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.837, \"Energy\": 0.364, \"Loudness\": -11.713, \"Speechiness\": 0.276, \"Acousticness\": 0.149, \"Liveness\": 0.271, \"Tempo\": 123.984, \"Duration (ms)\": 213594.0, \"Valence\": 0.463, \"Chord\": \"G#/Ab\"}, {\"Index\": 1454, \"Highest Charting Position\": 136, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Otro Trago - Remix\", \"Streams\": 4803294, \"Artist\": \"Sech, Ozuna, Anuel AA, Darell, Nicky Jam\", \"Artist Followers\": 8766508.0, \"Song ID\": \"4bTZeO72FwMa6wKOiqoynL\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-07-26\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.725, \"Energy\": 0.79, \"Loudness\": -2.331, \"Speechiness\": 0.197, \"Acousticness\": 0.0711, \"Liveness\": 0.0602, \"Tempo\": 175.988, \"Duration (ms)\": 287773.0, \"Valence\": 0.763, \"Chord\": \"C\"}, {\"Index\": 1455, \"Highest Charting Position\": 113, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"FML\", \"Streams\": 6350496, \"Artist\": \"Arizona Zervas\", \"Artist Followers\": 621200.0, \"Song ID\": \"6lruHh1jF7ezgbLv72xYmf\", \"Genre\": \"['pop rap', 'rhode island rap']\", \"Release Date\": \"2018-06-03\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 74.0, \"Danceability\": 0.822, \"Energy\": 0.575, \"Loudness\": -5.95, \"Speechiness\": 0.0934, \"Acousticness\": 0.113, \"Liveness\": 0.106, \"Tempo\": 100.087, \"Duration (ms)\": 223000.0, \"Valence\": 0.616, \"Chord\": \"F\"}, {\"Index\": 1456, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"King Of My City\", \"Streams\": 5922748, \"Artist\": \"A Boogie Wit da Hoodie\", \"Artist Followers\": 1251372.0, \"Song ID\": \"4JEz0Iz8PnzHe5B0CkYSjP\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 0.0, \"Danceability\": 0.679, \"Energy\": 0.679, \"Loudness\": -6.747, \"Speechiness\": 0.167, \"Acousticness\": 0.443, \"Liveness\": 0.153, \"Tempo\": 119.921, \"Duration (ms)\": 148676.0, \"Valence\": 0.245, \"Chord\": \"E\"}, {\"Index\": 1457, \"Highest Charting Position\": 22, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Those Kinda Nights (feat. Ed Sheeran)\", \"Streams\": 5823422, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"0VSzREd1OjEWJ9tXoFHRQH\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 66.0, \"Danceability\": 0.794, \"Energy\": 0.637, \"Loudness\": -6.29, \"Speechiness\": 0.339, \"Acousticness\": 0.028, \"Liveness\": 0.0919, \"Tempo\": 103.868, \"Duration (ms)\": 177693.0, \"Valence\": 0.393, \"Chord\": \"E\"}, {\"Index\": 1458, \"Highest Charting Position\": 136, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Mon Ami\", \"Streams\": 5774770, \"Artist\": \"Samra\", \"Artist Followers\": 1045091.0, \"Song ID\": \"1R4xkZXQUQ8QJtAdwHkSgC\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-01-29\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 53.0, \"Danceability\": 0.801, \"Energy\": 0.731, \"Loudness\": -3.723, \"Speechiness\": 0.383, \"Acousticness\": 0.188, \"Liveness\": 0.111, \"Tempo\": 105.666, \"Duration (ms)\": 138409.0, \"Valence\": 0.537, \"Chord\": \"G#/Ab\"}, {\"Index\": 1459, \"Highest Charting Position\": 120, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Break My Stride\", \"Streams\": 5312936, \"Artist\": \"Matthew Wilder\", \"Artist Followers\": 30386.0, \"Song ID\": \"1mCsF9Tw4AkIZOjvZbZZdT\", \"Genre\": \"['new wave pop']\", \"Release Date\": \"1983-03-19\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 73.0, \"Danceability\": 0.917, \"Energy\": 0.588, \"Loudness\": -11.047, \"Speechiness\": 0.0607, \"Acousticness\": 0.195, \"Liveness\": 0.0914, \"Tempo\": 110.077, \"Duration (ms)\": 184480.0, \"Valence\": 0.828, \"Chord\": \"A#/Bb\"}, {\"Index\": 1460, \"Highest Charting Position\": 76, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Kein Wort\", \"Streams\": 5208651, \"Artist\": \"Juju, Loredana, Miksu / Macloud\", \"Artist Followers\": 486474.0, \"Song ID\": \"1hoLUVBx0ixX3kn0EX0P5n\", \"Genre\": \"['frauenrap', 'german hip hop', 'german pop']\", \"Release Date\": \"2020-01-16\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.746, \"Energy\": 0.592, \"Loudness\": -6.861, \"Speechiness\": 0.0914, \"Acousticness\": 0.462, \"Liveness\": 0.187, \"Tempo\": 160.065, \"Duration (ms)\": 162094.0, \"Valence\": 0.629, \"Chord\": \"F#/Gb\"}, {\"Index\": 1461, \"Highest Charting Position\": 86, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Graveyard\", \"Streams\": 5044853, \"Artist\": \"Halsey\", \"Artist Followers\": 15663384.0, \"Song ID\": \"2ufmtcIFdFpuUYBPXK5f67\", \"Genre\": \"['dance pop', 'electropop', 'etherpop', 'indie poptimism', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.667, \"Energy\": 0.583, \"Loudness\": -5.127, \"Speechiness\": 0.0747, \"Acousticness\": 0.231, \"Liveness\": 0.181, \"Tempo\": 92.043, \"Duration (ms)\": 181806.0, \"Valence\": 0.187, \"Chord\": \"B\"}, {\"Index\": 1462, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Wake Up Call (feat. Trippie Redd)\", \"Streams\": 5029979, \"Artist\": \"KSI\", \"Artist Followers\": 2010879.0, \"Song ID\": \"5MYzajZVxBaPT2JUSRa99L\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2020-01-27\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 56.0, \"Danceability\": 0.642, \"Energy\": 0.669, \"Loudness\": -5.774, \"Speechiness\": 0.0486, \"Acousticness\": 0.318, \"Liveness\": 0.119, \"Tempo\": 156.084, \"Duration (ms)\": 175067.0, \"Valence\": 0.227, \"Chord\": \"F#/Gb\"}, {\"Index\": 1463, \"Highest Charting Position\": 131, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Turn Me On (feat. Vula)\", \"Streams\": 4925843, \"Artist\": \"Riton, Oliver Heldens\", \"Artist Followers\": 83743.0, \"Song ID\": \"0qaWEvPkts34WF68r8Dzx9\", \"Genre\": \"['dance pop', 'house', 'pop dance', 'tropical house', 'uk dance']\", \"Release Date\": \"2019-09-13\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.737, \"Energy\": 0.828, \"Loudness\": -4.711, \"Speechiness\": 0.0396, \"Acousticness\": 0.0149, \"Liveness\": 0.0862, \"Tempo\": 124.051, \"Duration (ms)\": 208474.0, \"Valence\": 0.517, \"Chord\": \"B\"}, {\"Index\": 1464, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Hips Don't Lie (feat. Wyclef Jean)\", \"Streams\": 4918636, \"Artist\": \"Shakira\", \"Artist Followers\": 22136717.0, \"Song ID\": \"3ZFTkvIE7kyPt6Nu3PEa7V\", \"Genre\": \"['colombian pop', 'dance pop', 'latin', 'latin pop', 'pop']\", \"Release Date\": \"2005-11-28\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 83.0, \"Danceability\": 0.778, \"Energy\": 0.824, \"Loudness\": -5.892, \"Speechiness\": 0.0707, \"Acousticness\": 0.284, \"Liveness\": 0.405, \"Tempo\": 100.024, \"Duration (ms)\": 218093.0, \"Valence\": 0.758, \"Chord\": \"A#/Bb\"}, {\"Index\": 1465, \"Highest Charting Position\": 106, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Liar\", \"Streams\": 4896939, \"Artist\": \"Camila Cabello\", \"Artist Followers\": 22698747.0, \"Song ID\": \"7LzouaWGFCy4tkXDOOnEyM\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-09-04\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 69.0, \"Danceability\": 0.74, \"Energy\": 0.498, \"Loudness\": -6.684, \"Speechiness\": 0.0456, \"Acousticness\": 0.0169, \"Liveness\": 0.319, \"Tempo\": 98.016, \"Duration (ms)\": 207039.0, \"Valence\": 0.652, \"Chord\": \"B\"}, {\"Index\": 1466, \"Highest Charting Position\": 191, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Going Bad (feat. Drake)\", \"Streams\": 4889500, \"Artist\": \"Meek Mill\", \"Artist Followers\": 5241145.0, \"Song ID\": \"2IRZnDFmlqMuOrYOLnZZyc\", \"Genre\": \"['hip hop', 'philly rap', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2018-11-30\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.889, \"Energy\": 0.496, \"Loudness\": -6.365, \"Speechiness\": 0.0905, \"Acousticness\": 0.259, \"Liveness\": 0.252, \"Tempo\": 86.003, \"Duration (ms)\": 180522.0, \"Valence\": 0.544, \"Chord\": \"E\"}, {\"Index\": 1467, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"ME! (feat. Brendon Urie of Panic! At The Disco)\", \"Streams\": 4884909, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2Rk4JlNc2TPmZe2af99d45\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 77.0, \"Danceability\": 0.61, \"Energy\": 0.83, \"Loudness\": -4.105, \"Speechiness\": 0.0571, \"Acousticness\": 0.033, \"Liveness\": 0.118, \"Tempo\": 182.162, \"Duration (ms)\": 193000.0, \"Valence\": 0.728, \"Chord\": \"C\"}, {\"Index\": 1468, \"Highest Charting Position\": 134, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Panini\", \"Streams\": 4867723, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5488666.0, \"Song ID\": \"1000nHvUdawXuUHgBod4Wv\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2019-09-13\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.703, \"Energy\": 0.594, \"Loudness\": -6.146, \"Speechiness\": 0.0752, \"Acousticness\": 0.342, \"Liveness\": 0.123, \"Tempo\": 153.848, \"Duration (ms)\": 114893.0, \"Valence\": 0.475, \"Chord\": \"F\"}, {\"Index\": 1469, \"Highest Charting Position\": 191, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"idontwannabeyouanymore\", \"Streams\": 4824483, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"41zXlQxzTi6cGAjpOXyLYH\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2017-12-22\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 78.0, \"Danceability\": 0.483, \"Energy\": 0.412, \"Loudness\": -8.461, \"Speechiness\": 0.0402, \"Acousticness\": 0.737, \"Liveness\": 0.116, \"Tempo\": 170.163, \"Duration (ms)\": 203569.0, \"Valence\": 0.247, \"Chord\": \"G\"}, {\"Index\": 1470, \"Highest Charting Position\": 158, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"The London (feat. J. Cole & Travis Scott)\", \"Streams\": 4791732, \"Artist\": \"J. Cole, Young Thug\", \"Artist Followers\": 6383275.0, \"Song ID\": \"7DcvwMAiqKJQD1rrdfxSDx\", \"Genre\": \"['atl hip hop', 'atl trap', 'gangster rap', 'hip hop', 'melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2019-05-23\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.796, \"Energy\": 0.586, \"Loudness\": -6.946, \"Speechiness\": 0.147, \"Acousticness\": 0.0247, \"Liveness\": 0.132, \"Tempo\": 97.981, \"Duration (ms)\": 200107.0, \"Valence\": 0.179, \"Chord\": \"E\"}, {\"Index\": 1471, \"Highest Charting Position\": 123, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"223's (feat. 9lokknine)\", \"Streams\": 4781697, \"Artist\": \"YNW Melly\", \"Artist Followers\": 6332535.0, \"Song ID\": \"4sjiIpEv617LDXaidKioOI\", \"Genre\": \"['melodic rap', 'trap']\", \"Release Date\": \"2019-08-09\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.932, \"Energy\": 0.547, \"Loudness\": -7.787, \"Speechiness\": 0.333, \"Acousticness\": 0.0388, \"Liveness\": 0.0924, \"Tempo\": 94.998, \"Duration (ms)\": 176640.0, \"Valence\": 0.695, \"Chord\": \"C\"}, {\"Index\": 1472, \"Highest Charting Position\": 26, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Darkness\", \"Streams\": 7618955, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5SiZJoLXp3WOl3J4C8IK0d\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 65.0, \"Danceability\": 0.671, \"Energy\": 0.623, \"Loudness\": -7.161, \"Speechiness\": 0.308, \"Acousticness\": 0.00998, \"Liveness\": 0.643, \"Tempo\": 75.055, \"Duration (ms)\": 337147.0, \"Valence\": 0.195, \"Chord\": \"D\"}, {\"Index\": 1473, \"Highest Charting Position\": 30, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"You Gon\\u2019 Learn (feat. Royce Da 5'9\\\" & White Gold)\", \"Streams\": 7157402, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"0GQ5bFTVFFKpwNPc7KwQnB\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 66.0, \"Danceability\": 0.68, \"Energy\": 0.82, \"Loudness\": -4.197, \"Speechiness\": 0.151, \"Acousticness\": 0.0614, \"Liveness\": 0.597, \"Tempo\": 140.033, \"Duration (ms)\": 234653.0, \"Valence\": 0.243, \"Chord\": \"E\"}, {\"Index\": 1474, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Blue World\", \"Streams\": 7060589, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"2hwOoMtWPtTSSn6WHV7Vp5\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 75.0, \"Danceability\": 0.742, \"Energy\": 0.553, \"Loudness\": -8.98, \"Speechiness\": 0.419, \"Acousticness\": 0.389, \"Liveness\": 0.0694, \"Tempo\": 84.931, \"Duration (ms)\": 209440.0, \"Valence\": 0.508, \"Chord\": \"G#/Ab\"}, {\"Index\": 1475, \"Highest Charting Position\": 99, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Liberdade Provis\\u00f3ria\", \"Streams\": 6442626, \"Artist\": \"Henrique & Juliano\", \"Artist Followers\": 13312073.0, \"Song ID\": \"1vG3YuKRYqPwTmNmYgqkpg\", \"Genre\": \"['sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.668, \"Energy\": 0.684, \"Loudness\": -5.937, \"Speechiness\": 0.0527, \"Acousticness\": 0.627, \"Liveness\": 0.923, \"Tempo\": 108.138, \"Duration (ms)\": 187986.0, \"Valence\": 0.7, \"Chord\": \"C#/Db\"}, {\"Index\": 1476, \"Highest Charting Position\": 32, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Unaccommodating (feat. Young M.A)\", \"Streams\": 6374807, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"0q2vG0UVuy6ajjcpkQHdZM\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 65.0, \"Danceability\": 0.852, \"Energy\": 0.752, \"Loudness\": -5.793, \"Speechiness\": 0.0597, \"Acousticness\": 0.0169, \"Liveness\": 0.394, \"Tempo\": 89.95, \"Duration (ms)\": 216600.0, \"Valence\": 0.389, \"Chord\": \"C#/Db\"}, {\"Index\": 1477, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Donuts\", \"Streams\": 6113037, \"Artist\": \"Gzuz\", \"Artist Followers\": 1140383.0, \"Song ID\": \"5XVPNr0CAoUn1jD033Ucoo\", \"Genre\": \"['deep german hip hop', 'german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-02-13\", \"Weeks Charted\": \"2020-01-24--2020-01-31\", \"Popularity\": 62.0, \"Danceability\": 0.784, \"Energy\": 0.703, \"Loudness\": -7.491, \"Speechiness\": 0.236, \"Acousticness\": 0.0973, \"Liveness\": 0.0754, \"Tempo\": 141.035, \"Duration (ms)\": 162938.0, \"Valence\": 0.556, \"Chord\": \"B\"}, {\"Index\": 1478, \"Highest Charting Position\": 44, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Leaving Heaven (feat. Skylar Grey)\", \"Streams\": 5466161, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5CpsIb7SMFHjmAG8RvIWfq\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.661, \"Energy\": 0.748, \"Loudness\": -4.809, \"Speechiness\": 0.206, \"Acousticness\": 0.175, \"Liveness\": 0.254, \"Tempo\": 171.983, \"Duration (ms)\": 265947.0, \"Valence\": 0.509, \"Chord\": \"D\"}, {\"Index\": 1479, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Zu Ende\", \"Streams\": 5297101, \"Artist\": \"Samra, ELIF\", \"Artist Followers\": 1045091.0, \"Song ID\": \"0Vl4eICpXMjtiK0RhdaWov\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-01-23\", \"Weeks Charted\": \"2020-01-24--2020-01-31\", \"Popularity\": 57.0, \"Danceability\": 0.707, \"Energy\": 0.747, \"Loudness\": -5.212, \"Speechiness\": 0.279, \"Acousticness\": 0.307, \"Liveness\": 0.183, \"Tempo\": 80.025, \"Duration (ms)\": 197861.0, \"Valence\": 0.491, \"Chord\": \"G#/Ab\"}, {\"Index\": 1480, \"Highest Charting Position\": 171, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"B.I.T.C.H.\", \"Streams\": 5215211, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"06scTb0zbkxYNgpAB3J9fN\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-01-24\", \"Weeks Charted\": \"2020-01-24--2020-01-31\", \"Popularity\": 59.0, \"Danceability\": 0.742, \"Energy\": 0.731, \"Loudness\": -4.362, \"Speechiness\": 0.306, \"Acousticness\": 0.0851, \"Liveness\": 0.131, \"Tempo\": 174.019, \"Duration (ms)\": 183143.0, \"Valence\": 0.547, \"Chord\": \"B\"}, {\"Index\": 1481, \"Highest Charting Position\": 56, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Look At Her Now\", \"Streams\": 5066377, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 1251372.0, \"Song ID\": \"2XUPkAie1nz9SYIhbdIVWb\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.753, \"Energy\": 0.564, \"Loudness\": -7.908, \"Speechiness\": 0.251, \"Acousticness\": 0.114, \"Liveness\": 0.359, \"Tempo\": 77.341, \"Duration (ms)\": 162596.0, \"Valence\": 0.55, \"Chord\": \"A#/Bb\"}, {\"Index\": 1482, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Bi Sonraki Hayat\\u0131mda Gel\", \"Streams\": 5037967, \"Artist\": \"Murda, Ezhel\", \"Artist Followers\": 862965.0, \"Song ID\": \"5SYkeNpjhJPFUMOP5TK8iw\", \"Genre\": \"['basshall', 'turkish trap']\", \"Release Date\": \"2020-08-28\", \"Weeks Charted\": \"2020-01-24--2020-01-31\", \"Popularity\": 57.0, \"Danceability\": 0.933, \"Energy\": 0.448, \"Loudness\": -4.491, \"Speechiness\": 0.136, \"Acousticness\": 0.0253, \"Liveness\": 0.104, \"Tempo\": 103.981, \"Duration (ms)\": 167350.0, \"Valence\": 0.737, \"Chord\": \"G#/Ab\"}, {\"Index\": 1483, \"Highest Charting Position\": 126, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Legends\", \"Streams\": 4922369, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"1Knctxx9vGZxpZfF66BIEa\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2018-06-22\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.594, \"Energy\": 0.798, \"Loudness\": -5.244, \"Speechiness\": 0.0844, \"Acousticness\": 0.115, \"Liveness\": 0.143, \"Tempo\": 142.049, \"Duration (ms)\": 191840.0, \"Valence\": 0.381, \"Chord\": \"E\"}, {\"Index\": 1484, \"Highest Charting Position\": 157, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"11 PM\", \"Streams\": 4891989, \"Artist\": \"Maluma\", \"Artist Followers\": 26784251.0, \"Song ID\": \"7KbF6AdprOXEEHlsq11Z6d\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.777, \"Energy\": 0.712, \"Loudness\": -4.84, \"Speechiness\": 0.277, \"Acousticness\": 0.217, \"Liveness\": 0.091, \"Tempo\": 95.692, \"Duration (ms)\": 175733.0, \"Valence\": 0.68, \"Chord\": \"A#/Bb\"}, {\"Index\": 1485, \"Highest Charting Position\": 182, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Post Malone (feat. RANI)\", \"Streams\": 4855270, \"Artist\": \"Sam Feldt\", \"Artist Followers\": 639516.0, \"Song ID\": \"0qc4QlcCxVTGyShurEv1UU\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'pop', 'pop dance', 'pop edm', 'tropical house']\", \"Release Date\": \"2019-05-24\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.59, \"Energy\": 0.642, \"Loudness\": -3.87, \"Speechiness\": 0.122, \"Acousticness\": 0.0771, \"Liveness\": 0.105, \"Tempo\": 107.356, \"Duration (ms)\": 174444.0, \"Valence\": 0.651, \"Chord\": \"G\"}, {\"Index\": 1486, \"Highest Charting Position\": 52, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"In Too Deep\", \"Streams\": 4824037, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"7Dj2wqPYXfSRFwa6qyOztr\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.72, \"Energy\": 0.767, \"Loudness\": -5.839, \"Speechiness\": 0.214, \"Acousticness\": 0.0387, \"Liveness\": 0.202, \"Tempo\": 88.966, \"Duration (ms)\": 194707.0, \"Valence\": 0.595, \"Chord\": \"A#/Bb\"}, {\"Index\": 1487, \"Highest Charting Position\": 57, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Premonition - Intro\", \"Streams\": 10830400, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"7ccTcabbJlCJiIqtrSSwBk\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.847, \"Energy\": 0.637, \"Loudness\": -5.193, \"Speechiness\": 0.367, \"Acousticness\": 0.0258, \"Liveness\": 0.382, \"Tempo\": 165.979, \"Duration (ms)\": 173893.0, \"Valence\": 0.511, \"Chord\": \"C#/Db\"}, {\"Index\": 1488, \"Highest Charting Position\": 62, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"I Can See\", \"Streams\": 10086930, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"3R8CyhJfVjvgIROd5RSGhQ\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.699, \"Energy\": 0.503, \"Loudness\": -9.922, \"Speechiness\": 0.0882, \"Acousticness\": 0.391, \"Liveness\": 0.0996, \"Tempo\": 114.86, \"Duration (ms)\": 220853.0, \"Valence\": 0.0546, \"Chord\": \"F\"}, {\"Index\": 1489, \"Highest Charting Position\": 69, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Hand Me Downs\", \"Streams\": 9521654, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"2Yv2mHzr5AQavVdwQjEokV\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.677, \"Energy\": 0.33, \"Loudness\": -11.198, \"Speechiness\": 0.149, \"Acousticness\": 0.474, \"Liveness\": 0.064, \"Tempo\": 68.985, \"Duration (ms)\": 298440.0, \"Valence\": 0.336, \"Chord\": \"D\"}, {\"Index\": 1490, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"No Regrets (feat. Don Toliver)\", \"Streams\": 9493884, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"1lO9CZo6eDrOy0S7khgryG\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 63.0, \"Danceability\": 0.756, \"Energy\": 0.747, \"Loudness\": -5.407, \"Speechiness\": 0.046, \"Acousticness\": 0.0048, \"Liveness\": 0.588, \"Tempo\": 134.935, \"Duration (ms)\": 200947.0, \"Valence\": 0.0687, \"Chord\": \"A\"}, {\"Index\": 1491, \"Highest Charting Position\": 71, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Complicated\", \"Streams\": 9443725, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"3WfSNAoj2D8C9noPSGZZFM\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.831, \"Energy\": 0.36, \"Loudness\": -8.073, \"Speechiness\": 0.052, \"Acousticness\": 0.136, \"Liveness\": 0.0703, \"Tempo\": 75.014, \"Duration (ms)\": 232212.0, \"Valence\": 0.601, \"Chord\": \"C\"}, {\"Index\": 1492, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Lock It Up (feat. Anderson .Paak)\", \"Streams\": 9328951, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"1qwMkkRiD5jqLeUUjfgblh\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.848, \"Energy\": 0.745, \"Loudness\": -3.052, \"Speechiness\": 0.221, \"Acousticness\": 0.0949, \"Liveness\": 0.0796, \"Tempo\": 137.024, \"Duration (ms)\": 170227.0, \"Valence\": 0.516, \"Chord\": \"F#/Gb\"}, {\"Index\": 1493, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Marsh\", \"Streams\": 9260007, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"34d7sGX6WUqq8f04e7CSNF\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.871, \"Energy\": 0.493, \"Loudness\": -6.356, \"Speechiness\": 0.205, \"Acousticness\": 0.0134, \"Liveness\": 0.385, \"Tempo\": 144.989, \"Duration (ms)\": 200573.0, \"Valence\": 0.0495, \"Chord\": \"C#/Db\"}, {\"Index\": 1494, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Stepdad\", \"Streams\": 9159901, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"3QVHSV8YKYq4L8tI5rnFgj\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 61.0, \"Danceability\": 0.779, \"Energy\": 0.805, \"Loudness\": -3.121, \"Speechiness\": 0.178, \"Acousticness\": 0.018, \"Liveness\": 0.321, \"Tempo\": 145.68, \"Duration (ms)\": 213413.0, \"Valence\": 0.557, \"Chord\": \"C#/Db\"}, {\"Index\": 1495, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Yah Yah (feat. Royce Da 5'9\\\", Black Thought, Q-Tip & Denaun)\", \"Streams\": 8695060, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5mZXWEH2eh8zMZGCxT5aW0\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.458, \"Energy\": 0.966, \"Loudness\": -2.107, \"Speechiness\": 0.384, \"Acousticness\": 0.14, \"Liveness\": 0.11, \"Tempo\": 183.586, \"Duration (ms)\": 286960.0, \"Valence\": 0.356, \"Chord\": \"C#/Db\"}, {\"Index\": 1496, \"Highest Charting Position\": 90, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Never Love Again\", \"Streams\": 8335790, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"40YbWniIEmqy6s58fYXLUh\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.747, \"Energy\": 0.899, \"Loudness\": -5.125, \"Speechiness\": 0.246, \"Acousticness\": 0.1, \"Liveness\": 0.486, \"Tempo\": 92.029, \"Duration (ms)\": 177547.0, \"Valence\": 0.581, \"Chord\": \"F\"}, {\"Index\": 1497, \"Highest Charting Position\": 91, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Woods\", \"Streams\": 8329349, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"3Qa944OTMZkg8DHjET8JQv\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.779, \"Energy\": 0.362, \"Loudness\": -10.847, \"Speechiness\": 0.0474, \"Acousticness\": 0.135, \"Liveness\": 0.111, \"Tempo\": 85.011, \"Duration (ms)\": 286387.0, \"Valence\": 0.46, \"Chord\": \"C\"}, {\"Index\": 1498, \"Highest Charting Position\": 94, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Farewell\", \"Streams\": 8277608, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"74gykWHknHDrg4eMdcmdRq\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 61.0, \"Danceability\": 0.89, \"Energy\": 0.664, \"Loudness\": -6.625, \"Speechiness\": 0.106, \"Acousticness\": 0.00487, \"Liveness\": 0.257, \"Tempo\": 93.007, \"Duration (ms)\": 247733.0, \"Valence\": 0.467, \"Chord\": \"E\"}, {\"Index\": 1499, \"Highest Charting Position\": 98, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Everybody\", \"Streams\": 8172098, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"1OuN92HcVG6NVpWbeESNB3\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.875, \"Energy\": 0.599, \"Loudness\": -9.077, \"Speechiness\": 0.138, \"Acousticness\": 0.0333, \"Liveness\": 0.113, \"Tempo\": 152.061, \"Duration (ms)\": 256507.0, \"Valence\": 0.112, \"Chord\": \"A\"}, {\"Index\": 1500, \"Highest Charting Position\": 100, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Alfred - Interlude\", \"Streams\": 8030151, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"4EmunTy7kNBYQivOa8F6b8\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 57.0, \"Danceability\": 0.429, \"Energy\": 0.231, \"Loudness\": -20.43, \"Speechiness\": 0.402, \"Acousticness\": 0.878, \"Liveness\": 0.279, \"Tempo\": 74.545, \"Duration (ms)\": 30133.0, \"Valence\": 0.914, \"Chord\": \"F\"}, {\"Index\": 1501, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Little Engine\", \"Streams\": 7913461, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"4qNWEOMyexn7b8Icyk29t9\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.769, \"Energy\": 0.811, \"Loudness\": -4.162, \"Speechiness\": 0.228, \"Acousticness\": 0.0234, \"Liveness\": 0.0451, \"Tempo\": 155.081, \"Duration (ms)\": 177293.0, \"Valence\": 0.76, \"Chord\": \"A#/Bb\"}, {\"Index\": 1502, \"Highest Charting Position\": 113, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"I Will (feat. KXNG Crooked, Royce Da 5'9\\\" & Joell Ortiz)\", \"Streams\": 7115414, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"3CJbxqRQ0JNCqboWDNUUeX\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.635, \"Energy\": 0.543, \"Loudness\": -5.941, \"Speechiness\": 0.067, \"Acousticness\": 0.0454, \"Liveness\": 0.272, \"Tempo\": 98.743, \"Duration (ms)\": 303000.0, \"Valence\": 0.036, \"Chord\": \"G#/Ab\"}, {\"Index\": 1503, \"Highest Charting Position\": 115, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Still Learning\", \"Streams\": 7050815, \"Artist\": \"Halsey\", \"Artist Followers\": 15663384.0, \"Song ID\": \"2Mfv5HaqnI18Q9JRv9hqnn\", \"Genre\": \"['dance pop', 'electropop', 'etherpop', 'indie poptimism', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 59.0, \"Danceability\": 0.708, \"Energy\": 0.661, \"Loudness\": -6.543, \"Speechiness\": 0.0546, \"Acousticness\": 0.0396, \"Liveness\": 0.113, \"Tempo\": 102.046, \"Duration (ms)\": 211784.0, \"Valence\": 0.317, \"Chord\": \"C\"}, {\"Index\": 1504, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Surf\", \"Streams\": 6960699, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"1kwnxJNVl7cwcU98RvMBaR\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 67.0, \"Danceability\": 0.828, \"Energy\": 0.182, \"Loudness\": -13.066, \"Speechiness\": 0.166, \"Acousticness\": 0.754, \"Liveness\": 0.15, \"Tempo\": 147.279, \"Duration (ms)\": 330507.0, \"Valence\": 0.231, \"Chord\": \"C#/Db\"}, {\"Index\": 1505, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"That's On Me\", \"Streams\": 6462701, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"0udOCZp7yk0Ml92C0k8H8D\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.583, \"Energy\": 0.499, \"Loudness\": -10.086, \"Speechiness\": 0.0261, \"Acousticness\": 0.591, \"Liveness\": 0.33, \"Tempo\": 155.199, \"Duration (ms)\": 217868.0, \"Valence\": 0.342, \"Chord\": \"A#/Bb\"}, {\"Index\": 1506, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Once A Day\", \"Streams\": 6159873, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"26G5nmIx7Yvq79bIIluyZV\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 61.0, \"Danceability\": 0.762, \"Energy\": 0.054, \"Loudness\": -16.735, \"Speechiness\": 0.0503, \"Acousticness\": 0.947, \"Liveness\": 0.124, \"Tempo\": 96.838, \"Duration (ms)\": 160267.0, \"Valence\": 0.339, \"Chord\": \"D\"}, {\"Index\": 1507, \"Highest Charting Position\": 155, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Big Drip\", \"Streams\": 6010373, \"Artist\": \"Ufo361, Future\", \"Artist Followers\": 1700759.0, \"Song ID\": \"7HZoWhGQaKg97OsqG7HLOS\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 48.0, \"Danceability\": 0.791, \"Energy\": 0.535, \"Loudness\": -6.753, \"Speechiness\": 0.311, \"Acousticness\": 0.0448, \"Liveness\": 0.129, \"Tempo\": 158.922, \"Duration (ms)\": 173785.0, \"Valence\": 0.443, \"Chord\": \"C\"}, {\"Index\": 1508, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Hands\", \"Streams\": 5934464, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"6CrnvqCxBKVWahSiQwOesM\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 58.0, \"Danceability\": 0.739, \"Energy\": 0.627, \"Loudness\": -8.608, \"Speechiness\": 0.171, \"Acousticness\": 0.0459, \"Liveness\": 0.159, \"Tempo\": 74.962, \"Duration (ms)\": 199981.0, \"Valence\": 0.542, \"Chord\": \"C\"}, {\"Index\": 1509, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Dans l'espace (feat. Heuss l'Enfoir\\u00e9)\", \"Streams\": 5678754, \"Artist\": \"Gambi\", \"Artist Followers\": 951798.0, \"Song ID\": \"2KAkkba3PaYFegfmYpUITv\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 59.0, \"Danceability\": 0.916, \"Energy\": 0.57, \"Loudness\": -6.278, \"Speechiness\": 0.18, \"Acousticness\": 0.0286, \"Liveness\": 0.0851, \"Tempo\": 110.05, \"Duration (ms)\": 169702.0, \"Valence\": 0.7, \"Chord\": \"C#/Db\"}, {\"Index\": 1510, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Blanche\", \"Streams\": 5656775, \"Artist\": \"Maes, Booba\", \"Artist Followers\": 1603670.0, \"Song ID\": \"5GyyPRvEwdI4wJSUbzxHQv\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2020-01-16\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 65.0, \"Danceability\": 0.776, \"Energy\": 0.713, \"Loudness\": -6.121, \"Speechiness\": 0.143, \"Acousticness\": 0.525, \"Liveness\": 0.306, \"Tempo\": 127.987, \"Duration (ms)\": 193453.0, \"Valence\": 0.551, \"Chord\": \"E\"}, {\"Index\": 1511, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Vulnerable\", \"Streams\": 7531094, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"11OwAR3GlBj9E35Cznf7Lj\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 55.0, \"Danceability\": 0.695, \"Energy\": 0.573, \"Loudness\": -8.882, \"Speechiness\": 0.167, \"Acousticness\": 0.132, \"Liveness\": 0.156, \"Tempo\": 100.031, \"Duration (ms)\": 192172.0, \"Valence\": 0.38, \"Chord\": \"A#/Bb\"}, {\"Index\": 1512, \"Highest Charting Position\": 90, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Dance Again\", \"Streams\": 7394604, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"5sK3o66yupTNIK6gWgzGjf\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 56.0, \"Danceability\": 0.784, \"Energy\": 0.552, \"Loudness\": -7.261, \"Speechiness\": 0.0871, \"Acousticness\": 0.0447, \"Liveness\": 0.192, \"Tempo\": 111.984, \"Duration (ms)\": 170498.0, \"Valence\": 0.465, \"Chord\": \"C#/Db\"}, {\"Index\": 1513, \"Highest Charting Position\": 107, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Ring\", \"Streams\": 6693229, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"11Ey4yJVeWEsA73KjACkVY\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 55.0, \"Danceability\": 0.873, \"Energy\": 0.51, \"Loudness\": -5.35, \"Speechiness\": 0.0661, \"Acousticness\": 0.565, \"Liveness\": 0.0738, \"Tempo\": 110.953, \"Duration (ms)\": 148776.0, \"Valence\": 0.871, \"Chord\": \"D#/Eb\"}, {\"Index\": 1514, \"Highest Charting Position\": 111, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Crowded Room (feat. 6LACK)\", \"Streams\": 6483001, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"2C0hTkdEoikhKzDCJl32QZ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 55.0, \"Danceability\": 0.724, \"Energy\": 0.415, \"Loudness\": -8.408, \"Speechiness\": 0.0518, \"Acousticness\": 0.764, \"Liveness\": 0.103, \"Tempo\": 89.999, \"Duration (ms)\": 186459.0, \"Valence\": 0.328, \"Chord\": \"G\"}, {\"Index\": 1515, \"Highest Charting Position\": 119, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"People You Know\", \"Streams\": 6255954, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"63mdJr3NMY3wReOkNE6c6W\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 54.0, \"Danceability\": 0.695, \"Energy\": 0.62, \"Loudness\": -8.082, \"Speechiness\": 0.0521, \"Acousticness\": 0.0881, \"Liveness\": 0.111, \"Tempo\": 150.032, \"Duration (ms)\": 194900.0, \"Valence\": 0.62, \"Chord\": \"G#/Ab\"}, {\"Index\": 1516, \"Highest Charting Position\": 83, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Up All Night\", \"Streams\": 5834918, \"Artist\": \"Khalid\", \"Artist Followers\": 14190858.0, \"Song ID\": \"1mpD5Q8IM32I4bF6eCpU74\", \"Genre\": \"['pop']\", \"Release Date\": \"2019-11-14\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 69.0, \"Danceability\": 0.665, \"Energy\": 0.712, \"Loudness\": -7.536, \"Speechiness\": 0.0527, \"Acousticness\": 0.00103, \"Liveness\": 0.102, \"Tempo\": 93.992, \"Duration (ms)\": 157220.0, \"Valence\": 0.669, \"Chord\": \"C#/Db\"}, {\"Index\": 1517, \"Highest Charting Position\": 111, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Nice To Meet Ya\", \"Streams\": 5730427, \"Artist\": \"Niall Horan\", \"Artist Followers\": 7564659.0, \"Song ID\": \"3cphb8kdsjElYR7r5icK3H\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.591, \"Energy\": 0.841, \"Loudness\": -4.351, \"Speechiness\": 0.0304, \"Acousticness\": 0.0119, \"Liveness\": 0.395, \"Tempo\": 109.034, \"Duration (ms)\": 158805.0, \"Valence\": 0.392, \"Chord\": \"E\"}, {\"Index\": 1518, \"Highest Charting Position\": 102, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Into the Unknown\", \"Streams\": 5705999, \"Artist\": \"Idina Menzel, AURORA\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3Z0oQ8r78OUaHvGPiDBR3W\", \"Genre\": \"[]\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.323, \"Energy\": 0.405, \"Loudness\": -8.533, \"Speechiness\": 0.0413, \"Acousticness\": 0.849, \"Liveness\": 0.138, \"Tempo\": 145.104, \"Duration (ms)\": 194848.0, \"Valence\": 0.274, \"Chord\": \"A#/Bb\"}, {\"Index\": 1519, \"Highest Charting Position\": 161, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Let Me Get Me\", \"Streams\": 5356671, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"0uFForNKQPvgSCnxlZIhQy\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 51.0, \"Danceability\": 0.826, \"Energy\": 0.571, \"Loudness\": -9.263, \"Speechiness\": 0.0426, \"Acousticness\": 0.249, \"Liveness\": 0.215, \"Tempo\": 121.06, \"Duration (ms)\": 189145.0, \"Valence\": 0.475, \"Chord\": \"D\"}, {\"Index\": 1520, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"A Sweeter Place (feat. Kid Cudi)\", \"Streams\": 5291134, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4bb94wZVF1cX66vQjNeJTX\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 52.0, \"Danceability\": 0.583, \"Energy\": 0.777, \"Loudness\": -6.991, \"Speechiness\": 0.185, \"Acousticness\": 0.109, \"Liveness\": 0.108, \"Tempo\": 190.054, \"Duration (ms)\": 263306.0, \"Valence\": 0.31, \"Chord\": \"A#/Bb\"}, {\"Index\": 1521, \"Highest Charting Position\": 131, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Stuck In A Dream (feat. Gunna)\", \"Streams\": 5258047, \"Artist\": \"Lil Mosey\", \"Artist Followers\": 3818503.0, \"Song ID\": \"7iHHxY2NLlJRAmlAmC4ahQ\", \"Genre\": \"['melodic rap', 'rap', 'rap conscient', 'trap', 'vapor trap']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.748, \"Energy\": 0.648, \"Loudness\": -6.445, \"Speechiness\": 0.0816, \"Acousticness\": 0.484, \"Liveness\": 0.126, \"Tempo\": 139.952, \"Duration (ms)\": 123560.0, \"Valence\": 0.726, \"Chord\": \"A#/Bb\"}, {\"Index\": 1522, \"Highest Charting Position\": 138, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Take What You Want (feat. Ozzy Osbourne & Travis Scott)\", \"Streams\": 5199618, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"7CZyCXKG6d5ALeq41sLzbw\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.499, \"Energy\": 0.8, \"Loudness\": -2.665, \"Speechiness\": 0.0502, \"Acousticness\": 0.0906, \"Liveness\": 0.147, \"Tempo\": 139.919, \"Duration (ms)\": 229573.0, \"Valence\": 0.272, \"Chord\": \"C#/Db\"}, {\"Index\": 1523, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Tip Toe (feat. A Boogie Wit da Hoodie)\", \"Streams\": 5150724, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6608815.0, \"Song ID\": \"6ztvsy3C6hPjVg9j4x1XKJ\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 63.0, \"Danceability\": 0.757, \"Energy\": 0.673, \"Loudness\": -8.513, \"Speechiness\": 0.141, \"Acousticness\": 0.095, \"Liveness\": 0.338, \"Tempo\": 92.958, \"Duration (ms)\": 185806.0, \"Valence\": 0.574, \"Chord\": \"C#/Db\"}, {\"Index\": 1524, \"Highest Charting Position\": 182, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Start Wit Me (feat. Gunna)\", \"Streams\": 5085706, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6608815.0, \"Song ID\": \"7A20WnLkjtZU2d7hIB6Ziu\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 68.0, \"Danceability\": 0.886, \"Energy\": 0.479, \"Loudness\": -8.054, \"Speechiness\": 0.334, \"Acousticness\": 0.077, \"Liveness\": 0.135, \"Tempo\": 130.029, \"Duration (ms)\": 158692.0, \"Valence\": 0.408, \"Chord\": \"E\"}, {\"Index\": 1525, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Diamonds (with Normani)\", \"Streams\": 4981484, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"0PQsrLxPbOBBwwmXCnGvcF\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 58.0, \"Danceability\": 0.785, \"Energy\": 0.753, \"Loudness\": -3.841, \"Speechiness\": 0.0873, \"Acousticness\": 0.188, \"Liveness\": 0.265, \"Tempo\": 94.012, \"Duration (ms)\": 199301.0, \"Valence\": 0.488, \"Chord\": \"C#/Db\"}, {\"Index\": 1526, \"Highest Charting Position\": 140, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Don't Call Me Up\", \"Streams\": 4931458, \"Artist\": \"Mabel\", \"Artist Followers\": 1374784.0, \"Song ID\": \"5WHTFyqSii0lmT9R21abT8\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2019-01-18\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.674, \"Energy\": 0.881, \"Loudness\": -2.853, \"Speechiness\": 0.147, \"Acousticness\": 0.296, \"Liveness\": 0.0793, \"Tempo\": 98.994, \"Duration (ms)\": 178480.0, \"Valence\": 0.234, \"Chord\": \"A\"}, {\"Index\": 1527, \"Highest Charting Position\": 177, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Death\", \"Streams\": 4929396, \"Artist\": \"Trippie Redd, DaBaby\", \"Artist Followers\": 6434201.0, \"Song ID\": \"3Kd6Wp3lG5HXMB2dlvuy7y\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 65.0, \"Danceability\": 0.802, \"Energy\": 0.82, \"Loudness\": -5.969, \"Speechiness\": 0.146, \"Acousticness\": 0.0579, \"Liveness\": 0.149, \"Tempo\": 164.005, \"Duration (ms)\": 172196.0, \"Valence\": 0.613, \"Chord\": \"A#/Bb\"}, {\"Index\": 1528, \"Highest Charting Position\": 133, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Calma - Remix\", \"Streams\": 4879713, \"Artist\": \"Pedro Cap\\u00f3, Farruko\", \"Artist Followers\": 1353049.0, \"Song ID\": \"5iwz1NiezX7WWjnCgY5TH4\", \"Genre\": \"['latin', 'latin pop', 'puerto rican pop']\", \"Release Date\": \"2018-10-05\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.826, \"Energy\": 0.773, \"Loudness\": -4.218, \"Speechiness\": 0.0524, \"Acousticness\": 0.323, \"Liveness\": 0.143, \"Tempo\": 126.899, \"Duration (ms)\": 238200.0, \"Valence\": 0.761, \"Chord\": \"B\"}, {\"Index\": 1529, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Cut You Off\", \"Streams\": 4874380, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4OtHGdb0KqEbaWb6edUnR9\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 51.0, \"Danceability\": 0.855, \"Energy\": 0.294, \"Loudness\": -8.676, \"Speechiness\": 0.286, \"Acousticness\": 0.3, \"Liveness\": 0.091, \"Tempo\": 139.745, \"Duration (ms)\": 182017.0, \"Valence\": 0.842, \"Chord\": \"F\"}, {\"Index\": 1530, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Kinda Crazy\", \"Streams\": 4866777, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"59iGOjPSOcPLGl3vqEStUp\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 49.0, \"Danceability\": 0.691, \"Energy\": 0.446, \"Loudness\": -10.304, \"Speechiness\": 0.0472, \"Acousticness\": 0.484, \"Liveness\": 0.183, \"Tempo\": 93.03, \"Duration (ms)\": 212436.0, \"Valence\": 0.534, \"Chord\": \"B\"}, {\"Index\": 1531, \"Highest Charting Position\": 179, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"2002\", \"Streams\": 4831644, \"Artist\": \"Anne-Marie\", \"Artist Followers\": 8153871.0, \"Song ID\": \"2BgEsaKNfHUdlh97KmvFyo\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2018-04-27\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.697, \"Energy\": 0.683, \"Loudness\": -2.881, \"Speechiness\": 0.117, \"Acousticness\": 0.0372, \"Liveness\": 0.137, \"Tempo\": 96.133, \"Duration (ms)\": 186987.0, \"Valence\": 0.603, \"Chord\": \"C#/Db\"}, {\"Index\": 1532, \"Highest Charting Position\": 153, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Taki Taki (feat. Selena Gomez, Ozuna & Cardi B)\", \"Streams\": 4816702, \"Artist\": \"DJ Snake\", \"Artist Followers\": 7408249.0, \"Song ID\": \"0KoiMHhqKLoL4xM54rcWYY\", \"Genre\": \"['dance pop', 'edm', 'electronic trap', 'pop', 'pop dance']\", \"Release Date\": \"2019-07-25\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.842, \"Energy\": 0.801, \"Loudness\": -4.167, \"Speechiness\": 0.228, \"Acousticness\": 0.157, \"Liveness\": 0.0642, \"Tempo\": 95.881, \"Duration (ms)\": 212500.0, \"Valence\": 0.617, \"Chord\": \"G#/Ab\"}, {\"Index\": 1533, \"Highest Charting Position\": 107, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Family\", \"Streams\": 6145132, \"Artist\": \"The Chainsmokers, Kygo\", \"Artist Followers\": 18195884.0, \"Song ID\": \"3TKpJrY9q49Mj1JOsM9zGL\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.584, \"Energy\": 0.607, \"Loudness\": -6.605, \"Speechiness\": 0.0356, \"Acousticness\": 0.426, \"Liveness\": 0.101, \"Tempo\": 117.817, \"Duration (ms)\": 194827.0, \"Valence\": 0.374, \"Chord\": \"B\"}, {\"Index\": 1534, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"GANG GANG\", \"Streams\": 5898484, \"Artist\": \"JACKBOYS, Sheck Wes\", \"Artist Followers\": 437907.0, \"Song ID\": \"6uJONCdr2rC65BNmCnTBWK\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 69.0, \"Danceability\": 0.859, \"Energy\": 0.6, \"Loudness\": -4.63, \"Speechiness\": 0.301, \"Acousticness\": 0.071, \"Liveness\": 0.353, \"Tempo\": 123.017, \"Duration (ms)\": 244761.0, \"Valence\": 0.568, \"Chord\": \"G\"}, {\"Index\": 1535, \"Highest Charting Position\": 39, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Had Enough (feat. Quavo & Offset)\", \"Streams\": 5748010, \"Artist\": \"Don Toliver\", \"Artist Followers\": 437907.0, \"Song ID\": \"7LGWmZaoS7jZJ5tEi9EcDi\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.75, \"Energy\": 0.789, \"Loudness\": -4.578, \"Speechiness\": 0.108, \"Acousticness\": 0.253, \"Liveness\": 0.129, \"Tempo\": 147.957, \"Duration (ms)\": 157133.0, \"Valence\": 0.673, \"Chord\": \"D\"}, {\"Index\": 1536, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"WHAT TO DO? (feat. Don Toliver)\", \"Streams\": 5586351, \"Artist\": \"JACKBOYS, Travis Scott\", \"Artist Followers\": 437907.0, \"Song ID\": \"4AO1XhrgJczQ9bNVxdfKQe\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.643, \"Energy\": 0.594, \"Loudness\": -5.191, \"Speechiness\": 0.0312, \"Acousticness\": 0.0695, \"Liveness\": 0.115, \"Tempo\": 118.037, \"Duration (ms)\": 250142.0, \"Valence\": 0.195, \"Chord\": \"A\"}, {\"Index\": 1537, \"Highest Charting Position\": 125, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Writing on the Wall (feat. Post Malone, Cardi B & Rvssian)\", \"Streams\": 5229616, \"Artist\": \"French Montana\", \"Artist Followers\": 4039037.0, \"Song ID\": \"7x9nXsowok1JszkVztI5NI\", \"Genre\": \"['gangster rap', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 59.0, \"Danceability\": 0.773, \"Energy\": 0.836, \"Loudness\": -2.326, \"Speechiness\": 0.153, \"Acousticness\": 0.283, \"Liveness\": 0.0828, \"Tempo\": 112.01, \"Duration (ms)\": 201271.0, \"Valence\": 0.497, \"Chord\": \"A\"}, {\"Index\": 1538, \"Highest Charting Position\": 169, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"VALENTINO\", \"Streams\": 4935492, \"Artist\": \"24kGoldn\", \"Artist Followers\": 1276406.0, \"Song ID\": \"6piAUJJQFD8oHDUr0b7l7q\", \"Genre\": \"['cali rap']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.746, \"Energy\": 0.717, \"Loudness\": -4.841, \"Speechiness\": 0.179, \"Acousticness\": 0.199, \"Liveness\": 0.132, \"Tempo\": 150.964, \"Duration (ms)\": 179133.0, \"Valence\": 0.523, \"Chord\": \"A\"}, {\"Index\": 1539, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"fuck, i'm lonely (with Anne-Marie) - from \\u201c13 Reasons Why: Season 3\\u201d\", \"Streams\": 4856458, \"Artist\": \"Lauv\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-01-03--2020-01-10\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 1540, \"Highest Charting Position\": 150, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Roller\", \"Streams\": 4732292, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"6hw1Sy9wZ8UCxYGdpKrU6M\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2019-10-25\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.941, \"Energy\": 0.758, \"Loudness\": -6.47, \"Speechiness\": 0.17, \"Acousticness\": 0.0256, \"Liveness\": 0.193, \"Tempo\": 128.017, \"Duration (ms)\": 157093.0, \"Valence\": 0.683, \"Chord\": \"A#/Bb\"}, {\"Index\": 1541, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Never Really Over\", \"Streams\": 4679948, \"Artist\": \"Katy Perry\", \"Artist Followers\": 18936929.0, \"Song ID\": \"5PYQUBXc7NYeI1obMKSJK0\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-05-31\", \"Weeks Charted\": \"2020-01-03--2020-01-10\", \"Popularity\": 74.0, \"Danceability\": 0.77, \"Energy\": 0.882, \"Loudness\": -4.792, \"Speechiness\": 0.0602, \"Acousticness\": 0.194, \"Liveness\": 0.316, \"Tempo\": 99.991, \"Duration (ms)\": 223523.0, \"Valence\": 0.385, \"Chord\": \"G#/Ab\"}, {\"Index\": 1542, \"Highest Charting Position\": 145, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"One Kiss (with Dua Lipa)\", \"Streams\": 4594157, \"Artist\": \"Calvin Harris\", \"Artist Followers\": 21946934.0, \"Song ID\": \"7ef4DlsgrMEH11cDZd32M6\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'house', 'pop', 'progressive house', 'uk dance']\", \"Release Date\": \"2018-04-06\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.791, \"Energy\": 0.862, \"Loudness\": -3.24, \"Speechiness\": 0.11, \"Acousticness\": 0.037, \"Liveness\": 0.0814, \"Tempo\": 123.994, \"Duration (ms)\": 214847.0, \"Valence\": 0.592, \"Chord\": \"A\"}, {\"Index\": 1543, \"Highest Charting Position\": 192, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Fantas\\u00eda\", \"Streams\": 4543012, \"Artist\": \"Ozuna\", \"Artist Followers\": 29238936.0, \"Song ID\": \"40rXWke6SnXiGkSmaT8ZUr\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-29\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 59.0, \"Danceability\": 0.695, \"Energy\": 0.719, \"Loudness\": -5.938, \"Speechiness\": 0.0903, \"Acousticness\": 0.227, \"Liveness\": 0.0884, \"Tempo\": 180.074, \"Duration (ms)\": 175187.0, \"Valence\": 0.781, \"Chord\": \"D\"}, {\"Index\": 1544, \"Highest Charting Position\": 59, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Trampoline\", \"Streams\": 8896030, \"Artist\": \"SHAED, ZAYN\", \"Artist Followers\": 139434.0, \"Song ID\": \"1iQDltZqI7BXnHrFy4Qo1k\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-09-26\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.619, \"Energy\": 0.459, \"Loudness\": -5.782, \"Speechiness\": 0.0334, \"Acousticness\": 0.56, \"Liveness\": 0.137, \"Tempo\": 126.803, \"Duration (ms)\": 184280.0, \"Valence\": 0.498, \"Chord\": \"G\"}, {\"Index\": 1545, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"GATTI\", \"Streams\": 7685470, \"Artist\": \"JACKBOYS, Pop Smoke, Travis Scott\", \"Artist Followers\": 437907.0, \"Song ID\": \"40mjsnRjCpycdUw3xhS20g\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.594, \"Energy\": 0.676, \"Loudness\": -5.808, \"Speechiness\": 0.344, \"Acousticness\": 0.135, \"Liveness\": 0.163, \"Tempo\": 143.477, \"Duration (ms)\": 181145.0, \"Valence\": 0.472, \"Chord\": \"D\"}, {\"Index\": 1546, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Candy\", \"Streams\": 5632102, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"1VJwtWR6z7SpZRwipI12be\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2018-03-30\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.689, \"Energy\": 0.516, \"Loudness\": -5.857, \"Speechiness\": 0.0444, \"Acousticness\": 0.513, \"Liveness\": 0.163, \"Tempo\": 124.876, \"Duration (ms)\": 190920.0, \"Valence\": 0.209, \"Chord\": \"G#/Ab\"}, {\"Index\": 1547, \"Highest Charting Position\": 143, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"JACKBOYS\", \"Streams\": 5363493, \"Artist\": \"JACKBOYS\", \"Artist Followers\": 437907.0, \"Song ID\": \"62zKJrpbLxz6InR3tGyr7o\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 56.0, \"Danceability\": 0.413, \"Energy\": 0.13, \"Loudness\": -25.166, \"Speechiness\": 0.0336, \"Acousticness\": 0.9, \"Liveness\": 0.111, \"Tempo\": 123.342, \"Duration (ms)\": 46837.0, \"Valence\": 0.0676, \"Chord\": \"C\"}, {\"Index\": 1548, \"Highest Charting Position\": 156, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Combatchy (feat. MC Rebecca)\", \"Streams\": 5149797, \"Artist\": \"Anitta, Lexa, Lu\\u00edsa Sonza\", \"Artist Followers\": 10741972.0, \"Song ID\": \"2bPtwnrpFNEe8N7Q85kLHw\", \"Genre\": \"['funk carioca', 'funk pop', 'pagode baiano', 'pop nacional']\", \"Release Date\": \"2019-11-20\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 64.0, \"Danceability\": 0.826, \"Energy\": 0.73, \"Loudness\": -3.032, \"Speechiness\": 0.0809, \"Acousticness\": 0.383, \"Liveness\": 0.0197, \"Tempo\": 150.134, \"Duration (ms)\": 157600.0, \"Valence\": 0.605, \"Chord\": \"C#/Db\"}, {\"Index\": 1549, \"Highest Charting Position\": 178, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Old Town Road\", \"Streams\": 4852004, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5488666.0, \"Song ID\": \"2YpeDb67231RjR0MgVLzsG\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.878, \"Energy\": 0.619, \"Loudness\": -5.56, \"Speechiness\": 0.102, \"Acousticness\": 0.0533, \"Liveness\": 0.113, \"Tempo\": 136.041, \"Duration (ms)\": 157067.0, \"Valence\": 0.639, \"Chord\": \"F#/Gb\"}, {\"Index\": 1550, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Let Me Know (I Wonder Why Freestyle)\", \"Streams\": 4701532, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"3wwo0bJvDSorOpNfzEkfXx\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2019-12-07\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.635, \"Energy\": 0.537, \"Loudness\": -7.895, \"Speechiness\": 0.0832, \"Acousticness\": 0.172, \"Liveness\": 0.418, \"Tempo\": 125.028, \"Duration (ms)\": 215381.0, \"Valence\": 0.383, \"Chord\": \"G\"}, {\"Index\": 1551, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Ne reviens pas\", \"Streams\": 4676857, \"Artist\": \"Gradur, Heuss L'enfoir\\u00e9\", \"Artist Followers\": 1390813.0, \"Song ID\": \"4TnFANpjVwVKWzkxNzIyFH\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2019-11-29\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 62.0, \"Danceability\": 0.932, \"Energy\": 0.778, \"Loudness\": -3.384, \"Speechiness\": 0.0638, \"Acousticness\": 0.212, \"Liveness\": 0.168, \"Tempo\": 124.996, \"Duration (ms)\": 188613.0, \"Valence\": 0.933, \"Chord\": \"A#/Bb\"}, {\"Index\": 1552, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"New Rules\", \"Streams\": 4630675, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"2ekn2ttSfGqwhhate0LSR0\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2017-06-02\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.762, \"Energy\": 0.7, \"Loudness\": -6.021, \"Speechiness\": 0.0694, \"Acousticness\": 0.00261, \"Liveness\": 0.153, \"Tempo\": 116.073, \"Duration (ms)\": 209320.0, \"Valence\": 0.608, \"Chord\": \"A\"}, {\"Index\": 1553, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Cheirosa - Ao Vivo\", \"Streams\": 4623030, \"Artist\": \"Jorge & Mateus\", \"Artist Followers\": 15019109.0, \"Song ID\": \"2PWjKmjyTZeDpmOUa3a5da\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2019-10-11\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.528, \"Energy\": 0.87, \"Loudness\": -3.123, \"Speechiness\": 0.0851, \"Acousticness\": 0.24, \"Liveness\": 0.333, \"Tempo\": 152.37, \"Duration (ms)\": 181930.0, \"Valence\": 0.714, \"Chord\": \"B\"}, {\"Index\": 1554, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Havana (feat. Young Thug)\", \"Streams\": 4620876, \"Artist\": \"Camila Cabello\", \"Artist Followers\": 22698747.0, \"Song ID\": \"1rfofaqEpACxVEHIZBJe6W\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-01-12\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.765, \"Energy\": 0.523, \"Loudness\": -4.333, \"Speechiness\": 0.03, \"Acousticness\": 0.184, \"Liveness\": 0.132, \"Tempo\": 104.988, \"Duration (ms)\": 217307.0, \"Valence\": 0.394, \"Chord\": \"D\"}, {\"Index\": 1555, \"Highest Charting Position\": 198, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Surtada - Remix Brega Funk\", \"Streams\": 4607385, \"Artist\": \"Dad\\u00e1 Bolad\\u00e3o, Tati Zaqui, OIK\", \"Artist Followers\": 208630.0, \"Song ID\": \"5F8ffc8KWKNawllr5WsW0r\", \"Genre\": \"['brega funk', 'funk carioca']\", \"Release Date\": \"2019-09-25\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 60.0, \"Danceability\": 0.832, \"Energy\": 0.55, \"Loudness\": -7.026, \"Speechiness\": 0.0587, \"Acousticness\": 0.249, \"Liveness\": 0.182, \"Tempo\": 154.064, \"Duration (ms)\": 152784.0, \"Valence\": 0.881, \"Chord\": \"F\"}, {\"Index\": 1556, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lover (Remix) [feat. Shawn Mendes]\", \"Streams\": 4595450, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3i9UVldZOE0aD0JnyfAZZ0\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-11-13\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.448, \"Energy\": 0.603, \"Loudness\": -7.176, \"Speechiness\": 0.064, \"Acousticness\": 0.433, \"Liveness\": 0.0862, \"Tempo\": 205.272, \"Duration (ms)\": 221307.0, \"Valence\": 0.422, \"Chord\": \"G\"}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 20,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "alt.Chart(df).mark_circle().encode(\n",
    "    x = \"Energy\",\n",
    "    y = \"Loudness\",\n",
    "    color = alt.Color('Acousticness',scale=alt.Scale(scheme=\"goldred\",reverse=True)),\n",
    "    tooltip = [\"Artist\",\"Song Name\",\"Release Date\",\"Chord\"]\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "e0ae77e3",
   "metadata": {},
   "source": [
    "(log-curve)=\n",
    "#### Spotify chart with tooltip\n",
    "\n",
    "In the following chart we use a different color scheme, we specify the dimensions of the chart to make it a little bigger, and we give the chart a title."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 21,
   "id": "e1c636df",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-2dbb77c3ccf14390ad8b2034f12ed2b5\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-2dbb77c3ccf14390ad8b2034f12ed2b5\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-2dbb77c3ccf14390ad8b2034f12ed2b5\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-67c9fb159873386c9c7303ca2ad81ad2\"}, \"mark\": \"circle\", \"encoding\": {\"color\": {\"type\": \"quantitative\", \"field\": \"Acousticness\", \"scale\": {\"reverse\": true, \"scheme\": \"turbo\"}}, \"tooltip\": [{\"type\": \"nominal\", \"field\": \"Artist\"}, {\"type\": \"nominal\", \"field\": \"Song Name\"}, {\"type\": \"nominal\", \"field\": \"Release Date\"}, {\"type\": \"nominal\", \"field\": \"Chord\"}], \"x\": {\"type\": \"quantitative\", \"field\": \"Energy\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"Loudness\"}}, \"height\": 450, \"title\": \"Spotify dataset from Kaggle\", \"width\": 720, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-67c9fb159873386c9c7303ca2ad81ad2\": [{\"Index\": 1, \"Highest Charting Position\": 1, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Beggin'\", \"Streams\": 48633449, \"Artist\": \"M\\u00e5neskin\", \"Artist Followers\": 3377762.0, \"Song ID\": \"3Wrjm47oTz2sjIgck11l5e\", \"Genre\": \"['indie rock italiano', 'italian pop']\", \"Release Date\": \"2017-12-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 100.0, \"Danceability\": 0.714, \"Energy\": 0.8, \"Loudness\": -4.808, \"Speechiness\": 0.0504, \"Acousticness\": 0.127, \"Liveness\": 0.359, \"Tempo\": 134.002, \"Duration (ms)\": 211560.0, \"Valence\": 0.589, \"Chord\": \"B\"}, {\"Index\": 2, \"Highest Charting Position\": 2, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"STAY (with Justin Bieber)\", \"Streams\": 47248719, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2230022.0, \"Song ID\": \"5HCyWlXZPP0y6Gqq8TgA20\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 99.0, \"Danceability\": 0.591, \"Energy\": 0.764, \"Loudness\": -5.484, \"Speechiness\": 0.0483, \"Acousticness\": 0.0383, \"Liveness\": 0.103, \"Tempo\": 169.928, \"Duration (ms)\": 141806.0, \"Valence\": 0.478, \"Chord\": \"C#/Db\"}, {\"Index\": 3, \"Highest Charting Position\": 1, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"good 4 u\", \"Streams\": 40162559, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"4ZtFanR9U6ndgddUvNcjcG\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 99.0, \"Danceability\": 0.563, \"Energy\": 0.664, \"Loudness\": -5.044, \"Speechiness\": 0.154, \"Acousticness\": 0.335, \"Liveness\": 0.0849, \"Tempo\": 166.928, \"Duration (ms)\": 178147.0, \"Valence\": 0.688, \"Chord\": \"A\"}, {\"Index\": 4, \"Highest Charting Position\": 3, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Bad Habits\", \"Streams\": 37799456, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83293380.0, \"Song ID\": \"6PQ88X9TkUIAUIZJHW2upE\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 98.0, \"Danceability\": 0.808, \"Energy\": 0.897, \"Loudness\": -3.712, \"Speechiness\": 0.0348, \"Acousticness\": 0.0469, \"Liveness\": 0.364, \"Tempo\": 126.026, \"Duration (ms)\": 231041.0, \"Valence\": 0.591, \"Chord\": \"B\"}, {\"Index\": 5, \"Highest Charting Position\": 5, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"INDUSTRY BABY (feat. Jack Harlow)\", \"Streams\": 33948454, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5473565.0, \"Song ID\": \"27NovPIUIRrOZoCHxABJwK\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2021-07-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 96.0, \"Danceability\": 0.736, \"Energy\": 0.704, \"Loudness\": -7.409, \"Speechiness\": 0.0615, \"Acousticness\": 0.0203, \"Liveness\": 0.0501, \"Tempo\": 149.995, \"Duration (ms)\": 212000.0, \"Valence\": 0.894, \"Chord\": \"D#/Eb\"}, {\"Index\": 6, \"Highest Charting Position\": 1, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"MONTERO (Call Me By Your Name)\", \"Streams\": 30071134, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5473565.0, \"Song ID\": \"67BtfxlNbhBmCDR2L2l8qd\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2021-03-31\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 97.0, \"Danceability\": 0.61, \"Energy\": 0.508, \"Loudness\": -6.682, \"Speechiness\": 0.152, \"Acousticness\": 0.297, \"Liveness\": 0.384, \"Tempo\": 178.818, \"Duration (ms)\": 137876.0, \"Valence\": 0.758, \"Chord\": \"G#/Ab\"}, {\"Index\": 7, \"Highest Charting Position\": 3, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Kiss Me More (feat. SZA)\", \"Streams\": 29356736, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"748mdHapucXQri7IAO8yFK\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 94.0, \"Danceability\": 0.762, \"Energy\": 0.701, \"Loudness\": -3.541, \"Speechiness\": 0.0286, \"Acousticness\": 0.235, \"Liveness\": 0.123, \"Tempo\": 110.968, \"Duration (ms)\": 208867.0, \"Valence\": 0.742, \"Chord\": \"G#/Ab\"}, {\"Index\": 8, \"Highest Charting Position\": 2, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Todo De Ti\", \"Streams\": 26951613, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6080597.0, \"Song ID\": \"4fSIb4hdOQ151TILNsSEaF\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2021-05-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 95.0, \"Danceability\": 0.78, \"Energy\": 0.718, \"Loudness\": -3.605, \"Speechiness\": 0.0506, \"Acousticness\": 0.31, \"Liveness\": 0.0932, \"Tempo\": 127.949, \"Duration (ms)\": 199604.0, \"Valence\": 0.342, \"Chord\": \"D#/Eb\"}, {\"Index\": 9, \"Highest Charting Position\": 3, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Yonaguni\", \"Streams\": 25030128, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36142273.0, \"Song ID\": \"2JPLbjOn0wPCngEot2STUS\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 96.0, \"Danceability\": 0.644, \"Energy\": 0.648, \"Loudness\": -4.601, \"Speechiness\": 0.118, \"Acousticness\": 0.276, \"Liveness\": 0.135, \"Tempo\": 179.951, \"Duration (ms)\": 206710.0, \"Valence\": 0.44, \"Chord\": \"C#/Db\"}, {\"Index\": 10, \"Highest Charting Position\": 8, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"I WANNA BE YOUR SLAVE\", \"Streams\": 24551591, \"Artist\": \"M\\u00e5neskin\", \"Artist Followers\": 3377762.0, \"Song ID\": \"4pt5fDVTg5GhEvEtlz9dKk\", \"Genre\": \"['indie rock italiano', 'italian pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 95.0, \"Danceability\": 0.75, \"Energy\": 0.608, \"Loudness\": -4.008, \"Speechiness\": 0.0387, \"Acousticness\": 0.00165, \"Liveness\": 0.178, \"Tempo\": 132.507, \"Duration (ms)\": 173347.0, \"Valence\": 0.958, \"Chord\": \"C#/Db\"}, {\"Index\": 11, \"Highest Charting Position\": 4, \"Number of Times Charted\": 43, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Levitating (feat. DaBaby)\", \"Streams\": 23518010, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"463CkQjx2Zk1yXoBuierM9\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-10-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 89.0, \"Danceability\": 0.702, \"Energy\": 0.825, \"Loudness\": -3.787, \"Speechiness\": 0.0601, \"Acousticness\": 0.00883, \"Liveness\": 0.0674, \"Tempo\": 102.977, \"Duration (ms)\": 203064.0, \"Valence\": 0.915, \"Chord\": \"F#/Gb\"}, {\"Index\": 12, \"Highest Charting Position\": 9, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Qu\\u00e9 M\\u00e1s Pues?\", \"Streams\": 22405111, \"Artist\": \"J Balvin, Maria Becerra\", \"Artist Followers\": 29051363.0, \"Song ID\": \"6hf0RpxTbOprT5nnwzkk8e\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\", \"Popularity\": 95.0, \"Danceability\": 0.891, \"Energy\": 0.819, \"Loudness\": -3.964, \"Speechiness\": 0.106, \"Acousticness\": 0.0261, \"Liveness\": 0.173, \"Tempo\": 101.968, \"Duration (ms)\": 217773.0, \"Valence\": 0.768, \"Chord\": \"G#/Ab\"}, {\"Index\": 13, \"Highest Charting Position\": 5, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Permission to Dance\", \"Streams\": 22062812, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"0LThjFY2iTtNdd4wviwVV2\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 95.0, \"Danceability\": 0.702, \"Energy\": 0.741, \"Loudness\": -5.33, \"Speechiness\": 0.0427, \"Acousticness\": 0.00544, \"Liveness\": 0.337, \"Tempo\": 124.925, \"Duration (ms)\": 187585.0, \"Valence\": 0.646, \"Chord\": \"A\"}, {\"Index\": 14, \"Highest Charting Position\": 1, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Peaches (feat. Daniel Caesar & Giveon)\", \"Streams\": 20294457, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48504126.0, \"Song ID\": \"4iJyoBOLtHqaGxP12qzhQI\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 94.0, \"Danceability\": 0.677, \"Energy\": 0.696, \"Loudness\": -6.181, \"Speechiness\": 0.119, \"Acousticness\": 0.321, \"Liveness\": 0.42, \"Tempo\": 90.03, \"Duration (ms)\": 198082.0, \"Valence\": 0.464, \"Chord\": \"C\"}, {\"Index\": 15, \"Highest Charting Position\": 2, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Butter\", \"Streams\": 19985713, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"2bgTY4UwhfBYhGT4HUYStN\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 95.0, \"Danceability\": 0.759, \"Energy\": 0.459, \"Loudness\": -5.187, \"Speechiness\": 0.0948, \"Acousticness\": 0.00323, \"Liveness\": 0.0906, \"Tempo\": 109.997, \"Duration (ms)\": 164442.0, \"Valence\": 0.695, \"Chord\": \"G#/Ab\"}, {\"Index\": 16, \"Highest Charting Position\": 7, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"traitor\", \"Streams\": 19480679, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"5CZ40GBx1sQ9agT82CLQCT\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 94.0, \"Danceability\": 0.38, \"Energy\": 0.339, \"Loudness\": -7.885, \"Speechiness\": 0.0338, \"Acousticness\": 0.691, \"Liveness\": 0.12, \"Tempo\": 100.607, \"Duration (ms)\": 229227.0, \"Valence\": 0.0849, \"Chord\": \"D#/Eb\"}, {\"Index\": 17, \"Highest Charting Position\": 3, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"deja vu\", \"Streams\": 18571755, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"6HU7h9RYOaPRFeh0R3UeAr\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 93.0, \"Danceability\": 0.442, \"Energy\": 0.612, \"Loudness\": -7.222, \"Speechiness\": 0.112, \"Acousticness\": 0.584, \"Liveness\": 0.37, \"Tempo\": 180.917, \"Duration (ms)\": 215507.0, \"Valence\": 0.178, \"Chord\": \"D\"}, {\"Index\": 18, \"Highest Charting Position\": 5, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Save Your Tears (with Ariana Grande) (Remix)\", \"Streams\": 18053141, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"37BZB0z9T8Xu7U3e65qxFy\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 94.0, \"Danceability\": 0.65, \"Energy\": 0.825, \"Loudness\": -4.645, \"Speechiness\": 0.0325, \"Acousticness\": 0.0215, \"Liveness\": 0.0936, \"Tempo\": 118.091, \"Duration (ms)\": 191014.0, \"Valence\": 0.593, \"Chord\": \"C\"}, {\"Index\": 19, \"Highest Charting Position\": 14, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"AM Remix\", \"Streams\": 17617965, \"Artist\": \"Nio Garcia, J Balvin, Bad Bunny\", \"Artist Followers\": 2123734.0, \"Song ID\": \"05bfbizlM5AX6Mf1RRyMho\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-24\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 93.0, \"Danceability\": 0.743, \"Energy\": 0.655, \"Loudness\": -5.015, \"Speechiness\": 0.159, \"Acousticness\": 0.114, \"Liveness\": 0.0764, \"Tempo\": 172.031, \"Duration (ms)\": 261335.0, \"Valence\": 0.785, \"Chord\": \"F#/Gb\"}, {\"Index\": 20, \"Highest Charting Position\": 20, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Need To Know\", \"Streams\": 16908917, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"3Vi5XqYrmQgOYBajMWSvCi\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 90.0, \"Danceability\": 0.664, \"Energy\": 0.609, \"Loudness\": -6.509, \"Speechiness\": 0.0707, \"Acousticness\": 0.304, \"Liveness\": 0.0926, \"Tempo\": 130.041, \"Duration (ms)\": 210560.0, \"Valence\": 0.194, \"Chord\": \"C#/Db\"}, {\"Index\": 21, \"Highest Charting Position\": 19, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Volando - Remix\", \"Streams\": 16606925, \"Artist\": \"Mora, Bad Bunny, Sech\", \"Artist Followers\": 151486.0, \"Song ID\": \"0G2zPzWqVjR68iNPmx2TBe\", \"Genre\": \"['reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 91.0, \"Danceability\": 0.659, \"Energy\": 0.688, \"Loudness\": -4.649, \"Speechiness\": 0.0673, \"Acousticness\": 0.207, \"Liveness\": 0.113, \"Tempo\": 153.979, \"Duration (ms)\": 273474.0, \"Valence\": 0.632, \"Chord\": \"F#/Gb\"}, {\"Index\": 22, \"Highest Charting Position\": 22, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Ain't Shit\", \"Streams\": 16126897, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"5lAnYvAIkSDNXqfo7DyFUm\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 90.0, \"Danceability\": 0.855, \"Energy\": 0.488, \"Loudness\": -4.601, \"Speechiness\": 0.208, \"Acousticness\": 0.506, \"Liveness\": 0.347, \"Tempo\": 124.097, \"Duration (ms)\": 174253.0, \"Valence\": 0.619, \"Chord\": \"D#/Eb\"}, {\"Index\": 23, \"Highest Charting Position\": 1, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"drivers license\", \"Streams\": 15684978, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"5wANPM4fQCJwkGd4rN57mH\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 92.0, \"Danceability\": 0.561, \"Energy\": 0.431, \"Loudness\": -8.81, \"Speechiness\": 0.0578, \"Acousticness\": 0.768, \"Liveness\": 0.106, \"Tempo\": 143.875, \"Duration (ms)\": 242013.0, \"Valence\": 0.137, \"Chord\": \"A#/Bb\"}, {\"Index\": 24, \"Highest Charting Position\": 24, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Heat Waves\", \"Streams\": 15089184, \"Artist\": \"Glass Animals\", \"Artist Followers\": 1890510.0, \"Song ID\": \"3USxtqRwSYz57Ewm6wWRMp\", \"Genre\": \"['gauze pop', 'indietronica', 'shiver pop']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 85.0, \"Danceability\": 0.761, \"Energy\": 0.525, \"Loudness\": -6.9, \"Speechiness\": 0.0944, \"Acousticness\": 0.44, \"Liveness\": 0.0921, \"Tempo\": 80.87, \"Duration (ms)\": 238805.0, \"Valence\": 0.531, \"Chord\": \"B\"}, {\"Index\": 25, \"Highest Charting Position\": 1, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Blinding Lights\", \"Streams\": 15011809, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"0VjIjW4GlUZAMYd2vXMi3b\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 92.0, \"Danceability\": 0.514, \"Energy\": 0.73, \"Loudness\": -5.934, \"Speechiness\": 0.0598, \"Acousticness\": 0.00146, \"Liveness\": 0.0897, \"Tempo\": 171.005, \"Duration (ms)\": 200040.0, \"Valence\": 0.334, \"Chord\": \"C#/Db\"}, {\"Index\": 26, \"Highest Charting Position\": 12, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"happier\", \"Streams\": 14849078, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"2tGvwE8GcFKwNdAXMnlbfl\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 92.0, \"Danceability\": 0.395, \"Energy\": 0.443, \"Loudness\": -9.72, \"Speechiness\": 0.133, \"Acousticness\": 0.765, \"Liveness\": 0.0839, \"Tempo\": 168.924, \"Duration (ms)\": 175933.0, \"Valence\": 0.338, \"Chord\": \"F#/Gb\"}, {\"Index\": 27, \"Highest Charting Position\": 27, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Pepas\", \"Streams\": 14809458, \"Artist\": \"Farruko\", \"Artist Followers\": 10502148.0, \"Song ID\": \"5fwSHlTEWpluwOM0Sxnh5k\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-24\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 92.0, \"Danceability\": 0.762, \"Energy\": 0.766, \"Loudness\": -3.955, \"Speechiness\": 0.0343, \"Acousticness\": 0.00776, \"Liveness\": 0.128, \"Tempo\": 130.001, \"Duration (ms)\": 287120.0, \"Valence\": 0.442, \"Chord\": \"G\"}, {\"Index\": 28, \"Highest Charting Position\": 18, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Motley Crew\", \"Streams\": 14329162, \"Artist\": \"Post Malone\", \"Artist Followers\": 33651775.0, \"Song ID\": \"40uMIn2zJLAQhNXghRjBed\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 90.0, \"Danceability\": 0.797, \"Energy\": 0.631, \"Loudness\": -3.818, \"Speechiness\": 0.0786, \"Acousticness\": 0.0904, \"Liveness\": 0.0998, \"Tempo\": 129.915, \"Duration (ms)\": 184213.0, \"Valence\": 0.288, \"Chord\": \"D#/Eb\"}, {\"Index\": 29, \"Highest Charting Position\": 15, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Friday (feat. Mufasa & Hypeman) - Dopamine Re-Edit\", \"Streams\": 14273637, \"Artist\": \"Riton, Nightcrawlers\", \"Artist Followers\": 83689.0, \"Song ID\": \"4cG7HUWYHBV6R6tHn1gxrl\", \"Genre\": \"['dance pop', 'house', 'pop dance', 'tropical house', 'uk dance']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 92.0, \"Danceability\": 0.824, \"Energy\": 0.862, \"Loudness\": -3.424, \"Speechiness\": 0.126, \"Acousticness\": 0.0076, \"Liveness\": 0.303, \"Tempo\": 122.98, \"Duration (ms)\": 169153.0, \"Valence\": 0.801, \"Chord\": \"D\"}, {\"Index\": 30, \"Highest Charting Position\": 3, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Astronaut In The Ocean\", \"Streams\": 14174752, \"Artist\": \"Masked Wolf\", \"Artist Followers\": 365975.0, \"Song ID\": \"3Ofmpyhv5UAQ70mENzB277\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2021-01-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 89.0, \"Danceability\": 0.778, \"Energy\": 0.695, \"Loudness\": -6.865, \"Speechiness\": 0.0913, \"Acousticness\": 0.175, \"Liveness\": 0.15, \"Tempo\": 149.996, \"Duration (ms)\": 132780.0, \"Valence\": 0.472, \"Chord\": \"E\"}, {\"Index\": 31, \"Highest Charting Position\": 5, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Leave The Door Open\", \"Streams\": 13963568, \"Artist\": \"Bruno Mars, Anderson .Paak, Silk Sonic\", \"Artist Followers\": 32574754.0, \"Song ID\": \"7MAibcTli4IisCtbHKrGMh\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 92.0, \"Danceability\": 0.586, \"Energy\": 0.616, \"Loudness\": -7.964, \"Speechiness\": 0.0324, \"Acousticness\": 0.182, \"Liveness\": 0.0927, \"Tempo\": 148.088, \"Duration (ms)\": 242096.0, \"Valence\": 0.719, \"Chord\": \"F\"}, {\"Index\": 32, \"Highest Charting Position\": 32, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Don't Go Yet\", \"Streams\": 13205250, \"Artist\": \"Camila Cabello\", \"Artist Followers\": 22683756.0, \"Song ID\": \"1058fW9H3fZA6QjYCdOBad\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-07-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 88.0, \"Danceability\": 0.666, \"Energy\": 0.796, \"Loudness\": -6.967, \"Speechiness\": 0.103, \"Acousticness\": 0.0492, \"Liveness\": 0.0442, \"Tempo\": 110.108, \"Duration (ms)\": 164842.0, \"Valence\": 0.61, \"Chord\": \"A#/Bb\"}, {\"Index\": 33, \"Highest Charting Position\": 11, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"favorite crime\", \"Streams\": 12818935, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"5JCoSi02qi3jJeHdZXMmR8\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 91.0, \"Danceability\": 0.369, \"Energy\": 0.272, \"Loudness\": -10.497, \"Speechiness\": 0.0364, \"Acousticness\": 0.866, \"Liveness\": 0.147, \"Tempo\": 172.929, \"Duration (ms)\": 152667.0, \"Valence\": 0.218, \"Chord\": \"A\"}, {\"Index\": 34, \"Highest Charting Position\": 10, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Pareja Del A\\u00f1o\", \"Streams\": 12572307, \"Artist\": \"Sebastian Yatra, Myke Towers\", \"Artist Followers\": 16216789.0, \"Song ID\": \"2rCbl9naJYhaxjLsfx88uM\", \"Genre\": \"['colombian pop', 'latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 91.0, \"Danceability\": 0.715, \"Energy\": 0.622, \"Loudness\": -5.102, \"Speechiness\": 0.046, \"Acousticness\": 0.163, \"Liveness\": 0.0948, \"Tempo\": 80.015, \"Duration (ms)\": 195053.0, \"Valence\": 0.808, \"Chord\": \"E\"}, {\"Index\": 35, \"Highest Charting Position\": 4, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Watermelon Sugar\", \"Streams\": 11996689, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16112621.0, \"Song ID\": \"6UelLqGlWMcVH1E5c4H7lY\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 90.0, \"Danceability\": 0.548, \"Energy\": 0.816, \"Loudness\": -4.209, \"Speechiness\": 0.0465, \"Acousticness\": 0.122, \"Liveness\": 0.335, \"Tempo\": 95.39, \"Duration (ms)\": 174000.0, \"Valence\": 0.557, \"Chord\": \"C\"}, {\"Index\": 36, \"Highest Charting Position\": 36, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"NOT SOBER (feat. Polo G & Stunna Gambino)\", \"Streams\": 11869336, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 37, \"Highest Charting Position\": 3, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"RAPSTAR\", \"Streams\": 11683383, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"43PGPuHIlVOc04jrZVh9L6\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 89.0, \"Danceability\": 0.789, \"Energy\": 0.536, \"Loudness\": -6.862, \"Speechiness\": 0.242, \"Acousticness\": 0.41, \"Liveness\": 0.129, \"Tempo\": 81.039, \"Duration (ms)\": 165926.0, \"Valence\": 0.437, \"Chord\": \"F#/Gb\"}, {\"Index\": 38, \"Highest Charting Position\": 15, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"You Right\", \"Streams\": 11629418, \"Artist\": \"Doja Cat, The Weeknd\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0k4d5YPDr1r7FX77VdqWez\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 89.0, \"Danceability\": 0.828, \"Energy\": 0.621, \"Loudness\": -6.414, \"Speechiness\": 0.0565, \"Acousticness\": 0.0164, \"Liveness\": 0.0845, \"Tempo\": 128.986, \"Duration (ms)\": 186173.0, \"Valence\": 0.436, \"Chord\": \"G#/Ab\"}, {\"Index\": 39, \"Highest Charting Position\": 39, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"911 - Remix\", \"Streams\": 11553846, \"Artist\": \"Sech, Jhay Cortez\", \"Artist Followers\": 8758283.0, \"Song ID\": \"27RSJHEA99Y0Vsow7nA37A\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 89.0, \"Danceability\": 0.816, \"Energy\": 0.71, \"Loudness\": -3.728, \"Speechiness\": 0.0398, \"Acousticness\": 0.165, \"Liveness\": 0.292, \"Tempo\": 93.02, \"Duration (ms)\": 208631.0, \"Valence\": 0.784, \"Chord\": \"G\"}, {\"Index\": 40, \"Highest Charting Position\": 1, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"D\\u00c1KITI\", \"Streams\": 11524288, \"Artist\": \"Bad Bunny, Jhay Cortez\", \"Artist Followers\": 36142273.0, \"Song ID\": \"4MzXwWMhyBbmu6hOcLVD49\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 86.0, \"Danceability\": 0.731, \"Energy\": 0.573, \"Loudness\": -10.059, \"Speechiness\": 0.0544, \"Acousticness\": 0.401, \"Liveness\": 0.113, \"Tempo\": 109.928, \"Duration (ms)\": 205090.0, \"Valence\": 0.145, \"Chord\": \"E\"}, {\"Index\": 41, \"Highest Charting Position\": 41, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Mi\\u00e9nteme\", \"Streams\": 11477024, \"Artist\": \"TINI, Maria Becerra\", \"Artist Followers\": 2936204.0, \"Song ID\": \"0cOa970mzTWAxKtltpkpLc\", \"Genre\": \"['latin pop', 'pop argentino']\", \"Release Date\": \"2021-04-29\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 90.0, \"Danceability\": 0.85, \"Energy\": 0.541, \"Loudness\": -4.522, \"Speechiness\": 0.0674, \"Acousticness\": 0.161, \"Liveness\": 0.286, \"Tempo\": 92.003, \"Duration (ms)\": 165275.0, \"Valence\": 0.916, \"Chord\": \"D\"}, {\"Index\": 42, \"Highest Charting Position\": 17, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"jealousy, jealousy\", \"Streams\": 11287301, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"0MMyJUC3WNnFS1lit5pTjk\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 90.0, \"Danceability\": 0.695, \"Energy\": 0.575, \"Loudness\": -6.334, \"Speechiness\": 0.116, \"Acousticness\": 0.198, \"Liveness\": 0.0614, \"Tempo\": 163.929, \"Duration (ms)\": 173160.0, \"Valence\": 0.699, \"Chord\": \"A#/Bb\"}, {\"Index\": 43, \"Highest Charting Position\": 33, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Poblado - Remix\", \"Streams\": 11283626, \"Artist\": \"J Balvin, KAROL G, Nicky Jam, Crissin, Totoy El Frio, Natan & Shander\", \"Artist Followers\": 29051363.0, \"Song ID\": \"1WedZeiezCmCEOzLwhx0hV\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 89.0, \"Danceability\": 0.813, \"Energy\": 0.809, \"Loudness\": -5.382, \"Speechiness\": 0.0846, \"Acousticness\": 0.102, \"Liveness\": 0.377, \"Tempo\": 93.005, \"Duration (ms)\": 393280.0, \"Valence\": 0.646, \"Chord\": \"D#/Eb\"}, {\"Index\": 44, \"Highest Charting Position\": 2, \"Number of Times Charted\": 49, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Dynamite\", \"Streams\": 11196819, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"4saklk6nie3yiGePpBwUoc\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 89.0, \"Danceability\": 0.746, \"Energy\": 0.765, \"Loudness\": -4.41, \"Speechiness\": 0.0993, \"Acousticness\": 0.0112, \"Liveness\": 0.0936, \"Tempo\": 114.044, \"Duration (ms)\": 199054.0, \"Valence\": 0.737, \"Chord\": \"F#/Gb\"}, {\"Index\": 45, \"Highest Charting Position\": 9, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"The Business\", \"Streams\": 10739770, \"Artist\": \"Ti\\u00ebsto\", \"Artist Followers\": 5785065.0, \"Song ID\": \"6f3Slt0GbA2bPZlz0aIFXN\", \"Genre\": \"['big room', 'brostep', 'dance pop', 'dutch edm', 'edm', 'electro house', 'house', 'pop dance', 'slap house', 'trance', 'tropical house']\", \"Release Date\": \"2020-09-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 90.0, \"Danceability\": 0.798, \"Energy\": 0.62, \"Loudness\": -7.079, \"Speechiness\": 0.232, \"Acousticness\": 0.414, \"Liveness\": 0.112, \"Tempo\": 120.031, \"Duration (ms)\": 164000.0, \"Valence\": 0.235, \"Chord\": \"G#/Ab\"}, {\"Index\": 46, \"Highest Charting Position\": 46, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Heartbreak Anthem (with David Guetta & Little Mix)\", \"Streams\": 10315460, \"Artist\": \"Galantis\", \"Artist Followers\": 3120157.0, \"Song ID\": \"5K6Ssv4Z3zRvxt0P6EKUAP\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2021-05-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 89.0, \"Danceability\": 0.595, \"Energy\": 0.784, \"Loudness\": -4.878, \"Speechiness\": 0.102, \"Acousticness\": 0.216, \"Liveness\": 0.0608, \"Tempo\": 124.111, \"Duration (ms)\": 183726.0, \"Valence\": 0.479, \"Chord\": \"C#/Db\"}, {\"Index\": 47, \"Highest Charting Position\": 1, \"Number of Times Charted\": 51, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Mood (feat. iann dior)\", \"Streams\": 10222056, \"Artist\": \"24kGoldn\", \"Artist Followers\": 1274433.0, \"Song ID\": \"4jPy3l0RUwlUI9T5XHBW2m\", \"Genre\": \"['cali rap']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 89.0, \"Danceability\": 0.701, \"Energy\": 0.716, \"Loudness\": -3.671, \"Speechiness\": 0.0361, \"Acousticness\": 0.174, \"Liveness\": 0.324, \"Tempo\": 91.007, \"Duration (ms)\": 140533.0, \"Valence\": 0.732, \"Chord\": \"G\"}, {\"Index\": 48, \"Highest Charting Position\": 48, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Entre Nosotros\", \"Streams\": 10215216, \"Artist\": \"Tiago PZK, LIT killah\", \"Artist Followers\": 375865.0, \"Song ID\": \"6w8yBI2vthyN9UnwO4UBWb\", \"Genre\": \"['trap argentino']\", \"Release Date\": \"2021-07-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 89.0, \"Danceability\": 0.729, \"Energy\": 0.513, \"Loudness\": -6.345, \"Speechiness\": 0.0455, \"Acousticness\": 0.494, \"Liveness\": 0.137, \"Tempo\": 170.064, \"Duration (ms)\": 192353.0, \"Valence\": 0.789, \"Chord\": \"F\"}, {\"Index\": 49, \"Highest Charting Position\": 29, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Fiel - Remix\", \"Streams\": 10032746, \"Artist\": \"Wisin, Jhay Cortez, Anuel AA, Los Legendarios, Myke Towers\", \"Artist Followers\": 6929075.0, \"Song ID\": \"43qcs9NpJhDxtG91zxFkj7\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 89.0, \"Danceability\": 0.839, \"Energy\": 0.711, \"Loudness\": -4.733, \"Speechiness\": 0.0473, \"Acousticness\": 0.398, \"Liveness\": 0.118, \"Tempo\": 97.99, \"Duration (ms)\": 349547.0, \"Valence\": 0.573, \"Chord\": \"F#/Gb\"}, {\"Index\": 50, \"Highest Charting Position\": 20, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Build a Bitch\", \"Streams\": 9841998, \"Artist\": \"Bella Poarch\", \"Artist Followers\": 389076.0, \"Song ID\": \"7BoobGhD4x5K96Me0hqC8Q\", \"Genre\": \"[]\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 89.0, \"Danceability\": 0.855, \"Energy\": 0.463, \"Loudness\": -7.454, \"Speechiness\": 0.0367, \"Acousticness\": 0.217, \"Liveness\": 0.347, \"Tempo\": 102.931, \"Duration (ms)\": 122773.0, \"Valence\": 0.866, \"Chord\": \"D#/Eb\"}, {\"Index\": 51, \"Highest Charting Position\": 19, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Nicky Jam: Bzrp Music Sessions, Vol. 41\", \"Streams\": 9799701, \"Artist\": \"Bizarrap, Nicky Jam\", \"Artist Followers\": 3126961.0, \"Song ID\": \"03LfOYi0icz4souspZVVhq\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2021-06-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 88.0, \"Danceability\": 0.627, \"Energy\": 0.849, \"Loudness\": -3.167, \"Speechiness\": 0.153, \"Acousticness\": 0.0913, \"Liveness\": 0.145, \"Tempo\": 89.907, \"Duration (ms)\": 158087.0, \"Valence\": 0.818, \"Chord\": \"C#/Db\"}, {\"Index\": 52, \"Highest Charting Position\": 52, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Tiroteo - Remix\", \"Streams\": 9781153, \"Artist\": \"Marc Segu\\u00ed, Rauw Alejandro, Pol Granch\", \"Artist Followers\": 45362.0, \"Song ID\": \"4OwhwvKESFtuu06dTgct7i\", \"Genre\": \"[]\", \"Release Date\": \"2021-04-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 88.0, \"Danceability\": 0.75, \"Energy\": 0.522, \"Loudness\": -7.018, \"Speechiness\": 0.0293, \"Acousticness\": 0.282, \"Liveness\": 0.0743, \"Tempo\": 110.427, \"Duration (ms)\": 321556.0, \"Valence\": 0.601, \"Chord\": \"A\"}, {\"Index\": 53, \"Highest Charting Position\": 19, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"NDA\", \"Streams\": 9635619, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47014200.0, \"Song ID\": \"38GBNKZUhfBkk3oNlWzRYd\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-07-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 84.0, \"Danceability\": 0.765, \"Energy\": 0.373, \"Loudness\": -9.921, \"Speechiness\": 0.0713, \"Acousticness\": 0.341, \"Liveness\": 0.112, \"Tempo\": 85.016, \"Duration (ms)\": 195777.0, \"Valence\": 0.554, \"Chord\": \"G#/Ab\"}, {\"Index\": 54, \"Highest Charting Position\": 40, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Rasputin\", \"Streams\": 9600707, \"Artist\": \"Majestic, Boney M.\", \"Artist Followers\": 32178.0, \"Song ID\": \"6FO4K7MrMoYkc5BlpX5LNV\", \"Genre\": \"['house', 'pop dance', 'uk dance']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 49.0, \"Danceability\": 0.83, \"Energy\": 0.839, \"Loudness\": -6.985, \"Speechiness\": 0.0699, \"Acousticness\": 0.00201, \"Liveness\": 0.0353, \"Tempo\": 128.012, \"Duration (ms)\": 345543.0, \"Valence\": 0.59, \"Chord\": \"F#/Gb\"}, {\"Index\": 55, \"Highest Charting Position\": 52, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Leave Before You Love Me (with Jonas Brothers)\", \"Streams\": 9428494, \"Artist\": \"Marshmello\", \"Artist Followers\": 31541310.0, \"Song ID\": \"4qu63nuBpdn0qHUHuObEj1\", \"Genre\": \"['brostep', 'edm', 'pop', 'pop dance', 'progressive electro house']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\", \"Popularity\": 89.0, \"Danceability\": 0.721, \"Energy\": 0.738, \"Loudness\": -4.77, \"Speechiness\": 0.0403, \"Acousticness\": 0.00226, \"Liveness\": 0.118, \"Tempo\": 119.976, \"Duration (ms)\": 154983.0, \"Valence\": 0.637, \"Chord\": \"G\"}, {\"Index\": 56, \"Highest Charting Position\": 56, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Freaks\", \"Streams\": 9319465, \"Artist\": \"Surf Curse\", \"Artist Followers\": 495226.0, \"Song ID\": \"7EkWXAI1wn8Ii883ecd9xr\", \"Genre\": \"['dreamo', 'indie surf', 'surf punk', 'vegas indie']\", \"Release Date\": \"2021-05-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 89.0, \"Danceability\": 0.345, \"Energy\": 0.941, \"Loudness\": -9.918, \"Speechiness\": 0.0466, \"Acousticness\": 3.84e-05, \"Liveness\": 0.0511, \"Tempo\": 179.626, \"Duration (ms)\": 147062.0, \"Valence\": 0.407, \"Chord\": \"A\"}, {\"Index\": 57, \"Highest Charting Position\": 57, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Meu Peda\\u00e7o de Pecado\", \"Streams\": 9206366, \"Artist\": \"Jo\\u00e3o Gomes\", \"Artist Followers\": 409173.0, \"Song ID\": \"2kJRlOyrxsy7Ot3c5TZ8Q6\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 83.0, \"Danceability\": 0.668, \"Energy\": 0.887, \"Loudness\": -4.404, \"Speechiness\": 0.0564, \"Acousticness\": 0.369, \"Liveness\": 0.257, \"Tempo\": 151.92, \"Duration (ms)\": 157176.0, \"Valence\": 0.907, \"Chord\": \"B\"}, {\"Index\": 58, \"Highest Charting Position\": 31, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"2/Catorce\", \"Streams\": 9086979, \"Artist\": \"Rauw Alejandro, Mr. Naisgai\", \"Artist Followers\": 6080597.0, \"Song ID\": \"71R8HJxQk5qMiRstrlXN9t\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2021-02-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 87.0, \"Danceability\": 0.54, \"Energy\": 0.455, \"Loudness\": -5.988, \"Speechiness\": 0.224, \"Acousticness\": 0.675, \"Liveness\": 0.12, \"Tempo\": 83.876, \"Duration (ms)\": 212032.0, \"Valence\": 0.432, \"Chord\": \"D#/Eb\"}, {\"Index\": 59, \"Highest Charting Position\": 34, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Beautiful Mistakes (feat. Megan Thee Stallion)\", \"Streams\": 9048966, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32262679.0, \"Song ID\": \"5zFglKYiknIxks8geR8rcL\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 88.0, \"Danceability\": 0.713, \"Energy\": 0.676, \"Loudness\": -5.483, \"Speechiness\": 0.027, \"Acousticness\": 0.0377, \"Liveness\": 0.154, \"Tempo\": 99.048, \"Duration (ms)\": 227395.0, \"Valence\": 0.721, \"Chord\": \"A#/Bb\"}, {\"Index\": 60, \"Highest Charting Position\": 31, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Run\", \"Streams\": 9017356, \"Artist\": \"OneRepublic\", \"Artist Followers\": 12169108.0, \"Song ID\": \"2UbVnbE5FH6008mAm6Mmgw\", \"Genre\": \"['dance pop', 'piano rock', 'pop', 'pop rock']\", \"Release Date\": \"2021-05-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2020-09-25--2020-10-02\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 88.0, \"Danceability\": 0.682, \"Energy\": 0.72, \"Loudness\": -8.173, \"Speechiness\": 0.0381, \"Acousticness\": 0.326, \"Liveness\": 0.148, \"Tempo\": 117.003, \"Duration (ms)\": 169011.0, \"Valence\": 0.673, \"Chord\": \"B\"}, {\"Index\": 61, \"Highest Charting Position\": 46, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Thot Shit\", \"Streams\": 8977336, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4787261.0, \"Song ID\": \"5zNW5ARjYhJQJz1AChP33n\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 88.0, \"Danceability\": 0.95, \"Energy\": 0.693, \"Loudness\": -3.424, \"Speechiness\": 0.0898, \"Acousticness\": 0.0133, \"Liveness\": 0.173, \"Tempo\": 130.02, \"Duration (ms)\": 184635.0, \"Valence\": 0.891, \"Chord\": \"A\"}, {\"Index\": 62, \"Highest Charting Position\": 26, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Your Love (9PM)\", \"Streams\": 8935418, \"Artist\": \"ATB, Topic, A7S\", \"Artist Followers\": 291777.0, \"Song ID\": \"5YaskwnGDZFDRipaqzbwQx\", \"Genre\": \"['german dance', 'german techno', 'german trance', 'trance']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 88.0, \"Danceability\": 0.669, \"Energy\": 0.784, \"Loudness\": -5.603, \"Speechiness\": 0.112, \"Acousticness\": 0.194, \"Liveness\": 0.115, \"Tempo\": 125.993, \"Duration (ms)\": 150053.0, \"Valence\": 0.517, \"Chord\": \"G\"}, {\"Index\": 63, \"Highest Charting Position\": 9, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"brutal\", \"Streams\": 8881356, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"6SRsiMl7w1USE4mFqrOhHC\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 89.0, \"Danceability\": 0.672, \"Energy\": 0.526, \"Loudness\": -6.446, \"Speechiness\": 0.0599, \"Acousticness\": 0.0311, \"Liveness\": 0.28, \"Tempo\": 123.999, \"Duration (ms)\": 143747.0, \"Valence\": 0.28, \"Chord\": \"E\"}, {\"Index\": 64, \"Highest Charting Position\": 2, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Save Your Tears\", \"Streams\": 8843110, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"37BZB0z9T8Xu7U3e65qxFy\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 94.0, \"Danceability\": 0.65, \"Energy\": 0.825, \"Loudness\": -4.645, \"Speechiness\": 0.0325, \"Acousticness\": 0.0215, \"Liveness\": 0.0936, \"Tempo\": 118.091, \"Duration (ms)\": 191014.0, \"Valence\": 0.593, \"Chord\": \"C\"}, {\"Index\": 65, \"Highest Charting Position\": 8, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Heartbreak Anniversary\", \"Streams\": 8832945, \"Artist\": \"Giveon\", \"Artist Followers\": 1398563.0, \"Song ID\": \"3FAJ6O0NOHQV8Mc5Ri6ENp\", \"Genre\": \"['pop', 'r&b']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 87.0, \"Danceability\": 0.449, \"Energy\": 0.465, \"Loudness\": -8.964, \"Speechiness\": 0.0791, \"Acousticness\": 0.524, \"Liveness\": 0.303, \"Tempo\": 89.087, \"Duration (ms)\": 198371.0, \"Valence\": 0.543, \"Chord\": \"C\"}, {\"Index\": 66, \"Highest Charting Position\": 2, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Don't Start Now\", \"Streams\": 8821971, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 1250353.0, \"Song ID\": \"7njGslFmqBmOSSOpTyZCs9\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.793, \"Energy\": 0.793, \"Loudness\": -4.521, \"Speechiness\": 0.083, \"Acousticness\": 0.0123, \"Liveness\": 0.0951, \"Tempo\": 123.95, \"Duration (ms)\": 183290.0, \"Valence\": 0.679, \"Chord\": \"B\"}, {\"Index\": 67, \"Highest Charting Position\": 33, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Dinero\", \"Streams\": 8564775, \"Artist\": \"Trinidad Cardona\", \"Artist Followers\": 116817.0, \"Song ID\": \"3ggtU1ZOKO8ZNiqPNyXGcm\", \"Genre\": \"[]\", \"Release Date\": \"2018-02-02\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 87.0, \"Danceability\": 0.708, \"Energy\": 0.782, \"Loudness\": -4.687, \"Speechiness\": 0.0674, \"Acousticness\": 0.00772, \"Liveness\": 0.107, \"Tempo\": 119.997, \"Duration (ms)\": 160880.0, \"Valence\": 0.484, \"Chord\": \"D\"}, {\"Index\": 68, \"Highest Charting Position\": 35, \"Number of Times Charted\": 48, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Sweater Weather\", \"Streams\": 8564017, \"Artist\": \"The Neighbourhood\", \"Artist Followers\": 6662605.0, \"Song ID\": \"2QjOHCTQ1Jl3zawyYOpxh6\", \"Genre\": \"['modern alternative rock', 'modern rock', 'pop']\", \"Release Date\": \"2013-04-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 87.0, \"Danceability\": 0.612, \"Energy\": 0.807, \"Loudness\": -2.81, \"Speechiness\": 0.0336, \"Acousticness\": 0.0495, \"Liveness\": 0.101, \"Tempo\": 124.053, \"Duration (ms)\": 240400.0, \"Valence\": 0.398, \"Chord\": \"A#/Bb\"}, {\"Index\": 69, \"Highest Charting Position\": 69, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Sobrio\", \"Streams\": 8514480, \"Artist\": \"Maluma\", \"Artist Followers\": 26769304.0, \"Song ID\": \"4HzqWEdAbzcVFDv0pvxV4w\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-07-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 87.0, \"Danceability\": 0.762, \"Energy\": 0.77, \"Loudness\": -2.758, \"Speechiness\": 0.223, \"Acousticness\": 0.138, \"Liveness\": 0.15, \"Tempo\": 177.998, \"Duration (ms)\": 201181.0, \"Valence\": 0.631, \"Chord\": \"F\"}, {\"Index\": 70, \"Highest Charting Position\": 12, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Someone You Loved\", \"Streams\": 8490162, \"Artist\": \"Lewis Capaldi\", \"Artist Followers\": 8384096.0, \"Song ID\": \"7qEHsqek33rTcFNT9PFqLf\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.501, \"Energy\": 0.405, \"Loudness\": -5.679, \"Speechiness\": 0.0319, \"Acousticness\": 0.751, \"Liveness\": 0.105, \"Tempo\": 109.891, \"Duration (ms)\": 182161.0, \"Valence\": 0.446, \"Chord\": \"C#/Db\"}, {\"Index\": 71, \"Highest Charting Position\": 71, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Over The Top (feat. Drake)\", \"Streams\": 8269753, \"Artist\": \"Smiley\", \"Artist Followers\": 26131.0, \"Song ID\": \"3yaYgjEFkRw3PVjW9mV1TO\", \"Genre\": \"['canadian hip hop', 'toronto rap']\", \"Release Date\": \"2021-07-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 83.0, \"Danceability\": 0.833, \"Energy\": 0.498, \"Loudness\": -5.196, \"Speechiness\": 0.117, \"Acousticness\": 0.0493, \"Liveness\": 0.119, \"Tempo\": 139.928, \"Duration (ms)\": 153406.0, \"Valence\": 0.259, \"Chord\": \"A#/Bb\"}, {\"Index\": 72, \"Highest Charting Position\": 72, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"2055\", \"Streams\": 8133401, \"Artist\": \"Sleepy Hallow\", \"Artist Followers\": 408696.0, \"Song ID\": \"4XvcHTUfIlWfyJTRG0aqlo\", \"Genre\": \"['brooklyn drill', 'nyc rap']\", \"Release Date\": \"2021-06-02\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 85.0, \"Danceability\": 0.829, \"Energy\": 0.512, \"Loudness\": -5.865, \"Speechiness\": 0.187, \"Acousticness\": 0.492, \"Liveness\": 0.12, \"Tempo\": 80.511, \"Duration (ms)\": 123987.0, \"Valence\": 0.638, \"Chord\": \"F#/Gb\"}, {\"Index\": 73, \"Highest Charting Position\": 33, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"EL MAKINON\", \"Streams\": 8102107, \"Artist\": \"KAROL G, Mariah Angeliq\", \"Artist Followers\": 17775316.0, \"Song ID\": \"2FSGUA0gFgGeQdprjtGM2M\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 87.0, \"Danceability\": 0.635, \"Energy\": 0.706, \"Loudness\": -3.224, \"Speechiness\": 0.125, \"Acousticness\": 0.256, \"Liveness\": 0.108, \"Tempo\": 88.863, \"Duration (ms)\": 209160.0, \"Valence\": 0.443, \"Chord\": \"F\"}, {\"Index\": 74, \"Highest Charting Position\": 74, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Loco\", \"Streams\": 8093413, \"Artist\": \"Justin Quiles, Chimbala, Zion & Lennox\", \"Artist Followers\": 2895789.0, \"Song ID\": \"6PDlkWmrq2ZKiUuFt2aQsH\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 87.0, \"Danceability\": 0.77, \"Energy\": 0.899, \"Loudness\": -2.981, \"Speechiness\": 0.0494, \"Acousticness\": 0.222, \"Liveness\": 0.0894, \"Tempo\": 128.05, \"Duration (ms)\": 231604.0, \"Valence\": 0.851, \"Chord\": \"G#/Ab\"}, {\"Index\": 75, \"Highest Charting Position\": 75, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Love Tonight - Edit\", \"Streams\": 8006336, \"Artist\": \"Shouse\", \"Artist Followers\": 27116.0, \"Song ID\": \"6OufwUcCqo81guU2jAlDVP\", \"Genre\": \"['aussietronica']\", \"Release Date\": \"2017-12-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 87.0, \"Danceability\": 0.727, \"Energy\": 0.681, \"Loudness\": -7.114, \"Speechiness\": 0.0265, \"Acousticness\": 0.00214, \"Liveness\": 0.0861, \"Tempo\": 123.028, \"Duration (ms)\": 241970.0, \"Valence\": 0.448, \"Chord\": \"F\"}, {\"Index\": 76, \"Highest Charting Position\": 12, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"ZITTI E BUONI\", \"Streams\": 7975148, \"Artist\": \"M\\u00e5neskin\", \"Artist Followers\": 3377762.0, \"Song ID\": \"776AftMmFFAWUIEAb3lHhw\", \"Genre\": \"['indie rock italiano', 'italian pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-03-05--2021-03-12\", \"Popularity\": 86.0, \"Danceability\": 0.625, \"Energy\": 0.939, \"Loudness\": -3.115, \"Speechiness\": 0.0669, \"Acousticness\": 0.00138, \"Liveness\": 0.424, \"Tempo\": 102.999, \"Duration (ms)\": 194787.0, \"Valence\": 0.644, \"Chord\": \"E\"}, {\"Index\": 77, \"Highest Charting Position\": 2, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"telepat\\u00eda\", \"Streams\": 7912399, \"Artist\": \"Kali Uchis\", \"Artist Followers\": 1999954.0, \"Song ID\": \"6tDDoYIxWvMLTdKpjFkc1B\", \"Genre\": \"['colombian pop', 'pop']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 88.0, \"Danceability\": 0.653, \"Energy\": 0.524, \"Loudness\": -9.016, \"Speechiness\": 0.0502, \"Acousticness\": 0.112, \"Liveness\": 0.203, \"Tempo\": 83.97, \"Duration (ms)\": 160191.0, \"Valence\": 0.553, \"Chord\": \"B\"}, {\"Index\": 78, \"Highest Charting Position\": 9, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Botella Tras Botella\", \"Streams\": 7735223, \"Artist\": \"Gera MX, Christian Nodal\", \"Artist Followers\": 2043294.0, \"Song ID\": \"2MnLkFqY9Rpg9s3Zv6ZJdK\", \"Genre\": \"['mexican hip hop', 'rap conciencia']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 87.0, \"Danceability\": 0.727, \"Energy\": 0.546, \"Loudness\": -4.572, \"Speechiness\": 0.0437, \"Acousticness\": 0.656, \"Liveness\": 0.122, \"Tempo\": 106.891, \"Duration (ms)\": 197333.0, \"Valence\": 0.69, \"Chord\": \"C\"}, {\"Index\": 79, \"Highest Charting Position\": 7, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Fiel\", \"Streams\": 7717211, \"Artist\": \"Los Legendarios, Wisin, Jhay Cortez\", \"Artist Followers\": 31488.0, \"Song ID\": \"7Bk0uXKk1uPT0XuQbpFzvs\", \"Genre\": \"['reggaeton', 'trap latino']\", \"Release Date\": \"2021-02-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 88.0, \"Danceability\": 0.849, \"Energy\": 0.701, \"Loudness\": -4.407, \"Speechiness\": 0.06, \"Acousticness\": 0.407, \"Liveness\": 0.112, \"Tempo\": 98.005, \"Duration (ms)\": 261667.0, \"Valence\": 0.505, \"Chord\": \"F#/Gb\"}, {\"Index\": 80, \"Highest Charting Position\": 1, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Dance Monkey\", \"Streams\": 7687058, \"Artist\": \"Tones And I\", \"Artist Followers\": 2819593.0, \"Song ID\": \"2XU0oxnq2qxCpomAAuJY8K\", \"Genre\": \"['australian pop', 'pop']\", \"Release Date\": \"2019-10-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.824, \"Energy\": 0.588, \"Loudness\": -6.4, \"Speechiness\": 0.0924, \"Acousticness\": 0.692, \"Liveness\": 0.149, \"Tempo\": 98.027, \"Duration (ms)\": 209438.0, \"Valence\": 0.513, \"Chord\": \"F#/Gb\"}, {\"Index\": 81, \"Highest Charting Position\": 7, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"WITHOUT YOU\", \"Streams\": 7642130, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2230022.0, \"Song ID\": \"27OeeYzk6klgBh83TSvGMA\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 87.0, \"Danceability\": 0.662, \"Energy\": 0.413, \"Loudness\": -7.357, \"Speechiness\": 0.0299, \"Acousticness\": 0.213, \"Liveness\": 0.134, \"Tempo\": 93.005, \"Duration (ms)\": 161385.0, \"Valence\": 0.467, \"Chord\": \"C\"}, {\"Index\": 82, \"Highest Charting Position\": 6, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Wants and Needs (feat. Lil Baby)\", \"Streams\": 7637626, \"Artist\": \"Drake\", \"Artist Followers\": 56308172.0, \"Song ID\": \"65OVbaJR5O1RmwOQx0875b\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 87.0, \"Danceability\": 0.578, \"Energy\": 0.449, \"Loudness\": -6.349, \"Speechiness\": 0.286, \"Acousticness\": 0.0618, \"Liveness\": 0.119, \"Tempo\": 136.006, \"Duration (ms)\": 192956.0, \"Valence\": 0.1, \"Chord\": \"C#/Db\"}, {\"Index\": 83, \"Highest Charting Position\": 83, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Bezos I\", \"Streams\": 7516291, \"Artist\": \"Bo Burnham\", \"Artist Followers\": 1042079.0, \"Song ID\": \"0Kdj7nwaYQmvhxnqZaIQuW\", \"Genre\": \"['comic']\", \"Release Date\": \"2021-06-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 84.0, \"Danceability\": 0.694, \"Energy\": 0.948, \"Loudness\": -5.307, \"Speechiness\": 0.0361, \"Acousticness\": 0.00936, \"Liveness\": 0.139, \"Tempo\": 115.044, \"Duration (ms)\": 58149.0, \"Valence\": 0.705, \"Chord\": \"D\"}, {\"Index\": 84, \"Highest Charting Position\": 76, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Love Again\", \"Streams\": 7465445, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 1250353.0, \"Song ID\": \"2sN1pMv6d2t5GlvN6IBMlK\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2020-03-27--2020-04-03\", \"Popularity\": 0.0, \"Danceability\": 0.659, \"Energy\": 0.667, \"Loudness\": -4.668, \"Speechiness\": 0.0339, \"Acousticness\": 0.00173, \"Liveness\": 0.1, \"Tempo\": 115.982, \"Duration (ms)\": 258004.0, \"Valence\": 0.468, \"Chord\": \"B\"}, {\"Index\": 85, \"Highest Charting Position\": 32, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Goosebumps - Remix\", \"Streams\": 7452633, \"Artist\": \"Travis Scott, HVME\", \"Artist Followers\": 17719446.0, \"Song ID\": \"5uEYRdEIh9Bo4fpjDd4Na9\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 87.0, \"Danceability\": 0.841, \"Energy\": 0.593, \"Loudness\": -7.846, \"Speechiness\": 0.0379, \"Acousticness\": 0.418, \"Liveness\": 0.124, \"Tempo\": 124.917, \"Duration (ms)\": 162803.0, \"Valence\": 0.808, \"Chord\": \"C#/Db\"}, {\"Index\": 86, \"Highest Charting Position\": 11, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Head & Heart (feat. MNEK)\", \"Streams\": 7434252, \"Artist\": \"Joel Corry\", \"Artist Followers\": 207547.0, \"Song ID\": \"6cx06DFPPHchuUAcTxznu9\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance', 'tropical house', 'uk dance']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 87.0, \"Danceability\": 0.734, \"Energy\": 0.874, \"Loudness\": -3.158, \"Speechiness\": 0.0662, \"Acousticness\": 0.168, \"Liveness\": 0.0489, \"Tempo\": 122.953, \"Duration (ms)\": 166028.0, \"Valence\": 0.905, \"Chord\": \"G#/Ab\"}, {\"Index\": 87, \"Highest Charting Position\": 42, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"BED\", \"Streams\": 7383369, \"Artist\": \"Joel Corry, RAYE, David Guetta\", \"Artist Followers\": 207547.0, \"Song ID\": \"0siYMEsGrzzzlWLXK5zJfS\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance', 'tropical house', 'uk dance']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 87.0, \"Danceability\": 0.671, \"Energy\": 0.782, \"Loudness\": -4.593, \"Speechiness\": 0.0341, \"Acousticness\": 0.0142, \"Liveness\": 0.333, \"Tempo\": 123.989, \"Duration (ms)\": 178088.0, \"Valence\": 0.618, \"Chord\": \"F#/Gb\"}, {\"Index\": 88, \"Highest Charting Position\": 78, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Iko Iko (My Bestie)\", \"Streams\": 7381585, \"Artist\": \"Justin Wellington, Small Jam\", \"Artist Followers\": 18228.0, \"Song ID\": \"7MC4XR9M9amdmKQr2iDF7i\", \"Genre\": \"['melanesian pop', 'pacific islands pop', 'png pop']\", \"Release Date\": \"2019-06-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 87.0, \"Danceability\": 0.862, \"Energy\": 0.753, \"Loudness\": -5.356, \"Speechiness\": 0.0625, \"Acousticness\": 0.131, \"Liveness\": 0.077, \"Tempo\": 105.039, \"Duration (ms)\": 182857.0, \"Valence\": 0.827, \"Chord\": \"F\"}, {\"Index\": 89, \"Highest Charting Position\": 89, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Better Believe\", \"Streams\": 7365053, \"Artist\": \"Belly, The Weeknd, Young Thug\", \"Artist Followers\": 203972.0, \"Song ID\": \"3zs87EV3EZSh2UpiXxT52Y\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'pop rap', 'rap', 'southern hip hop', 'trap', 'trap soul', 'underground hip hop']\", \"Release Date\": \"2021-07-22\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 80.0, \"Danceability\": 0.797, \"Energy\": 0.573, \"Loudness\": -7.85, \"Speechiness\": 0.319, \"Acousticness\": 0.159, \"Liveness\": 0.144, \"Tempo\": 124.995, \"Duration (ms)\": 206629.0, \"Valence\": 0.445, \"Chord\": \"C\"}, {\"Index\": 90, \"Highest Charting Position\": 23, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Arcade\", \"Streams\": 7353795, \"Artist\": \"Duncan Laurence\", \"Artist Followers\": 287361.0, \"Song ID\": \"1Xi84slp6FryDSCbzq4UCD\", \"Genre\": \"['dutch pop']\", \"Release Date\": \"2019-03-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 84.0, \"Danceability\": 0.45, \"Energy\": 0.329, \"Loudness\": -12.603, \"Speechiness\": 0.0441, \"Acousticness\": 0.818, \"Liveness\": 0.135, \"Tempo\": 71.884, \"Duration (ms)\": 183624.0, \"Valence\": 0.266, \"Chord\": \"A\"}, {\"Index\": 91, \"Highest Charting Position\": 55, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"512\", \"Streams\": 7336542, \"Artist\": \"Mora, Jhay Cortez\", \"Artist Followers\": 151486.0, \"Song ID\": \"5jzEwSyyymBlf1fa1o39T2\", \"Genre\": \"['reggaeton', 'trap latino']\", \"Release Date\": \"2021-02-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 87.0, \"Danceability\": 0.818, \"Energy\": 0.673, \"Loudness\": -7.542, \"Speechiness\": 0.148, \"Acousticness\": 0.348, \"Liveness\": 0.172, \"Tempo\": 87.961, \"Duration (ms)\": 193636.0, \"Valence\": 0.695, \"Chord\": \"E\"}, {\"Index\": 92, \"Highest Charting Position\": 1, \"Number of Times Charted\": 40, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"positions\", \"Streams\": 7244853, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67158068.0, \"Song ID\": \"35mvY5S1H3J2QZyna3TFe0\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 86.0, \"Danceability\": 0.737, \"Energy\": 0.802, \"Loudness\": -4.771, \"Speechiness\": 0.0878, \"Acousticness\": 0.468, \"Liveness\": 0.0931, \"Tempo\": 144.015, \"Duration (ms)\": 172325.0, \"Valence\": 0.682, \"Chord\": \"C\"}, {\"Index\": 93, \"Highest Charting Position\": 6, \"Number of Times Charted\": 84, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Circles\", \"Streams\": 7156162, \"Artist\": \"Post Malone\", \"Artist Followers\": 33651775.0, \"Song ID\": \"21jGcNKet2qwijlDFuPiPb\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 87.0, \"Danceability\": 0.695, \"Energy\": 0.762, \"Loudness\": -3.497, \"Speechiness\": 0.0395, \"Acousticness\": 0.192, \"Liveness\": 0.0863, \"Tempo\": 120.042, \"Duration (ms)\": 215280.0, \"Valence\": 0.553, \"Chord\": \"C\"}, {\"Index\": 94, \"Highest Charting Position\": 94, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Blaues Licht\", \"Streams\": 7084292, \"Artist\": \"RAF Camora, Bonez MC\", \"Artist Followers\": 1329531.0, \"Song ID\": \"08EPQiLMyGB8GJX2EiVoCM\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 78.0, \"Danceability\": 0.819, \"Energy\": 0.835, \"Loudness\": -4.899, \"Speechiness\": 0.102, \"Acousticness\": 0.398, \"Liveness\": 0.252, \"Tempo\": 144.955, \"Duration (ms)\": 144264.0, \"Valence\": 0.703, \"Chord\": \"G#/Ab\"}, {\"Index\": 95, \"Highest Charting Position\": 75, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Ram Pam Pam\", \"Streams\": 7064003, \"Artist\": \"Natti Natasha, Becky G\", \"Artist Followers\": 6341942.0, \"Song ID\": \"4DHDIdeayp8xvlyg22wREO\", \"Genre\": \"['latin', 'latin pop', 'rap latina', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-04-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 86.0, \"Danceability\": 0.908, \"Energy\": 0.813, \"Loudness\": -2.749, \"Speechiness\": 0.0777, \"Acousticness\": 0.305, \"Liveness\": 0.278, \"Tempo\": 97.018, \"Duration (ms)\": 200785.0, \"Valence\": 0.924, \"Chord\": \"F\"}, {\"Index\": 96, \"Highest Charting Position\": 96, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"In Da Getto\", \"Streams\": 6984262, \"Artist\": \"J Balvin, Skrillex\", \"Artist Followers\": 1250353.0, \"Song ID\": \"5lGtPshEJlsJgmqKLi41LY\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 2.0, \"Danceability\": 0.915, \"Energy\": 0.72, \"Loudness\": -3.126, \"Speechiness\": 0.0459, \"Acousticness\": 0.025, \"Liveness\": 0.0942, \"Tempo\": 126.986, \"Duration (ms)\": 131067.0, \"Valence\": 0.631, \"Chord\": \"G#/Ab\"}, {\"Index\": 97, \"Highest Charting Position\": 97, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Woman\", \"Streams\": 6858466, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"6Uj1ctrBOjOas8xZXGqKk4\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-06-25--2021-07-02\", \"Popularity\": 86.0, \"Danceability\": 0.824, \"Energy\": 0.764, \"Loudness\": -4.175, \"Speechiness\": 0.0854, \"Acousticness\": 0.0888, \"Liveness\": 0.117, \"Tempo\": 107.998, \"Duration (ms)\": 172627.0, \"Valence\": 0.881, \"Chord\": \"F\"}, {\"Index\": 98, \"Highest Charting Position\": 60, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"t r a n s p a r e n t s o u l feat. Travis Barker\", \"Streams\": 6853994, \"Artist\": \"WILLOW\", \"Artist Followers\": 1521837.0, \"Song ID\": \"1QL7nSDZCwZMnbisV4KOXt\", \"Genre\": \"['afrofuturism', 'dance pop', 'electropop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2021-04-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 85.0, \"Danceability\": 0.39, \"Energy\": 0.83, \"Loudness\": -5.201, \"Speechiness\": 0.0563, \"Acousticness\": 0.0021, \"Liveness\": 0.156, \"Tempo\": 90.021, \"Duration (ms)\": 168030.0, \"Valence\": 0.191, \"Chord\": \"B\"}, {\"Index\": 99, \"Highest Charting Position\": 99, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Clash (feat. Stormzy)\", \"Streams\": 6825463, \"Artist\": \"Dave\", \"Artist Followers\": 1427540.0, \"Song ID\": \"2oUwMN5VfdGX10XeQJLBBi\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2021-07-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-09--2021-07-16\", \"Popularity\": 79.0, \"Danceability\": 0.871, \"Energy\": 0.519, \"Loudness\": -6.549, \"Speechiness\": 0.258, \"Acousticness\": 0.313, \"Liveness\": 0.0869, \"Tempo\": 140.013, \"Duration (ms)\": 251733.0, \"Valence\": 0.532, \"Chord\": \"D\"}, {\"Index\": 100, \"Highest Charting Position\": 22, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Before You Go\", \"Streams\": 6813800, \"Artist\": \"Lewis Capaldi\", \"Artist Followers\": 8384096.0, \"Song ID\": \"2gMXnyrvIjhVBUZwvLZDMP\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.459, \"Energy\": 0.575, \"Loudness\": -4.858, \"Speechiness\": 0.0573, \"Acousticness\": 0.604, \"Liveness\": 0.0885, \"Tempo\": 111.881, \"Duration (ms)\": 215107.0, \"Valence\": 0.183, \"Chord\": \"D#/Eb\"}, {\"Index\": 101, \"Highest Charting Position\": 52, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Levitating\", \"Streams\": 6799831, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"463CkQjx2Zk1yXoBuierM9\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-10-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 89.0, \"Danceability\": 0.702, \"Energy\": 0.825, \"Loudness\": -3.787, \"Speechiness\": 0.0601, \"Acousticness\": 0.00883, \"Liveness\": 0.0674, \"Tempo\": 102.977, \"Duration (ms)\": 203064.0, \"Valence\": 0.915, \"Chord\": \"F#/Gb\"}, {\"Index\": 102, \"Highest Charting Position\": 85, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Reckless\", \"Streams\": 6711375, \"Artist\": \"Madison Beer\", \"Artist Followers\": 3363988.0, \"Song ID\": \"5ajjAnNRh8bxFvaVHzpPjh\", \"Genre\": \"['alt z', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 86.0, \"Danceability\": 0.386, \"Energy\": 0.426, \"Loudness\": -6.642, \"Speechiness\": 0.0363, \"Acousticness\": 0.807, \"Liveness\": 0.14, \"Tempo\": 180.104, \"Duration (ms)\": 203385.0, \"Valence\": 0.261, \"Chord\": \"D#/Eb\"}, {\"Index\": 103, \"Highest Charting Position\": 103, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"No Me Conocen (Remix) [con DUKI, Rei & Tiago PZK]\", \"Streams\": 6709106, \"Artist\": \"BANDIDO\", \"Artist Followers\": 16074.0, \"Song ID\": \"7COGuXyTr12KvdaYXMqheC\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 85.0, \"Danceability\": 0.769, \"Energy\": 0.812, \"Loudness\": -2.088, \"Speechiness\": 0.0825, \"Acousticness\": 0.281, \"Liveness\": 0.0781, \"Tempo\": 180.003, \"Duration (ms)\": 280274.0, \"Valence\": 0.926, \"Chord\": \"C#/Db\"}, {\"Index\": 104, \"Highest Charting Position\": 88, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Believer\", \"Streams\": 6699895, \"Artist\": \"Imagine Dragons\", \"Artist Followers\": 35285425.0, \"Song ID\": \"0pqnGHJpmpxLKifKRmU6WP\", \"Genre\": \"['modern rock', 'pop', 'rock']\", \"Release Date\": \"2017-06-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.776, \"Energy\": 0.78, \"Loudness\": -4.374, \"Speechiness\": 0.128, \"Acousticness\": 0.0622, \"Liveness\": 0.081, \"Tempo\": 124.949, \"Duration (ms)\": 204347.0, \"Valence\": 0.666, \"Chord\": \"A#/Bb\"}, {\"Index\": 105, \"Highest Charting Position\": 2, \"Number of Times Charted\": 48, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Lemonade (feat. Gunna, Don Toliver & NAV)\", \"Streams\": 6697067, \"Artist\": \"Internet Money\", \"Artist Followers\": 411579.0, \"Song ID\": \"02kDW379Yfd5PzW5A6vuGt\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 82.0, \"Danceability\": 0.799, \"Energy\": 0.66, \"Loudness\": -6.153, \"Speechiness\": 0.079, \"Acousticness\": 0.256, \"Liveness\": 0.111, \"Tempo\": 140.04, \"Duration (ms)\": 195429.0, \"Valence\": 0.471, \"Chord\": \"C#/Db\"}, {\"Index\": 106, \"Highest Charting Position\": 45, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Talking to the Moon\", \"Streams\": 6660319, \"Artist\": \"Bruno Mars\", \"Artist Followers\": 32574754.0, \"Song ID\": \"161DnLWsx1i3u1JT05lzqU\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2010-10-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 83.0, \"Danceability\": 0.523, \"Energy\": 0.606, \"Loudness\": -4.754, \"Speechiness\": 0.0301, \"Acousticness\": 0.512, \"Liveness\": 0.106, \"Tempo\": 145.837, \"Duration (ms)\": 217867.0, \"Valence\": 0.065, \"Chord\": \"C#/Db\"}, {\"Index\": 107, \"Highest Charting Position\": 3, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Roses - Imanbek Remix\", \"Streams\": 6653690, \"Artist\": \"SAINt JHN\", \"Artist Followers\": 742692.0, \"Song ID\": \"0zLCBJZSiELJf02ucPP9wb\", \"Genre\": \"['melodic rap', 'pop rap', 'rap', 'slap house', 'trap']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.769, \"Energy\": 0.719, \"Loudness\": -5.472, \"Speechiness\": 0.0474, \"Acousticness\": 0.0143, \"Liveness\": 0.359, \"Tempo\": 121.955, \"Duration (ms)\": 176867.0, \"Valence\": 0.863, \"Chord\": \"G#/Ab\"}, {\"Index\": 108, \"Highest Charting Position\": 59, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Sal y Perrea\", \"Streams\": 6635076, \"Artist\": \"Sech\", \"Artist Followers\": 8758283.0, \"Song ID\": \"5u7twkeask1VIyDeNTElSU\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-04-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 86.0, \"Danceability\": 0.786, \"Energy\": 0.899, \"Loudness\": -0.515, \"Speechiness\": 0.127, \"Acousticness\": 0.192, \"Liveness\": 0.299, \"Tempo\": 90.025, \"Duration (ms)\": 216510.0, \"Valence\": 0.813, \"Chord\": \"A#/Bb\"}, {\"Index\": 109, \"Highest Charting Position\": 109, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Fulanito\", \"Streams\": 6614072, \"Artist\": \"Becky G, El Alfa\", \"Artist Followers\": 10356559.0, \"Song ID\": \"59L8x0xy8njj75vzVCPMqg\", \"Genre\": \"['dance pop', 'latin', 'latin pop', 'latin viral pop', 'pop', 'rap latina', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 86.0, \"Danceability\": 0.93, \"Energy\": 0.837, \"Loudness\": -4.632, \"Speechiness\": 0.187, \"Acousticness\": 0.256, \"Liveness\": 0.239, \"Tempo\": 111.898, \"Duration (ms)\": 158532.0, \"Valence\": 0.821, \"Chord\": \"G\"}, {\"Index\": 110, \"Highest Charting Position\": 110, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Par\\u00eds\", \"Streams\": 6584896, \"Artist\": \"Ingratax\", \"Artist Followers\": 56699.0, \"Song ID\": \"4bF2y8rR7GUjrd5LNEvej3\", \"Genre\": \"[]\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 86.0, \"Danceability\": 0.57, \"Energy\": 0.455, \"Loudness\": -5.748, \"Speechiness\": 0.0996, \"Acousticness\": 0.441, \"Liveness\": 0.0654, \"Tempo\": 167.933, \"Duration (ms)\": 151429.0, \"Valence\": 0.399, \"Chord\": \"C#/Db\"}, {\"Index\": 111, \"Highest Charting Position\": 46, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"lovely (with Khalid)\", \"Streams\": 6569547, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47014200.0, \"Song ID\": \"0u2P5u6lvoDfwTYjAADbn4\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2018-04-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.351, \"Energy\": 0.296, \"Loudness\": -10.109, \"Speechiness\": 0.0333, \"Acousticness\": 0.934, \"Liveness\": 0.095, \"Tempo\": 115.284, \"Duration (ms)\": 200186.0, \"Valence\": 0.12, \"Chord\": \"E\"}, {\"Index\": 112, \"Highest Charting Position\": 24, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Sunflower - Spider-Man: Into the Spider-Verse\", \"Streams\": 6546948, \"Artist\": \"Post Malone, Swae Lee\", \"Artist Followers\": 1250353.0, \"Song ID\": \"3KkXRkHbMCARz0aVfEt68P\", \"Genre\": \"[]\", \"Release Date\": \"2018-12-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.76, \"Energy\": 0.479, \"Loudness\": -5.574, \"Speechiness\": 0.0466, \"Acousticness\": 0.556, \"Liveness\": 0.0703, \"Tempo\": 89.911, \"Duration (ms)\": 158040.0, \"Valence\": 0.913, \"Chord\": \"D\"}, {\"Index\": 113, \"Highest Charting Position\": 113, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"double take\", \"Streams\": 6539852, \"Artist\": \"dhruv\", \"Artist Followers\": 73211.0, \"Song ID\": \"2CVChktEKBsM6v4IfdFU5k\", \"Genre\": \"['chill r&b', 'nyc pop']\", \"Release Date\": \"2019-05-24\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 86.0, \"Danceability\": 0.663, \"Energy\": 0.434, \"Loudness\": -11.177, \"Speechiness\": 0.0648, \"Acousticness\": 0.828, \"Liveness\": 0.249, \"Tempo\": 109.075, \"Duration (ms)\": 171743.0, \"Valence\": 0.225, \"Chord\": \"G#/Ab\"}, {\"Index\": 114, \"Highest Charting Position\": 9, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Streets\", \"Streams\": 6502302, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"60ynsPSSKe6O3sfwRnIBRf\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 86.0, \"Danceability\": 0.749, \"Energy\": 0.463, \"Loudness\": -8.433, \"Speechiness\": 0.0842, \"Acousticness\": 0.21, \"Liveness\": 0.338, \"Tempo\": 90.035, \"Duration (ms)\": 226987.0, \"Valence\": 0.189, \"Chord\": \"B\"}, {\"Index\": 115, \"Highest Charting Position\": 80, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"By Your Side (feat. Tom Grennan)\", \"Streams\": 6488622, \"Artist\": \"Calvin Harris\", \"Artist Followers\": 21942793.0, \"Song ID\": \"0vR2rIVORmgeKiGIgNT0fV\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'house', 'pop', 'progressive house', 'uk dance']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 85.0, \"Danceability\": 0.733, \"Energy\": 0.96, \"Loudness\": -3.597, \"Speechiness\": 0.0295, \"Acousticness\": 0.0514, \"Liveness\": 0.287, \"Tempo\": 124.01, \"Duration (ms)\": 189672.0, \"Valence\": 0.811, \"Chord\": \"G\"}, {\"Index\": 116, \"Highest Charting Position\": 116, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"MORENA\", \"Streams\": 6469500, \"Artist\": \"Luan Santana\", \"Artist Followers\": 5420471.0, \"Song ID\": \"4PQdrXMDHDPl1RczrrlADd\", \"Genre\": \"['sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2021-06-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 85.0, \"Danceability\": 0.526, \"Energy\": 0.731, \"Loudness\": -4.662, \"Speechiness\": 0.0887, \"Acousticness\": 0.18, \"Liveness\": 0.0891, \"Tempo\": 86.959, \"Duration (ms)\": 193221.0, \"Valence\": 0.476, \"Chord\": \"B\"}, {\"Index\": 117, \"Highest Charting Position\": 80, \"Number of Times Charted\": 80, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Shape of You\", \"Streams\": 6452492, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83293380.0, \"Song ID\": \"7qiZfU4dY1lWllzX7mPBI3\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2017-03-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.825, \"Energy\": 0.652, \"Loudness\": -3.183, \"Speechiness\": 0.0802, \"Acousticness\": 0.581, \"Liveness\": 0.0931, \"Tempo\": 95.977, \"Duration (ms)\": 233713.0, \"Valence\": 0.931, \"Chord\": \"C#/Db\"}, {\"Index\": 118, \"Highest Charting Position\": 9, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Se\\u00f1orita\", \"Streams\": 6317487, \"Artist\": \"Shawn Mendes, Camila Cabello\", \"Artist Followers\": 33879560.0, \"Song ID\": \"0TK2YIli7K1leLovkQiNik\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.759, \"Energy\": 0.54, \"Loudness\": -6.039, \"Speechiness\": 0.0287, \"Acousticness\": 0.037, \"Liveness\": 0.0945, \"Tempo\": 116.947, \"Duration (ms)\": 190960.0, \"Valence\": 0.75, \"Chord\": \"A\"}, {\"Index\": 119, \"Highest Charting Position\": 5, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Hold On\", \"Streams\": 6300416, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 1250353.0, \"Song ID\": \"49xx65gvlD7xXjDTavFqaJ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 0.0, \"Danceability\": 0.658, \"Energy\": 0.634, \"Loudness\": -5.797, \"Speechiness\": 0.0413, \"Acousticness\": 0.0106, \"Liveness\": 0.132, \"Tempo\": 139.98, \"Duration (ms)\": 170813.0, \"Valence\": 0.29, \"Chord\": \"C#/Db\"}, {\"Index\": 120, \"Highest Charting Position\": 99, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Perfect\", \"Streams\": 6278765, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83293380.0, \"Song ID\": \"0tgVpDi06FyKpA1z0VMD4v\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2017-03-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.599, \"Energy\": 0.448, \"Loudness\": -6.312, \"Speechiness\": 0.0232, \"Acousticness\": 0.163, \"Liveness\": 0.106, \"Tempo\": 95.05, \"Duration (ms)\": 263400.0, \"Valence\": 0.168, \"Chord\": \"G#/Ab\"}, {\"Index\": 121, \"Highest Charting Position\": 80, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"2:50 Remix\", \"Streams\": 6244011, \"Artist\": \"MYA, TINI, Duki\", \"Artist Followers\": 282045.0, \"Song ID\": \"74znaWw1hmQBusGPSOuTFy\", \"Genre\": \"['latin pop']\", \"Release Date\": \"2021-06-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 85.0, \"Danceability\": 0.818, \"Energy\": 0.812, \"Loudness\": -4.425, \"Speechiness\": 0.0475, \"Acousticness\": 0.112, \"Liveness\": 0.234, \"Tempo\": 139.966, \"Duration (ms)\": 231708.0, \"Valence\": 0.844, \"Chord\": \"A\"}, {\"Index\": 122, \"Highest Charting Position\": 2, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"LA NOCHE DE ANOCHE\", \"Streams\": 6242863, \"Artist\": \"Bad Bunny, ROSAL\\u00cdA\", \"Artist Followers\": 36142273.0, \"Song ID\": \"2XIc1pqjXV3Cr2BQUGNBck\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 86.0, \"Danceability\": 0.856, \"Energy\": 0.618, \"Loudness\": -4.892, \"Speechiness\": 0.286, \"Acousticness\": 0.0303, \"Liveness\": 0.0866, \"Tempo\": 81.993, \"Duration (ms)\": 203201.0, \"Valence\": 0.391, \"Chord\": \"G\"}, {\"Index\": 123, \"Highest Charting Position\": 1, \"Number of Times Charted\": 67, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"ROCKSTAR (feat. Roddy Ricch)\", \"Streams\": 6180056, \"Artist\": \"DaBaby\", \"Artist Followers\": 7593046.0, \"Song ID\": \"7ytR5pFWmSjzHJIeQkgog4\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 86.0, \"Danceability\": 0.746, \"Energy\": 0.69, \"Loudness\": -7.956, \"Speechiness\": 0.164, \"Acousticness\": 0.247, \"Liveness\": 0.101, \"Tempo\": 89.977, \"Duration (ms)\": 181733.0, \"Valence\": 0.497, \"Chord\": \"B\"}, {\"Index\": 124, \"Highest Charting Position\": 12, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Heather\", \"Streams\": 6164795, \"Artist\": \"Conan Gray\", \"Artist Followers\": 3794081.0, \"Song ID\": \"4xqrdfXkTW4T0RauPLv3WA\", \"Genre\": \"['alt z', 'bedroom pop', 'electropop', 'indie pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 86.0, \"Danceability\": 0.357, \"Energy\": 0.425, \"Loudness\": -7.301, \"Speechiness\": 0.0333, \"Acousticness\": 0.584, \"Liveness\": 0.322, \"Tempo\": 102.078, \"Duration (ms)\": 198040.0, \"Valence\": 0.27, \"Chord\": \"F\"}, {\"Index\": 125, \"Highest Charting Position\": 13, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"you broke me first\", \"Streams\": 6152121, \"Artist\": \"Tate McRae\", \"Artist Followers\": 1647262.0, \"Song ID\": \"45bE4HXI0AwGZXfZtMp8JR\", \"Genre\": \"['alt z', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 86.0, \"Danceability\": 0.667, \"Energy\": 0.373, \"Loudness\": -9.389, \"Speechiness\": 0.05, \"Acousticness\": 0.785, \"Liveness\": 0.0906, \"Tempo\": 124.148, \"Duration (ms)\": 169266.0, \"Valence\": 0.0823, \"Chord\": \"E\"}, {\"Index\": 126, \"Highest Charting Position\": 126, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"The Nights\", \"Streams\": 6136340, \"Artist\": \"Avicii\", \"Artist Followers\": 20270895.0, \"Song ID\": \"0ct6r3EGTcMLPtrXHDvVjc\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance']\", \"Release Date\": \"2014-01-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 85.0, \"Danceability\": 0.527, \"Energy\": 0.835, \"Loudness\": -5.298, \"Speechiness\": 0.0433, \"Acousticness\": 0.0166, \"Liveness\": 0.249, \"Tempo\": 125.983, \"Duration (ms)\": 176658.0, \"Valence\": 0.654, \"Chord\": \"F#/Gb\"}, {\"Index\": 127, \"Highest Charting Position\": 122, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Riptide\", \"Streams\": 6089242, \"Artist\": \"Vance Joy\", \"Artist Followers\": 2421254.0, \"Song ID\": \"3JvrhDOgAt6p7K8mDyZwRd\", \"Genre\": \"['folk-pop', 'modern rock', 'pop', 'pop rock']\", \"Release Date\": \"2014-09-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 78.0, \"Danceability\": 0.484, \"Energy\": 0.731, \"Loudness\": -6.694, \"Speechiness\": 0.0379, \"Acousticness\": 0.431, \"Liveness\": 0.151, \"Tempo\": 101.654, \"Duration (ms)\": 204280.0, \"Valence\": 0.51, \"Chord\": \"C#/Db\"}, {\"Index\": 128, \"Highest Charting Position\": 128, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Smells Like Teen Spirit\", \"Streams\": 6065267, \"Artist\": \"Nirvana\", \"Artist Followers\": 13261089.0, \"Song ID\": \"5ghIJDpPoe3CfHMGu71E6T\", \"Genre\": \"['grunge', 'permanent wave', 'rock']\", \"Release Date\": \"1991-09-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\", \"Popularity\": 77.0, \"Danceability\": 0.502, \"Energy\": 0.912, \"Loudness\": -4.556, \"Speechiness\": 0.0564, \"Acousticness\": 2.55e-05, \"Liveness\": 0.106, \"Tempo\": 116.761, \"Duration (ms)\": 301920.0, \"Valence\": 0.72, \"Chord\": \"C#/Db\"}, {\"Index\": 129, \"Highest Charting Position\": 11, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"enough for you\", \"Streams\": 6040918, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"2TOzTqQXNmR2zDJXihjZ2e\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 86.0, \"Danceability\": 0.638, \"Energy\": 0.259, \"Loudness\": -10.706, \"Speechiness\": 0.0898, \"Acousticness\": 0.753, \"Liveness\": 0.219, \"Tempo\": 88.485, \"Duration (ms)\": 202827.0, \"Valence\": 0.269, \"Chord\": \"G\"}, {\"Index\": 130, \"Highest Charting Position\": 99, \"Number of Times Charted\": 42, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Daddy Issues\", \"Streams\": 6014443, \"Artist\": \"The Neighbourhood\", \"Artist Followers\": 6662605.0, \"Song ID\": \"5E30LdtzQTGqRvNd7l6kG5\", \"Genre\": \"['modern alternative rock', 'modern rock', 'pop']\", \"Release Date\": \"2015-10-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 85.0, \"Danceability\": 0.588, \"Energy\": 0.521, \"Loudness\": -9.461, \"Speechiness\": 0.0329, \"Acousticness\": 0.0678, \"Liveness\": 0.123, \"Tempo\": 85.012, \"Duration (ms)\": 260173.0, \"Valence\": 0.337, \"Chord\": \"A#/Bb\"}, {\"Index\": 131, \"Highest Charting Position\": 131, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Aquelas Coisas\", \"Streams\": 6012839, \"Artist\": \"Jo\\u00e3o Gomes\", \"Artist Followers\": 409173.0, \"Song ID\": \"0FqVtQxRD3HsPltldG5v5M\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 84.0, \"Danceability\": 0.682, \"Energy\": 0.873, \"Loudness\": -4.163, \"Speechiness\": 0.0449, \"Acousticness\": 0.402, \"Liveness\": 0.0946, \"Tempo\": 150.006, \"Duration (ms)\": 147072.0, \"Valence\": 0.964, \"Chord\": \"F#/Gb\"}, {\"Index\": 132, \"Highest Charting Position\": 19, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Miss The Rage (feat. Playboi Carti)\", \"Streams\": 5952490, \"Artist\": \"Trippie Redd\", \"Artist Followers\": 6430522.0, \"Song ID\": \"2BITQ360Knh6qNAOqR7Dyq\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2021-05-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 85.0, \"Danceability\": 0.584, \"Energy\": 0.859, \"Loudness\": -5.616, \"Speechiness\": 0.121, \"Acousticness\": 0.0144, \"Liveness\": 0.847, \"Tempo\": 77.005, \"Duration (ms)\": 236883.0, \"Valence\": 0.369, \"Chord\": \"G#/Ab\"}, {\"Index\": 133, \"Highest Charting Position\": 4, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Memories\", \"Streams\": 5928329, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32262679.0, \"Song ID\": \"4cktbXiXOapiLBMprHFErI\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.775, \"Energy\": 0.327, \"Loudness\": -7.241, \"Speechiness\": 0.0557, \"Acousticness\": 0.841, \"Liveness\": 0.0821, \"Tempo\": 91.05, \"Duration (ms)\": 189486.0, \"Valence\": 0.595, \"Chord\": \"B\"}, {\"Index\": 134, \"Highest Charting Position\": 76, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Another Love\", \"Streams\": 5914661, \"Artist\": \"Tom Odell\", \"Artist Followers\": 1838616.0, \"Song ID\": \"7otCGmgp9h4CsR2LhwB6gt\", \"Genre\": \"['pop']\", \"Release Date\": \"2013-09-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 67.0, \"Danceability\": 0.445, \"Energy\": 0.537, \"Loudness\": -8.532, \"Speechiness\": 0.04, \"Acousticness\": 0.695, \"Liveness\": 0.0941, \"Tempo\": 122.764, \"Duration (ms)\": 244360.0, \"Valence\": 0.131, \"Chord\": \"E\"}, {\"Index\": 135, \"Highest Charting Position\": 135, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Here's Your Perfect\", \"Streams\": 5912784, \"Artist\": \"Jamie Miller\", \"Artist Followers\": 64288.0, \"Song ID\": \"2aTKrdenCq5qBOoJPFdn4P\", \"Genre\": \"['pop soul']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 85.0, \"Danceability\": 0.558, \"Energy\": 0.454, \"Loudness\": -5.335, \"Speechiness\": 0.0551, \"Acousticness\": 0.499, \"Liveness\": 0.146, \"Tempo\": 113.12, \"Duration (ms)\": 158594.0, \"Valence\": 0.424, \"Chord\": \"F#/Gb\"}, {\"Index\": 136, \"Highest Charting Position\": 108, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Take Me To Church\", \"Streams\": 5907750, \"Artist\": \"Hozier\", \"Artist Followers\": 4781906.0, \"Song ID\": \"1CS7Sd1u5tWkstBhpssyjP\", \"Genre\": \"['irish singer-songwriter', 'modern rock', 'pop']\", \"Release Date\": \"2014-09-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 74.0, \"Danceability\": 0.566, \"Energy\": 0.664, \"Loudness\": -5.303, \"Speechiness\": 0.0464, \"Acousticness\": 0.634, \"Liveness\": 0.116, \"Tempo\": 128.945, \"Duration (ms)\": 241693.0, \"Valence\": 0.437, \"Chord\": \"E\"}, {\"Index\": 137, \"Highest Charting Position\": 110, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Little Bit of Love\", \"Streams\": 5848466, \"Artist\": \"Tom Grennan\", \"Artist Followers\": 261225.0, \"Song ID\": \"2sX7lJXsOYGP1Us6CqM9t1\", \"Genre\": \"['modern rock', 'uk pop']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 80.0, \"Danceability\": 0.689, \"Energy\": 0.706, \"Loudness\": -4.48, \"Speechiness\": 0.0312, \"Acousticness\": 0.0833, \"Liveness\": 0.105, \"Tempo\": 106.52, \"Duration (ms)\": 226268.0, \"Valence\": 0.623, \"Chord\": \"C#/Db\"}, {\"Index\": 138, \"Highest Charting Position\": 138, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Ficha Limpa\", \"Streams\": 5847975, \"Artist\": \"Gusttavo Lima\", \"Artist Followers\": 12969190.0, \"Song ID\": \"5SwyN9hzmWjBsINlif8li8\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2021-06-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 85.0, \"Danceability\": 0.774, \"Energy\": 0.732, \"Loudness\": -4.227, \"Speechiness\": 0.0308, \"Acousticness\": 0.108, \"Liveness\": 0.243, \"Tempo\": 135.005, \"Duration (ms)\": 192725.0, \"Valence\": 0.734, \"Chord\": \"A\"}, {\"Index\": 139, \"Highest Charting Position\": 14, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Up\", \"Streams\": 5845156, \"Artist\": \"Cardi B\", \"Artist Followers\": 17353707.0, \"Song ID\": \"1XXimziG1uhM0eDNCZCrUl\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'rap']\", \"Release Date\": \"2021-02-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 83.0, \"Danceability\": 0.868, \"Energy\": 0.795, \"Loudness\": -6.044, \"Speechiness\": 0.269, \"Acousticness\": 0.0012, \"Liveness\": 0.0461, \"Tempo\": 166.0, \"Duration (ms)\": 156945.0, \"Valence\": 0.819, \"Chord\": \"B\"}, {\"Index\": 140, \"Highest Charting Position\": 2, \"Number of Times Charted\": 52, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Haw\\u00e1i\", \"Streams\": 5769714, \"Artist\": \"Maluma\", \"Artist Followers\": 26769304.0, \"Song ID\": \"0GzuHFG4Ql6DoyxFRnIk3F\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-11-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 77.0, \"Danceability\": 0.766, \"Energy\": 0.788, \"Loudness\": -3.128, \"Speechiness\": 0.312, \"Acousticness\": 0.105, \"Liveness\": 0.142, \"Tempo\": 179.984, \"Duration (ms)\": 200482.0, \"Valence\": 0.609, \"Chord\": \"F#/Gb\"}, {\"Index\": 141, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"New Normal\", \"Streams\": 5768653, \"Artist\": \"Khalid\", \"Artist Followers\": 14187747.0, \"Song ID\": \"2CIYemjFXdmCWpJnfbtrD6\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-07-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 79.0, \"Danceability\": 0.39, \"Energy\": 0.534, \"Loudness\": -9.575, \"Speechiness\": 0.0709, \"Acousticness\": 0.0807, \"Liveness\": 0.184, \"Tempo\": 92.047, \"Duration (ms)\": 198765.0, \"Valence\": 0.244, \"Chord\": \"C\"}, {\"Index\": 142, \"Highest Charting Position\": 81, \"Number of Times Charted\": 81, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Bohemian Rhapsody - Remastered 2011\", \"Streams\": 5756583, \"Artist\": \"Queen\", \"Artist Followers\": 35888760.0, \"Song ID\": \"7tFiyTwD0nx5a1eklYtX2J\", \"Genre\": \"['classic rock', 'glam rock', 'rock']\", \"Release Date\": \"1975-11-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.392, \"Energy\": 0.402, \"Loudness\": -9.961, \"Speechiness\": 0.0536, \"Acousticness\": 0.288, \"Liveness\": 0.243, \"Tempo\": 143.883, \"Duration (ms)\": 354320.0, \"Valence\": 0.228, \"Chord\": \"C\"}, {\"Index\": 143, \"Highest Charting Position\": 5, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Bandido\", \"Streams\": 5734402, \"Artist\": \"Myke Towers, Juhn\", \"Artist Followers\": 6150675.0, \"Song ID\": \"1xK1Gg9SxG8fy2Ya373oqb\", \"Genre\": \"['trap latino']\", \"Release Date\": \"2020-12-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\", \"Popularity\": 85.0, \"Danceability\": 0.713, \"Energy\": 0.617, \"Loudness\": -4.637, \"Speechiness\": 0.0887, \"Acousticness\": 0.122, \"Liveness\": 0.0962, \"Tempo\": 168.021, \"Duration (ms)\": 232853.0, \"Valence\": 0.682, \"Chord\": \"G#/Ab\"}, {\"Index\": 144, \"Highest Charting Position\": 25, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Paradise (feat. Dermot Kennedy)\", \"Streams\": 5693848, \"Artist\": \"MEDUZA\", \"Artist Followers\": 441674.0, \"Song ID\": \"6ft4hAq6yde8jPZY2i5zLr\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop house', 'tropical house']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 85.0, \"Danceability\": 0.632, \"Energy\": 0.595, \"Loudness\": -7.644, \"Speechiness\": 0.0401, \"Acousticness\": 0.0689, \"Liveness\": 0.209, \"Tempo\": 124.114, \"Duration (ms)\": 167903.0, \"Valence\": 0.435, \"Chord\": \"G#/Ab\"}, {\"Index\": 145, \"Highest Charting Position\": 13, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"goosebumps\", \"Streams\": 5691540, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17719446.0, \"Song ID\": \"5uEYRdEIh9Bo4fpjDd4Na9\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 87.0, \"Danceability\": 0.841, \"Energy\": 0.593, \"Loudness\": -7.846, \"Speechiness\": 0.0379, \"Acousticness\": 0.418, \"Liveness\": 0.124, \"Tempo\": 124.917, \"Duration (ms)\": 162803.0, \"Valence\": 0.808, \"Chord\": \"C#/Db\"}, {\"Index\": 146, \"Highest Charting Position\": 90, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Wasted Love (feat. Lagique)\", \"Streams\": 5690260, \"Artist\": \"Ofenbach\", \"Artist Followers\": 432581.0, \"Song ID\": \"2pPO9YecZimmuVQfIzfV6U\", \"Genre\": \"['edm', 'new french touch', 'pop dance', 'tropical house']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 85.0, \"Danceability\": 0.734, \"Energy\": 0.855, \"Loudness\": -4.578, \"Speechiness\": 0.135, \"Acousticness\": 0.0821, \"Liveness\": 0.0901, \"Tempo\": 121.955, \"Duration (ms)\": 139563.0, \"Valence\": 0.54, \"Chord\": \"F#/Gb\"}, {\"Index\": 147, \"Highest Charting Position\": 100, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"KESI - Remix\", \"Streams\": 5682062, \"Artist\": \"Camilo, Shawn Mendes\", \"Artist Followers\": 10561047.0, \"Song ID\": \"0IqCoZ168iRc9LqfrYgpZy\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2021-07-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 83.0, \"Danceability\": 0.871, \"Energy\": 0.815, \"Loudness\": -4.439, \"Speechiness\": 0.0477, \"Acousticness\": 0.127, \"Liveness\": 0.094, \"Tempo\": 122.959, \"Duration (ms)\": 176575.0, \"Valence\": 0.823, \"Chord\": \"E\"}, {\"Index\": 148, \"Highest Charting Position\": 59, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Shallow\", \"Streams\": 5672480, \"Artist\": \"Lady Gaga, Bradley Cooper\", \"Artist Followers\": 18572085.0, \"Song ID\": \"2VxeLyX666F8uXCJ0dZF8B\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-10-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.572, \"Energy\": 0.385, \"Loudness\": -6.362, \"Speechiness\": 0.0308, \"Acousticness\": 0.371, \"Liveness\": 0.231, \"Tempo\": 95.799, \"Duration (ms)\": 215733.0, \"Valence\": 0.323, \"Chord\": \"G\"}, {\"Index\": 149, \"Highest Charting Position\": 110, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Tell Em\", \"Streams\": 5668576, \"Artist\": \"Cochise, $NOT\", \"Artist Followers\": 159647.0, \"Song ID\": \"7nc7mlSdWYeFom84zZ8Wr8\", \"Genre\": \"['plugg', 'vapor trap', 'viral rap']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\", \"Popularity\": 85.0, \"Danceability\": 0.672, \"Energy\": 0.717, \"Loudness\": -7.476, \"Speechiness\": 0.226, \"Acousticness\": 0.103, \"Liveness\": 0.398, \"Tempo\": 157.905, \"Duration (ms)\": 180380.0, \"Valence\": 0.473, \"Chord\": \"F\"}, {\"Index\": 150, \"Highest Charting Position\": 103, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"N\\u00e3o, N\\u00e3o Vou\", \"Streams\": 5652272, \"Artist\": \"Mari Fernandez\", \"Artist Followers\": 15889.0, \"Song ID\": \"0xBQvhJAm6f7J142ympKOn\", \"Genre\": \"[]\", \"Release Date\": \"2021-04-29\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.631, \"Energy\": 0.861, \"Loudness\": -1.891, \"Speechiness\": 0.0424, \"Acousticness\": 0.427, \"Liveness\": 0.215, \"Tempo\": 149.95, \"Duration (ms)\": 173038.0, \"Valence\": 0.822, \"Chord\": \"B\"}, {\"Index\": 151, \"Highest Charting Position\": 147, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Counting Stars\", \"Streams\": 5647568, \"Artist\": \"OneRepublic\", \"Artist Followers\": 12169108.0, \"Song ID\": \"6sy3LkhNFjJWlaeSMNwQ62\", \"Genre\": \"['dance pop', 'piano rock', 'pop', 'pop rock']\", \"Release Date\": \"2014-01-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 74.0, \"Danceability\": 0.664, \"Energy\": 0.705, \"Loudness\": -4.972, \"Speechiness\": 0.0382, \"Acousticness\": 0.0654, \"Liveness\": 0.115, \"Tempo\": 122.017, \"Duration (ms)\": 257840.0, \"Valence\": 0.477, \"Chord\": \"C#/Db\"}, {\"Index\": 152, \"Highest Charting Position\": 121, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Yellow\", \"Streams\": 5628703, \"Artist\": \"Coldplay\", \"Artist Followers\": 31151294.0, \"Song ID\": \"3AJwUDP919kvQ9QcozQPxg\", \"Genre\": \"['permanent wave', 'pop']\", \"Release Date\": \"2000-07-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 85.0, \"Danceability\": 0.429, \"Energy\": 0.661, \"Loudness\": -7.227, \"Speechiness\": 0.0281, \"Acousticness\": 0.00239, \"Liveness\": 0.234, \"Tempo\": 173.372, \"Duration (ms)\": 266773.0, \"Valence\": 0.285, \"Chord\": \"B\"}, {\"Index\": 153, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Como Si No Importara\", \"Streams\": 5627257, \"Artist\": \"Emilia, Duki\", \"Artist Followers\": 205590.0, \"Song ID\": \"1GYJpuLq41vEVKXiHGEY9j\", \"Genre\": \"[]\", \"Release Date\": \"2021-07-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 83.0, \"Danceability\": 0.843, \"Energy\": 0.534, \"Loudness\": -6.658, \"Speechiness\": 0.142, \"Acousticness\": 0.467, \"Liveness\": 0.0984, \"Tempo\": 94.984, \"Duration (ms)\": 173053.0, \"Valence\": 0.528, \"Chord\": \"C#/Db\"}, {\"Index\": 154, \"Highest Charting Position\": 154, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Se For Amor\", \"Streams\": 5618268, \"Artist\": \"Jo\\u00e3o Gomes, Vitor Fernandes\", \"Artist Followers\": 409173.0, \"Song ID\": \"5F2xRvRFkxDvqdFtUNAEyw\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 81.0, \"Danceability\": 0.667, \"Energy\": 0.899, \"Loudness\": -4.402, \"Speechiness\": 0.0322, \"Acousticness\": 0.423, \"Liveness\": 0.332, \"Tempo\": 147.962, \"Duration (ms)\": 239928.0, \"Valence\": 0.835, \"Chord\": \"B\"}, {\"Index\": 155, \"Highest Charting Position\": 142, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Wake Me Up\", \"Streams\": 5607285, \"Artist\": \"Avicii\", \"Artist Followers\": 20270895.0, \"Song ID\": \"0nrRP2bk19rLc0orkWPQk2\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance']\", \"Release Date\": \"2013-01-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-01--2021-01-08\\n2020-08-07--2020-08-14\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.532, \"Energy\": 0.783, \"Loudness\": -5.697, \"Speechiness\": 0.0523, \"Acousticness\": 0.0038, \"Liveness\": 0.161, \"Tempo\": 124.08, \"Duration (ms)\": 247427.0, \"Valence\": 0.643, \"Chord\": \"D\"}, {\"Index\": 156, \"Highest Charting Position\": 128, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Baby Me Atende\", \"Streams\": 5594505, \"Artist\": \"Matheus Fernandes, Dilsinho\", \"Artist Followers\": 77034.0, \"Song ID\": \"5R9KPXQVeyqsHZoPLMgfNy\", \"Genre\": \"['forro', 'sertanejo pop']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 83.0, \"Danceability\": 0.65, \"Energy\": 0.792, \"Loudness\": -3.825, \"Speechiness\": 0.0393, \"Acousticness\": 0.607, \"Liveness\": 0.92, \"Tempo\": 154.027, \"Duration (ms)\": 225672.0, \"Valence\": 0.872, \"Chord\": \"F#/Gb\"}, {\"Index\": 157, \"Highest Charting Position\": 68, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Ramenez la coupe \\u00e0 la maison\", \"Streams\": 5576844, \"Artist\": \"Vegedream\", \"Artist Followers\": 1250353.0, \"Song ID\": \"0dqVP9CnGjaYNjya3gYbYy\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 0.0, \"Danceability\": 0.808, \"Energy\": 0.66, \"Loudness\": -6.237, \"Speechiness\": 0.0395, \"Acousticness\": 0.0358, \"Liveness\": 0.138, \"Tempo\": 107.994, \"Duration (ms)\": 235556.0, \"Valence\": 0.804, \"Chord\": \"C\"}, {\"Index\": 158, \"Highest Charting Position\": 6, \"Number of Times Charted\": 47, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"What You Know Bout Love\", \"Streams\": 5570735, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"1tkg4EHVoqnhR6iFEXb60y\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-07-03--2020-07-10\", \"Popularity\": 85.0, \"Danceability\": 0.709, \"Energy\": 0.548, \"Loudness\": -8.493, \"Speechiness\": 0.353, \"Acousticness\": 0.65, \"Liveness\": 0.133, \"Tempo\": 83.995, \"Duration (ms)\": 160000.0, \"Valence\": 0.543, \"Chord\": \"A#/Bb\"}, {\"Index\": 159, \"Highest Charting Position\": 19, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Runaway\", \"Streams\": 5566150, \"Artist\": \"AURORA\", \"Artist Followers\": 1687399.0, \"Song ID\": \"0TCmhnbMpw5zwPsTvlXTJi\", \"Genre\": \"['art pop', 'norwegian pop']\", \"Release Date\": \"2014\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 77.0, \"Danceability\": 0.521, \"Energy\": 0.277, \"Loudness\": -10.34, \"Speechiness\": 0.0356, \"Acousticness\": 0.634, \"Liveness\": 0.103, \"Tempo\": 115.01, \"Duration (ms)\": 248827.0, \"Valence\": 0.13, \"Chord\": \"B\"}, {\"Index\": 160, \"Highest Charting Position\": 121, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Red Light Green Light\", \"Streams\": 5493760, \"Artist\": \"DaBaby\", \"Artist Followers\": 7593046.0, \"Song ID\": \"1YDebgap5OFwXEBG18NJvy\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.933, \"Energy\": 0.656, \"Loudness\": -5.85, \"Speechiness\": 0.322, \"Acousticness\": 0.129, \"Liveness\": 0.161, \"Tempo\": 119.987, \"Duration (ms)\": 159083.0, \"Valence\": 0.934, \"Chord\": \"D\"}, {\"Index\": 161, \"Highest Charting Position\": 120, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Ball If I Want To\", \"Streams\": 5478055, \"Artist\": \"DaBaby\", \"Artist Followers\": 7593046.0, \"Song ID\": \"0cu0rhnlCnJ7JIeHRiLpj3\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\", \"Popularity\": 84.0, \"Danceability\": 0.902, \"Energy\": 0.669, \"Loudness\": -5.049, \"Speechiness\": 0.457, \"Acousticness\": 0.161, \"Liveness\": 0.0728, \"Tempo\": 139.949, \"Duration (ms)\": 112547.0, \"Valence\": 0.628, \"Chord\": \"C#/Db\"}, {\"Index\": 162, \"Highest Charting Position\": 31, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lucid Dreams\", \"Streams\": 5477563, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"285pBltuF7vW8TeWk8hdRR\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2018-12-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.511, \"Energy\": 0.566, \"Loudness\": -7.23, \"Speechiness\": 0.2, \"Acousticness\": 0.349, \"Liveness\": 0.34, \"Tempo\": 83.903, \"Duration (ms)\": 239836.0, \"Valence\": 0.218, \"Chord\": \"F#/Gb\"}, {\"Index\": 163, \"Highest Charting Position\": 4, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Calling My Phone\", \"Streams\": 5467753, \"Artist\": \"Lil Tjay, 6LACK\", \"Artist Followers\": 3553442.0, \"Song ID\": \"3J8EOeKLTLXORtWPpOU5bE\", \"Genre\": \"['brooklyn drill', 'melodic rap', 'nyc rap']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 85.0, \"Danceability\": 0.907, \"Energy\": 0.393, \"Loudness\": -7.636, \"Speechiness\": 0.0539, \"Acousticness\": 0.451, \"Liveness\": 0.135, \"Tempo\": 104.949, \"Duration (ms)\": 205458.0, \"Valence\": 0.202, \"Chord\": \"E\"}, {\"Index\": 164, \"Highest Charting Position\": 5, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"34+35\", \"Streams\": 5453159, \"Artist\": \"Ariana Grande\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 165, \"Highest Charting Position\": 13, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"bad guy\", \"Streams\": 5436286, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"1hewNsVmijBqjKvFRQfk4m\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.701, \"Energy\": 0.425, \"Loudness\": -10.965, \"Speechiness\": 0.375, \"Acousticness\": 0.328, \"Liveness\": 0.1, \"Tempo\": 135.128, \"Duration (ms)\": 194088.0, \"Valence\": 0.562, \"Chord\": \"G\"}, {\"Index\": 166, \"Highest Charting Position\": 59, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Cover Me In Sunshine\", \"Streams\": 5434073, \"Artist\": \"P!nk, Willow Sage Hart\", \"Artist Followers\": 11477164.0, \"Song ID\": \"6Tio0ZoDeSQnI7EBAqWer2\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-02-12\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 83.0, \"Danceability\": 0.476, \"Energy\": 0.594, \"Loudness\": -6.879, \"Speechiness\": 0.135, \"Acousticness\": 0.0599, \"Liveness\": 0.0785, \"Tempo\": 159.702, \"Duration (ms)\": 141050.0, \"Valence\": 0.314, \"Chord\": \"F\"}, {\"Index\": 167, \"Highest Charting Position\": 7, \"Number of Times Charted\": 56, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"For The Night (feat. Lil Baby & DaBaby)\", \"Streams\": 5431375, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"0PvFJmanyNQMseIFrU708S\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 84.0, \"Danceability\": 0.823, \"Energy\": 0.586, \"Loudness\": -6.606, \"Speechiness\": 0.2, \"Acousticness\": 0.114, \"Liveness\": 0.193, \"Tempo\": 125.971, \"Duration (ms)\": 190476.0, \"Valence\": 0.347, \"Chord\": \"F#/Gb\"}, {\"Index\": 168, \"Highest Charting Position\": 13, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"1 step forward, 3 steps back\", \"Streams\": 5420003, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"4wcBRRpIfesgcyUtis7PEg\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 85.0, \"Danceability\": 0.473, \"Energy\": 0.203, \"Loudness\": -12.627, \"Speechiness\": 0.102, \"Acousticness\": 0.941, \"Liveness\": 0.126, \"Tempo\": 168.884, \"Duration (ms)\": 163587.0, \"Valence\": 0.419, \"Chord\": \"D\"}, {\"Index\": 169, \"Highest Charting Position\": 1, \"Number of Times Charted\": 51, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"WAP (feat. Megan Thee Stallion)\", \"Streams\": 5386268, \"Artist\": \"Cardi B\", \"Artist Followers\": 17353707.0, \"Song ID\": \"4Oun2ylbjFKMPTiaSbbCih\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'rap']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 84.0, \"Danceability\": 0.935, \"Energy\": 0.454, \"Loudness\": -7.509, \"Speechiness\": 0.375, \"Acousticness\": 0.0194, \"Liveness\": 0.0824, \"Tempo\": 133.073, \"Duration (ms)\": 187541.0, \"Valence\": 0.357, \"Chord\": \"C#/Db\"}, {\"Index\": 170, \"Highest Charting Position\": 155, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Mr. Brightside\", \"Streams\": 5382191, \"Artist\": \"The Killers\", \"Artist Followers\": 6118063.0, \"Song ID\": \"7oK9VyNzrYvRFo7nQEYkWN\", \"Genre\": \"['dance rock', 'modern rock', 'permanent wave', 'rock']\", \"Release Date\": \"2004-06-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-12--2021-03-19\\n2021-02-26--2021-03-05\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 75.0, \"Danceability\": 0.356, \"Energy\": 0.924, \"Loudness\": -3.74, \"Speechiness\": 0.0808, \"Acousticness\": 0.00101, \"Liveness\": 0.0953, \"Tempo\": 148.017, \"Duration (ms)\": 222587.0, \"Valence\": 0.232, \"Chord\": \"C#/Db\"}, {\"Index\": 171, \"Highest Charting Position\": 144, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Every Breath You Take\", \"Streams\": 5379704, \"Artist\": \"The Police\", \"Artist Followers\": 4339245.0, \"Song ID\": \"1JSTJqkT5qHq8MDJnJbRE1\", \"Genre\": \"['album rock', 'art rock', 'classic rock', 'mellow gold', 'new wave', 'permanent wave', 'rock', 'soft rock']\", \"Release Date\": \"1983-06-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-01-01--2021-01-08\\n2020-06-19--2020-06-26\\n2020-06-05--2020-06-12\", \"Popularity\": 83.0, \"Danceability\": 0.82, \"Energy\": 0.452, \"Loudness\": -9.796, \"Speechiness\": 0.0348, \"Acousticness\": 0.543, \"Liveness\": 0.0714, \"Tempo\": 117.401, \"Duration (ms)\": 253920.0, \"Valence\": 0.74, \"Chord\": \"C#/Db\"}, {\"Index\": 172, \"Highest Charting Position\": 20, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Dreams - 2004 Remaster\", \"Streams\": 5378971, \"Artist\": \"Fleetwood Mac\", \"Artist Followers\": 6930669.0, \"Song ID\": \"0ofHAoxe9vBkTCp2UQIavz\", \"Genre\": \"['album rock', 'classic rock', 'mellow gold', 'rock', 'soft rock', 'yacht rock']\", \"Release Date\": \"1977-02-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 84.0, \"Danceability\": 0.828, \"Energy\": 0.492, \"Loudness\": -9.744, \"Speechiness\": 0.0276, \"Acousticness\": 0.0644, \"Liveness\": 0.128, \"Tempo\": 120.151, \"Duration (ms)\": 257800.0, \"Valence\": 0.789, \"Chord\": \"C\"}, {\"Index\": 173, \"Highest Charting Position\": 94, \"Number of Times Charted\": 82, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Say You Won't Let Go\", \"Streams\": 5375426, \"Artist\": \"James Arthur\", \"Artist Followers\": 8441598.0, \"Song ID\": \"5uCax9HTNlzGybIStD3vDh\", \"Genre\": \"['pop', 'post-teen pop', 'talent show', 'uk pop']\", \"Release Date\": \"2016-10-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.358, \"Energy\": 0.557, \"Loudness\": -7.398, \"Speechiness\": 0.059, \"Acousticness\": 0.695, \"Liveness\": 0.0902, \"Tempo\": 85.043, \"Duration (ms)\": 211467.0, \"Valence\": 0.494, \"Chord\": \"A#/Bb\"}, {\"Index\": 174, \"Highest Charting Position\": 110, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Wild Side (feat. Cardi B)\", \"Streams\": 5366242, \"Artist\": \"Normani\", \"Artist Followers\": 1304510.0, \"Song ID\": \"2vXgyN14LX2zl7JEASw242\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop', 'r&b', 'urban contemporary']\", \"Release Date\": \"2021-07-22\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 75.0, \"Danceability\": 0.74, \"Energy\": 0.576, \"Loudness\": -6.744, \"Speechiness\": 0.146, \"Acousticness\": 0.0249, \"Liveness\": 0.104, \"Tempo\": 110.095, \"Duration (ms)\": 209476.0, \"Valence\": 0.315, \"Chord\": \"F#/Gb\"}, {\"Index\": 175, \"Highest Charting Position\": 65, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Bout A Million (feat. 42 Dugg & 21 Savage)\", \"Streams\": 5315734, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"4LaGu95Ui2s4vprSQYWUAZ\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 81.0, \"Danceability\": 0.716, \"Energy\": 0.67, \"Loudness\": -6.995, \"Speechiness\": 0.101, \"Acousticness\": 0.526, \"Liveness\": 0.13, \"Tempo\": 145.043, \"Duration (ms)\": 203586.0, \"Valence\": 0.411, \"Chord\": \"C\"}, {\"Index\": 176, \"Highest Charting Position\": 72, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Demeanor (feat. Dua Lipa)\", \"Streams\": 5245618, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"3DMs7bahbQTnoxCjgP7qoK\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 81.0, \"Danceability\": 0.675, \"Energy\": 0.608, \"Loudness\": -6.934, \"Speechiness\": 0.103, \"Acousticness\": 0.336, \"Liveness\": 0.11, \"Tempo\": 99.865, \"Duration (ms)\": 184800.0, \"Valence\": 0.728, \"Chord\": \"D#/Eb\"}, {\"Index\": 177, \"Highest Charting Position\": 4, \"Number of Times Charted\": 76, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"death bed (coffee for your head)\", \"Streams\": 5238547, \"Artist\": \"Powfu, beabadoobee\", \"Artist Followers\": 924083.0, \"Song ID\": \"7eJMfftS33KTjuF7lTsMCx\", \"Genre\": \"['sad rap']\", \"Release Date\": \"2020-02-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 85.0, \"Danceability\": 0.726, \"Energy\": 0.431, \"Loudness\": -8.765, \"Speechiness\": 0.135, \"Acousticness\": 0.731, \"Liveness\": 0.696, \"Tempo\": 144.026, \"Duration (ms)\": 173333.0, \"Valence\": 0.348, \"Chord\": \"G#/Ab\"}, {\"Index\": 178, \"Highest Charting Position\": 100, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Our Song\", \"Streams\": 5235335, \"Artist\": \"Anne-Marie, Niall Horan\", \"Artist Followers\": 8148393.0, \"Song ID\": \"5zqObw7wjBgL9TDiAymxPn\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 83.0, \"Danceability\": 0.595, \"Energy\": 0.759, \"Loudness\": -4.245, \"Speechiness\": 0.0423, \"Acousticness\": 0.141, \"Liveness\": 0.172, \"Tempo\": 80.953, \"Duration (ms)\": 163733.0, \"Valence\": 0.515, \"Chord\": \"B\"}, {\"Index\": 179, \"Highest Charting Position\": 138, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Another One Bites The Dust - Remastered 2011\", \"Streams\": 5204983, \"Artist\": \"Queen\", \"Artist Followers\": 35888760.0, \"Song ID\": \"57JVGBtBLCfHw2muk5416J\", \"Genre\": \"['classic rock', 'glam rock', 'rock']\", \"Release Date\": \"1980-06-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.933, \"Energy\": 0.528, \"Loudness\": -6.472, \"Speechiness\": 0.162, \"Acousticness\": 0.112, \"Liveness\": 0.163, \"Tempo\": 109.975, \"Duration (ms)\": 214653.0, \"Valence\": 0.756, \"Chord\": \"F\"}, {\"Index\": 180, \"Highest Charting Position\": 149, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"One Dance\", \"Streams\": 5178490, \"Artist\": \"Drake, WizKid, Kyla\", \"Artist Followers\": 56308172.0, \"Song ID\": \"1zi7xx7UVEFkmKfv06H8x0\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2016-05-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 84.0, \"Danceability\": 0.792, \"Energy\": 0.625, \"Loudness\": -5.609, \"Speechiness\": 0.0536, \"Acousticness\": 0.00776, \"Liveness\": 0.329, \"Tempo\": 103.967, \"Duration (ms)\": 173987.0, \"Valence\": 0.37, \"Chord\": \"C#/Db\"}, {\"Index\": 181, \"Highest Charting Position\": 15, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Adore You\", \"Streams\": 5166847, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16112621.0, \"Song ID\": \"3jjujdWJ72nww5eGnfs2E7\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.676, \"Energy\": 0.771, \"Loudness\": -3.675, \"Speechiness\": 0.0483, \"Acousticness\": 0.0237, \"Liveness\": 0.102, \"Tempo\": 99.048, \"Duration (ms)\": 207133.0, \"Valence\": 0.569, \"Chord\": \"G#/Ab\"}, {\"Index\": 182, \"Highest Charting Position\": 181, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"As the World Caves In\", \"Streams\": 5145493, \"Artist\": \"Sarah Cothran\", \"Artist Followers\": 180723.0, \"Song ID\": \"2xXNLutYAOELYVObYb1C1S\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-04--2021-06-11\", \"Popularity\": 71.0, \"Danceability\": 0.422, \"Energy\": 0.25, \"Loudness\": -6.836, \"Speechiness\": 0.0351, \"Acousticness\": 0.441, \"Liveness\": 0.35, \"Tempo\": 124.026, \"Duration (ms)\": 161613.0, \"Valence\": 0.246, \"Chord\": \"C\"}, {\"Index\": 183, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Fancy Like\", \"Streams\": 5145432, \"Artist\": \"Walker Hayes\", \"Artist Followers\": 304995.0, \"Song ID\": \"3ZozFqJJlDBNIm4xqxn2ZD\", \"Genre\": \"['contemporary country', 'country', 'country road', 'modern country rock']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 83.0, \"Danceability\": 0.649, \"Energy\": 0.76, \"Loudness\": -6.487, \"Speechiness\": 0.0574, \"Acousticness\": 0.114, \"Liveness\": 0.317, \"Tempo\": 80.018, \"Duration (ms)\": 161853.0, \"Valence\": 0.843, \"Chord\": \"C#/Db\"}, {\"Index\": 184, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"C\\u00farame\", \"Streams\": 5104206, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6080597.0, \"Song ID\": \"3PwRuzdphgedcWVUOVYJ7I\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 85.0, \"Danceability\": 0.765, \"Energy\": 0.625, \"Loudness\": -3.599, \"Speechiness\": 0.0548, \"Acousticness\": 0.584, \"Liveness\": 0.112, \"Tempo\": 102.101, \"Duration (ms)\": 164706.0, \"Valence\": 0.262, \"Chord\": \"A\"}, {\"Index\": 185, \"Highest Charting Position\": 110, \"Number of Times Charted\": 78, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"All of Me\", \"Streams\": 5103014, \"Artist\": \"John Legend\", \"Artist Followers\": 5799137.0, \"Song ID\": \"3U4isOIWM3VvDubwSI3y7a\", \"Genre\": \"['neo soul', 'pop', 'pop soul', 'r&b', 'urban contemporary']\", \"Release Date\": \"2013-08-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.422, \"Energy\": 0.264, \"Loudness\": -7.064, \"Speechiness\": 0.0322, \"Acousticness\": 0.922, \"Liveness\": 0.132, \"Tempo\": 119.93, \"Duration (ms)\": 269560.0, \"Valence\": 0.331, \"Chord\": \"G#/Ab\"}, {\"Index\": 186, \"Highest Charting Position\": 80, \"Number of Times Charted\": 41, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Martin & Gina\", \"Streams\": 5098609, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"1VLtjHwRWOVJiE5Py7JxoQ\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 85.0, \"Danceability\": 0.832, \"Energy\": 0.534, \"Loudness\": -7.813, \"Speechiness\": 0.253, \"Acousticness\": 0.345, \"Liveness\": 0.165, \"Tempo\": 93.924, \"Duration (ms)\": 132833.0, \"Valence\": 0.116, \"Chord\": \"C#/Db\"}, {\"Index\": 187, \"Highest Charting Position\": 40, \"Number of Times Charted\": 65, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Dior\", \"Streams\": 5092354, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"79s5XnCN4TJKTVMSmOx8Ep\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2019-07-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-06-18--2021-06-25\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 83.0, \"Danceability\": 0.548, \"Energy\": 0.805, \"Loudness\": -5.732, \"Speechiness\": 0.351, \"Acousticness\": 0.212, \"Liveness\": 0.408, \"Tempo\": 142.094, \"Duration (ms)\": 216387.0, \"Valence\": 0.648, \"Chord\": \"G\"}, {\"Index\": 188, \"Highest Charting Position\": 45, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Best Friend (feat. Doja Cat)\", \"Streams\": 5090062, \"Artist\": \"Saweetie\", \"Artist Followers\": 1254432.0, \"Song ID\": \"2etHQJxIbV0soyPhelVs9Y\", \"Genre\": \"['cali rap', 'dance pop', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2021-01-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 83.0, \"Danceability\": 0.84, \"Energy\": 0.766, \"Loudness\": -4.12, \"Speechiness\": 0.136, \"Acousticness\": 0.00302, \"Liveness\": 0.0684, \"Tempo\": 94.018, \"Duration (ms)\": 155884.0, \"Valence\": 0.402, \"Chord\": \"E\"}, {\"Index\": 189, \"Highest Charting Position\": 52, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"The Hills\", \"Streams\": 5068864, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"7fBv7CLKzipRk6EC6TWHOB\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2015-08-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 84.0, \"Danceability\": 0.585, \"Energy\": 0.564, \"Loudness\": -7.063, \"Speechiness\": 0.0515, \"Acousticness\": 0.0671, \"Liveness\": 0.135, \"Tempo\": 113.003, \"Duration (ms)\": 242253.0, \"Valence\": 0.137, \"Chord\": \"C\"}, {\"Index\": 190, \"Highest Charting Position\": 5, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Good Days\", \"Streams\": 5065132, \"Artist\": \"SZA\", \"Artist Followers\": 5881963.0, \"Song ID\": \"3YJJjQPAbDT7mGpX3WtQ9A\", \"Genre\": \"['pop', 'pop rap', 'r&b']\", \"Release Date\": \"2020-12-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 84.0, \"Danceability\": 0.436, \"Energy\": 0.655, \"Loudness\": -8.37, \"Speechiness\": 0.0583, \"Acousticness\": 0.499, \"Liveness\": 0.688, \"Tempo\": 121.002, \"Duration (ms)\": 279204.0, \"Valence\": 0.412, \"Chord\": \"C#/Db\"}, {\"Index\": 191, \"Highest Charting Position\": 191, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Kiss My (Uh Oh)\", \"Streams\": 5063181, \"Artist\": \"Anne-Marie, Little Mix\", \"Artist Followers\": 8148393.0, \"Song ID\": \"0MWiSBKm8Avs8iDIxcertp\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2021-07-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 78.0, \"Danceability\": 0.638, \"Energy\": 0.878, \"Loudness\": -3.639, \"Speechiness\": 0.0484, \"Acousticness\": 0.0151, \"Liveness\": 0.308, \"Tempo\": 103.948, \"Duration (ms)\": 176800.0, \"Valence\": 0.481, \"Chord\": \"F\"}, {\"Index\": 192, \"Highest Charting Position\": 64, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"De Museo\", \"Streams\": 5016125, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36142273.0, \"Song ID\": \"267NGliXM8YLVZiKAD9Otm\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 83.0, \"Danceability\": 0.592, \"Energy\": 0.494, \"Loudness\": -10.618, \"Speechiness\": 0.0747, \"Acousticness\": 0.237, \"Liveness\": 0.13, \"Tempo\": 132.037, \"Duration (ms)\": 209771.0, \"Valence\": 0.231, \"Chord\": \"E\"}, {\"Index\": 193, \"Highest Charting Position\": 41, \"Number of Times Charted\": 81, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"7 rings\", \"Streams\": 5002227, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67158068.0, \"Song ID\": \"6ocbgoVGwYJhOv1GgI9NsF\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-02-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.778, \"Energy\": 0.317, \"Loudness\": -10.732, \"Speechiness\": 0.334, \"Acousticness\": 0.592, \"Liveness\": 0.0881, \"Tempo\": 140.048, \"Duration (ms)\": 178627.0, \"Valence\": 0.327, \"Chord\": \"C#/Db\"}, {\"Index\": 194, \"Highest Charting Position\": 194, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Chosen (feat. Ty Dolla $ign)\", \"Streams\": 4992405, \"Artist\": \"Blxst, Tyga\", \"Artist Followers\": 167628.0, \"Song ID\": \"1dIWPXMX4kRHj6Dt2DStUQ\", \"Genre\": \"[]\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 84.0, \"Danceability\": 0.571, \"Energy\": 0.767, \"Loudness\": -5.16, \"Speechiness\": 0.287, \"Acousticness\": 0.336, \"Liveness\": 0.0809, \"Tempo\": 93.421, \"Duration (ms)\": 161684.0, \"Valence\": 0.605, \"Chord\": \"D\"}, {\"Index\": 195, \"Highest Charting Position\": 149, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"N\\u00e3o Nasceu pra Namorar\", \"Streams\": 4978559, \"Artist\": \"MC Zaquin, MC Rick\", \"Artist Followers\": 130627.0, \"Song ID\": \"6pQKUKBpwr6GhfhcFFFozo\", \"Genre\": \"['funk bh', 'funk carioca']\", \"Release Date\": \"2021-02-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.525, \"Energy\": 0.448, \"Loudness\": -4.075, \"Speechiness\": 0.0443, \"Acousticness\": 0.14, \"Liveness\": 0.0922, \"Tempo\": 83.406, \"Duration (ms)\": 140308.0, \"Valence\": 0.527, \"Chord\": \"C#/Db\"}, {\"Index\": 196, \"Highest Charting Position\": 8, \"Number of Times Charted\": 71, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Breaking Me\", \"Streams\": 4977498, \"Artist\": \"Topic, A7S\", \"Artist Followers\": 151832.0, \"Song ID\": \"3H7ihDc1dqLriiWXwsc2po\", \"Genre\": \"['dance pop', 'edm', 'german dance', 'pop dance', 'pop edm', 'tropical house']\", \"Release Date\": \"2019-12-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 84.0, \"Danceability\": 0.789, \"Energy\": 0.72, \"Loudness\": -5.652, \"Speechiness\": 0.218, \"Acousticness\": 0.223, \"Liveness\": 0.129, \"Tempo\": 122.031, \"Duration (ms)\": 166794.0, \"Valence\": 0.664, \"Chord\": \"G#/Ab\"}, {\"Index\": 197, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"penhasco.\", \"Streams\": 4973937, \"Artist\": \"Lu\\u00edsa Sonza\", \"Artist Followers\": 1909059.0, \"Song ID\": \"5VTqW8raQYnj2avZ27nO2a\", \"Genre\": \"['funk carioca', 'pop nacional']\", \"Release Date\": \"2021-07-18\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 80.0, \"Danceability\": 0.43, \"Energy\": 0.467, \"Loudness\": -8.56, \"Speechiness\": 0.051, \"Acousticness\": 0.775, \"Liveness\": 0.0933, \"Tempo\": 77.249, \"Duration (ms)\": 186121.0, \"Valence\": 0.382, \"Chord\": \"G#/Ab\"}, {\"Index\": 198, \"Highest Charting Position\": 58, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Late At Night\", \"Streams\": 4954899, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6603627.0, \"Song ID\": \"1fxYz1s15pyZLsJT0Hdh1m\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 84.0, \"Danceability\": 0.643, \"Energy\": 0.403, \"Loudness\": -11.254, \"Speechiness\": 0.41, \"Acousticness\": 0.343, \"Liveness\": 0.138, \"Tempo\": 98.54, \"Duration (ms)\": 174682.0, \"Valence\": 0.111, \"Chord\": \"C#/Db\"}, {\"Index\": 199, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Verdansk\", \"Streams\": 4950275, \"Artist\": \"Dave\", \"Artist Followers\": 1427540.0, \"Song ID\": \"7IPKXYU2rTMnrLW5IZ7ZI5\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2021-07-22\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 77.0, \"Danceability\": 0.961, \"Energy\": 0.502, \"Loudness\": -8.605, \"Speechiness\": 0.312, \"Acousticness\": 0.28, \"Liveness\": 0.145, \"Tempo\": 117.078, \"Duration (ms)\": 182285.0, \"Valence\": 0.536, \"Chord\": \"D\"}, {\"Index\": 200, \"Highest Charting Position\": 172, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"The Real Slim Shady\", \"Streams\": 4948965, \"Artist\": \"Eminem\", \"Artist Followers\": 46785561.0, \"Song ID\": \"3yfqSUWxFvZELEM4PmlwIR\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2000-05-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 84.0, \"Danceability\": 0.949, \"Energy\": 0.661, \"Loudness\": -4.244, \"Speechiness\": 0.0572, \"Acousticness\": 0.0302, \"Liveness\": 0.0454, \"Tempo\": 104.504, \"Duration (ms)\": 284200.0, \"Valence\": 0.76, \"Chord\": \"F\"}, {\"Index\": 201, \"Highest Charting Position\": 66, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Tell The Vision (feat. Kanye West & Pusha T)\", \"Streams\": 8859168, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"1Eu51GaXEehPMrDMh5QghA\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 57.0, \"Danceability\": 0.662, \"Energy\": 0.686, \"Loudness\": -8.302, \"Speechiness\": 0.332, \"Acousticness\": 0.251, \"Liveness\": 0.349, \"Tempo\": 143.971, \"Duration (ms)\": 215000.0, \"Valence\": 0.678, \"Chord\": \"G\"}, {\"Index\": 202, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Woo Baby (feat. Chris Brown)\", \"Streams\": 7371935, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"6bsqes8Zg9gUULzuCkMUs0\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 56.0, \"Danceability\": 0.563, \"Energy\": 0.672, \"Loudness\": -7.226, \"Speechiness\": 0.0765, \"Acousticness\": 0.359, \"Liveness\": 0.0972, \"Tempo\": 99.772, \"Duration (ms)\": 156000.0, \"Valence\": 0.284, \"Chord\": \"A\"}, {\"Index\": 203, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Holy Smokes\", \"Streams\": 6464206, \"Artist\": \"Trippie Redd, Lil Uzi Vert\", \"Artist Followers\": 6430522.0, \"Song ID\": \"3EpF150nXMSNjiH0bbmXIL\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 79.0, \"Danceability\": 0.437, \"Energy\": 0.527, \"Loudness\": -6.967, \"Speechiness\": 0.465, \"Acousticness\": 0.185, \"Liveness\": 0.153, \"Tempo\": 187.815, \"Duration (ms)\": 181714.0, \"Valence\": 0.701, \"Chord\": \"F#/Gb\"}, {\"Index\": 204, \"Highest Charting Position\": 127, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"More Time\", \"Streams\": 6238351, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"7wAnRqccDr2tzcSKLR4jKl\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 55.0, \"Danceability\": 0.628, \"Energy\": 0.581, \"Loudness\": -8.377, \"Speechiness\": 0.188, \"Acousticness\": 0.46, \"Liveness\": 0.152, \"Tempo\": 145.396, \"Duration (ms)\": 120828.0, \"Valence\": 0.259, \"Chord\": \"D\"}, {\"Index\": 205, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Coupe\", \"Streams\": 6161664, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"7LB3ilSpX1mSMKKztNTnu2\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 54.0, \"Danceability\": 0.912, \"Energy\": 0.589, \"Loudness\": -7.476, \"Speechiness\": 0.2, \"Acousticness\": 0.0332, \"Liveness\": 0.0795, \"Tempo\": 135.921, \"Duration (ms)\": 123549.0, \"Valence\": 0.486, \"Chord\": \"G#/Ab\"}, {\"Index\": 206, \"Highest Charting Position\": 76, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Holiday\", \"Streams\": 5883145, \"Artist\": \"KSI\", \"Artist Followers\": 2008516.0, \"Song ID\": \"6nV2dFZXpv1JlqDWBeTXRl\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 81.0, \"Danceability\": 0.356, \"Energy\": 0.684, \"Loudness\": -7.347, \"Speechiness\": 0.0878, \"Acousticness\": 0.152, \"Liveness\": 0.101, \"Tempo\": 87.188, \"Duration (ms)\": 193733.0, \"Valence\": 0.347, \"Chord\": \"G#/Ab\"}, {\"Index\": 207, \"Highest Charting Position\": 150, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Manslaughter (feat. Rick Ross & The-Dream)\", \"Streams\": 5822266, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"4byRwLo7EmkCNBU6S8G6u0\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 55.0, \"Danceability\": 0.441, \"Energy\": 0.623, \"Loudness\": -7.331, \"Speechiness\": 0.0414, \"Acousticness\": 0.135, \"Liveness\": 0.14, \"Tempo\": 78.082, \"Duration (ms)\": 249231.0, \"Valence\": 0.285, \"Chord\": \"C#/Db\"}, {\"Index\": 208, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Genius (feat. Lil Tjay & Swae Lee)\", \"Streams\": 5702636, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"2mmRtchzDVpCj9LSyexgjS\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 53.0, \"Danceability\": 0.723, \"Energy\": 0.667, \"Loudness\": -7.524, \"Speechiness\": 0.351, \"Acousticness\": 0.256, \"Liveness\": 0.261, \"Tempo\": 143.044, \"Duration (ms)\": 208112.0, \"Valence\": 0.396, \"Chord\": \"D\"}, {\"Index\": 209, \"Highest Charting Position\": 22, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"WUSYANAME (feat. Youngboy Never Broke Again & Ty Dolla $ign)\", \"Streams\": 5696113, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"5B0kgjHULYJhAQkK5XsMoC\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.493, \"Energy\": 0.653, \"Loudness\": -5.666, \"Speechiness\": 0.0466, \"Acousticness\": 0.269, \"Liveness\": 0.511, \"Tempo\": 142.347, \"Duration (ms)\": 121573.0, \"Valence\": 0.852, \"Chord\": \"C\"}, {\"Index\": 210, \"Highest Charting Position\": 105, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Sommergewitter\", \"Streams\": 5627519, \"Artist\": \"Pashanim\", \"Artist Followers\": 208554.0, \"Song ID\": \"2H7jZg2HliuQhZjfBblLrZ\", \"Genre\": \"['german alternative rap', 'german drill', 'german hip hop', 'german trap']\", \"Release Date\": \"2021-06-24\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.787, \"Energy\": 0.531, \"Loudness\": -10.569, \"Speechiness\": 0.101, \"Acousticness\": 0.132, \"Liveness\": 0.112, \"Tempo\": 91.996, \"Duration (ms)\": 138533.0, \"Valence\": 0.721, \"Chord\": \"B\"}, {\"Index\": 211, \"Highest Charting Position\": 17, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Body (Remix) [feat. ArrDee, E1 (3x3), ZT (3x3), Bugzy Malone, Buni, Fivio Foreign & Darkoo]\", \"Streams\": 5383125, \"Artist\": \"Tion Wayne, Russ Millions\", \"Artist Followers\": 323203.0, \"Song ID\": \"6uvMKqNlrSvcC4NaKnrwjZ\", \"Genre\": \"['london rap']\", \"Release Date\": \"2021-04-22\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 84.0, \"Danceability\": 0.883, \"Energy\": 0.674, \"Loudness\": -8.043, \"Speechiness\": 0.357, \"Acousticness\": 0.21, \"Liveness\": 0.0678, \"Tempo\": 141.02, \"Duration (ms)\": 278085.0, \"Valence\": 0.73, \"Chord\": \"B\"}, {\"Index\": 212, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Brush Em (feat. Rah Swish)\", \"Streams\": 5335271, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"58aW6yZGFl7rVM7SLfLnLL\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 54.0, \"Danceability\": 0.654, \"Energy\": 0.724, \"Loudness\": -6.59, \"Speechiness\": 0.355, \"Acousticness\": 0.106, \"Liveness\": 0.655, \"Tempo\": 71.696, \"Duration (ms)\": 150449.0, \"Valence\": 0.717, \"Chord\": \"D#/Eb\"}, {\"Index\": 213, \"Highest Charting Position\": 13, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"AM\", \"Streams\": 5288927, \"Artist\": \"Nio Garcia, Flow La Movie\", \"Artist Followers\": 2123734.0, \"Song ID\": \"2dNhNlpZAtV4lwAFW45LIv\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-01-28\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 85.0, \"Danceability\": 0.83, \"Energy\": 0.517, \"Loudness\": -6.416, \"Speechiness\": 0.333, \"Acousticness\": 0.399, \"Liveness\": 0.0916, \"Tempo\": 171.959, \"Duration (ms)\": 182496.0, \"Valence\": 0.616, \"Chord\": \"F#/Gb\"}, {\"Index\": 214, \"Highest Charting Position\": 175, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"MI FAI IMPAZZIRE\", \"Streams\": 5242097, \"Artist\": \"BLANCO, Sfera Ebbasta\", \"Artist Followers\": 127364.0, \"Song ID\": \"1x3Qb8np6S1UvpSLthwEJN\", \"Genre\": \"['italian hip hop', 'italian pop']\", \"Release Date\": \"2021-06-17\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\", \"Popularity\": 83.0, \"Danceability\": 0.477, \"Energy\": 0.844, \"Loudness\": -4.87, \"Speechiness\": 0.0458, \"Acousticness\": 0.00273, \"Liveness\": 0.137, \"Tempo\": 169.941, \"Duration (ms)\": 220235.0, \"Valence\": 0.203, \"Chord\": \"B\"}, {\"Index\": 215, \"Highest Charting Position\": 20, \"Number of Times Charted\": 82, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Ride It\", \"Streams\": 5235088, \"Artist\": \"Regard\", \"Artist Followers\": 152226.0, \"Song ID\": \"2tnVG71enUj33Ic2nFN6kZ\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop edm', 'slap house', 'tropical house']\", \"Release Date\": \"2019-07-26\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.88, \"Energy\": 0.751, \"Loudness\": -4.258, \"Speechiness\": 0.0874, \"Acousticness\": 0.177, \"Liveness\": 0.106, \"Tempo\": 117.948, \"Duration (ms)\": 157606.0, \"Valence\": 0.884, \"Chord\": \"G\"}, {\"Index\": 216, \"Highest Charting Position\": 15, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Lost Cause\", \"Streams\": 5203319, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"36fhyo5QlxBW7DrDHIOn1G\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 0.0, \"Danceability\": 0.671, \"Energy\": 0.336, \"Loudness\": -8.494, \"Speechiness\": 0.241, \"Acousticness\": 0.705, \"Liveness\": 0.0577, \"Tempo\": 75.051, \"Duration (ms)\": 212496.0, \"Valence\": 0.518, \"Chord\": \"A#/Bb\"}, {\"Index\": 217, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Shot in the Dark\", \"Streams\": 5173308, \"Artist\": \"John Mayer\", \"Artist Followers\": 5178156.0, \"Song ID\": \"239yM7BAQ2CkNc61ogPGXo\", \"Genre\": \"['neo mellow', 'pop rock', 'singer-songwriter']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 76.0, \"Danceability\": 0.741, \"Energy\": 0.556, \"Loudness\": -9.184, \"Speechiness\": 0.0266, \"Acousticness\": 0.0629, \"Liveness\": 0.103, \"Tempo\": 122.008, \"Duration (ms)\": 249080.0, \"Valence\": 0.587, \"Chord\": \"D\"}, {\"Index\": 218, \"Highest Charting Position\": 71, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Wrecked\", \"Streams\": 5150909, \"Artist\": \"Imagine Dragons\", \"Artist Followers\": 35285425.0, \"Song ID\": \"2d1MywHy6FwKdzxFuSJnwl\", \"Genre\": \"['modern rock', 'pop', 'rock']\", \"Release Date\": \"2021-07-02\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 83.0, \"Danceability\": 0.626, \"Energy\": 0.56, \"Loudness\": -5.82, \"Speechiness\": 0.0288, \"Acousticness\": 0.148, \"Liveness\": 0.109, \"Tempo\": 93.989, \"Duration (ms)\": 244005.0, \"Valence\": 0.229, \"Chord\": \"C\"}, {\"Index\": 219, \"Highest Charting Position\": 79, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Bipolar\", \"Streams\": 5116589, \"Artist\": \"Mc Davi, Mc Pedrinho, Mc Don Juan\", \"Artist Followers\": 2586114.0, \"Song ID\": \"0qxLQ6opocOGyFnlXqJ53x\", \"Genre\": \"['funk carioca', 'funk ostentacao', 'funk paulista']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 84.0, \"Danceability\": 0.601, \"Energy\": 0.36, \"Loudness\": -7.791, \"Speechiness\": 0.0877, \"Acousticness\": 0.586, \"Liveness\": 0.0882, \"Tempo\": 124.993, \"Duration (ms)\": 276480.0, \"Valence\": 0.335, \"Chord\": \"A\"}, {\"Index\": 220, \"Highest Charting Position\": 122, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"His & Hers (feat. Don Toliver, Lil Uzi Vert & Gunna)\", \"Streams\": 5110475, \"Artist\": \"Internet Money\", \"Artist Followers\": 411579.0, \"Song ID\": \"2IePEfMAtqWS6rLXXFZIgI\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-05-14--2021-05-21\", \"Popularity\": 84.0, \"Danceability\": 0.792, \"Energy\": 0.707, \"Loudness\": -5.218, \"Speechiness\": 0.0623, \"Acousticness\": 0.116, \"Liveness\": 0.12, \"Tempo\": 134.997, \"Duration (ms)\": 224042.0, \"Valence\": 0.408, \"Chord\": \"G\"}, {\"Index\": 221, \"Highest Charting Position\": 75, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Follow You\", \"Streams\": 5097187, \"Artist\": \"Imagine Dragons\", \"Artist Followers\": 35285425.0, \"Song ID\": \"7FdUvDkaE24o3FPIWTvzv2\", \"Genre\": \"['modern rock', 'pop', 'rock']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 84.0, \"Danceability\": 0.542, \"Energy\": 0.732, \"Loudness\": -5.956, \"Speechiness\": 0.0521, \"Acousticness\": 0.00209, \"Liveness\": 0.496, \"Tempo\": 124.912, \"Duration (ms)\": 175644.0, \"Valence\": 0.489, \"Chord\": \"A\"}, {\"Index\": 222, \"Highest Charting Position\": 22, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"We're Good\", \"Streams\": 6318660, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"1diS6nkxMQc3wwC4G1j0bh\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 83.0, \"Danceability\": 0.722, \"Energy\": 0.588, \"Loudness\": -5.932, \"Speechiness\": 0.0544, \"Acousticness\": 0.0319, \"Liveness\": 0.183, \"Tempo\": 134.01, \"Duration (ms)\": 165507.0, \"Valence\": 0.59, \"Chord\": \"F#/Gb\"}, {\"Index\": 223, \"Highest Charting Position\": 4, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Life Goes On\", \"Streams\": 6142975, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"249gnXrbfmV8NG6jTEMSwD\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 84.0, \"Danceability\": 0.566, \"Energy\": 0.716, \"Loudness\": -5.733, \"Speechiness\": 0.0424, \"Acousticness\": 0.00691, \"Liveness\": 0.37, \"Tempo\": 81.068, \"Duration (ms)\": 207481.0, \"Valence\": 0.45, \"Chord\": \"C#/Db\"}, {\"Index\": 224, \"Highest Charting Position\": 28, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"911\", \"Streams\": 6111108, \"Artist\": \"Sech\", \"Artist Followers\": 8758283.0, \"Song ID\": \"27RSJHEA99Y0Vsow7nA37A\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2020-05-29--2020-06-05\", \"Popularity\": 89.0, \"Danceability\": 0.816, \"Energy\": 0.71, \"Loudness\": -3.728, \"Speechiness\": 0.0398, \"Acousticness\": 0.165, \"Liveness\": 0.292, \"Tempo\": 93.02, \"Duration (ms)\": 208631.0, \"Valence\": 0.784, \"Chord\": \"G\"}, {\"Index\": 225, \"Highest Charting Position\": 17, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Baila Conmigo (with Rauw Alejandro)\", \"Streams\": 5588217, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28909504.0, \"Song ID\": \"079Ey5uxL04AKPQgVQwx5h\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 84.0, \"Danceability\": 0.823, \"Energy\": 0.544, \"Loudness\": -7.132, \"Speechiness\": 0.0715, \"Acousticness\": 0.0215, \"Liveness\": 0.0966, \"Tempo\": 149.903, \"Duration (ms)\": 186088.0, \"Valence\": 0.664, \"Chord\": \"F\"}, {\"Index\": 226, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"The Jackie (with J. Cole & Lil Tjay)\", \"Streams\": 5454994, \"Artist\": \"Bas\", \"Artist Followers\": 386757.0, \"Song ID\": \"15qKrPi4Kg0z7g9HlwWyeb\", \"Genre\": \"['hip hop', 'pop rap', 'queens hip hop', 'rap', 'sudanese pop', 'underground hip hop']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-09--2021-07-16\", \"Popularity\": 76.0, \"Danceability\": 0.784, \"Energy\": 0.474, \"Loudness\": -6.139, \"Speechiness\": 0.0524, \"Acousticness\": 0.333, \"Liveness\": 0.278, \"Tempo\": 128.012, \"Duration (ms)\": 204434.0, \"Valence\": 0.64, \"Chord\": \"G#/Ab\"}, {\"Index\": 227, \"Highest Charting Position\": 22, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"hope ur ok\", \"Streams\": 5435614, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"1zejeOnykpCoyVSit6Bwp3\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 84.0, \"Danceability\": 0.443, \"Energy\": 0.298, \"Loudness\": -12.181, \"Speechiness\": 0.0644, \"Acousticness\": 0.388, \"Liveness\": 0.103, \"Tempo\": 77.253, \"Duration (ms)\": 209560.0, \"Valence\": 0.172, \"Chord\": \"C\"}, {\"Index\": 228, \"Highest Charting Position\": 169, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Faz Amor Comigo S\\u00f3 Hoje - Ao Vivo\", \"Streams\": 5269757, \"Artist\": \"Israel & Rodolffo, Wesley Safad\\u00e3o\", \"Artist Followers\": 1097789.0, \"Song ID\": \"7Kba4OaxQFQ1zlknQUpNqN\", \"Genre\": \"['sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2021-05-26\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 82.0, \"Danceability\": 0.624, \"Energy\": 0.922, \"Loudness\": -4.628, \"Speechiness\": 0.0439, \"Acousticness\": 0.3, \"Liveness\": 0.112, \"Tempo\": 164.819, \"Duration (ms)\": 148228.0, \"Valence\": 0.884, \"Chord\": \"C#/Db\"}, {\"Index\": 229, \"Highest Charting Position\": 80, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Alcohol-Free\", \"Streams\": 5259503, \"Artist\": \"TWICE\", \"Artist Followers\": 9987114.0, \"Song ID\": \"0BTaaKT4RMbs5M73tOHX5Y\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 82.0, \"Danceability\": 0.688, \"Energy\": 0.909, \"Loudness\": -1.992, \"Speechiness\": 0.0624, \"Acousticness\": 0.0474, \"Liveness\": 0.0674, \"Tempo\": 97.097, \"Duration (ms)\": 210573.0, \"Valence\": 0.702, \"Chord\": \"G#/Ab\"}, {\"Index\": 230, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"WHOLE LOTTA MONEY (feat. Nicki Minaj) - Remix\", \"Streams\": 5186354, \"Artist\": \"BIA\", \"Artist Followers\": 151870.0, \"Song ID\": \"67G6iaOw8DZqp1z8STR89R\", \"Genre\": \"['escape room', 'r&b', 'rap latina', 'trap queen']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-09--2021-07-16\", \"Popularity\": 80.0, \"Danceability\": 0.893, \"Energy\": 0.463, \"Loudness\": -5.301, \"Speechiness\": 0.36, \"Acousticness\": 0.199, \"Liveness\": 0.318, \"Tempo\": 81.026, \"Duration (ms)\": 229601.0, \"Valence\": 0.591, \"Chord\": \"C#/Db\"}, {\"Index\": 231, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Memory\", \"Streams\": 5173178, \"Artist\": \"Kane Brown, blackbear\", \"Artist Followers\": 3507622.0, \"Song ID\": \"34chhNX59Wo9HMFCsI3K8Y\", \"Genre\": \"['contemporary country', 'country road']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-09--2021-07-16\", \"Popularity\": 80.0, \"Danceability\": 0.434, \"Energy\": 0.889, \"Loudness\": -5.684, \"Speechiness\": 0.0509, \"Acousticness\": 0.395, \"Liveness\": 0.273, \"Tempo\": 113.326, \"Duration (ms)\": 153338.0, \"Valence\": 0.845, \"Chord\": \"A\"}, {\"Index\": 232, \"Highest Charting Position\": 183, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Me Fije\", \"Streams\": 5068677, \"Artist\": \"Alex Rose, Rauw Alejandro\", \"Artist Followers\": 2166191.0, \"Song ID\": \"6Et5KimMg3IXwD6lJPGmQw\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2021-03-18\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-05-07--2021-05-14\", \"Popularity\": 83.0, \"Danceability\": 0.76, \"Energy\": 0.674, \"Loudness\": -4.039, \"Speechiness\": 0.0636, \"Acousticness\": 0.396, \"Liveness\": 0.0977, \"Tempo\": 172.024, \"Duration (ms)\": 202307.0, \"Valence\": 0.735, \"Chord\": \"G\"}, {\"Index\": 233, \"Highest Charting Position\": 71, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Volta Beb\\u00ea, Volta Nen\\u00e9m\", \"Streams\": 5041120, \"Artist\": \"Dj Guuga, DJ Ivis\", \"Artist Followers\": 608109.0, \"Song ID\": \"4wQUopWk9Ed7Ng5qpKN5qd\", \"Genre\": \"['funk carioca', 'funk paulista', 'rave funk']\", \"Release Date\": \"2021-03-27\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 79.0, \"Danceability\": 0.583, \"Energy\": 0.918, \"Loudness\": -3.612, \"Speechiness\": 0.0518, \"Acousticness\": 0.288, \"Liveness\": 0.0701, \"Tempo\": 164.081, \"Duration (ms)\": 172973.0, \"Valence\": 0.836, \"Chord\": \"F#/Gb\"}, {\"Index\": 234, \"Highest Charting Position\": 95, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Aloha\", \"Streams\": 5036030, \"Artist\": \"Maluma, Be\\u00e9le, Rauw Alejandro, Mambo Kingz, DJ Luian, Darell\", \"Artist Followers\": 26769304.0, \"Song ID\": \"5RAIMjdrCEjpjaR5tBATXU\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 84.0, \"Danceability\": 0.807, \"Energy\": 0.712, \"Loudness\": -5.757, \"Speechiness\": 0.1, \"Acousticness\": 0.532, \"Liveness\": 0.163, \"Tempo\": 100.004, \"Duration (ms)\": 241659.0, \"Valence\": 0.792, \"Chord\": \"C#/Db\"}, {\"Index\": 235, \"Highest Charting Position\": 184, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Sexo Virtual\", \"Streams\": 4975786, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6080597.0, \"Song ID\": \"0giiXonRhODYy4J1iy4Lb3\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 82.0, \"Danceability\": 0.704, \"Energy\": 0.739, \"Loudness\": -3.286, \"Speechiness\": 0.112, \"Acousticness\": 0.328, \"Liveness\": 0.0856, \"Tempo\": 179.879, \"Duration (ms)\": 208292.0, \"Valence\": 0.425, \"Chord\": \"G#/Ab\"}, {\"Index\": 236, \"Highest Charting Position\": 141, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Closer\", \"Streams\": 4954679, \"Artist\": \"The Chainsmokers, Halsey\", \"Artist Followers\": 18191658.0, \"Song ID\": \"7BKLCZ1jbUBVqRi2FVlTVw\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2016-07-29\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-01--2021-01-08\\n2020-08-14--2020-08-21\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.748, \"Energy\": 0.524, \"Loudness\": -5.599, \"Speechiness\": 0.0338, \"Acousticness\": 0.414, \"Liveness\": 0.111, \"Tempo\": 95.01, \"Duration (ms)\": 244960.0, \"Valence\": 0.661, \"Chord\": \"G#/Ab\"}, {\"Index\": 237, \"Highest Charting Position\": 194, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Wonderwall - Remastered\", \"Streams\": 4938180, \"Artist\": \"Oasis\", \"Artist Followers\": 6475631.0, \"Song ID\": \"7ygpwy2qP3NbrxVkHvUhXY\", \"Genre\": \"['beatlesque', 'britpop', 'madchester', 'permanent wave', 'rock']\", \"Release Date\": \"1995\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-05-28--2021-06-04\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 78.0, \"Danceability\": 0.375, \"Energy\": 0.893, \"Loudness\": -4.097, \"Speechiness\": 0.0406, \"Acousticness\": 0.000509, \"Liveness\": 0.187, \"Tempo\": 174.323, \"Duration (ms)\": 258773.0, \"Valence\": 0.434, \"Chord\": \"D\"}, {\"Index\": 238, \"Highest Charting Position\": 101, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Wasting Time ( feat. Drake )\", \"Streams\": 6731106, \"Artist\": \"Brent Faiyaz\", \"Artist Followers\": 1724414.0, \"Song ID\": \"48WidxP9CqyYtk97pwGZ3c\", \"Genre\": \"['dmv rap', 'pop', 'r&b', 'rap']\", \"Release Date\": \"2021-07-01\", \"Weeks Charted\": \"2021-07-02--2021-07-09\", \"Popularity\": 78.0, \"Danceability\": 0.652, \"Energy\": 0.717, \"Loudness\": -3.751, \"Speechiness\": 0.0581, \"Acousticness\": 0.0694, \"Liveness\": 0.0906, \"Tempo\": 89.982, \"Duration (ms)\": 301304.0, \"Valence\": 0.377, \"Chord\": \"G\"}, {\"Index\": 239, \"Highest Charting Position\": 55, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"I Don't Do Drugs (feat. Ariana Grande)\", \"Streams\": 5912293, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0FFsgUoFibYISzMxuGS61W\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 80.0, \"Danceability\": 0.683, \"Energy\": 0.615, \"Loudness\": -5.737, \"Speechiness\": 0.0966, \"Acousticness\": 0.222, \"Liveness\": 0.154, \"Tempo\": 77.014, \"Duration (ms)\": 188893.0, \"Valence\": 0.45, \"Chord\": \"F\"}, {\"Index\": 240, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Renegade (feat. Taylor Swift)\", \"Streams\": 5876058, \"Artist\": \"Big Red Machine\", \"Artist Followers\": 98503.0, \"Song ID\": \"1aU1wpYBSpP0M6IiihY5Ue\", \"Genre\": \"['eau claire indie', 'folktronica']\", \"Release Date\": \"2021-07-02\", \"Weeks Charted\": \"2021-07-02--2021-07-09\", \"Popularity\": 77.0, \"Danceability\": 0.532, \"Energy\": 0.708, \"Loudness\": -8.121, \"Speechiness\": 0.0505, \"Acousticness\": 0.435, \"Liveness\": 0.107, \"Tempo\": 167.977, \"Duration (ms)\": 254467.0, \"Valence\": 0.586, \"Chord\": \"C\"}, {\"Index\": 241, \"Highest Charting Position\": 40, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"JUGGERNAUT (feat. Lil Uzi Vert & Pharrell Williams)\", \"Streams\": 5392334, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"7z4xW9WY86uH3gd1V9pfCM\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 80.0, \"Danceability\": 0.827, \"Energy\": 0.571, \"Loudness\": -7.949, \"Speechiness\": 0.366, \"Acousticness\": 0.0195, \"Liveness\": 0.166, \"Tempo\": 142.034, \"Duration (ms)\": 146419.0, \"Valence\": 0.62, \"Chord\": \"B\"}, {\"Index\": 242, \"Highest Charting Position\": 152, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"All Eyes On Me\", \"Streams\": 5347263, \"Artist\": \"Bo Burnham\", \"Artist Followers\": 1042079.0, \"Song ID\": \"3rV5y8rcQrwRt9fWGLmjOQ\", \"Genre\": \"['comic']\", \"Release Date\": \"2021-06-10\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 81.0, \"Danceability\": 0.352, \"Energy\": 0.424, \"Loudness\": -10.131, \"Speechiness\": 0.0394, \"Acousticness\": 0.733, \"Liveness\": 0.0664, \"Tempo\": 127.047, \"Duration (ms)\": 302951.0, \"Valence\": 0.141, \"Chord\": \"F#/Gb\"}, {\"Index\": 243, \"Highest Charting Position\": 101, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"EVERY CHANCE I GET (feat. Lil Baby & Lil Durk)\", \"Streams\": 5321544, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6278835.0, \"Song ID\": \"1EJIcDYXwSqipW5dFe4uJz\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 83.0, \"Danceability\": 0.477, \"Energy\": 0.727, \"Loudness\": -4.053, \"Speechiness\": 0.286, \"Acousticness\": 0.000866, \"Liveness\": 0.108, \"Tempo\": 150.062, \"Duration (ms)\": 236524.0, \"Valence\": 0.227, \"Chord\": \"D\"}, {\"Index\": 244, \"Highest Charting Position\": 72, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Dick (feat. Doja Cat)\", \"Streams\": 5258628, \"Artist\": \"StarBoi3\", \"Artist Followers\": 17202.0, \"Song ID\": \"3nY8AqaMNNHHLYV4380ol0\", \"Genre\": \"[]\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 83.0, \"Danceability\": 0.647, \"Energy\": 0.608, \"Loudness\": -6.831, \"Speechiness\": 0.42, \"Acousticness\": 0.13, \"Liveness\": 0.0584, \"Tempo\": 125.994, \"Duration (ms)\": 175238.0, \"Valence\": 0.474, \"Chord\": \"A\"}, {\"Index\": 245, \"Highest Charting Position\": 25, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Solar Power\", \"Streams\": 5234112, \"Artist\": \"Lorde\", \"Artist Followers\": 8083566.0, \"Song ID\": \"3KdoeNlEN0BoAKWzaRLNZa\", \"Genre\": \"['art pop', 'dance pop', 'electropop', 'metropopolis', 'nz pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-06-10\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 81.0, \"Danceability\": 0.735, \"Energy\": 0.47, \"Loudness\": -9.405, \"Speechiness\": 0.1, \"Acousticness\": 0.266, \"Liveness\": 0.32, \"Tempo\": 87.971, \"Duration (ms)\": 192621.0, \"Valence\": 0.897, \"Chord\": \"E\"}, {\"Index\": 246, \"Highest Charting Position\": 4, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Your Power\", \"Streams\": 5135380, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47014200.0, \"Song ID\": \"042Sl6Mn83JHyLEqdK7uI0\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-07-30\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 81.0, \"Danceability\": 0.632, \"Energy\": 0.284, \"Loudness\": -14.025, \"Speechiness\": 0.0801, \"Acousticness\": 0.932, \"Liveness\": 0.233, \"Tempo\": 129.642, \"Duration (ms)\": 245897.0, \"Valence\": 0.208, \"Chord\": \"A\"}, {\"Index\": 247, \"Highest Charting Position\": 189, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Lieben wir\", \"Streams\": 5029898, \"Artist\": \"Shirin David\", \"Artist Followers\": 558345.0, \"Song ID\": \"49gzU1IS1B6P3GATSZ5eCE\", \"Genre\": \"['frauenrap', 'german hip hop', 'german pop']\", \"Release Date\": \"2021-07-01\", \"Weeks Charted\": \"2021-07-02--2021-07-09\", \"Popularity\": 77.0, \"Danceability\": 0.871, \"Energy\": 0.669, \"Loudness\": -7.62, \"Speechiness\": 0.329, \"Acousticness\": 0.0113, \"Liveness\": 0.0795, \"Tempo\": 95.939, \"Duration (ms)\": 155363.0, \"Valence\": 0.806, \"Chord\": \"A#/Bb\"}, {\"Index\": 248, \"Highest Charting Position\": 8, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Whoopty\", \"Streams\": 5013017, \"Artist\": \"CJ\", \"Artist Followers\": 180454.0, \"Song ID\": \"5vGLcdRuSbUhD8ScwsGSdA\", \"Genre\": \"['nyc rap']\", \"Release Date\": \"2020-08-20\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 81.0, \"Danceability\": 0.719, \"Energy\": 0.648, \"Loudness\": -7.6, \"Speechiness\": 0.125, \"Acousticness\": 0.2, \"Liveness\": 0.127, \"Tempo\": 140.201, \"Duration (ms)\": 123263.0, \"Valence\": 0.66, \"Chord\": \"D#/Eb\"}, {\"Index\": 249, \"Highest Charting Position\": 55, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Batom de Cereja - Ao Vivo\", \"Streams\": 5011753, \"Artist\": \"Israel & Rodolffo\", \"Artist Followers\": 1097789.0, \"Song ID\": \"2MZQAvsA7aZDssppBLRxYp\", \"Genre\": \"['sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2021-01-29\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 83.0, \"Danceability\": 0.606, \"Energy\": 0.908, \"Loudness\": -6.201, \"Speechiness\": 0.0565, \"Acousticness\": 0.556, \"Liveness\": 0.19, \"Tempo\": 171.966, \"Duration (ms)\": 140942.0, \"Valence\": 0.798, \"Chord\": \"F#/Gb\"}, {\"Index\": 250, \"Highest Charting Position\": 11, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Prisoner (feat. Dua Lipa)\", \"Streams\": 5005018, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15770302.0, \"Song ID\": \"5JqZ3oqF00jkT81foAFvqg\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 79.0, \"Danceability\": 0.781, \"Energy\": 0.67, \"Loudness\": -3.912, \"Speechiness\": 0.0452, \"Acousticness\": 0.0103, \"Liveness\": 0.0761, \"Tempo\": 127.99, \"Duration (ms)\": 169333.0, \"Valence\": 0.595, \"Chord\": \"D#/Eb\"}, {\"Index\": 251, \"Highest Charting Position\": 136, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Stereo Hearts (feat. Adam Levine)\", \"Streams\": 4992345, \"Artist\": \"Gym Class Heroes\", \"Artist Followers\": 1275345.0, \"Song ID\": \"0qOnSQQF0yzuPWsXrQ9paz\", \"Genre\": \"['dance pop', 'pop rap']\", \"Release Date\": \"2011-11-11\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 82.0, \"Danceability\": 0.646, \"Energy\": 0.795, \"Loudness\": -3.293, \"Speechiness\": 0.0976, \"Acousticness\": 0.0319, \"Liveness\": 0.267, \"Tempo\": 89.99, \"Duration (ms)\": 210960.0, \"Valence\": 0.796, \"Chord\": \"A\"}, {\"Index\": 252, \"Highest Charting Position\": 32, \"Number of Times Charted\": 36, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Reloj\", \"Streams\": 4980155, \"Artist\": \"Rauw Alejandro, Anuel AA\", \"Artist Followers\": 6080597.0, \"Song ID\": \"7r9ZhitdQBONTFOiJW5mr8\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-10-22\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 79.0, \"Danceability\": 0.823, \"Energy\": 0.537, \"Loudness\": -2.639, \"Speechiness\": 0.209, \"Acousticness\": 0.176, \"Liveness\": 0.123, \"Tempo\": 175.946, \"Duration (ms)\": 231595.0, \"Valence\": 0.615, \"Chord\": \"G#/Ab\"}, {\"Index\": 253, \"Highest Charting Position\": 81, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"malibu\", \"Streams\": 4973063, \"Artist\": \"sangiovanni\", \"Artist Followers\": 384097.0, \"Song ID\": \"01hEpx8jnOG4q7nDK14Rhi\", \"Genre\": \"[]\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.733, \"Energy\": 0.736, \"Loudness\": -5.123, \"Speechiness\": 0.111, \"Acousticness\": 0.028, \"Liveness\": 0.131, \"Tempo\": 147.897, \"Duration (ms)\": 166216.0, \"Valence\": 0.669, \"Chord\": \"G\"}, {\"Index\": 254, \"Highest Charting Position\": 101, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Eladio Carrion: Bzrp Music Sessions, Vol. 40\", \"Streams\": 4965913, \"Artist\": \"Bizarrap, Eladio Carrion\", \"Artist Followers\": 3126961.0, \"Song ID\": \"1VauUM5CBX7nkLcgafQL2B\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2021-06-09\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 81.0, \"Danceability\": 0.783, \"Energy\": 0.524, \"Loudness\": -6.455, \"Speechiness\": 0.0554, \"Acousticness\": 0.241, \"Liveness\": 0.271, \"Tempo\": 117.496, \"Duration (ms)\": 164896.0, \"Valence\": 0.839, \"Chord\": \"F\"}, {\"Index\": 255, \"Highest Charting Position\": 117, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Do I Wanna Know?\", \"Streams\": 4938586, \"Artist\": \"Arctic Monkeys\", \"Artist Followers\": 12369079.0, \"Song ID\": \"5FVd6KXrgO9B3JPmC8OPst\", \"Genre\": \"['garage rock', 'permanent wave', 'rock', 'sheffield indie']\", \"Release Date\": \"2013-09-09\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 84.0, \"Danceability\": 0.548, \"Energy\": 0.532, \"Loudness\": -7.596, \"Speechiness\": 0.0323, \"Acousticness\": 0.186, \"Liveness\": 0.217, \"Tempo\": 85.03, \"Duration (ms)\": 272394.0, \"Valence\": 0.405, \"Chord\": \"F\"}, {\"Index\": 256, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"LUMBERJACK\", \"Streams\": 11756283, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"0BiK5BbYNFLb88CCOxBFJe\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 76.0, \"Danceability\": 0.386, \"Energy\": 0.762, \"Loudness\": -6.341, \"Speechiness\": 0.564, \"Acousticness\": 0.122, \"Liveness\": 0.527, \"Tempo\": 170.691, \"Duration (ms)\": 138312.0, \"Valence\": 0.433, \"Chord\": \"A\"}, {\"Index\": 257, \"Highest Charting Position\": 47, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"LEMONHEAD (feat. 42 Dugg)\", \"Streams\": 11380679, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"5fbHRCsGpFIOLRtlhCRFDR\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 78.0, \"Danceability\": 0.62, \"Energy\": 0.586, \"Loudness\": -6.612, \"Speechiness\": 0.212, \"Acousticness\": 0.155, \"Liveness\": 0.535, \"Tempo\": 137.131, \"Duration (ms)\": 130980.0, \"Valence\": 0.487, \"Chord\": \"C#/Db\"}, {\"Index\": 258, \"Highest Charting Position\": 59, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"HOT WIND BLOWS (feat. Lil Wayne)\", \"Streams\": 9889197, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"3JJL91ilRV6fXhKqu0FGXs\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 77.0, \"Danceability\": 0.371, \"Energy\": 0.75, \"Loudness\": -5.382, \"Speechiness\": 0.402, \"Acousticness\": 0.601, \"Liveness\": 0.482, \"Tempo\": 173.456, \"Duration (ms)\": 155293.0, \"Valence\": 0.729, \"Chord\": \"G\"}, {\"Index\": 259, \"Highest Charting Position\": 63, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"CORSO\", \"Streams\": 9503981, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"46oHvXwpEZOFX518we1nJD\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 77.0, \"Danceability\": 0.703, \"Energy\": 0.845, \"Loudness\": -4.851, \"Speechiness\": 0.337, \"Acousticness\": 0.169, \"Liveness\": 0.122, \"Tempo\": 97.672, \"Duration (ms)\": 146482.0, \"Valence\": 0.745, \"Chord\": \"A#/Bb\"}, {\"Index\": 260, \"Highest Charting Position\": 69, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"SWEET / I THOUGHT YOU WANTED TO DANCE (feat. Brent Faiyaz & Fana Hues)\", \"Streams\": 9142721, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"3EG9FJ0ToLfgnc1IG2Z1wz\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 79.0, \"Danceability\": 0.468, \"Energy\": 0.652, \"Loudness\": -4.912, \"Speechiness\": 0.0722, \"Acousticness\": 0.333, \"Liveness\": 0.55, \"Tempo\": 140.223, \"Duration (ms)\": 588139.0, \"Valence\": 0.39, \"Chord\": \"C\"}, {\"Index\": 261, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"SIR BAUDELAIRE (feat. DJ Drama)\", \"Streams\": 8884283, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"4ydmav4vl7hebadtfZtMrg\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 75.0, \"Danceability\": 0.467, \"Energy\": 0.635, \"Loudness\": -6.115, \"Speechiness\": 0.154, \"Acousticness\": 0.314, \"Liveness\": 0.844, \"Tempo\": 127.596, \"Duration (ms)\": 88625.0, \"Valence\": 0.51, \"Chord\": \"G\"}, {\"Index\": 262, \"Highest Charting Position\": 82, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"MASSA\", \"Streams\": 8218423, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"2goHCrsDJaflEwQ930ef0o\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 74.0, \"Danceability\": 0.685, \"Energy\": 0.855, \"Loudness\": -6.724, \"Speechiness\": 0.438, \"Acousticness\": 0.329, \"Liveness\": 0.301, \"Tempo\": 157.181, \"Duration (ms)\": 223719.0, \"Valence\": 0.46, \"Chord\": \"C#/Db\"}, {\"Index\": 263, \"Highest Charting Position\": 85, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"RUNITUP (feat. Teezo Touchdown)\", \"Streams\": 7917707, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"13HsOwrwTA5HgLuoaDHncP\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 75.0, \"Danceability\": 0.665, \"Energy\": 0.469, \"Loudness\": -7.778, \"Speechiness\": 0.13, \"Acousticness\": 0.565, \"Liveness\": 0.219, \"Tempo\": 115.852, \"Duration (ms)\": 229565.0, \"Valence\": 0.142, \"Chord\": \"A#/Bb\"}, {\"Index\": 264, \"Highest Charting Position\": 108, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"MANIFESTO (feat. Domo Genesis)\", \"Streams\": 6988886, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"6qouBO0wJtYc3k7DfKRUBx\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.454, \"Energy\": 0.866, \"Loudness\": -5.348, \"Speechiness\": 0.391, \"Acousticness\": 0.121, \"Liveness\": 0.167, \"Tempo\": 92.463, \"Duration (ms)\": 175123.0, \"Valence\": 0.518, \"Chord\": \"D\"}, {\"Index\": 265, \"Highest Charting Position\": 121, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Get Into It (Yuh)\", \"Streams\": 6503281, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0W6I02J9xcqK8MtSeosEXb\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 80.0, \"Danceability\": 0.912, \"Energy\": 0.655, \"Loudness\": -6.029, \"Speechiness\": 0.162, \"Acousticness\": 0.315, \"Liveness\": 0.0894, \"Tempo\": 91.942, \"Duration (ms)\": 138293.0, \"Valence\": 0.793, \"Chord\": \"G#/Ab\"}, {\"Index\": 266, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"WILSHIRE\", \"Streams\": 6268542, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"1pbbsI2KGPOMu0HmuGccBu\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.555, \"Energy\": 0.712, \"Loudness\": -7.446, \"Speechiness\": 0.323, \"Acousticness\": 0.0451, \"Liveness\": 0.182, \"Tempo\": 78.958, \"Duration (ms)\": 515865.0, \"Valence\": 0.555, \"Chord\": \"C#/Db\"}, {\"Index\": 267, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"RISE! (feat. DAISY WORLD)\", \"Streams\": 6034281, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"4Hta7Oy5W9HD0UgT1P8PPV\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.766, \"Energy\": 0.814, \"Loudness\": -3.367, \"Speechiness\": 0.0733, \"Acousticness\": 0.044, \"Liveness\": 0.195, \"Tempo\": 108.07, \"Duration (ms)\": 203588.0, \"Valence\": 0.481, \"Chord\": \"D\"}, {\"Index\": 268, \"Highest Charting Position\": 165, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Naked\", \"Streams\": 5527865, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0CsR9Y9SnC6ZWmekmVqSHz\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 75.0, \"Danceability\": 0.733, \"Energy\": 0.862, \"Loudness\": -5.736, \"Speechiness\": 0.197, \"Acousticness\": 0.374, \"Liveness\": 0.131, \"Tempo\": 111.076, \"Duration (ms)\": 223560.0, \"Valence\": 0.536, \"Chord\": \"G\"}, {\"Index\": 269, \"Highest Charting Position\": 50, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Having Our Way (feat. Drake)\", \"Streams\": 5424579, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"2NM0qHzx4Ohy8iXHEEgwlO\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 79.0, \"Danceability\": 0.927, \"Energy\": 0.538, \"Loudness\": -3.917, \"Speechiness\": 0.116, \"Acousticness\": 0.0312, \"Liveness\": 0.0945, \"Tempo\": 125.983, \"Duration (ms)\": 278191.0, \"Valence\": 0.221, \"Chord\": \"C#/Db\"}, {\"Index\": 270, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Payday (feat. Young Thug)\", \"Streams\": 5393789, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"2HolBGR6tpiWI80MXoV1dJ\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.619, \"Energy\": 0.707, \"Loudness\": -5.791, \"Speechiness\": 0.0499, \"Acousticness\": 0.0366, \"Liveness\": 0.13, \"Tempo\": 168.995, \"Duration (ms)\": 212947.0, \"Valence\": 0.558, \"Chord\": \"C#/Db\"}, {\"Index\": 271, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Been Like This\", \"Streams\": 5362817, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"7y3xU9vEC1s8DSuuoSYKih\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 74.0, \"Danceability\": 0.678, \"Energy\": 0.531, \"Loudness\": -5.029, \"Speechiness\": 0.0374, \"Acousticness\": 0.126, \"Liveness\": 0.377, \"Tempo\": 99.008, \"Duration (ms)\": 177373.0, \"Valence\": 0.176, \"Chord\": \"A#/Bb\"}, {\"Index\": 272, \"Highest Charting Position\": 138, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"MILLE (feat. Orietta Berti)\", \"Streams\": 5341887, \"Artist\": \"Fedez, Achille Lauro\", \"Artist Followers\": 1650683.0, \"Song ID\": \"6qdMhG7pRFi0csRlFGvLE4\", \"Genre\": \"['italian adult pop', 'italian pop']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 82.0, \"Danceability\": 0.527, \"Energy\": 0.764, \"Loudness\": -4.297, \"Speechiness\": 0.322, \"Acousticness\": 0.016, \"Liveness\": 0.0273, \"Tempo\": 184.339, \"Duration (ms)\": 175924.0, \"Valence\": 0.829, \"Chord\": \"D\"}, {\"Index\": 273, \"Highest Charting Position\": 10, \"Number of Times Charted\": 49, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"UN DIA (ONE DAY) (Feat. Tainy)\", \"Streams\": 5203364, \"Artist\": \"J Balvin, Dua Lipa, Bad Bunny\", \"Artist Followers\": 29051363.0, \"Song ID\": \"0EhpEsp4L0oRGM0vmeaN5e\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 83.0, \"Danceability\": 0.571, \"Energy\": 0.693, \"Loudness\": -8.234, \"Speechiness\": 0.0545, \"Acousticness\": 0.00536, \"Liveness\": 0.173, \"Tempo\": 168.169, \"Duration (ms)\": 232253.0, \"Valence\": 0.393, \"Chord\": \"F#/Gb\"}, {\"Index\": 274, \"Highest Charting Position\": 1, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Savage Love (Laxed - Siren Beat)\", \"Streams\": 5108950, \"Artist\": \"Jawsh 685, Jason Derulo\", \"Artist Followers\": 100604.0, \"Song ID\": \"1xQ6trAsedVPCdbtDAmk0c\", \"Genre\": \"['nz pop']\", \"Release Date\": \"2020-06-11\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 82.0, \"Danceability\": 0.767, \"Energy\": 0.481, \"Loudness\": -8.52, \"Speechiness\": 0.0803, \"Acousticness\": 0.234, \"Liveness\": 0.269, \"Tempo\": 150.076, \"Duration (ms)\": 171375.0, \"Valence\": 0.761, \"Chord\": \"C\"}, {\"Index\": 275, \"Highest Charting Position\": 59, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Poblado\", \"Streams\": 6893939, \"Artist\": \"Crissin, Totoy El Frio, Natan & Shander\", \"Artist Followers\": 29051363.0, \"Song ID\": \"1WedZeiezCmCEOzLwhx0hV\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 89.0, \"Danceability\": 0.813, \"Energy\": 0.809, \"Loudness\": -5.382, \"Speechiness\": 0.0846, \"Acousticness\": 0.102, \"Liveness\": 0.377, \"Tempo\": 93.005, \"Duration (ms)\": 393280.0, \"Valence\": 0.646, \"Chord\": \"D#/Eb\"}, {\"Index\": 276, \"Highest Charting Position\": 17, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Hecha Pa' Mi\", \"Streams\": 6308369, \"Artist\": \"Boza\", \"Artist Followers\": 278679.0, \"Song ID\": \"3VvA1wSxukMLsvXoXtlwWx\", \"Genre\": \"['reggaeton']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 83.0, \"Danceability\": 0.725, \"Energy\": 0.756, \"Loudness\": -5.013, \"Speechiness\": 0.0572, \"Acousticness\": 0.362, \"Liveness\": 0.103, \"Tempo\": 100.07, \"Duration (ms)\": 186133.0, \"Valence\": 0.828, \"Chord\": \"E\"}, {\"Index\": 277, \"Highest Charting Position\": 146, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"working\", \"Streams\": 5666770, \"Artist\": \"Tate McRae, Khalid\", \"Artist Followers\": 1647262.0, \"Song ID\": \"31sSFHIe4NaxltVFOEIcTa\", \"Genre\": \"['alt z', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-06-17\", \"Weeks Charted\": \"2021-06-18--2021-06-25\", \"Popularity\": 80.0, \"Danceability\": 0.783, \"Energy\": 0.435, \"Loudness\": -7.78, \"Speechiness\": 0.0588, \"Acousticness\": 0.282, \"Liveness\": 0.0833, \"Tempo\": 106.974, \"Duration (ms)\": 210220.0, \"Valence\": 0.512, \"Chord\": \"G\"}, {\"Index\": 278, \"Highest Charting Position\": 112, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Petrouchka (feat. PLK)\", \"Streams\": 5511544, \"Artist\": \"Soso Maness\", \"Artist Followers\": 289437.0, \"Song ID\": \"03y045SZqaC94yfXl1cU4E\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais', 'rap marseille']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 79.0, \"Danceability\": 0.624, \"Energy\": 0.802, \"Loudness\": -4.818, \"Speechiness\": 0.311, \"Acousticness\": 0.0597, \"Liveness\": 0.252, \"Tempo\": 133.888, \"Duration (ms)\": 189933.0, \"Valence\": 0.818, \"Chord\": \"F#/Gb\"}, {\"Index\": 279, \"Highest Charting Position\": 11, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"p r i d e . i s . t h e . d e v i l (with Lil Baby)\", \"Streams\": 5430260, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5W8jRrZ6tWrTrqnKRtIQBf\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.861, \"Energy\": 0.656, \"Loudness\": -7.867, \"Speechiness\": 0.425, \"Acousticness\": 0.104, \"Liveness\": 0.0986, \"Tempo\": 88.967, \"Duration (ms)\": 218210.0, \"Valence\": 0.331, \"Chord\": \"E\"}, {\"Index\": 280, \"Highest Charting Position\": 6, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"m y . l i f e (with 21 Savage & Morray)\", \"Streams\": 5246577, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"1D3z6HTiQsNmZxjl7F7eoG\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.597, \"Energy\": 0.587, \"Loudness\": -7.026, \"Speechiness\": 0.137, \"Acousticness\": 0.0622, \"Liveness\": 0.214, \"Tempo\": 140.021, \"Duration (ms)\": 218802.0, \"Valence\": 0.0753, \"Chord\": \"G\"}, {\"Index\": 281, \"Highest Charting Position\": 96, \"Number of Times Charted\": 77, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Jocelyn Flores\", \"Streams\": 5220422, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29539807.0, \"Song ID\": \"7m9OqQk4RVRkw9JJdeAw96\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2017-08-25\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.872, \"Energy\": 0.391, \"Loudness\": -9.144, \"Speechiness\": 0.242, \"Acousticness\": 0.469, \"Liveness\": 0.297, \"Tempo\": 134.021, \"Duration (ms)\": 119133.0, \"Valence\": 0.437, \"Chord\": \"C\"}, {\"Index\": 282, \"Highest Charting Position\": 66, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"No Return (with The Kid LAROI & Lil Durk)\", \"Streams\": 5189427, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"23OYT3SFtoJqhiAUqktbc1\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 80.0, \"Danceability\": 0.479, \"Energy\": 0.645, \"Loudness\": -7.336, \"Speechiness\": 0.302, \"Acousticness\": 0.135, \"Liveness\": 0.0825, \"Tempo\": 155.057, \"Duration (ms)\": 168729.0, \"Valence\": 0.381, \"Chord\": \"F\"}, {\"Index\": 283, \"Highest Charting Position\": 1, \"Number of Times Charted\": 78, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"The Box\", \"Streams\": 5145099, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6603627.0, \"Song ID\": \"0nbXyq5TXYPCO7pr3N8S4I\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.896, \"Energy\": 0.586, \"Loudness\": -6.687, \"Speechiness\": 0.0559, \"Acousticness\": 0.104, \"Liveness\": 0.79, \"Tempo\": 116.971, \"Duration (ms)\": 196653.0, \"Valence\": 0.642, \"Chord\": \"A#/Bb\"}, {\"Index\": 284, \"Highest Charting Position\": 31, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Wellerman - Sea Shanty / 220 KID x Billen Ted Remix\", \"Streams\": 5124606, \"Artist\": \"Nathan Evans\", \"Artist Followers\": 140812.0, \"Song ID\": \"3iw6V4LH7yPj1ESORX9RIN\", \"Genre\": \"[]\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 83.0, \"Danceability\": 0.722, \"Energy\": 0.893, \"Loudness\": -3.255, \"Speechiness\": 0.0475, \"Acousticness\": 0.0441, \"Liveness\": 0.0673, \"Tempo\": 119.932, \"Duration (ms)\": 116750.0, \"Valence\": 0.439, \"Chord\": \"C\"}, {\"Index\": 285, \"Highest Charting Position\": 170, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Can't Hold Us - feat. Ray Dalton\", \"Streams\": 5085147, \"Artist\": \"Macklemore & Ryan Lewis\", \"Artist Followers\": 2562082.0, \"Song ID\": \"3bidbhpOYeV4knp8AIu8Xn\", \"Genre\": \"['modern rock', 'pop rap', 'seattle hip hop']\", \"Release Date\": \"2012-10-09\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.641, \"Energy\": 0.922, \"Loudness\": -4.457, \"Speechiness\": 0.0786, \"Acousticness\": 0.0291, \"Liveness\": 0.0862, \"Tempo\": 146.078, \"Duration (ms)\": 258343.0, \"Valence\": 0.847, \"Chord\": \"D\"}, {\"Index\": 286, \"Highest Charting Position\": 6, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Anyone\", \"Streams\": 5079587, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 1250353.0, \"Song ID\": \"2RwMwWo43LapkA4raptxaB\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-01-31--2020-02-07\", \"Popularity\": 0.0, \"Danceability\": 0.686, \"Energy\": 0.538, \"Loudness\": -8.026, \"Speechiness\": 0.0345, \"Acousticness\": 0.181, \"Liveness\": 0.113, \"Tempo\": 115.884, \"Duration (ms)\": 190779.0, \"Valence\": 0.584, \"Chord\": \"D\"}, {\"Index\": 287, \"Highest Charting Position\": 39, \"Number of Times Charted\": 45, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"my ex's best friend (with blackbear)\", \"Streams\": 5048079, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3864419.0, \"Song ID\": \"7kDUspsoYfLkWnZR7qwHZl\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 83.0, \"Danceability\": 0.731, \"Energy\": 0.675, \"Loudness\": -5.134, \"Speechiness\": 0.0434, \"Acousticness\": 0.00473, \"Liveness\": 0.141, \"Tempo\": 124.939, \"Duration (ms)\": 139461.0, \"Valence\": 0.298, \"Chord\": \"F\"}, {\"Index\": 288, \"Highest Charting Position\": 133, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Just the Way You Are\", \"Streams\": 5043647, \"Artist\": \"Bruno Mars\", \"Artist Followers\": 32574754.0, \"Song ID\": \"7BqBn9nzAq8spo5e7cZ0dJ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2010-10-05\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 80.0, \"Danceability\": 0.637, \"Energy\": 0.843, \"Loudness\": -5.413, \"Speechiness\": 0.0432, \"Acousticness\": 0.0151, \"Liveness\": 0.0876, \"Tempo\": 109.012, \"Duration (ms)\": 220733.0, \"Valence\": 0.434, \"Chord\": \"F\"}, {\"Index\": 289, \"Highest Charting Position\": 17, \"Number of Times Charted\": 78, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"HIGHEST IN THE ROOM\", \"Streams\": 4975720, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17719446.0, \"Song ID\": \"3eekarcy7kvN4yt5ZFzltW\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.598, \"Energy\": 0.427, \"Loudness\": -8.764, \"Speechiness\": 0.0317, \"Acousticness\": 0.0546, \"Liveness\": 0.21, \"Tempo\": 76.469, \"Duration (ms)\": 175721.0, \"Valence\": 0.0605, \"Chord\": \"G\"}, {\"Index\": 290, \"Highest Charting Position\": 7, \"Number of Times Charted\": 65, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Break My Heart\", \"Streams\": 4971176, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"017PF4Q3l4DBUiWoXk4OWT\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 80.0, \"Danceability\": 0.73, \"Energy\": 0.729, \"Loudness\": -3.434, \"Speechiness\": 0.0884, \"Acousticness\": 0.167, \"Liveness\": 0.349, \"Tempo\": 113.011, \"Duration (ms)\": 221820.0, \"Valence\": 0.467, \"Chord\": \"E\"}, {\"Index\": 291, \"Highest Charting Position\": 2, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Laugh Now Cry Later (feat. Lil Durk)\", \"Streams\": 4916860, \"Artist\": \"Drake\", \"Artist Followers\": 56308172.0, \"Song ID\": \"2SAqBLGA283SUiwJ3xOUVI\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 83.0, \"Danceability\": 0.761, \"Energy\": 0.518, \"Loudness\": -8.871, \"Speechiness\": 0.134, \"Acousticness\": 0.244, \"Liveness\": 0.107, \"Tempo\": 133.976, \"Duration (ms)\": 261493.0, \"Valence\": 0.522, \"Chord\": \"C\"}, {\"Index\": 292, \"Highest Charting Position\": 175, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"We Are The People (feat. Bono & The Edge) - Official UEFA EURO 2020 Song\", \"Streams\": 4912036, \"Artist\": \"Martin Garrix\", \"Artist Followers\": 14917926.0, \"Song ID\": \"2iL0W5qi0ivZ9WRXbZ74cS\", \"Genre\": \"['dance pop', 'dutch edm', 'edm', 'pop', 'pop dance', 'progressive house', 'tropical house']\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.66, \"Energy\": 0.733, \"Loudness\": -4.619, \"Speechiness\": 0.0359, \"Acousticness\": 0.248, \"Liveness\": 0.17, \"Tempo\": 119.933, \"Duration (ms)\": 217000.0, \"Valence\": 0.304, \"Chord\": \"C\"}, {\"Index\": 293, \"Highest Charting Position\": 23, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Ella No Es Tuya - Remix\", \"Streams\": 4911162, \"Artist\": \"Rochy RD, Myke Towers, Nicki Nicole\", \"Artist Followers\": 319192.0, \"Song ID\": \"5YYW3yRktprLRr47WK219Y\", \"Genre\": \"['dembow', 'dominican pop', 'rap dominicano', 'trap latino']\", \"Release Date\": \"2021-02-03\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 82.0, \"Danceability\": 0.585, \"Energy\": 0.611, \"Loudness\": -4.132, \"Speechiness\": 0.288, \"Acousticness\": 0.39, \"Liveness\": 0.649, \"Tempo\": 97.041, \"Duration (ms)\": 218107.0, \"Valence\": 0.962, \"Chord\": \"F#/Gb\"}, {\"Index\": 294, \"Highest Charting Position\": 176, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"In the End\", \"Streams\": 4910070, \"Artist\": \"Linkin Park\", \"Artist Followers\": 19584111.0, \"Song ID\": \"60a0Rd6pjrkxjPbaKzXjfq\", \"Genre\": \"['alternative metal', 'nu metal', 'post-grunge', 'rap metal']\", \"Release Date\": \"2000-10-24\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-03-19--2021-03-26\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 83.0, \"Danceability\": 0.556, \"Energy\": 0.864, \"Loudness\": -5.87, \"Speechiness\": 0.0584, \"Acousticness\": 0.00958, \"Liveness\": 0.209, \"Tempo\": 105.143, \"Duration (ms)\": 216880.0, \"Valence\": 0.4, \"Chord\": \"D#/Eb\"}, {\"Index\": 295, \"Highest Charting Position\": 119, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"No Role Modelz\", \"Streams\": 4904401, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"62vpWI1CHwFy7tMIcSStl8\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2014-12-09\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 84.0, \"Danceability\": 0.692, \"Energy\": 0.521, \"Loudness\": -8.465, \"Speechiness\": 0.33, \"Acousticness\": 0.301, \"Liveness\": 0.0565, \"Tempo\": 100.45, \"Duration (ms)\": 292987.0, \"Valence\": 0.463, \"Chord\": \"A#/Bb\"}, {\"Index\": 296, \"Highest Charting Position\": 7, \"Number of Times Charted\": 74, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"SICKO MODE\", \"Streams\": 4898977, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17719446.0, \"Song ID\": \"2xLMifQCjDGFmkHkpNLD9h\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2018-08-03\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.834, \"Energy\": 0.73, \"Loudness\": -3.714, \"Speechiness\": 0.222, \"Acousticness\": 0.00513, \"Liveness\": 0.124, \"Tempo\": 155.008, \"Duration (ms)\": 312820.0, \"Valence\": 0.446, \"Chord\": \"G#/Ab\"}, {\"Index\": 297, \"Highest Charting Position\": 161, \"Number of Times Charted\": 41, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Something Just Like This\", \"Streams\": 4862683, \"Artist\": \"The Chainsmokers, Coldplay\", \"Artist Followers\": 18191658.0, \"Song ID\": \"6RUKPb4LETWmmr3iAEQktW\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2017-04-07\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-02-26--2021-03-05\\n2021-01-01--2021-01-08\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.617, \"Energy\": 0.635, \"Loudness\": -6.769, \"Speechiness\": 0.0317, \"Acousticness\": 0.0498, \"Liveness\": 0.164, \"Tempo\": 103.019, \"Duration (ms)\": 247160.0, \"Valence\": 0.446, \"Chord\": \"B\"}, {\"Index\": 298, \"Highest Charting Position\": 84, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"You\", \"Streams\": 4846549, \"Artist\": \"Regard, Troye Sivan, Tate McRae\", \"Artist Followers\": 152226.0, \"Song ID\": \"2cc8Sw1OnCuA5bV8nqWqpE\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop edm', 'slap house', 'tropical house']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 83.0, \"Danceability\": 0.691, \"Energy\": 0.695, \"Loudness\": -5.6, \"Speechiness\": 0.0367, \"Acousticness\": 0.0592, \"Liveness\": 0.0647, \"Tempo\": 106.064, \"Duration (ms)\": 233386.0, \"Valence\": 0.514, \"Chord\": \"C\"}, {\"Index\": 299, \"Highest Charting Position\": 84, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Straightenin\", \"Streams\": 7615531, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"3X2r2CnHOJeV5YekPTgBnK\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 77.0, \"Danceability\": 0.847, \"Energy\": 0.629, \"Loudness\": -5.81, \"Speechiness\": 0.102, \"Acousticness\": 0.0318, \"Liveness\": 0.152, \"Tempo\": 135.976, \"Duration (ms)\": 255532.0, \"Valence\": 0.109, \"Chord\": \"A\"}, {\"Index\": 300, \"Highest Charting Position\": 71, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"GANG GANG (with Lil Wayne)\", \"Streams\": 7506580, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"4VW44pawoOHPUjlN7DX5vk\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 78.0, \"Danceability\": 0.752, \"Energy\": 0.563, \"Loudness\": -8.066, \"Speechiness\": 0.209, \"Acousticness\": 0.146, \"Liveness\": 0.103, \"Tempo\": 145.05, \"Duration (ms)\": 178776.0, \"Valence\": 0.551, \"Chord\": \"D#/Eb\"}, {\"Index\": 301, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Black Hearted\", \"Streams\": 6989528, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"25qk9xa71F1POdI4vj7rbi\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 75.0, \"Danceability\": 0.506, \"Energy\": 0.563, \"Loudness\": -7.664, \"Speechiness\": 0.411, \"Acousticness\": 0.0326, \"Liveness\": 0.0856, \"Tempo\": 168.146, \"Duration (ms)\": 190509.0, \"Valence\": 0.153, \"Chord\": \"C#/Db\"}, {\"Index\": 302, \"Highest Charting Position\": 124, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Lost\", \"Streams\": 6410263, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32262679.0, \"Song ID\": \"18XlJEroUwFo0tLZxscgXE\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 79.0, \"Danceability\": 0.766, \"Energy\": 0.706, \"Loudness\": -6.553, \"Speechiness\": 0.16, \"Acousticness\": 0.223, \"Liveness\": 0.064, \"Tempo\": 142.989, \"Duration (ms)\": 172598.0, \"Valence\": 0.766, \"Chord\": \"G\"}, {\"Index\": 303, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Avalanche\", \"Streams\": 6323268, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"4KD0lLJ4OGonZhBeKtct9I\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 71.0, \"Danceability\": 0.917, \"Energy\": 0.623, \"Loudness\": -8.231, \"Speechiness\": 0.135, \"Acousticness\": 0.0985, \"Liveness\": 0.0833, \"Tempo\": 126.063, \"Duration (ms)\": 206272.0, \"Valence\": 0.687, \"Chord\": \"C#/Db\"}, {\"Index\": 304, \"Highest Charting Position\": 59, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"My Head & My Heart\", \"Streams\": 5470147, \"Artist\": \"Ava Max\", \"Artist Followers\": 3911473.0, \"Song ID\": \"1KixkQVDUHggZMU9dUobgm\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 83.0, \"Danceability\": 0.614, \"Energy\": 0.934, \"Loudness\": -3.709, \"Speechiness\": 0.07, \"Acousticness\": 0.0697, \"Liveness\": 0.121, \"Tempo\": 116.001, \"Duration (ms)\": 174760.0, \"Valence\": 0.436, \"Chord\": \"A\"}, {\"Index\": 305, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Malibu (feat. Polo G)\", \"Streams\": 5456648, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"3v1zVVdzNVNt7vmI9VG2gq\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 72.0, \"Danceability\": 0.831, \"Energy\": 0.719, \"Loudness\": -6.836, \"Speechiness\": 0.235, \"Acousticness\": 0.514, \"Liveness\": 0.0675, \"Tempo\": 155.038, \"Duration (ms)\": 248652.0, \"Valence\": 0.859, \"Chord\": \"A#/Bb\"}, {\"Index\": 306, \"Highest Charting Position\": 36, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"GIRL LIKE ME\", \"Streams\": 5395181, \"Artist\": \"Black Eyed Peas, Shakira\", \"Artist Followers\": 5963840.0, \"Song ID\": \"1zLBsSVxETQOfINOLYvT5m\", \"Genre\": \"['dance pop', 'pop', 'pop rap']\", \"Release Date\": \"2020-11-02\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\", \"Popularity\": 82.0, \"Danceability\": 0.965, \"Energy\": 0.485, \"Loudness\": -8.784, \"Speechiness\": 0.191, \"Acousticness\": 0.0206, \"Liveness\": 0.0655, \"Tempo\": 124.025, \"Duration (ms)\": 222523.0, \"Valence\": 0.312, \"Chord\": \"D\"}, {\"Index\": 307, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Clueless (with Pop Smoke & Fivio Foreign)\", \"Streams\": 5335308, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"4CPcZHzSvIBM8AKhdHUwnL\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 74.0, \"Danceability\": 0.734, \"Energy\": 0.712, \"Loudness\": -6.217, \"Speechiness\": 0.201, \"Acousticness\": 0.391, \"Liveness\": 0.103, \"Tempo\": 140.369, \"Duration (ms)\": 165405.0, \"Valence\": 0.674, \"Chord\": \"F#/Gb\"}, {\"Index\": 308, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Modern Day\", \"Streams\": 5322745, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"2Igem6Q4sfvXGJ3JkG7Baw\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 78.0, \"Danceability\": 0.87, \"Energy\": 0.629, \"Loudness\": -7.598, \"Speechiness\": 0.279, \"Acousticness\": 0.173, \"Liveness\": 0.101, \"Tempo\": 134.944, \"Duration (ms)\": 241790.0, \"Valence\": 0.512, \"Chord\": \"B\"}, {\"Index\": 309, \"Highest Charting Position\": 2, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Therefore I Am\", \"Streams\": 5265630, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"0aACcc1jEv2C6VSmmJbllJ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 0.0, \"Danceability\": 0.889, \"Energy\": 0.34, \"Loudness\": -7.773, \"Speechiness\": 0.0697, \"Acousticness\": 0.218, \"Liveness\": 0.055, \"Tempo\": 94.009, \"Duration (ms)\": 174321.0, \"Valence\": 0.716, \"Chord\": \"B\"}, {\"Index\": 310, \"Highest Charting Position\": 12, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"TE MUDASTE\", \"Streams\": 5242347, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36142273.0, \"Song ID\": \"5RubKOuDoPn5Kj5TLVxSxY\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 82.0, \"Danceability\": 0.811, \"Energy\": 0.637, \"Loudness\": -4.835, \"Speechiness\": 0.0591, \"Acousticness\": 0.234, \"Liveness\": 0.118, \"Tempo\": 92.025, \"Duration (ms)\": 130014.0, \"Valence\": 0.471, \"Chord\": \"A#/Bb\"}, {\"Index\": 311, \"Highest Charting Position\": 108, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Tipo Gin - Ao Vivo\", \"Streams\": 5155238, \"Artist\": \"MC Kevin o Chris\", \"Artist Followers\": 2753929.0, \"Song ID\": \"4llr8mcoauwrHBtjGb7F9S\", \"Genre\": \"['funk 150 bpm', 'funk carioca']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 81.0, \"Danceability\": 0.75, \"Energy\": 0.668, \"Loudness\": -4.49, \"Speechiness\": 0.061, \"Acousticness\": 0.78, \"Liveness\": 0.338, \"Tempo\": 94.998, \"Duration (ms)\": 159147.0, \"Valence\": 0.786, \"Chord\": \"C\"}, {\"Index\": 312, \"Highest Charting Position\": 39, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Higher Power\", \"Streams\": 5142982, \"Artist\": \"Coldplay\", \"Artist Followers\": 1250353.0, \"Song ID\": \"4rOEoKL0fHrxBMhVljpbGW\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 0.0, \"Danceability\": 0.507, \"Energy\": 0.828, \"Loudness\": -6.023, \"Speechiness\": 0.0449, \"Acousticness\": 0.00711, \"Liveness\": 0.261, \"Tempo\": 178.032, \"Duration (ms)\": 211295.0, \"Valence\": 0.489, \"Chord\": \"A#/Bb\"}, {\"Index\": 313, \"Highest Charting Position\": 54, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"SUN GOES DOWN\", \"Streams\": 5125477, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5473565.0, \"Song ID\": \"34eF4BoV8FPk0uhAAoqU7h\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 80.0, \"Danceability\": 0.551, \"Energy\": 0.636, \"Loudness\": -6.798, \"Speechiness\": 0.054, \"Acousticness\": 0.0837, \"Liveness\": 0.112, \"Tempo\": 174.065, \"Duration (ms)\": 168276.0, \"Valence\": 0.148, \"Chord\": \"D\"}, {\"Index\": 314, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Painting Pictures\", \"Streams\": 5119845, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"25uBGaikHi0DhMiGMfuXYE\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 72.0, \"Danceability\": 0.522, \"Energy\": 0.466, \"Loudness\": -8.05, \"Speechiness\": 0.458, \"Acousticness\": 0.331, \"Liveness\": 0.11, \"Tempo\": 78.43, \"Duration (ms)\": 137692.0, \"Valence\": 0.459, \"Chord\": \"D#/Eb\"}, {\"Index\": 315, \"Highest Charting Position\": 1, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Rain On Me (with Ariana Grande)\", \"Streams\": 5041656, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18572085.0, \"Song ID\": \"24ySl2hOPGCDcxBxFIqWBu\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 79.0, \"Danceability\": 0.672, \"Energy\": 0.855, \"Loudness\": -3.764, \"Speechiness\": 0.0397, \"Acousticness\": 0.021, \"Liveness\": 0.323, \"Tempo\": 123.056, \"Duration (ms)\": 182200.0, \"Valence\": 0.646, \"Chord\": \"A\"}, {\"Index\": 316, \"Highest Charting Position\": 97, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Hats Off (feat. Travis Scott)\", \"Streams\": 7324233, \"Artist\": \"Lil Baby, Lil Durk\", \"Artist Followers\": 7805880.0, \"Song ID\": \"4lUmnwRybYH7mMzf16xB0y\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-06-04--2021-06-11\", \"Popularity\": 81.0, \"Danceability\": 0.596, \"Energy\": 0.65, \"Loudness\": -5.167, \"Speechiness\": 0.337, \"Acousticness\": 0.138, \"Liveness\": 0.14, \"Tempo\": 133.997, \"Duration (ms)\": 257428.0, \"Valence\": 0.188, \"Chord\": \"A\"}, {\"Index\": 317, \"Highest Charting Position\": 117, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Last Train Home\", \"Streams\": 6439718, \"Artist\": \"John Mayer\", \"Artist Followers\": 5178156.0, \"Song ID\": \"0tgBtQ0ISnMQOKorrN9HLX\", \"Genre\": \"['neo mellow', 'pop rock', 'singer-songwriter']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-06-04--2021-06-11\", \"Popularity\": 75.0, \"Danceability\": 0.591, \"Energy\": 0.831, \"Loudness\": -6.612, \"Speechiness\": 0.0355, \"Acousticness\": 0.235, \"Liveness\": 0.0571, \"Tempo\": 93.007, \"Duration (ms)\": 187307.0, \"Valence\": 0.678, \"Chord\": \"E\"}, {\"Index\": 318, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Voice of the Heroes\", \"Streams\": 6249801, \"Artist\": \"Lil Baby, Lil Durk\", \"Artist Followers\": 7805880.0, \"Song ID\": \"4lUmnwRybYH7mMzf16xB0y\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-06-04--2021-06-11\", \"Popularity\": 81.0, \"Danceability\": 0.596, \"Energy\": 0.65, \"Loudness\": -5.167, \"Speechiness\": 0.337, \"Acousticness\": 0.138, \"Liveness\": 0.14, \"Tempo\": 133.997, \"Duration (ms)\": 257428.0, \"Valence\": 0.188, \"Chord\": \"A\"}, {\"Index\": 319, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"0X1=LOVESONG (I Know I Love you)\", \"Streams\": 6040553, \"Artist\": \"TOMORROW X TOGETHER, Seori\", \"Artist Followers\": 4136553.0, \"Song ID\": \"1Z8TPHiKeCUyClxV6WTTIf\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-05-31\", \"Weeks Charted\": \"2021-06-04--2021-06-11\", \"Popularity\": 81.0, \"Danceability\": 0.584, \"Energy\": 0.836, \"Loudness\": -4.925, \"Speechiness\": 0.079, \"Acousticness\": 0.0558, \"Liveness\": 0.0663, \"Tempo\": 104.973, \"Duration (ms)\": 202204.0, \"Valence\": 0.484, \"Chord\": \"C\"}, {\"Index\": 320, \"Highest Charting Position\": 10, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"a m a r i\", \"Streams\": 5645966, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"2cnKST6T9qUo2i907lm8zX\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 79.0, \"Danceability\": 0.725, \"Energy\": 0.713, \"Loudness\": -6.173, \"Speechiness\": 0.187, \"Acousticness\": 0.127, \"Liveness\": 0.617, \"Tempo\": 65.988, \"Duration (ms)\": 148421.0, \"Valence\": 0.207, \"Chord\": \"E\"}, {\"Index\": 321, \"Highest Charting Position\": 72, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"NEVER LEFT\", \"Streams\": 5552212, \"Artist\": \"Lil Tecca\", \"Artist Followers\": 4016497.0, \"Song ID\": \"21UkXrc9kD48rNpTMI2ecz\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2021-05-06\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 82.0, \"Danceability\": 0.807, \"Energy\": 0.659, \"Loudness\": -6.92, \"Speechiness\": 0.332, \"Acousticness\": 0.0224, \"Liveness\": 0.309, \"Tempo\": 82.465, \"Duration (ms)\": 168727.0, \"Valence\": 0.438, \"Chord\": \"B\"}, {\"Index\": 322, \"Highest Charting Position\": 27, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Solid (feat. Drake)\", \"Streams\": 5347781, \"Artist\": \"Young Stoner Life, Young Thug, Gunna\", \"Artist Followers\": 61930.0, \"Song ID\": \"6rTInqW3YECMkQsBEHw4sd\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 82.0, \"Danceability\": 0.887, \"Energy\": 0.485, \"Loudness\": -9.358, \"Speechiness\": 0.2, \"Acousticness\": 0.0392, \"Liveness\": 0.141, \"Tempo\": 125.987, \"Duration (ms)\": 215693.0, \"Valence\": 0.328, \"Chord\": \"B\"}, {\"Index\": 323, \"Highest Charting Position\": 21, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"La Nota\", \"Streams\": 5300884, \"Artist\": \"Manuel Turizo, Rauw Alejandro, Myke Towers\", \"Artist Followers\": 7904381.0, \"Song ID\": \"7ndTONDDRFGiPnnhOzOXxq\", \"Genre\": \"['colombian pop', 'latin', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2020-10-08\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 79.0, \"Danceability\": 0.736, \"Energy\": 0.632, \"Loudness\": -4.939, \"Speechiness\": 0.0648, \"Acousticness\": 0.18, \"Liveness\": 0.349, \"Tempo\": 92.03, \"Duration (ms)\": 216107.0, \"Valence\": 0.503, \"Chord\": \"B\"}, {\"Index\": 324, \"Highest Charting Position\": 47, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Golden\", \"Streams\": 5298893, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16112621.0, \"Song ID\": \"45S5WTQEGOB1VHr1Q4FuPl\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 83.0, \"Danceability\": 0.448, \"Energy\": 0.838, \"Loudness\": -5.257, \"Speechiness\": 0.0557, \"Acousticness\": 0.21, \"Liveness\": 0.131, \"Tempo\": 139.863, \"Duration (ms)\": 208907.0, \"Valence\": 0.254, \"Chord\": \"E\"}, {\"Index\": 325, \"Highest Charting Position\": 127, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"CORALINE\", \"Streams\": 5241813, \"Artist\": \"M\\u00e5neskin\", \"Artist Followers\": 3377762.0, \"Song ID\": \"7HMz8o0m7ASQ3ImFPfhWTY\", \"Genre\": \"['indie rock italiano', 'italian pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\", \"Popularity\": 81.0, \"Danceability\": 0.363, \"Energy\": 0.678, \"Loudness\": -4.939, \"Speechiness\": 0.0995, \"Acousticness\": 0.0299, \"Liveness\": 0.324, \"Tempo\": 162.124, \"Duration (ms)\": 300413.0, \"Valence\": 0.321, \"Chord\": \"D\"}, {\"Index\": 326, \"Highest Charting Position\": 3, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"BICHOTA\", \"Streams\": 5201714, \"Artist\": \"KAROL G\", \"Artist Followers\": 1250353.0, \"Song ID\": \"4nYLZSNXJyPq8Jj3cEdykP\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 0.0, \"Danceability\": 0.863, \"Energy\": 0.666, \"Loudness\": -4.158, \"Speechiness\": 0.152, \"Acousticness\": 0.212, \"Liveness\": 0.103, \"Tempo\": 163.908, \"Duration (ms)\": 178947.0, \"Valence\": 0.838, \"Chord\": \"C#/Db\"}, {\"Index\": 327, \"Highest Charting Position\": 96, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Slumber Party (feat. Princess Nokia)\", \"Streams\": 5113574, \"Artist\": \"Ashnikko\", \"Artist Followers\": 1246335.0, \"Song ID\": \"11ZulcYY4lowvcQm4oe3VJ\", \"Genre\": \"['electropop', 'escape room', 'pop']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 82.0, \"Danceability\": 0.964, \"Energy\": 0.398, \"Loudness\": -8.981, \"Speechiness\": 0.0795, \"Acousticness\": 0.00151, \"Liveness\": 0.101, \"Tempo\": 105.012, \"Duration (ms)\": 178405.0, \"Valence\": 0.563, \"Chord\": \"B\"}, {\"Index\": 328, \"Highest Charting Position\": 170, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Killer (feat. Jack Harlow & Cordae) - Remix\", \"Streams\": 5404939, \"Artist\": \"Eminem\", \"Artist Followers\": 46785561.0, \"Song ID\": \"7zl7kehxesNEo2pYkKXTSe\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-05-28--2021-06-04\", \"Popularity\": 76.0, \"Danceability\": 0.924, \"Energy\": 0.73, \"Loudness\": -6.125, \"Speechiness\": 0.274, \"Acousticness\": 0.0525, \"Liveness\": 0.113, \"Tempo\": 99.01, \"Duration (ms)\": 236666.0, \"Valence\": 0.848, \"Chord\": \"B\"}, {\"Index\": 329, \"Highest Charting Position\": 105, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Liberdade (Quando o Grave Bate Forte)\", \"Streams\": 5378350, \"Artist\": \"Alok, Mc Don Juan, Dj GBR\", \"Artist Followers\": 10334543.0, \"Song ID\": \"2QLbRVzixE282JSQjBz2DG\", \"Genre\": \"['electro house', 'pop nacional', 'slap house']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 80.0, \"Danceability\": 0.81, \"Energy\": 0.789, \"Loudness\": -4.032, \"Speechiness\": 0.0498, \"Acousticness\": 0.0254, \"Liveness\": 0.104, \"Tempo\": 129.988, \"Duration (ms)\": 150462.0, \"Valence\": 0.432, \"Chord\": \"F#/Gb\"}, {\"Index\": 330, \"Highest Charting Position\": 108, \"Number of Times Charted\": 51, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"All Girls Are The Same\", \"Streams\": 5372180, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"4VXIryQMWpIdGgYR4TrjT1\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2018-12-10\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-08--2020-05-15\\n2020-04-24--2020-05-01\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.671, \"Energy\": 0.529, \"Loudness\": -7.226, \"Speechiness\": 0.307, \"Acousticness\": 0.0769, \"Liveness\": 0.0856, \"Tempo\": 161.989, \"Duration (ms)\": 165820.0, \"Valence\": 0.203, \"Chord\": \"C\"}, {\"Index\": 331, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"734\", \"Streams\": 5368759, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"6vB8bdQCCTDDIH8fhRfuXA\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-05-28--2021-06-04\", \"Popularity\": 75.0, \"Danceability\": 0.663, \"Energy\": 0.545, \"Loudness\": -3.93, \"Speechiness\": 0.036, \"Acousticness\": 0.123, \"Liveness\": 0.106, \"Tempo\": 78.452, \"Duration (ms)\": 196147.0, \"Valence\": 0.344, \"Chord\": \"D\"}, {\"Index\": 332, \"Highest Charting Position\": 85, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Boy With Luv (feat. Halsey)\", \"Streams\": 5266625, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"5KawlOMHjWeUjQtnuRs22c\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2019-04-12\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2020-11-20--2020-11-27\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-01-17--2020-01-24\", \"Popularity\": 82.0, \"Danceability\": 0.645, \"Energy\": 0.862, \"Loudness\": -4.757, \"Speechiness\": 0.0965, \"Acousticness\": 0.0923, \"Liveness\": 0.192, \"Tempo\": 119.991, \"Duration (ms)\": 229773.0, \"Valence\": 0.798, \"Chord\": \"B\"}, {\"Index\": 333, \"Highest Charting Position\": 82, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Disco Arranhado - Funk Remix\", \"Streams\": 5207186, \"Artist\": \"Malu, DJ Lucas Beat\", \"Artist Followers\": 74814.0, \"Song ID\": \"2Gjt4rUHBUH0rMKpBg0hF4\", \"Genre\": \"[]\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 80.0, \"Danceability\": 0.747, \"Energy\": 0.725, \"Loudness\": -2.564, \"Speechiness\": 0.363, \"Acousticness\": 0.551, \"Liveness\": 0.0626, \"Tempo\": 129.96, \"Duration (ms)\": 125558.0, \"Valence\": 0.904, \"Chord\": \"D\"}, {\"Index\": 334, \"Highest Charting Position\": 4, \"Number of Times Charted\": 70, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Godzilla (feat. Juice WRLD)\", \"Streams\": 5143522, \"Artist\": \"Eminem\", \"Artist Followers\": 46785561.0, \"Song ID\": \"7FIWs0pqAYbP91WWM0vlTQ\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 83.0, \"Danceability\": 0.808, \"Energy\": 0.745, \"Loudness\": -5.26, \"Speechiness\": 0.342, \"Acousticness\": 0.145, \"Liveness\": 0.292, \"Tempo\": 165.995, \"Duration (ms)\": 210800.0, \"Valence\": 0.829, \"Chord\": \"A#/Bb\"}, {\"Index\": 335, \"Highest Charting Position\": 8, \"Number of Times Charted\": 68, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Blueberry Faygo\", \"Streams\": 5085511, \"Artist\": \"Lil Mosey\", \"Artist Followers\": 3816446.0, \"Song ID\": \"6wJYhPfqk3KGhHRG76WzOh\", \"Genre\": \"['melodic rap', 'rap', 'rap conscient', 'trap', 'vapor trap']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 79.0, \"Danceability\": 0.774, \"Energy\": 0.554, \"Loudness\": -7.909, \"Speechiness\": 0.0383, \"Acousticness\": 0.207, \"Liveness\": 0.132, \"Tempo\": 99.034, \"Duration (ms)\": 162547.0, \"Valence\": 0.349, \"Chord\": \"C\"}, {\"Index\": 336, \"Highest Charting Position\": 129, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Somebody That I Used To Know\", \"Streams\": 5068972, \"Artist\": \"Gotye, Kimbra\", \"Artist Followers\": 2263960.0, \"Song ID\": \"4wCmqSrbyCgxEXROQE6vtV\", \"Genre\": \"['australian pop']\", \"Release Date\": \"2011-01-01\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 76.0, \"Danceability\": 0.864, \"Energy\": 0.495, \"Loudness\": -7.036, \"Speechiness\": 0.037, \"Acousticness\": 0.591, \"Liveness\": 0.0992, \"Tempo\": 129.062, \"Duration (ms)\": 244973.0, \"Valence\": 0.72, \"Chord\": \"C\"}, {\"Index\": 337, \"Highest Charting Position\": 4, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Holy (feat. Chance The Rapper)\", \"Streams\": 5063015, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48504126.0, \"Song ID\": \"5u1n1kITHCxxp8twBcZxWy\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 81.0, \"Danceability\": 0.673, \"Energy\": 0.704, \"Loudness\": -8.056, \"Speechiness\": 0.36, \"Acousticness\": 0.196, \"Liveness\": 0.0898, \"Tempo\": 86.919, \"Duration (ms)\": 212093.0, \"Valence\": 0.372, \"Chord\": \"F#/Gb\"}, {\"Index\": 338, \"Highest Charting Position\": 200, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Vida Louca\", \"Streams\": 5051514, \"Artist\": \"Mc Poze do Rodo, Neo Beats, Mainstreet\", \"Artist Followers\": 448447.0, \"Song ID\": \"7IG7laqVpcvIIULrwWP5SA\", \"Genre\": \"['funk carioca', 'funk ostentacao']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-05-28--2021-06-04\", \"Popularity\": 82.0, \"Danceability\": 0.852, \"Energy\": 0.62, \"Loudness\": -5.79, \"Speechiness\": 0.227, \"Acousticness\": 0.359, \"Liveness\": 0.101, \"Tempo\": 92.464, \"Duration (ms)\": 155676.0, \"Valence\": 0.744, \"Chord\": \"F#/Gb\"}, {\"Index\": 339, \"Highest Charting Position\": 15, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"i n t e r l u d e\", \"Streams\": 7880155, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"08LwMWf5Tcfsd752EPzFV0\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 76.0, \"Danceability\": 0.77, \"Energy\": 0.574, \"Loudness\": -5.525, \"Speechiness\": 0.106, \"Acousticness\": 0.0617, \"Liveness\": 0.104, \"Tempo\": 98.962, \"Duration (ms)\": 133022.0, \"Valence\": 0.104, \"Chord\": \"C#/Db\"}, {\"Index\": 340, \"Highest Charting Position\": 95, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Butter (Instrumental)\", \"Streams\": 7450126, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"2Ol2sv6gePRdJrZC1hDVNY\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 70.0, \"Danceability\": 0.429, \"Energy\": 0.387, \"Loudness\": -7.486, \"Speechiness\": 0.0753, \"Acousticness\": 0.000178, \"Liveness\": 0.142, \"Tempo\": 109.893, \"Duration (ms)\": 162147.0, \"Valence\": 0.41, \"Chord\": \"C#/Db\"}, {\"Index\": 341, \"Highest Charting Position\": 25, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Film out\", \"Streams\": 7198095, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"3UHPGOkUcE4hE7sqBF4Snt\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-04-01\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 81.0, \"Danceability\": 0.499, \"Energy\": 0.709, \"Loudness\": -6.404, \"Speechiness\": 0.134, \"Acousticness\": 0.296, \"Liveness\": 0.331, \"Tempo\": 164.032, \"Duration (ms)\": 214621.0, \"Valence\": 0.314, \"Chord\": \"A#/Bb\"}, {\"Index\": 342, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Voil\\u00e0\", \"Streams\": 6935400, \"Artist\": \"Barbara Pravi\", \"Artist Followers\": 75496.0, \"Song ID\": \"1uAOCTevGnyKIDbgZdOCnE\", \"Genre\": \"['eurovision', 'nouvelle chanson francaise']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 72.0, \"Danceability\": 0.447, \"Energy\": 0.337, \"Loudness\": -8.665, \"Speechiness\": 0.0631, \"Acousticness\": 0.773, \"Liveness\": 0.298, \"Tempo\": 135.379, \"Duration (ms)\": 176816.0, \"Valence\": 0.603, \"Chord\": \"D\"}, {\"Index\": 343, \"Highest Charting Position\": 53, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Shy Away\", \"Streams\": 6634722, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20823062.0, \"Song ID\": \"2nG54Y4a3sH9YpfxMolOyi\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 77.0, \"Danceability\": 0.588, \"Energy\": 0.856, \"Loudness\": -5.242, \"Speechiness\": 0.0316, \"Acousticness\": 0.000818, \"Liveness\": 0.238, \"Tempo\": 96.966, \"Duration (ms)\": 175044.0, \"Valence\": 0.635, \"Chord\": \"A\"}, {\"Index\": 344, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Saturday\", \"Streams\": 6628638, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20823062.0, \"Song ID\": \"60dwJ8dnqZ4WrIdiu7LkNR\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 75.0, \"Danceability\": 0.687, \"Energy\": 0.89, \"Loudness\": -5.99, \"Speechiness\": 0.0344, \"Acousticness\": 0.00396, \"Liveness\": 0.0436, \"Tempo\": 113.06, \"Duration (ms)\": 172232.0, \"Valence\": 0.854, \"Chord\": \"G#/Ab\"}, {\"Index\": 345, \"Highest Charting Position\": 18, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"9 5 . s o u t h\", \"Streams\": 6333126, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5R691ipUYRDYW6ehapjoj6\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 75.0, \"Danceability\": 0.713, \"Energy\": 0.793, \"Loudness\": -5.277, \"Speechiness\": 0.397, \"Acousticness\": 0.271, \"Liveness\": 0.727, \"Tempo\": 71.724, \"Duration (ms)\": 196946.0, \"Valence\": 0.203, \"Chord\": \"D\"}, {\"Index\": 346, \"Highest Charting Position\": 67, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Seeing Green (with Drake & Lil Wayne)\", \"Streams\": 6299936, \"Artist\": \"Nicki Minaj\", \"Artist Followers\": 22161310.0, \"Song ID\": \"1TZv3bujNaYz646eezRE91\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'pop rap', 'post-teen pop', 'queens hip hop']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 77.0, \"Danceability\": 0.573, \"Energy\": 0.867, \"Loudness\": -2.876, \"Speechiness\": 0.168, \"Acousticness\": 0.0853, \"Liveness\": 0.38, \"Tempo\": 74.861, \"Duration (ms)\": 339506.0, \"Valence\": 0.231, \"Chord\": \"F\"}, {\"Index\": 347, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Dark Side\", \"Streams\": 6277641, \"Artist\": \"Blind Channel\", \"Artist Followers\": 121225.0, \"Song ID\": \"1ovFnZv6mUe0LzAbfVqOmh\", \"Genre\": \"['eurovision', 'oulu metal', 'trancecore']\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 72.0, \"Danceability\": 0.571, \"Energy\": 0.955, \"Loudness\": -3.795, \"Speechiness\": 0.105, \"Acousticness\": 0.00254, \"Liveness\": 0.274, \"Tempo\": 98.01, \"Duration (ms)\": 177790.0, \"Valence\": 0.437, \"Chord\": \"G\"}, {\"Index\": 348, \"Highest Charting Position\": 137, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"SHUM\", \"Streams\": 6237019, \"Artist\": \"Go_A\", \"Artist Followers\": 107553.0, \"Song ID\": \"7mEDVrAHDnQJStDo8jKJJm\", \"Genre\": \"['eurovision']\", \"Release Date\": \"2021-03-10\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 75.0, \"Danceability\": 0.527, \"Energy\": 0.737, \"Loudness\": -5.34, \"Speechiness\": 0.0642, \"Acousticness\": 0.05, \"Liveness\": 0.105, \"Tempo\": 116.431, \"Duration (ms)\": 172675.0, \"Valence\": 0.499, \"Chord\": \"E\"}, {\"Index\": 349, \"Highest Charting Position\": 69, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"In the morning\", \"Streams\": 5738325, \"Artist\": \"ITZY\", \"Artist Followers\": 2379448.0, \"Song ID\": \"2QdH0rKlV3d9Y6lWzcnlBH\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 79.0, \"Danceability\": 0.847, \"Energy\": 0.814, \"Loudness\": -4.668, \"Speechiness\": 0.152, \"Acousticness\": 0.0825, \"Liveness\": 0.0948, \"Tempo\": 140.057, \"Duration (ms)\": 172359.0, \"Valence\": 0.711, \"Chord\": \"B\"}, {\"Index\": 350, \"Highest Charting Position\": 27, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"l e t . g o . m y . h a n d (with Bas & 6LACK)\", \"Streams\": 5393643, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"0GAyuCo975IHGxxiLKDufB\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 73.0, \"Danceability\": 0.583, \"Energy\": 0.625, \"Loudness\": -8.011, \"Speechiness\": 0.277, \"Acousticness\": 0.506, \"Liveness\": 0.196, \"Tempo\": 89.812, \"Duration (ms)\": 266291.0, \"Valence\": 0.516, \"Chord\": \"C#/Db\"}, {\"Index\": 351, \"Highest Charting Position\": 2, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"What\\u2019s Next\", \"Streams\": 5335112, \"Artist\": \"Drake\", \"Artist Followers\": 56308172.0, \"Song ID\": \"3aQem4jVGdhtg116TmJnHz\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 81.0, \"Danceability\": 0.781, \"Energy\": 0.594, \"Loudness\": -6.959, \"Speechiness\": 0.0485, \"Acousticness\": 0.0136, \"Liveness\": 0.162, \"Tempo\": 129.895, \"Duration (ms)\": 178154.0, \"Valence\": 0.0628, \"Chord\": \"C\"}, {\"Index\": 352, \"Highest Charting Position\": 154, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Ramen & OJ\", \"Streams\": 5282702, \"Artist\": \"Joyner Lucas, Lil Baby\", \"Artist Followers\": 1725025.0, \"Song ID\": \"4TIqzdAssasqx3DAe6cG9J\", \"Genre\": \"['boston hip hop', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 81.0, \"Danceability\": 0.597, \"Energy\": 0.571, \"Loudness\": -6.205, \"Speechiness\": 0.293, \"Acousticness\": 0.492, \"Liveness\": 0.093, \"Tempo\": 106.196, \"Duration (ms)\": 218448.0, \"Valence\": 0.165, \"Chord\": \"C#/Db\"}, {\"Index\": 353, \"Highest Charting Position\": 91, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Cloud 9\", \"Streams\": 5252767, \"Artist\": \"Beach Bunny\", \"Artist Followers\": 618444.0, \"Song ID\": \"6vFsBXYczYsP0H3lgunZOm\", \"Genre\": \"['bubblegrunge', 'chicago indie', 'indie pop', 'pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 81.0, \"Danceability\": 0.637, \"Energy\": 0.929, \"Loudness\": -3.593, \"Speechiness\": 0.0491, \"Acousticness\": 0.00167, \"Liveness\": 0.344, \"Tempo\": 80.974, \"Duration (ms)\": 147351.0, \"Valence\": 0.902, \"Chord\": \"E\"}, {\"Index\": 354, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Tout l'univers\", \"Streams\": 5174437, \"Artist\": \"Gjon's Tears\", \"Artist Followers\": 32257.0, \"Song ID\": \"3MvY2XbGYFi6p2dgmdcOYG\", \"Genre\": \"[]\", \"Release Date\": \"2021-03-10\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 69.0, \"Danceability\": 0.534, \"Energy\": 0.365, \"Loudness\": -9.187, \"Speechiness\": 0.033, \"Acousticness\": 0.81, \"Liveness\": 0.158, \"Tempo\": 123.466, \"Duration (ms)\": 183707.0, \"Valence\": 0.237, \"Chord\": \"A\"}, {\"Index\": 355, \"Highest Charting Position\": 64, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Headshot (feat. Polo G & Fivio Foreign)\", \"Streams\": 5174298, \"Artist\": \"Lil Tjay\", \"Artist Followers\": 3553442.0, \"Song ID\": \"4eNOLmx8r2IJAVKvBBL1jv\", \"Genre\": \"['brooklyn drill', 'melodic rap', 'nyc rap']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 81.0, \"Danceability\": 0.808, \"Energy\": 0.639, \"Loudness\": -7.266, \"Speechiness\": 0.279, \"Acousticness\": 0.0802, \"Liveness\": 0.15, \"Tempo\": 118.0, \"Duration (ms)\": 144349.0, \"Valence\": 0.395, \"Chord\": \"C#/Db\"}, {\"Index\": 356, \"Highest Charting Position\": 198, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Mask\", \"Streams\": 5156496, \"Artist\": \"Dream\", \"Artist Followers\": 727731.0, \"Song ID\": \"3IxMaULfjq4IT2IN6v54PB\", \"Genre\": \"['dream smp']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 76.0, \"Danceability\": 0.636, \"Energy\": 0.749, \"Loudness\": -4.197, \"Speechiness\": 0.0631, \"Acousticness\": 0.195, \"Liveness\": 0.107, \"Tempo\": 117.904, \"Duration (ms)\": 174936.0, \"Valence\": 0.653, \"Chord\": \"C#/Db\"}, {\"Index\": 357, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"10 Years\", \"Streams\": 5152139, \"Artist\": \"Da\\u00f0i Freyr\", \"Artist Followers\": 169137.0, \"Song ID\": \"4O0LQKVT6hGmVGNwizmydg\", \"Genre\": \"['icelandic pop', 'sunnlensk tonlist']\", \"Release Date\": \"2021-03-13\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 70.0, \"Danceability\": 0.798, \"Energy\": 0.621, \"Loudness\": -6.916, \"Speechiness\": 0.0391, \"Acousticness\": 0.0141, \"Liveness\": 0.0926, \"Tempo\": 123.038, \"Duration (ms)\": 166000.0, \"Valence\": 0.443, \"Chord\": \"D\"}, {\"Index\": 358, \"Highest Charting Position\": 127, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Choker\", \"Streams\": 5150176, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20823062.0, \"Song ID\": \"732E6ibFkQR5lNIPEeiEnx\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-04-30--2021-05-07\", \"Popularity\": 72.0, \"Danceability\": 0.7, \"Energy\": 0.664, \"Loudness\": -8.211, \"Speechiness\": 0.0394, \"Acousticness\": 0.306, \"Liveness\": 0.249, \"Tempo\": 142.009, \"Duration (ms)\": 223066.0, \"Valence\": 0.585, \"Chord\": \"G\"}, {\"Index\": 359, \"Highest Charting Position\": 25, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"a p p l y i n g . p r e s s u r e\", \"Streams\": 15967986, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"1d7q712nXjG98HiwHk7HFS\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 71.0, \"Danceability\": 0.699, \"Energy\": 0.759, \"Loudness\": -5.302, \"Speechiness\": 0.311, \"Acousticness\": 0.0814, \"Liveness\": 0.312, \"Tempo\": 83.092, \"Duration (ms)\": 177337.0, \"Valence\": 0.404, \"Chord\": \"C#/Db\"}, {\"Index\": 360, \"Highest Charting Position\": 30, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"1 0 0 . m i l \\u2018 (with Bas)\", \"Streams\": 15171655, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"4n6NDfYake476trCjJRNl0\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 72.0, \"Danceability\": 0.711, \"Energy\": 0.647, \"Loudness\": -5.667, \"Speechiness\": 0.0822, \"Acousticness\": 0.334, \"Liveness\": 0.312, \"Tempo\": 125.092, \"Duration (ms)\": 163302.0, \"Valence\": 0.227, \"Chord\": \"D\"}, {\"Index\": 361, \"Highest Charting Position\": 32, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"p u n c h i n \\u2018 . t h e . c l o c k\", \"Streams\": 14051831, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"57ZUX6TNyKLBydAdVVd02x\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 70.0, \"Danceability\": 0.769, \"Energy\": 0.74, \"Loudness\": -6.579, \"Speechiness\": 0.378, \"Acousticness\": 0.197, \"Liveness\": 0.171, \"Tempo\": 94.104, \"Duration (ms)\": 112579.0, \"Valence\": 0.692, \"Chord\": \"B\"}, {\"Index\": 362, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"t h e . c l i m b . b a c k\", \"Streams\": 12648655, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5lLNBIyjp72btcnrjBG751\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.618, \"Energy\": 0.632, \"Loudness\": -6.973, \"Speechiness\": 0.346, \"Acousticness\": 0.0526, \"Liveness\": 0.353, \"Tempo\": 81.446, \"Duration (ms)\": 306257.0, \"Valence\": 0.319, \"Chord\": \"B\"}, {\"Index\": 363, \"Highest Charting Position\": 48, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"h u n g e r . o n . h i l l s i d e (with Bas)\", \"Streams\": 11647489, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5BwQjRasNcdRPuVWKcHto2\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 71.0, \"Danceability\": 0.563, \"Energy\": 0.703, \"Loudness\": -5.756, \"Speechiness\": 0.0702, \"Acousticness\": 0.126, \"Liveness\": 0.213, \"Tempo\": 94.983, \"Duration (ms)\": 238972.0, \"Valence\": 0.294, \"Chord\": \"D\"}, {\"Index\": 364, \"Highest Charting Position\": 55, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"c l o s e\", \"Streams\": 10712648, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"1D3z6HTiQsNmZxjl7F7eoG\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.597, \"Energy\": 0.587, \"Loudness\": -7.026, \"Speechiness\": 0.137, \"Acousticness\": 0.0622, \"Liveness\": 0.214, \"Tempo\": 140.021, \"Duration (ms)\": 218802.0, \"Valence\": 0.0753, \"Chord\": \"G\"}, {\"Index\": 365, \"Highest Charting Position\": 34, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"WITHOUT YOU (with Miley Cyrus)\", \"Streams\": 6081034, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2230022.0, \"Song ID\": \"1EHUQesfVKwbthtNcpBi9g\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 81.0, \"Danceability\": 0.655, \"Energy\": 0.469, \"Loudness\": -6.257, \"Speechiness\": 0.0292, \"Acousticness\": 0.173, \"Liveness\": 0.0956, \"Tempo\": 92.56, \"Duration (ms)\": 161385.0, \"Valence\": 0.467, \"Chord\": \"C\"}, {\"Index\": 366, \"Highest Charting Position\": 92, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Snow Tha Product: Bzrp Music Sessions, Vol. 39\", \"Streams\": 5595839, \"Artist\": \"Bizarrap, Snow Tha Product\", \"Artist Followers\": 3126961.0, \"Song ID\": \"3ke6it1vTmHtz2ApcIVUz5\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2021-04-28\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 78.0, \"Danceability\": 0.83, \"Energy\": 0.748, \"Loudness\": -5.362, \"Speechiness\": 0.162, \"Acousticness\": 0.354, \"Liveness\": 0.0992, \"Tempo\": 133.028, \"Duration (ms)\": 177443.0, \"Valence\": 0.523, \"Chord\": \"C#/Db\"}, {\"Index\": 367, \"Highest Charting Position\": 87, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Travesuras - Remix\", \"Streams\": 5518444, \"Artist\": \"Nio Garcia, Casper Magico, Ozuna, Wisin & Yandel, Myke Towers, Flow La Movie\", \"Artist Followers\": 2123734.0, \"Song ID\": \"0VWLId2RwPCno9s1cJm2Vy\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-03-11\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 81.0, \"Danceability\": 0.739, \"Energy\": 0.788, \"Loudness\": -5.198, \"Speechiness\": 0.0731, \"Acousticness\": 0.0513, \"Liveness\": 0.282, \"Tempo\": 175.996, \"Duration (ms)\": 324426.0, \"Valence\": 0.473, \"Chord\": \"C#/Db\"}, {\"Index\": 368, \"Highest Charting Position\": 148, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Bubblegum Bitch\", \"Streams\": 5375782, \"Artist\": \"MARINA\", \"Artist Followers\": 2918229.0, \"Song ID\": \"0ZFBKLOZLIM16RAUb5eomN\", \"Genre\": \"['dance pop', 'electropop', 'metropopolis', 'pop', 'post-teen pop', 'uk alternative pop']\", \"Release Date\": \"2012-04-30\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 73.0, \"Danceability\": 0.495, \"Energy\": 0.856, \"Loudness\": -5.123, \"Speechiness\": 0.0311, \"Acousticness\": 0.000219, \"Liveness\": 0.103, \"Tempo\": 158.024, \"Duration (ms)\": 154667.0, \"Valence\": 0.609, \"Chord\": \"C\"}, {\"Index\": 369, \"Highest Charting Position\": 5, \"Number of Times Charted\": 142, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Falling\", \"Streams\": 5294368, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16112621.0, \"Song ID\": \"1ZMiCix7XSAbfAJlEZWMCp\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.567, \"Energy\": 0.267, \"Loudness\": -6.502, \"Speechiness\": 0.0299, \"Acousticness\": 0.839, \"Liveness\": 0.089, \"Tempo\": 110.011, \"Duration (ms)\": 240133.0, \"Valence\": 0.0592, \"Chord\": \"E\"}, {\"Index\": 370, \"Highest Charting Position\": 182, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Expl\\u00edcito\", \"Streams\": 5278449, \"Artist\": \"Myke Towers\", \"Artist Followers\": 6150675.0, \"Song ID\": \"6qraVL4IJaIj0IuEexYJNa\", \"Genre\": \"['trap latino']\", \"Release Date\": \"2020-12-15\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-03-26--2021-04-02\", \"Popularity\": 81.0, \"Danceability\": 0.828, \"Energy\": 0.83, \"Loudness\": -3.371, \"Speechiness\": 0.047, \"Acousticness\": 0.348, \"Liveness\": 0.0613, \"Tempo\": 95.007, \"Duration (ms)\": 195066.0, \"Valence\": 0.422, \"Chord\": \"D\"}, {\"Index\": 371, \"Highest Charting Position\": 58, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"No Te Enamores - Remix\", \"Streams\": 5218146, \"Artist\": \"Milly, Farruko, Nio Garcia, Jay Wheeler, Amenazzy\", \"Artist Followers\": 22718.0, \"Song ID\": \"2mM3gZ0BbPwPPMelbA8vgt\", \"Genre\": \"['reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 79.0, \"Danceability\": 0.824, \"Energy\": 0.837, \"Loudness\": -4.603, \"Speechiness\": 0.107, \"Acousticness\": 0.573, \"Liveness\": 0.271, \"Tempo\": 100.021, \"Duration (ms)\": 289933.0, \"Valence\": 0.58, \"Chord\": \"F\"}, {\"Index\": 372, \"Highest Charting Position\": 110, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"PROBLEMA\", \"Streams\": 5215973, \"Artist\": \"Daddy Yankee\", \"Artist Followers\": 1250353.0, \"Song ID\": \"7vzPjsX8UzlPKKtV47qGPn\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 0.0, \"Danceability\": 0.773, \"Energy\": 0.8, \"Loudness\": -3.17, \"Speechiness\": 0.0987, \"Acousticness\": 0.0613, \"Liveness\": 0.0327, \"Tempo\": 89.988, \"Duration (ms)\": 184507.0, \"Valence\": 0.842, \"Chord\": \"A#/Bb\"}, {\"Index\": 373, \"Highest Charting Position\": 5, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Lonely (with benny blanco)\", \"Streams\": 5191697, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48504126.0, \"Song ID\": \"4y4spB9m0Q6026KfkAvy9Q\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 80.0, \"Danceability\": 0.631, \"Energy\": 0.239, \"Loudness\": -7.071, \"Speechiness\": 0.0398, \"Acousticness\": 0.864, \"Liveness\": 0.116, \"Tempo\": 79.859, \"Duration (ms)\": 149297.0, \"Valence\": 0.0927, \"Chord\": \"B\"}, {\"Index\": 374, \"Highest Charting Position\": 77, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Cupid's Chokehold / Breakfast in America\", \"Streams\": 5165035, \"Artist\": \"Gym Class Heroes\", \"Artist Followers\": 1275345.0, \"Song ID\": \"2Lhdl74nwwVGOE2Gv35QuK\", \"Genre\": \"['dance pop', 'pop rap']\", \"Release Date\": \"2005-02-22\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 81.0, \"Danceability\": 0.72, \"Energy\": 0.744, \"Loudness\": -6.938, \"Speechiness\": 0.12, \"Acousticness\": 0.237, \"Liveness\": 0.255, \"Tempo\": 78.953, \"Duration (ms)\": 243773.0, \"Valence\": 0.619, \"Chord\": \"C#/Db\"}, {\"Index\": 375, \"Highest Charting Position\": 38, \"Number of Times Charted\": 72, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"If the World Was Ending - feat. Julia Michaels\", \"Streams\": 5127736, \"Artist\": \"JP Saxe\", \"Artist Followers\": 280585.0, \"Song ID\": \"2kJwzbxV2ppxnQoYw4GLBZ\", \"Genre\": \"['alt z', 'canadian contemporary r&b', 'indie cafe pop', 'pop', 'pop rock', 'post-teen pop']\", \"Release Date\": \"2019-10-17\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.464, \"Energy\": 0.473, \"Loudness\": -10.086, \"Speechiness\": 0.129, \"Acousticness\": 0.866, \"Liveness\": 0.109, \"Tempo\": 75.801, \"Duration (ms)\": 208687.0, \"Valence\": 0.604, \"Chord\": \"C#/Db\"}, {\"Index\": 376, \"Highest Charting Position\": 47, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"I DID IT (feat. Post Malone, Megan Thee Stallion, Lil Baby & DaBaby)\", \"Streams\": 7347891, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6278835.0, \"Song ID\": \"20GrahbI4AzAOWxpYfDKkf\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 76.0, \"Danceability\": 0.757, \"Energy\": 0.721, \"Loudness\": -2.906, \"Speechiness\": 0.0691, \"Acousticness\": 0.00196, \"Liveness\": 0.647, \"Tempo\": 124.036, \"Duration (ms)\": 165366.0, \"Valence\": 0.364, \"Chord\": \"E\"}, {\"Index\": 377, \"Highest Charting Position\": 61, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Body\", \"Streams\": 5831357, \"Artist\": \"Russ Millions, Tion Wayne\", \"Artist Followers\": 323203.0, \"Song ID\": \"6uvMKqNlrSvcC4NaKnrwjZ\", \"Genre\": \"['london rap']\", \"Release Date\": \"2021-04-22\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 84.0, \"Danceability\": 0.883, \"Energy\": 0.674, \"Loudness\": -8.043, \"Speechiness\": 0.357, \"Acousticness\": 0.21, \"Liveness\": 0.0678, \"Tempo\": 141.02, \"Duration (ms)\": 278085.0, \"Valence\": 0.73, \"Chord\": \"B\"}, {\"Index\": 378, \"Highest Charting Position\": 10, \"Number of Times Charted\": 69, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"everything i wanted\", \"Streams\": 5448680, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"1OC8hMoqAuWmTWJ4heJNlO\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.704, \"Energy\": 0.225, \"Loudness\": -14.454, \"Speechiness\": 0.0994, \"Acousticness\": 0.901, \"Liveness\": 0.106, \"Tempo\": 120.006, \"Duration (ms)\": 245426.0, \"Valence\": 0.243, \"Chord\": \"F#/Gb\"}, {\"Index\": 379, \"Highest Charting Position\": 169, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"What You Need\", \"Streams\": 5346005, \"Artist\": \"Don Toliver\", \"Artist Followers\": 1605329.0, \"Song ID\": \"6LcX2hBbXaJcK4AuefE936\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2021-05-04\", \"Weeks Charted\": \"2021-05-07--2021-05-14\", \"Popularity\": 76.0, \"Danceability\": 0.664, \"Energy\": 0.655, \"Loudness\": -7.327, \"Speechiness\": 0.0461, \"Acousticness\": 0.059, \"Liveness\": 0.17, \"Tempo\": 129.987, \"Duration (ms)\": 217609.0, \"Valence\": 0.13, \"Chord\": \"A#/Bb\"}, {\"Index\": 380, \"Highest Charting Position\": 115, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"L-Gante: Bzrp Music Sessions, Vol.38\", \"Streams\": 5290877, \"Artist\": \"Bizarrap, L-Gante\", \"Artist Followers\": 3126961.0, \"Song ID\": \"1Crj1zkRMpsEjb9NOR6Zof\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2021-03-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 80.0, \"Danceability\": 0.553, \"Energy\": 0.819, \"Loudness\": -3.083, \"Speechiness\": 0.257, \"Acousticness\": 0.368, \"Liveness\": 0.0915, \"Tempo\": 87.913, \"Duration (ms)\": 192348.0, \"Valence\": 0.761, \"Chord\": \"D\"}, {\"Index\": 381, \"Highest Charting Position\": 19, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"HOLIDAY\", \"Streams\": 5264232, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5473565.0, \"Song ID\": \"6zFMeegAMYQo0mt8rXtrli\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 83.0, \"Danceability\": 0.81, \"Energy\": 0.511, \"Loudness\": -6.924, \"Speechiness\": 0.164, \"Acousticness\": 0.12, \"Liveness\": 0.0832, \"Tempo\": 151.947, \"Duration (ms)\": 154998.0, \"Valence\": 0.837, \"Chord\": \"F\"}, {\"Index\": 382, \"Highest Charting Position\": 71, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"At My Worst\", \"Streams\": 5258000, \"Artist\": \"Pink Sweat$\", \"Artist Followers\": 942628.0, \"Song ID\": \"0ri0Han4IRJhzvERHOZTMr\", \"Genre\": \"['bedroom soul', 'pop']\", \"Release Date\": \"2020-07-17\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 79.0, \"Danceability\": 0.813, \"Energy\": 0.415, \"Loudness\": -5.926, \"Speechiness\": 0.0349, \"Acousticness\": 0.777, \"Liveness\": 0.131, \"Tempo\": 91.921, \"Duration (ms)\": 170345.0, \"Valence\": 0.667, \"Chord\": \"C\"}, {\"Index\": 383, \"Highest Charting Position\": 3, \"Number of Times Charted\": 70, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Life Is Good (feat. Drake)\", \"Streams\": 5241227, \"Artist\": \"Future\", \"Artist Followers\": 10488292.0, \"Song ID\": \"5yY9lUy8nbvjM1Uyo1Uqoc\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 81.0, \"Danceability\": 0.676, \"Energy\": 0.609, \"Loudness\": -5.831, \"Speechiness\": 0.481, \"Acousticness\": 0.0706, \"Liveness\": 0.152, \"Tempo\": 142.037, \"Duration (ms)\": 237735.0, \"Valence\": 0.508, \"Chord\": \"D\"}, {\"Index\": 384, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Extasy\", \"Streams\": 5203700, \"Artist\": \"187 Strassenbande, Bonez MC, Frauenarzt\", \"Artist Followers\": 1223734.0, \"Song ID\": \"79lc69ZXfL4WmJIzVSDmWT\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-05-07--2021-05-14\", \"Popularity\": 67.0, \"Danceability\": 0.863, \"Energy\": 0.739, \"Loudness\": -5.879, \"Speechiness\": 0.153, \"Acousticness\": 0.0289, \"Liveness\": 0.0931, \"Tempo\": 129.964, \"Duration (ms)\": 174021.0, \"Valence\": 0.547, \"Chord\": \"A\"}, {\"Index\": 385, \"Highest Charting Position\": 7, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Wishing Well\", \"Streams\": 5125706, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"2U5WueTLIK5WJLD7mvDODv\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 83.0, \"Danceability\": 0.65, \"Energy\": 0.613, \"Loudness\": -6.13, \"Speechiness\": 0.128, \"Acousticness\": 0.00336, \"Liveness\": 0.267, \"Tempo\": 149.972, \"Duration (ms)\": 194621.0, \"Valence\": 0.0804, \"Chord\": \"A\"}, {\"Index\": 386, \"Highest Charting Position\": 164, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Fan de Tus Fotos\", \"Streams\": 5103863, \"Artist\": \"Nicky Jam, Romeo Santos\", \"Artist Followers\": 14826679.0, \"Song ID\": \"1mauYRwbpoGQX6itP2FAJC\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-02-08\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\", \"Popularity\": 79.0, \"Danceability\": 0.728, \"Energy\": 0.689, \"Loudness\": -5.718, \"Speechiness\": 0.0725, \"Acousticness\": 0.293, \"Liveness\": 0.109, \"Tempo\": 170.089, \"Duration (ms)\": 197647.0, \"Valence\": 0.431, \"Chord\": \"G\"}, {\"Index\": 387, \"Highest Charting Position\": 82, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Tap\\u00e3o Na Raba\", \"Streams\": 5088848, \"Artist\": \"Ra\\u00ed Saia Rodada\", \"Artist Followers\": 1260752.0, \"Song ID\": \"58pgi1RpcU2fVJsxhm7BIr\", \"Genre\": \"['forro']\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 80.0, \"Danceability\": 0.808, \"Energy\": 0.796, \"Loudness\": -3.169, \"Speechiness\": 0.0305, \"Acousticness\": 0.462, \"Liveness\": 0.155, \"Tempo\": 128.048, \"Duration (ms)\": 175047.0, \"Valence\": 0.799, \"Chord\": \"C#/Db\"}, {\"Index\": 388, \"Highest Charting Position\": 66, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Machu Picchu\", \"Streams\": 5062404, \"Artist\": \"Camilo, Evaluna Montaner\", \"Artist Followers\": 10561047.0, \"Song ID\": \"1LXb70u8SLsvBAPWHMCTMe\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2021-03-01\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 76.0, \"Danceability\": 0.788, \"Energy\": 0.789, \"Loudness\": -2.39, \"Speechiness\": 0.124, \"Acousticness\": 0.397, \"Liveness\": 0.226, \"Tempo\": 167.897, \"Duration (ms)\": 179005.0, \"Valence\": 0.867, \"Chord\": \"C\"}, {\"Index\": 389, \"Highest Charting Position\": 4, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Come & Go (with Marshmello)\", \"Streams\": 5037124, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"2Y0wPrPQBrGhoLn14xRYCG\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 83.0, \"Danceability\": 0.625, \"Energy\": 0.814, \"Loudness\": -5.181, \"Speechiness\": 0.0657, \"Acousticness\": 0.0172, \"Liveness\": 0.158, \"Tempo\": 144.991, \"Duration (ms)\": 205485.0, \"Valence\": 0.535, \"Chord\": \"C\"}, {\"Index\": 390, \"Highest Charting Position\": 71, \"Number of Times Charted\": 72, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Robbery\", \"Streams\": 5024884, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"6Hj9jySrnFppAI0sEMCZpJ\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2019-03-08\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.685, \"Energy\": 0.692, \"Loudness\": -5.122, \"Speechiness\": 0.0457, \"Acousticness\": 0.328, \"Liveness\": 0.153, \"Tempo\": 159.966, \"Duration (ms)\": 240051.0, \"Valence\": 0.578, \"Chord\": \"D\"}, {\"Index\": 391, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Paradigmas\", \"Streams\": 5018076, \"Artist\": \"Jorge & Mateus\", \"Artist Followers\": 15013645.0, \"Song ID\": \"17UfXrL7Run3GyZJW4uRjC\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2021-04-22\", \"Weeks Charted\": \"2021-05-07--2021-05-14\", \"Popularity\": 72.0, \"Danceability\": 0.686, \"Energy\": 0.789, \"Loudness\": -4.103, \"Speechiness\": 0.126, \"Acousticness\": 0.322, \"Liveness\": 0.4, \"Tempo\": 157.932, \"Duration (ms)\": 157355.0, \"Valence\": 0.822, \"Chord\": \"C#/Db\"}, {\"Index\": 392, \"Highest Charting Position\": 53, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"SugarCrash!\", \"Streams\": 5018005, \"Artist\": \"ElyOtto\", \"Artist Followers\": 85617.0, \"Song ID\": \"2ePtv8MlBO9nuuXABqAfEX\", \"Genre\": \"['weirdcore']\", \"Release Date\": \"2020-08-25\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 80.0, \"Danceability\": 0.748, \"Energy\": 0.734, \"Loudness\": -6.499, \"Speechiness\": 0.124, \"Acousticness\": 0.524, \"Liveness\": 0.0975, \"Tempo\": 97.753, \"Duration (ms)\": 80081.0, \"Valence\": 0.368, \"Chord\": \"C\"}, {\"Index\": 393, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"durag activity (with Travis Scott)\", \"Streams\": 7939784, \"Artist\": \"Baby Keem\", \"Artist Followers\": 279741.0, \"Song ID\": \"4JJcP0Rv9AgyPD6ZGaC8EE\", \"Genre\": \"['hip hop', 'rap', 'trap', 'underground hip hop']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-04-30--2021-05-07\", \"Popularity\": 75.0, \"Danceability\": 0.89, \"Energy\": 0.701, \"Loudness\": -5.712, \"Speechiness\": 0.342, \"Acousticness\": 0.00306, \"Liveness\": 0.0895, \"Tempo\": 80.462, \"Duration (ms)\": 225020.0, \"Valence\": 0.505, \"Chord\": \"C\"}, {\"Index\": 394, \"Highest Charting Position\": 113, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"love race (feat. Kellin Quinn)\", \"Streams\": 6325080, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3864419.0, \"Song ID\": \"1F9kEuwT29fgqlovIclu81\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2021-04-29\", \"Weeks Charted\": \"2021-04-30--2021-05-07\", \"Popularity\": 76.0, \"Danceability\": 0.517, \"Energy\": 0.848, \"Loudness\": -4.054, \"Speechiness\": 0.0521, \"Acousticness\": 0.00581, \"Liveness\": 0.214, \"Tempo\": 95.906, \"Duration (ms)\": 188779.0, \"Valence\": 0.429, \"Chord\": \"A#/Bb\"}, {\"Index\": 395, \"Highest Charting Position\": 7, \"Number of Times Charted\": 40, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"POPSTAR (feat. Drake)\", \"Streams\": 6127103, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6278835.0, \"Song ID\": \"6EDO9iiTtwNv6waLwa1UUq\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-07-17\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 80.0, \"Danceability\": 0.8, \"Energy\": 0.56, \"Loudness\": -4.818, \"Speechiness\": 0.261, \"Acousticness\": 0.057, \"Liveness\": 0.134, \"Tempo\": 163.071, \"Duration (ms)\": 200221.0, \"Valence\": 0.45, \"Chord\": \"F\"}, {\"Index\": 396, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"LET IT GO (feat. Justin Bieber & 21 Savage)\", \"Streams\": 6083338, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6278835.0, \"Song ID\": \"1cEhrSF6EylAEqdhUGuNpX\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-04-30--2021-05-07\", \"Popularity\": 75.0, \"Danceability\": 0.877, \"Energy\": 0.444, \"Loudness\": -7.547, \"Speechiness\": 0.172, \"Acousticness\": 0.24, \"Liveness\": 0.169, \"Tempo\": 129.06, \"Duration (ms)\": 165527.0, \"Valence\": 0.658, \"Chord\": \"G#/Ab\"}, {\"Index\": 397, \"Highest Charting Position\": 137, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Girl From Rio\", \"Streams\": 5768836, \"Artist\": \"Anitta\", \"Artist Followers\": 10740222.0, \"Song ID\": \"6CF085Ol0cVda1WqelybEQ\", \"Genre\": \"['funk carioca', 'funk pop', 'pagode baiano', 'pop nacional']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-04-30--2021-05-07\", \"Popularity\": 69.0, \"Danceability\": 0.732, \"Energy\": 0.604, \"Loudness\": -7.472, \"Speechiness\": 0.0443, \"Acousticness\": 0.0112, \"Liveness\": 0.219, \"Tempo\": 139.982, \"Duration (ms)\": 195429.0, \"Valence\": 0.732, \"Chord\": \"C\"}, {\"Index\": 398, \"Highest Charting Position\": 10, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"On The Ground\", \"Streams\": 5655879, \"Artist\": \"ROS\\u00c9\", \"Artist Followers\": 1094731.0, \"Song ID\": \"2pn8dNVSpYnAtlKFC8Q0DJ\", \"Genre\": \"[]\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 74.0, \"Danceability\": 0.311, \"Energy\": 0.607, \"Loudness\": -6.578, \"Speechiness\": 0.11, \"Acousticness\": 0.0174, \"Liveness\": 0.131, \"Tempo\": 188.7, \"Duration (ms)\": 168086.0, \"Valence\": 0.286, \"Chord\": \"C#/Db\"}, {\"Index\": 399, \"Highest Charting Position\": 20, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Mr. Perfectly Fine (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5480722, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2CYVETnhM9aytqrazYYwrK\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 74.0, \"Danceability\": 0.66, \"Energy\": 0.817, \"Loudness\": -6.269, \"Speechiness\": 0.0521, \"Acousticness\": 0.162, \"Liveness\": 0.0667, \"Tempo\": 135.942, \"Duration (ms)\": 277592.0, \"Valence\": 0.714, \"Chord\": \"B\"}, {\"Index\": 400, \"Highest Charting Position\": 42, \"Number of Times Charted\": 60, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"when the party's over\", \"Streams\": 5467596, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"5KWwUzVxubgSPmLIUAQhYt\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.484, \"Energy\": 0.103, \"Loudness\": -14.075, \"Speechiness\": 0.0627, \"Acousticness\": 0.979, \"Liveness\": 0.0895, \"Tempo\": 124.011, \"Duration (ms)\": 199931.0, \"Valence\": 0.194, \"Chord\": \"C#/Db\"}, {\"Index\": 401, \"Highest Charting Position\": 63, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Otra Noche Sin Ti\", \"Streams\": 5377794, \"Artist\": \"J Balvin, Khalid\", \"Artist Followers\": 29051363.0, \"Song ID\": \"2CdTLdDjwZdVcm0bresVWx\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 80.0, \"Danceability\": 0.503, \"Energy\": 0.548, \"Loudness\": -7.564, \"Speechiness\": 0.164, \"Acousticness\": 0.0751, \"Liveness\": 0.145, \"Tempo\": 94.036, \"Duration (ms)\": 228920.0, \"Valence\": 0.441, \"Chord\": \"C\"}, {\"Index\": 402, \"Highest Charting Position\": 33, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Met Him Last Night (feat. Ariana Grande)\", \"Streams\": 5200695, \"Artist\": \"Demi Lovato\", \"Artist Followers\": 20331923.0, \"Song ID\": \"0BI0hfbmqybnd3TezrDME3\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 72.0, \"Danceability\": 0.538, \"Energy\": 0.512, \"Loudness\": -4.548, \"Speechiness\": 0.0262, \"Acousticness\": 0.22, \"Liveness\": 0.101, \"Tempo\": 144.978, \"Duration (ms)\": 204632.0, \"Valence\": 0.12, \"Chord\": \"E\"}, {\"Index\": 403, \"Highest Charting Position\": 100, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Back In Blood (feat. Lil Durk)\", \"Streams\": 5198209, \"Artist\": \"Pooh Shiesty\", \"Artist Followers\": 423237.0, \"Song ID\": \"7JuHVG3qQKQKxC4doneXVW\", \"Genre\": \"['memphis hip hop', 'rap', 'southern hip hop', 'tennessee hip hop', 'trap']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 75.0, \"Danceability\": 0.759, \"Energy\": 0.538, \"Loudness\": -8.256, \"Speechiness\": 0.384, \"Acousticness\": 0.151, \"Liveness\": 0.126, \"Tempo\": 146.933, \"Duration (ms)\": 184490.0, \"Valence\": 0.831, \"Chord\": \"G#/Ab\"}, {\"Index\": 404, \"Highest Charting Position\": 94, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Run It Up (feat. Offset & Moneybagg Yo)\", \"Streams\": 5107084, \"Artist\": \"Lil Tjay\", \"Artist Followers\": 3553442.0, \"Song ID\": \"1dg3qy5DjoJodawfOCgrTP\", \"Genre\": \"['brooklyn drill', 'melodic rap', 'nyc rap']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 81.0, \"Danceability\": 0.88, \"Energy\": 0.575, \"Loudness\": -6.091, \"Speechiness\": 0.163, \"Acousticness\": 0.415, \"Liveness\": 0.109, \"Tempo\": 120.031, \"Duration (ms)\": 232048.0, \"Valence\": 0.671, \"Chord\": \"F#/Gb\"}, {\"Index\": 405, \"Highest Charting Position\": 37, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Mi Ni\\u00f1a\", \"Streams\": 5026961, \"Artist\": \"Wisin, Myke Towers, Los Legendarios\", \"Artist Followers\": 6929075.0, \"Song ID\": \"2bgcUk2A3jjKbCJ7KPquTi\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-23\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 79.0, \"Danceability\": 0.823, \"Energy\": 0.821, \"Loudness\": -3.402, \"Speechiness\": 0.166, \"Acousticness\": 0.31, \"Liveness\": 0.143, \"Tempo\": 99.999, \"Duration (ms)\": 213314.0, \"Valence\": 0.791, \"Chord\": \"G#/Ab\"}, {\"Index\": 406, \"Highest Charting Position\": 9, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"As I Am (feat. Khalid)\", \"Streams\": 5896065, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6F2r4HgpJnvKDmkN6JEN6J\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 72.0, \"Danceability\": 0.595, \"Energy\": 0.543, \"Loudness\": -8.149, \"Speechiness\": 0.038, \"Acousticness\": 0.127, \"Liveness\": 0.0975, \"Tempo\": 99.928, \"Duration (ms)\": 174406.0, \"Valence\": 0.109, \"Chord\": \"B\"}, {\"Index\": 407, \"Highest Charting Position\": 150, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Come Through (feat. Chris Brown)\", \"Streams\": 5531998, \"Artist\": \"H.E.R.\", \"Artist Followers\": 4138951.0, \"Song ID\": \"3krZxyBsWEHfEfJegYaWTd\", \"Genre\": \"['alternative r&b', 'dance pop', 'pop', 'r&b']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-04-23--2021-04-30\", \"Popularity\": 74.0, \"Danceability\": 0.615, \"Energy\": 0.422, \"Loudness\": -8.019, \"Speechiness\": 0.0504, \"Acousticness\": 0.604, \"Liveness\": 0.112, \"Tempo\": 135.859, \"Duration (ms)\": 214094.0, \"Valence\": 0.185, \"Chord\": \"F\"}, {\"Index\": 408, \"Highest Charting Position\": 33, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Goosebumps\", \"Streams\": 5496962, \"Artist\": \"HVME\", \"Artist Followers\": 17719446.0, \"Song ID\": \"5uEYRdEIh9Bo4fpjDd4Na9\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 87.0, \"Danceability\": 0.841, \"Energy\": 0.593, \"Loudness\": -7.846, \"Speechiness\": 0.0379, \"Acousticness\": 0.418, \"Liveness\": 0.124, \"Tempo\": 124.917, \"Duration (ms)\": 162803.0, \"Valence\": 0.808, \"Chord\": \"C#/Db\"}, {\"Index\": 409, \"Highest Charting Position\": 18, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Put Your Records On\", \"Streams\": 5181180, \"Artist\": \"Ritt Momney\", \"Artist Followers\": 100463.0, \"Song ID\": \"6AGOKlMZWLCaEJGnaROtF9\", \"Genre\": \"['bedroom pop']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 81.0, \"Danceability\": 0.399, \"Energy\": 0.491, \"Loudness\": -10.778, \"Speechiness\": 0.0538, \"Acousticness\": 0.0563, \"Liveness\": 0.11, \"Tempo\": 91.066, \"Duration (ms)\": 210463.0, \"Valence\": 0.151, \"Chord\": \"F#/Gb\"}, {\"Index\": 410, \"Highest Charting Position\": 137, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Facas - Ao Vivo\", \"Streams\": 5141640, \"Artist\": \"Diego & Victor Hugo, Bruno & Marrone\", \"Artist Followers\": 1585593.0, \"Song ID\": \"1ere9b9vDw2N3m9d4uiXxa\", \"Genre\": \"['sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2020-10-15\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 79.0, \"Danceability\": 0.443, \"Energy\": 0.509, \"Loudness\": -5.995, \"Speechiness\": 0.0536, \"Acousticness\": 0.615, \"Liveness\": 0.472, \"Tempo\": 160.984, \"Duration (ms)\": 196380.0, \"Valence\": 0.69, \"Chord\": \"D\"}, {\"Index\": 411, \"Highest Charting Position\": 62, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Train Wreck\", \"Streams\": 5081800, \"Artist\": \"James Arthur\", \"Artist Followers\": 8446147.0, \"Song ID\": \"55Am8neGJkdj2ADaM3aw5H\", \"Genre\": \"['pop', 'post-teen pop', 'talent show', 'uk pop']\", \"Release Date\": \"2016-10-28\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 82.0, \"Danceability\": 0.311, \"Energy\": 0.485, \"Loudness\": -5.726, \"Speechiness\": 0.0365, \"Acousticness\": 0.701, \"Liveness\": 0.0726, \"Tempo\": 77.355, \"Duration (ms)\": 208827.0, \"Valence\": 0.225, \"Chord\": \"F#/Gb\"}, {\"Index\": 412, \"Highest Charting Position\": 7, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Monster (Shawn Mendes & Justin Bieber)\", \"Streams\": 5069268, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 33893352.0, \"Song ID\": \"2Z8yfpFX0ZMavHkcIeHiO1\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 79.0, \"Danceability\": 0.652, \"Energy\": 0.383, \"Loudness\": -7.076, \"Speechiness\": 0.0516, \"Acousticness\": 0.0676, \"Liveness\": 0.0828, \"Tempo\": 145.765, \"Duration (ms)\": 178994.0, \"Valence\": 0.549, \"Chord\": \"D\"}, {\"Index\": 413, \"Highest Charting Position\": 6, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"In Your Eyes\", \"Streams\": 5054319, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"7szuecWAPwGoV1e5vGu8tl\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 81.0, \"Danceability\": 0.667, \"Energy\": 0.719, \"Loudness\": -5.371, \"Speechiness\": 0.0346, \"Acousticness\": 0.00285, \"Liveness\": 0.0736, \"Tempo\": 100.021, \"Duration (ms)\": 237520.0, \"Valence\": 0.717, \"Chord\": \"G\"}, {\"Index\": 414, \"Highest Charting Position\": 101, \"Number of Times Charted\": 68, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"SAD!\", \"Streams\": 5051338, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"3ee8Jmje8o58CHK66QrVC2\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2018-03-16\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.74, \"Energy\": 0.613, \"Loudness\": -4.88, \"Speechiness\": 0.145, \"Acousticness\": 0.258, \"Liveness\": 0.123, \"Tempo\": 75.023, \"Duration (ms)\": 166606.0, \"Valence\": 0.473, \"Chord\": \"G#/Ab\"}, {\"Index\": 415, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Good Without\", \"Streams\": 4998044, \"Artist\": \"Mimi Webb\", \"Artist Followers\": 130801.0, \"Song ID\": \"15OCqNPYoLziEAsbVnqRj5\", \"Genre\": \"['alt z', 'indie cafe pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-04-23--2021-04-30\", \"Popularity\": 81.0, \"Danceability\": 0.616, \"Energy\": 0.576, \"Loudness\": -5.495, \"Speechiness\": 0.0532, \"Acousticness\": 0.0723, \"Liveness\": 0.375, \"Tempo\": 89.962, \"Duration (ms)\": 182121.0, \"Valence\": 0.269, \"Chord\": \"B\"}, {\"Index\": 416, \"Highest Charting Position\": 19, \"Number of Times Charted\": 66, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"hot girl bummer\", \"Streams\": 4992396, \"Artist\": \"blackbear\", \"Artist Followers\": 4270131.0, \"Song ID\": \"2mt1IqcFyY1zmYZT8Q3xw9\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.782, \"Energy\": 0.559, \"Loudness\": -7.106, \"Speechiness\": 0.0767, \"Acousticness\": 0.125, \"Liveness\": 0.385, \"Tempo\": 129.992, \"Duration (ms)\": 188344.0, \"Valence\": 0.685, \"Chord\": \"F#/Gb\"}, {\"Index\": 417, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"When I Was Your Man\", \"Streams\": 4945935, \"Artist\": \"Bruno Mars\", \"Artist Followers\": 32603394.0, \"Song ID\": \"0nJW01T7XtvILxQgC5J7Wh\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2012-12-07\", \"Weeks Charted\": \"2021-04-23--2021-04-30\", \"Popularity\": 82.0, \"Danceability\": 0.612, \"Energy\": 0.28, \"Loudness\": -8.648, \"Speechiness\": 0.0434, \"Acousticness\": 0.932, \"Liveness\": 0.088, \"Tempo\": 72.795, \"Duration (ms)\": 213827.0, \"Valence\": 0.387, \"Chord\": \"C\"}, {\"Index\": 418, \"Highest Charting Position\": 73, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"LOCATION\", \"Streams\": 4940701, \"Artist\": \"KAROL G, Anuel AA, J Balvin\", \"Artist Followers\": 1250353.0, \"Song ID\": \"1aH3EQY5LTXjRZQLpl1Gby\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 0.0, \"Danceability\": 0.772, \"Energy\": 0.758, \"Loudness\": -3.891, \"Speechiness\": 0.0482, \"Acousticness\": 0.0433, \"Liveness\": 0.295, \"Tempo\": 115.977, \"Duration (ms)\": 265240.0, \"Valence\": 0.654, \"Chord\": \"A\"}, {\"Index\": 419, \"Highest Charting Position\": 177, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Stressed Out\", \"Streams\": 4913147, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20823062.0, \"Song ID\": \"3CRDbSIZ4r5MsZ0YwxuEkn\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2015-05-15\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 83.0, \"Danceability\": 0.734, \"Energy\": 0.637, \"Loudness\": -5.677, \"Speechiness\": 0.141, \"Acousticness\": 0.0462, \"Liveness\": 0.0602, \"Tempo\": 169.977, \"Duration (ms)\": 202333.0, \"Valence\": 0.648, \"Chord\": \"E\"}, {\"Index\": 420, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Ski\", \"Streams\": 7753784, \"Artist\": \"Young Stoner Life, Young Thug, Gunna\", \"Artist Followers\": 61930.0, \"Song ID\": \"6755DFiZ7CWe2WMdTGW5C1\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-04-16--2021-04-23\", \"Popularity\": 78.0, \"Danceability\": 0.953, \"Energy\": 0.621, \"Loudness\": -7.638, \"Speechiness\": 0.221, \"Acousticness\": 0.017, \"Liveness\": 0.0398, \"Tempo\": 123.016, \"Duration (ms)\": 152333.0, \"Valence\": 0.883, \"Chord\": \"G#/Ab\"}, {\"Index\": 421, \"Highest Charting Position\": 75, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Diamonds Dancing (feat. Travis Scott)\", \"Streams\": 7515766, \"Artist\": \"Young Stoner Life, Young Thug, Gunna\", \"Artist Followers\": 61930.0, \"Song ID\": \"7uZqvqXzzYMKrexKxdcGmd\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-04-16--2021-04-23\", \"Popularity\": 69.0, \"Danceability\": 0.851, \"Energy\": 0.703, \"Loudness\": -7.351, \"Speechiness\": 0.303, \"Acousticness\": 0.00949, \"Liveness\": 0.0895, \"Tempo\": 74.017, \"Duration (ms)\": 242600.0, \"Valence\": 0.596, \"Chord\": \"E\"}, {\"Index\": 422, \"Highest Charting Position\": 8, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Love Story (Taylor\\u2019s Version)\", \"Streams\": 6202933, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6YvqWjhGD8mB5QXcbcUKtx\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 73.0, \"Danceability\": 0.627, \"Energy\": 0.792, \"Loudness\": -4.311, \"Speechiness\": 0.031, \"Acousticness\": 0.13, \"Liveness\": 0.0845, \"Tempo\": 119.054, \"Duration (ms)\": 235767.0, \"Valence\": 0.415, \"Chord\": \"D\"}, {\"Index\": 423, \"Highest Charting Position\": 107, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Ele \\u00c9 Ele, Eu Sou Eu\", \"Streams\": 5380517, \"Artist\": \"Wesley Safad\\u00e3o, Os Bar\\u00f5es Da Pisadinha\", \"Artist Followers\": 9907270.0, \"Song ID\": \"7EWXP47VlXKO3r7mNxuWHw\", \"Genre\": \"['forro']\", \"Release Date\": \"2020-11-12\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 73.0, \"Danceability\": 0.758, \"Energy\": 0.763, \"Loudness\": -8.754, \"Speechiness\": 0.0768, \"Acousticness\": 0.23, \"Liveness\": 0.0703, \"Tempo\": 163.946, \"Duration (ms)\": 155210.0, \"Valence\": 0.854, \"Chord\": \"C#/Db\"}, {\"Index\": 424, \"Highest Charting Position\": 186, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Quero Ver \\u00e9 Me Esquecer (feat. Jorge) - Ao Vivo\", \"Streams\": 5159208, \"Artist\": \"Os Bar\\u00f5es Da Pisadinha\", \"Artist Followers\": 4271775.0, \"Song ID\": \"2SUPbyD77tJuOUbqbxct6l\", \"Genre\": \"['forro', 'piseiro']\", \"Release Date\": \"2021-02-19\", \"Weeks Charted\": \"2021-04-16--2021-04-23\", \"Popularity\": 80.0, \"Danceability\": 0.593, \"Energy\": 0.932, \"Loudness\": -2.324, \"Speechiness\": 0.0526, \"Acousticness\": 0.302, \"Liveness\": 0.133, \"Tempo\": 171.977, \"Duration (ms)\": 147876.0, \"Valence\": 0.913, \"Chord\": \"G#/Ab\"}, {\"Index\": 425, \"Highest Charting Position\": 3, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"willow\", \"Streams\": 5016865, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0lx2cLdOt3piJbcaXIV74f\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 79.0, \"Danceability\": 0.392, \"Energy\": 0.574, \"Loudness\": -9.195, \"Speechiness\": 0.17, \"Acousticness\": 0.833, \"Liveness\": 0.145, \"Tempo\": 81.112, \"Duration (ms)\": 214707.0, \"Valence\": 0.529, \"Chord\": \"G\"}, {\"Index\": 426, \"Highest Charting Position\": 104, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Why'd You Only Call Me When You're High?\", \"Streams\": 4976405, \"Artist\": \"Arctic Monkeys\", \"Artist Followers\": 12375514.0, \"Song ID\": \"086myS9r57YsLbJpU0TgK9\", \"Genre\": \"['garage rock', 'permanent wave', 'rock', 'sheffield indie']\", \"Release Date\": \"2013-09-09\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 82.0, \"Danceability\": 0.691, \"Energy\": 0.631, \"Loudness\": -6.478, \"Speechiness\": 0.0368, \"Acousticness\": 0.0483, \"Liveness\": 0.104, \"Tempo\": 92.004, \"Duration (ms)\": 161124.0, \"Valence\": 0.8, \"Chord\": \"D\"}, {\"Index\": 427, \"Highest Charting Position\": 18, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Afterglow\", \"Streams\": 4965330, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 1250353.0, \"Song ID\": \"5dA45onYgYACRp8C5xEOS9\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\", \"Popularity\": 0.0, \"Danceability\": 0.641, \"Energy\": 0.324, \"Loudness\": -5.851, \"Speechiness\": 0.0299, \"Acousticness\": 0.698, \"Liveness\": 0.328, \"Tempo\": 110.184, \"Duration (ms)\": 185487.0, \"Valence\": 0.273, \"Chord\": \"B\"}, {\"Index\": 428, \"Highest Charting Position\": 43, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"LA CANCI\\u00d3N\", \"Streams\": 4959754, \"Artist\": \"J Balvin, Bad Bunny\", \"Artist Followers\": 29051363.0, \"Song ID\": \"0fea68AdmYNygeTGI4RC18\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.754, \"Energy\": 0.646, \"Loudness\": -5.795, \"Speechiness\": 0.317, \"Acousticness\": 0.152, \"Liveness\": 0.108, \"Tempo\": 176.089, \"Duration (ms)\": 242573.0, \"Valence\": 0.429, \"Chord\": \"G\"}, {\"Index\": 429, \"Highest Charting Position\": 52, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"You Belong With Me (Taylor\\u2019s Version)\", \"Streams\": 9872084, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1qrpoAMXodY6895hGKoUpA\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 73.0, \"Danceability\": 0.632, \"Energy\": 0.773, \"Loudness\": -4.856, \"Speechiness\": 0.0346, \"Acousticness\": 0.0623, \"Liveness\": 0.0885, \"Tempo\": 130.033, \"Duration (ms)\": 231124.0, \"Valence\": 0.474, \"Chord\": \"F#/Gb\"}, {\"Index\": 430, \"Highest Charting Position\": 54, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Fearless (Taylor\\u2019s Version)\", \"Streams\": 9676024, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"77sMIMlNaSURUAXq5coCxE\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 69.0, \"Danceability\": 0.569, \"Energy\": 0.741, \"Loudness\": -4.963, \"Speechiness\": 0.0282, \"Acousticness\": 0.0122, \"Liveness\": 0.333, \"Tempo\": 100.118, \"Duration (ms)\": 241592.0, \"Valence\": 0.43, \"Chord\": \"F\"}, {\"Index\": 431, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"X Gon' Give It To Ya\", \"Streams\": 8638360, \"Artist\": \"DMX\", \"Artist Followers\": 2815928.0, \"Song ID\": \"1zzxoZVylsna2BQB65Ppcb\", \"Genre\": \"['east coast hip hop', 'gangster rap', 'hardcore hip hop', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2007-06-12\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 73.0, \"Danceability\": 0.761, \"Energy\": 0.899, \"Loudness\": -3.09, \"Speechiness\": 0.183, \"Acousticness\": 0.0135, \"Liveness\": 0.0719, \"Tempo\": 95.027, \"Duration (ms)\": 217587.0, \"Valence\": 0.673, \"Chord\": \"A#/Bb\"}, {\"Index\": 432, \"Highest Charting Position\": 80, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Fifteen (Taylor\\u2019s Version)\", \"Streams\": 7852063, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2nqio0SfWg6gh2eCtfuMa5\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 66.0, \"Danceability\": 0.559, \"Energy\": 0.646, \"Loudness\": -4.61, \"Speechiness\": 0.0272, \"Acousticness\": 0.116, \"Liveness\": 0.32, \"Tempo\": 95.466, \"Duration (ms)\": 294419.0, \"Valence\": 0.289, \"Chord\": \"G\"}, {\"Index\": 433, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"The Way I Loved You (Taylor\\u2019s Version)\", \"Streams\": 7736262, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"22bPsP2jCgbLUvh82U0Z3M\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 72.0, \"Danceability\": 0.402, \"Energy\": 0.732, \"Loudness\": -4.665, \"Speechiness\": 0.0484, \"Acousticness\": 0.0033, \"Liveness\": 0.108, \"Tempo\": 161.032, \"Duration (ms)\": 243137.0, \"Valence\": 0.472, \"Chord\": \"F\"}, {\"Index\": 434, \"Highest Charting Position\": 51, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"You All Over Me (feat. Maren Morris) (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 7712896, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5pcjystBtalYeqaiXCcgEY\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 65.0, \"Danceability\": 0.589, \"Energy\": 0.496, \"Loudness\": -7.606, \"Speechiness\": 0.0377, \"Acousticness\": 0.818, \"Liveness\": 0.101, \"Tempo\": 142.731, \"Duration (ms)\": 220839.0, \"Valence\": 0.44, \"Chord\": \"D\"}, {\"Index\": 435, \"Highest Charting Position\": 93, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Hey Stephen (Taylor\\u2019s Version)\", \"Streams\": 7385864, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"550erGcdD9n6PnwxrvYqZT\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 66.0, \"Danceability\": 0.788, \"Energy\": 0.571, \"Loudness\": -6.135, \"Speechiness\": 0.0296, \"Acousticness\": 0.106, \"Liveness\": 0.0934, \"Tempo\": 115.99, \"Duration (ms)\": 254255.0, \"Valence\": 0.797, \"Chord\": \"F#/Gb\"}, {\"Index\": 436, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"White Horse (Taylor\\u2019s Version)\", \"Streams\": 7039222, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5YL553x8sHderRBDlm3NM3\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 65.0, \"Danceability\": 0.423, \"Energy\": 0.517, \"Loudness\": -7.377, \"Speechiness\": 0.0486, \"Acousticness\": 0.369, \"Liveness\": 0.177, \"Tempo\": 185.262, \"Duration (ms)\": 234516.0, \"Valence\": 0.366, \"Chord\": \"C\"}, {\"Index\": 437, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Forever & Always (Taylor\\u2019s Version)\", \"Streams\": 6566059, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1msEuwSBneBKpVCZQcFTsU\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 66.0, \"Danceability\": 0.598, \"Energy\": 0.821, \"Loudness\": -4.433, \"Speechiness\": 0.0447, \"Acousticness\": 0.0231, \"Liveness\": 0.143, \"Tempo\": 128.03, \"Duration (ms)\": 225328.0, \"Valence\": 0.673, \"Chord\": \"A#/Bb\"}, {\"Index\": 438, \"Highest Charting Position\": 119, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Breathe (feat. Colbie Caillat) (Taylor\\u2019s Version)\", \"Streams\": 6508683, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7HC7R2D8WjXVcUHJyEGjRs\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 64.0, \"Danceability\": 0.506, \"Energy\": 0.626, \"Loudness\": -6.066, \"Speechiness\": 0.0287, \"Acousticness\": 0.156, \"Liveness\": 0.228, \"Tempo\": 148.035, \"Duration (ms)\": 263377.0, \"Valence\": 0.321, \"Chord\": \"C#/Db\"}, {\"Index\": 439, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Ruff Ryders' Anthem\", \"Streams\": 5988511, \"Artist\": \"DMX\", \"Artist Followers\": 2815928.0, \"Song ID\": \"1BKT2I9x4RGKaKqW4up34s\", \"Genre\": \"['east coast hip hop', 'gangster rap', 'hardcore hip hop', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"1998-05-01\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 72.0, \"Danceability\": 0.88, \"Energy\": 0.577, \"Loudness\": -8.093, \"Speechiness\": 0.302, \"Acousticness\": 0.0564, \"Liveness\": 0.201, \"Tempo\": 90.991, \"Duration (ms)\": 214440.0, \"Valence\": 0.74, \"Chord\": \"A#/Bb\"}, {\"Index\": 440, \"Highest Charting Position\": 146, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"That\\u2019s When (feat. Keith Urban) (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5889939, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7eResoqEJJAVTkQYSqvO3P\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 67.0, \"Danceability\": 0.588, \"Energy\": 0.608, \"Loudness\": -7.062, \"Speechiness\": 0.0365, \"Acousticness\": 0.225, \"Liveness\": 0.092, \"Tempo\": 90.201, \"Duration (ms)\": 189496.0, \"Valence\": 0.508, \"Chord\": \"F\"}, {\"Index\": 441, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Tell Me Why (Taylor\\u2019s Version)\", \"Streams\": 5885151, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0k0vFacOHNuArLWMiH60p7\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 63.0, \"Danceability\": 0.578, \"Energy\": 0.909, \"Loudness\": -3.669, \"Speechiness\": 0.0628, \"Acousticness\": 0.0222, \"Liveness\": 0.333, \"Tempo\": 100.023, \"Duration (ms)\": 200576.0, \"Valence\": 0.541, \"Chord\": \"G\"}, {\"Index\": 442, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"You\\u2019re Not Sorry (Taylor\\u2019s Version)\", \"Streams\": 5860405, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6iiAfo4wTA2CVC3Uwx9uh8\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 64.0, \"Danceability\": 0.506, \"Energy\": 0.444, \"Loudness\": -4.99, \"Speechiness\": 0.0285, \"Acousticness\": 0.0538, \"Liveness\": 0.123, \"Tempo\": 133.873, \"Duration (ms)\": 261843.0, \"Valence\": 0.241, \"Chord\": \"F#/Gb\"}, {\"Index\": 443, \"Highest Charting Position\": 40, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Chica Ideal\", \"Streams\": 5217052, \"Artist\": \"Sebastian Yatra, Guaynaa\", \"Artist Followers\": 1250353.0, \"Song ID\": \"6M3Bdl5UtQtmjnYDW69LZQ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 0.0, \"Danceability\": 0.574, \"Energy\": 0.891, \"Loudness\": -3.665, \"Speechiness\": 0.157, \"Acousticness\": 0.0847, \"Liveness\": 0.16, \"Tempo\": 100.978, \"Duration (ms)\": 183240.0, \"Valence\": 0.707, \"Chord\": \"C\"}, {\"Index\": 444, \"Highest Charting Position\": 15, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Relaci\\u00f3n - Remix\", \"Streams\": 5206614, \"Artist\": \"Sech, Daddy Yankee, J Balvin, ROSAL\\u00cdA, Farruko\", \"Artist Followers\": 8758283.0, \"Song ID\": \"35UUpTmrcFXNIVIN26ujXl\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 80.0, \"Danceability\": 0.793, \"Energy\": 0.771, \"Loudness\": -3.417, \"Speechiness\": 0.0959, \"Acousticness\": 0.0337, \"Liveness\": 0.284, \"Tempo\": 171.943, \"Duration (ms)\": 247308.0, \"Valence\": 0.835, \"Chord\": \"F\"}, {\"Index\": 445, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Don\\u2019t You (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5197564, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"4uuEGH5SVuzkkSFjo2DEiY\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 65.0, \"Danceability\": 0.563, \"Energy\": 0.473, \"Loudness\": -11.548, \"Speechiness\": 0.0503, \"Acousticness\": 0.514, \"Liveness\": 0.109, \"Tempo\": 101.934, \"Duration (ms)\": 208609.0, \"Valence\": 0.405, \"Chord\": \"D#/Eb\"}, {\"Index\": 446, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"We Were Happy (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5189423, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"34V9RiEPe8MNdU32qJsJa1\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 64.0, \"Danceability\": 0.609, \"Energy\": 0.373, \"Loudness\": -8.819, \"Speechiness\": 0.0263, \"Acousticness\": 0.849, \"Liveness\": 0.0779, \"Tempo\": 106.007, \"Duration (ms)\": 244237.0, \"Valence\": 0.13, \"Chord\": \"C\"}, {\"Index\": 447, \"Highest Charting Position\": 153, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"WACHA\", \"Streams\": 5172999, \"Artist\": \"KHEA, Duki\", \"Artist Followers\": 3198705.0, \"Song ID\": \"5RmSunLqeDqNWww8LWhAiK\", \"Genre\": \"['argentine hip hop', 'trap argentino', 'trap latino', 'trap triste']\", \"Release Date\": \"2021-04-01\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 75.0, \"Danceability\": 0.737, \"Energy\": 0.634, \"Loudness\": -4.25, \"Speechiness\": 0.0424, \"Acousticness\": 0.345, \"Liveness\": 0.111, \"Tempo\": 94.927, \"Duration (ms)\": 206360.0, \"Valence\": 0.528, \"Chord\": \"D#/Eb\"}, {\"Index\": 448, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Dancing With The Devil\", \"Streams\": 5836326, \"Artist\": \"Demi Lovato\", \"Artist Followers\": 20338833.0, \"Song ID\": \"2kONpeXXK70YEs7c0UQbmq\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-04-02--2021-04-09\", \"Popularity\": 66.0, \"Danceability\": 0.413, \"Energy\": 0.64, \"Loudness\": -5.811, \"Speechiness\": 0.0427, \"Acousticness\": 0.273, \"Liveness\": 0.11, \"Tempo\": 75.245, \"Duration (ms)\": 243992.0, \"Valence\": 0.149, \"Chord\": \"G#/Ab\"}, {\"Index\": 449, \"Highest Charting Position\": 26, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Gone\", \"Streams\": 5427638, \"Artist\": \"ROS\\u00c9\", \"Artist Followers\": 1099480.0, \"Song ID\": \"2dHoVW9AxJVSRebPRyV2aA\", \"Genre\": \"[]\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 71.0, \"Danceability\": 0.647, \"Energy\": 0.377, \"Loudness\": -6.003, \"Speechiness\": 0.0375, \"Acousticness\": 0.594, \"Liveness\": 0.0768, \"Tempo\": 79.936, \"Duration (ms)\": 207164.0, \"Valence\": 0.653, \"Chord\": \"F#/Gb\"}, {\"Index\": 450, \"Highest Charting Position\": 160, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"What Other People Say\", \"Streams\": 5413003, \"Artist\": \"Sam Fischer, Demi Lovato\", \"Artist Followers\": 122746.0, \"Song ID\": \"2h9TDNEXRhcDIV3fsoEVq9\", \"Genre\": \"['alt z', 'australian pop', 'dance pop', 'indie cafe pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2021-02-04\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\", \"Popularity\": 77.0, \"Danceability\": 0.652, \"Energy\": 0.472, \"Loudness\": -8.084, \"Speechiness\": 0.0399, \"Acousticness\": 0.158, \"Liveness\": 0.121, \"Tempo\": 126.904, \"Duration (ms)\": 194890.0, \"Valence\": 0.24, \"Chord\": \"G\"}, {\"Index\": 451, \"Highest Charting Position\": 88, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Hello (feat. A Boogie Wit da Hoodie)\", \"Streams\": 5323062, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"2r6OAV3WsYtXuXjvJ1lIDi\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-20\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 82.0, \"Danceability\": 0.905, \"Energy\": 0.647, \"Loudness\": -5.065, \"Speechiness\": 0.107, \"Acousticness\": 0.0187, \"Liveness\": 0.282, \"Tempo\": 130.97, \"Duration (ms)\": 190534.0, \"Valence\": 0.367, \"Chord\": \"A#/Bb\"}, {\"Index\": 452, \"Highest Charting Position\": 91, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Hasta Abajo\", \"Streams\": 5269163, \"Artist\": \"Kevin Roldan, Bryant Myers, Lyanno\", \"Artist Followers\": 4026643.0, \"Song ID\": \"4PEfJZpVjdclfzZ9XO8uDw\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'reggaeton colombiano', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 77.0, \"Danceability\": 0.714, \"Energy\": 0.671, \"Loudness\": -5.119, \"Speechiness\": 0.362, \"Acousticness\": 0.289, \"Liveness\": 0.325, \"Tempo\": 169.732, \"Duration (ms)\": 229827.0, \"Valence\": 0.641, \"Chord\": \"F\"}, {\"Index\": 453, \"Highest Charting Position\": 30, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Take You Dancing\", \"Streams\": 5176493, \"Artist\": \"Jason Derulo\", \"Artist Followers\": 9778632.0, \"Song ID\": \"59qrUpoplZxbIZxk6X0Bm3\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2020-07-22\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 82.0, \"Danceability\": 0.789, \"Energy\": 0.711, \"Loudness\": -4.248, \"Speechiness\": 0.041, \"Acousticness\": 0.0332, \"Liveness\": 0.0876, \"Tempo\": 112.985, \"Duration (ms)\": 190306.0, \"Valence\": 0.753, \"Chord\": \"D\"}, {\"Index\": 454, \"Highest Charting Position\": 28, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Unstable (feat. The Kid LAROI)\", \"Streams\": 5137645, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"137mSruegm1u6x9NvwiagR\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 74.0, \"Danceability\": 0.495, \"Energy\": 0.333, \"Loudness\": -10.109, \"Speechiness\": 0.0288, \"Acousticness\": 0.737, \"Liveness\": 0.112, \"Tempo\": 99.757, \"Duration (ms)\": 158324.0, \"Valence\": 0.37, \"Chord\": \"E\"}, {\"Index\": 455, \"Highest Charting Position\": 2, \"Number of Times Charted\": 48, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Stuck with U (with Justin Bieber)\", \"Streams\": 5094660, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"4HBZA5flZLE435QTztThqH\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 84.0, \"Danceability\": 0.597, \"Energy\": 0.45, \"Loudness\": -6.658, \"Speechiness\": 0.0418, \"Acousticness\": 0.223, \"Liveness\": 0.382, \"Tempo\": 178.765, \"Duration (ms)\": 228482.0, \"Valence\": 0.537, \"Chord\": \"G#/Ab\"}, {\"Index\": 456, \"Highest Charting Position\": 120, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Hayloft\", \"Streams\": 5086382, \"Artist\": \"Mother Mother\", \"Artist Followers\": 2110870.0, \"Song ID\": \"2kS6td1yvmpNgZTt1q5pQq\", \"Genre\": \"['indie pop', 'vancouver indie']\", \"Release Date\": \"2008-09-23\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 81.0, \"Danceability\": 0.527, \"Energy\": 0.922, \"Loudness\": -2.666, \"Speechiness\": 0.0728, \"Acousticness\": 0.00475, \"Liveness\": 0.422, \"Tempo\": 95.975, \"Duration (ms)\": 181680.0, \"Valence\": 0.49, \"Chord\": \"A\"}, {\"Index\": 457, \"Highest Charting Position\": 191, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Esquema Preferido (feat. Tarc\\u00edsio do Acordeon)\", \"Streams\": 5078174, \"Artist\": \"DJ Ivis\", \"Artist Followers\": 342930.0, \"Song ID\": \"0e6NlGJxYlHvAN8SKxad7N\", \"Genre\": \"['piseiro']\", \"Release Date\": \"2020-11-26\", \"Weeks Charted\": \"2021-04-02--2021-04-09\", \"Popularity\": 73.0, \"Danceability\": 0.676, \"Energy\": 0.823, \"Loudness\": -4.386, \"Speechiness\": 0.102, \"Acousticness\": 0.242, \"Liveness\": 0.0773, \"Tempo\": 160.013, \"Duration (ms)\": 190680.0, \"Valence\": 0.907, \"Chord\": \"F\"}, {\"Index\": 458, \"Highest Charting Position\": 75, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Adem\\u00e1s de M\\u00ed - Remix\", \"Streams\": 5060336, \"Artist\": \"Rusherking, KHEA, Duki, Maria Becerra, LIT killah, Tiago PZK\", \"Artist Followers\": 301217.0, \"Song ID\": \"7I8L3vYCLThw2FDrE6LuzE\", \"Genre\": \"['trap argentino', 'trap latino', 'trap triste']\", \"Release Date\": \"2021-03-04\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 78.0, \"Danceability\": 0.397, \"Energy\": 0.613, \"Loudness\": -5.077, \"Speechiness\": 0.0549, \"Acousticness\": 0.0396, \"Liveness\": 0.192, \"Tempo\": 78.4, \"Duration (ms)\": 330040.0, \"Valence\": 0.405, \"Chord\": \"F#/Gb\"}, {\"Index\": 459, \"Highest Charting Position\": 193, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Payphone\", \"Streams\": 5052717, \"Artist\": \"Maroon 5, Wiz Khalifa\", \"Artist Followers\": 32279979.0, \"Song ID\": \"1LmN9SSHISbtp9LoaR5ZVJ\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2012-01-01\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 74.0, \"Danceability\": 0.739, \"Energy\": 0.756, \"Loudness\": -4.828, \"Speechiness\": 0.0394, \"Acousticness\": 0.0136, \"Liveness\": 0.37, \"Tempo\": 110.028, \"Duration (ms)\": 231387.0, \"Valence\": 0.523, \"Chord\": \"E\"}, {\"Index\": 460, \"Highest Charting Position\": 50, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Ghost\", \"Streams\": 5013450, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6I3mqTwhRpn34SLVafSH7G\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 71.0, \"Danceability\": 0.601, \"Energy\": 0.741, \"Loudness\": -5.569, \"Speechiness\": 0.0478, \"Acousticness\": 0.185, \"Liveness\": 0.415, \"Tempo\": 153.96, \"Duration (ms)\": 153190.0, \"Valence\": 0.441, \"Chord\": \"D\"}, {\"Index\": 461, \"Highest Charting Position\": 37, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Off My Face\", \"Streams\": 5004111, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"3T03rPwlL8NVk1yIaxeD8U\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 75.0, \"Danceability\": 0.509, \"Energy\": 0.228, \"Loudness\": -8.68, \"Speechiness\": 0.0332, \"Acousticness\": 0.92, \"Liveness\": 0.104, \"Tempo\": 90.674, \"Duration (ms)\": 156468.0, \"Valence\": 0.586, \"Chord\": \"E\"}, {\"Index\": 462, \"Highest Charting Position\": 140, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Whats Poppin (feat. DaBaby, Tory Lanez & Lil Wayne) [Remix] - Bonus Track\", \"Streams\": 4972518, \"Artist\": \"Jack Harlow\", \"Artist Followers\": 1053324.0, \"Song ID\": \"0ZLuW8uOXdFNWcI40C0OC2\", \"Genre\": \"['deep underground hip hop', 'kentucky hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\", \"Popularity\": 73.0, \"Danceability\": 0.904, \"Energy\": 0.723, \"Loudness\": -5.224, \"Speechiness\": 0.26, \"Acousticness\": 0.0631, \"Liveness\": 0.185, \"Tempo\": 145.013, \"Duration (ms)\": 227478.0, \"Valence\": 0.835, \"Chord\": \"B\"}, {\"Index\": 463, \"Highest Charting Position\": 188, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Take on Me\", \"Streams\": 4969662, \"Artist\": \"a-ha\", \"Artist Followers\": 1560784.0, \"Song ID\": \"2WfaOiMkCvy7F5fcp2zZ8L\", \"Genre\": \"['new romantic', 'new wave', 'new wave pop', 'permanent wave', 'soft rock', 'synthpop']\", \"Release Date\": \"1985-06-01\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 84.0, \"Danceability\": 0.573, \"Energy\": 0.902, \"Loudness\": -7.638, \"Speechiness\": 0.054, \"Acousticness\": 0.018, \"Liveness\": 0.0928, \"Tempo\": 84.412, \"Duration (ms)\": 225280.0, \"Valence\": 0.876, \"Chord\": \"F#/Gb\"}, {\"Index\": 464, \"Highest Charting Position\": 45, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"BEB\\u00c9\", \"Streams\": 4967348, \"Artist\": \"Camilo, El Alfa\", \"Artist Followers\": 10580764.0, \"Song ID\": \"7D7EH7MGyNHWSkqrszerI1\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-11-25\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 78.0, \"Danceability\": 0.862, \"Energy\": 0.72, \"Loudness\": -4.048, \"Speechiness\": 0.0379, \"Acousticness\": 0.487, \"Liveness\": 0.0604, \"Tempo\": 129.972, \"Duration (ms)\": 198707.0, \"Valence\": 0.965, \"Chord\": \"E\"}, {\"Index\": 465, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Richer (feat. Polo G)\", \"Streams\": 6292362, \"Artist\": \"Rod Wave\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-03-26--2021-04-02\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 466, \"Highest Charting Position\": 128, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Tu Veneno\", \"Streams\": 6007541, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"5KFHrrBMyGj5MhVbZMM3ts\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 76.0, \"Danceability\": 0.664, \"Energy\": 0.659, \"Loudness\": -4.232, \"Speechiness\": 0.0873, \"Acousticness\": 0.0625, \"Liveness\": 0.0874, \"Tempo\": 175.826, \"Duration (ms)\": 157320.0, \"Valence\": 0.797, \"Chord\": \"A#/Bb\"}, {\"Index\": 467, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Deserve You\", \"Streams\": 5837372, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5NU40QTlXrDUJzDBdv79bg\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 69.0, \"Danceability\": 0.677, \"Energy\": 0.633, \"Loudness\": -7.831, \"Speechiness\": 0.0771, \"Acousticness\": 0.0314, \"Liveness\": 0.112, \"Tempo\": 89.934, \"Duration (ms)\": 187239.0, \"Valence\": 0.409, \"Chord\": \"G\"}, {\"Index\": 468, \"Highest Charting Position\": 44, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"2 Much\", \"Streams\": 5794583, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"0oaY19dUwZimIgzn3ZZLZO\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 70.0, \"Danceability\": 0.583, \"Energy\": 0.444, \"Loudness\": -8.601, \"Speechiness\": 0.0456, \"Acousticness\": 0.593, \"Liveness\": 0.353, \"Tempo\": 119.59, \"Duration (ms)\": 152796.0, \"Valence\": 0.167, \"Chord\": \"A\"}, {\"Index\": 469, \"Highest Charting Position\": 3, \"Number of Times Charted\": 66, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Tusa\", \"Streams\": 5510113, \"Artist\": \"KAROL G, Nicki Minaj\", \"Artist Followers\": 17792779.0, \"Song ID\": \"7k4t7uLgtOxPwTpFmtJNTY\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.803, \"Energy\": 0.715, \"Loudness\": -3.28, \"Speechiness\": 0.298, \"Acousticness\": 0.295, \"Liveness\": 0.0574, \"Tempo\": 101.085, \"Duration (ms)\": 200960.0, \"Valence\": 0.574, \"Chord\": \"D\"}, {\"Index\": 470, \"Highest Charting Position\": 34, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Una Locura\", \"Streams\": 5466954, \"Artist\": \"Ozuna, J Balvin, Chencho Corleone\", \"Artist Followers\": 29238936.0, \"Song ID\": \"5y7DaS3jAc9eZzcSOoUIwU\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 81.0, \"Danceability\": 0.714, \"Energy\": 0.761, \"Loudness\": -4.596, \"Speechiness\": 0.0427, \"Acousticness\": 0.139, \"Liveness\": 0.241, \"Tempo\": 168.022, \"Duration (ms)\": 230693.0, \"Valence\": 0.906, \"Chord\": \"F\"}, {\"Index\": 471, \"Highest Charting Position\": 61, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Loved By You (feat. Burna Boy)\", \"Streams\": 5419040, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2tB9OFgAHjAds3cqquLlvp\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 69.0, \"Danceability\": 0.79, \"Energy\": 0.724, \"Loudness\": -6.972, \"Speechiness\": 0.0852, \"Acousticness\": 0.0696, \"Liveness\": 0.113, \"Tempo\": 101.04, \"Duration (ms)\": 159250.0, \"Valence\": 0.642, \"Chord\": \"C#/Db\"}, {\"Index\": 472, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Girls Like Us\", \"Streams\": 5410730, \"Artist\": \"Zoe Wees\", \"Artist Followers\": 203555.0, \"Song ID\": \"5SFXOMJJ334Wn2PwBHeRZN\", \"Genre\": \"['german pop']\", \"Release Date\": \"2021-01-12\", \"Weeks Charted\": \"2021-03-26--2021-04-02\", \"Popularity\": 78.0, \"Danceability\": 0.444, \"Energy\": 0.648, \"Loudness\": -4.955, \"Speechiness\": 0.0476, \"Acousticness\": 0.288, \"Liveness\": 0.059, \"Tempo\": 125.706, \"Duration (ms)\": 189000.0, \"Valence\": 0.171, \"Chord\": \"C#/Db\"}, {\"Index\": 473, \"Highest Charting Position\": 17, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Lemon Pepper Freestyle (feat. Rick Ross)\", \"Streams\": 5365747, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"4FRW5Nza1Ym91BGV4nFWXI\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 76.0, \"Danceability\": 0.77, \"Energy\": 0.637, \"Loudness\": -5.53, \"Speechiness\": 0.345, \"Acousticness\": 0.103, \"Liveness\": 0.171, \"Tempo\": 94.966, \"Duration (ms)\": 383037.0, \"Valence\": 0.431, \"Chord\": \"C#/Db\"}, {\"Index\": 474, \"Highest Charting Position\": 97, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Esquema Preferido\", \"Streams\": 5356696, \"Artist\": \"DJ Ivis, Tarc\\u00edsio do Acordeon\", \"Artist Followers\": 342930.0, \"Song ID\": \"0e6NlGJxYlHvAN8SKxad7N\", \"Genre\": \"['piseiro']\", \"Release Date\": \"2020-11-26\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 73.0, \"Danceability\": 0.676, \"Energy\": 0.823, \"Loudness\": -4.386, \"Speechiness\": 0.102, \"Acousticness\": 0.242, \"Liveness\": 0.0773, \"Tempo\": 160.013, \"Duration (ms)\": 190680.0, \"Valence\": 0.907, \"Chord\": \"F\"}, {\"Index\": 475, \"Highest Charting Position\": 105, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Love Not War (The Tampa Beat)\", \"Streams\": 5326719, \"Artist\": \"Jason Derulo, Nuka\", \"Artist Followers\": 9778632.0, \"Song ID\": \"4Lt6GXGzYsa1tgkv3nGSTm\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 79.0, \"Danceability\": 0.738, \"Energy\": 0.85, \"Loudness\": -3.049, \"Speechiness\": 0.0642, \"Acousticness\": 0.105, \"Liveness\": 0.23, \"Tempo\": 98.013, \"Duration (ms)\": 192921.0, \"Valence\": 0.865, \"Chord\": \"G#/Ab\"}, {\"Index\": 476, \"Highest Charting Position\": 57, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Die For You (feat. Dominic Fike)\", \"Streams\": 5323412, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"7aely3H8kMj9o0gt6vXHE1\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 67.0, \"Danceability\": 0.728, \"Energy\": 0.629, \"Loudness\": -6.629, \"Speechiness\": 0.0318, \"Acousticness\": 0.00196, \"Liveness\": 0.0847, \"Tempo\": 135.031, \"Duration (ms)\": 198426.0, \"Valence\": 0.71, \"Chord\": \"C#/Db\"}, {\"Index\": 477, \"Highest Charting Position\": 64, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Starboy\", \"Streams\": 5302285, \"Artist\": \"The Weeknd, Daft Punk\", \"Artist Followers\": 35340069.0, \"Song ID\": \"7MXVkk9YMctZqd1Srtv4MB\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2016-11-25\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 83.0, \"Danceability\": 0.679, \"Energy\": 0.587, \"Loudness\": -7.015, \"Speechiness\": 0.276, \"Acousticness\": 0.141, \"Liveness\": 0.137, \"Tempo\": 186.003, \"Duration (ms)\": 230453.0, \"Valence\": 0.486, \"Chord\": \"G\"}, {\"Index\": 478, \"Highest Charting Position\": 22, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"La T\\u00f3xica\", \"Streams\": 5255393, \"Artist\": \"Farruko\", \"Artist Followers\": 10510156.0, \"Song ID\": \"15OjBeqNX3bShsGYQbteRv\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 78.0, \"Danceability\": 0.659, \"Energy\": 0.701, \"Loudness\": -4.107, \"Speechiness\": 0.164, \"Acousticness\": 0.0882, \"Liveness\": 0.0866, \"Tempo\": 91.97, \"Duration (ms)\": 180520.0, \"Valence\": 0.623, \"Chord\": \"A\"}, {\"Index\": 479, \"Highest Charting Position\": 181, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Cora\\u00e7\\u00e3o Na Cama - Ao Vivo\", \"Streams\": 5211351, \"Artist\": \"Hugo & Guilherme\", \"Artist Followers\": 435936.0, \"Song ID\": \"2nZj5YymF54qhAu7RneVP6\", \"Genre\": \"['sertanejo pop']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 77.0, \"Danceability\": 0.764, \"Energy\": 0.794, \"Loudness\": -4.096, \"Speechiness\": 0.0589, \"Acousticness\": 0.663, \"Liveness\": 0.34, \"Tempo\": 110.013, \"Duration (ms)\": 173227.0, \"Valence\": 0.721, \"Chord\": \"G#/Ab\"}, {\"Index\": 480, \"Highest Charting Position\": 60, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Love You Different (feat. BEAM)\", \"Streams\": 10024729, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"27UcQ6dAvQrgH9C880rCM3\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-19--2021-03-26\", \"Popularity\": 66.0, \"Danceability\": 0.759, \"Energy\": 0.584, \"Loudness\": -6.655, \"Speechiness\": 0.06, \"Acousticness\": 0.0652, \"Liveness\": 0.16, \"Tempo\": 127.138, \"Duration (ms)\": 186696.0, \"Valence\": 0.374, \"Chord\": \"G#/Ab\"}, {\"Index\": 481, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Somebody\", \"Streams\": 8912458, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"3rLIv187BhjyweFe89SgLn\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2010-01-01\", \"Weeks Charted\": \"2021-03-19--2021-03-26\", \"Popularity\": 67.0, \"Danceability\": 0.714, \"Energy\": 0.833, \"Loudness\": -5.239, \"Speechiness\": 0.0259, \"Acousticness\": 0.00249, \"Liveness\": 0.298, \"Tempo\": 129.964, \"Duration (ms)\": 220920.0, \"Valence\": 0.663, \"Chord\": \"F\"}, {\"Index\": 482, \"Highest Charting Position\": 152, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"White Dress\", \"Streams\": 5796978, \"Artist\": \"Lana Del Rey\", \"Artist Followers\": 13697048.0, \"Song ID\": \"4Hl9rOqYomojCmxYfr25im\", \"Genre\": \"['art pop', 'pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-19--2021-03-26\", \"Popularity\": 65.0, \"Danceability\": 0.493, \"Energy\": 0.263, \"Loudness\": -12.805, \"Speechiness\": 0.0351, \"Acousticness\": 0.926, \"Liveness\": 0.0879, \"Tempo\": 122.792, \"Duration (ms)\": 333710.0, \"Valence\": 0.158, \"Chord\": \"C\"}, {\"Index\": 483, \"Highest Charting Position\": 82, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Polvo\", \"Streams\": 5528508, \"Artist\": \"Nicky Jam, Myke Towers\", \"Artist Followers\": 14831925.0, \"Song ID\": \"68mrW6gXHgupgSiDHgaDi5\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 76.0, \"Danceability\": 0.763, \"Energy\": 0.621, \"Loudness\": -6.169, \"Speechiness\": 0.066, \"Acousticness\": 0.0105, \"Liveness\": 0.106, \"Tempo\": 82.042, \"Duration (ms)\": 211130.0, \"Valence\": 0.582, \"Chord\": \"B\"}, {\"Index\": 484, \"Highest Charting Position\": 138, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Chemtrails Over The Country Club\", \"Streams\": 5418816, \"Artist\": \"Lana Del Rey\", \"Artist Followers\": 13697048.0, \"Song ID\": \"7bPWdJgx8vek7S5i5yAtvG\", \"Genre\": \"['art pop', 'pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-01-15--2021-01-22\", \"Popularity\": 73.0, \"Danceability\": 0.334, \"Energy\": 0.276, \"Loudness\": -13.125, \"Speechiness\": 0.0643, \"Acousticness\": 0.877, \"Liveness\": 0.113, \"Tempo\": 201.025, \"Duration (ms)\": 271177.0, \"Valence\": 0.429, \"Chord\": \"E\"}, {\"Index\": 485, \"Highest Charting Position\": 37, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Parce (feat. Justin Quiles)\", \"Streams\": 5312876, \"Artist\": \"Maluma, Lenny Tav\\u00e1rez\", \"Artist Followers\": 26769304.0, \"Song ID\": \"4RJz8NfIe09gpKMiRUWKhJ\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 78.0, \"Danceability\": 0.691, \"Energy\": 0.739, \"Loudness\": -3.09, \"Speechiness\": 0.229, \"Acousticness\": 0.422, \"Liveness\": 0.11, \"Tempo\": 83.897, \"Duration (ms)\": 248345.0, \"Valence\": 0.884, \"Chord\": \"F\"}, {\"Index\": 486, \"Highest Charting Position\": 40, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Ropa Cara\", \"Streams\": 5249427, \"Artist\": \"Camilo\", \"Artist Followers\": 10580764.0, \"Song ID\": \"7BIy3EGQhg98CsRdKYHnJC\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2021-01-18\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 73.0, \"Danceability\": 0.813, \"Energy\": 0.526, \"Loudness\": -4.787, \"Speechiness\": 0.125, \"Acousticness\": 0.105, \"Liveness\": 0.11, \"Tempo\": 170.002, \"Duration (ms)\": 163320.0, \"Valence\": 0.608, \"Chord\": \"E\"}, {\"Index\": 487, \"Highest Charting Position\": 25, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Vida de Rico\", \"Streams\": 5189822, \"Artist\": \"Camilo\", \"Artist Followers\": 10580764.0, \"Song ID\": \"73nAK3HgQK8dak83Y2WQ8F\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-09-21\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 79.0, \"Danceability\": 0.824, \"Energy\": 0.457, \"Loudness\": -5.428, \"Speechiness\": 0.0543, \"Acousticness\": 0.167, \"Liveness\": 0.041, \"Tempo\": 87.977, \"Duration (ms)\": 187427.0, \"Valence\": 0.95, \"Chord\": \"F#/Gb\"}, {\"Index\": 488, \"Highest Charting Position\": 182, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Devil Eyes\", \"Streams\": 5098581, \"Artist\": \"Hippie Sabotage\", \"Artist Followers\": 713486.0, \"Song ID\": \"7MiZjKawmXTsTNePyTfPyL\", \"Genre\": \"['edm', 'electronic trap']\", \"Release Date\": \"2016-02-05\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 80.0, \"Danceability\": 0.391, \"Energy\": 0.396, \"Loudness\": -8.621, \"Speechiness\": 0.189, \"Acousticness\": 0.702, \"Liveness\": 0.315, \"Tempo\": 99.112, \"Duration (ms)\": 131272.0, \"Valence\": 0.199, \"Chord\": \"C#/Db\"}, {\"Index\": 489, \"Highest Charting Position\": 141, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Ponte Pa' Mi\", \"Streams\": 5082870, \"Artist\": \"Justin Quiles\", \"Artist Followers\": 2897862.0, \"Song ID\": \"4C6BlqqMwjFzOXzqpTeoWR\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 76.0, \"Danceability\": 0.878, \"Energy\": 0.713, \"Loudness\": -4.566, \"Speechiness\": 0.0948, \"Acousticness\": 0.0581, \"Liveness\": 0.0822, \"Tempo\": 92.028, \"Duration (ms)\": 202373.0, \"Valence\": 0.615, \"Chord\": \"F\"}, {\"Index\": 490, \"Highest Charting Position\": 109, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"D\\u00e1melo To\\u2019 (feat. Myke Towers)\", \"Streams\": 6426522, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"36CiGk9oRdwTnBDMgKEfjl\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 64.0, \"Danceability\": 0.787, \"Energy\": 0.641, \"Loudness\": -7.376, \"Speechiness\": 0.315, \"Acousticness\": 0.101, \"Liveness\": 0.07, \"Tempo\": 182.003, \"Duration (ms)\": 184134.0, \"Valence\": 0.437, \"Chord\": \"G#/Ab\"}, {\"Index\": 491, \"Highest Charting Position\": 121, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Patience (feat. YUNGBLUD & Polo G)\", \"Streams\": 6155698, \"Artist\": \"KSI\", \"Artist Followers\": 2010879.0, \"Song ID\": \"5J5CpT6bgE6KYKk23jgp9W\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 71.0, \"Danceability\": 0.616, \"Energy\": 0.741, \"Loudness\": -4.272, \"Speechiness\": 0.0426, \"Acousticness\": 0.00251, \"Liveness\": 0.307, \"Tempo\": 122.012, \"Duration (ms)\": 181720.0, \"Valence\": 0.431, \"Chord\": \"G\"}, {\"Index\": 492, \"Highest Charting Position\": 56, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Selfish Love (with Selena Gomez)\", \"Streams\": 6020785, \"Artist\": \"DJ Snake\", \"Artist Followers\": 7408249.0, \"Song ID\": \"3XoflnowYPFRPOh3uFvHcm\", \"Genre\": \"['dance pop', 'edm', 'electronic trap', 'pop', 'pop dance']\", \"Release Date\": \"2021-03-04\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 74.0, \"Danceability\": 0.723, \"Energy\": 0.646, \"Loudness\": -7.973, \"Speechiness\": 0.102, \"Acousticness\": 0.0206, \"Liveness\": 0.0994, \"Tempo\": 110.971, \"Duration (ms)\": 168649.0, \"Valence\": 0.443, \"Chord\": \"F\"}, {\"Index\": 493, \"Highest Charting Position\": 12, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Snowman\", \"Streams\": 5454807, \"Artist\": \"Sia\", \"Artist Followers\": 20528724.0, \"Song ID\": \"7uoFMmxln0GPXQ0AcCBXRq\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'pop']\", \"Release Date\": \"2018-11-01\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 77.0, \"Danceability\": 0.716, \"Energy\": 0.512, \"Loudness\": -6.257, \"Speechiness\": 0.0331, \"Acousticness\": 0.483, \"Liveness\": 0.0928, \"Tempo\": 104.957, \"Duration (ms)\": 165907.0, \"Valence\": 0.326, \"Chord\": \"C#/Db\"}, {\"Index\": 494, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"DAYWALKER! (feat. CORPSE)\", \"Streams\": 5439646, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3868320.0, \"Song ID\": \"2NnJpRXIlx35Vij3bPZO0h\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 74.0, \"Danceability\": 0.632, \"Energy\": 0.922, \"Loudness\": -2.173, \"Speechiness\": 0.0794, \"Acousticness\": 0.00558, \"Liveness\": 0.0927, \"Tempo\": 88.972, \"Duration (ms)\": 137747.0, \"Valence\": 0.497, \"Chord\": \"G\"}, {\"Index\": 495, \"Highest Charting Position\": 19, \"Number of Times Charted\": 38, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"La Curiosidad\", \"Streams\": 5198514, \"Artist\": \"Jay Wheeler, DJ Nelson, Myke Towers\", \"Artist Followers\": 1650912.0, \"Song ID\": \"4HYDUMY0xSpeBr0AMY9cUz\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 82.0, \"Danceability\": 0.845, \"Energy\": 0.677, \"Loudness\": -4.798, \"Speechiness\": 0.136, \"Acousticness\": 0.269, \"Liveness\": 0.108, \"Tempo\": 90.013, \"Duration (ms)\": 219048.0, \"Valence\": 0.68, \"Chord\": \"B\"}, {\"Index\": 496, \"Highest Charting Position\": 86, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"All We Got (feat. KIDDO)\", \"Streams\": 5156937, \"Artist\": \"Robin Schulz\", \"Artist Followers\": 2786366.0, \"Song ID\": \"1FP9s72rDYty6mfoOEYKnE\", \"Genre\": \"['dance pop', 'deep euro house', 'deep house', 'edm', 'german dance', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 74.0, \"Danceability\": 0.504, \"Energy\": 0.76, \"Loudness\": -4.246, \"Speechiness\": 0.0426, \"Acousticness\": 0.286, \"Liveness\": 0.151, \"Tempo\": 183.933, \"Duration (ms)\": 190218.0, \"Valence\": 0.64, \"Chord\": \"E\"}, {\"Index\": 497, \"Highest Charting Position\": 6, \"Number of Times Charted\": 60, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Say So\", \"Streams\": 5103528, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"3Dv1eDb0MEgF93GpLXlucZ\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-02-26--2021-03-05\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.787, \"Energy\": 0.673, \"Loudness\": -4.583, \"Speechiness\": 0.159, \"Acousticness\": 0.264, \"Liveness\": 0.0904, \"Tempo\": 110.962, \"Duration (ms)\": 237893.0, \"Valence\": 0.779, \"Chord\": \"B\"}, {\"Index\": 498, \"Highest Charting Position\": 157, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Hope\", \"Streams\": 5085527, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"2ZRo7axmMPeSVUvDbGkJah\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2018-03-16\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 84.0, \"Danceability\": 0.592, \"Energy\": 0.457, \"Loudness\": -6.081, \"Speechiness\": 0.0603, \"Acousticness\": 0.661, \"Liveness\": 0.146, \"Tempo\": 146.04, \"Duration (ms)\": 110886.0, \"Valence\": 0.225, \"Chord\": \"A\"}, {\"Index\": 499, \"Highest Charting Position\": 149, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"The Less I Know The Better\", \"Streams\": 5084635, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"6K4t31amVTZDgR3sKmwUJJ\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2015-07-17\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-01-03--2020-01-10\", \"Popularity\": 84.0, \"Danceability\": 0.64, \"Energy\": 0.74, \"Loudness\": -4.083, \"Speechiness\": 0.0284, \"Acousticness\": 0.0115, \"Liveness\": 0.167, \"Tempo\": 116.879, \"Duration (ms)\": 216320.0, \"Valence\": 0.785, \"Chord\": \"E\"}, {\"Index\": 500, \"Highest Charting Position\": 109, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"I Feel It Coming\", \"Streams\": 5079857, \"Artist\": \"The Weeknd, Daft Punk\", \"Artist Followers\": 35340069.0, \"Song ID\": \"3dhjNA0jGA8vHBQ1VdD6vV\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2016-11-25\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 80.0, \"Danceability\": 0.773, \"Energy\": 0.819, \"Loudness\": -5.946, \"Speechiness\": 0.118, \"Acousticness\": 0.428, \"Liveness\": 0.0679, \"Tempo\": 92.987, \"Duration (ms)\": 269187.0, \"Valence\": 0.585, \"Chord\": \"C\"}, {\"Index\": 501, \"Highest Charting Position\": 12, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Mood Swings (feat. Lil Tjay)\", \"Streams\": 5068349, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"5rZlwNFl01HqLWBQGryKSm\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 82.0, \"Danceability\": 0.48, \"Energy\": 0.602, \"Loudness\": -6.335, \"Speechiness\": 0.368, \"Acousticness\": 0.487, \"Liveness\": 0.0848, \"Tempo\": 179.798, \"Duration (ms)\": 213333.0, \"Valence\": 0.269, \"Chord\": \"A#/Bb\"}, {\"Index\": 502, \"Highest Charting Position\": 123, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Someone To You\", \"Streams\": 5054881, \"Artist\": \"BANNERS\", \"Artist Followers\": 419151.0, \"Song ID\": \"2f0pn9DkEJwAzXApnFh5cr\", \"Genre\": \"['indie cafe pop', 'indie poptimism', 'modern rock', 'pop', 'pop rock']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 79.0, \"Danceability\": 0.52, \"Energy\": 0.903, \"Loudness\": -5.497, \"Speechiness\": 0.042, \"Acousticness\": 0.00517, \"Liveness\": 0.254, \"Tempo\": 74.988, \"Duration (ms)\": 219801.0, \"Valence\": 0.652, \"Chord\": \"D\"}, {\"Index\": 503, \"Highest Charting Position\": 198, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"To the Bone\", \"Streams\": 5052557, \"Artist\": \"Pamungkas\", \"Artist Followers\": 1643882.0, \"Song ID\": \"3pCt2wRdBDa2kCisIdHWgF\", \"Genre\": \"['indonesian pop']\", \"Release Date\": \"2019-06-14\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 81.0, \"Danceability\": 0.668, \"Energy\": 0.727, \"Loudness\": -6.55, \"Speechiness\": 0.027, \"Acousticness\": 0.514, \"Liveness\": 0.1, \"Tempo\": 139.991, \"Duration (ms)\": 344571.0, \"Valence\": 0.939, \"Chord\": \"G\"}, {\"Index\": 504, \"Highest Charting Position\": 4, \"Number of Times Charted\": 38, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"How You Like That\", \"Streams\": 5023592, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"4SFknyjLcyTLJFPKD2m96o\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 79.0, \"Danceability\": 0.812, \"Energy\": 0.761, \"Loudness\": -5.222, \"Speechiness\": 0.0812, \"Acousticness\": 0.0465, \"Liveness\": 0.0601, \"Tempo\": 130.032, \"Duration (ms)\": 182956.0, \"Valence\": 0.344, \"Chord\": \"B\"}, {\"Index\": 505, \"Highest Charting Position\": 200, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"LOST\", \"Streams\": 5013851, \"Artist\": \"NF, Hopsin\", \"Artist Followers\": 5831194.0, \"Song ID\": \"2MZrOmrVxRmmOoFW6dhenG\", \"Genre\": \"['hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2021-03-11\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 66.0, \"Danceability\": 0.637, \"Energy\": 0.912, \"Loudness\": -3.123, \"Speechiness\": 0.308, \"Acousticness\": 0.352, \"Liveness\": 0.0657, \"Tempo\": 116.919, \"Duration (ms)\": 234852.0, \"Valence\": 0.451, \"Chord\": \"F\"}, {\"Index\": 506, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"VOCE\", \"Streams\": 5510906, \"Artist\": \"Madame\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6CAVxdHTkls5loqUmfM52V\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 0.0, \"Danceability\": 0.615, \"Energy\": 0.834, \"Loudness\": -5.471, \"Speechiness\": 0.0667, \"Acousticness\": 0.105, \"Liveness\": 0.157, \"Tempo\": 112.602, \"Duration (ms)\": 211411.0, \"Valence\": 0.341, \"Chord\": \"G#/Ab\"}, {\"Index\": 507, \"Highest Charting Position\": 64, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"AP - Music from the film Boogie\", \"Streams\": 5462333, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"17vGPZ5EsdvtgAOCD4FLWI\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\", \"Popularity\": 75.0, \"Danceability\": 0.751, \"Energy\": 0.744, \"Loudness\": -6.859, \"Speechiness\": 0.177, \"Acousticness\": 0.152, \"Liveness\": 0.252, \"Tempo\": 148.014, \"Duration (ms)\": 171892.0, \"Valence\": 0.634, \"Chord\": \"C#/Db\"}, {\"Index\": 508, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Life's A Mess II (with Clever & Post Malone)\", \"Streams\": 5393459, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4O3RwH1TFG1EjPezLIYehI\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 72.0, \"Danceability\": 0.53, \"Energy\": 0.37, \"Loudness\": -9.989, \"Speechiness\": 0.0279, \"Acousticness\": 0.806, \"Liveness\": 0.112, \"Tempo\": 140.061, \"Duration (ms)\": 206734.0, \"Valence\": 0.701, \"Chord\": \"F#/Gb\"}, {\"Index\": 509, \"Highest Charting Position\": 170, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"CHIAMAMI PER NOME\", \"Streams\": 5321946, \"Artist\": \"Francesca Michielin, Fedez\", \"Artist Followers\": 568711.0, \"Song ID\": \"0ZqHo6eTBHUcOVjZzPvftT\", \"Genre\": \"['italian adult pop', 'italian indie pop', 'italian pop', 'italian pop rock']\", \"Release Date\": \"2021-03-03\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 67.0, \"Danceability\": 0.641, \"Energy\": 0.636, \"Loudness\": -4.318, \"Speechiness\": 0.0414, \"Acousticness\": 0.289, \"Liveness\": 0.125, \"Tempo\": 89.826, \"Duration (ms)\": 222667.0, \"Valence\": 0.285, \"Chord\": \"A#/Bb\"}, {\"Index\": 510, \"Highest Charting Position\": 54, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Antes\", \"Streams\": 5232377, \"Artist\": \"Anuel AA, Ozuna\", \"Artist Followers\": 18306226.0, \"Song ID\": \"73O30uMI7n6DuzBmbtO7kC\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 73.0, \"Danceability\": 0.817, \"Energy\": 0.737, \"Loudness\": -5.453, \"Speechiness\": 0.102, \"Acousticness\": 0.046, \"Liveness\": 0.092, \"Tempo\": 93.985, \"Duration (ms)\": 206587.0, \"Valence\": 0.67, \"Chord\": \"F#/Gb\"}, {\"Index\": 511, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Mona Lisa\", \"Streams\": 5208787, \"Artist\": \"Booba, JSX\", \"Artist Followers\": 2161609.0, \"Song ID\": \"5LYRIyhmlrDAQsYdHEvP0f\", \"Genre\": \"['french hip hop', 'old school rap francais', 'pop urbaine', 'rap conscient']\", \"Release Date\": \"2021-03-04\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 72.0, \"Danceability\": 0.784, \"Energy\": 0.529, \"Loudness\": -7.681, \"Speechiness\": 0.0742, \"Acousticness\": 0.683, \"Liveness\": 0.118, \"Tempo\": 134.041, \"Duration (ms)\": 187362.0, \"Valence\": 0.246, \"Chord\": \"B\"}, {\"Index\": 512, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Real As It Gets (feat. EST Gee)\", \"Streams\": 5170861, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"7eX3um6NpOQKWJMGCi97XD\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2021-03-04\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 74.0, \"Danceability\": 0.779, \"Energy\": 0.705, \"Loudness\": -5.891, \"Speechiness\": 0.163, \"Acousticness\": 0.00471, \"Liveness\": 0.0971, \"Tempo\": 140.005, \"Duration (ms)\": 192804.0, \"Valence\": 0.196, \"Chord\": \"F#/Gb\"}, {\"Index\": 513, \"Highest Charting Position\": 24, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Se Te Nota (with Guaynaa)\", \"Streams\": 5168240, \"Artist\": \"Lele Pons\", \"Artist Followers\": 786461.0, \"Song ID\": \"11EnQRgRMJwMAesfkB5pnu\", \"Genre\": \"['latin pop', 'viral pop']\", \"Release Date\": \"2020-09-02\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 77.0, \"Danceability\": 0.905, \"Energy\": 0.686, \"Loudness\": -3.152, \"Speechiness\": 0.0664, \"Acousticness\": 0.0907, \"Liveness\": 0.266, \"Tempo\": 103.013, \"Duration (ms)\": 155825.0, \"Valence\": 0.963, \"Chord\": \"C\"}, {\"Index\": 514, \"Highest Charting Position\": 91, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Head Shoulders Knees & Toes (feat. Norma Jean Martine)\", \"Streams\": 5093408, \"Artist\": \"Ofenbach, Quarterhead\", \"Artist Followers\": 432511.0, \"Song ID\": \"6i7zAdNhzUN2k1HcrBxPHG\", \"Genre\": \"['edm', 'new french touch', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 79.0, \"Danceability\": 0.798, \"Energy\": 0.828, \"Loudness\": -5.36, \"Speechiness\": 0.193, \"Acousticness\": 0.0247, \"Liveness\": 0.121, \"Tempo\": 124.962, \"Duration (ms)\": 156960.0, \"Valence\": 0.6, \"Chord\": \"D\"}, {\"Index\": 515, \"Highest Charting Position\": 152, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Star Shopping\", \"Streams\": 5073657, \"Artist\": \"Lil Peep\", \"Artist Followers\": 7535054.0, \"Song ID\": \"30bqVoKjX479ab90a8Pafp\", \"Genre\": \"['emo rap', 'lgbtq+ hip hop']\", \"Release Date\": \"2015\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 82.0, \"Danceability\": 0.585, \"Energy\": 0.471, \"Loudness\": -9.934, \"Speechiness\": 0.0616, \"Acousticness\": 0.0967, \"Liveness\": 0.115, \"Tempo\": 93.099, \"Duration (ms)\": 142000.0, \"Valence\": 0.323, \"Chord\": \"E\"}, {\"Index\": 516, \"Highest Charting Position\": 61, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Electric Love\", \"Streams\": 5060903, \"Artist\": \"B\\u00d8RNS\", \"Artist Followers\": 1027085.0, \"Song ID\": \"2GiJYvgVaD2HtM8GqD9EgQ\", \"Genre\": \"['modern alternative rock', 'modern rock', 'pop']\", \"Release Date\": \"2015-10-16\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 83.0, \"Danceability\": 0.611, \"Energy\": 0.797, \"Loudness\": -7.627, \"Speechiness\": 0.0533, \"Acousticness\": 0.00543, \"Liveness\": 0.26, \"Tempo\": 120.041, \"Duration (ms)\": 218107.0, \"Valence\": 0.518, \"Chord\": \"F#/Gb\"}, {\"Index\": 517, \"Highest Charting Position\": 112, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Maniac\", \"Streams\": 5044929, \"Artist\": \"Conan Gray\", \"Artist Followers\": 3799104.0, \"Song ID\": \"6KfoDhO4XUWSbnyKjNp9c4\", \"Genre\": \"['alt z', 'bedroom pop', 'electropop', 'indie pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.628, \"Energy\": 0.639, \"Loudness\": -5.46, \"Speechiness\": 0.0435, \"Acousticness\": 0.00162, \"Liveness\": 0.354, \"Tempo\": 108.045, \"Duration (ms)\": 185773.0, \"Valence\": 0.493, \"Chord\": \"G#/Ab\"}, {\"Index\": 518, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Only Wanna Be With You - Pok\\u00e9mon 25 Version\", \"Streams\": 7464020, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"3SawmGBjjq8EOYZJV11cJm\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2021-02-25\", \"Weeks Charted\": \"2021-02-26--2021-03-05\", \"Popularity\": 72.0, \"Danceability\": 0.47, \"Energy\": 0.709, \"Loudness\": -4.563, \"Speechiness\": 0.0299, \"Acousticness\": 0.00124, \"Liveness\": 0.302, \"Tempo\": 98.036, \"Duration (ms)\": 241360.0, \"Valence\": 0.247, \"Chord\": \"G\"}, {\"Index\": 519, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"test drive\", \"Streams\": 6591829, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3eZYOQO4UzKrUDYDghtnFw\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-02-19\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 71.0, \"Danceability\": 0.698, \"Energy\": 0.708, \"Loudness\": -4.943, \"Speechiness\": 0.0454, \"Acousticness\": 0.0251, \"Liveness\": 0.124, \"Tempo\": 115.036, \"Duration (ms)\": 122174.0, \"Valence\": 0.322, \"Chord\": \"A\"}, {\"Index\": 520, \"Highest Charting Position\": 42, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"T\\u00fa Me Dejaste De Querer\", \"Streams\": 5874460, \"Artist\": \"C. Tangana, Ni\\u00f1o de Elche, La H\\u00fangara\", \"Artist Followers\": 1453875.0, \"Song ID\": \"5ddFjrPG8NgQQ6xlOQIVd2\", \"Genre\": \"['urbano espanol']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 75.0, \"Danceability\": 0.823, \"Energy\": 0.723, \"Loudness\": -4.778, \"Speechiness\": 0.229, \"Acousticness\": 0.311, \"Liveness\": 0.0998, \"Tempo\": 83.97, \"Duration (ms)\": 198493.0, \"Valence\": 0.505, \"Chord\": \"E\"}, {\"Index\": 521, \"Highest Charting Position\": 46, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"SO DONE\", \"Streams\": 5440707, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"5psEZhQu6lukjhavJo4AbC\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-10-23\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 74.0, \"Danceability\": 0.719, \"Energy\": 0.598, \"Loudness\": -6.254, \"Speechiness\": 0.077, \"Acousticness\": 0.232, \"Liveness\": 0.115, \"Tempo\": 142.592, \"Duration (ms)\": 126521.0, \"Valence\": 0.303, \"Chord\": \"A\"}, {\"Index\": 522, \"Highest Charting Position\": 35, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Jeans\", \"Streams\": 5145966, \"Artist\": \"Justin Quiles\", \"Artist Followers\": 2897862.0, \"Song ID\": \"3GtnId3Cm1Xa6joCj08nzW\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 75.0, \"Danceability\": 0.807, \"Energy\": 0.656, \"Loudness\": -4.395, \"Speechiness\": 0.105, \"Acousticness\": 0.0165, \"Liveness\": 0.0693, \"Tempo\": 83.943, \"Duration (ms)\": 185840.0, \"Valence\": 0.89, \"Chord\": \"D#/Eb\"}, {\"Index\": 523, \"Highest Charting Position\": 2, \"Number of Times Charted\": 61, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"ROXANNE\", \"Streams\": 5124742, \"Artist\": \"Arizona Zervas\", \"Artist Followers\": 621200.0, \"Song ID\": \"696DnlkuDOXcMAnKlTgXXK\", \"Genre\": \"['pop rap', 'rhode island rap']\", \"Release Date\": \"2019-10-10\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.621, \"Energy\": 0.601, \"Loudness\": -5.616, \"Speechiness\": 0.148, \"Acousticness\": 0.0522, \"Liveness\": 0.46, \"Tempo\": 116.735, \"Duration (ms)\": 163636.0, \"Valence\": 0.457, \"Chord\": \"F#/Gb\"}, {\"Index\": 524, \"Highest Charting Position\": 83, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"rockstar (feat. 21 Savage)\", \"Streams\": 5115990, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"0e7ipj03S05BNilyu5bRzt\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2018-04-27\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-01-29--2021-02-05\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.585, \"Energy\": 0.52, \"Loudness\": -6.136, \"Speechiness\": 0.0712, \"Acousticness\": 0.124, \"Liveness\": 0.131, \"Tempo\": 159.801, \"Duration (ms)\": 218147.0, \"Valence\": 0.129, \"Chord\": \"F\"}, {\"Index\": 525, \"Highest Charting Position\": 185, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"P\\u00e1rteme La Cara\", \"Streams\": 5079580, \"Artist\": \"C. Tangana, Ed Maverick\", \"Artist Followers\": 1453875.0, \"Song ID\": \"5gEUDNQvoQjdjklrwPdGwD\", \"Genre\": \"['urbano espanol']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-02-26--2021-03-05\", \"Popularity\": 70.0, \"Danceability\": 0.761, \"Energy\": 0.296, \"Loudness\": -10.22, \"Speechiness\": 0.0484, \"Acousticness\": 0.551, \"Liveness\": 0.134, \"Tempo\": 127.938, \"Duration (ms)\": 167867.0, \"Valence\": 0.579, \"Chord\": \"C\"}, {\"Index\": 526, \"Highest Charting Position\": 80, \"Number of Times Charted\": 57, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Without Me\", \"Streams\": 5016283, \"Artist\": \"Halsey\", \"Artist Followers\": 15663384.0, \"Song ID\": \"5p7ujcrUXASCNwRaWNHR1C\", \"Genre\": \"['dance pop', 'electropop', 'etherpop', 'indie poptimism', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-10-04\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.752, \"Energy\": 0.488, \"Loudness\": -7.05, \"Speechiness\": 0.0705, \"Acousticness\": 0.297, \"Liveness\": 0.0936, \"Tempo\": 136.041, \"Duration (ms)\": 201661.0, \"Valence\": 0.533, \"Chord\": \"F#/Gb\"}, {\"Index\": 527, \"Highest Charting Position\": 33, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"BOOKER T\", \"Streams\": 4995965, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"26w9NTiE9NGjW1ZvIOd1So\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 77.0, \"Danceability\": 0.883, \"Energy\": 0.6, \"Loudness\": -7.188, \"Speechiness\": 0.37, \"Acousticness\": 0.114, \"Liveness\": 0.0931, \"Tempo\": 113.903, \"Duration (ms)\": 156430.0, \"Valence\": 0.691, \"Chord\": \"G\"}, {\"Index\": 528, \"Highest Charting Position\": 5, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Intentions (feat. Quavo)\", \"Streams\": 4994138, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"4umIPjkehX1r7uhmGvXiSV\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 77.0, \"Danceability\": 0.806, \"Energy\": 0.546, \"Loudness\": -6.637, \"Speechiness\": 0.0575, \"Acousticness\": 0.3, \"Liveness\": 0.102, \"Tempo\": 147.986, \"Duration (ms)\": 212867.0, \"Valence\": 0.874, \"Chord\": \"A\"}, {\"Index\": 529, \"Highest Charting Position\": 49, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Sofia\", \"Streams\": 4982892, \"Artist\": \"Clairo\", \"Artist Followers\": 2722638.0, \"Song ID\": \"7B3z0ySL9Rr0XvZEAjWZzM\", \"Genre\": \"['bedroom pop', 'indie pop', 'pop']\", \"Release Date\": \"2019-08-02\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 81.0, \"Danceability\": 0.744, \"Energy\": 0.619, \"Loudness\": -9.805, \"Speechiness\": 0.039, \"Acousticness\": 0.598, \"Liveness\": 0.231, \"Tempo\": 112.997, \"Duration (ms)\": 188387.0, \"Valence\": 0.641, \"Chord\": \"C\"}, {\"Index\": 530, \"Highest Charting Position\": 176, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Photograph\", \"Streams\": 4974880, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"1HNkqx9Ahdgi1Ixy2xkKkL\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2014-06-21\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-02-07--2020-02-14\\n2020-01-03--2020-01-10\", \"Popularity\": 83.0, \"Danceability\": 0.614, \"Energy\": 0.379, \"Loudness\": -10.48, \"Speechiness\": 0.0476, \"Acousticness\": 0.607, \"Liveness\": 0.0986, \"Tempo\": 107.989, \"Duration (ms)\": 258987.0, \"Valence\": 0.201, \"Chord\": \"E\"}, {\"Index\": 531, \"Highest Charting Position\": 20, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"34+35 Remix (feat. Doja Cat, Megan Thee Stallion) - Remix\", \"Streams\": 6162453, \"Artist\": \"Ariana Grande\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 532, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"Madonna\", \"Streams\": 5936752, \"Artist\": \"Bausa, Apache 207\", \"Artist Followers\": 961181.0, \"Song ID\": \"6a3kNt1UlUOapDKmEr3JzZ\", \"Genre\": \"['german hip hop', 'german pop']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-02-19--2021-02-26\", \"Popularity\": 68.0, \"Danceability\": 0.806, \"Energy\": 0.565, \"Loudness\": -8.96, \"Speechiness\": 0.113, \"Acousticness\": 0.47, \"Liveness\": 0.0824, \"Tempo\": 116.963, \"Duration (ms)\": 195734.0, \"Valence\": 0.311, \"Chord\": \"B\"}, {\"Index\": 533, \"Highest Charting Position\": 144, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"CLOUDS\", \"Streams\": 5897983, \"Artist\": \"NF\", \"Artist Followers\": 5831194.0, \"Song ID\": \"5UMMPHPp6vRP6ghPpSUOzp\", \"Genre\": \"['hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2021-02-18\", \"Weeks Charted\": \"2021-02-19--2021-02-26\", \"Popularity\": 69.0, \"Danceability\": 0.793, \"Energy\": 0.65, \"Loudness\": -3.944, \"Speechiness\": 0.397, \"Acousticness\": 0.371, \"Liveness\": 0.854, \"Tempo\": 128.111, \"Duration (ms)\": 243750.0, \"Valence\": 0.809, \"Chord\": \"C#/Db\"}, {\"Index\": 534, \"Highest Charting Position\": 12, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Wonder\", \"Streams\": 5535339, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 1251372.0, \"Song ID\": \"7jjS2fSD9zuzbEHeVEFJ2w\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 0.0, \"Danceability\": 0.333, \"Energy\": 0.637, \"Loudness\": -4.904, \"Speechiness\": 0.0581, \"Acousticness\": 0.131, \"Liveness\": 0.149, \"Tempo\": 139.898, \"Duration (ms)\": 172693.0, \"Valence\": 0.132, \"Chord\": \"C#/Db\"}, {\"Index\": 535, \"Highest Charting Position\": 50, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Skin\", \"Streams\": 5497942, \"Artist\": \"Sabrina Carpenter\", \"Artist Followers\": 3689546.0, \"Song ID\": \"03B2SfXuvDh1m9F4tqrX07\", \"Genre\": \"['alt z', 'dance pop', 'electropop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 76.0, \"Danceability\": 0.557, \"Energy\": 0.457, \"Loudness\": -5.372, \"Speechiness\": 0.0335, \"Acousticness\": 0.428, \"Liveness\": 0.0567, \"Tempo\": 105.918, \"Duration (ms)\": 177500.0, \"Valence\": 0.328, \"Chord\": \"G\"}, {\"Index\": 536, \"Highest Charting Position\": 62, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Tyler Herro\", \"Streams\": 5168107, \"Artist\": \"Jack Harlow\", \"Artist Followers\": 1053324.0, \"Song ID\": \"4DuUwzP4ALMqpquHU0ltAB\", \"Genre\": \"['deep underground hip hop', 'kentucky hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-10-22\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 76.0, \"Danceability\": 0.794, \"Energy\": 0.756, \"Loudness\": -7.16, \"Speechiness\": 0.136, \"Acousticness\": 0.11, \"Liveness\": 0.247, \"Tempo\": 123.066, \"Duration (ms)\": 156498.0, \"Valence\": 0.775, \"Chord\": \"F\"}, {\"Index\": 537, \"Highest Charting Position\": 173, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Remember That Night?\", \"Streams\": 5116325, \"Artist\": \"Sara Kays\", \"Artist Followers\": 251549.0, \"Song ID\": \"1nYzjrdVQ8RpF93M0jPFW7\", \"Genre\": \"['alt z', 'indie cafe pop', 'modern indie pop', 'pop', 'social media pop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 78.0, \"Danceability\": 0.679, \"Energy\": 0.61, \"Loudness\": -10.936, \"Speechiness\": 0.0305, \"Acousticness\": 0.585, \"Liveness\": 0.156, \"Tempo\": 123.978, \"Duration (ms)\": 227186.0, \"Valence\": 0.554, \"Chord\": \"G\"}, {\"Index\": 538, \"Highest Charting Position\": 128, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Lifestyle (feat. Adam Levine)\", \"Streams\": 5059891, \"Artist\": \"Jason Derulo, Maroon 5\", \"Artist Followers\": 9778632.0, \"Song ID\": \"0osvOdeD3YXZiWkT8MKolJ\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 78.0, \"Danceability\": 0.749, \"Energy\": 0.674, \"Loudness\": -5.128, \"Speechiness\": 0.0366, \"Acousticness\": 0.0209, \"Liveness\": 0.169, \"Tempo\": 123.055, \"Duration (ms)\": 153865.0, \"Valence\": 0.711, \"Chord\": \"A#/Bb\"}, {\"Index\": 539, \"Highest Charting Position\": 177, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Fly Away\", \"Streams\": 5053713, \"Artist\": \"Tones And I\", \"Artist Followers\": 2820477.0, \"Song ID\": \"5ri4zqtWhG07hIuNNDWP76\", \"Genre\": \"['australian pop', 'pop']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 79.0, \"Danceability\": 0.806, \"Energy\": 0.513, \"Loudness\": -6.208, \"Speechiness\": 0.0685, \"Acousticness\": 0.217, \"Liveness\": 0.217, \"Tempo\": 124.988, \"Duration (ms)\": 178157.0, \"Valence\": 0.503, \"Chord\": \"E\"}, {\"Index\": 540, \"Highest Charting Position\": 37, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Despeinada\", \"Streams\": 5004462, \"Artist\": \"Ozuna, Camilo\", \"Artist Followers\": 29238936.0, \"Song ID\": \"0JAZWvvqttGFm4UMDsPQXC\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 75.0, \"Danceability\": 0.734, \"Energy\": 0.775, \"Loudness\": -3.855, \"Speechiness\": 0.0614, \"Acousticness\": 0.186, \"Liveness\": 0.123, \"Tempo\": 166.039, \"Duration (ms)\": 224187.0, \"Valence\": 0.72, \"Chord\": \"G#/Ab\"}, {\"Index\": 541, \"Highest Charting Position\": 14, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"motive (with Doja Cat)\", \"Streams\": 4986037, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"5GkQIP5mWPi4KZLLXeuFTT\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 80.0, \"Danceability\": 0.789, \"Energy\": 0.742, \"Loudness\": -5.664, \"Speechiness\": 0.0652, \"Acousticness\": 0.0681, \"Liveness\": 0.166, \"Tempo\": 116.965, \"Duration (ms)\": 167990.0, \"Valence\": 0.661, \"Chord\": \"A#/Bb\"}, {\"Index\": 542, \"Highest Charting Position\": 28, \"Number of Times Charted\": 57, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"I Don't Care (with Justin Bieber)\", \"Streams\": 4984399, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"3HVWdVOQ0ZA45FuZGSfvns\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-05-10\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.798, \"Energy\": 0.675, \"Loudness\": -5.041, \"Speechiness\": 0.0442, \"Acousticness\": 0.0912, \"Liveness\": 0.0894, \"Tempo\": 101.956, \"Duration (ms)\": 219947.0, \"Valence\": 0.842, \"Chord\": \"F#/Gb\"}, {\"Index\": 543, \"Highest Charting Position\": 14, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Ay, DiOs M\\u00edo!\", \"Streams\": 5344862, \"Artist\": \"KAROL G\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3PF1mUoD0NgK4ykdt5sk3g\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 0.0, \"Danceability\": 0.715, \"Energy\": 0.706, \"Loudness\": -4.423, \"Speechiness\": 0.195, \"Acousticness\": 0.496, \"Liveness\": 0.106, \"Tempo\": 179.997, \"Duration (ms)\": 189840.0, \"Valence\": 0.522, \"Chord\": \"B\"}, {\"Index\": 544, \"Highest Charting Position\": 83, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Nathy Peluso: Bzrp Music Sessions, Vol. 36\", \"Streams\": 5232509, \"Artist\": \"Bizarrap, Nathy Peluso\", \"Artist Followers\": 3134041.0, \"Song ID\": \"78SeXVRJ7KCqVmOwTiFjnI\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 77.0, \"Danceability\": 0.65, \"Energy\": 0.655, \"Loudness\": -3.71, \"Speechiness\": 0.405, \"Acousticness\": 0.25, \"Liveness\": 0.0691, \"Tempo\": 94.059, \"Duration (ms)\": 171215.0, \"Valence\": 0.735, \"Chord\": \"C#/Db\"}, {\"Index\": 545, \"Highest Charting Position\": 17, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Haw\\u00e1i - Remix\", \"Streams\": 5163323, \"Artist\": \"Maluma, The Weeknd\", \"Artist Followers\": 26784251.0, \"Song ID\": \"0GzuHFG4Ql6DoyxFRnIk3F\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-11-05\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 77.0, \"Danceability\": 0.766, \"Energy\": 0.788, \"Loudness\": -3.128, \"Speechiness\": 0.312, \"Acousticness\": 0.105, \"Liveness\": 0.142, \"Tempo\": 179.984, \"Duration (ms)\": 200482.0, \"Valence\": 0.609, \"Chord\": \"F#/Gb\"}, {\"Index\": 546, \"Highest Charting Position\": 22, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Tattoo - Remix with Camilo\", \"Streams\": 5120753, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6096559.0, \"Song ID\": \"4ZRrLHqzhGRXYj2qcB4s5S\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-07-09\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 78.0, \"Danceability\": 0.848, \"Energy\": 0.637, \"Loudness\": -5.132, \"Speechiness\": 0.156, \"Acousticness\": 0.0413, \"Liveness\": 0.0521, \"Tempo\": 96.988, \"Duration (ms)\": 222680.0, \"Valence\": 0.698, \"Chord\": \"A\"}, {\"Index\": 547, \"Highest Charting Position\": 151, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Meia Noite (Voc\\u00ea tem meu Whatsapp)\", \"Streams\": 5044252, \"Artist\": \"Tarc\\u00edsio do Acordeon\", \"Artist Followers\": 1200248.0, \"Song ID\": \"6sPBi0qLI6KM3yXX56NxsA\", \"Genre\": \"[]\", \"Release Date\": \"2020-12-17\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 67.0, \"Danceability\": 0.709, \"Energy\": 0.816, \"Loudness\": -4.787, \"Speechiness\": 0.0346, \"Acousticness\": 0.685, \"Liveness\": 0.146, \"Tempo\": 150.06, \"Duration (ms)\": 237900.0, \"Valence\": 0.921, \"Chord\": \"B\"}, {\"Index\": 548, \"Highest Charting Position\": 143, \"Number of Times Charted\": 42, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Moonlight\", \"Streams\": 5003825, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"0JP9xo3adEtGSdUEISiszL\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2018-03-16\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2020-09-18--2020-09-25\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.921, \"Energy\": 0.537, \"Loudness\": -5.723, \"Speechiness\": 0.0804, \"Acousticness\": 0.556, \"Liveness\": 0.102, \"Tempo\": 128.009, \"Duration (ms)\": 135090.0, \"Valence\": 0.711, \"Chord\": \"A\"}, {\"Index\": 549, \"Highest Charting Position\": 182, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Thinking out Loud\", \"Streams\": 4995623, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"34gCuhDGsG4bRPIf9bb02f\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2014-06-21\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 82.0, \"Danceability\": 0.781, \"Energy\": 0.445, \"Loudness\": -6.061, \"Speechiness\": 0.0295, \"Acousticness\": 0.474, \"Liveness\": 0.184, \"Tempo\": 78.998, \"Duration (ms)\": 281560.0, \"Valence\": 0.591, \"Chord\": \"D\"}, {\"Index\": 550, \"Highest Charting Position\": 2, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Toosie Slide\", \"Streams\": 4966878, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"127QTOFJsJQp5LbJbu3A1y\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 78.0, \"Danceability\": 0.834, \"Energy\": 0.454, \"Loudness\": -9.75, \"Speechiness\": 0.201, \"Acousticness\": 0.321, \"Liveness\": 0.114, \"Tempo\": 81.618, \"Duration (ms)\": 247059.0, \"Valence\": 0.837, \"Chord\": \"C#/Db\"}, {\"Index\": 551, \"Highest Charting Position\": 167, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Earned It (Fifty Shades Of Grey)\", \"Streams\": 4929647, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"4frLb7nWtsz2ymBE6k2GRP\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2015-08-28\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 69.0, \"Danceability\": 0.659, \"Energy\": 0.291, \"Loudness\": -8.275, \"Speechiness\": 0.0348, \"Acousticness\": 0.405, \"Liveness\": 0.0771, \"Tempo\": 119.829, \"Duration (ms)\": 277680.0, \"Valence\": 0.406, \"Chord\": \"D\"}, {\"Index\": 552, \"Highest Charting Position\": 9, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"ily (i love you baby) (feat. Emilee)\", \"Streams\": 4908929, \"Artist\": \"Surf Mesa\", \"Artist Followers\": 132855.0, \"Song ID\": \"62aP9fBQKYKxi7PDXwcUAS\", \"Genre\": \"['tropical house']\", \"Release Date\": \"2019-11-26\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 81.0, \"Danceability\": 0.674, \"Energy\": 0.774, \"Loudness\": -7.567, \"Speechiness\": 0.0892, \"Acousticness\": 0.0686, \"Liveness\": 0.393, \"Tempo\": 112.05, \"Duration (ms)\": 176547.0, \"Valence\": 0.33, \"Chord\": \"B\"}, {\"Index\": 553, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Wonderwall\", \"Streams\": 4902737, \"Artist\": \"Oasis\", \"Artist Followers\": 6478565.0, \"Song ID\": \"7ygpwy2qP3NbrxVkHvUhXY\", \"Genre\": \"['beatlesque', 'britpop', 'madchester', 'permanent wave', 'rock']\", \"Release Date\": \"1995\", \"Weeks Charted\": \"2021-02-12--2021-02-19\", \"Popularity\": 78.0, \"Danceability\": 0.375, \"Energy\": 0.893, \"Loudness\": -4.097, \"Speechiness\": 0.0406, \"Acousticness\": 0.000509, \"Liveness\": 0.187, \"Tempo\": 174.323, \"Duration (ms)\": 258773.0, \"Valence\": 0.434, \"Chord\": \"D\"}, {\"Index\": 554, \"Highest Charting Position\": 181, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Everybody Dies In Their Nightmares\", \"Streams\": 4847224, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"3GVkPk8mqxz0itaAriG1L7\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2017-08-25\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\", \"Popularity\": 83.0, \"Danceability\": 0.734, \"Energy\": 0.57, \"Loudness\": -7.066, \"Speechiness\": 0.133, \"Acousticness\": 0.847, \"Liveness\": 0.112, \"Tempo\": 129.953, \"Duration (ms)\": 95467.0, \"Valence\": 0.689, \"Chord\": \"G\"}, {\"Index\": 555, \"Highest Charting Position\": 27, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Bad Boy (with Young Thug)\", \"Streams\": 6011642, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"43CIWpJaJHRcI4mUSjqgc2\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 76.0, \"Danceability\": 0.697, \"Energy\": 0.674, \"Loudness\": -6.326, \"Speechiness\": 0.0533, \"Acousticness\": 0.00215, \"Liveness\": 0.138, \"Tempo\": 81.535, \"Duration (ms)\": 157355.0, \"Valence\": 0.198, \"Chord\": \"C#/Db\"}, {\"Index\": 556, \"Highest Charting Position\": 19, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Lo Vas A Olvidar (with ROSAL\\u00cdA)\", \"Streams\": 5963380, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"0psS4i5YooJrXfDnGvWRLi\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 68.0, \"Danceability\": 0.343, \"Energy\": 0.243, \"Loudness\": -14.66, \"Speechiness\": 0.0777, \"Acousticness\": 0.721, \"Liveness\": 0.0668, \"Tempo\": 135.154, \"Duration (ms)\": 203464.0, \"Valence\": 0.032, \"Chord\": \"E\"}, {\"Index\": 557, \"Highest Charting Position\": 152, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Floating Through Space\", \"Streams\": 5579697, \"Artist\": \"Sia, David Guetta\", \"Artist Followers\": 20528724.0, \"Song ID\": \"2AceGjiX9isUbXmMZa0Dl1\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'pop']\", \"Release Date\": \"2021-02-04\", \"Weeks Charted\": \"2021-02-05--2021-02-12\", \"Popularity\": 78.0, \"Danceability\": 0.575, \"Energy\": 0.844, \"Loudness\": -4.89, \"Speechiness\": 0.072, \"Acousticness\": 0.00172, \"Liveness\": 0.114, \"Tempo\": 104.914, \"Duration (ms)\": 177801.0, \"Valence\": 0.277, \"Chord\": \"F#/Gb\"}, {\"Index\": 558, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Can't Feel My Face\", \"Streams\": 5479407, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"22VdIZQfgXJea34mQxlt81\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2015-08-28\", \"Weeks Charted\": \"2021-02-05--2021-02-12\", \"Popularity\": 80.0, \"Danceability\": 0.705, \"Energy\": 0.769, \"Loudness\": -5.526, \"Speechiness\": 0.0425, \"Acousticness\": 0.113, \"Liveness\": 0.105, \"Tempo\": 107.949, \"Duration (ms)\": 213520.0, \"Valence\": 0.583, \"Chord\": \"A\"}, {\"Index\": 559, \"Highest Charting Position\": 89, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"You (with Marshmello & Vance Joy)\", \"Streams\": 5342938, \"Artist\": \"benny blanco\", \"Artist Followers\": 804613.0, \"Song ID\": \"1GkHyypTFkUf0QQKwYoXH4\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2021-01-29\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 73.0, \"Danceability\": 0.668, \"Energy\": 0.563, \"Loudness\": -6.433, \"Speechiness\": 0.0522, \"Acousticness\": 0.0493, \"Liveness\": 0.119, \"Tempo\": 103.116, \"Duration (ms)\": 169632.0, \"Valence\": 0.305, \"Chord\": \"B\"}, {\"Index\": 560, \"Highest Charting Position\": 168, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Call Out My Name\", \"Streams\": 5233359, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"09mEdoA6zrmBPgTEN5qXmN\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2018-03-30\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\", \"Popularity\": 80.0, \"Danceability\": 0.461, \"Energy\": 0.593, \"Loudness\": -4.954, \"Speechiness\": 0.0356, \"Acousticness\": 0.17, \"Liveness\": 0.307, \"Tempo\": 134.17, \"Duration (ms)\": 228373.0, \"Valence\": 0.175, \"Chord\": \"C#/Db\"}, {\"Index\": 561, \"Highest Charting Position\": 14, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Midnight Sky\", \"Streams\": 5208100, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"27ycaQnQAxaPiyeg3nr2aB\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 76.0, \"Danceability\": 0.705, \"Energy\": 0.814, \"Loudness\": -5.466, \"Speechiness\": 0.0346, \"Acousticness\": 0.00115, \"Liveness\": 0.203, \"Tempo\": 110.0, \"Duration (ms)\": 223279.0, \"Valence\": 0.259, \"Chord\": \"E\"}, {\"Index\": 562, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Pressure (feat. Tove Lo)\", \"Streams\": 5197587, \"Artist\": \"Martin Garrix\", \"Artist Followers\": 14921269.0, \"Song ID\": \"4ga4WvRNhMsIL38pkBbnIN\", \"Genre\": \"['dance pop', 'dutch edm', 'edm', 'pop', 'pop dance', 'progressive house', 'tropical house']\", \"Release Date\": \"2021-02-05\", \"Weeks Charted\": \"2021-02-05--2021-02-12\", \"Popularity\": 76.0, \"Danceability\": 0.859, \"Energy\": 0.558, \"Loudness\": -8.991, \"Speechiness\": 0.0902, \"Acousticness\": 0.659, \"Liveness\": 0.124, \"Tempo\": 114.978, \"Duration (ms)\": 144391.0, \"Valence\": 0.357, \"Chord\": \"G\"}, {\"Index\": 563, \"Highest Charting Position\": 140, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Can You Feel My Heart\", \"Streams\": 5092250, \"Artist\": \"Bring Me The Horizon\", \"Artist Followers\": 3912138.0, \"Song ID\": \"0WSa1sucoNRcEeULlZVQXj\", \"Genre\": \"['melodic metalcore', 'metalcore', 'rock', 'uk metalcore']\", \"Release Date\": \"2013-04-01\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 77.0, \"Danceability\": 0.15, \"Energy\": 0.859, \"Loudness\": -2.827, \"Speechiness\": 0.0595, \"Acousticness\": 0.00201, \"Liveness\": 0.387, \"Tempo\": 170.527, \"Duration (ms)\": 228147.0, \"Valence\": 0.354, \"Chord\": \"E\"}, {\"Index\": 564, \"Highest Charting Position\": 167, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Agua de Jamaica\", \"Streams\": 5072462, \"Artist\": \"Maluma\", \"Artist Followers\": 26784251.0, \"Song ID\": \"41BzKiCrKpUQHS3TP0jmdr\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-01-28\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 75.0, \"Danceability\": 0.664, \"Energy\": 0.665, \"Loudness\": -3.616, \"Speechiness\": 0.0879, \"Acousticness\": 0.123, \"Liveness\": 0.411, \"Tempo\": 173.961, \"Duration (ms)\": 176970.0, \"Valence\": 0.726, \"Chord\": \"A#/Bb\"}, {\"Index\": 565, \"Highest Charting Position\": 162, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Mds\", \"Streams\": 5046418, \"Artist\": \"Kawe, Mc Lele JP\", \"Artist Followers\": 444736.0, \"Song ID\": \"0QglpM23kl9ldvVdoYNZwF\", \"Genre\": \"['brazilian hip hop', 'funk ostentacao']\", \"Release Date\": \"2020-05-19\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 72.0, \"Danceability\": 0.885, \"Energy\": 0.561, \"Loudness\": -5.331, \"Speechiness\": 0.249, \"Acousticness\": 0.261, \"Liveness\": 0.121, \"Tempo\": 140.02, \"Duration (ms)\": 125143.0, \"Valence\": 0.644, \"Chord\": \"F#/Gb\"}, {\"Index\": 566, \"Highest Charting Position\": 18, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Heartless\", \"Streams\": 4995578, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"6bnF93Rx87YqUBLSgjiMU8\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.537, \"Energy\": 0.746, \"Loudness\": -5.507, \"Speechiness\": 0.15, \"Acousticness\": 0.0236, \"Liveness\": 0.156, \"Tempo\": 170.062, \"Duration (ms)\": 198267.0, \"Valence\": 0.252, \"Chord\": \"A#/Bb\"}, {\"Index\": 567, \"Highest Charting Position\": 20, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"pov\", \"Streams\": 4906738, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3UoULw70kMsiVXxW0L3A33\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 79.0, \"Danceability\": 0.487, \"Energy\": 0.534, \"Loudness\": -5.664, \"Speechiness\": 0.0555, \"Acousticness\": 0.36, \"Liveness\": 0.1, \"Tempo\": 131.798, \"Duration (ms)\": 201882.0, \"Valence\": 0.173, \"Chord\": \"C\"}, {\"Index\": 568, \"Highest Charting Position\": 138, \"Number of Times Charted\": 49, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Be Alright\", \"Streams\": 4900492, \"Artist\": \"Dean Lewis\", \"Artist Followers\": 1692635.0, \"Song ID\": \"3EPXxR3ImUwfayaurPi3cm\", \"Genre\": \"['australian pop', 'indie cafe pop', 'pop', 'pop rock', 'post-teen pop']\", \"Release Date\": \"2018-06-29\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.553, \"Energy\": 0.586, \"Loudness\": -6.319, \"Speechiness\": 0.0362, \"Acousticness\": 0.697, \"Liveness\": 0.0813, \"Tempo\": 126.684, \"Duration (ms)\": 196373.0, \"Valence\": 0.443, \"Chord\": \"B\"}, {\"Index\": 569, \"Highest Charting Position\": 174, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Cry Baby (feat. DaBaby)\", \"Streams\": 4884711, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"4aarlAfLKVCTxUDNgbwhjH\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 76.0, \"Danceability\": 0.957, \"Energy\": 0.437, \"Loudness\": -7.882, \"Speechiness\": 0.359, \"Acousticness\": 0.00402, \"Liveness\": 0.219, \"Tempo\": 130.058, \"Duration (ms)\": 137984.0, \"Valence\": 0.616, \"Chord\": \"B\"}, {\"Index\": 570, \"Highest Charting Position\": 47, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Mi Cuarto\", \"Streams\": 4873380, \"Artist\": \"Jerry Di\", \"Artist Followers\": 149682.0, \"Song ID\": \"6fmQjRuo7XvRFCK2qex5hQ\", \"Genre\": \"['cubaton', 'dominican pop', 'pop venezolano', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 76.0, \"Danceability\": 0.854, \"Energy\": 0.525, \"Loudness\": -4.426, \"Speechiness\": 0.214, \"Acousticness\": 0.819, \"Liveness\": 0.146, \"Tempo\": 97.054, \"Duration (ms)\": 197587.0, \"Valence\": 0.63, \"Chord\": \"C#/Db\"}, {\"Index\": 571, \"Highest Charting Position\": 99, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Ohne Dich\", \"Streams\": 5487774, \"Artist\": \"KASIMIR1441, badm\\u00f3mzjay, WILDBWOYS\", \"Artist Followers\": 197320.0, \"Song ID\": \"4hSJUp6k7QeHLxU32MrLIU\", \"Genre\": \"['german alternative rap', 'german hip hop', 'german trap', 'tekk']\", \"Release Date\": \"2021-01-14\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 70.0, \"Danceability\": 0.807, \"Energy\": 0.535, \"Loudness\": -6.519, \"Speechiness\": 0.349, \"Acousticness\": 0.191, \"Liveness\": 0.125, \"Tempo\": 156.013, \"Duration (ms)\": 125720.0, \"Valence\": 0.925, \"Chord\": \"B\"}, {\"Index\": 572, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Gravity (feat. Tyler, The Creator)\", \"Streams\": 5136895, \"Artist\": \"Brent Faiyaz, DJ Dahi\", \"Artist Followers\": 1726216.0, \"Song ID\": \"6u3CPnFMKANYgfdiifFOiJ\", \"Genre\": \"['dmv rap', 'pop', 'r&b', 'rap']\", \"Release Date\": \"2021-01-29\", \"Weeks Charted\": \"2021-01-29--2021-02-05\", \"Popularity\": 76.0, \"Danceability\": 0.539, \"Energy\": 0.615, \"Loudness\": -8.746, \"Speechiness\": 0.252, \"Acousticness\": 0.173, \"Liveness\": 0.144, \"Tempo\": 163.924, \"Duration (ms)\": 214693.0, \"Valence\": 0.493, \"Chord\": \"C#/Db\"}, {\"Index\": 573, \"Highest Charting Position\": 55, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Vibez\", \"Streams\": 5071718, \"Artist\": \"ZAYN\", \"Artist Followers\": 16655692.0, \"Song ID\": \"709F3MwiVvLD0LQXeKs5Cz\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 69.0, \"Danceability\": 0.635, \"Energy\": 0.659, \"Loudness\": -7.499, \"Speechiness\": 0.116, \"Acousticness\": 0.242, \"Liveness\": 0.105, \"Tempo\": 96.855, \"Duration (ms)\": 163127.0, \"Valence\": 0.34, \"Chord\": \"G\"}, {\"Index\": 574, \"Highest Charting Position\": 103, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"All I Want - From \\\"High School Musical: The Musical: The Series\\\"\", \"Streams\": 5052801, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6313514.0, \"Song ID\": \"4Yxc55NX3tAXC2mHRAhtcW\", \"Genre\": \"['pop']\", \"Release Date\": \"2019-11-27\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 76.0, \"Danceability\": 0.376, \"Energy\": 0.43, \"Loudness\": -6.585, \"Speechiness\": 0.0328, \"Acousticness\": 0.0902, \"Liveness\": 0.0912, \"Tempo\": 77.599, \"Duration (ms)\": 177323.0, \"Valence\": 0.129, \"Chord\": \"C\"}, {\"Index\": 575, \"Highest Charting Position\": 45, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Daisy\", \"Streams\": 5030670, \"Artist\": \"Ashnikko\", \"Artist Followers\": 1248499.0, \"Song ID\": \"0AUvWawuP0ibk4SQ3sIZjk\", \"Genre\": \"['electropop', 'escape room', 'pop']\", \"Release Date\": \"2020-07-09\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 76.0, \"Danceability\": 0.834, \"Energy\": 0.663, \"Loudness\": -6.143, \"Speechiness\": 0.133, \"Acousticness\": 0.235, \"Liveness\": 0.372, \"Tempo\": 121.876, \"Duration (ms)\": 146523.0, \"Valence\": 0.774, \"Chord\": \"G#/Ab\"}, {\"Index\": 576, \"Highest Charting Position\": 83, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Wasted On You\", \"Streams\": 4948563, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"3cBsEDNhFI9E82vPj3kvi3\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 76.0, \"Danceability\": 0.505, \"Energy\": 0.657, \"Loudness\": -5.24, \"Speechiness\": 0.0318, \"Acousticness\": 0.373, \"Liveness\": 0.126, \"Tempo\": 196.0, \"Duration (ms)\": 178520.0, \"Valence\": 0.252, \"Chord\": \"B\"}, {\"Index\": 577, \"Highest Charting Position\": 13, \"Number of Times Charted\": 38, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"La Jeepeta - Remix\", \"Streams\": 4942545, \"Artist\": \"Nio Garcia, Anuel AA, Myke Towers, Brray, Juanka\", \"Artist Followers\": 2127531.0, \"Song ID\": \"1mohfLaTJtB2RplHLQVM70\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 75.0, \"Danceability\": 0.815, \"Energy\": 0.715, \"Loudness\": -4.65, \"Speechiness\": 0.207, \"Acousticness\": 0.3, \"Liveness\": 0.091, \"Tempo\": 176.007, \"Duration (ms)\": 345241.0, \"Valence\": 0.786, \"Chord\": \"E\"}, {\"Index\": 578, \"Highest Charting Position\": 137, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Los Dioses\", \"Streams\": 5929507, \"Artist\": \"Anuel AA, Ozuna\", \"Artist Followers\": 18306226.0, \"Song ID\": \"73O30uMI7n6DuzBmbtO7kC\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-01-22--2021-01-29\", \"Popularity\": 73.0, \"Danceability\": 0.817, \"Energy\": 0.737, \"Loudness\": -5.453, \"Speechiness\": 0.102, \"Acousticness\": 0.046, \"Liveness\": 0.092, \"Tempo\": 93.985, \"Duration (ms)\": 206587.0, \"Valence\": 0.67, \"Chord\": \"F#/Gb\"}, {\"Index\": 579, \"Highest Charting Position\": 132, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Si Me Tomo Una Cerveza\", \"Streams\": 5427534, \"Artist\": \"Migrantes, Alico\", \"Artist Followers\": 114348.0, \"Song ID\": \"3lCbsHaN1wCxyDzcNN2x4N\", \"Genre\": \"['cumbia pop']\", \"Release Date\": \"2020-11-07\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 74.0, \"Danceability\": 0.72, \"Energy\": 0.613, \"Loudness\": -6.899, \"Speechiness\": 0.0572, \"Acousticness\": 0.185, \"Liveness\": 0.155, \"Tempo\": 84.974, \"Duration (ms)\": 182199.0, \"Valence\": 0.857, \"Chord\": \"C#/Db\"}, {\"Index\": 580, \"Highest Charting Position\": 90, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Somebody\\u2019s Problem\", \"Streams\": 5332437, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"0SErdEdRcVX1uJCf1eTGYH\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2020-11-20--2020-11-27\", \"Popularity\": 70.0, \"Danceability\": 0.657, \"Energy\": 0.54, \"Loudness\": -7.675, \"Speechiness\": 0.0287, \"Acousticness\": 0.662, \"Liveness\": 0.123, \"Tempo\": 136.97, \"Duration (ms)\": 161773.0, \"Valence\": 0.625, \"Chord\": \"F\"}, {\"Index\": 581, \"Highest Charting Position\": 66, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"De Una Vez\", \"Streams\": 5186567, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"1v3lhrZEsOcazqR2QIyyRu\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 70.0, \"Danceability\": 0.659, \"Energy\": 0.479, \"Loudness\": -6.79, \"Speechiness\": 0.2, \"Acousticness\": 0.152, \"Liveness\": 0.268, \"Tempo\": 163.882, \"Duration (ms)\": 155956.0, \"Valence\": 0.0395, \"Chord\": \"B\"}, {\"Index\": 582, \"Highest Charting Position\": 121, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Way Out (feat. Big Sean)\", \"Streams\": 4962949, \"Artist\": \"Jack Harlow\", \"Artist Followers\": 1053324.0, \"Song ID\": \"6rLi6PyWXu1rPlShuIZpj6\", \"Genre\": \"['deep underground hip hop', 'kentucky hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-09\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 72.0, \"Danceability\": 0.945, \"Energy\": 0.582, \"Loudness\": -8.357, \"Speechiness\": 0.0719, \"Acousticness\": 0.114, \"Liveness\": 0.103, \"Tempo\": 108.025, \"Duration (ms)\": 168906.0, \"Valence\": 0.907, \"Chord\": \"B\"}, {\"Index\": 583, \"Highest Charting Position\": 42, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Diamonds\", \"Streams\": 4931163, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"5hvwx5i67IwnCkjl9VHkNv\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-09-17\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 77.0, \"Danceability\": 0.653, \"Energy\": 0.667, \"Loudness\": -6.764, \"Speechiness\": 0.0423, \"Acousticness\": 0.154, \"Liveness\": 0.107, \"Tempo\": 104.181, \"Duration (ms)\": 213869.0, \"Valence\": 0.556, \"Chord\": \"A#/Bb\"}, {\"Index\": 584, \"Highest Charting Position\": 190, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Dancing in My Room\", \"Streams\": 4914093, \"Artist\": \"347aidan\", \"Artist Followers\": 211500.0, \"Song ID\": \"6Pgmqg15yVexuOgtzuxwoX\", \"Genre\": \"['sad rap']\", \"Release Date\": \"2020-10-26\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\", \"Popularity\": 79.0, \"Danceability\": 0.98, \"Energy\": 0.413, \"Loudness\": -11.052, \"Speechiness\": 0.101, \"Acousticness\": 0.671, \"Liveness\": 0.17, \"Tempo\": 119.993, \"Duration (ms)\": 180139.0, \"Valence\": 0.764, \"Chord\": \"G#/Ab\"}, {\"Index\": 585, \"Highest Charting Position\": 116, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"De Cora <3\", \"Streams\": 4864544, \"Artist\": \"Rauw Alejandro, J Balvin\", \"Artist Followers\": 6096559.0, \"Song ID\": \"22Sh5dlwbERqJAq1fZk5b2\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 73.0, \"Danceability\": 0.811, \"Energy\": 0.683, \"Loudness\": -2.028, \"Speechiness\": 0.241, \"Acousticness\": 0.46, \"Liveness\": 0.128, \"Tempo\": 176.037, \"Duration (ms)\": 190101.0, \"Valence\": 0.571, \"Chord\": \"B\"}, {\"Index\": 586, \"Highest Charting Position\": 10, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"champagne problems\", \"Streams\": 4848954, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0sY6ZUTh4yoctD8VIXz339\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 75.0, \"Danceability\": 0.462, \"Energy\": 0.24, \"Loudness\": -12.077, \"Speechiness\": 0.0377, \"Acousticness\": 0.92, \"Liveness\": 0.113, \"Tempo\": 171.319, \"Duration (ms)\": 244000.0, \"Valence\": 0.32, \"Chord\": \"C\"}, {\"Index\": 587, \"Highest Charting Position\": 37, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Go Crazy\", \"Streams\": 4833081, \"Artist\": \"Chris Brown, Young Thug\", \"Artist Followers\": 14073083.0, \"Song ID\": \"1IIKrJVP1C9N7iPtG6eOsK\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'r&b', 'rap']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 80.0, \"Danceability\": 0.755, \"Energy\": 0.578, \"Loudness\": -8.932, \"Speechiness\": 0.145, \"Acousticness\": 0.316, \"Liveness\": 0.25, \"Tempo\": 94.148, \"Duration (ms)\": 176960.0, \"Valence\": 0.581, \"Chord\": \"C\"}, {\"Index\": 588, \"Highest Charting Position\": 73, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Reminds Me Of You\", \"Streams\": 5942551, \"Artist\": \"Juice WRLD, The Kid LAROI\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5YSHygGN9D0mID1NsVd5my\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-12-08\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 75.0, \"Danceability\": 0.613, \"Energy\": 0.631, \"Loudness\": -6.965, \"Speechiness\": 0.12, \"Acousticness\": 0.0663, \"Liveness\": 0.169, \"Tempo\": 149.992, \"Duration (ms)\": 158033.0, \"Valence\": 0.33, \"Chord\": \"E\"}, {\"Index\": 589, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Don't Play\", \"Streams\": 5119828, \"Artist\": \"Anne-Marie, KSI, Digital Farm Animals\", \"Artist Followers\": 8153871.0, \"Song ID\": \"4I5bvu2KDsrCg0EWHIcvul\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-01-15--2021-01-22\", \"Popularity\": 73.0, \"Danceability\": 0.695, \"Energy\": 0.784, \"Loudness\": -6.564, \"Speechiness\": 0.0402, \"Acousticness\": 0.0889, \"Liveness\": 0.0843, \"Tempo\": 128.031, \"Duration (ms)\": 188581.0, \"Valence\": 0.52, \"Chord\": \"F#/Gb\"}, {\"Index\": 590, \"Highest Charting Position\": 108, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"MODO TURBO\", \"Streams\": 4983557, \"Artist\": \"Lu\\u00edsa Sonza, Pabllo Vittar, Anitta\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5217tPOJfhVUY8q9TCKHO1\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-11\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 1.0, \"Danceability\": 0.655, \"Energy\": 0.726, \"Loudness\": -7.628, \"Speechiness\": 0.0796, \"Acousticness\": 0.334, \"Liveness\": 0.232, \"Tempo\": 160.064, \"Duration (ms)\": 150260.0, \"Valence\": 0.766, \"Chord\": \"A#/Bb\"}, {\"Index\": 591, \"Highest Charting Position\": 191, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Buss It\", \"Streams\": 4915403, \"Artist\": \"Erica Banks\", \"Artist Followers\": 41551.0, \"Song ID\": \"25j0Sape7qZbq6ZPLFefTT\", \"Genre\": \"['trap queen']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2021-01-15--2021-01-22\", \"Popularity\": 72.0, \"Danceability\": 0.956, \"Energy\": 0.502, \"Loudness\": -5.995, \"Speechiness\": 0.213, \"Acousticness\": 0.0593, \"Liveness\": 0.238, \"Tempo\": 110.003, \"Duration (ms)\": 187000.0, \"Valence\": 0.795, \"Chord\": \"A\"}, {\"Index\": 592, \"Highest Charting Position\": 41, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Kings & Queens\", \"Streams\": 4855690, \"Artist\": \"Ava Max\", \"Artist Followers\": 3916979.0, \"Song ID\": \"7a53HqqArd4b9NF4XAmlbI\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 82.0, \"Danceability\": 0.637, \"Energy\": 0.69, \"Loudness\": -4.057, \"Speechiness\": 0.0405, \"Acousticness\": 0.00786, \"Liveness\": 0.124, \"Tempo\": 129.857, \"Duration (ms)\": 162399.0, \"Valence\": 0.457, \"Chord\": \"C#/Db\"}, {\"Index\": 593, \"Highest Charting Position\": 6, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Lovesick Girls\", \"Streams\": 4796365, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"4Ws314Ylb27BVsvlZOy30C\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 75.0, \"Danceability\": 0.654, \"Energy\": 0.707, \"Loudness\": -5.661, \"Speechiness\": 0.0664, \"Acousticness\": 0.00559, \"Liveness\": 0.0873, \"Tempo\": 127.97, \"Duration (ms)\": 194765.0, \"Valence\": 0.448, \"Chord\": \"F#/Gb\"}, {\"Index\": 594, \"Highest Charting Position\": 17, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Caramelo\", \"Streams\": 4790233, \"Artist\": \"Ozuna\", \"Artist Followers\": 29238936.0, \"Song ID\": \"3gD4J3RUHy4OUuZ3qAiaiG\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-06-11\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 74.0, \"Danceability\": 0.728, \"Energy\": 0.806, \"Loudness\": -3.766, \"Speechiness\": 0.0623, \"Acousticness\": 0.0531, \"Liveness\": 0.153, \"Tempo\": 168.084, \"Duration (ms)\": 217547.0, \"Valence\": 0.698, \"Chord\": \"F#/Gb\"}, {\"Index\": 595, \"Highest Charting Position\": 67, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Deep End\", \"Streams\": 5622565, \"Artist\": \"Foushe\\u00e9\", \"Artist Followers\": 411262.0, \"Song ID\": \"2AlYncTpVHKwHb55F9lF6O\", \"Genre\": \"['brooklyn drill', 'nyc rap']\", \"Release Date\": \"2020-06-05\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 72.0, \"Danceability\": 0.868, \"Energy\": 0.479, \"Loudness\": -6.687, \"Speechiness\": 0.445, \"Acousticness\": 0.703, \"Liveness\": 0.102, \"Tempo\": 133.928, \"Duration (ms)\": 115200.0, \"Valence\": 0.776, \"Chord\": \"E\"}, {\"Index\": 596, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Sand In My Boots\", \"Streams\": 5446609, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"0uRrG2jRR5tuifsYIJHEao\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\", \"Popularity\": 75.0, \"Danceability\": 0.403, \"Energy\": 0.537, \"Loudness\": -6.628, \"Speechiness\": 0.031, \"Acousticness\": 0.59, \"Liveness\": 0.112, \"Tempo\": 69.877, \"Duration (ms)\": 202133.0, \"Valence\": 0.414, \"Chord\": \"D#/Eb\"}, {\"Index\": 597, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"865\", \"Streams\": 5160123, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"0sKEilrw1GrBlG6qsTCrP4\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\", \"Popularity\": 70.0, \"Danceability\": 0.532, \"Energy\": 0.584, \"Loudness\": -5.254, \"Speechiness\": 0.0248, \"Acousticness\": 0.723, \"Liveness\": 0.101, \"Tempo\": 88.003, \"Duration (ms)\": 190680.0, \"Valence\": 0.367, \"Chord\": \"G#/Ab\"}, {\"Index\": 598, \"Highest Charting Position\": 53, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"7 Summers\", \"Streams\": 5064504, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"4obHzpwGrjoTuZh2DItEMZ\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2020-09-11--2020-09-18\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 73.0, \"Danceability\": 0.466, \"Energy\": 0.786, \"Loudness\": -5.13, \"Speechiness\": 0.0328, \"Acousticness\": 0.417, \"Liveness\": 0.125, \"Tempo\": 203.903, \"Duration (ms)\": 210507.0, \"Valence\": 0.571, \"Chord\": \"C\"}, {\"Index\": 599, \"Highest Charting Position\": 21, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"HACIENDO QUE ME AMAS\", \"Streams\": 4935633, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"26QApq0cuO9brJigr0C0W4\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 78.0, \"Danceability\": 0.584, \"Energy\": 0.411, \"Loudness\": -7.147, \"Speechiness\": 0.0838, \"Acousticness\": 0.869, \"Liveness\": 0.0955, \"Tempo\": 169.934, \"Duration (ms)\": 217769.0, \"Valence\": 0.412, \"Chord\": \"A#/Bb\"}, {\"Index\": 600, \"Highest Charting Position\": 65, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"La Luz\", \"Streams\": 4906324, \"Artist\": \"Sech, J Balvin\", \"Artist Followers\": 8766508.0, \"Song ID\": \"5zj8WNkBrEzlI5FKeYV4ol\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-10-31\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 70.0, \"Danceability\": 0.665, \"Energy\": 0.697, \"Loudness\": -4.819, \"Speechiness\": 0.154, \"Acousticness\": 0.427, \"Liveness\": 0.599, \"Tempo\": 94.053, \"Duration (ms)\": 216747.0, \"Valence\": 0.556, \"Chord\": \"A\"}, {\"Index\": 601, \"Highest Charting Position\": 17, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"The Woo (feat. 50 Cent & Roddy Ricch)\", \"Streams\": 4892682, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"1H7KnK26kc1YyellpbINEn\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 79.0, \"Danceability\": 0.49, \"Energy\": 0.618, \"Loudness\": -5.655, \"Speechiness\": 0.104, \"Acousticness\": 0.0221, \"Liveness\": 0.259, \"Tempo\": 99.7, \"Duration (ms)\": 201600.0, \"Valence\": 0.286, \"Chord\": \"C#/Db\"}, {\"Index\": 602, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"More Than My Hometown\", \"Streams\": 4879971, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"5OELUCYgOHKFAvCERnAvfS\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\", \"Popularity\": 75.0, \"Danceability\": 0.62, \"Energy\": 0.869, \"Loudness\": -5.479, \"Speechiness\": 0.0462, \"Acousticness\": 0.615, \"Liveness\": 0.131, \"Tempo\": 126.019, \"Duration (ms)\": 216573.0, \"Valence\": 0.597, \"Chord\": \"F#/Gb\"}, {\"Index\": 603, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Warning\", \"Streams\": 4860714, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"64SCQtbRtmO28ks1QhS3w5\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\", \"Popularity\": 68.0, \"Danceability\": 0.633, \"Energy\": 0.664, \"Loudness\": -5.037, \"Speechiness\": 0.0294, \"Acousticness\": 0.46, \"Liveness\": 0.108, \"Tempo\": 115.058, \"Duration (ms)\": 156747.0, \"Valence\": 0.268, \"Chord\": \"A#/Bb\"}, {\"Index\": 604, \"Highest Charting Position\": 117, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Recairei - Ao Vivo\", \"Streams\": 4815342, \"Artist\": \"Os Bar\\u00f5es Da Pisadinha\", \"Artist Followers\": 4281787.0, \"Song ID\": \"71FrGl0XcpL3VId65tB5mg\", \"Genre\": \"['forro', 'piseiro']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-27--2020-12-04\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 69.0, \"Danceability\": 0.582, \"Energy\": 0.937, \"Loudness\": -2.118, \"Speechiness\": 0.0858, \"Acousticness\": 0.449, \"Liveness\": 0.684, \"Tempo\": 168.096, \"Duration (ms)\": 166838.0, \"Valence\": 0.939, \"Chord\": \"A#/Bb\"}, {\"Index\": 605, \"Highest Charting Position\": 5, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Ice Cream (with Selena Gomez)\", \"Streams\": 4812765, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"4JUPEh2DVSXFGExu4Uxevz\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 71.0, \"Danceability\": 0.79, \"Energy\": 0.701, \"Loudness\": -4.81, \"Speechiness\": 0.365, \"Acousticness\": 0.0317, \"Liveness\": 0.0311, \"Tempo\": 159.972, \"Duration (ms)\": 177813.0, \"Valence\": 0.91, \"Chord\": \"A\"}, {\"Index\": 606, \"Highest Charting Position\": 22, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Be Kind (with Halsey)\", \"Streams\": 4790427, \"Artist\": \"Marshmello\", \"Artist Followers\": 31552500.0, \"Song ID\": \"3Z8FwOEN59mRMxDCtb8N0A\", \"Genre\": \"['brostep', 'edm', 'pop', 'pop dance', 'progressive electro house']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 80.0, \"Danceability\": 0.63, \"Energy\": 0.633, \"Loudness\": -7.088, \"Speechiness\": 0.0457, \"Acousticness\": 0.00776, \"Liveness\": 0.0541, \"Tempo\": 93.995, \"Duration (ms)\": 172762.0, \"Valence\": 0.452, \"Chord\": \"E\"}, {\"Index\": 607, \"Highest Charting Position\": 76, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Fever\", \"Streams\": 4769618, \"Artist\": \"Dua Lipa, Ang\\u00e8le\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3wJVBz7gvGTwTWVAxFa6ny\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-10-29\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 73.0, \"Danceability\": 0.868, \"Energy\": 0.693, \"Loudness\": -7.052, \"Speechiness\": 0.181, \"Acousticness\": 0.0597, \"Liveness\": 0.106, \"Tempo\": 114.999, \"Duration (ms)\": 156911.0, \"Valence\": 0.396, \"Chord\": \"F#/Gb\"}, {\"Index\": 608, \"Highest Charting Position\": 141, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Angst\", \"Streams\": 5317174, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"5yUzqd3H7cmJ1no6B4uTzu\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2021-01-01\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.599, \"Energy\": 0.79, \"Loudness\": -4.352, \"Speechiness\": 0.386, \"Acousticness\": 0.0213, \"Liveness\": 0.0778, \"Tempo\": 100.119, \"Duration (ms)\": 201501.0, \"Valence\": 0.528, \"Chord\": \"A\"}, {\"Index\": 609, \"Highest Charting Position\": 15, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"no body, no crime (feat. HAIM)\", \"Streams\": 4986214, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3RaT22zZsxVYxxKR7TAaYF\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 68.0, \"Danceability\": 0.546, \"Energy\": 0.613, \"Loudness\": -7.589, \"Speechiness\": 0.0264, \"Acousticness\": 0.418, \"Liveness\": 0.103, \"Tempo\": 79.015, \"Duration (ms)\": 215627.0, \"Valence\": 0.535, \"Chord\": \"G\"}, {\"Index\": 610, \"Highest Charting Position\": 13, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Sunday Best\", \"Streams\": 4858392, \"Artist\": \"Surfaces\", \"Artist Followers\": 724903.0, \"Song ID\": \"1Cv1YLb4q0RzL6pybtaMLo\", \"Genre\": \"['bedroom soul', 'pop']\", \"Release Date\": \"2019-01-06\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 80.0, \"Danceability\": 0.878, \"Energy\": 0.525, \"Loudness\": -6.832, \"Speechiness\": 0.0578, \"Acousticness\": 0.183, \"Liveness\": 0.0714, \"Tempo\": 112.022, \"Duration (ms)\": 158571.0, \"Valence\": 0.694, \"Chord\": \"F\"}, {\"Index\": 611, \"Highest Charting Position\": 171, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Amor ou o Litr\\u00e3o\", \"Streams\": 4848222, \"Artist\": \"Petter Ferraz, Menor Nico\", \"Artist Followers\": 14122.0, \"Song ID\": \"7qmnP8Woc47dLSrMD5MxL1\", \"Genre\": \"[]\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 66.0, \"Danceability\": 0.934, \"Energy\": 0.707, \"Loudness\": -4.214, \"Speechiness\": 0.0646, \"Acousticness\": 0.437, \"Liveness\": 0.0628, \"Tempo\": 138.023, \"Duration (ms)\": 173913.0, \"Valence\": 0.961, \"Chord\": \"A\"}, {\"Index\": 612, \"Highest Charting Position\": 66, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Happier\", \"Streams\": 4655272, \"Artist\": \"Marshmello, Bastille\", \"Artist Followers\": 31552500.0, \"Song ID\": \"2dpaYNEQHiRxtZbfNsse99\", \"Genre\": \"['brostep', 'edm', 'pop', 'pop dance', 'progressive electro house']\", \"Release Date\": \"2018-08-17\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-11-13--2020-11-20\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.687, \"Energy\": 0.792, \"Loudness\": -2.749, \"Speechiness\": 0.0452, \"Acousticness\": 0.191, \"Liveness\": 0.167, \"Tempo\": 100.015, \"Duration (ms)\": 214290.0, \"Valence\": 0.671, \"Chord\": \"F\"}, {\"Index\": 613, \"Highest Charting Position\": 138, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Don't Stop Me Now - Remastered 2011\", \"Streams\": 4630572, \"Artist\": \"Queen\", \"Artist Followers\": 35910149.0, \"Song ID\": \"7hQJA50XrCWABAu5v6QZ4i\", \"Genre\": \"['classic rock', 'glam rock', 'rock']\", \"Release Date\": \"1978-11-10\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-15--2020-05-22\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.563, \"Energy\": 0.865, \"Loudness\": -5.277, \"Speechiness\": 0.16, \"Acousticness\": 0.0472, \"Liveness\": 0.77, \"Tempo\": 156.271, \"Duration (ms)\": 209413.0, \"Valence\": 0.601, \"Chord\": \"F\"}, {\"Index\": 614, \"Highest Charting Position\": 61, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Azul\", \"Streams\": 4606011, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"2lCkncy6bIB0LTMT7kvrD1\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 77.0, \"Danceability\": 0.843, \"Energy\": 0.836, \"Loudness\": -2.474, \"Speechiness\": 0.0695, \"Acousticness\": 0.0816, \"Liveness\": 0.0532, \"Tempo\": 94.018, \"Duration (ms)\": 205933.0, \"Valence\": 0.65, \"Chord\": \"B\"}, {\"Index\": 615, \"Highest Charting Position\": 183, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Basta Voc\\u00ea Me Ligar - Ao Vivo\", \"Streams\": 4580123, \"Artist\": \"Os Bar\\u00f5es Da Pisadinha, Xand Avi\\u00e3o\", \"Artist Followers\": 4281787.0, \"Song ID\": \"3AV1KI22k1jGMz792lDrj1\", \"Genre\": \"['forro', 'piseiro']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 68.0, \"Danceability\": 0.599, \"Energy\": 0.914, \"Loudness\": -2.415, \"Speechiness\": 0.0629, \"Acousticness\": 0.5, \"Liveness\": 0.694, \"Tempo\": 168.008, \"Duration (ms)\": 182977.0, \"Valence\": 0.831, \"Chord\": \"F\"}, {\"Index\": 616, \"Highest Charting Position\": 49, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Tequila Shots\", \"Streams\": 4540781, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"30KctD1WsHKTIYczXjip5a\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 74.0, \"Danceability\": 0.712, \"Energy\": 0.556, \"Loudness\": -7.214, \"Speechiness\": 0.0531, \"Acousticness\": 0.084, \"Liveness\": 0.527, \"Tempo\": 90.494, \"Duration (ms)\": 193293.0, \"Valence\": 0.22, \"Chord\": \"F\"}, {\"Index\": 617, \"Highest Charting Position\": 27, \"Number of Times Charted\": 45, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Lose Control\", \"Streams\": 4516053, \"Artist\": \"MEDUZA, Becky Hill, Goodboys\", \"Artist Followers\": 441714.0, \"Song ID\": \"7CHi4DtfK4heMlQaudCuHK\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop house', 'tropical house']\", \"Release Date\": \"2019-10-11\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.598, \"Energy\": 0.526, \"Loudness\": -8.659, \"Speechiness\": 0.0415, \"Acousticness\": 0.129, \"Liveness\": 0.14, \"Tempo\": 123.935, \"Duration (ms)\": 168387.0, \"Valence\": 0.529, \"Chord\": \"A#/Bb\"}, {\"Index\": 618, \"Highest Charting Position\": 68, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"I CAN'T STOP ME\", \"Streams\": 4504304, \"Artist\": \"TWICE\", \"Artist Followers\": 9998991.0, \"Song ID\": \"37ZtpRBkHcaq6hHy0X98zn\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-26\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 76.0, \"Danceability\": 0.657, \"Energy\": 0.88, \"Loudness\": -3.672, \"Speechiness\": 0.102, \"Acousticness\": 0.121, \"Liveness\": 0.463, \"Tempo\": 150.084, \"Duration (ms)\": 205493.0, \"Valence\": 0.769, \"Chord\": \"A#/Bb\"}, {\"Index\": 619, \"Highest Charting Position\": 158, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"E-GIRLS ARE RUINING MY LIFE!\", \"Streams\": 4488125, \"Artist\": \"CORPSE, Savage Ga$p\", \"Artist Followers\": 1777797.0, \"Song ID\": \"7bCfHiRcfUjG0YVVNUL7Ve\", \"Genre\": \"['dream smp', 'viral rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 77.0, \"Danceability\": 0.614, \"Energy\": 0.937, \"Loudness\": -7.443, \"Speechiness\": 0.115, \"Acousticness\": 0.00161, \"Liveness\": 0.103, \"Tempo\": 84.98, \"Duration (ms)\": 105176.0, \"Valence\": 0.386, \"Chord\": \"C#/Db\"}, {\"Index\": 620, \"Highest Charting Position\": 1, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"All I Want for Christmas Is You\", \"Streams\": 23235257, \"Artist\": \"Mariah Carey\", \"Artist Followers\": 6931357.0, \"Song ID\": \"0bYg9bo50gSsH3LtXe2SQn\", \"Genre\": \"['dance pop', 'pop', 'r&b', 'urban contemporary']\", \"Release Date\": \"1994-11-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2019-12-27--2020-01-03\", \"Popularity\": 65.0, \"Danceability\": 0.336, \"Energy\": 0.627, \"Loudness\": -7.463, \"Speechiness\": 0.0384, \"Acousticness\": 0.164, \"Liveness\": 0.0708, \"Tempo\": 150.273, \"Duration (ms)\": 241107.0, \"Valence\": 0.35, \"Chord\": \"G\"}, {\"Index\": 621, \"Highest Charting Position\": 2, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Last Christmas\", \"Streams\": 20709328, \"Artist\": \"Wham!\", \"Artist Followers\": 1631876.0, \"Song ID\": \"2FRnf9qhLbvw8fu4IBXx78\", \"Genre\": \"['disco', 'europop', 'new romantic', 'new wave', 'new wave pop', 'soft rock', 'synthpop']\", \"Release Date\": \"1984-11-29\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 63.0, \"Danceability\": 0.735, \"Energy\": 0.478, \"Loudness\": -12.472, \"Speechiness\": 0.0293, \"Acousticness\": 0.189, \"Liveness\": 0.355, \"Tempo\": 107.682, \"Duration (ms)\": 262960.0, \"Valence\": 0.947, \"Chord\": \"D\"}, {\"Index\": 622, \"Highest Charting Position\": 3, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Tell Me\", \"Streams\": 16657592, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"0lizgQ7Qw35od7CYaoMBZb\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2014-11-24\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 61.0, \"Danceability\": 0.525, \"Energy\": 0.621, \"Loudness\": -7.364, \"Speechiness\": 0.116, \"Acousticness\": 0.0489, \"Liveness\": 0.294, \"Tempo\": 191.9, \"Duration (ms)\": 204093.0, \"Valence\": 0.591, \"Chord\": \"G\"}, {\"Index\": 623, \"Highest Charting Position\": 5, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Rockin' Around The Christmas Tree\", \"Streams\": 16613649, \"Artist\": \"Brenda Lee\", \"Artist Followers\": 222627.0, \"Song ID\": \"2EjXfH91m7f8HiJN1yQg97\", \"Genre\": \"['adult standards', 'brill building pop', 'easy listening', 'lounge', 'rockabilly', 'vocal jazz']\", \"Release Date\": \"1964-10-19\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 58.0, \"Danceability\": 0.589, \"Energy\": 0.472, \"Loudness\": -8.749, \"Speechiness\": 0.0502, \"Acousticness\": 0.614, \"Liveness\": 0.505, \"Tempo\": 67.196, \"Duration (ms)\": 126267.0, \"Valence\": 0.898, \"Chord\": \"G#/Ab\"}, {\"Index\": 624, \"Highest Charting Position\": 7, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Jingle Bell Rock\", \"Streams\": 16527404, \"Artist\": \"Bobby Helms\", \"Artist Followers\": 20637.0, \"Song ID\": \"7vQbuQcyTflfCIOu3Uzzya\", \"Genre\": \"[]\", \"Release Date\": \"1957-12-02\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 56.0, \"Danceability\": 0.754, \"Energy\": 0.424, \"Loudness\": -8.463, \"Speechiness\": 0.0363, \"Acousticness\": 0.643, \"Liveness\": 0.0652, \"Tempo\": 119.705, \"Duration (ms)\": 130973.0, \"Valence\": 0.806, \"Chord\": \"D\"}, {\"Index\": 625, \"Highest Charting Position\": 6, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"It's Beginning to Look a Lot like Christmas\", \"Streams\": 15424001, \"Artist\": \"Michael Bubl\\u00e9\", \"Artist Followers\": 4702232.0, \"Song ID\": \"5a1iz510sv2W9Dt1MvFd5R\", \"Genre\": \"['adult standards', 'canadian pop', 'jazz pop', 'lounge']\", \"Release Date\": \"2012-11-09\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 55.0, \"Danceability\": 0.339, \"Energy\": 0.214, \"Loudness\": -11.714, \"Speechiness\": 0.0375, \"Acousticness\": 0.908, \"Liveness\": 0.341, \"Tempo\": 94.775, \"Duration (ms)\": 206640.0, \"Valence\": 0.363, \"Chord\": \"E\"}, {\"Index\": 626, \"Highest Charting Position\": 8, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"It's the Most Wonderful Time of the Year\", \"Streams\": 14582001, \"Artist\": \"Andy Williams\", \"Artist Followers\": 369548.0, \"Song ID\": \"5hslUAKq9I9CG2bAulFkHN\", \"Genre\": \"['adult standards', 'brill building pop', 'easy listening', 'lounge', 'mellow gold', 'vocal jazz']\", \"Release Date\": \"1963-11-24\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 55.0, \"Danceability\": 0.24, \"Energy\": 0.598, \"Loudness\": -8.435, \"Speechiness\": 0.0369, \"Acousticness\": 0.766, \"Liveness\": 0.117, \"Tempo\": 201.629, \"Duration (ms)\": 151933.0, \"Valence\": 0.776, \"Chord\": \"G\"}, {\"Index\": 627, \"Highest Charting Position\": 9, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Underneath the Tree\", \"Streams\": 12266990, \"Artist\": \"Kelly Clarkson\", \"Artist Followers\": 7869617.0, \"Song ID\": \"3YZE5qDV7u1ZD1gZc47ZeR\", \"Genre\": \"['dance pop', 'neo mellow', 'pop', 'pop rock', 'post-teen pop', 'talent show']\", \"Release Date\": \"2013-10-29\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 49.0, \"Danceability\": 0.509, \"Energy\": 0.812, \"Loudness\": -5.439, \"Speechiness\": 0.0537, \"Acousticness\": 0.00128, \"Liveness\": 0.214, \"Tempo\": 159.878, \"Duration (ms)\": 229640.0, \"Valence\": 0.689, \"Chord\": \"G#/Ab\"}, {\"Index\": 628, \"Highest Charting Position\": 14, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Feliz Navidad\", \"Streams\": 11664490, \"Artist\": \"Jos\\u00e9 Feliciano\", \"Artist Followers\": 239129.0, \"Song ID\": \"0oPdaY4dXtc3ZsaG17V972\", \"Genre\": \"['latin pop', 'puerto rican pop']\", \"Release Date\": \"2002-09-24\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 49.0, \"Danceability\": 0.513, \"Energy\": 0.831, \"Loudness\": -9.004, \"Speechiness\": 0.0383, \"Acousticness\": 0.55, \"Liveness\": 0.336, \"Tempo\": 148.837, \"Duration (ms)\": 182067.0, \"Valence\": 0.963, \"Chord\": \"D\"}, {\"Index\": 629, \"Highest Charting Position\": 11, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Let It Snow! Let It Snow! Let It Snow!\", \"Streams\": 10884855, \"Artist\": \"Dean Martin\", \"Artist Followers\": 1139096.0, \"Song ID\": \"2uFaJJtFpPDc5Pa95XzTvg\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"1959-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 54.0, \"Danceability\": 0.451, \"Energy\": 0.24, \"Loudness\": -14.014, \"Speechiness\": 0.0351, \"Acousticness\": 0.912, \"Liveness\": 0.175, \"Tempo\": 134.009, \"Duration (ms)\": 117147.0, \"Valence\": 0.701, \"Chord\": \"C#/Db\"}, {\"Index\": 630, \"Highest Charting Position\": 19, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Let It Snow! Let It Snow! Let It Snow! (with The B. Swanson Quartet)\", \"Streams\": 10787165, \"Artist\": \"Frank Sinatra\", \"Artist Followers\": 4953667.0, \"Song ID\": \"4kKdvXD0ez7jp1296JmAts\", \"Genre\": \"['adult standards', 'easy listening', 'lounge']\", \"Release Date\": \"1994-11-08\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 53.0, \"Danceability\": 0.652, \"Energy\": 0.259, \"Loudness\": -13.336, \"Speechiness\": 0.0595, \"Acousticness\": 0.903, \"Liveness\": 0.362, \"Tempo\": 142.169, \"Duration (ms)\": 155453.0, \"Valence\": 0.836, \"Chord\": \"D\"}, {\"Index\": 631, \"Highest Charting Position\": 15, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Mistletoe\", \"Streams\": 10609206, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"7xapw9Oy21WpfEcib2ErSA\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2011-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 59.0, \"Danceability\": 0.657, \"Energy\": 0.56, \"Loudness\": -9.049, \"Speechiness\": 0.0467, \"Acousticness\": 0.498, \"Liveness\": 0.0794, \"Tempo\": 161.993, \"Duration (ms)\": 182947.0, \"Valence\": 0.854, \"Chord\": \"F#/Gb\"}, {\"Index\": 632, \"Highest Charting Position\": 16, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Sleigh Ride\", \"Streams\": 10508459, \"Artist\": \"The Ronettes\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5ASM6Qjiav2xPe7gRkQMsQ\", \"Genre\": \"[]\", \"Release Date\": \"1963\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 50.0, \"Danceability\": 0.529, \"Energy\": 0.772, \"Loudness\": -7.013, \"Speechiness\": 0.0287, \"Acousticness\": 0.403, \"Liveness\": 0.316, \"Tempo\": 91.751, \"Duration (ms)\": 181267.0, \"Valence\": 0.853, \"Chord\": \"D\"}, {\"Index\": 633, \"Highest Charting Position\": 17, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Do They Know It's Christmas? - 1984 Version\", \"Streams\": 10476212, \"Artist\": \"Band Aid\", \"Artist Followers\": 4883.0, \"Song ID\": \"0247StOpd3AkeBQzANX4Zf\", \"Genre\": \"['musical advocacy']\", \"Release Date\": \"2004-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 51.0, \"Danceability\": 0.599, \"Energy\": 0.642, \"Loudness\": -6.936, \"Speechiness\": 0.0363, \"Acousticness\": 0.164, \"Liveness\": 0.0992, \"Tempo\": 115.412, \"Duration (ms)\": 222533.0, \"Valence\": 0.349, \"Chord\": \"C\"}, {\"Index\": 634, \"Highest Charting Position\": 23, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Wonderful Christmastime - Edited Version / Remastered 2011\", \"Streams\": 9882989, \"Artist\": \"Paul McCartney\", \"Artist Followers\": 3609658.0, \"Song ID\": \"1SV1fxF65n9NhRHp3KlBuu\", \"Genre\": \"['album rock', 'art rock', 'beatlesque', 'classic rock', 'mellow gold', 'rock', 'soft rock']\", \"Release Date\": \"1980-05-16\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 51.0, \"Danceability\": 0.774, \"Energy\": 0.511, \"Loudness\": -8.914, \"Speechiness\": 0.0319, \"Acousticness\": 0.322, \"Liveness\": 0.0672, \"Tempo\": 94.736, \"Duration (ms)\": 227653.0, \"Valence\": 0.771, \"Chord\": \"B\"}, {\"Index\": 635, \"Highest Charting Position\": 21, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Holly Jolly Christmas\", \"Streams\": 9852792, \"Artist\": \"Michael Bubl\\u00e9\", \"Artist Followers\": 4702232.0, \"Song ID\": \"5PuKlCjfEVIXl0ZBp5ZW9g\", \"Genre\": \"['adult standards', 'canadian pop', 'jazz pop', 'lounge']\", \"Release Date\": \"2012-11-09\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 48.0, \"Danceability\": 0.647, \"Energy\": 0.465, \"Loudness\": -8.308, \"Speechiness\": 0.0428, \"Acousticness\": 0.865, \"Liveness\": 0.0882, \"Tempo\": 151.251, \"Duration (ms)\": 119787.0, \"Valence\": 0.699, \"Chord\": \"G\"}, {\"Index\": 636, \"Highest Charting Position\": 24, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Happy Xmas (War Is Over) - Remastered 2010\", \"Streams\": 9509781, \"Artist\": \"John Lennon, Yoko Ono\", \"Artist Followers\": 4313100.0, \"Song ID\": \"27RYrbL6S02LNVhDWVl38b\", \"Genre\": \"['album rock', 'art rock', 'beatlesque', 'classic rock', 'folk rock', 'mellow gold', 'rock']\", \"Release Date\": \"2010-10-05\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 53.0, \"Danceability\": 0.321, \"Energy\": 0.64, \"Loudness\": -10.023, \"Speechiness\": 0.0324, \"Acousticness\": 0.28, \"Liveness\": 0.718, \"Tempo\": 146.172, \"Duration (ms)\": 214333.0, \"Valence\": 0.414, \"Chord\": \"D\"}, {\"Index\": 637, \"Highest Charting Position\": 22, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Driving Home for Christmas - 2019 Remaster\", \"Streams\": 8804531, \"Artist\": \"Chris Rea\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 638, \"Highest Charting Position\": 32, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"The Christmas Song (Merry Christmas To You)\", \"Streams\": 8478518, \"Artist\": \"Nat King Cole\", \"Artist Followers\": 1634288.0, \"Song ID\": \"4PS1e8f2LvuTFgUs1Cn3ON\", \"Genre\": \"['adult standards', 'lounge', 'soul', 'vocal jazz']\", \"Release Date\": \"1962\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 53.0, \"Danceability\": 0.319, \"Energy\": 0.21, \"Loudness\": -15.231, \"Speechiness\": 0.0341, \"Acousticness\": 0.92, \"Liveness\": 0.138, \"Tempo\": 78.696, \"Duration (ms)\": 192160.0, \"Valence\": 0.209, \"Chord\": \"C#/Db\"}, {\"Index\": 639, \"Highest Charting Position\": 39, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"White Christmas\", \"Streams\": 7045348, \"Artist\": \"Bing Crosby, Ken Darby Singers, John Scott Trotter & His Orchestra\", \"Artist Followers\": 359973.0, \"Song ID\": \"4so0Wek9Ig1p6CRCHuINwW\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'swing', 'vocal jazz']\", \"Release Date\": \"1942-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 51.0, \"Danceability\": 0.317, \"Energy\": 0.158, \"Loudness\": -16.485, \"Speechiness\": 0.0381, \"Acousticness\": 0.673, \"Liveness\": 0.338, \"Tempo\": 130.503, \"Duration (ms)\": 177480.0, \"Valence\": 0.247, \"Chord\": \"A\"}, {\"Index\": 640, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Slay3r\", \"Streams\": 6912271, \"Artist\": \"Playboi Carti\", \"Artist Followers\": 4958353.0, \"Song ID\": \"1eMNW1HQjF1dbb4GtnmpaX\", \"Genre\": \"['atl hip hop', 'plugg', 'rap', 'trap']\", \"Release Date\": \"2020-12-25\", \"Weeks Charted\": \"2020-12-25--2021-01-01\", \"Popularity\": 63.0, \"Danceability\": 0.885, \"Energy\": 0.661, \"Loudness\": -5.062, \"Speechiness\": 0.141, \"Acousticness\": 0.165, \"Liveness\": 0.334, \"Tempo\": 140.028, \"Duration (ms)\": 164591.0, \"Valence\": 0.436, \"Chord\": \"E\"}, {\"Index\": 641, \"Highest Charting Position\": 42, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"A Holly Jolly Christmas - Single Version\", \"Streams\": 6716353, \"Artist\": \"Burl Ives\", \"Artist Followers\": 58479.0, \"Song ID\": \"77khP2fIVhSW23NwxrRluh\", \"Genre\": \"['adult standards', 'american folk revival']\", \"Release Date\": \"1965-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 49.0, \"Danceability\": 0.683, \"Energy\": 0.375, \"Loudness\": -13.056, \"Speechiness\": 0.0303, \"Acousticness\": 0.579, \"Liveness\": 0.076, \"Tempo\": 140.467, \"Duration (ms)\": 135533.0, \"Valence\": 0.888, \"Chord\": \"C\"}, {\"Index\": 642, \"Highest Charting Position\": 47, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Fairytale of New York (feat. Kirsty MacColl)\", \"Streams\": 6404964, \"Artist\": \"The Pogues\", \"Artist Followers\": 382997.0, \"Song ID\": \"3VTNVsTTu05dmTsVFrmGpK\", \"Genre\": \"['celtic', 'celtic punk', 'celtic rock', 'folk punk', 'irish folk', 'punk']\", \"Release Date\": \"1988-09-05\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 55.0, \"Danceability\": 0.271, \"Energy\": 0.551, \"Loudness\": -7.48, \"Speechiness\": 0.0457, \"Acousticness\": 0.582, \"Liveness\": 0.256, \"Tempo\": 78.111, \"Duration (ms)\": 272467.0, \"Valence\": 0.428, \"Chord\": \"D\"}, {\"Index\": 643, \"Highest Charting Position\": 38, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Merry Christmas Everyone\", \"Streams\": 6052105, \"Artist\": \"Shakin' Stevens\", \"Artist Followers\": 99249.0, \"Song ID\": \"2TE4xW3ImvpltVU0cPcKUn\", \"Genre\": \"['classic uk pop', 'new wave pop', 'rock-and-roll', 'rockabilly', 'soft rock']\", \"Release Date\": \"1991-11-25\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 47.0, \"Danceability\": 0.534, \"Energy\": 0.904, \"Loudness\": -3.315, \"Speechiness\": 0.0369, \"Acousticness\": 0.129, \"Liveness\": 0.128, \"Tempo\": 202.899, \"Duration (ms)\": 220160.0, \"Valence\": 0.96, \"Chord\": \"A\"}, {\"Index\": 644, \"Highest Charting Position\": 62, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Blue Christmas\", \"Streams\": 6007011, \"Artist\": \"Elvis Presley\", \"Artist Followers\": 5698788.0, \"Song ID\": \"3QiAAp20rPC3dcAtKtMaqQ\", \"Genre\": \"['rock-and-roll', 'rockabilly']\", \"Release Date\": \"1957-10-15\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 49.0, \"Danceability\": 0.465, \"Energy\": 0.27, \"Loudness\": -16.661, \"Speechiness\": 0.0425, \"Acousticness\": 0.9, \"Liveness\": 0.145, \"Tempo\": 94.518, \"Duration (ms)\": 129173.0, \"Valence\": 0.58, \"Chord\": \"E\"}, {\"Index\": 645, \"Highest Charting Position\": 65, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Run Rudolph Run - Single Version\", \"Streams\": 5802508, \"Artist\": \"Chuck Berry\", \"Artist Followers\": 1251372.0, \"Song ID\": \"47CIT5hMphuMQkpeyfGQTL\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 0.0, \"Danceability\": 0.647, \"Energy\": 0.876, \"Loudness\": -5.662, \"Speechiness\": 0.185, \"Acousticness\": 0.881, \"Liveness\": 0.26, \"Tempo\": 151.925, \"Duration (ms)\": 162897.0, \"Valence\": 0.949, \"Chord\": \"A#/Bb\"}, {\"Index\": 646, \"Highest Charting Position\": 59, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Claus Is Coming To Town\", \"Streams\": 5801639, \"Artist\": \"The Jackson 5\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5Gz7EYD7JAmItA7FbhKgKb\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 0.0, \"Danceability\": 0.691, \"Energy\": 0.776, \"Loudness\": -4.177, \"Speechiness\": 0.0341, \"Acousticness\": 0.458, \"Liveness\": 0.33, \"Tempo\": 146.861, \"Duration (ms)\": 144080.0, \"Valence\": 0.961, \"Chord\": \"C\"}, {\"Index\": 647, \"Highest Charting Position\": 52, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Baby\", \"Streams\": 5687085, \"Artist\": \"Kylie Minogue\", \"Artist Followers\": 1324920.0, \"Song ID\": \"0cM5URUqqQTpJWonmdzF1J\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'electropop', 'eurodance', 'europop', 'new wave pop', 'pop']\", \"Release Date\": \"2010-11-30\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 42.0, \"Danceability\": 0.685, \"Energy\": 0.391, \"Loudness\": -7.183, \"Speechiness\": 0.0435, \"Acousticness\": 0.744, \"Liveness\": 0.142, \"Tempo\": 87.101, \"Duration (ms)\": 202547.0, \"Valence\": 0.443, \"Chord\": \"C#/Db\"}, {\"Index\": 648, \"Highest Charting Position\": 60, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"It's Beginning to Look a Lot Like Christmas (with Mitchell Ayres & His Orchestra)\", \"Streams\": 5422082, \"Artist\": \"Perry Como, The Fontane Sisters\", \"Artist Followers\": 336373.0, \"Song ID\": \"2pXpURmn6zC5ZYDMms6fwa\", \"Genre\": \"['adult standards', 'brill building pop', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"1999-08-20\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 49.0, \"Danceability\": 0.724, \"Energy\": 0.276, \"Loudness\": -12.25, \"Speechiness\": 0.0599, \"Acousticness\": 0.76, \"Liveness\": 0.116, \"Tempo\": 112.874, \"Duration (ms)\": 155933.0, \"Valence\": 0.718, \"Chord\": \"G\"}, {\"Index\": 649, \"Highest Charting Position\": 69, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas (Baby Please Come Home)\", \"Streams\": 5394054, \"Artist\": \"Darlene Love\", \"Artist Followers\": 1251372.0, \"Song ID\": \"46pF1zFimM582ss1PrMy68\", \"Genre\": \"[]\", \"Release Date\": \"1963\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-12-04--2020-12-11\", \"Popularity\": 45.0, \"Danceability\": 0.325, \"Energy\": 0.759, \"Loudness\": -7.146, \"Speechiness\": 0.053, \"Acousticness\": 0.395, \"Liveness\": 0.0773, \"Tempo\": 126.627, \"Duration (ms)\": 166453.0, \"Valence\": 0.36, \"Chord\": \"G#/Ab\"}, {\"Index\": 650, \"Highest Charting Position\": 66, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Step Into Christmas\", \"Streams\": 5353591, \"Artist\": \"Elton John\", \"Artist Followers\": 7504724.0, \"Song ID\": \"6sBWmE23q6xQHlnEZ8jYPT\", \"Genre\": \"['glam rock', 'mellow gold', 'piano rock']\", \"Release Date\": \"1973-10-05\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 43.0, \"Danceability\": 0.526, \"Energy\": 0.925, \"Loudness\": -5.584, \"Speechiness\": 0.0363, \"Acousticness\": 0.102, \"Liveness\": 0.305, \"Tempo\": 140.308, \"Duration (ms)\": 272394.0, \"Valence\": 0.819, \"Chord\": \"D\"}, {\"Index\": 651, \"Highest Charting Position\": 54, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Show Out (with Skepta & Pop Smoke)\", \"Streams\": 5209372, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"5CFJRZRq6sdKKtRwNPWbYv\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 76.0, \"Danceability\": 0.619, \"Energy\": 0.589, \"Loudness\": -6.531, \"Speechiness\": 0.124, \"Acousticness\": 0.43, \"Liveness\": 0.378, \"Tempo\": 143.896, \"Duration (ms)\": 174960.0, \"Valence\": 0.158, \"Chord\": \"C#/Db\"}, {\"Index\": 652, \"Highest Charting Position\": 166, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Investe Em Mim\", \"Streams\": 5191001, \"Artist\": \"Jonas Esticado\", \"Artist Followers\": 1293055.0, \"Song ID\": \"15k1TDabqSEmyXOwMq9RM7\", \"Genre\": \"['forro', 'sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 72.0, \"Danceability\": 0.632, \"Energy\": 0.953, \"Loudness\": -1.283, \"Speechiness\": 0.0325, \"Acousticness\": 0.317, \"Liveness\": 0.125, \"Tempo\": 160.061, \"Duration (ms)\": 186533.0, \"Valence\": 0.798, \"Chord\": \"A\"}, {\"Index\": 653, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Lance Individual\", \"Streams\": 5152906, \"Artist\": \"Jorge & Mateus\", \"Artist Followers\": 15019109.0, \"Song ID\": \"7GLWWrk1YlkPYqJK3ynIA0\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-12-25--2021-01-01\", \"Popularity\": 72.0, \"Danceability\": 0.752, \"Energy\": 0.62, \"Loudness\": -5.536, \"Speechiness\": 0.0509, \"Acousticness\": 0.309, \"Liveness\": 0.075, \"Tempo\": 117.399, \"Duration (ms)\": 164459.0, \"Valence\": 0.962, \"Chord\": \"F\"}, {\"Index\": 654, \"Highest Charting Position\": 71, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Jingle Bell Rock - Daryl's Version\", \"Streams\": 10522305, \"Artist\": \"Daryl Hall & John Oates\", \"Artist Followers\": 1549216.0, \"Song ID\": \"6pVW5LRWgeLaHudxauOTJU\", \"Genre\": \"['album rock', 'classic rock', 'mellow gold', 'rock', 'soft rock', 'yacht rock']\", \"Release Date\": \"1983-11-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 43.0, \"Danceability\": 0.666, \"Energy\": 0.841, \"Loudness\": -3.592, \"Speechiness\": 0.0312, \"Acousticness\": 0.613, \"Liveness\": 0.113, \"Tempo\": 128.706, \"Duration (ms)\": 126360.0, \"Valence\": 0.84, \"Chord\": \"D\"}, {\"Index\": 655, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Thank God It's Christmas - Non-Album Single\", \"Streams\": 10509961, \"Artist\": \"Queen\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 656, \"Highest Charting Position\": 74, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas Lights\", \"Streams\": 10455065, \"Artist\": \"Coldplay\", \"Artist Followers\": 31161671.0, \"Song ID\": \"4QVdnpSO5JGMFOEl6ys4RQ\", \"Genre\": \"['permanent wave', 'pop']\", \"Release Date\": \"2016-12-16\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 53.0, \"Danceability\": 0.295, \"Energy\": 0.496, \"Loudness\": -9.478, \"Speechiness\": 0.0327, \"Acousticness\": 0.207, \"Liveness\": 0.858, \"Tempo\": 132.062, \"Duration (ms)\": 268521.0, \"Valence\": 0.224, \"Chord\": \"G\"}, {\"Index\": 657, \"Highest Charting Position\": 83, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Have Yourself A Merry Little Christmas\", \"Streams\": 9548924, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"1Qi2wh8fFgDV7tl4Sj3f2K\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2014-12-05\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 46.0, \"Danceability\": 0.438, \"Energy\": 0.178, \"Loudness\": -9.402, \"Speechiness\": 0.0414, \"Acousticness\": 0.957, \"Liveness\": 0.316, \"Tempo\": 75.248, \"Duration (ms)\": 170964.0, \"Valence\": 0.344, \"Chord\": \"F\"}, {\"Index\": 658, \"Highest Charting Position\": 85, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa's Coming for Us\", \"Streams\": 9474711, \"Artist\": \"Sia\", \"Artist Followers\": 20528724.0, \"Song ID\": \"1N1ZpYUJc9fwrqk53FGgWv\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'pop']\", \"Release Date\": \"2018-11-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 49.0, \"Danceability\": 0.547, \"Energy\": 0.814, \"Loudness\": -6.191, \"Speechiness\": 0.12, \"Acousticness\": 0.0215, \"Liveness\": 0.0475, \"Tempo\": 92.986, \"Duration (ms)\": 205267.0, \"Valence\": 0.724, \"Chord\": \"C#/Db\"}, {\"Index\": 659, \"Highest Charting Position\": 86, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"My Only Wish (This Year)\", \"Streams\": 9457199, \"Artist\": \"Britney Spears\", \"Artist Followers\": 9470311.0, \"Song ID\": \"0YWUHZPJVg4iujddsJDwhM\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2000-11-14\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-04--2020-12-11\", \"Popularity\": 43.0, \"Danceability\": 0.669, \"Energy\": 0.843, \"Loudness\": -3.766, \"Speechiness\": 0.0268, \"Acousticness\": 0.169, \"Liveness\": 0.195, \"Tempo\": 147.08, \"Duration (ms)\": 255400.0, \"Valence\": 0.702, \"Chord\": \"C\"}, {\"Index\": 660, \"Highest Charting Position\": 89, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Baby, It's Cold Outside (feat. Meghan Trainor)\", \"Streams\": 9270017, \"Artist\": \"Brett Eldredge\", \"Artist Followers\": 1298537.0, \"Song ID\": \"5Q2P43CJra0uRAogjHyJDK\", \"Genre\": \"['contemporary country', 'country', 'country road', 'modern country rock']\", \"Release Date\": \"2016-10-28\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 44.0, \"Danceability\": 0.583, \"Energy\": 0.572, \"Loudness\": -4.776, \"Speechiness\": 0.0366, \"Acousticness\": 0.738, \"Liveness\": 0.266, \"Tempo\": 113.998, \"Duration (ms)\": 173560.0, \"Valence\": 0.684, \"Chord\": \"C#/Db\"}, {\"Index\": 661, \"Highest Charting Position\": 92, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Like It's Christmas\", \"Streams\": 9167304, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"1OjmlSFuzYflWjSMTCyTJv\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-04--2020-12-11\", \"Popularity\": 47.0, \"Danceability\": 0.725, \"Energy\": 0.571, \"Loudness\": -6.007, \"Speechiness\": 0.102, \"Acousticness\": 0.0183, \"Liveness\": 0.0519, \"Tempo\": 146.035, \"Duration (ms)\": 200880.0, \"Valence\": 0.61, \"Chord\": \"C#/Db\"}, {\"Index\": 662, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas Without You\", \"Streams\": 8813922, \"Artist\": \"Ava Max\", \"Artist Followers\": 3916979.0, \"Song ID\": \"1QLZKzC2pjP4ySf4ALrNhm\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-10-15\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 45.0, \"Danceability\": 0.654, \"Energy\": 0.596, \"Loudness\": -4.68, \"Speechiness\": 0.0458, \"Acousticness\": 0.424, \"Liveness\": 0.11, \"Tempo\": 118.078, \"Duration (ms)\": 169245.0, \"Valence\": 0.382, \"Chord\": \"C#/Db\"}, {\"Index\": 663, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"You Make It Feel Like Christmas (feat. Blake Shelton)\", \"Streams\": 8696354, \"Artist\": \"Gwen Stefani\", \"Artist Followers\": 4805333.0, \"Song ID\": \"2OQ6a4CfUeYskpTTgyawyJ\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'post-teen pop', 'urban contemporary']\", \"Release Date\": \"2017-10-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.635, \"Energy\": 0.87, \"Loudness\": -4.291, \"Speechiness\": 0.04, \"Acousticness\": 0.0156, \"Liveness\": 0.118, \"Tempo\": 93.0, \"Duration (ms)\": 156773.0, \"Valence\": 0.912, \"Chord\": \"D\"}, {\"Index\": 664, \"Highest Charting Position\": 107, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Gnat\", \"Streams\": 8614955, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"6cS9PmLky2NhLOhpIsUlow\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 70.0, \"Danceability\": 0.835, \"Energy\": 0.869, \"Loudness\": -4.582, \"Speechiness\": 0.27, \"Acousticness\": 0.248, \"Liveness\": 0.462, \"Tempo\": 140.945, \"Duration (ms)\": 224656.0, \"Valence\": 0.82, \"Chord\": \"A#/Bb\"}, {\"Index\": 665, \"Highest Charting Position\": 111, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Joy To The World\", \"Streams\": 8387899, \"Artist\": \"Nat King Cole\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5oWFPbd340pwiXKMO1CQRy\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 0.0, \"Danceability\": 0.59, \"Energy\": 0.305, \"Loudness\": -12.955, \"Speechiness\": 0.032, \"Acousticness\": 0.894, \"Liveness\": 0.14, \"Tempo\": 102.103, \"Duration (ms)\": 86760.0, \"Valence\": 0.545, \"Chord\": \"A#/Bb\"}, {\"Index\": 666, \"Highest Charting Position\": 117, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Claus Is Coming to Town\", \"Streams\": 8177832, \"Artist\": \"Michael Bubl\\u00e9\", \"Artist Followers\": 4702232.0, \"Song ID\": \"1RMDXedcRno6rDBCbNHDJf\", \"Genre\": \"['adult standards', 'canadian pop', 'jazz pop', 'lounge']\", \"Release Date\": \"2012-11-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.594, \"Energy\": 0.389, \"Loudness\": -7.109, \"Speechiness\": 0.0517, \"Acousticness\": 0.785, \"Liveness\": 0.0313, \"Tempo\": 122.331, \"Duration (ms)\": 171093.0, \"Valence\": 0.396, \"Chord\": \"A#/Bb\"}, {\"Index\": 667, \"Highest Charting Position\": 119, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Baby It's Cold Outside (duet with Michael Bubl\\u00e9)\", \"Streams\": 8160534, \"Artist\": \"Idina Menzel\", \"Artist Followers\": 353571.0, \"Song ID\": \"0Ie5uiv54KgCr7P4sYDTHl\", \"Genre\": \"['hollywood', 'show tunes']\", \"Release Date\": \"2014-10-10\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 47.0, \"Danceability\": 0.553, \"Energy\": 0.476, \"Loudness\": -8.869, \"Speechiness\": 0.0649, \"Acousticness\": 0.647, \"Liveness\": 0.281, \"Tempo\": 113.401, \"Duration (ms)\": 166147.0, \"Valence\": 0.558, \"Chord\": \"C\"}, {\"Index\": 668, \"Highest Charting Position\": 22, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"\\u2018tis the damn season\", \"Streams\": 8115520, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7dW84mWkdWE5a6lFWxJCBG\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.575, \"Energy\": 0.434, \"Loudness\": -8.193, \"Speechiness\": 0.0312, \"Acousticness\": 0.735, \"Liveness\": 0.105, \"Tempo\": 145.916, \"Duration (ms)\": 229840.0, \"Valence\": 0.348, \"Chord\": \"F\"}, {\"Index\": 669, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"I Saw Mommy Kissing Santa Claus\", \"Streams\": 8064361, \"Artist\": \"The Jackson 5\", \"Artist Followers\": 1151360.0, \"Song ID\": \"15sxLiiChE5dCW3Y756oas\", \"Genre\": \"['motown', 'soul']\", \"Release Date\": \"1970-10-15\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.583, \"Energy\": 0.712, \"Loudness\": -8.222, \"Speechiness\": 0.0538, \"Acousticness\": 0.263, \"Liveness\": 0.817, \"Tempo\": 128.897, \"Duration (ms)\": 181267.0, \"Valence\": 0.614, \"Chord\": \"D#/Eb\"}, {\"Index\": 670, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Baby (with Henri Ren\\u00e9 & His Orchestra)\", \"Streams\": 8022773, \"Artist\": \"Eartha Kitt, Henri Rene & His Orchestra\", \"Artist Followers\": 127251.0, \"Song ID\": \"1foCxQtxBweJtZmdxhEHVO\", \"Genre\": \"['adult standards', 'lounge', 'torch song', 'vocal jazz']\", \"Release Date\": \"2002\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.7, \"Energy\": 0.139, \"Loudness\": -12.346, \"Speechiness\": 0.0607, \"Acousticness\": 0.902, \"Liveness\": 0.185, \"Tempo\": 84.485, \"Duration (ms)\": 206067.0, \"Valence\": 0.49, \"Chord\": \"G#/Ab\"}, {\"Index\": 671, \"Highest Charting Position\": 127, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Carol of the Bells\", \"Streams\": 7993078, \"Artist\": \"Mykola Dmytrovych Leontovych, John Williams\", \"Artist Followers\": 1024868.0, \"Song ID\": \"4tHqQMWSqmL6YjXwsqthDI\", \"Genre\": \"['soundtrack']\", \"Release Date\": \"1990\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 51.0, \"Danceability\": 0.418, \"Energy\": 0.106, \"Loudness\": -22.507, \"Speechiness\": 0.0448, \"Acousticness\": 0.994, \"Liveness\": 0.179, \"Tempo\": 46.718, \"Duration (ms)\": 85267.0, \"Valence\": 0.8, \"Chord\": \"G#/Ab\"}, {\"Index\": 672, \"Highest Charting Position\": 19, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"gold rush\", \"Streams\": 7901968, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5BK0uqwY9DNfZ630STAEaq\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 70.0, \"Danceability\": 0.512, \"Energy\": 0.462, \"Loudness\": -10.491, \"Speechiness\": 0.0408, \"Acousticness\": 0.83, \"Liveness\": 0.121, \"Tempo\": 112.05, \"Duration (ms)\": 185320.0, \"Valence\": 0.353, \"Chord\": \"A\"}, {\"Index\": 673, \"Highest Charting Position\": 133, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"What Christmas Means To Me\", \"Streams\": 7792643, \"Artist\": \"Stevie Wonder\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6Wn9zkkbWdK42uXCcADkRq\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 0.0, \"Danceability\": 0.545, \"Energy\": 0.7, \"Loudness\": -6.961, \"Speechiness\": 0.0323, \"Acousticness\": 0.0982, \"Liveness\": 0.1, \"Tempo\": 83.506, \"Duration (ms)\": 148147.0, \"Valence\": 0.799, \"Chord\": \"F\"}, {\"Index\": 674, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"The Christmas Song (Shawn Mendes & Camila Cabello)\", \"Streams\": 7536851, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 33893352.0, \"Song ID\": \"0fwxmtpxpMmEMphmJbCAEx\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2020-12-07\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 42.0, \"Danceability\": 0.341, \"Energy\": 0.181, \"Loudness\": -12.073, \"Speechiness\": 0.0366, \"Acousticness\": 0.888, \"Liveness\": 0.137, \"Tempo\": 83.608, \"Duration (ms)\": 196254.0, \"Valence\": 0.212, \"Chord\": \"D\"}, {\"Index\": 675, \"Highest Charting Position\": 144, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Baby, It's Cold Outside\", \"Streams\": 7367482, \"Artist\": \"Dean Martin\", \"Artist Followers\": 1139096.0, \"Song ID\": \"4MrfQL4TYQXJBlZYpAHTuE\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"1959-01-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.469, \"Energy\": 0.196, \"Loudness\": -16.093, \"Speechiness\": 0.0571, \"Acousticness\": 0.882, \"Liveness\": 0.0513, \"Tempo\": 130.036, \"Duration (ms)\": 143733.0, \"Valence\": 0.537, \"Chord\": \"C\"}, {\"Index\": 676, \"Highest Charting Position\": 145, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Claus Is Comin' to Town - Live at C.W. Post College, Greenvale, NY - December 1975\", \"Streams\": 7363913, \"Artist\": \"Bruce Springsteen\", \"Artist Followers\": 4224071.0, \"Song ID\": \"6s2wpWPFPAgKg2LXxi1Oee\", \"Genre\": \"['classic rock', 'heartland rock', 'mellow gold', 'permanent wave', 'rock', 'singer-songwriter']\", \"Release Date\": \"1981\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.357, \"Energy\": 0.668, \"Loudness\": -8.444, \"Speechiness\": 0.0479, \"Acousticness\": 0.362, \"Liveness\": 0.727, \"Tempo\": 139.986, \"Duration (ms)\": 267600.0, \"Valence\": 0.407, \"Chord\": \"C\"}, {\"Index\": 677, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"One More Sleep\", \"Streams\": 7350024, \"Artist\": \"Leona Lewis\", \"Artist Followers\": 2877234.0, \"Song ID\": \"78pn8k7RogKo2oxl0DyX6d\", \"Genre\": \"['british soul', 'dance pop', 'europop', 'pop', 'post-teen pop', 'talent show']\", \"Release Date\": \"2013-12-02\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 42.0, \"Danceability\": 0.638, \"Energy\": 0.813, \"Loudness\": -3.849, \"Speechiness\": 0.0362, \"Acousticness\": 0.464, \"Liveness\": 0.344, \"Tempo\": 112.986, \"Duration (ms)\": 239587.0, \"Valence\": 0.754, \"Chord\": \"B\"}, {\"Index\": 678, \"Highest Charting Position\": 149, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Little Saint Nick - 1991 Remix\", \"Streams\": 7301381, \"Artist\": \"The Beach Boys\", \"Artist Followers\": 1251372.0, \"Song ID\": \"63Lk6VuXdj7S58R3wLdv9r\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 0.0, \"Danceability\": 0.602, \"Energy\": 0.553, \"Loudness\": -9.336, \"Speechiness\": 0.0328, \"Acousticness\": 0.108, \"Liveness\": 0.0512, \"Tempo\": 130.594, \"Duration (ms)\": 118840.0, \"Valence\": 0.971, \"Chord\": \"B\"}, {\"Index\": 679, \"Highest Charting Position\": 150, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Naughty List (with Dixie)\", \"Streams\": 7299201, \"Artist\": \"Liam Payne\", \"Artist Followers\": 8037861.0, \"Song ID\": \"2Y0ktCGrGoGcQFXsGztvhi\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 51.0, \"Danceability\": 0.619, \"Energy\": 0.771, \"Loudness\": -2.204, \"Speechiness\": 0.0601, \"Acousticness\": 0.0318, \"Liveness\": 0.114, \"Tempo\": 81.966, \"Duration (ms)\": 154747.0, \"Valence\": 0.704, \"Chord\": \"A\"}, {\"Index\": 680, \"Highest Charting Position\": 152, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"I'll Be Home\", \"Streams\": 7281773, \"Artist\": \"Meghan Trainor\", \"Artist Followers\": 10606572.0, \"Song ID\": \"0lTurWECr2XL607eJAj1A3\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2015-01-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 45.0, \"Danceability\": 0.542, \"Energy\": 0.37, \"Loudness\": -7.779, \"Speechiness\": 0.0257, \"Acousticness\": 0.318, \"Liveness\": 0.108, \"Tempo\": 84.796, \"Duration (ms)\": 219653.0, \"Valence\": 0.289, \"Chord\": \"D\"}, {\"Index\": 681, \"Highest Charting Position\": 156, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Rudolph The Red-Nosed Reindeer\", \"Streams\": 7227612, \"Artist\": \"Dean Martin\", \"Artist Followers\": 1139096.0, \"Song ID\": \"2L9QLAhrvtP4EYg1lY0Tnw\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"1959-01-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.478, \"Energy\": 0.201, \"Loudness\": -16.768, \"Speechiness\": 0.0332, \"Acousticness\": 0.919, \"Liveness\": 0.0854, \"Tempo\": 136.471, \"Duration (ms)\": 135760.0, \"Valence\": 0.857, \"Chord\": \"G\"}, {\"Index\": 682, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Mistletoe And Holly - Remastered 1999\", \"Streams\": 7225080, \"Artist\": \"Frank Sinatra\", \"Artist Followers\": 4953667.0, \"Song ID\": \"7faDzZnZYqTyYThx2sbHVQ\", \"Genre\": \"['adult standards', 'easy listening', 'lounge']\", \"Release Date\": \"1957-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 38.0, \"Danceability\": 0.607, \"Energy\": 0.103, \"Loudness\": -14.405, \"Speechiness\": 0.0404, \"Acousticness\": 0.804, \"Liveness\": 0.076, \"Tempo\": 110.378, \"Duration (ms)\": 136427.0, \"Valence\": 0.341, \"Chord\": \"A\"}, {\"Index\": 683, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Jingle Bells - Remastered 1999\", \"Streams\": 7182262, \"Artist\": \"Frank Sinatra\", \"Artist Followers\": 4953667.0, \"Song ID\": \"4HEOgBHRCExyYVeTyrXsnL\", \"Genre\": \"['adult standards', 'easy listening', 'lounge']\", \"Release Date\": \"1957-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 36.0, \"Danceability\": 0.512, \"Energy\": 0.339, \"Loudness\": -13.119, \"Speechiness\": 0.0498, \"Acousticness\": 0.727, \"Liveness\": 0.0977, \"Tempo\": 174.609, \"Duration (ms)\": 120693.0, \"Valence\": 0.951, \"Chord\": \"G#/Ab\"}, {\"Index\": 684, \"Highest Charting Position\": 160, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Oh Santa! (feat. Ariana Grande & Jennifer Hudson)\", \"Streams\": 7170169, \"Artist\": \"Mariah Carey\", \"Artist Followers\": 6931357.0, \"Song ID\": \"1Ri9P0ZPrqr6h0REDRdJBd\", \"Genre\": \"['dance pop', 'pop', 'r&b', 'urban contemporary']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 47.0, \"Danceability\": 0.648, \"Energy\": 0.938, \"Loudness\": -3.298, \"Speechiness\": 0.115, \"Acousticness\": 0.0339, \"Liveness\": 0.0564, \"Tempo\": 78.496, \"Duration (ms)\": 200467.0, \"Valence\": 0.849, \"Chord\": \"C#/Db\"}, {\"Index\": 685, \"Highest Charting Position\": 161, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Do You Hear What I Hear? - Remastered 2006\", \"Streams\": 7149158, \"Artist\": \"Bing Crosby\", \"Artist Followers\": 359973.0, \"Song ID\": \"5aDoUmxBsbdpS16alksb5Z\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'swing', 'vocal jazz']\", \"Release Date\": \"2006-01-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.566, \"Energy\": 0.246, \"Loudness\": -15.499, \"Speechiness\": 0.0276, \"Acousticness\": 0.813, \"Liveness\": 0.195, \"Tempo\": 101.529, \"Duration (ms)\": 165667.0, \"Valence\": 0.412, \"Chord\": \"A#/Bb\"}, {\"Index\": 686, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Hallelujah\", \"Streams\": 6985392, \"Artist\": \"Pentatonix\", \"Artist Followers\": 3083825.0, \"Song ID\": \"0HZk0QsXPhMNAWNDR3rYE8\", \"Genre\": \"['a cappella']\", \"Release Date\": \"2017-12-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 60.0, \"Danceability\": 0.364, \"Energy\": 0.378, \"Loudness\": -7.381, \"Speechiness\": 0.0331, \"Acousticness\": 0.47, \"Liveness\": 0.339, \"Tempo\": 89.918, \"Duration (ms)\": 268960.0, \"Valence\": 0.366, \"Chord\": \"G\"}, {\"Index\": 687, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"This Christmas\", \"Streams\": 6809438, \"Artist\": \"Donny Hathaway\", \"Artist Followers\": 424935.0, \"Song ID\": \"38xhBO2AKrJnjdjVnhJES6\", \"Genre\": \"['chicago soul', 'classic soul', 'funk', 'motown', 'neo soul', 'quiet storm', 'soul', 'southern soul']\", \"Release Date\": \"1990-04-03\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 42.0, \"Danceability\": 0.634, \"Energy\": 0.645, \"Loudness\": -9.2, \"Speechiness\": 0.0376, \"Acousticness\": 0.292, \"Liveness\": 0.246, \"Tempo\": 93.047, \"Duration (ms)\": 231173.0, \"Valence\": 0.677, \"Chord\": \"F\"}, {\"Index\": 688, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Winter Wonderland\", \"Streams\": 6680928, \"Artist\": \"Tony Bennett\", \"Artist Followers\": 659472.0, \"Song ID\": \"6kkJlaBYdyFcwCg67hW40t\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"2014-12-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 29.0, \"Danceability\": 0.604, \"Energy\": 0.497, \"Loudness\": -6.676, \"Speechiness\": 0.0319, \"Acousticness\": 0.727, \"Liveness\": 0.102, \"Tempo\": 126.011, \"Duration (ms)\": 149307.0, \"Valence\": 0.72, \"Chord\": \"C#/Db\"}, {\"Index\": 689, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas Tree Farm\", \"Streams\": 6657404, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2mvabkN1i2gLnGAPUVdwek\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 52.0, \"Danceability\": 0.598, \"Energy\": 0.68, \"Loudness\": -4.505, \"Speechiness\": 0.0331, \"Acousticness\": 0.06, \"Liveness\": 0.324, \"Tempo\": 134.002, \"Duration (ms)\": 228027.0, \"Valence\": 0.437, \"Chord\": \"G\"}, {\"Index\": 690, \"Highest Charting Position\": 182, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Cozy Little Christmas\", \"Streams\": 6652130, \"Artist\": \"Katy Perry\", \"Artist Followers\": 18936929.0, \"Song ID\": \"02FaKXXL7KUtRc7K0k54tL\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-11-15\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.774, \"Energy\": 0.608, \"Loudness\": -6.264, \"Speechiness\": 0.128, \"Acousticness\": 0.128, \"Liveness\": 0.0895, \"Tempo\": 137.494, \"Duration (ms)\": 182521.0, \"Valence\": 0.56, \"Chord\": \"G\"}, {\"Index\": 691, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Merry Christmas, Happy Holidays\", \"Streams\": 6635128, \"Artist\": \"*NSYNC\", \"Artist Followers\": 1564750.0, \"Song ID\": \"4v9WbaxW8HdjqfUiWYWsII\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"1998-10-30\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.643, \"Energy\": 0.939, \"Loudness\": -3.967, \"Speechiness\": 0.0463, \"Acousticness\": 0.104, \"Liveness\": 0.881, \"Tempo\": 104.999, \"Duration (ms)\": 255307.0, \"Valence\": 0.756, \"Chord\": \"F\"}, {\"Index\": 692, \"Highest Charting Position\": 24, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"tolerate it\", \"Streams\": 6635109, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0PurA4JVJ8YQgSVopY8fn6\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 67.0, \"Danceability\": 0.316, \"Energy\": 0.361, \"Loudness\": -10.381, \"Speechiness\": 0.0488, \"Acousticness\": 0.878, \"Liveness\": 0.0797, \"Tempo\": 74.952, \"Duration (ms)\": 245440.0, \"Valence\": 0.221, \"Chord\": \"A\"}, {\"Index\": 693, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Please Come Home for Christmas - 2013 Remaster\", \"Streams\": 6400108, \"Artist\": \"Eagles\", \"Artist Followers\": 6896776.0, \"Song ID\": \"3QIoEi8Enr9uHffwInGIsC\", \"Genre\": \"['album rock', 'classic rock', 'country rock', 'folk rock', 'heartland rock', 'mellow gold', 'rock', 'soft rock', 'yacht rock']\", \"Release Date\": \"1994\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.612, \"Energy\": 0.289, \"Loudness\": -11.568, \"Speechiness\": 0.0421, \"Acousticness\": 0.599, \"Liveness\": 0.0561, \"Tempo\": 183.18, \"Duration (ms)\": 177440.0, \"Valence\": 0.466, \"Chord\": \"A\"}, {\"Index\": 694, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"My Kind Of Present\", \"Streams\": 6278993, \"Artist\": \"Meghan Trainor\", \"Artist Followers\": 10606572.0, \"Song ID\": \"2rkb8ijsPapKDMEh0cSe8I\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.485, \"Energy\": 0.444, \"Loudness\": -6.232, \"Speechiness\": 0.195, \"Acousticness\": 0.373, \"Liveness\": 0.0969, \"Tempo\": 179.967, \"Duration (ms)\": 161013.0, \"Valence\": 0.777, \"Chord\": \"C#/Db\"}, {\"Index\": 695, \"Highest Charting Position\": 28, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"happiness\", \"Streams\": 16213589, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"73YUReisjb3A9ActdLLjJQ\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 65.0, \"Danceability\": 0.559, \"Energy\": 0.334, \"Loudness\": -10.733, \"Speechiness\": 0.0376, \"Acousticness\": 0.87, \"Liveness\": 0.114, \"Tempo\": 122.079, \"Duration (ms)\": 315147.0, \"Valence\": 0.211, \"Chord\": \"B\"}, {\"Index\": 696, \"Highest Charting Position\": 34, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"ivy\", \"Streams\": 14519547, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"19CSr8rwW05VJL2F91KFNK\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.515, \"Energy\": 0.545, \"Loudness\": -9.277, \"Speechiness\": 0.0353, \"Acousticness\": 0.855, \"Liveness\": 0.0921, \"Tempo\": 88.856, \"Duration (ms)\": 260440.0, \"Valence\": 0.535, \"Chord\": \"D\"}, {\"Index\": 697, \"Highest Charting Position\": 38, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"dorothea\", \"Streams\": 14392788, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"670fUmXf4KQekzbEgaXyPA\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.605, \"Energy\": 0.488, \"Loudness\": -8.322, \"Speechiness\": 0.0264, \"Acousticness\": 0.696, \"Liveness\": 0.129, \"Tempo\": 119.966, \"Duration (ms)\": 225880.0, \"Valence\": 0.354, \"Chord\": \"E\"}, {\"Index\": 698, \"Highest Charting Position\": 39, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"coney island (feat. The National)\", \"Streams\": 14385703, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3k7ne7VmH43ZPWxPdvPUgR\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.537, \"Energy\": 0.537, \"Loudness\": -11.266, \"Speechiness\": 0.0617, \"Acousticness\": 0.819, \"Liveness\": 0.142, \"Tempo\": 107.895, \"Duration (ms)\": 275320.0, \"Valence\": 0.292, \"Chord\": \"G#/Ab\"}, {\"Index\": 699, \"Highest Charting Position\": 43, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"evermore (feat. Bon Iver)\", \"Streams\": 13810722, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3O5osWf1rSoKMwe6E9ZaXP\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.39, \"Energy\": 0.27, \"Loudness\": -10.673, \"Speechiness\": 0.0308, \"Acousticness\": 0.937, \"Liveness\": 0.111, \"Tempo\": 125.177, \"Duration (ms)\": 304107.0, \"Valence\": 0.32, \"Chord\": \"C#/Db\"}, {\"Index\": 700, \"Highest Charting Position\": 45, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"long story short\", \"Streams\": 13583538, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2o2sgVJIgFXk8GQjWTgI6U\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.546, \"Energy\": 0.73, \"Loudness\": -7.704, \"Speechiness\": 0.0417, \"Acousticness\": 0.66, \"Liveness\": 0.0972, \"Tempo\": 157.895, \"Duration (ms)\": 215920.0, \"Valence\": 0.573, \"Chord\": \"C\"}, {\"Index\": 701, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"cowboy like me\", \"Streams\": 12782098, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1XjHRolIXL2M1EEOUsGGR4\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.604, \"Energy\": 0.517, \"Loudness\": -9.014, \"Speechiness\": 0.0347, \"Acousticness\": 0.768, \"Liveness\": 0.123, \"Tempo\": 127.967, \"Duration (ms)\": 275040.0, \"Valence\": 0.511, \"Chord\": \"C\"}, {\"Index\": 702, \"Highest Charting Position\": 57, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"marjorie\", \"Streams\": 12234761, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"12ntTeqEeTg7GAVpe8Mhpl\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.535, \"Energy\": 0.561, \"Loudness\": -11.609, \"Speechiness\": 0.0484, \"Acousticness\": 0.876, \"Liveness\": 0.115, \"Tempo\": 96.103, \"Duration (ms)\": 257773.0, \"Valence\": 0.287, \"Chord\": \"F\"}, {\"Index\": 703, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"closure\", \"Streams\": 11245393, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"35rdVq36LMHQX0Suw9a6tK\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 62.0, \"Danceability\": 0.689, \"Energy\": 0.704, \"Loudness\": -10.813, \"Speechiness\": 0.245, \"Acousticness\": 0.835, \"Liveness\": 0.134, \"Tempo\": 151.884, \"Duration (ms)\": 180653.0, \"Valence\": 0.92, \"Chord\": \"A\"}, {\"Index\": 704, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"She Knows This\", \"Streams\": 10561183, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"1xzUQMiCoY5pdego0pHMeV\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.39, \"Energy\": 0.724, \"Loudness\": -7.607, \"Speechiness\": 0.0889, \"Acousticness\": 0.162, \"Liveness\": 0.393, \"Tempo\": 165.945, \"Duration (ms)\": 216560.0, \"Valence\": 0.312, \"Chord\": \"F#/Gb\"}, {\"Index\": 705, \"Highest Charting Position\": 97, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Another Day\", \"Streams\": 8901697, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"6myUpr3GDR80Dg3zqNTmmG\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 63.0, \"Danceability\": 0.646, \"Energy\": 0.758, \"Loudness\": -7.75, \"Speechiness\": 0.0708, \"Acousticness\": 0.556, \"Liveness\": 0.335, \"Tempo\": 172.995, \"Duration (ms)\": 199787.0, \"Valence\": 0.0642, \"Chord\": \"E\"}, {\"Index\": 706, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Solo Dolo, Pt. III\", \"Streams\": 7655623, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"27oVCAziETRbNuo5A8LNpg\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 61.0, \"Danceability\": 0.589, \"Energy\": 0.727, \"Loudness\": -6.907, \"Speechiness\": 0.0866, \"Acousticness\": 0.239, \"Liveness\": 0.164, \"Tempo\": 152.058, \"Duration (ms)\": 242267.0, \"Valence\": 0.52, \"Chord\": \"A#/Bb\"}, {\"Index\": 707, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Dive\", \"Streams\": 7524738, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"7Hc3YL8oDiAzbiAW32KXrw\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 60.0, \"Danceability\": 0.64, \"Energy\": 0.621, \"Loudness\": -8.269, \"Speechiness\": 0.0679, \"Acousticness\": 0.67, \"Liveness\": 0.36, \"Tempo\": 123.105, \"Duration (ms)\": 148707.0, \"Valence\": 0.332, \"Chord\": \"A\"}, {\"Index\": 708, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Heaven On Earth\", \"Streams\": 7117347, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"2koUj1Fn5TKFEkChSmBPIb\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 59.0, \"Danceability\": 0.786, \"Energy\": 0.61, \"Loudness\": -6.736, \"Speechiness\": 0.0558, \"Acousticness\": 0.379, \"Liveness\": 0.0765, \"Tempo\": 130.036, \"Duration (ms)\": 201093.0, \"Valence\": 0.228, \"Chord\": \"C\"}, {\"Index\": 709, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Sad People\", \"Streams\": 6865689, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"4nuAslShoN77tq12fzwjUq\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 62.0, \"Danceability\": 0.636, \"Energy\": 0.647, \"Loudness\": -6.971, \"Speechiness\": 0.0381, \"Acousticness\": 0.247, \"Liveness\": 0.113, \"Tempo\": 158.073, \"Duration (ms)\": 176027.0, \"Valence\": 0.416, \"Chord\": \"F\"}, {\"Index\": 710, \"Highest Charting Position\": 152, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Damaged\", \"Streams\": 6763705, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"2n7Ao4nyESBa5ti8gcAbBt\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 57.0, \"Danceability\": 0.625, \"Energy\": 0.581, \"Loudness\": -7.1, \"Speechiness\": 0.0316, \"Acousticness\": 0.553, \"Liveness\": 0.254, \"Tempo\": 142.04, \"Duration (ms)\": 150853.0, \"Valence\": 0.267, \"Chord\": \"G#/Ab\"}, {\"Index\": 711, \"Highest Charting Position\": 17, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"YO VISTO AS\\u00cd\", \"Streams\": 6388079, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5fROvzNghPid8mbKNDYvpJ\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 73.0, \"Danceability\": 0.688, \"Energy\": 0.881, \"Loudness\": -4.889, \"Speechiness\": 0.0474, \"Acousticness\": 0.0947, \"Liveness\": 0.0804, \"Tempo\": 123.013, \"Duration (ms)\": 191526.0, \"Valence\": 0.677, \"Chord\": \"G\"}, {\"Index\": 712, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Beautiful Trip\", \"Streams\": 6108393, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"4IIuCotvqijraSdnVLaFnM\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 54.0, \"Danceability\": 0.331, \"Energy\": 0.513, \"Loudness\": -15.392, \"Speechiness\": 0.632, \"Acousticness\": 0.972, \"Liveness\": 0.882, \"Tempo\": 133.971, \"Duration (ms)\": 37013.0, \"Valence\": 0.42, \"Chord\": \"B\"}, {\"Index\": 713, \"Highest Charting Position\": 185, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"The Void\", \"Streams\": 6068816, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"2yg7MXp8nSPaf61HVkhEr3\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 61.0, \"Danceability\": 0.464, \"Energy\": 0.459, \"Loudness\": -8.736, \"Speechiness\": 0.0314, \"Acousticness\": 0.365, \"Liveness\": 0.117, \"Tempo\": 142.017, \"Duration (ms)\": 325413.0, \"Valence\": 0.0786, \"Chord\": \"G\"}, {\"Index\": 714, \"Highest Charting Position\": 1, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"cardigan\", \"Streams\": 5845457, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"4R2kfaDFhslZEMJqAFNpdd\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-12-11--2020-12-18\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 79.0, \"Danceability\": 0.613, \"Energy\": 0.581, \"Loudness\": -8.588, \"Speechiness\": 0.0424, \"Acousticness\": 0.537, \"Liveness\": 0.25, \"Tempo\": 130.033, \"Duration (ms)\": 239560.0, \"Valence\": 0.551, \"Chord\": \"C\"}, {\"Index\": 715, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Real Shit (with benny blanco)\", \"Streams\": 9325928, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"3uVPLtkmDu8pDkYEAVqbgS\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-12-02\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 70.0, \"Danceability\": 0.703, \"Energy\": 0.703, \"Loudness\": -4.672, \"Speechiness\": 0.133, \"Acousticness\": 0.605, \"Liveness\": 0.12, \"Tempo\": 76.017, \"Duration (ms)\": 183783.0, \"Valence\": 0.697, \"Chord\": \"C#/Db\"}, {\"Index\": 716, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Teach Me How To Love\", \"Streams\": 7932101, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 33893352.0, \"Song ID\": \"5LZtB6nxvjIhUoElp3Zqk0\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 68.0, \"Danceability\": 0.592, \"Energy\": 0.885, \"Loudness\": -4.944, \"Speechiness\": 0.0807, \"Acousticness\": 0.0505, \"Liveness\": 0.0843, \"Tempo\": 98.991, \"Duration (ms)\": 202357.0, \"Valence\": 0.731, \"Chord\": \"A\"}, {\"Index\": 717, \"Highest Charting Position\": 138, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Blinding Lights (with ROSAL\\u00cdA) - Remix\", \"Streams\": 6653913, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"7MXgrcOQAJ5VwSNUL0lDd3\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 64.0, \"Danceability\": 0.49, \"Energy\": 0.694, \"Loudness\": -5.793, \"Speechiness\": 0.0618, \"Acousticness\": 0.0133, \"Liveness\": 0.0946, \"Tempo\": 170.903, \"Duration (ms)\": 216123.0, \"Valence\": 0.249, \"Chord\": \"F\"}, {\"Index\": 718, \"Highest Charting Position\": 15, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"WHATS POPPIN (feat. DaBaby, Tory Lanez & Lil Wayne) - Remix\", \"Streams\": 6567755, \"Artist\": \"Tory Lanez, Jack Harlow\", \"Artist Followers\": 3828418.0, \"Song ID\": \"2MbdDtCv5LUVjYy9RuGTgC\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-06-24\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 80.0, \"Danceability\": 0.904, \"Energy\": 0.723, \"Loudness\": -5.224, \"Speechiness\": 0.26, \"Acousticness\": 0.0631, \"Liveness\": 0.185, \"Tempo\": 145.013, \"Duration (ms)\": 227478.0, \"Valence\": 0.835, \"Chord\": \"B\"}, {\"Index\": 719, \"Highest Charting Position\": 29, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"TE DESEO LO MEJOR\", \"Streams\": 6204228, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"23XjN1s3DZC8Q9ZwuorYY4\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.763, \"Energy\": 0.597, \"Loudness\": -5.054, \"Speechiness\": 0.0416, \"Acousticness\": 0.158, \"Liveness\": 0.111, \"Tempo\": 126.054, \"Duration (ms)\": 139576.0, \"Valence\": 0.194, \"Chord\": \"C#/Db\"}, {\"Index\": 720, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Errbody\", \"Streams\": 5929516, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"6eVxH9Kyanzrw636zJRPcw\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-12-03\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 68.0, \"Danceability\": 0.887, \"Energy\": 0.606, \"Loudness\": -6.572, \"Speechiness\": 0.324, \"Acousticness\": 0.000407, \"Liveness\": 0.151, \"Tempo\": 139.995, \"Duration (ms)\": 210699.0, \"Valence\": 0.272, \"Chord\": \"D\"}, {\"Index\": 721, \"Highest Charting Position\": 86, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"Angels Like You\", \"Streams\": 5884221, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"1daDRI9ahBonbWD8YcxOIB\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 77.0, \"Danceability\": 0.672, \"Energy\": 0.642, \"Loudness\": -4.035, \"Speechiness\": 0.0313, \"Acousticness\": 0.0981, \"Liveness\": 0.1, \"Tempo\": 121.981, \"Duration (ms)\": 196453.0, \"Valence\": 0.494, \"Chord\": \"F\"}, {\"Index\": 722, \"Highest Charting Position\": 18, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Blue & Grey\", \"Streams\": 5698275, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"0n2moJpAEWHwaPYYjkzMDl\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 77.0, \"Danceability\": 0.547, \"Energy\": 0.605, \"Loudness\": -6.755, \"Speechiness\": 0.0415, \"Acousticness\": 0.42, \"Liveness\": 0.125, \"Tempo\": 121.953, \"Duration (ms)\": 254950.0, \"Valence\": 0.364, \"Chord\": \"G#/Ab\"}, {\"Index\": 723, \"Highest Charting Position\": 46, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Mad at Disney\", \"Streams\": 5436450, \"Artist\": \"salem ilese\", \"Artist Followers\": 133998.0, \"Song ID\": \"7aGyRfJWtLqgJaZoG9lJhE\", \"Genre\": \"['alt z', 'modern indie pop', 'social media pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 76.0, \"Danceability\": 0.738, \"Energy\": 0.621, \"Loudness\": -7.313, \"Speechiness\": 0.0486, \"Acousticness\": 0.424, \"Liveness\": 0.692, \"Tempo\": 113.968, \"Duration (ms)\": 136839.0, \"Valence\": 0.715, \"Chord\": \"C\"}, {\"Index\": 724, \"Highest Charting Position\": 9, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Safaera\", \"Streams\": 5390363, \"Artist\": \"Bad Bunny, Jowell & Randy, \\u00d1engo Flow\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2DEZmgHKAvm41k4J3R2E9Y\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 79.0, \"Danceability\": 0.607, \"Energy\": 0.829, \"Loudness\": -4.074, \"Speechiness\": 0.379, \"Acousticness\": 0.0103, \"Liveness\": 0.107, \"Tempo\": 96.172, \"Duration (ms)\": 295177.0, \"Valence\": 0.685, \"Chord\": \"D\"}, {\"Index\": 725, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"LA DROGA\", \"Streams\": 5375449, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"67ACYA3UI6QMNtHX6b34wX\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.643, \"Energy\": 0.727, \"Loudness\": -5.506, \"Speechiness\": 0.0389, \"Acousticness\": 0.0439, \"Liveness\": 0.123, \"Tempo\": 90.019, \"Duration (ms)\": 162299.0, \"Valence\": 0.295, \"Chord\": \"C#/Db\"}, {\"Index\": 726, \"Highest Charting Position\": 60, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"GO (feat. Juice WRLD)\", \"Streams\": 5370330, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"2rPHUAeUPbNgTmK18FPTiZ\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-06--2020-11-13\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 78.0, \"Danceability\": 0.487, \"Energy\": 0.74, \"Loudness\": -4.973, \"Speechiness\": 0.0944, \"Acousticness\": 0.157, \"Liveness\": 0.612, \"Tempo\": 73.779, \"Duration (ms)\": 181688.0, \"Valence\": 0.522, \"Chord\": \"F#/Gb\"}, {\"Index\": 727, \"Highest Charting Position\": 180, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"Jenny (I Wanna Ruin Our Friendship)\", \"Streams\": 5364223, \"Artist\": \"Studio Killers\", \"Artist Followers\": 181236.0, \"Song ID\": \"4JLBDUYSaOMPYND0iWeSWQ\", \"Genre\": \"[]\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 72.0, \"Danceability\": 0.668, \"Energy\": 0.798, \"Loudness\": -5.701, \"Speechiness\": 0.0334, \"Acousticness\": 0.00305, \"Liveness\": 0.277, \"Tempo\": 133.928, \"Duration (ms)\": 215280.0, \"Valence\": 0.575, \"Chord\": \"B\"}, {\"Index\": 728, \"Highest Charting Position\": 35, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Mood (Remix) feat. Justin Bieber, J Balvin & iann dior\", \"Streams\": 5314734, \"Artist\": \"24kGoldn\", \"Artist Followers\": 1276406.0, \"Song ID\": \"6FuGJB290AQMAHTfjOYVaK\", \"Genre\": \"['cali rap']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 77.0, \"Danceability\": 0.721, \"Energy\": 0.745, \"Loudness\": -3.508, \"Speechiness\": 0.0366, \"Acousticness\": 0.151, \"Liveness\": 0.372, \"Tempo\": 90.988, \"Duration (ms)\": 192745.0, \"Valence\": 0.699, \"Chord\": \"G\"}, {\"Index\": 729, \"Highest Charting Position\": 41, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"HOY COBR\\u00c9\", \"Streams\": 12914431, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0tjZv2hChdHZCW1zFXpy1J\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.86, \"Energy\": 0.725, \"Loudness\": -6.7, \"Speechiness\": 0.249, \"Acousticness\": 0.0464, \"Liveness\": 0.0994, \"Tempo\": 145.001, \"Duration (ms)\": 162151.0, \"Valence\": 0.375, \"Chord\": \"B\"}, {\"Index\": 730, \"Highest Charting Position\": 44, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"MALDITA POBREZA\", \"Streams\": 12660806, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0Lsis3LB0XAK6XlTHXaJk2\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 67.0, \"Danceability\": 0.762, \"Energy\": 0.861, \"Loudness\": -4.075, \"Speechiness\": 0.0652, \"Acousticness\": 0.139, \"Liveness\": 0.0956, \"Tempo\": 133.037, \"Duration (ms)\": 213609.0, \"Valence\": 0.588, \"Chord\": \"E\"}, {\"Index\": 731, \"Highest Charting Position\": 48, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"EL MUNDO ES M\\u00cdO\", \"Streams\": 12507010, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"36DHxTW2xdr9GG15T9oK9L\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 67.0, \"Danceability\": 0.716, \"Energy\": 0.522, \"Loudness\": -6.834, \"Speechiness\": 0.0582, \"Acousticness\": 0.166, \"Liveness\": 0.113, \"Tempo\": 76.993, \"Duration (ms)\": 165199.0, \"Valence\": 0.224, \"Chord\": \"F\"}, {\"Index\": 732, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"ANTES QUE SE ACABE\", \"Streams\": 11298839, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"7kjEqI6eZ7YlFrGhxixnlN\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 76.0, \"Danceability\": 0.693, \"Energy\": 0.549, \"Loudness\": -6.098, \"Speechiness\": 0.0577, \"Acousticness\": 0.505, \"Liveness\": 0.324, \"Tempo\": 139.988, \"Duration (ms)\": 221187.0, \"Valence\": 0.473, \"Chord\": \"D\"}, {\"Index\": 733, \"Highest Charting Position\": 59, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"SORRY PAPI\", \"Streams\": 11066606, \"Artist\": \"Bad Bunny, ABRA\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5jZ32WOU7sqzDYbzINwMUk\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.612, \"Energy\": 0.561, \"Loudness\": -6.054, \"Speechiness\": 0.0851, \"Acousticness\": 0.0601, \"Liveness\": 0.145, \"Tempo\": 191.911, \"Duration (ms)\": 163053.0, \"Valence\": 0.393, \"Chord\": \"C#/Db\"}, {\"Index\": 734, \"Highest Charting Position\": 63, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"120\", \"Streams\": 10957181, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3KJ3opyV29269SXkPrc19l\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 72.0, \"Danceability\": 0.636, \"Energy\": 0.656, \"Loudness\": -5.542, \"Speechiness\": 0.0676, \"Acousticness\": 0.451, \"Liveness\": 0.287, \"Tempo\": 171.918, \"Duration (ms)\": 151506.0, \"Valence\": 0.439, \"Chord\": \"D\"}, {\"Index\": 735, \"Highest Charting Position\": 66, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"TRELLAS\", \"Streams\": 10733416, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"09WAnxdBuebQopKhJT3oZS\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 66.0, \"Danceability\": 0.43, \"Energy\": 0.412, \"Loudness\": -5.372, \"Speechiness\": 0.0281, \"Acousticness\": 0.2, \"Liveness\": 0.324, \"Tempo\": 90.872, \"Duration (ms)\": 157673.0, \"Valence\": 0.0508, \"Chord\": \"D\"}, {\"Index\": 736, \"Highest Charting Position\": 83, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"Wonderful Christmastime [Edited Version] - Remastered 2011 / Edited Version\", \"Streams\": 9624871, \"Artist\": \"Paul McCartney\", \"Artist Followers\": 3609658.0, \"Song ID\": \"1SV1fxF65n9NhRHp3KlBuu\", \"Genre\": \"['album rock', 'art rock', 'beatlesque', 'classic rock', 'mellow gold', 'rock', 'soft rock']\", \"Release Date\": \"1980-05-16\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 51.0, \"Danceability\": 0.774, \"Energy\": 0.511, \"Loudness\": -8.914, \"Speechiness\": 0.0319, \"Acousticness\": 0.322, \"Liveness\": 0.0672, \"Tempo\": 94.736, \"Duration (ms)\": 227653.0, \"Valence\": 0.771, \"Chord\": \"B\"}, {\"Index\": 737, \"Highest Charting Position\": 16, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Fly To My Room\", \"Streams\": 8413330, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3QH8rQGNFX8VLbCgZ7uPTS\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 76.0, \"Danceability\": 0.764, \"Energy\": 0.526, \"Loudness\": -7.355, \"Speechiness\": 0.212, \"Acousticness\": 0.0484, \"Liveness\": 0.0718, \"Tempo\": 114.91, \"Duration (ms)\": 222243.0, \"Valence\": 0.588, \"Chord\": \"B\"}, {\"Index\": 738, \"Highest Charting Position\": 24, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Telepathy\", \"Streams\": 7703744, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"2FVpOsjT1iquZ3SpCjZ9Ne\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 77.0, \"Danceability\": 0.787, \"Energy\": 0.669, \"Loudness\": -4.333, \"Speechiness\": 0.0428, \"Acousticness\": 0.00782, \"Liveness\": 0.123, \"Tempo\": 104.994, \"Duration (ms)\": 202313.0, \"Valence\": 0.57, \"Chord\": \"F\"}, {\"Index\": 739, \"Highest Charting Position\": 26, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Dis-ease\", \"Streams\": 7165808, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"54DmTIv86D3sYdiawjULQ0\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 75.0, \"Danceability\": 0.731, \"Energy\": 0.845, \"Loudness\": -5.352, \"Speechiness\": 0.132, \"Acousticness\": 0.0132, \"Liveness\": 0.0782, \"Tempo\": 101.085, \"Duration (ms)\": 239722.0, \"Valence\": 0.484, \"Chord\": \"G#/Ab\"}, {\"Index\": 740, \"Highest Charting Position\": 27, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Stay\", \"Streams\": 7010227, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3ndCsZfq8OVwwkz9mmZvUz\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 76.0, \"Danceability\": 0.582, \"Energy\": 0.693, \"Loudness\": -5.048, \"Speechiness\": 0.0465, \"Acousticness\": 0.114, \"Liveness\": 0.13, \"Tempo\": 125.904, \"Duration (ms)\": 204800.0, \"Valence\": 0.341, \"Chord\": \"F#/Gb\"}, {\"Index\": 741, \"Highest Charting Position\": 151, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Heart Of Glass (Live from the iHeart Festival)\", \"Streams\": 6006877, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"5i7ThJfYLAzp2DyZuFpF6j\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-09-29\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 71.0, \"Danceability\": 0.58, \"Energy\": 0.908, \"Loudness\": -5.303, \"Speechiness\": 0.0341, \"Acousticness\": 0.000335, \"Liveness\": 0.087, \"Tempo\": 115.016, \"Duration (ms)\": 213672.0, \"Valence\": 0.427, \"Chord\": \"E\"}, {\"Index\": 742, \"Highest Charting Position\": 171, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"CANTARES DE NAVIDAD\", \"Streams\": 5842320, \"Artist\": \"Trio Vegabaje\\u00f1o\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2Iv6YBslkxslMJQsxshZh5\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 56.0, \"Danceability\": 0.764, \"Energy\": 0.523, \"Loudness\": -7.371, \"Speechiness\": 0.0406, \"Acousticness\": 0.777, \"Liveness\": 0.352, \"Tempo\": 118.671, \"Duration (ms)\": 199720.0, \"Valence\": 0.962, \"Chord\": \"D\"}, {\"Index\": 743, \"Highest Charting Position\": 172, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"Plastic Hearts\", \"Streams\": 5816739, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"6qCsKKS7Ol63SJW3LOIX5R\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 74.0, \"Danceability\": 0.551, \"Energy\": 0.756, \"Loudness\": -4.948, \"Speechiness\": 0.0652, \"Acousticness\": 0.0511, \"Liveness\": 0.0765, \"Tempo\": 175.984, \"Duration (ms)\": 205733.0, \"Valence\": 0.618, \"Chord\": \"D\"}, {\"Index\": 744, \"Highest Charting Position\": 63, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"C\\u00d3MO SE SIENTE - Remix\", \"Streams\": 5463964, \"Artist\": \"Jhay Cortez, Bad Bunny\", \"Artist Followers\": 2435159.0, \"Song ID\": \"2tFwfmceQa1Y6nRPhYbEtC\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-09\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 81.0, \"Danceability\": 0.807, \"Energy\": 0.606, \"Loudness\": -8.871, \"Speechiness\": 0.088, \"Acousticness\": 0.0946, \"Liveness\": 0.119, \"Tempo\": 92.988, \"Duration (ms)\": 227520.0, \"Valence\": 0.304, \"Chord\": \"D#/Eb\"}, {\"Index\": 745, \"Highest Charting Position\": 78, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Skit\", \"Streams\": 8392247, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4GVwjLRT7oSsKby7Vy8EHr\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 60.0, \"Danceability\": 0.703, \"Energy\": 0.321, \"Loudness\": -13.135, \"Speechiness\": 0.884, \"Acousticness\": 0.864, \"Liveness\": 0.908, \"Tempo\": 114.822, \"Duration (ms)\": 179548.0, \"Valence\": 0.544, \"Chord\": \"E\"}, {\"Index\": 746, \"Highest Charting Position\": 105, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Baby (with J Balvin)\", \"Streams\": 7276896, \"Artist\": \"Sfera Ebbasta\", \"Artist Followers\": 4430628.0, \"Song ID\": \"3eblNP3Zd5b5J3JaOckl8Y\", \"Genre\": \"['italian hip hop', 'italian pop', 'trap italiana']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 69.0, \"Danceability\": 0.755, \"Energy\": 0.882, \"Loudness\": -1.957, \"Speechiness\": 0.0532, \"Acousticness\": 0.125, \"Liveness\": 0.103, \"Tempo\": 99.984, \"Duration (ms)\": 193555.0, \"Valence\": 0.606, \"Chord\": \"A#/Bb\"}, {\"Index\": 747, \"Highest Charting Position\": 82, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Tick Tock (feat. 24kGoldn)\", \"Streams\": 6241923, \"Artist\": \"Clean Bandit, Mabel\", \"Artist Followers\": 4431309.0, \"Song ID\": \"27u7t9d7ZQoyjsCROHuZJ3\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk dance', 'uk funky']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 78.0, \"Danceability\": 0.779, \"Energy\": 0.705, \"Loudness\": -3.895, \"Speechiness\": 0.0344, \"Acousticness\": 0.369, \"Liveness\": 0.124, \"Tempo\": 101.022, \"Duration (ms)\": 178374.0, \"Valence\": 0.946, \"Chord\": \"C\"}, {\"Index\": 748, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Dime C\\u00f3mo Quieres\", \"Streams\": 6152821, \"Artist\": \"Christian Nodal, \\u00c1ngela Aguilar\", \"Artist Followers\": 8123757.0, \"Song ID\": \"4jcxBTrNvyqMJdMDyyjdYV\", \"Genre\": \"['mariachi', 'nuevo regional mexicano', 'ranchera', 'regional mexican']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 75.0, \"Danceability\": 0.839, \"Energy\": 0.667, \"Loudness\": -3.961, \"Speechiness\": 0.031, \"Acousticness\": 0.322, \"Liveness\": 0.244, \"Tempo\": 124.889, \"Duration (ms)\": 171360.0, \"Valence\": 0.878, \"Chord\": \"B\"}, {\"Index\": 749, \"Highest Charting Position\": 162, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Tik Tok (feat. Marracash & Gu\\u00e8 Pequeno)\", \"Streams\": 5504912, \"Artist\": \"Sfera Ebbasta\", \"Artist Followers\": 4430628.0, \"Song ID\": \"3tkYK45AZC0PqJ7MSe6IyJ\", \"Genre\": \"['italian hip hop', 'italian pop', 'trap italiana']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 59.0, \"Danceability\": 0.723, \"Energy\": 0.673, \"Loudness\": -7.636, \"Speechiness\": 0.137, \"Acousticness\": 0.0985, \"Liveness\": 0.323, \"Tempo\": 120.046, \"Duration (ms)\": 230389.0, \"Valence\": 0.302, \"Chord\": \"A\"}, {\"Index\": 750, \"Highest Charting Position\": 88, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Jerusalema (feat. Nomcebo Zikode)\", \"Streams\": 5362508, \"Artist\": \"Master KG\", \"Artist Followers\": 247480.0, \"Song ID\": \"2MlOUXmcofMackX3bxfSwi\", \"Genre\": \"['south african house']\", \"Release Date\": \"2020-01-24\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 78.0, \"Danceability\": 0.88, \"Energy\": 0.483, \"Loudness\": -7.012, \"Speechiness\": 0.0505, \"Acousticness\": 0.0185, \"Liveness\": 0.0607, \"Tempo\": 124.009, \"Duration (ms)\": 342613.0, \"Valence\": 0.827, \"Chord\": \"C#/Db\"}, {\"Index\": 751, \"Highest Charting Position\": 19, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Agua (with J Balvin) - Music From \\\"Sponge On The Run\\\" Movie\", \"Streams\": 5358940, \"Artist\": \"Tainy\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 752, \"Highest Charting Position\": 174, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Abracadabra (feat. Future)\", \"Streams\": 5263469, \"Artist\": \"Sfera Ebbasta\", \"Artist Followers\": 4430628.0, \"Song ID\": \"2GuLouaDNgLGxdJoe0vYf6\", \"Genre\": \"['italian hip hop', 'italian pop', 'trap italiana']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 55.0, \"Danceability\": 0.846, \"Energy\": 0.681, \"Loudness\": -7.091, \"Speechiness\": 0.174, \"Acousticness\": 0.0461, \"Liveness\": 0.112, \"Tempo\": 131.988, \"Duration (ms)\": 192965.0, \"Valence\": 0.809, \"Chord\": \"F\"}, {\"Index\": 753, \"Highest Charting Position\": 36, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Djadja (feat. Maluma) - Remix\", \"Streams\": 5203423, \"Artist\": \"Aya Nakamura\", \"Artist Followers\": 2953525.0, \"Song ID\": \"6AzKhCHOms83jvNVLsz0Bt\", \"Genre\": \"['basshall', 'francoton']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 72.0, \"Danceability\": 0.791, \"Energy\": 0.682, \"Loudness\": -7.328, \"Speechiness\": 0.158, \"Acousticness\": 0.175, \"Liveness\": 0.0926, \"Tempo\": 98.031, \"Duration (ms)\": 166851.0, \"Valence\": 0.672, \"Chord\": \"F\"}, {\"Index\": 754, \"Highest Charting Position\": 140, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"ALWAYS DO\", \"Streams\": 5196635, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"3QCU8BT0zDS9LPVfEhRFEE\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 76.0, \"Danceability\": 0.762, \"Energy\": 0.426, \"Loudness\": -6.865, \"Speechiness\": 0.113, \"Acousticness\": 0.0442, \"Liveness\": 0.0858, \"Tempo\": 167.827, \"Duration (ms)\": 151705.0, \"Valence\": 0.582, \"Chord\": \"G#/Ab\"}, {\"Index\": 755, \"Highest Charting Position\": 7, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Smile (with The Weeknd)\", \"Streams\": 5164187, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"6wQlQrTY5mVS8EGaFZVwVF\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 75.0, \"Danceability\": 0.694, \"Energy\": 0.685, \"Loudness\": -6.535, \"Speechiness\": 0.133, \"Acousticness\": 0.224, \"Liveness\": 0.124, \"Tempo\": 158.831, \"Duration (ms)\": 196180.0, \"Valence\": 0.306, \"Chord\": \"F#/Gb\"}, {\"Index\": 756, \"Highest Charting Position\": 22, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Pretty Savage\", \"Streams\": 5039047, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"1XnpzbOGptRwfJhZgLbmSr\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 75.0, \"Danceability\": 0.701, \"Energy\": 0.556, \"Loudness\": -7.42, \"Speechiness\": 0.0414, \"Acousticness\": 0.00886, \"Liveness\": 0.106, \"Tempo\": 152.045, \"Duration (ms)\": 201122.0, \"Valence\": 0.333, \"Chord\": \"A\"}, {\"Index\": 757, \"Highest Charting Position\": 41, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Savage Love (Laxed \\u2013 Siren Beat) [BTS Remix]\", \"Streams\": 4995203, \"Artist\": \"Jawsh 685, Jason Derulo\", \"Artist Followers\": 100635.0, \"Song ID\": \"4TgxFMOn5yoESW6zCidCXL\", \"Genre\": \"['nz pop']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 76.0, \"Danceability\": 0.758, \"Energy\": 0.598, \"Loudness\": -5.695, \"Speechiness\": 0.0868, \"Acousticness\": 0.16, \"Liveness\": 0.295, \"Tempo\": 149.836, \"Duration (ms)\": 184905.0, \"Valence\": 0.658, \"Chord\": \"C\"}, {\"Index\": 758, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Mirrors\", \"Streams\": 4988571, \"Artist\": \"Justin Timberlake\", \"Artist Followers\": 11034144.0, \"Song ID\": \"4rHZZAmHpZrA3iH5zx8frV\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2013-03-15\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 78.0, \"Danceability\": 0.574, \"Energy\": 0.512, \"Loudness\": -6.664, \"Speechiness\": 0.0503, \"Acousticness\": 0.234, \"Liveness\": 0.0946, \"Tempo\": 76.899, \"Duration (ms)\": 484147.0, \"Valence\": 0.512, \"Chord\": \"F\"}, {\"Index\": 759, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Hollywood (feat. Diplo)\", \"Streams\": 4920218, \"Artist\": \"Sfera Ebbasta\", \"Artist Followers\": 4430628.0, \"Song ID\": \"0WXU7I74NEN1DMLIT406Wx\", \"Genre\": \"['italian hip hop', 'italian pop', 'trap italiana']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 63.0, \"Danceability\": 0.848, \"Energy\": 0.708, \"Loudness\": -6.336, \"Speechiness\": 0.0366, \"Acousticness\": 0.153, \"Liveness\": 0.0948, \"Tempo\": 137.973, \"Duration (ms)\": 191869.0, \"Valence\": 0.926, \"Chord\": \"D\"}, {\"Index\": 760, \"Highest Charting Position\": 24, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Runnin\", \"Streams\": 4914682, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"5SWnsxjhdcEDc7LJjq9UHk\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 78.0, \"Danceability\": 0.819, \"Energy\": 0.626, \"Loudness\": -4.574, \"Speechiness\": 0.202, \"Acousticness\": 0.00748, \"Liveness\": 0.167, \"Tempo\": 143.01, \"Duration (ms)\": 195906.0, \"Valence\": 0.415, \"Chord\": \"A#/Bb\"}, {\"Index\": 761, \"Highest Charting Position\": 105, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Are You Bored Yet? (feat. Clairo)\", \"Streams\": 4911995, \"Artist\": \"Wallows\", \"Artist Followers\": 1963296.0, \"Song ID\": \"57RA3JGafJm5zRtKJiKPIm\", \"Genre\": \"['indie pop', 'modern rock', 'pop', 'rock']\", \"Release Date\": \"2019-03-22\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 81.0, \"Danceability\": 0.682, \"Energy\": 0.683, \"Loudness\": -6.444, \"Speechiness\": 0.0287, \"Acousticness\": 0.156, \"Liveness\": 0.273, \"Tempo\": 120.023, \"Duration (ms)\": 178000.0, \"Valence\": 0.64, \"Chord\": \"G#/Ab\"}, {\"Index\": 762, \"Highest Charting Position\": 44, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"10,000 Hours (with Justin Bieber)\", \"Streams\": 4911749, \"Artist\": \"Dan + Shay\", \"Artist Followers\": 2334615.0, \"Song ID\": \"2wrJq5XKLnmhRXHIAf9xBa\", \"Genre\": \"['contemporary country', 'country', 'pop']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.654, \"Energy\": 0.63, \"Loudness\": -4.644, \"Speechiness\": 0.0259, \"Acousticness\": 0.153, \"Liveness\": 0.111, \"Tempo\": 89.991, \"Duration (ms)\": 167693.0, \"Valence\": 0.43, \"Chord\": \"A#/Bb\"}, {\"Index\": 763, \"Highest Charting Position\": 87, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"You Got It\", \"Streams\": 4907925, \"Artist\": \"Vedo\", \"Artist Followers\": 260236.0, \"Song ID\": \"4lsHZ92XCFOQfzJFBTluk8\", \"Genre\": \"['pop r&b', 'r&b']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 79.0, \"Danceability\": 0.762, \"Energy\": 0.433, \"Loudness\": -8.937, \"Speechiness\": 0.187, \"Acousticness\": 0.143, \"Liveness\": 0.118, \"Tempo\": 122.074, \"Duration (ms)\": 203145.0, \"Valence\": 0.394, \"Chord\": \"F\"}, {\"Index\": 764, \"Highest Charting Position\": 129, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Qui\\u00e9reme Mientras Se Pueda\", \"Streams\": 4899440, \"Artist\": \"Manuel Turizo\", \"Artist Followers\": 7909963.0, \"Song ID\": \"34LI7rwi9H8w2S5KTHnv1M\", \"Genre\": \"['colombian pop', 'latin', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 74.0, \"Danceability\": 0.793, \"Energy\": 0.782, \"Loudness\": -3.945, \"Speechiness\": 0.0582, \"Acousticness\": 0.447, \"Liveness\": 0.124, \"Tempo\": 143.86, \"Duration (ms)\": 191945.0, \"Valence\": 0.81, \"Chord\": \"E\"}, {\"Index\": 765, \"Highest Charting Position\": 9, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Party Girl\", \"Streams\": 4878286, \"Artist\": \"StaySolidRocky\", \"Artist Followers\": 150587.0, \"Song ID\": \"5RqR4ZCCKJDcBLIn4sih9l\", \"Genre\": \"['melodic rap']\", \"Release Date\": \"2020-04-21\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 77.0, \"Danceability\": 0.728, \"Energy\": 0.431, \"Loudness\": -9.966, \"Speechiness\": 0.0622, \"Acousticness\": 0.749, \"Liveness\": 0.0996, \"Tempo\": 130.022, \"Duration (ms)\": 147800.0, \"Valence\": 0.629, \"Chord\": \"F#/Gb\"}, {\"Index\": 766, \"Highest Charting Position\": 95, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Drankin N Smokin\", \"Streams\": 7292247, \"Artist\": \"Future, Lil Uzi Vert\", \"Artist Followers\": 10491105.0, \"Song ID\": \"0k7wmahjkn389wAZdz19Cv\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-11-13--2020-11-20\", \"Popularity\": 78.0, \"Danceability\": 0.752, \"Energy\": 0.658, \"Loudness\": -6.297, \"Speechiness\": 0.342, \"Acousticness\": 0.0421, \"Liveness\": 0.0927, \"Tempo\": 151.951, \"Duration (ms)\": 213520.0, \"Valence\": 0.387, \"Chord\": \"C\"}, {\"Index\": 767, \"Highest Charting Position\": 86, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Be Like That - feat. Swae Lee & Khalid\", \"Streams\": 5929062, \"Artist\": \"Kane Brown\", \"Artist Followers\": 3509653.0, \"Song ID\": \"5f1joOtoMeyppIcJGZQvqJ\", \"Genre\": \"['contemporary country', 'country road']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 79.0, \"Danceability\": 0.727, \"Energy\": 0.626, \"Loudness\": -8.415, \"Speechiness\": 0.0726, \"Acousticness\": 0.0469, \"Liveness\": 0.126, \"Tempo\": 86.97, \"Duration (ms)\": 191406.0, \"Valence\": 0.322, \"Chord\": \"G\"}, {\"Index\": 768, \"Highest Charting Position\": 74, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"MORE\", \"Streams\": 5602168, \"Artist\": \"K/DA, Madison Beer, (G)I-DLE, Lexie Liu, Jaira Burns, Seraphine, League of Legends\", \"Artist Followers\": 1245965.0, \"Song ID\": \"6juLaduD4STCUDWT0AYun4\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2020-10-28\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 73.0, \"Danceability\": 0.66, \"Energy\": 0.787, \"Loudness\": -4.592, \"Speechiness\": 0.032, \"Acousticness\": 0.00257, \"Liveness\": 0.323, \"Tempo\": 142.018, \"Duration (ms)\": 217088.0, \"Valence\": 0.199, \"Chord\": \"C#/Db\"}, {\"Index\": 769, \"Highest Charting Position\": 140, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Enchule\", \"Streams\": 5561227, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6096559.0, \"Song ID\": \"3ThrfRAmijYU098H9q9tAs\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 70.0, \"Danceability\": 0.763, \"Energy\": 0.666, \"Loudness\": -3.316, \"Speechiness\": 0.194, \"Acousticness\": 0.153, \"Liveness\": 0.301, \"Tempo\": 90.086, \"Duration (ms)\": 185719.0, \"Valence\": 0.587, \"Chord\": \"G\"}, {\"Index\": 770, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Stripes Like Burberry\", \"Streams\": 5445204, \"Artist\": \"Future, Lil Uzi Vert\", \"Artist Followers\": 10491105.0, \"Song ID\": \"6lt8iodSkYWEV0ifKCSlfg\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-11-13--2020-11-20\", \"Popularity\": 56.0, \"Danceability\": 0.758, \"Energy\": 0.574, \"Loudness\": -7.833, \"Speechiness\": 0.217, \"Acousticness\": 0.216, \"Liveness\": 0.144, \"Tempo\": 144.081, \"Duration (ms)\": 274313.0, \"Valence\": 0.706, \"Chord\": \"A\"}, {\"Index\": 771, \"Highest Charting Position\": 117, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Papi Chulo\", \"Streams\": 5361669, \"Artist\": \"Octavian, Skepta\", \"Artist Followers\": 213344.0, \"Song ID\": \"6Juv5N0dNU1imms9c9u1dA\", \"Genre\": \"['afroswing', 'london rap', 'uk alternative hip hop', 'uk hip hop']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 73.0, \"Danceability\": 0.866, \"Energy\": 0.563, \"Loudness\": -6.964, \"Speechiness\": 0.108, \"Acousticness\": 0.185, \"Liveness\": 0.0889, \"Tempo\": 127.954, \"Duration (ms)\": 161668.0, \"Valence\": 0.307, \"Chord\": \"B\"}, {\"Index\": 772, \"Highest Charting Position\": 20, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"off the table (with The Weeknd)\", \"Streams\": 5308945, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"7E1jVNoWuemqUryI4FxsVD\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 67.0, \"Danceability\": 0.411, \"Energy\": 0.522, \"Loudness\": -7.295, \"Speechiness\": 0.0981, \"Acousticness\": 0.519, \"Liveness\": 0.398, \"Tempo\": 88.332, \"Duration (ms)\": 239949.0, \"Valence\": 0.382, \"Chord\": \"C\"}, {\"Index\": 773, \"Highest Charting Position\": 52, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Spicy (feat. Post Malone)\", \"Streams\": 5303146, \"Artist\": \"Ty Dolla $ign\", \"Artist Followers\": 3866304.0, \"Song ID\": \"5IUtvfNvOyVYZUa6AJFrnP\", \"Genre\": \"['hip hop', 'pop', 'pop rap', 'r&b', 'southern hip hop', 'trap', 'trap soul']\", \"Release Date\": \"2020-10-23\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 80.0, \"Danceability\": 0.782, \"Energy\": 0.51, \"Loudness\": -5.724, \"Speechiness\": 0.0419, \"Acousticness\": 0.143, \"Liveness\": 0.115, \"Tempo\": 99.993, \"Duration (ms)\": 143375.0, \"Valence\": 0.118, \"Chord\": \"E\"}, {\"Index\": 774, \"Highest Charting Position\": 124, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Sweet Melody\", \"Streams\": 5201322, \"Artist\": \"Little Mix\", \"Artist Followers\": 9398941.0, \"Song ID\": \"76Tuo484SLohJakHLnGI3B\", \"Genre\": \"['dance pop', 'girl group', 'pop', 'post-teen pop', 'talent show', 'uk pop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\", \"Popularity\": 73.0, \"Danceability\": 0.448, \"Energy\": 0.824, \"Loudness\": -4.249, \"Speechiness\": 0.057, \"Acousticness\": 0.0739, \"Liveness\": 0.113, \"Tempo\": 119.965, \"Duration (ms)\": 213693.0, \"Valence\": 0.419, \"Chord\": \"F\"}, {\"Index\": 775, \"Highest Charting Position\": 144, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Blueberry Eyes (feat. SUGA of BTS)\", \"Streams\": 5158896, \"Artist\": \"MAX\", \"Artist Followers\": 689627.0, \"Song ID\": \"5dn6QANKbf76pANGjMBida\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'pop rap', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2020-09-15\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 72.0, \"Danceability\": 0.746, \"Energy\": 0.611, \"Loudness\": -7.034, \"Speechiness\": 0.101, \"Acousticness\": 0.454, \"Liveness\": 0.133, \"Tempo\": 149.967, \"Duration (ms)\": 172245.0, \"Valence\": 0.411, \"Chord\": \"C\"}, {\"Index\": 776, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"That\\u2019s It\", \"Streams\": 5151014, \"Artist\": \"Future, Lil Uzi Vert\", \"Artist Followers\": 10491105.0, \"Song ID\": \"5n6gBhdEjCuj3obgCoTEFD\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-11-13--2020-11-20\", \"Popularity\": 64.0, \"Danceability\": 0.94, \"Energy\": 0.532, \"Loudness\": -5.998, \"Speechiness\": 0.358, \"Acousticness\": 0.12, \"Liveness\": 0.0925, \"Tempo\": 123.043, \"Duration (ms)\": 228796.0, \"Valence\": 0.599, \"Chord\": \"B\"}, {\"Index\": 777, \"Highest Charting Position\": 157, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Promiscuous\", \"Streams\": 5083648, \"Artist\": \"Nelly Furtado, Timbaland\", \"Artist Followers\": 2688557.0, \"Song ID\": \"2gam98EZKrF9XuOkU13ApN\", \"Genre\": \"['canadian latin', 'canadian pop', 'dance pop', 'pop', 'pop rap']\", \"Release Date\": \"2006-01-01\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 82.0, \"Danceability\": 0.808, \"Energy\": 0.97, \"Loudness\": -6.098, \"Speechiness\": 0.0506, \"Acousticness\": 0.0569, \"Liveness\": 0.154, \"Tempo\": 114.328, \"Duration (ms)\": 242293.0, \"Valence\": 0.868, \"Chord\": \"A#/Bb\"}, {\"Index\": 778, \"Highest Charting Position\": 22, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"GREECE (feat. Drake)\", \"Streams\": 5043665, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6281829.0, \"Song ID\": \"35RJhm1pEovTBwnNR0zWad\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-07-16\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 77.0, \"Danceability\": 0.695, \"Energy\": 0.343, \"Loudness\": -10.798, \"Speechiness\": 0.0432, \"Acousticness\": 0.0743, \"Liveness\": 0.107, \"Tempo\": 85.84, \"Duration (ms)\": 218902.0, \"Valence\": 0.229, \"Chord\": \"F\"}, {\"Index\": 779, \"Highest Charting Position\": 25, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"just like magic\", \"Streams\": 4980571, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"7Dx9Z6Aon1qPS2N0rHSWTe\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 69.0, \"Danceability\": 0.719, \"Energy\": 0.607, \"Loudness\": -5.156, \"Speechiness\": 0.165, \"Acousticness\": 0.08, \"Liveness\": 0.125, \"Tempo\": 128.006, \"Duration (ms)\": 149900.0, \"Valence\": 0.464, \"Chord\": \"G#/Ab\"}, {\"Index\": 780, \"Highest Charting Position\": 53, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Still Don't Know My Name\", \"Streams\": 4926802, \"Artist\": \"Labrinth\", \"Artist Followers\": 1685215.0, \"Song ID\": \"6N22FZs2ZhPBYi3b9XPajV\", \"Genre\": \"['indie poptimism', 'pop']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 80.0, \"Danceability\": 0.316, \"Energy\": 0.63, \"Loudness\": -5.963, \"Speechiness\": 0.117, \"Acousticness\": 0.471, \"Liveness\": 0.205, \"Tempo\": 89.643, \"Duration (ms)\": 153294.0, \"Valence\": 0.313, \"Chord\": \"F\"}, {\"Index\": 781, \"Highest Charting Position\": 32, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Hasta Que Dios Diga\", \"Streams\": 4899099, \"Artist\": \"Anuel AA, Bad Bunny\", \"Artist Followers\": 18306226.0, \"Song ID\": \"06s3QtMJVXw1AJX3UfvZG1\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 76.0, \"Danceability\": 0.691, \"Energy\": 0.765, \"Loudness\": -4.727, \"Speechiness\": 0.111, \"Acousticness\": 0.464, \"Liveness\": 0.203, \"Tempo\": 174.021, \"Duration (ms)\": 246000.0, \"Valence\": 0.855, \"Chord\": \"G#/Ab\"}, {\"Index\": 782, \"Highest Charting Position\": 102, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Get You The Moon (feat. Sn\\u00f8w)\", \"Streams\": 4872409, \"Artist\": \"Kina\", \"Artist Followers\": 661863.0, \"Song ID\": \"4ZLzoOkj0MPWrTLvooIuaa\", \"Genre\": \"['sad rap']\", \"Release Date\": \"2018-10-08\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.498, \"Energy\": 0.235, \"Loudness\": -16.541, \"Speechiness\": 0.188, \"Acousticness\": 0.72, \"Liveness\": 0.144, \"Tempo\": 118.917, \"Duration (ms)\": 179080.0, \"Valence\": 0.0895, \"Chord\": \"C#/Db\"}, {\"Index\": 783, \"Highest Charting Position\": 162, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Moonwalking in Calabasas (feat. Blueface) - Remix\", \"Streams\": 4863053, \"Artist\": \"DDG\", \"Artist Followers\": 486194.0, \"Song ID\": \"7o4gBbTM6UBLkOYPw9xMCz\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2020-12-02\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 74.0, \"Danceability\": 0.928, \"Energy\": 0.341, \"Loudness\": -10.196, \"Speechiness\": 0.103, \"Acousticness\": 0.0614, \"Liveness\": 0.162, \"Tempo\": 129.966, \"Duration (ms)\": 170233.0, \"Valence\": 0.745, \"Chord\": \"B\"}, {\"Index\": 784, \"Highest Charting Position\": 29, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Forever After All\", \"Streams\": 4746415, \"Artist\": \"Luke Combs\", \"Artist Followers\": 5371000.0, \"Song ID\": \"6IBcOGPsniK3Pso1wHIhew\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2020-10-23\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 80.0, \"Danceability\": 0.487, \"Energy\": 0.65, \"Loudness\": -5.195, \"Speechiness\": 0.0253, \"Acousticness\": 0.191, \"Liveness\": 0.0933, \"Tempo\": 151.964, \"Duration (ms)\": 232533.0, \"Valence\": 0.456, \"Chord\": \"C\"}, {\"Index\": 785, \"Highest Charting Position\": 76, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Lean (feat. Towy, Osquel, Beltito & Sammy & Falsetto)\", \"Streams\": 4739241, \"Artist\": \"Super Yei, Jone Quest\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 786, \"Highest Charting Position\": 156, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"SLOW DANCING IN THE DARK\", \"Streams\": 4732343, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"0rKtyWc8bvkriBthvHKY8d\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2018-10-26\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-05-08--2020-05-15\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.515, \"Energy\": 0.479, \"Loudness\": -7.458, \"Speechiness\": 0.0261, \"Acousticness\": 0.544, \"Liveness\": 0.191, \"Tempo\": 88.964, \"Duration (ms)\": 209274.0, \"Valence\": 0.284, \"Chord\": \"D#/Eb\"}, {\"Index\": 787, \"Highest Charting Position\": 92, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Don Don\", \"Streams\": 4731423, \"Artist\": \"Daddy Yankee, Anuel AA, Kendo Kaponi\", \"Artist Followers\": 23936368.0, \"Song ID\": \"3kml9ZdpT7UYk1ugkjqOzt\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-11\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 69.0, \"Danceability\": 0.838, \"Energy\": 0.819, \"Loudness\": -4.681, \"Speechiness\": 0.211, \"Acousticness\": 0.285, \"Liveness\": 0.224, \"Tempo\": 105.027, \"Duration (ms)\": 275893.0, \"Valence\": 0.656, \"Chord\": \"F\"}, {\"Index\": 788, \"Highest Charting Position\": 5, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"my future\", \"Streams\": 4721082, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"3YUMWmx8EJq0DurfuIwoGh\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-07-30\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 80.0, \"Danceability\": 0.456, \"Energy\": 0.285, \"Loudness\": -10.755, \"Speechiness\": 0.0979, \"Acousticness\": 0.814, \"Liveness\": 0.307, \"Tempo\": 104.89, \"Duration (ms)\": 210005.0, \"Valence\": 0.0809, \"Chord\": \"G#/Ab\"}, {\"Index\": 789, \"Highest Charting Position\": 163, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Nada\", \"Streams\": 4713873, \"Artist\": \"Cali Y El Dandee, Danna Paola\", \"Artist Followers\": 3152313.0, \"Song ID\": \"4K8cyoCDovlc4FvtUr2Hfx\", \"Genre\": \"['champeta', 'colombian pop', 'electro latino', 'latin', 'latin pop', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 76.0, \"Danceability\": 0.684, \"Energy\": 0.808, \"Loudness\": -2.737, \"Speechiness\": 0.061, \"Acousticness\": 0.0518, \"Liveness\": 0.0858, \"Tempo\": 173.905, \"Duration (ms)\": 174027.0, \"Valence\": 0.712, \"Chord\": \"C\"}, {\"Index\": 790, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"safety net (feat. Ty Dolla $ign)\", \"Streams\": 5798744, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"14gkWVFMwdxBMyqBw1wmIg\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 70.0, \"Danceability\": 0.552, \"Energy\": 0.599, \"Loudness\": -5.75, \"Speechiness\": 0.0404, \"Acousticness\": 0.0703, \"Liveness\": 0.0986, \"Tempo\": 161.884, \"Duration (ms)\": 208457.0, \"Valence\": 0.0916, \"Chord\": \"C#/Db\"}, {\"Index\": 791, \"Highest Charting Position\": 31, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"shut up\", \"Streams\": 5282490, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3ko9jEHNt4O5fjKN65ULJp\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 63.0, \"Danceability\": 0.499, \"Energy\": 0.462, \"Loudness\": -5.308, \"Speechiness\": 0.0312, \"Acousticness\": 0.801, \"Liveness\": 0.0946, \"Tempo\": 127.698, \"Duration (ms)\": 157710.0, \"Valence\": 0.599, \"Chord\": \"C\"}, {\"Index\": 792, \"Highest Charting Position\": 42, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"nasty\", \"Streams\": 5249342, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"0sci7ppTZFm4mjcH3nu8yO\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 69.0, \"Danceability\": 0.772, \"Energy\": 0.506, \"Loudness\": -6.558, \"Speechiness\": 0.139, \"Acousticness\": 0.0814, \"Liveness\": 0.182, \"Tempo\": 127.894, \"Duration (ms)\": 200733.0, \"Valence\": 0.456, \"Chord\": \"F#/Gb\"}, {\"Index\": 793, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"TRAGIC (feat. Youngboy Never Broke Again & Internet Money)\", \"Streams\": 5226940, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"13EW51DKru044OJDJ9Bm8o\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-11-06--2020-11-13\", \"Popularity\": 76.0, \"Danceability\": 0.779, \"Energy\": 0.642, \"Loudness\": -6.321, \"Speechiness\": 0.116, \"Acousticness\": 0.0383, \"Liveness\": 0.2, \"Tempo\": 82.363, \"Duration (ms)\": 153147.0, \"Valence\": 0.388, \"Chord\": \"G#/Ab\"}, {\"Index\": 794, \"Highest Charting Position\": 49, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Ayer Me Llam\\u00f3 Mi Ex (feat. Lenny Santos)\", \"Streams\": 5220504, \"Artist\": \"KHEA\", \"Artist Followers\": 3198705.0, \"Song ID\": \"6C6mUonH6MNdSg5pw7kOc9\", \"Genre\": \"['argentine hip hop', 'trap argentino', 'trap latino', 'trap triste']\", \"Release Date\": \"2020-08-20\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 71.0, \"Danceability\": 0.752, \"Energy\": 0.716, \"Loudness\": -5.2, \"Speechiness\": 0.0325, \"Acousticness\": 0.254, \"Liveness\": 0.243, \"Tempo\": 117.007, \"Duration (ms)\": 206760.0, \"Valence\": 0.553, \"Chord\": \"A#/Bb\"}, {\"Index\": 795, \"Highest Charting Position\": 119, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Madrid (feat. Myke Towers)\", \"Streams\": 5064484, \"Artist\": \"Maluma\", \"Artist Followers\": 26784251.0, \"Song ID\": \"19OXtYzrJyCrQvTbfukt4H\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 73.0, \"Danceability\": 0.764, \"Energy\": 0.741, \"Loudness\": -3.617, \"Speechiness\": 0.101, \"Acousticness\": 0.239, \"Liveness\": 0.107, \"Tempo\": 170.081, \"Duration (ms)\": 198570.0, \"Valence\": 0.802, \"Chord\": \"A\"}, {\"Index\": 796, \"Highest Charting Position\": 85, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Caramelo - Remix\", \"Streams\": 5033798, \"Artist\": \"Ozuna, KAROL G, Myke Towers\", \"Artist Followers\": 29238936.0, \"Song ID\": \"2uu2aGqA2UblCg581Q7l1g\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-08-17\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 72.0, \"Danceability\": 0.754, \"Energy\": 0.796, \"Loudness\": -3.743, \"Speechiness\": 0.139, \"Acousticness\": 0.062, \"Liveness\": 0.204, \"Tempo\": 168.045, \"Duration (ms)\": 233160.0, \"Valence\": 0.62, \"Chord\": \"D#/Eb\"}, {\"Index\": 797, \"Highest Charting Position\": 25, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Mr. Right Now (feat. Drake)\", \"Streams\": 4951481, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"4Q34FP1AT7GEl9oLgNtiWj\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 75.0, \"Danceability\": 0.647, \"Energy\": 0.667, \"Loudness\": -5.563, \"Speechiness\": 0.304, \"Acousticness\": 0.231, \"Liveness\": 0.133, \"Tempo\": 172.08, \"Duration (ms)\": 193839.0, \"Valence\": 0.704, \"Chord\": \"F\"}, {\"Index\": 798, \"Highest Charting Position\": 41, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Got It On Me\", \"Streams\": 4924030, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"25zlnOAzbVoOzIeXSvQFf1\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 78.0, \"Danceability\": 0.688, \"Energy\": 0.647, \"Loudness\": -7.258, \"Speechiness\": 0.19, \"Acousticness\": 0.00815, \"Liveness\": 0.095, \"Tempo\": 88.834, \"Duration (ms)\": 164580.0, \"Valence\": 0.195, \"Chord\": \"D\"}, {\"Index\": 799, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"my hair\", \"Streams\": 4896521, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"6u7gmPOz7pzzaeR9xSBpsR\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 66.0, \"Danceability\": 0.686, \"Energy\": 0.526, \"Loudness\": -6.842, \"Speechiness\": 0.0374, \"Acousticness\": 0.0815, \"Liveness\": 0.144, \"Tempo\": 92.013, \"Duration (ms)\": 158436.0, \"Valence\": 0.372, \"Chord\": \"C\"}, {\"Index\": 800, \"Highest Charting Position\": 59, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"obvious\", \"Streams\": 4865084, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"0q85C1JiECyYIQthz1posA\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 65.0, \"Danceability\": 0.624, \"Energy\": 0.672, \"Loudness\": -5.334, \"Speechiness\": 0.106, \"Acousticness\": 0.0967, \"Liveness\": 0.155, \"Tempo\": 159.852, \"Duration (ms)\": 146959.0, \"Valence\": 0.26, \"Chord\": \"C\"}, {\"Index\": 801, \"Highest Charting Position\": 30, \"Number of Times Charted\": 45, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Beautiful People (feat. Khalid)\", \"Streams\": 4813796, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"4evmHXcjt3bTUHD1cvny97\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.64, \"Energy\": 0.648, \"Loudness\": -8.113, \"Speechiness\": 0.187, \"Acousticness\": 0.124, \"Liveness\": 0.0802, \"Tempo\": 92.977, \"Duration (ms)\": 197867.0, \"Valence\": 0.548, \"Chord\": \"F\"}, {\"Index\": 802, \"Highest Charting Position\": 29, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Favorito\", \"Streams\": 4787127, \"Artist\": \"Camilo\", \"Artist Followers\": 10580764.0, \"Song ID\": \"0Snbzbd74RLfL0i4nn1vU5\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-26\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 73.0, \"Danceability\": 0.611, \"Energy\": 0.851, \"Loudness\": -2.982, \"Speechiness\": 0.0598, \"Acousticness\": 0.229, \"Liveness\": 0.232, \"Tempo\": 178.032, \"Duration (ms)\": 211613.0, \"Valence\": 0.823, \"Chord\": \"A\"}, {\"Index\": 803, \"Highest Charting Position\": 42, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"After Party\", \"Streams\": 4784580, \"Artist\": \"Don Toliver\", \"Artist Followers\": 1606884.0, \"Song ID\": \"527k23H0A4Q0UJN3vGs0Da\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 80.0, \"Danceability\": 0.629, \"Energy\": 0.692, \"Loudness\": -8.045, \"Speechiness\": 0.0376, \"Acousticness\": 0.00981, \"Liveness\": 0.603, \"Tempo\": 162.948, \"Duration (ms)\": 167916.0, \"Valence\": 0.453, \"Chord\": \"F\"}, {\"Index\": 804, \"Highest Charting Position\": 14, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Rojo\", \"Streams\": 4773792, \"Artist\": \"J Balvin\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3zR9JVqHsILrkNyCOqA6jM\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 0.0, \"Danceability\": 0.652, \"Energy\": 0.595, \"Loudness\": -4.04, \"Speechiness\": 0.117, \"Acousticness\": 0.15, \"Liveness\": 0.0836, \"Tempo\": 172.277, \"Duration (ms)\": 151147.0, \"Valence\": 0.421, \"Chord\": \"B\"}, {\"Index\": 805, \"Highest Charting Position\": 51, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"six thirty\", \"Streams\": 10941573, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"2IKJtXeR5UsaUjZB46fTOK\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 63.0, \"Danceability\": 0.739, \"Energy\": 0.516, \"Loudness\": -7.154, \"Speechiness\": 0.0539, \"Acousticness\": 0.67, \"Liveness\": 0.151, \"Tempo\": 120.109, \"Duration (ms)\": 183874.0, \"Valence\": 0.434, \"Chord\": \"C\"}, {\"Index\": 806, \"Highest Charting Position\": 65, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"love language\", \"Streams\": 9399230, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"6NYtLvyThMT0oALFdJFdzq\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 62.0, \"Danceability\": 0.688, \"Energy\": 0.573, \"Loudness\": -5.03, \"Speechiness\": 0.208, \"Acousticness\": 0.0686, \"Liveness\": 0.0749, \"Tempo\": 110.034, \"Duration (ms)\": 179861.0, \"Valence\": 0.553, \"Chord\": \"A#/Bb\"}, {\"Index\": 807, \"Highest Charting Position\": 66, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"west side\", \"Streams\": 9397167, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"1whfVLMKWqAX3uk97VXsNN\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 62.0, \"Danceability\": 0.688, \"Energy\": 0.455, \"Loudness\": -8.632, \"Speechiness\": 0.199, \"Acousticness\": 0.186, \"Liveness\": 0.0794, \"Tempo\": 87.865, \"Duration (ms)\": 132279.0, \"Valence\": 0.557, \"Chord\": \"B\"}, {\"Index\": 808, \"Highest Charting Position\": 146, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Thriller\", \"Streams\": 5605234, \"Artist\": \"Michael Jackson\", \"Artist Followers\": 19345579.0, \"Song ID\": \"7azo4rpSUh8nXgtonC6Pkq\", \"Genre\": \"['pop', 'r&b', 'soul']\", \"Release Date\": \"2017-09-27\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 68.0, \"Danceability\": 0.764, \"Energy\": 0.887, \"Loudness\": -3.726, \"Speechiness\": 0.0744, \"Acousticness\": 0.0816, \"Liveness\": 0.847, \"Tempo\": 118.427, \"Duration (ms)\": 358053.0, \"Valence\": 0.72, \"Chord\": \"B\"}, {\"Index\": 809, \"Highest Charting Position\": 105, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Dancing With A Stranger (with Normani)\", \"Streams\": 5229835, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"6Qs4SXO9dwPj5GKvVOv8Ki\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2019-01-11\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.741, \"Energy\": 0.52, \"Loudness\": -7.513, \"Speechiness\": 0.0656, \"Acousticness\": 0.45, \"Liveness\": 0.222, \"Tempo\": 102.998, \"Duration (ms)\": 171030.0, \"Valence\": 0.347, \"Chord\": \"G#/Ab\"}, {\"Index\": 810, \"Highest Charting Position\": 91, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Angeklagt\", \"Streams\": 5226264, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"5eu4Lxm5TlI0tKSTTDWJAT\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-10-29\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 60.0, \"Danceability\": 0.658, \"Energy\": 0.624, \"Loudness\": -9.155, \"Speechiness\": 0.0915, \"Acousticness\": 0.171, \"Liveness\": 0.116, \"Tempo\": 181.942, \"Duration (ms)\": 168991.0, \"Valence\": 0.314, \"Chord\": \"C#/Db\"}, {\"Index\": 811, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Kids Again\", \"Streams\": 5103194, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"1ABS9lKaZ1uXkXCqr9zFO7\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 62.0, \"Danceability\": 0.666, \"Energy\": 0.726, \"Loudness\": -2.998, \"Speechiness\": 0.0262, \"Acousticness\": 0.486, \"Liveness\": 0.0892, \"Tempo\": 128.044, \"Duration (ms)\": 207528.0, \"Valence\": 0.468, \"Chord\": \"B\"}, {\"Index\": 812, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Highway to Hell\", \"Streams\": 5096618, \"Artist\": \"AC/DC\", \"Artist Followers\": 20110171.0, \"Song ID\": \"2zYzyRzz6pRmhPzyfMEC8s\", \"Genre\": \"['australian rock', 'hard rock', 'rock']\", \"Release Date\": \"1979-07-27\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 83.0, \"Danceability\": 0.574, \"Energy\": 0.913, \"Loudness\": -4.793, \"Speechiness\": 0.133, \"Acousticness\": 0.061, \"Liveness\": 0.156, \"Tempo\": 115.728, \"Duration (ms)\": 208400.0, \"Valence\": 0.423, \"Chord\": \"F#/Gb\"}, {\"Index\": 813, \"Highest Charting Position\": 38, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Me Gusta (with Cardi B & Myke Towers)\", \"Streams\": 4914412, \"Artist\": \"Anitta\", \"Artist Followers\": 10741972.0, \"Song ID\": \"7e1VoRlNumuEkXlITMHKLE\", \"Genre\": \"['funk carioca', 'funk pop', 'pagode baiano', 'pop nacional']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 72.0, \"Danceability\": 0.91, \"Energy\": 0.604, \"Loudness\": -4.392, \"Speechiness\": 0.082, \"Acousticness\": 0.448, \"Liveness\": 0.0863, \"Tempo\": 110.075, \"Duration (ms)\": 180788.0, \"Valence\": 0.807, \"Chord\": \"F#/Gb\"}, {\"Index\": 814, \"Highest Charting Position\": 133, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"24 (feat. Lil Baby)\", \"Streams\": 4904772, \"Artist\": \"Money Man\", \"Artist Followers\": 345027.0, \"Song ID\": \"0xUvi7wldroBzaZCengPa5\", \"Genre\": \"['memphis hip hop', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 74.0, \"Danceability\": 0.868, \"Energy\": 0.638, \"Loudness\": -7.746, \"Speechiness\": 0.0736, \"Acousticness\": 0.146, \"Liveness\": 0.0931, \"Tempo\": 126.03, \"Duration (ms)\": 182857.0, \"Valence\": 0.459, \"Chord\": \"D\"}, {\"Index\": 815, \"Highest Charting Position\": 23, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Relaci\\u00f3n\", \"Streams\": 4825749, \"Artist\": \"Sech\", \"Artist Followers\": 8766508.0, \"Song ID\": \"35UUpTmrcFXNIVIN26ujXl\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-04-10--2020-04-17\", \"Popularity\": 80.0, \"Danceability\": 0.793, \"Energy\": 0.771, \"Loudness\": -3.417, \"Speechiness\": 0.0959, \"Acousticness\": 0.0337, \"Liveness\": 0.284, \"Tempo\": 171.943, \"Duration (ms)\": 247308.0, \"Valence\": 0.835, \"Chord\": \"F\"}, {\"Index\": 816, \"Highest Charting Position\": 14, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"FRANCHISE (feat. Young Thug & M.I.A.)\", \"Streams\": 4821213, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"4jVBIpuOiMj1crqd8LoCrJ\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 74.0, \"Danceability\": 0.835, \"Energy\": 0.699, \"Loudness\": -5.405, \"Speechiness\": 0.277, \"Acousticness\": 0.00671, \"Liveness\": 0.195, \"Tempo\": 154.981, \"Duration (ms)\": 202795.0, \"Valence\": 0.547, \"Chord\": \"G#/Ab\"}, {\"Index\": 817, \"Highest Charting Position\": 11, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Bet You Wanna (feat. Cardi B)\", \"Streams\": 6846771, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"7iAgNZdotu40NwtoIWJHFe\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 67.0, \"Danceability\": 0.653, \"Energy\": 0.662, \"Loudness\": -6.168, \"Speechiness\": 0.162, \"Acousticness\": 0.00465, \"Liveness\": 0.0626, \"Tempo\": 111.712, \"Duration (ms)\": 161168.0, \"Valence\": 0.674, \"Chord\": \"G\"}, {\"Index\": 818, \"Highest Charting Position\": 82, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Wolves (feat. Post Malone)\", \"Streams\": 5547002, \"Artist\": \"Big Sean\", \"Artist Followers\": 8673345.0, \"Song ID\": \"33gwZOGJWEZ7dRWPqPxBEZ\", \"Genre\": \"['detroit hip hop', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 79.0, \"Danceability\": 0.724, \"Energy\": 0.675, \"Loudness\": -5.267, \"Speechiness\": 0.0867, \"Acousticness\": 0.0978, \"Liveness\": 0.351, \"Tempo\": 160.048, \"Duration (ms)\": 199758.0, \"Valence\": 0.325, \"Chord\": \"D\"}, {\"Index\": 819, \"Highest Charting Position\": 88, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"thank u, next\", \"Streams\": 5079328, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3e9HZxeyfWwjeyPAMmWSSQ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-02-08\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.717, \"Energy\": 0.653, \"Loudness\": -5.634, \"Speechiness\": 0.0658, \"Acousticness\": 0.229, \"Liveness\": 0.101, \"Tempo\": 106.966, \"Duration (ms)\": 207320.0, \"Valence\": 0.412, \"Chord\": \"C#/Db\"}, {\"Index\": 820, \"Highest Charting Position\": 19, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"MAMACITA\", \"Streams\": 5016343, \"Artist\": \"Black Eyed Peas, Ozuna, J. Rey Soul\", \"Artist Followers\": 5966748.0, \"Song ID\": \"14wf185UxfNbSy8dwt4r4q\", \"Genre\": \"['dance pop', 'pop', 'pop rap']\", \"Release Date\": \"2020-04-10\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 74.0, \"Danceability\": 0.894, \"Energy\": 0.635, \"Loudness\": -6.929, \"Speechiness\": 0.0473, \"Acousticness\": 0.193, \"Liveness\": 0.0823, \"Tempo\": 105.013, \"Duration (ms)\": 249143.0, \"Valence\": 0.428, \"Chord\": \"D\"}, {\"Index\": 821, \"Highest Charting Position\": 137, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Fake\", \"Streams\": 5010179, \"Artist\": \"Lauv, Conan Gray\", \"Artist Followers\": 4442273.0, \"Song ID\": \"4Gt2kh3QbAGU6yquOWn4aW\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-13\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 73.0, \"Danceability\": 0.703, \"Energy\": 0.657, \"Loudness\": -5.363, \"Speechiness\": 0.0783, \"Acousticness\": 0.139, \"Liveness\": 0.093, \"Tempo\": 82.96, \"Duration (ms)\": 146375.0, \"Valence\": 0.455, \"Chord\": \"E\"}, {\"Index\": 822, \"Highest Charting Position\": 56, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"OK Not To Be OK\", \"Streams\": 4980744, \"Artist\": \"Marshmello, Demi Lovato\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6PiO7fUEPKnJfaCQbPrIyg\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 0.0, \"Danceability\": 0.743, \"Energy\": 0.837, \"Loudness\": -5.025, \"Speechiness\": 0.0649, \"Acousticness\": 0.0172, \"Liveness\": 0.0743, \"Tempo\": 103.072, \"Duration (ms)\": 159863.0, \"Valence\": 0.263, \"Chord\": \"C#/Db\"}, {\"Index\": 823, \"Highest Charting Position\": 1, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"THE SCOTTS\", \"Streams\": 4941592, \"Artist\": \"THE SCOTTS, Travis Scott, Kid Cudi\", \"Artist Followers\": 179193.0, \"Song ID\": \"39Yp9wwQiSRIDOvrVg7mbk\", \"Genre\": \"['pop rap']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 79.0, \"Danceability\": 0.716, \"Energy\": 0.537, \"Loudness\": -7.648, \"Speechiness\": 0.0514, \"Acousticness\": 0.233, \"Liveness\": 0.157, \"Tempo\": 129.979, \"Duration (ms)\": 165978.0, \"Valence\": 0.28, \"Chord\": \"C\"}, {\"Index\": 824, \"Highest Charting Position\": 37, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Mamichula - con Nicki Nicole\", \"Streams\": 4817969, \"Artist\": \"Trueno, Bizarrap, Taiu, TATOOL\", \"Artist Followers\": 2172969.0, \"Song ID\": \"0TUW9faHNaBmi89wsYGp9y\", \"Genre\": \"['argentine hip hop', 'trap argentino', 'trap latino']\", \"Release Date\": \"2020-07-23\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 75.0, \"Danceability\": 0.696, \"Energy\": 0.678, \"Loudness\": -5.893, \"Speechiness\": 0.0735, \"Acousticness\": 0.582, \"Liveness\": 0.134, \"Tempo\": 91.985, \"Duration (ms)\": 219202.0, \"Valence\": 0.346, \"Chord\": \"E\"}, {\"Index\": 825, \"Highest Charting Position\": 172, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Let Her Go\", \"Streams\": 4765198, \"Artist\": \"Passenger\", \"Artist Followers\": 2819406.0, \"Song ID\": \"0JmiBCpWc1IAc0et7Xm7FL\", \"Genre\": \"['folk-pop', 'neo mellow', 'pop', 'pop rock']\", \"Release Date\": \"2013-02-17\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 75.0, \"Danceability\": 0.479, \"Energy\": 0.545, \"Loudness\": -7.346, \"Speechiness\": 0.0688, \"Acousticness\": 0.365, \"Liveness\": 0.0963, \"Tempo\": 74.897, \"Duration (ms)\": 252733.0, \"Valence\": 0.243, \"Chord\": \"G\"}, {\"Index\": 826, \"Highest Charting Position\": 26, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Play Date\", \"Streams\": 4745568, \"Artist\": \"Melanie Martinez\", \"Artist Followers\": 10925614.0, \"Song ID\": \"4DpNNXFMMxQEKl7r0ykkWA\", \"Genre\": \"['alt z', 'electropop', 'modern rock', 'pop']\", \"Release Date\": \"2015-08-14\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 80.0, \"Danceability\": 0.68, \"Energy\": 0.729, \"Loudness\": -5.077, \"Speechiness\": 0.0475, \"Acousticness\": 0.612, \"Liveness\": 0.224, \"Tempo\": 123.97, \"Duration (ms)\": 179867.0, \"Valence\": 0.446, \"Chord\": \"F\"}, {\"Index\": 827, \"Highest Charting Position\": 32, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Lose Somebody\", \"Streams\": 4709053, \"Artist\": \"Kygo, OneRepublic\", \"Artist Followers\": 7593792.0, \"Song ID\": \"1sgDyuLooyvEML4oHspNza\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 75.0, \"Danceability\": 0.58, \"Energy\": 0.586, \"Loudness\": -6.883, \"Speechiness\": 0.0357, \"Acousticness\": 0.344, \"Liveness\": 0.0755, \"Tempo\": 147.988, \"Duration (ms)\": 199549.0, \"Valence\": 0.507, \"Chord\": \"C#/Db\"}, {\"Index\": 828, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Someone Like You\", \"Streams\": 4703672, \"Artist\": \"Adele\", \"Artist Followers\": 28335338.0, \"Song ID\": \"1zwMYTA5nlNjZxYrvBB2pV\", \"Genre\": \"['british soul', 'pop', 'pop soul', 'uk pop']\", \"Release Date\": \"2011-01-24\", \"Weeks Charted\": \"2020-10-23--2020-10-30\", \"Popularity\": 77.0, \"Danceability\": 0.556, \"Energy\": 0.319, \"Loudness\": -8.251, \"Speechiness\": 0.0281, \"Acousticness\": 0.893, \"Liveness\": 0.0996, \"Tempo\": 135.187, \"Duration (ms)\": 285240.0, \"Valence\": 0.294, \"Chord\": \"A\"}, {\"Index\": 829, \"Highest Charting Position\": 73, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"It's You\", \"Streams\": 4674658, \"Artist\": \"Ali Gatie\", \"Artist Followers\": 1758300.0, \"Song ID\": \"5DqdesEfbRyOlSS3Tf6c29\", \"Genre\": \"['canadian hip hop', 'pop']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.732, \"Energy\": 0.463, \"Loudness\": -6.972, \"Speechiness\": 0.0287, \"Acousticness\": 0.374, \"Liveness\": 0.194, \"Tempo\": 95.971, \"Duration (ms)\": 212607.0, \"Valence\": 0.397, \"Chord\": \"B\"}, {\"Index\": 830, \"Highest Charting Position\": 68, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Stunnin' (feat. Harm Franklin)\", \"Streams\": 5183246, \"Artist\": \"Curtis Waters\", \"Artist Followers\": 68875.0, \"Song ID\": \"2JSmxLqt8h7ZpJJkfuLJvK\", \"Genre\": \"[]\", \"Release Date\": \"2020-10-09\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 68.0, \"Danceability\": 0.885, \"Energy\": 0.685, \"Loudness\": -6.429, \"Speechiness\": 0.0627, \"Acousticness\": 0.33, \"Liveness\": 0.148, \"Tempo\": 99.954, \"Duration (ms)\": 144000.0, \"Valence\": 0.937, \"Chord\": \"B\"}, {\"Index\": 831, \"Highest Charting Position\": 35, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Love To Hate Me\", \"Streams\": 5125708, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"7iKDsPfLT0d5mu2htfMKBZ\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 69.0, \"Danceability\": 0.686, \"Energy\": 0.64, \"Loudness\": -5.491, \"Speechiness\": 0.159, \"Acousticness\": 0.0334, \"Liveness\": 0.0801, \"Tempo\": 162.225, \"Duration (ms)\": 171798.0, \"Valence\": 0.597, \"Chord\": \"G#/Ab\"}, {\"Index\": 832, \"Highest Charting Position\": 165, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Hate The Way (feat. blackbear)\", \"Streams\": 5116071, \"Artist\": \"G-Eazy\", \"Artist Followers\": 4894656.0, \"Song ID\": \"3QGppKBPd9gHOgHJzRbVIw\", \"Genre\": \"['hip hop', 'indie pop rap', 'oakland hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2020-10-16--2020-10-23\", \"Popularity\": 68.0, \"Danceability\": 0.569, \"Energy\": 0.865, \"Loudness\": -3.844, \"Speechiness\": 0.266, \"Acousticness\": 0.0673, \"Liveness\": 0.312, \"Tempo\": 82.011, \"Duration (ms)\": 214363.0, \"Valence\": 0.361, \"Chord\": \"E\"}, {\"Index\": 833, \"Highest Charting Position\": 89, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Bande organis\\u00e9e\", \"Streams\": 5112572, \"Artist\": \"13 Organis\\u00e9, SCH, Kofs, Jul, Naps, Soso Maness, Elams, Solda, Houari\", \"Artist Followers\": 249910.0, \"Song ID\": \"205HNJ73cgpC0LAOnuQiWT\", \"Genre\": \"['french hip hop', 'pop urbaine', 'rap francais', 'rap marseille']\", \"Release Date\": \"2020-08-15\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 72.0, \"Danceability\": 0.901, \"Energy\": 0.939, \"Loudness\": -2.762, \"Speechiness\": 0.274, \"Acousticness\": 0.117, \"Liveness\": 0.0643, \"Tempo\": 142.948, \"Duration (ms)\": 356347.0, \"Valence\": 0.805, \"Chord\": \"F#/Gb\"}, {\"Index\": 834, \"Highest Charting Position\": 32, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Crazy Over You\", \"Streams\": 5056387, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"7qq0EOPW4RRlqdvMBmdd73\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 68.0, \"Danceability\": 0.804, \"Energy\": 0.633, \"Loudness\": -6.186, \"Speechiness\": 0.0612, \"Acousticness\": 0.0371, \"Liveness\": 0.102, \"Tempo\": 115.002, \"Duration (ms)\": 163946.0, \"Valence\": 0.67, \"Chord\": \"E\"}, {\"Index\": 835, \"Highest Charting Position\": 109, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Baby, I'm Jealous (feat. Doja Cat)\", \"Streams\": 4870203, \"Artist\": \"Bebe Rexha\", \"Artist Followers\": 6569150.0, \"Song ID\": \"2fTdRdN73RgIgcUZN33dvt\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-09\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 69.0, \"Danceability\": 0.737, \"Energy\": 0.867, \"Loudness\": -2.259, \"Speechiness\": 0.0458, \"Acousticness\": 0.0398, \"Liveness\": 0.32, \"Tempo\": 98.05, \"Duration (ms)\": 175873.0, \"Valence\": 0.506, \"Chord\": \"B\"}, {\"Index\": 836, \"Highest Charting Position\": 15, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"TKN (feat. Travis Scott)\", \"Streams\": 4752289, \"Artist\": \"ROSAL\\u00cdA\", \"Artist Followers\": 4769627.0, \"Song ID\": \"4w47S36wQGBhGg073q3nt7\", \"Genre\": \"['r&b en espanol']\", \"Release Date\": \"2020-05-28\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 75.0, \"Danceability\": 0.776, \"Energy\": 0.509, \"Loudness\": -6.266, \"Speechiness\": 0.467, \"Acousticness\": 0.192, \"Liveness\": 0.115, \"Tempo\": 94.634, \"Duration (ms)\": 129371.0, \"Valence\": 0.485, \"Chord\": \"C\"}, {\"Index\": 837, \"Highest Charting Position\": 135, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"El Mismo Aire - con Pablo Albor\\u00e1n\", \"Streams\": 4705484, \"Artist\": \"Camilo\", \"Artist Followers\": 10580764.0, \"Song ID\": \"5EbtodsuLbxrFDH6j5avVS\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-06-10\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 75.0, \"Danceability\": 0.483, \"Energy\": 0.492, \"Loudness\": -6.591, \"Speechiness\": 0.295, \"Acousticness\": 0.603, \"Liveness\": 0.323, \"Tempo\": 144.511, \"Duration (ms)\": 188213.0, \"Valence\": 0.66, \"Chord\": \"C\"}, {\"Index\": 838, \"Highest Charting Position\": 18, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Yo Perreo Sola\", \"Streams\": 4680447, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0SqqAgdovOE24BzxIClpjw\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 78.0, \"Danceability\": 0.86, \"Energy\": 0.758, \"Loudness\": -5.16, \"Speechiness\": 0.0695, \"Acousticness\": 0.021, \"Liveness\": 0.344, \"Tempo\": 97.014, \"Duration (ms)\": 172127.0, \"Valence\": 0.453, \"Chord\": \"B\"}, {\"Index\": 839, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Let Me Love You Like A Woman\", \"Streams\": 4665053, \"Artist\": \"Lana Del Rey\", \"Artist Followers\": 13697048.0, \"Song ID\": \"1gxdWpeOUBpvB908fiZs4D\", \"Genre\": \"['art pop', 'pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2020-10-16--2020-10-23\", \"Popularity\": 67.0, \"Danceability\": 0.303, \"Energy\": 0.249, \"Loudness\": -11.715, \"Speechiness\": 0.111, \"Acousticness\": 0.97, \"Liveness\": 0.117, \"Tempo\": 66.932, \"Duration (ms)\": 200661.0, \"Valence\": 0.131, \"Chord\": \"C\"}, {\"Index\": 840, \"Highest Charting Position\": 69, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"DOLLAZ ON MY HEAD (feat. Young Thug)\", \"Streams\": 4652712, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"3nS9a01VvXHQriLqJYwRqG\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 76.0, \"Danceability\": 0.825, \"Energy\": 0.458, \"Loudness\": -7.47, \"Speechiness\": 0.0577, \"Acousticness\": 0.114, \"Liveness\": 0.102, \"Tempo\": 145.115, \"Duration (ms)\": 197760.0, \"Valence\": 0.161, \"Chord\": \"C\"}, {\"Index\": 841, \"Highest Charting Position\": 54, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Eleg\\u00ed (feat. D\\u00edmelo Flow)\", \"Streams\": 4607003, \"Artist\": \"Rauw Alejandro, Dalex, Lenny Tav\\u00e1rez\", \"Artist Followers\": 6096559.0, \"Song ID\": \"50ZC4PM7hywH27RcCfViau\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-03-26\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 75.0, \"Danceability\": 0.824, \"Energy\": 0.631, \"Loudness\": -2.791, \"Speechiness\": 0.0809, \"Acousticness\": 0.237, \"Liveness\": 0.0531, \"Tempo\": 171.965, \"Duration (ms)\": 197721.0, \"Valence\": 0.678, \"Chord\": \"C\"}, {\"Index\": 842, \"Highest Charting Position\": 77, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"July\", \"Streams\": 4598766, \"Artist\": \"Noah Cyrus\", \"Artist Followers\": 891555.0, \"Song ID\": \"6J2LdBN97cDWn0MLxYh9HB\", \"Genre\": \"['alt z', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.708, \"Energy\": 0.186, \"Loudness\": -8.953, \"Speechiness\": 0.042, \"Acousticness\": 0.868, \"Liveness\": 0.0779, \"Tempo\": 72.541, \"Duration (ms)\": 156106.0, \"Valence\": 0.322, \"Chord\": \"A\"}, {\"Index\": 843, \"Highest Charting Position\": 93, \"Number of Times Charted\": 38, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Bruises\", \"Streams\": 4560503, \"Artist\": \"Lewis Capaldi\", \"Artist Followers\": 8388838.0, \"Song ID\": \"4Of7rzpRpV1mWRbhp5rAqG\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.736, \"Energy\": 0.308, \"Loudness\": -7.83, \"Speechiness\": 0.0677, \"Acousticness\": 0.946, \"Liveness\": 0.186, \"Tempo\": 111.202, \"Duration (ms)\": 220492.0, \"Valence\": 0.361, \"Chord\": \"E\"}, {\"Index\": 844, \"Highest Charting Position\": 46, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"You Never Know\", \"Streams\": 5304382, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"3b7trEcKoglybN5MxGuSaw\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2021-08-03\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 54.0, \"Danceability\": 0.535, \"Energy\": 0.434, \"Loudness\": -5.768, \"Speechiness\": 0.0505, \"Acousticness\": 0.405, \"Liveness\": 0.253, \"Tempo\": 144.497, \"Duration (ms)\": 229236.0, \"Valence\": 0.271, \"Chord\": \"F\"}, {\"Index\": 845, \"Highest Charting Position\": 12, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Supalonely\", \"Streams\": 5089970, \"Artist\": \"BENEE, Gus Dapperton\", \"Artist Followers\": 638337.0, \"Song ID\": \"4nK5YrxbMGZstTLbvj6Gxw\", \"Genre\": \"['alt z', 'nz pop', 'pop']\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 77.0, \"Danceability\": 0.863, \"Energy\": 0.631, \"Loudness\": -4.689, \"Speechiness\": 0.0534, \"Acousticness\": 0.305, \"Liveness\": 0.123, \"Tempo\": 128.977, \"Duration (ms)\": 223480.0, \"Valence\": 0.817, \"Chord\": \"G\"}, {\"Index\": 846, \"Highest Charting Position\": 53, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Glock In My Lap\", \"Streams\": 4947593, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"6pcywuOeGGWeOQzdUyti6k\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 69.0, \"Danceability\": 0.847, \"Energy\": 0.733, \"Loudness\": -6.439, \"Speechiness\": 0.16, \"Acousticness\": 0.00574, \"Liveness\": 0.151, \"Tempo\": 130.029, \"Duration (ms)\": 193591.0, \"Valence\": 0.202, \"Chord\": \"A#/Bb\"}, {\"Index\": 847, \"Highest Charting Position\": 49, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Better\", \"Streams\": 4933462, \"Artist\": \"ZAYN\", \"Artist Followers\": 16655692.0, \"Song ID\": \"1dLXLETYiZohIZWnse4ypG\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-01-03--2020-01-10\", \"Popularity\": 68.0, \"Danceability\": 0.637, \"Energy\": 0.418, \"Loudness\": -7.137, \"Speechiness\": 0.301, \"Acousticness\": 0.353, \"Liveness\": 0.131, \"Tempo\": 84.295, \"Duration (ms)\": 174517.0, \"Valence\": 0.0807, \"Chord\": \"D\"}, {\"Index\": 848, \"Highest Charting Position\": 59, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"forget me too (feat. Halsey)\", \"Streams\": 4751756, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3868320.0, \"Song ID\": \"1VSuFS7PahCN3SWbOcQ98m\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 78.0, \"Danceability\": 0.654, \"Energy\": 0.875, \"Loudness\": -4.845, \"Speechiness\": 0.0744, \"Acousticness\": 0.000417, \"Liveness\": 0.194, \"Tempo\": 99.975, \"Duration (ms)\": 171621.0, \"Valence\": 0.522, \"Chord\": \"C#/Db\"}, {\"Index\": 849, \"Highest Charting Position\": 110, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Oh Juliana\", \"Streams\": 4751064, \"Artist\": \"Niack\", \"Artist Followers\": 352402.0, \"Song ID\": \"4xWzZmX4K1yyrdtRfbUvjt\", \"Genre\": \"['funk carioca']\", \"Release Date\": \"2020-06-30\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 66.0, \"Danceability\": 0.799, \"Energy\": 0.568, \"Loudness\": -3.089, \"Speechiness\": 0.25, \"Acousticness\": 0.387, \"Liveness\": 0.0892, \"Tempo\": 129.63, \"Duration (ms)\": 153078.0, \"Valence\": 0.963, \"Chord\": \"F#/Gb\"}, {\"Index\": 850, \"Highest Charting Position\": 81, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"PORFA Remix ( Feat. Maluma, Nicky Jam, Sech) - Remix\", \"Streams\": 4727923, \"Artist\": \"Feid, J Balvin, Justin Quiles\", \"Artist Followers\": 613348.0, \"Song ID\": \"7lUdbnz7wsv3C9zzf4WHl9\", \"Genre\": \"['colombian pop', 'latin', 'pop reggaeton', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 70.0, \"Danceability\": 0.793, \"Energy\": 0.737, \"Loudness\": -4.731, \"Speechiness\": 0.0785, \"Acousticness\": 0.0765, \"Liveness\": 0.0747, \"Tempo\": 167.969, \"Duration (ms)\": 333800.0, \"Valence\": 0.697, \"Chord\": \"F#/Gb\"}, {\"Index\": 851, \"Highest Charting Position\": 108, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"No Guidance (feat. Drake)\", \"Streams\": 4641393, \"Artist\": \"Chris Brown\", \"Artist Followers\": 14073083.0, \"Song ID\": \"6XHVuErjQ4XNm6nDPVCxVX\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'r&b', 'rap']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.696, \"Energy\": 0.454, \"Loudness\": -6.756, \"Speechiness\": 0.153, \"Acousticness\": 0.123, \"Liveness\": 0.155, \"Tempo\": 92.928, \"Duration (ms)\": 260640.0, \"Valence\": 0.136, \"Chord\": \"C#/Db\"}, {\"Index\": 852, \"Highest Charting Position\": 65, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Rich Nigga Shit (feat. Young Thug)\", \"Streams\": 9129562, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"3ruoIF2UnoXdzK8mR61ebq\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 73.0, \"Danceability\": 0.825, \"Energy\": 0.733, \"Loudness\": -5.625, \"Speechiness\": 0.0969, \"Acousticness\": 0.349, \"Liveness\": 0.112, \"Tempo\": 97.974, \"Duration (ms)\": 190331.0, \"Valence\": 0.62, \"Chord\": \"C#/Db\"}, {\"Index\": 853, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Many Men\", \"Streams\": 8675173, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"3CDVMejYHnB1SkEEx0T1N4\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 65.0, \"Danceability\": 0.635, \"Energy\": 0.793, \"Loudness\": -4.333, \"Speechiness\": 0.0322, \"Acousticness\": 0.000647, \"Liveness\": 0.113, \"Tempo\": 77.594, \"Duration (ms)\": 201856.0, \"Valence\": 0.281, \"Chord\": \"A#/Bb\"}, {\"Index\": 854, \"Highest Charting Position\": 77, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Slidin\", \"Streams\": 8243488, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"7fxSLnklnayJNBIKntXedZ\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 64.0, \"Danceability\": 0.774, \"Energy\": 0.706, \"Loudness\": -6.494, \"Speechiness\": 0.355, \"Acousticness\": 0.00163, \"Liveness\": 0.104, \"Tempo\": 152.891, \"Duration (ms)\": 185037.0, \"Valence\": 0.382, \"Chord\": \"D\"}, {\"Index\": 855, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Outta Time (feat. Drake)\", \"Streams\": 7762934, \"Artist\": \"Bryson Tiller\", \"Artist Followers\": 5019909.0, \"Song ID\": \"4SCnCPOUOUXUmCX2uHb3r7\", \"Genre\": \"['kentucky hip hop', 'pop', 'pop rap', 'r&b', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 68.0, \"Danceability\": 0.714, \"Energy\": 0.582, \"Loudness\": -7.272, \"Speechiness\": 0.0808, \"Acousticness\": 0.0129, \"Liveness\": 0.0774, \"Tempo\": 92.819, \"Duration (ms)\": 198822.0, \"Valence\": 0.338, \"Chord\": \"F\"}, {\"Index\": 856, \"Highest Charting Position\": 131, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"My Dawg\", \"Streams\": 6029118, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"42Tohunwlh34o0mgxYx5iq\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 60.0, \"Danceability\": 0.831, \"Energy\": 0.532, \"Loudness\": -5.319, \"Speechiness\": 0.301, \"Acousticness\": 0.0652, \"Liveness\": 0.464, \"Tempo\": 140.105, \"Duration (ms)\": 181716.0, \"Valence\": 0.364, \"Chord\": \"C\"}, {\"Index\": 857, \"Highest Charting Position\": 138, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Snitches & Rats (feat. Young Nudy)\", \"Streams\": 5846760, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"3WaDoMDQRqDdgtCDLxanpN\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 57.0, \"Danceability\": 0.821, \"Energy\": 0.671, \"Loudness\": -5.893, \"Speechiness\": 0.18, \"Acousticness\": 0.00843, \"Liveness\": 0.0972, \"Tempo\": 145.953, \"Duration (ms)\": 187773.0, \"Valence\": 0.494, \"Chord\": \"A\"}, {\"Index\": 858, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Brand New Draco\", \"Streams\": 5841110, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"4V9ynsDPwHtdItksqjuRu0\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 63.0, \"Danceability\": 0.697, \"Energy\": 0.709, \"Loudness\": -6.642, \"Speechiness\": 0.298, \"Acousticness\": 0.041, \"Liveness\": 0.0886, \"Tempo\": 155.023, \"Duration (ms)\": 202420.0, \"Valence\": 0.439, \"Chord\": \"B\"}, {\"Index\": 859, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Lemonade (Feat. Roddy Ricch & Don Toliver) [Remix]\", \"Streams\": 5550390, \"Artist\": \"Internet Money\", \"Artist Followers\": 412466.0, \"Song ID\": \"5sBplhIrmzA4kQGyIOpmDf\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-09-30\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 69.0, \"Danceability\": 0.832, \"Energy\": 0.549, \"Loudness\": -8.259, \"Speechiness\": 0.0602, \"Acousticness\": 0.168, \"Liveness\": 0.11, \"Tempo\": 140.045, \"Duration (ms)\": 181496.0, \"Valence\": 0.384, \"Chord\": \"C#/Db\"}, {\"Index\": 860, \"Highest Charting Position\": 77, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Your Man\", \"Streams\": 5233336, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"6Vgtvd7I5yopJdBuxqjBd2\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-24\", \"Weeks Charted\": \"2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 68.0, \"Danceability\": 0.785, \"Energy\": 0.818, \"Loudness\": -8.711, \"Speechiness\": 0.099, \"Acousticness\": 0.624, \"Liveness\": 0.149, \"Tempo\": 117.98, \"Duration (ms)\": 163759.0, \"Valence\": 0.0503, \"Chord\": \"G\"}, {\"Index\": 861, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"No Opp Left Behind\", \"Streams\": 5154955, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"50I7FNN2rl2rWiNwGxS146\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 61.0, \"Danceability\": 0.823, \"Energy\": 0.703, \"Loudness\": -2.691, \"Speechiness\": 0.298, \"Acousticness\": 0.0161, \"Liveness\": 0.294, \"Tempo\": 178.043, \"Duration (ms)\": 194214.0, \"Valence\": 0.26, \"Chord\": \"G#/Ab\"}, {\"Index\": 862, \"Highest Charting Position\": 106, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Lets Link\", \"Streams\": 5109038, \"Artist\": \"WhoHeem\", \"Artist Followers\": 25417.0, \"Song ID\": \"6fMzgFFGzWCwiHMzDzNpp5\", \"Genre\": \"['viral rap']\", \"Release Date\": \"2020-08-20\", \"Weeks Charted\": \"2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 61.0, \"Danceability\": 0.839, \"Energy\": 0.683, \"Loudness\": -9.232, \"Speechiness\": 0.165, \"Acousticness\": 0.00667, \"Liveness\": 0.241, \"Tempo\": 120.003, \"Duration (ms)\": 159955.0, \"Valence\": 0.522, \"Chord\": \"A#/Bb\"}, {\"Index\": 863, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"RIP Luv\", \"Streams\": 4915080, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"1wGnp7ejkCuXRsehXx0PNP\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 62.0, \"Danceability\": 0.63, \"Energy\": 0.399, \"Loudness\": -9.869, \"Speechiness\": 0.178, \"Acousticness\": 0.105, \"Liveness\": 0.234, \"Tempo\": 183.016, \"Duration (ms)\": 214192.0, \"Valence\": 0.0657, \"Chord\": \"F\"}, {\"Index\": 864, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Steppin On Niggas\", \"Streams\": 4853661, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"7FtZFla3ZH6PqsAJ9MvVCM\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 57.0, \"Danceability\": 0.849, \"Energy\": 0.635, \"Loudness\": -4.068, \"Speechiness\": 0.254, \"Acousticness\": 0.000608, \"Liveness\": 0.062, \"Tempo\": 89.484, \"Duration (ms)\": 140833.0, \"Valence\": 0.798, \"Chord\": \"G\"}, {\"Index\": 865, \"Highest Charting Position\": 58, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Gimme Love\", \"Streams\": 7471309, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"2hfoyc7ve6xM4ZEiNIiU1B\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-04-16\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 69.0, \"Danceability\": 0.482, \"Energy\": 0.631, \"Loudness\": -6.917, \"Speechiness\": 0.0986, \"Acousticness\": 0.696, \"Liveness\": 0.209, \"Tempo\": 126.576, \"Duration (ms)\": 214558.0, \"Valence\": 0.0743, \"Chord\": \"F\"}, {\"Index\": 866, \"Highest Charting Position\": 97, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Ew\", \"Streams\": 6936305, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"7xcUWyLh6fIMsYjoVI7NnZ\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 67.0, \"Danceability\": 0.48, \"Energy\": 0.373, \"Loudness\": -9.297, \"Speechiness\": 0.0278, \"Acousticness\": 0.804, \"Liveness\": 0.12, \"Tempo\": 114.078, \"Duration (ms)\": 207710.0, \"Valence\": 0.0376, \"Chord\": \"A#/Bb\"}, {\"Index\": 867, \"Highest Charting Position\": 99, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Daylight\", \"Streams\": 6819838, \"Artist\": \"Joji, Diplo\", \"Artist Followers\": 4759367.0, \"Song ID\": \"6Ed1q0X8oSKSm4IIhiQbYg\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-08-06\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-08-07--2020-08-14\", \"Popularity\": 72.0, \"Danceability\": 0.528, \"Energy\": 0.749, \"Loudness\": -7.571, \"Speechiness\": 0.0479, \"Acousticness\": 0.00488, \"Liveness\": 0.0949, \"Tempo\": 163.944, \"Duration (ms)\": 163906.0, \"Valence\": 0.729, \"Chord\": \"G\"}, {\"Index\": 868, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Epidemic\", \"Streams\": 6292620, \"Artist\": \"Polo G\", \"Artist Followers\": 4849204.0, \"Song ID\": \"170DNUSnQRp1tGpppF26pA\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 71.0, \"Danceability\": 0.616, \"Energy\": 0.617, \"Loudness\": -8.431, \"Speechiness\": 0.52, \"Acousticness\": 0.128, \"Liveness\": 0.177, \"Tempo\": 175.929, \"Duration (ms)\": 177273.0, \"Valence\": 0.476, \"Chord\": \"C#/Db\"}, {\"Index\": 869, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"bloody valentine\", \"Streams\": 6032935, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3868320.0, \"Song ID\": \"6mADjHs6FXdroPzEGW6KVJ\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 77.0, \"Danceability\": 0.533, \"Energy\": 0.858, \"Loudness\": -4.212, \"Speechiness\": 0.0766, \"Acousticness\": 0.00021, \"Liveness\": 0.148, \"Tempo\": 160.057, \"Duration (ms)\": 205159.0, \"Valence\": 0.506, \"Chord\": \"D\"}, {\"Index\": 870, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"MODUS\", \"Streams\": 6013371, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"5SjtAe7xzUgHDtNTmt8zS7\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 66.0, \"Danceability\": 0.738, \"Energy\": 0.533, \"Loudness\": -7.617, \"Speechiness\": 0.0492, \"Acousticness\": 0.183, \"Liveness\": 0.115, \"Tempo\": 132.008, \"Duration (ms)\": 207265.0, \"Valence\": 0.262, \"Chord\": \"G\"}, {\"Index\": 871, \"Highest Charting Position\": 145, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Tick Tock\", \"Streams\": 5547939, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"5E7p95xh9Ul4vZp4LEoJwi\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 65.0, \"Danceability\": 0.781, \"Energy\": 0.613, \"Loudness\": -5.582, \"Speechiness\": 0.0524, \"Acousticness\": 0.0399, \"Liveness\": 0.0976, \"Tempo\": 80.53, \"Duration (ms)\": 132215.0, \"Valence\": 0.613, \"Chord\": \"E\"}, {\"Index\": 872, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Sanctuary\", \"Streams\": 5482390, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"3xaugmCyXrVkrDTXbFkMW3\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2019-06-14\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 69.0, \"Danceability\": 0.552, \"Energy\": 0.65, \"Loudness\": -7.199, \"Speechiness\": 0.128, \"Acousticness\": 0.422, \"Liveness\": 0.372, \"Tempo\": 167.788, \"Duration (ms)\": 180019.0, \"Valence\": 0.316, \"Chord\": \"C#/Db\"}, {\"Index\": 873, \"Highest Charting Position\": 112, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"feel something\", \"Streams\": 5463424, \"Artist\": \"Bea Miller\", \"Artist Followers\": 2396662.0, \"Song ID\": \"7JDWhC422Gtk1Bq0mL3OTC\", \"Genre\": \"['alt z', 'dance pop', 'electropop', 'indie cafe pop', 'indie poptimism', 'modern rock', 'pop', 'pop rap', 'post-teen pop', 'talent show']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 75.0, \"Danceability\": 0.74, \"Energy\": 0.415, \"Loudness\": -8.914, \"Speechiness\": 0.0707, \"Acousticness\": 0.242, \"Liveness\": 0.319, \"Tempo\": 136.029, \"Duration (ms)\": 180161.0, \"Valence\": 0.156, \"Chord\": \"C\"}, {\"Index\": 874, \"Highest Charting Position\": 86, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Tap In\", \"Streams\": 5220309, \"Artist\": \"Saweetie\", \"Artist Followers\": 1255573.0, \"Song ID\": \"4Hpib09wXgD84w4uwTPnYD\", \"Genre\": \"['cali rap', 'dance pop', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-06-17\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 73.0, \"Danceability\": 0.954, \"Energy\": 0.696, \"Loudness\": -7.117, \"Speechiness\": 0.204, \"Acousticness\": 0.00576, \"Liveness\": 0.0754, \"Tempo\": 100.036, \"Duration (ms)\": 139413.0, \"Valence\": 0.432, \"Chord\": \"A#/Bb\"}, {\"Index\": 875, \"Highest Charting Position\": 171, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Pretty Boy (feat. Lil Yachty)\", \"Streams\": 5141212, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"0f1G5SHFoFC9lO03gHCGVS\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 66.0, \"Danceability\": 0.656, \"Energy\": 0.776, \"Loudness\": -6.184, \"Speechiness\": 0.0672, \"Acousticness\": 0.16, \"Liveness\": 0.372, \"Tempo\": 156.049, \"Duration (ms)\": 156759.0, \"Valence\": 0.638, \"Chord\": \"F#/Gb\"}, {\"Index\": 876, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Afterthought\", \"Streams\": 4977405, \"Artist\": \"Joji, BENEE\", \"Artist Followers\": 4759367.0, \"Song ID\": \"6zvqq50PL7io0rprbkrYc9\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 67.0, \"Danceability\": 0.668, \"Energy\": 0.547, \"Loudness\": -8.024, \"Speechiness\": 0.0353, \"Acousticness\": 0.398, \"Liveness\": 0.0931, \"Tempo\": 83.5, \"Duration (ms)\": 194871.0, \"Valence\": 0.192, \"Chord\": \"C#/Db\"}, {\"Index\": 877, \"Highest Charting Position\": 164, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"+Linda\", \"Streams\": 4964708, \"Artist\": \"Dalex\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-08-28--2020-09-04\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 878, \"Highest Charting Position\": 24, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Over Now (with The Weeknd)\", \"Streams\": 4867620, \"Artist\": \"Calvin Harris\", \"Artist Followers\": 21946934.0, \"Song ID\": \"58AGoOGbwsQMhBbH0eFLRR\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'house', 'pop', 'progressive house', 'uk dance']\", \"Release Date\": \"2020-08-28\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 72.0, \"Danceability\": 0.612, \"Energy\": 0.884, \"Loudness\": -4.113, \"Speechiness\": 0.0454, \"Acousticness\": 0.0759, \"Liveness\": 0.247, \"Tempo\": 178.043, \"Duration (ms)\": 210795.0, \"Valence\": 0.679, \"Chord\": \"E\"}, {\"Index\": 879, \"Highest Charting Position\": 14, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Hate The Other Side (with Marshmello & The Kid Laroi)\", \"Streams\": 4851997, \"Artist\": \"Juice WRLD, Polo G\", \"Artist Followers\": 19102888.0, \"Song ID\": \"0ada5XsQGLPUVbmTCkAP49\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 78.0, \"Danceability\": 0.701, \"Energy\": 0.65, \"Loudness\": -6.313, \"Speechiness\": 0.104, \"Acousticness\": 0.291, \"Liveness\": 0.112, \"Tempo\": 90.003, \"Duration (ms)\": 160212.0, \"Valence\": 0.647, \"Chord\": \"F#/Gb\"}, {\"Index\": 880, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"drunk face\", \"Streams\": 4834258, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3868320.0, \"Song ID\": \"3k0YJnqMKRZb8swo86vCkq\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 72.0, \"Danceability\": 0.691, \"Energy\": 0.77, \"Loudness\": -4.578, \"Speechiness\": 0.0367, \"Acousticness\": 0.0282, \"Liveness\": 0.497, \"Tempo\": 90.024, \"Duration (ms)\": 143901.0, \"Valence\": 0.344, \"Chord\": \"G\"}, {\"Index\": 881, \"Highest Charting Position\": 76, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Tak Tiki Tak\", \"Streams\": 4761286, \"Artist\": \"Harry Nach\", \"Artist Followers\": 134339.0, \"Song ID\": \"7gwwt1IaAWwmB7af0AcuBM\", \"Genre\": \"['trap chileno', 'trap latino']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\", \"Popularity\": 71.0, \"Danceability\": 0.801, \"Energy\": 0.579, \"Loudness\": -4.78, \"Speechiness\": 0.0813, \"Acousticness\": 0.333, \"Liveness\": 0.172, \"Tempo\": 99.994, \"Duration (ms)\": 212406.0, \"Valence\": 0.231, \"Chord\": \"B\"}, {\"Index\": 882, \"Highest Charting Position\": 26, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"WHATS POPPIN\", \"Streams\": 4745752, \"Artist\": \"Jack Harlow\", \"Artist Followers\": 3828418.0, \"Song ID\": \"2MbdDtCv5LUVjYy9RuGTgC\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-06-24\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 80.0, \"Danceability\": 0.904, \"Energy\": 0.723, \"Loudness\": -5.224, \"Speechiness\": 0.26, \"Acousticness\": 0.0631, \"Liveness\": 0.185, \"Tempo\": 145.013, \"Duration (ms)\": 227478.0, \"Valence\": 0.835, \"Chord\": \"B\"}, {\"Index\": 883, \"Highest Charting Position\": 143, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Money Trees\", \"Streams\": 4632724, \"Artist\": \"Kendrick Lamar, Jay Rock\", \"Artist Followers\": 17931101.0, \"Song ID\": \"2HbKqm4o0w5wEeEFXm2sD4\", \"Genre\": \"['conscious hip hop', 'hip hop', 'rap', 'west coast rap']\", \"Release Date\": \"2012\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 75.0, \"Danceability\": 0.716, \"Energy\": 0.531, \"Loudness\": -7.355, \"Speechiness\": 0.122, \"Acousticness\": 0.0703, \"Liveness\": 0.224, \"Tempo\": 71.994, \"Duration (ms)\": 386907.0, \"Valence\": 0.344, \"Chord\": \"G\"}, {\"Index\": 884, \"Highest Charting Position\": 65, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Blastoff (feat. Juice Wrld & Trippie Redd)\", \"Streams\": 4628159, \"Artist\": \"Internet Money, Diplo\", \"Artist Followers\": 412466.0, \"Song ID\": \"2rFsFjq0D9JAmc0APpCO6P\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-08-29\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 70.0, \"Danceability\": 0.761, \"Energy\": 0.517, \"Loudness\": -6.916, \"Speechiness\": 0.0927, \"Acousticness\": 0.114, \"Liveness\": 0.157, \"Tempo\": 147.912, \"Duration (ms)\": 174730.0, \"Valence\": 0.46, \"Chord\": \"F\"}, {\"Index\": 885, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"September\", \"Streams\": 5329256, \"Artist\": \"Earth, Wind & Fire\", \"Artist Followers\": 3008916.0, \"Song ID\": \"2grjqo0Frpf2okIBiifQKs\", \"Genre\": \"['disco', 'funk', 'jazz funk', 'motown', 'quiet storm', 'soul']\", \"Release Date\": \"1978-11-23\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 80.0, \"Danceability\": 0.697, \"Energy\": 0.832, \"Loudness\": -7.264, \"Speechiness\": 0.0298, \"Acousticness\": 0.168, \"Liveness\": 0.269, \"Tempo\": 125.926, \"Duration (ms)\": 215093.0, \"Valence\": 0.979, \"Chord\": \"A\"}, {\"Index\": 886, \"Highest Charting Position\": 64, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Secrets\", \"Streams\": 5178107, \"Artist\": \"Regard, RAYE\", \"Artist Followers\": 152237.0, \"Song ID\": \"66W1rVTnEv86dIkFhoiElg\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop edm', 'slap house', 'tropical house']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 78.0, \"Danceability\": 0.848, \"Energy\": 0.768, \"Loudness\": -5.386, \"Speechiness\": 0.0373, \"Acousticness\": 0.0412, \"Liveness\": 0.195, \"Tempo\": 118.961, \"Duration (ms)\": 176767.0, \"Valence\": 0.777, \"Chord\": \"F#/Gb\"}, {\"Index\": 887, \"Highest Charting Position\": 150, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"21\", \"Streams\": 5151406, \"Artist\": \"Polo G\", \"Artist Followers\": 4849204.0, \"Song ID\": \"3JKgcAa7r07ocVWcV8bS0H\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 80.0, \"Danceability\": 0.783, \"Energy\": 0.479, \"Loudness\": -10.646, \"Speechiness\": 0.541, \"Acousticness\": 0.149, \"Liveness\": 0.101, \"Tempo\": 176.027, \"Duration (ms)\": 163798.0, \"Valence\": 0.533, \"Chord\": \"G\"}, {\"Index\": 888, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"BXL ZOO\", \"Streams\": 5101640, \"Artist\": \"Damso, Hamza\", \"Artist Followers\": 3071170.0, \"Song ID\": \"1VBt9dPtYfLnVeKaa6CQPr\", \"Genre\": \"['belgian hip hop', 'french hip hop', 'pop urbaine', 'rap belge', 'rap conscient']\", \"Release Date\": \"2021-04-28\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 62.0, \"Danceability\": 0.745, \"Energy\": 0.656, \"Loudness\": -6.829, \"Speechiness\": 0.203, \"Acousticness\": 0.0604, \"Liveness\": 0.11, \"Tempo\": 137.997, \"Duration (ms)\": 201333.0, \"Valence\": 0.405, \"Chord\": \"B\"}, {\"Index\": 889, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"DEUX TOILES DE MER\", \"Streams\": 5094137, \"Artist\": \"Damso\", \"Artist Followers\": 3071170.0, \"Song ID\": \"6vw0mOQ5vm3C5RPm7Rvl2w\", \"Genre\": \"['belgian hip hop', 'french hip hop', 'pop urbaine', 'rap belge', 'rap conscient']\", \"Release Date\": \"2021-04-28\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 62.0, \"Danceability\": 0.521, \"Energy\": 0.39, \"Loudness\": -9.726, \"Speechiness\": 0.128, \"Acousticness\": 0.582, \"Liveness\": 0.112, \"Tempo\": 104.106, \"Duration (ms)\": 315640.0, \"Valence\": 0.157, \"Chord\": \"G#/Ab\"}, {\"Index\": 890, \"Highest Charting Position\": 4, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"exile (feat. Bon Iver)\", \"Streams\": 4924533, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"4pvb0WLRcMtbPGmtejJJ6y\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 77.0, \"Danceability\": 0.298, \"Energy\": 0.38, \"Loudness\": -8.426, \"Speechiness\": 0.0287, \"Acousticness\": 0.778, \"Liveness\": 0.11, \"Tempo\": 75.602, \"Duration (ms)\": 285634.0, \"Valence\": 0.152, \"Chord\": \"F#/Gb\"}, {\"Index\": 891, \"Highest Charting Position\": 10, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Righteous\", \"Streams\": 4819362, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5dOxHHMOFAbG3VH23t0xNm\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 78.0, \"Danceability\": 0.706, \"Energy\": 0.625, \"Loudness\": -7.426, \"Speechiness\": 0.0314, \"Acousticness\": 0.0417, \"Liveness\": 0.129, \"Tempo\": 142.948, \"Duration (ms)\": 242181.0, \"Valence\": 0.225, \"Chord\": \"C\"}, {\"Index\": 892, \"Highest Charting Position\": 9, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Conversations\", \"Streams\": 4805366, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4K06PO78fW4mnBVenxGNob\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 75.0, \"Danceability\": 0.747, \"Energy\": 0.622, \"Loudness\": -5.825, \"Speechiness\": 0.0838, \"Acousticness\": 0.176, \"Liveness\": 0.151, \"Tempo\": 159.93, \"Duration (ms)\": 181661.0, \"Valence\": 0.57, \"Chord\": \"B\"}, {\"Index\": 893, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Dolly (with Lil Uzi Vert)\", \"Streams\": 4800543, \"Artist\": \"Lil Tecca\", \"Artist Followers\": 4022792.0, \"Song ID\": \"77Xwqkw7VrV8E5FCq9JhO8\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 63.0, \"Danceability\": 0.664, \"Energy\": 0.586, \"Loudness\": -7.813, \"Speechiness\": 0.238, \"Acousticness\": 0.212, \"Liveness\": 0.216, \"Tempo\": 88.502, \"Duration (ms)\": 179813.0, \"Valence\": 0.589, \"Chord\": \"G\"}, {\"Index\": 894, \"Highest Charting Position\": 23, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Chicago Freestyle (feat. Giveon)\", \"Streams\": 4799038, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"4wVOKKEHUJxHCFFNUWDn0B\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 80.0, \"Danceability\": 0.735, \"Energy\": 0.449, \"Loudness\": -7.507, \"Speechiness\": 0.347, \"Acousticness\": 0.629, \"Liveness\": 0.113, \"Tempo\": 122.947, \"Duration (ms)\": 220488.0, \"Valence\": 0.0397, \"Chord\": \"A#/Bb\"}, {\"Index\": 895, \"Highest Charting Position\": 4, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"GOOBA\", \"Streams\": 4690955, \"Artist\": \"6ix9ine\", \"Artist Followers\": 6514102.0, \"Song ID\": \"4NhDYoQTYCdWHTvlbGVgwo\", \"Genre\": \"['emo rap', 'rap']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 70.0, \"Danceability\": 0.611, \"Energy\": 0.688, \"Loudness\": -5.688, \"Speechiness\": 0.341, \"Acousticness\": 0.0264, \"Liveness\": 0.251, \"Tempo\": 178.462, \"Duration (ms)\": 132303.0, \"Valence\": 0.393, \"Chord\": \"C#/Db\"}, {\"Index\": 896, \"Highest Charting Position\": 12, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Physical\", \"Streams\": 4599807, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3AzjcOeAmA57TIOr9zF1ZW\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 77.0, \"Danceability\": 0.647, \"Energy\": 0.844, \"Loudness\": -3.756, \"Speechiness\": 0.0457, \"Acousticness\": 0.0137, \"Liveness\": 0.102, \"Tempo\": 146.967, \"Duration (ms)\": 193829.0, \"Valence\": 0.746, \"Chord\": \"C\"}, {\"Index\": 897, \"Highest Charting Position\": 194, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Hot Stuff\", \"Streams\": 4569978, \"Artist\": \"Kygo, Donna Summer\", \"Artist Followers\": 7593792.0, \"Song ID\": \"00ETaeHUQ6lops3oWU1Wrt\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 71.0, \"Danceability\": 0.681, \"Energy\": 0.773, \"Loudness\": -5.749, \"Speechiness\": 0.148, \"Acousticness\": 0.019, \"Liveness\": 0.11, \"Tempo\": 119.961, \"Duration (ms)\": 199008.0, \"Valence\": 0.429, \"Chord\": \"F\"}, {\"Index\": 898, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Who's Laughing Now\", \"Streams\": 4526982, \"Artist\": \"Ava Max\", \"Artist Followers\": 3916979.0, \"Song ID\": \"1Pmp486RrLRkaEkE3HFHXP\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 73.0, \"Danceability\": 0.648, \"Energy\": 0.641, \"Loudness\": -5.521, \"Speechiness\": 0.0389, \"Acousticness\": 0.00565, \"Liveness\": 0.109, \"Tempo\": 184.021, \"Duration (ms)\": 180348.0, \"Valence\": 0.505, \"Chord\": \"G\"}, {\"Index\": 899, \"Highest Charting Position\": 91, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Sweet but Psycho\", \"Streams\": 4502853, \"Artist\": \"Ava Max\", \"Artist Followers\": 3916979.0, \"Song ID\": \"7DnAm9FOTWE3cUvso43HhI\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.72, \"Energy\": 0.706, \"Loudness\": -4.719, \"Speechiness\": 0.0473, \"Acousticness\": 0.0684, \"Liveness\": 0.166, \"Tempo\": 133.002, \"Duration (ms)\": 187436.0, \"Valence\": 0.62, \"Chord\": \"C#/Db\"}, {\"Index\": 900, \"Highest Charting Position\": 83, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Del Mar\", \"Streams\": 5698099, \"Artist\": \"Ozuna, Doja Cat, Sia\", \"Artist Followers\": 29238936.0, \"Song ID\": \"5cpJFiNwYyWwFLH0V6B3N8\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 79.0, \"Danceability\": 0.759, \"Energy\": 0.636, \"Loudness\": -5.585, \"Speechiness\": 0.0369, \"Acousticness\": 0.0224, \"Liveness\": 0.166, \"Tempo\": 109.976, \"Duration (ms)\": 214507.0, \"Valence\": 0.536, \"Chord\": \"F#/Gb\"}, {\"Index\": 901, \"Highest Charting Position\": 72, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Hit Different\", \"Streams\": 5049863, \"Artist\": \"SZA, The Neptunes, Pharrell Williams, Ty Dolla $ign\", \"Artist Followers\": 5888533.0, \"Song ID\": \"7Bar1kLTmsRmH6FCKKMEyU\", \"Genre\": \"['pop', 'pop rap', 'r&b']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 74.0, \"Danceability\": 0.679, \"Energy\": 0.516, \"Loudness\": -6.371, \"Speechiness\": 0.0452, \"Acousticness\": 0.199, \"Liveness\": 0.0965, \"Tempo\": 120.074, \"Duration (ms)\": 202008.0, \"Valence\": 0.716, \"Chord\": \"C\"}, {\"Index\": 902, \"Highest Charting Position\": 65, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Nobody's Love\", \"Streams\": 4957966, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32279979.0, \"Song ID\": \"2ST72jD2KVe7f3fbcGyX1b\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 73.0, \"Danceability\": 0.485, \"Energy\": 0.567, \"Loudness\": -6.456, \"Speechiness\": 0.0388, \"Acousticness\": 0.316, \"Liveness\": 0.0949, \"Tempo\": 93.676, \"Duration (ms)\": 211254.0, \"Valence\": 0.157, \"Chord\": \"C#/Db\"}, {\"Index\": 903, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"M\\u00e1quina do Tempo\", \"Streams\": 4938139, \"Artist\": \"Matu\\u00ea\", \"Artist Followers\": 3263283.0, \"Song ID\": \"5oI9blwsXC8AkTWw6wASY8\", \"Genre\": \"['r&b brasileiro', 'rap cearense', 'trap brasileiro']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-09-11--2020-09-18\", \"Popularity\": 70.0, \"Danceability\": 0.629, \"Energy\": 0.727, \"Loudness\": -4.387, \"Speechiness\": 0.0499, \"Acousticness\": 0.0647, \"Liveness\": 0.138, \"Tempo\": 149.978, \"Duration (ms)\": 230400.0, \"Valence\": 0.132, \"Chord\": \"E\"}, {\"Index\": 904, \"Highest Charting Position\": 112, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Fuckst mich nur ab\", \"Streams\": 4898520, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"0y8mJFmm4ogCHnfe0oTuT6\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 63.0, \"Danceability\": 0.817, \"Energy\": 0.468, \"Loudness\": -10.945, \"Speechiness\": 0.287, \"Acousticness\": 0.233, \"Liveness\": 0.0905, \"Tempo\": 104.875, \"Duration (ms)\": 182931.0, \"Valence\": 0.237, \"Chord\": \"C#/Db\"}, {\"Index\": 905, \"Highest Charting Position\": 122, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Jangueo\", \"Streams\": 4877753, \"Artist\": \"Alex Rose, Rafa Pab\\u00f6n\", \"Artist Followers\": 2168452.0, \"Song ID\": \"1bRpSCFv6P2OUhciByeRYR\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 74.0, \"Danceability\": 0.861, \"Energy\": 0.678, \"Loudness\": -4.157, \"Speechiness\": 0.0536, \"Acousticness\": 0.253, \"Liveness\": 0.106, \"Tempo\": 103.994, \"Duration (ms)\": 259600.0, \"Valence\": 0.723, \"Chord\": \"G#/Ab\"}, {\"Index\": 906, \"Highest Charting Position\": 68, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"We Paid (feat. 42 Dugg)\", \"Streams\": 4776686, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"6gxKUmycQX7uyMwJcweFjp\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 76.0, \"Danceability\": 0.926, \"Energy\": 0.542, \"Loudness\": -5.064, \"Speechiness\": 0.293, \"Acousticness\": 0.135, \"Liveness\": 0.0877, \"Tempo\": 135.14, \"Duration (ms)\": 181929.0, \"Valence\": 0.564, \"Chord\": \"C#/Db\"}, {\"Index\": 907, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Ihr Hobby\", \"Streams\": 4723116, \"Artist\": \"Bonez MC, Maxwell\", \"Artist Followers\": 1683006.0, \"Song ID\": \"4aZfvvgfoSfmSZpfwQYzC0\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-09-11--2020-09-18\", \"Popularity\": 59.0, \"Danceability\": 0.774, \"Energy\": 0.814, \"Loudness\": -6.145, \"Speechiness\": 0.0584, \"Acousticness\": 0.204, \"Liveness\": 0.118, \"Tempo\": 109.019, \"Duration (ms)\": 185330.0, \"Valence\": 0.254, \"Chord\": \"A#/Bb\"}, {\"Index\": 908, \"Highest Charting Position\": 150, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"When I Look At You\", \"Streams\": 4652583, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"7ywzEdEuVG1lsjsRCGJfLy\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2009-01-01\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 63.0, \"Danceability\": 0.459, \"Energy\": 0.545, \"Loudness\": -4.874, \"Speechiness\": 0.0282, \"Acousticness\": 0.142, \"Liveness\": 0.105, \"Tempo\": 137.941, \"Duration (ms)\": 248587.0, \"Valence\": 0.194, \"Chord\": \"F#/Gb\"}, {\"Index\": 909, \"Highest Charting Position\": 21, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Boss Bitch\", \"Streams\": 4620838, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"78qd8dvwea0Gosb6Fe6j3k\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-01-23\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 81.0, \"Danceability\": 0.707, \"Energy\": 0.955, \"Loudness\": -4.593, \"Speechiness\": 0.222, \"Acousticness\": 0.127, \"Liveness\": 0.202, \"Tempo\": 125.989, \"Duration (ms)\": 134240.0, \"Valence\": 0.575, \"Chord\": \"A#/Bb\"}, {\"Index\": 910, \"Highest Charting Position\": 142, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Ain't It Different (feat. AJ Tracey & Stormzy)\", \"Streams\": 4602336, \"Artist\": \"Headie One\", \"Artist Followers\": 328877.0, \"Song ID\": \"6NJfIydBMYrXvlaXsFxmc8\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2020-08-20\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 69.0, \"Danceability\": 0.767, \"Energy\": 0.569, \"Loudness\": -6.805, \"Speechiness\": 0.216, \"Acousticness\": 0.00988, \"Liveness\": 0.109, \"Tempo\": 77.052, \"Duration (ms)\": 196363.0, \"Valence\": 0.524, \"Chord\": \"E\"}, {\"Index\": 911, \"Highest Charting Position\": 75, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Some Say - Felix Jaehn Remix\", \"Streams\": 4598325, \"Artist\": \"Nea\", \"Artist Followers\": 38111.0, \"Song ID\": \"7C1trmcQQ5n5RNy4l6ziCv\", \"Genre\": \"['scandipop', 'swedish pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 77.0, \"Danceability\": 0.682, \"Energy\": 0.7, \"Loudness\": -5.591, \"Speechiness\": 0.0397, \"Acousticness\": 0.406, \"Liveness\": 0.174, \"Tempo\": 120.03, \"Duration (ms)\": 186878.0, \"Valence\": 0.637, \"Chord\": \"F#/Gb\"}, {\"Index\": 912, \"Highest Charting Position\": 13, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Savage Remix (feat. Beyonc\\u00e9)\", \"Streams\": 4568308, \"Artist\": \"Beyonc\\u00e9, Megan Thee Stallion\", \"Artist Followers\": 28335112.0, \"Song ID\": \"5v4GgrXPMghOnBBLmveLac\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'r&b']\", \"Release Date\": \"2020-04-29\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 73.0, \"Danceability\": 0.822, \"Energy\": 0.743, \"Loudness\": -4.772, \"Speechiness\": 0.28, \"Acousticness\": 0.016, \"Liveness\": 0.127, \"Tempo\": 84.459, \"Duration (ms)\": 242001.0, \"Valence\": 0.636, \"Chord\": \"A#/Bb\"}, {\"Index\": 913, \"Highest Charting Position\": 115, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Lithuania (feat. Travis Scott)\", \"Streams\": 5949270, \"Artist\": \"Big Sean\", \"Artist Followers\": 8673345.0, \"Song ID\": \"4VLTxHOyFX5FRtkpsFm5Pc\", \"Genre\": \"['detroit hip hop', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-09-04--2020-09-11\", \"Popularity\": 62.0, \"Danceability\": 0.676, \"Energy\": 0.82, \"Loudness\": -5.217, \"Speechiness\": 0.0554, \"Acousticness\": 0.0493, \"Liveness\": 0.615, \"Tempo\": 152.028, \"Duration (ms)\": 199250.0, \"Valence\": 0.618, \"Chord\": \"G\"}, {\"Index\": 914, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Tap In (feat. Post Malone, DaBaby & Jack Harlow)\", \"Streams\": 5117128, \"Artist\": \"Saweetie\", \"Artist Followers\": 1255573.0, \"Song ID\": \"5woaU1FNkqCwg6WzWiQPW5\", \"Genre\": \"['cali rap', 'dance pop', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-08-28\", \"Weeks Charted\": \"2020-09-04--2020-09-11\", \"Popularity\": 64.0, \"Danceability\": 0.948, \"Energy\": 0.63, \"Loudness\": -7.011, \"Speechiness\": 0.219, \"Acousticness\": 0.00647, \"Liveness\": 0.0737, \"Tempo\": 100.032, \"Duration (ms)\": 253569.0, \"Valence\": 0.425, \"Chord\": \"C#/Db\"}, {\"Index\": 915, \"Highest Charting Position\": 91, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Not Shy\", \"Streams\": 4982232, \"Artist\": \"ITZY\", \"Artist Followers\": 2384076.0, \"Song ID\": \"4ecVWqbtW6phQGpZMAyqIU\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2020-08-17\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 73.0, \"Danceability\": 0.776, \"Energy\": 0.911, \"Loudness\": -3.08, \"Speechiness\": 0.131, \"Acousticness\": 0.155, \"Liveness\": 0.268, \"Tempo\": 101.027, \"Duration (ms)\": 177728.0, \"Valence\": 0.56, \"Chord\": \"D\"}, {\"Index\": 916, \"Highest Charting Position\": 71, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"The Plan - From the Motion Picture \\\"TENET\\\"\", \"Streams\": 4876238, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"551xyaSJsg8hILXFq9JdST\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2020-08-22\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 67.0, \"Danceability\": 0.433, \"Energy\": 0.443, \"Loudness\": -10.568, \"Speechiness\": 0.0361, \"Acousticness\": 0.0922, \"Liveness\": 0.117, \"Tempo\": 79.903, \"Duration (ms)\": 185851.0, \"Valence\": 0.0363, \"Chord\": \"C#/Db\"}, {\"Index\": 917, \"Highest Charting Position\": 152, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"ADMV\", \"Streams\": 4737291, \"Artist\": \"Maluma\", \"Artist Followers\": 26784251.0, \"Song ID\": \"3eJMSq78dDaFb7VvhNFnq6\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-04-23\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 72.0, \"Danceability\": 0.565, \"Energy\": 0.39, \"Loudness\": -4.959, \"Speechiness\": 0.0556, \"Acousticness\": 0.817, \"Liveness\": 0.126, \"Tempo\": 163.781, \"Duration (ms)\": 193700.0, \"Valence\": 0.708, \"Chord\": \"A\"}, {\"Index\": 918, \"Highest Charting Position\": 122, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Alane\", \"Streams\": 4668193, \"Artist\": \"Robin Schulz, Wes\", \"Artist Followers\": 2786366.0, \"Song ID\": \"2u6Jm2klS4yvAlbSHlxUwI\", \"Genre\": \"['dance pop', 'deep euro house', 'deep house', 'edm', 'german dance', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 67.0, \"Danceability\": 0.581, \"Energy\": 0.799, \"Loudness\": -6.66, \"Speechiness\": 0.164, \"Acousticness\": 0.0419, \"Liveness\": 0.11, \"Tempo\": 124.002, \"Duration (ms)\": 175016.0, \"Valence\": 0.662, \"Chord\": \"D#/Eb\"}, {\"Index\": 919, \"Highest Charting Position\": 82, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"THE BADDEST\", \"Streams\": 4642057, \"Artist\": \"K/DA, (G)I-DLE, Wolftyla, Bea Miller, League of Legends\", \"Artist Followers\": 1245965.0, \"Song ID\": \"2V4Fx72svQRxrFvNT1eq5f\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2020-08-27\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 70.0, \"Danceability\": 0.676, \"Energy\": 0.857, \"Loudness\": -4.368, \"Speechiness\": 0.0438, \"Acousticness\": 0.0215, \"Liveness\": 0.254, \"Tempo\": 149.981, \"Duration (ms)\": 162600.0, \"Valence\": 0.717, \"Chord\": \"A#/Bb\"}, {\"Index\": 920, \"Highest Charting Position\": 112, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Desce Pro Play (PA PA PA)\", \"Streams\": 4615520, \"Artist\": \"Mc Zaac, Anitta, Tyga\", \"Artist Followers\": 1555628.0, \"Song ID\": \"4zGtfOglDBfVUypabBwIjQ\", \"Genre\": \"['funk carioca', 'funk pop']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 68.0, \"Danceability\": 0.935, \"Energy\": 0.71, \"Loudness\": -5.085, \"Speechiness\": 0.158, \"Acousticness\": 0.0769, \"Liveness\": 0.173, \"Tempo\": 100.009, \"Duration (ms)\": 168507.0, \"Valence\": 0.635, \"Chord\": \"B\"}, {\"Index\": 921, \"Highest Charting Position\": 103, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Mariposa\", \"Streams\": 4593366, \"Artist\": \"Peach Tree Rascals\", \"Artist Followers\": 177972.0, \"Song ID\": \"4ja2gzrNh9VNigzoXfmbwD\", \"Genre\": \"['alternative r&b', 'chill r&b', 'indie r&b', 'pop']\", \"Release Date\": \"2019-08-28\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 76.0, \"Danceability\": 0.676, \"Energy\": 0.525, \"Loudness\": -5.88, \"Speechiness\": 0.028, \"Acousticness\": 0.617, \"Liveness\": 0.356, \"Tempo\": 112.011, \"Duration (ms)\": 210000.0, \"Valence\": 0.421, \"Chord\": \"A\"}, {\"Index\": 922, \"Highest Charting Position\": 5, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"the 1\", \"Streams\": 4587573, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0Jlcvv8IykzHaSmj49uNW8\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 75.0, \"Danceability\": 0.777, \"Energy\": 0.357, \"Loudness\": -6.942, \"Speechiness\": 0.0522, \"Acousticness\": 0.757, \"Liveness\": 0.108, \"Tempo\": 139.883, \"Duration (ms)\": 210252.0, \"Valence\": 0.172, \"Chord\": \"C\"}, {\"Index\": 923, \"Highest Charting Position\": 11, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"RITMO (Bad Boys For Life)\", \"Streams\": 4585895, \"Artist\": \"Black Eyed Peas, J Balvin\", \"Artist Followers\": 5966748.0, \"Song ID\": \"6cy3ki60hLwimwIje7tALf\", \"Genre\": \"['dance pop', 'pop', 'pop rap']\", \"Release Date\": \"2019-10-12\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.721, \"Energy\": 0.716, \"Loudness\": -7.037, \"Speechiness\": 0.0657, \"Acousticness\": 0.0334, \"Liveness\": 0.237, \"Tempo\": 104.994, \"Duration (ms)\": 221714.0, \"Valence\": 0.667, \"Chord\": \"A#/Bb\"}, {\"Index\": 924, \"Highest Charting Position\": 134, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Unterwegs\", \"Streams\": 4572706, \"Artist\": \"KitschKrieg, Jamule, SFR\", \"Artist Followers\": 166517.0, \"Song ID\": \"7mrWTjhYctgEQb0lJKrVWy\", \"Genre\": \"['german hip hop', 'german pop', 'hamburg hip hop']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 68.0, \"Danceability\": 0.88, \"Energy\": 0.607, \"Loudness\": -7.067, \"Speechiness\": 0.0777, \"Acousticness\": 0.195, \"Liveness\": 0.15, \"Tempo\": 126.039, \"Duration (ms)\": 233905.0, \"Valence\": 0.823, \"Chord\": \"F#/Gb\"}, {\"Index\": 925, \"Highest Charting Position\": 86, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"What's Love Got to Do with It\", \"Streams\": 4538382, \"Artist\": \"Kygo, Tina Turner\", \"Artist Followers\": 7593792.0, \"Song ID\": \"3Be7CLdHZpyzsVijme39cW\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-07-17\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 74.0, \"Danceability\": 0.75, \"Energy\": 0.664, \"Loudness\": -5.908, \"Speechiness\": 0.154, \"Acousticness\": 0.275, \"Liveness\": 0.0632, \"Tempo\": 105.023, \"Duration (ms)\": 208156.0, \"Valence\": 0.617, \"Chord\": \"G#/Ab\"}, {\"Index\": 926, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Cry About It Later\", \"Streams\": 5306994, \"Artist\": \"Katy Perry\", \"Artist Followers\": 18936929.0, \"Song ID\": \"43WYPxyEfIxlIjNlxQGYzc\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2020-08-28--2020-09-04\", \"Popularity\": 67.0, \"Danceability\": 0.676, \"Energy\": 0.794, \"Loudness\": -4.78, \"Speechiness\": 0.0366, \"Acousticness\": 0.0513, \"Liveness\": 0.0723, \"Tempo\": 125.957, \"Duration (ms)\": 159286.0, \"Valence\": 0.161, \"Chord\": \"D\"}, {\"Index\": 927, \"Highest Charting Position\": 71, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Banana (feat. Shaggy) - DJ FLe - Minisiren Remix\", \"Streams\": 4624448, \"Artist\": \"Conkarah\", \"Artist Followers\": 67074.0, \"Song ID\": \"0dZpw3h6KZhcHec61qwevZ\", \"Genre\": \"['jawaiian']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 70.0, \"Danceability\": 0.824, \"Energy\": 0.854, \"Loudness\": -5.312, \"Speechiness\": 0.177, \"Acousticness\": 0.016, \"Liveness\": 0.117, \"Tempo\": 95.114, \"Duration (ms)\": 210329.0, \"Valence\": 0.896, \"Chord\": \"G#/Ab\"}, {\"Index\": 928, \"Highest Charting Position\": 185, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Gifted (feat. Roddy Ricch)\", \"Streams\": 4609169, \"Artist\": \"Cordae\", \"Artist Followers\": 1492551.0, \"Song ID\": \"0mb3uDw5vfFUcZfJYFOMRu\", \"Genre\": \"['dmv rap', 'hip hop', 'pop rap', 'rap', 'trap', 'underground hip hop', 'vapor trap']\", \"Release Date\": \"2020-08-27\", \"Weeks Charted\": \"2020-08-28--2020-09-04\", \"Popularity\": 65.0, \"Danceability\": 0.653, \"Energy\": 0.603, \"Loudness\": -5.697, \"Speechiness\": 0.171, \"Acousticness\": 0.175, \"Liveness\": 0.18, \"Tempo\": 151.016, \"Duration (ms)\": 168477.0, \"Valence\": 0.551, \"Chord\": \"F\"}, {\"Index\": 929, \"Highest Charting Position\": 27, \"Number of Times Charted\": 36, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"OUT WEST (feat. Young Thug)\", \"Streams\": 4597001, \"Artist\": \"JACKBOYS, Travis Scott\", \"Artist Followers\": 437907.0, \"Song ID\": \"6gi6y1xwmVszDWkUqab1qw\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.802, \"Energy\": 0.591, \"Loudness\": -4.895, \"Speechiness\": 0.225, \"Acousticness\": 0.0104, \"Liveness\": 0.196, \"Tempo\": 139.864, \"Duration (ms)\": 157712.0, \"Valence\": 0.309, \"Chord\": \"G#/Ab\"}, {\"Index\": 930, \"Highest Charting Position\": 174, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Anaranjado\", \"Streams\": 4575403, \"Artist\": \"Jowell & Randy, J Balvin\", \"Artist Followers\": 2919696.0, \"Song ID\": \"5iw28wvyHgj4ppOu5AdcEU\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-07-16\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 66.0, \"Danceability\": 0.763, \"Energy\": 0.58, \"Loudness\": -6.196, \"Speechiness\": 0.144, \"Acousticness\": 0.0466, \"Liveness\": 0.154, \"Tempo\": 175.937, \"Duration (ms)\": 212011.0, \"Valence\": 0.608, \"Chord\": \"G#/Ab\"}, {\"Index\": 931, \"Highest Charting Position\": 111, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Reggaetonera\", \"Streams\": 4564331, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"6yVkakCN460KOVol9ZazjH\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-05-29--2020-06-05\", \"Popularity\": 69.0, \"Danceability\": 0.694, \"Energy\": 0.796, \"Loudness\": -4.164, \"Speechiness\": 0.0565, \"Acousticness\": 0.48, \"Liveness\": 0.108, \"Tempo\": 93.064, \"Duration (ms)\": 212312.0, \"Valence\": 0.515, \"Chord\": \"F#/Gb\"}, {\"Index\": 932, \"Highest Charting Position\": 5, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Sour Candy (with BLACKPINK)\", \"Streams\": 4556900, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"6R6ZoHTypt5lt68MWbzZXv\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-28\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 70.0, \"Danceability\": 0.752, \"Energy\": 0.87, \"Loudness\": -3.812, \"Speechiness\": 0.0623, \"Acousticness\": 0.0604, \"Liveness\": 0.489, \"Tempo\": 120.006, \"Duration (ms)\": 157707.0, \"Valence\": 0.784, \"Chord\": \"A\"}, {\"Index\": 933, \"Highest Charting Position\": 113, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Rags2Riches 2 (feat. Lil Baby)\", \"Streams\": 4547965, \"Artist\": \"Rod Wave\", \"Artist Followers\": 2203386.0, \"Song ID\": \"40TPiJpvwGIyvPjJMDTKfy\", \"Genre\": \"['florida rap']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 60.0, \"Danceability\": 0.874, \"Energy\": 0.443, \"Loudness\": -9.628, \"Speechiness\": 0.241, \"Acousticness\": 0.147, \"Liveness\": 0.124, \"Tempo\": 118.004, \"Duration (ms)\": 235988.0, \"Valence\": 0.298, \"Chord\": \"F\"}, {\"Index\": 934, \"Highest Charting Position\": 31, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Bandit (with YoungBoy Never Broke Again)\", \"Streams\": 4514763, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"6Gg1gjgKi2AK4e0qzsR7sd\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.474, \"Energy\": 0.631, \"Loudness\": -5.884, \"Speechiness\": 0.343, \"Acousticness\": 0.0687, \"Liveness\": 0.132, \"Tempo\": 180.051, \"Duration (ms)\": 189323.0, \"Valence\": 0.425, \"Chord\": \"F\"}, {\"Index\": 935, \"Highest Charting Position\": 117, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"PAM\", \"Streams\": 4501441, \"Artist\": \"Justin Quiles, Daddy Yankee, El Alfa\", \"Artist Followers\": 2897862.0, \"Song ID\": \"0eeKDrQxjqNl5bX5VCHDcn\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 73.0, \"Danceability\": 0.889, \"Energy\": 0.863, \"Loudness\": -3.011, \"Speechiness\": 0.0757, \"Acousticness\": 0.289, \"Liveness\": 0.0798, \"Tempo\": 112.953, \"Duration (ms)\": 201000.0, \"Valence\": 0.776, \"Chord\": \"B\"}, {\"Index\": 936, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Lemonade\", \"Streams\": 11373347, \"Artist\": \"Internet Money, Gunna, Don Toliver, NAV\", \"Artist Followers\": 412466.0, \"Song ID\": \"02kDW379Yfd5PzW5A6vuGt\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 82.0, \"Danceability\": 0.799, \"Energy\": 0.66, \"Loudness\": -6.153, \"Speechiness\": 0.079, \"Acousticness\": 0.256, \"Liveness\": 0.111, \"Tempo\": 140.04, \"Duration (ms)\": 195429.0, \"Valence\": 0.471, \"Chord\": \"C#/Db\"}, {\"Index\": 937, \"Highest Charting Position\": 145, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Fr\\u00fchst\\u00fcck in Paris\", \"Streams\": 5440253, \"Artist\": \"Capital Bra, Cro\", \"Artist Followers\": 4093115.0, \"Song ID\": \"1ddbNJwDjjmCYz1GFGYnsw\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-09-17\", \"Weeks Charted\": \"2020-08-21--2020-08-28\", \"Popularity\": 56.0, \"Danceability\": 0.744, \"Energy\": 0.644, \"Loudness\": -5.562, \"Speechiness\": 0.0641, \"Acousticness\": 0.229, \"Liveness\": 0.204, \"Tempo\": 96.852, \"Duration (ms)\": 151360.0, \"Valence\": 0.577, \"Chord\": \"G#/Ab\"}, {\"Index\": 938, \"Highest Charting Position\": 22, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"ON\", \"Streams\": 5391018, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"2QyuXBcV1LJ2rq01KhreMF\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 77.0, \"Danceability\": 0.583, \"Energy\": 0.817, \"Loudness\": -5.146, \"Speechiness\": 0.0987, \"Acousticness\": 0.118, \"Liveness\": 0.338, \"Tempo\": 105.936, \"Duration (ms)\": 246381.0, \"Valence\": 0.438, \"Chord\": \"A\"}, {\"Index\": 939, \"Highest Charting Position\": 106, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"My Oasis (feat. Burna Boy)\", \"Streams\": 4887204, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"2KoHxhRyWxJzA0VafWd5Nk\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-07-30\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 69.0, \"Danceability\": 0.691, \"Energy\": 0.474, \"Loudness\": -8.742, \"Speechiness\": 0.0583, \"Acousticness\": 0.569, \"Liveness\": 0.099, \"Tempo\": 143.783, \"Duration (ms)\": 179917.0, \"Valence\": 0.381, \"Chord\": \"A#/Bb\"}, {\"Index\": 940, \"Highest Charting Position\": 8, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Life's A Mess (feat. Halsey)\", \"Streams\": 4883202, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5wWAwzGp2OaaoIkwcz6wZs\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 74.0, \"Danceability\": 0.63, \"Energy\": 0.446, \"Loudness\": -8.9, \"Speechiness\": 0.0351, \"Acousticness\": 0.337, \"Liveness\": 0.166, \"Tempo\": 143.078, \"Duration (ms)\": 202193.0, \"Valence\": 0.177, \"Chord\": \"C#/Db\"}, {\"Index\": 941, \"Highest Charting Position\": 56, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"PORFA\", \"Streams\": 4702117, \"Artist\": \"Feid, Justin Quiles\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5PwAiSk3ufe0YwOHRFPHEG\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 0.0, \"Danceability\": 0.843, \"Energy\": 0.549, \"Loudness\": -8.018, \"Speechiness\": 0.164, \"Acousticness\": 0.0948, \"Liveness\": 0.155, \"Tempo\": 83.982, \"Duration (ms)\": 233000.0, \"Valence\": 0.542, \"Chord\": \"F#/Gb\"}, {\"Index\": 942, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"2012\", \"Streams\": 4685894, \"Artist\": \"Bausa, Juju\", \"Artist Followers\": 961181.0, \"Song ID\": \"6bM4daGlfZHtKMQp8tEqVz\", \"Genre\": \"['german hip hop', 'german pop']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-08-21--2020-08-28\", \"Popularity\": 62.0, \"Danceability\": 0.805, \"Energy\": 0.619, \"Loudness\": -7.907, \"Speechiness\": 0.0771, \"Acousticness\": 0.218, \"Liveness\": 0.114, \"Tempo\": 98.995, \"Duration (ms)\": 170200.0, \"Valence\": 0.476, \"Chord\": \"F\"}, {\"Index\": 943, \"Highest Charting Position\": 11, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"august\", \"Streams\": 4586236, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3hUxzQpSfdDqwM3ZTFQY0K\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 76.0, \"Danceability\": 0.532, \"Energy\": 0.623, \"Loudness\": -9.208, \"Speechiness\": 0.0331, \"Acousticness\": 0.538, \"Liveness\": 0.0925, \"Tempo\": 89.937, \"Duration (ms)\": 261923.0, \"Valence\": 0.403, \"Chord\": \"F\"}, {\"Index\": 944, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"if i were u (with Lauv)\", \"Streams\": 4561189, \"Artist\": \"blackbear\", \"Artist Followers\": 4272745.0, \"Song ID\": \"0CF1RH8dQKuK2lQPSQw2lZ\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2020-08-19\", \"Weeks Charted\": \"2020-08-21--2020-08-28\", \"Popularity\": 64.0, \"Danceability\": 0.666, \"Energy\": 0.628, \"Loudness\": -5.613, \"Speechiness\": 0.0623, \"Acousticness\": 0.144, \"Liveness\": 0.189, \"Tempo\": 82.992, \"Duration (ms)\": 186468.0, \"Valence\": 0.767, \"Chord\": \"G#/Ab\"}, {\"Index\": 945, \"Highest Charting Position\": 37, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Ballin' (with Roddy Ricch)\", \"Streams\": 4436934, \"Artist\": \"Mustard\", \"Artist Followers\": 881797.0, \"Song ID\": \"3QzAOrNlsabgbMwlZt7TAY\", \"Genre\": \"['cali rap', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.809, \"Energy\": 0.545, \"Loudness\": -6.678, \"Speechiness\": 0.0735, \"Acousticness\": 0.392, \"Liveness\": 0.151, \"Tempo\": 97.008, \"Duration (ms)\": 180435.0, \"Valence\": 0.244, \"Chord\": \"G\"}, {\"Index\": 946, \"Highest Charting Position\": 72, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Stay Gold\", \"Streams\": 4405338, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3Ys2PYl1wyPKQIwyqhP9cQ\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-07-14\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-07-10--2020-07-17\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 73.0, \"Danceability\": 0.723, \"Energy\": 0.634, \"Loudness\": -5.415, \"Speechiness\": 0.0542, \"Acousticness\": 0.0892, \"Liveness\": 0.0787, \"Tempo\": 129.017, \"Duration (ms)\": 243267.0, \"Valence\": 0.582, \"Chord\": \"C#/Db\"}, {\"Index\": 947, \"Highest Charting Position\": 186, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"I'm Yours\", \"Streams\": 4391666, \"Artist\": \"Jason Mraz\", \"Artist Followers\": 6167871.0, \"Song ID\": \"1EzrEOXmMH3G43AXT1y7pA\", \"Genre\": \"['acoustic pop', 'neo mellow', 'pop', 'pop rock']\", \"Release Date\": \"2008-05-12\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\", \"Popularity\": 80.0, \"Danceability\": 0.686, \"Energy\": 0.457, \"Loudness\": -8.322, \"Speechiness\": 0.0468, \"Acousticness\": 0.595, \"Liveness\": 0.105, \"Tempo\": 150.953, \"Duration (ms)\": 242187.0, \"Valence\": 0.718, \"Chord\": \"B\"}, {\"Index\": 948, \"Highest Charting Position\": 136, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Youngblood\", \"Streams\": 4390823, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"2iUXsYOEPhVqEBwsqP70rE\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-06-15\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.596, \"Energy\": 0.854, \"Loudness\": -5.114, \"Speechiness\": 0.463, \"Acousticness\": 0.0169, \"Liveness\": 0.124, \"Tempo\": 120.274, \"Duration (ms)\": 203418.0, \"Valence\": 0.152, \"Chord\": \"G\"}, {\"Index\": 949, \"Highest Charting Position\": 8, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"the last great american dynasty\", \"Streams\": 4389670, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2Eeur20xVqfUoM3Q7EFPFt\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.686, \"Energy\": 0.662, \"Loudness\": -8.505, \"Speechiness\": 0.0413, \"Acousticness\": 0.467, \"Liveness\": 0.109, \"Tempo\": 147.922, \"Duration (ms)\": 230999.0, \"Valence\": 0.706, \"Chord\": \"G\"}, {\"Index\": 950, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Levitating (feat. Madonna and Missy Elliott) [The Blessed Madonna Remix]\", \"Streams\": 5254969, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"0pk1hxhJLBSZZ5RKBhcwOa\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-08-13\", \"Weeks Charted\": \"2020-08-14--2020-08-21\", \"Popularity\": 62.0, \"Danceability\": 0.808, \"Energy\": 0.655, \"Loudness\": -7.34, \"Speechiness\": 0.139, \"Acousticness\": 0.0373, \"Liveness\": 0.208, \"Tempo\": 116.029, \"Duration (ms)\": 250280.0, \"Valence\": 0.56, \"Chord\": \"B\"}, {\"Index\": 951, \"Highest Charting Position\": 10, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"my tears ricochet\", \"Streams\": 5111416, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1MgV7FIyNxIG7WzMRJV5HC\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.456, \"Energy\": 0.263, \"Loudness\": -10.63, \"Speechiness\": 0.0332, \"Acousticness\": 0.806, \"Liveness\": 0.0749, \"Tempo\": 129.86, \"Duration (ms)\": 255894.0, \"Valence\": 0.111, \"Chord\": \"C\"}, {\"Index\": 952, \"Highest Charting Position\": 59, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Rags2Riches (feat. ATR Son Son)\", \"Streams\": 4737306, \"Artist\": \"Rod Wave\", \"Artist Followers\": 2203386.0, \"Song ID\": \"0qg0GJp7HSewRCVPP4fKGk\", \"Genre\": \"['florida rap']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 55.0, \"Danceability\": 0.904, \"Energy\": 0.26, \"Loudness\": -17.57, \"Speechiness\": 0.101, \"Acousticness\": 0.277, \"Liveness\": 0.121, \"Tempo\": 117.967, \"Duration (ms)\": 167147.0, \"Valence\": 0.231, \"Chord\": \"F\"}, {\"Index\": 953, \"Highest Charting Position\": 79, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Flex (feat. Juice WRLD)\", \"Streams\": 4664281, \"Artist\": \"Polo G\", \"Artist Followers\": 4849204.0, \"Song ID\": \"2QqJTIlGKRLJC3onkavYEz\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 76.0, \"Danceability\": 0.752, \"Energy\": 0.673, \"Loudness\": -5.792, \"Speechiness\": 0.153, \"Acousticness\": 0.0538, \"Liveness\": 0.133, \"Tempo\": 164.009, \"Duration (ms)\": 163902.0, \"Valence\": 0.35, \"Chord\": \"A#/Bb\"}, {\"Index\": 954, \"Highest Charting Position\": 77, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Rover (feat. DTG)\", \"Streams\": 4488631, \"Artist\": \"S1mba\", \"Artist Followers\": 46992.0, \"Song ID\": \"4slSrbTK1sNK4I1mDYEthf\", \"Genre\": \"['afroswing', 'social media pop']\", \"Release Date\": \"2020-03-04\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 73.0, \"Danceability\": 0.613, \"Energy\": 0.624, \"Loudness\": -6.66, \"Speechiness\": 0.206, \"Acousticness\": 0.496, \"Liveness\": 0.283, \"Tempo\": 62.948, \"Duration (ms)\": 167917.0, \"Valence\": 0.804, \"Chord\": \"B\"}, {\"Index\": 955, \"Highest Charting Position\": 74, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Only You Freestyle\", \"Streams\": 4480780, \"Artist\": \"Headie One, Drake\", \"Artist Followers\": 328877.0, \"Song ID\": \"4OENnoidV0h8gJV6bhrw7r\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2020-07-20\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 68.0, \"Danceability\": 0.68, \"Energy\": 0.826, \"Loudness\": -2.561, \"Speechiness\": 0.27, \"Acousticness\": 0.562, \"Liveness\": 0.254, \"Tempo\": 146.95, \"Duration (ms)\": 248937.0, \"Valence\": 0.804, \"Chord\": \"F\"}, {\"Index\": 956, \"Highest Charting Position\": 55, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Hallucinate\", \"Streams\": 4472669, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"1nYeVF5vIBxMxfPoL0SIWg\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 72.0, \"Danceability\": 0.627, \"Energy\": 0.69, \"Loudness\": -5.396, \"Speechiness\": 0.139, \"Acousticness\": 0.033, \"Liveness\": 0.0742, \"Tempo\": 122.053, \"Duration (ms)\": 208505.0, \"Valence\": 0.627, \"Chord\": \"A#/Bb\"}, {\"Index\": 957, \"Highest Charting Position\": 100, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"El Efecto\", \"Streams\": 4466143, \"Artist\": \"Rauw Alejandro, Chencho Corleone\", \"Artist Followers\": 6096559.0, \"Song ID\": \"4SJHHpKhcuXwDsCsPqshXj\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2019-03-15\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 76.0, \"Danceability\": 0.849, \"Energy\": 0.781, \"Loudness\": -4.635, \"Speechiness\": 0.159, \"Acousticness\": 0.406, \"Liveness\": 0.0801, \"Tempo\": 84.041, \"Duration (ms)\": 217143.0, \"Valence\": 0.893, \"Chord\": \"C\"}, {\"Index\": 958, \"Highest Charting Position\": 176, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Co\\u00f1o\", \"Streams\": 4462411, \"Artist\": \"Jason Derulo, Puri, Jhorrmountain\", \"Artist Followers\": 9778632.0, \"Song ID\": \"5DV4ZSCqbFv74ui3ZhimXo\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 69.0, \"Danceability\": 0.899, \"Energy\": 0.528, \"Loudness\": -5.442, \"Speechiness\": 0.181, \"Acousticness\": 0.000554, \"Liveness\": 0.105, \"Tempo\": 100.037, \"Duration (ms)\": 111852.0, \"Valence\": 0.456, \"Chord\": \"A\"}, {\"Index\": 959, \"Highest Charting Position\": 126, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Jolie nana\", \"Streams\": 4449437, \"Artist\": \"Aya Nakamura\", \"Artist Followers\": 2953525.0, \"Song ID\": \"65RWVU6N81CeH65nu52K1U\", \"Genre\": \"['basshall', 'francoton']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 69.0, \"Danceability\": 0.813, \"Energy\": 0.64, \"Loudness\": -5.908, \"Speechiness\": 0.272, \"Acousticness\": 0.269, \"Liveness\": 0.131, \"Tempo\": 92.989, \"Duration (ms)\": 147076.0, \"Valence\": 0.488, \"Chord\": \"D\"}, {\"Index\": 960, \"Highest Charting Position\": 189, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Lovefool\", \"Streams\": 4439790, \"Artist\": \"twocolors\", \"Artist Followers\": 36369.0, \"Song ID\": \"51Of5p3lKZeOg6itfs4og4\", \"Genre\": \"['edm', 'pop dance', 'pop edm', 'tropical house']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 79.0, \"Danceability\": 0.677, \"Energy\": 0.766, \"Loudness\": -6.896, \"Speechiness\": 0.0568, \"Acousticness\": 0.0219, \"Liveness\": 0.129, \"Tempo\": 123.062, \"Duration (ms)\": 190488.0, \"Valence\": 0.198, \"Chord\": \"F#/Gb\"}, {\"Index\": 961, \"Highest Charting Position\": 17, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"invisible string\", \"Streams\": 4424118, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6VsvKPJ4xjVNKpI8VVZ3SV\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.653, \"Energy\": 0.452, \"Loudness\": -11.143, \"Speechiness\": 0.055, \"Acousticness\": 0.838, \"Liveness\": 0.108, \"Tempo\": 83.433, \"Duration (ms)\": 252881.0, \"Valence\": 0.45, \"Chord\": \"E\"}, {\"Index\": 962, \"Highest Charting Position\": 118, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Higher Love\", \"Streams\": 4392936, \"Artist\": \"Kygo, Whitney Houston\", \"Artist Followers\": 7593792.0, \"Song ID\": \"6oJ6le65B3SEqPwMRNXWjY\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.693, \"Energy\": 0.678, \"Loudness\": -7.159, \"Speechiness\": 0.0324, \"Acousticness\": 0.0151, \"Liveness\": 0.101, \"Tempo\": 103.952, \"Duration (ms)\": 228267.0, \"Valence\": 0.404, \"Chord\": \"G#/Ab\"}, {\"Index\": 963, \"Highest Charting Position\": 185, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Como Llora\", \"Streams\": 4380308, \"Artist\": \"Juanfran\", \"Artist Followers\": 117894.0, \"Song ID\": \"52zq2a71SGs3f1vJuv59ui\", \"Genre\": \"['dominican pop', 'pop reggaeton', 'urbano espanol']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 67.0, \"Danceability\": 0.827, \"Energy\": 0.629, \"Loudness\": -3.966, \"Speechiness\": 0.185, \"Acousticness\": 0.183, \"Liveness\": 0.084, \"Tempo\": 88.064, \"Duration (ms)\": 187500.0, \"Valence\": 0.486, \"Chord\": \"F#/Gb\"}, {\"Index\": 964, \"Highest Charting Position\": 50, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Walk Em Down (feat. Roddy Ricch)\", \"Streams\": 4371370, \"Artist\": \"NLE Choppa\", \"Artist Followers\": 6608815.0, \"Song ID\": \"4cSSL3YafYjM3yjgFO1vJg\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 74.0, \"Danceability\": 0.867, \"Energy\": 0.744, \"Loudness\": -5.171, \"Speechiness\": 0.227, \"Acousticness\": 0.268, \"Liveness\": 0.0713, \"Tempo\": 84.005, \"Duration (ms)\": 173288.0, \"Valence\": 0.645, \"Chord\": \"D\"}, {\"Index\": 965, \"Highest Charting Position\": 74, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Wow.\", \"Streams\": 4351784, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"7xQAfvXzm3AkraOtGPWIZg\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.829, \"Energy\": 0.539, \"Loudness\": -7.359, \"Speechiness\": 0.208, \"Acousticness\": 0.136, \"Liveness\": 0.103, \"Tempo\": 99.96, \"Duration (ms)\": 149547.0, \"Valence\": 0.388, \"Chord\": \"B\"}, {\"Index\": 966, \"Highest Charting Position\": 13, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"mirrorball\", \"Streams\": 5564072, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0ZNU020wNYvgW84iljPkPP\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.553, \"Energy\": 0.413, \"Loudness\": -10.037, \"Speechiness\": 0.0334, \"Acousticness\": 0.687, \"Liveness\": 0.0594, \"Tempo\": 110.107, \"Duration (ms)\": 208978.0, \"Valence\": 0.379, \"Chord\": \"D\"}, {\"Index\": 967, \"Highest Charting Position\": 15, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"seven\", \"Streams\": 5459423, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6KJqZcs9XDgVck7Lg9QOTC\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 69.0, \"Danceability\": 0.596, \"Energy\": 0.488, \"Loudness\": -10.769, \"Speechiness\": 0.0274, \"Acousticness\": 0.9, \"Liveness\": 0.091, \"Tempo\": 94.926, \"Duration (ms)\": 208907.0, \"Valence\": 0.415, \"Chord\": \"E\"}, {\"Index\": 968, \"Highest Charting Position\": 18, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"this is me trying\", \"Streams\": 5128412, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7kt9e9LFSpN1zQtYEl19o1\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.515, \"Energy\": 0.476, \"Loudness\": -9.843, \"Speechiness\": 0.0328, \"Acousticness\": 0.314, \"Liveness\": 0.171, \"Tempo\": 135.886, \"Duration (ms)\": 195097.0, \"Valence\": 0.412, \"Chord\": \"A\"}, {\"Index\": 969, \"Highest Charting Position\": 24, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"betty\", \"Streams\": 5112180, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5kI4eCXXzyuIUXjQra0Cxi\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.593, \"Energy\": 0.377, \"Loudness\": -8.761, \"Speechiness\": 0.0253, \"Acousticness\": 0.6, \"Liveness\": 0.0976, \"Tempo\": 95.939, \"Duration (ms)\": 294521.0, \"Valence\": 0.502, \"Chord\": \"C\"}, {\"Index\": 970, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"BLIND (feat. Young Thug)\", \"Streams\": 5074613, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"2T5NBwKRySiCR78vVk08vr\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-08-04\", \"Weeks Charted\": \"2020-08-07--2020-08-14\", \"Popularity\": 69.0, \"Danceability\": 0.709, \"Energy\": 0.679, \"Loudness\": -6.503, \"Speechiness\": 0.346, \"Acousticness\": 0.0115, \"Liveness\": 0.0971, \"Tempo\": 162.973, \"Duration (ms)\": 153467.0, \"Valence\": 0.754, \"Chord\": \"B\"}, {\"Index\": 971, \"Highest Charting Position\": 20, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"illicit affairs\", \"Streams\": 5053658, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2NmsngXHeC1GQ9wWrzhOMf\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.559, \"Energy\": 0.31, \"Loudness\": -10.445, \"Speechiness\": 0.0338, \"Acousticness\": 0.881, \"Liveness\": 0.106, \"Tempo\": 119.845, \"Duration (ms)\": 190898.0, \"Valence\": 0.46, \"Chord\": \"A#/Bb\"}, {\"Index\": 972, \"Highest Charting Position\": 170, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Freak\", \"Streams\": 4736059, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"3aA6xB0tOilDDX17fIJ0Bl\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2020-08-07--2020-08-14\", \"Popularity\": 75.0, \"Danceability\": 0.688, \"Energy\": 0.716, \"Loudness\": -5.702, \"Speechiness\": 0.0385, \"Acousticness\": 0.0969, \"Liveness\": 0.0989, \"Tempo\": 116.912, \"Duration (ms)\": 284480.0, \"Valence\": 0.373, \"Chord\": \"G\"}, {\"Index\": 973, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"PUNANI\", \"Streams\": 4625985, \"Artist\": \"6ix9ine\", \"Artist Followers\": 6514102.0, \"Song ID\": \"41xKiK40e7MFu1bqcGSz1d\", \"Genre\": \"['emo rap', 'rap']\", \"Release Date\": \"2020-08-02\", \"Weeks Charted\": \"2020-08-07--2020-08-14\", \"Popularity\": 58.0, \"Danceability\": 0.841, \"Energy\": 0.541, \"Loudness\": -7.121, \"Speechiness\": 0.229, \"Acousticness\": 0.0186, \"Liveness\": 0.123, \"Tempo\": 97.961, \"Duration (ms)\": 115255.0, \"Valence\": 0.42, \"Chord\": \"A\"}, {\"Index\": 974, \"Highest Charting Position\": 50, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Bl\\u00e4ulich\", \"Streams\": 4599408, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"2WRTnY0slmFgWcrmEr8dPj\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 60.0, \"Danceability\": 0.79, \"Energy\": 0.704, \"Loudness\": -7.935, \"Speechiness\": 0.417, \"Acousticness\": 0.069, \"Liveness\": 0.113, \"Tempo\": 154.007, \"Duration (ms)\": 196213.0, \"Valence\": 0.212, \"Chord\": \"A#/Bb\"}, {\"Index\": 975, \"Highest Charting Position\": 170, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Never Let Me Down\", \"Streams\": 4522005, \"Artist\": \"VIZE, Tom Gregory\", \"Artist Followers\": 141016.0, \"Song ID\": \"3bXiWZWR3CoZbhcsqfsMNa\", \"Genre\": \"['dance pop', 'german dance', 'pop dance', 'slap house', 'tropical house']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 61.0, \"Danceability\": 0.758, \"Energy\": 0.848, \"Loudness\": -3.84, \"Speechiness\": 0.0457, \"Acousticness\": 0.21, \"Liveness\": 0.114, \"Tempo\": 127.96, \"Duration (ms)\": 153149.0, \"Valence\": 0.706, \"Chord\": \"A#/Bb\"}, {\"Index\": 976, \"Highest Charting Position\": 16, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Savage\", \"Streams\": 4510218, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"55CHeLEfn5iJ0IIkgaa4si\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 75.0, \"Danceability\": 0.843, \"Energy\": 0.741, \"Loudness\": -5.609, \"Speechiness\": 0.334, \"Acousticness\": 0.0252, \"Liveness\": 0.096, \"Tempo\": 168.983, \"Duration (ms)\": 155497.0, \"Valence\": 0.68, \"Chord\": \"B\"}, {\"Index\": 977, \"Highest Charting Position\": 29, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"mad woman\", \"Streams\": 6796343, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2QDyYdZyhlP2fp79KZX8Bi\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 67.0, \"Danceability\": 0.592, \"Energy\": 0.699, \"Loudness\": -8.995, \"Speechiness\": 0.0471, \"Acousticness\": 0.655, \"Liveness\": 0.114, \"Tempo\": 141.916, \"Duration (ms)\": 237258.0, \"Valence\": 0.506, \"Chord\": \"D#/Eb\"}, {\"Index\": 978, \"Highest Charting Position\": 33, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"epiphany\", \"Streams\": 6085522, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"08fa9LFcFBTcilB3iq2e2A\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 66.0, \"Danceability\": 0.354, \"Energy\": 0.267, \"Loudness\": -13.69, \"Speechiness\": 0.0281, \"Acousticness\": 0.731, \"Liveness\": 0.0858, \"Tempo\": 94.219, \"Duration (ms)\": 289749.0, \"Valence\": 0.113, \"Chord\": \"C#/Db\"}, {\"Index\": 979, \"Highest Charting Position\": 41, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"peace\", \"Streams\": 5943851, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7MbT4I8qGntX4fMdqMQgke\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 67.0, \"Danceability\": 0.647, \"Energy\": 0.272, \"Loudness\": -12.906, \"Speechiness\": 0.0916, \"Acousticness\": 0.918, \"Liveness\": 0.0918, \"Tempo\": 150.044, \"Duration (ms)\": 234000.0, \"Valence\": 0.339, \"Chord\": \"F\"}, {\"Index\": 980, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Move Ya Hips (feat. Nicki Minaj & MadeinTYO)\", \"Streams\": 5768616, \"Artist\": \"A$AP Ferg\", \"Artist Followers\": 3037935.0, \"Song ID\": \"13v5IXnvO2BccWwOx5rb4s\", \"Genre\": \"['hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap', 'underground hip hop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 61.0, \"Danceability\": 0.808, \"Energy\": 0.676, \"Loudness\": -4.902, \"Speechiness\": 0.223, \"Acousticness\": 0.0618, \"Liveness\": 0.11, \"Tempo\": 144.018, \"Duration (ms)\": 144973.0, \"Valence\": 0.0763, \"Chord\": \"E\"}, {\"Index\": 981, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Sie ruft\", \"Streams\": 5752169, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"4CyCHkhRsDXUeP5K4Y3xjU\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 59.0, \"Danceability\": 0.819, \"Energy\": 0.507, \"Loudness\": -7.336, \"Speechiness\": 0.0881, \"Acousticness\": 0.482, \"Liveness\": 0.105, \"Tempo\": 130.009, \"Duration (ms)\": 152013.0, \"Valence\": 0.634, \"Chord\": \"C#/Db\"}, {\"Index\": 982, \"Highest Charting Position\": 144, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Tilidin Weg\", \"Streams\": 5674945, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"7idxewQZ24F0gQy2EWE6Ug\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 60.0, \"Danceability\": 0.882, \"Energy\": 0.526, \"Loudness\": -8.553, \"Speechiness\": 0.237, \"Acousticness\": 0.118, \"Liveness\": 0.0835, \"Tempo\": 109.075, \"Duration (ms)\": 180950.0, \"Valence\": 0.182, \"Chord\": \"A#/Bb\"}, {\"Index\": 983, \"Highest Charting Position\": 149, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Over Your Head\", \"Streams\": 5534361, \"Artist\": \"Future, Lil Uzi Vert\", \"Artist Followers\": 10491105.0, \"Song ID\": \"0Tcw8w9pvPrZoORgxsNASW\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 59.0, \"Danceability\": 0.773, \"Energy\": 0.742, \"Loudness\": -5.453, \"Speechiness\": 0.162, \"Acousticness\": 0.00198, \"Liveness\": 0.558, \"Tempo\": 148.949, \"Duration (ms)\": 186843.0, \"Valence\": 0.35, \"Chord\": \"F\"}, {\"Index\": 984, \"Highest Charting Position\": 47, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"hoax\", \"Streams\": 5375944, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6MWoRt97mnSTXZhu3ggi9C\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 66.0, \"Danceability\": 0.662, \"Energy\": 0.181, \"Loudness\": -15.065, \"Speechiness\": 0.0415, \"Acousticness\": 0.966, \"Liveness\": 0.133, \"Tempo\": 118.819, \"Duration (ms)\": 220043.0, \"Valence\": 0.429, \"Chord\": \"G#/Ab\"}, {\"Index\": 985, \"Highest Charting Position\": 25, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Blood On My Jeans\", \"Streams\": 4978899, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"0fCwrjKfWxF3xQhZrYUw4T\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 73.0, \"Danceability\": 0.868, \"Energy\": 0.55, \"Loudness\": -6.417, \"Speechiness\": 0.226, \"Acousticness\": 0.183, \"Liveness\": 0.109, \"Tempo\": 117.943, \"Duration (ms)\": 154767.0, \"Valence\": 0.464, \"Chord\": \"F#/Gb\"}, {\"Index\": 986, \"Highest Charting Position\": 171, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Narrow Road (feat. Lil Baby)\", \"Streams\": 4828004, \"Artist\": \"NLE Choppa\", \"Artist Followers\": 3372385.0, \"Song ID\": \"3GZd1aDsgKL71Kt3VIp0hc\", \"Genre\": \"['memphis hip hop']\", \"Release Date\": \"2020-07-30\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 64.0, \"Danceability\": 0.614, \"Energy\": 0.553, \"Loudness\": -8.225, \"Speechiness\": 0.169, \"Acousticness\": 0.0306, \"Liveness\": 0.203, \"Tempo\": 159.999, \"Duration (ms)\": 240297.0, \"Valence\": 0.161, \"Chord\": \"G\"}, {\"Index\": 987, \"Highest Charting Position\": 26, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Amarillo\", \"Streams\": 4695091, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"6zEgnpM0qYmHLDnh8WPejL\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 73.0, \"Danceability\": 0.641, \"Energy\": 0.857, \"Loudness\": -5.725, \"Speechiness\": 0.301, \"Acousticness\": 0.013, \"Liveness\": 0.0695, \"Tempo\": 122.728, \"Duration (ms)\": 157733.0, \"Valence\": 0.961, \"Chord\": \"C#/Db\"}, {\"Index\": 988, \"Highest Charting Position\": 179, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Singapur\", \"Streams\": 4661170, \"Artist\": \"El Alfa, Chael Produciendo\", \"Artist Followers\": 1779640.0, \"Song ID\": \"4QfZYDhGZc0T2RDvGiI69E\", \"Genre\": \"['dembow', 'latin', 'rap dominicano', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 69.0, \"Danceability\": 0.853, \"Energy\": 0.909, \"Loudness\": -2.473, \"Speechiness\": 0.229, \"Acousticness\": 0.0522, \"Liveness\": 0.129, \"Tempo\": 112.987, \"Duration (ms)\": 178407.0, \"Valence\": 0.803, \"Chord\": \"G\"}, {\"Index\": 989, \"Highest Charting Position\": 42, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Tattoo\", \"Streams\": 4588064, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6096559.0, \"Song ID\": \"4ZRrLHqzhGRXYj2qcB4s5S\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-07-09\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 78.0, \"Danceability\": 0.848, \"Energy\": 0.637, \"Loudness\": -5.132, \"Speechiness\": 0.156, \"Acousticness\": 0.0413, \"Liveness\": 0.0521, \"Tempo\": 96.988, \"Duration (ms)\": 222680.0, \"Valence\": 0.698, \"Chord\": \"A\"}, {\"Index\": 990, \"Highest Charting Position\": 86, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Ego Death (feat. Kanye West, FKA twigs & Skrillex)\", \"Streams\": 4583475, \"Artist\": \"Ty Dolla $ign\", \"Artist Followers\": 3866304.0, \"Song ID\": \"3Q5cLvkKsHJvYltf8k7HkO\", \"Genre\": \"['hip hop', 'pop', 'pop rap', 'r&b', 'southern hip hop', 'trap', 'trap soul']\", \"Release Date\": \"2020-10-22\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 71.0, \"Danceability\": 0.818, \"Energy\": 0.598, \"Loudness\": -5.948, \"Speechiness\": 0.113, \"Acousticness\": 0.0573, \"Liveness\": 0.634, \"Tempo\": 111.052, \"Duration (ms)\": 231618.0, \"Valence\": 0.331, \"Chord\": \"A#/Bb\"}, {\"Index\": 991, \"Highest Charting Position\": 33, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Morado\", \"Streams\": 4561936, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"3mQ6SLdxxaL52Yte7KF2Ks\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-01-09\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 71.0, \"Danceability\": 0.881, \"Energy\": 0.696, \"Loudness\": -3.838, \"Speechiness\": 0.0797, \"Acousticness\": 0.137, \"Liveness\": 0.0927, \"Tempo\": 97.002, \"Duration (ms)\": 200667.0, \"Valence\": 0.781, \"Chord\": \"B\"}, {\"Index\": 992, \"Highest Charting Position\": 101, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"ocean eyes\", \"Streams\": 4476954, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6pFTDHGJtKOxrQ85xRZ8Ue\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 1.0, \"Danceability\": 0.358, \"Energy\": 0.372, \"Loudness\": -7.664, \"Speechiness\": 0.0464, \"Acousticness\": 0.81, \"Liveness\": 0.0877, \"Tempo\": 144.833, \"Duration (ms)\": 200387.0, \"Valence\": 0.16, \"Chord\": \"E\"}, {\"Index\": 993, \"Highest Charting Position\": 82, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Lion King On Ice\", \"Streams\": 8293983, \"Artist\": \"J. Cole\", \"Artist Followers\": 14103694.0, \"Song ID\": \"1ZvBVbsaNqHEP6ymXaPGlj\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2020-07-22\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 64.0, \"Danceability\": 0.732, \"Energy\": 0.663, \"Loudness\": -7.616, \"Speechiness\": 0.192, \"Acousticness\": 0.0819, \"Liveness\": 0.115, \"Tempo\": 139.964, \"Duration (ms)\": 210587.0, \"Valence\": 0.227, \"Chord\": \"F#/Gb\"}, {\"Index\": 994, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Andere Welt\", \"Streams\": 5600868, \"Artist\": \"Capital Bra, Clueso, KC Rebell\", \"Artist Followers\": 4093115.0, \"Song ID\": \"5PAAUJTKLT0nCmHUlLdPXb\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-07-23\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 60.0, \"Danceability\": 0.692, \"Energy\": 0.764, \"Loudness\": -5.233, \"Speechiness\": 0.113, \"Acousticness\": 0.574, \"Liveness\": 0.106, \"Tempo\": 84.029, \"Duration (ms)\": 189686.0, \"Valence\": 0.564, \"Chord\": \"F\"}, {\"Index\": 995, \"Highest Charting Position\": 163, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"TELL ME WHY\", \"Streams\": 5056986, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"3jlxX3VXPiY3lvBBbppQD3\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.6, \"Energy\": 0.723, \"Loudness\": -4.928, \"Speechiness\": 0.158, \"Acousticness\": 0.109, \"Liveness\": 0.167, \"Tempo\": 149.881, \"Duration (ms)\": 195268.0, \"Valence\": 0.463, \"Chord\": \"F#/Gb\"}, {\"Index\": 996, \"Highest Charting Position\": 37, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Stay High\", \"Streams\": 5047752, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"21CkzgKCBCq5V4XKjiGSIj\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 75.0, \"Danceability\": 0.745, \"Energy\": 0.5, \"Loudness\": -6.184, \"Speechiness\": 0.135, \"Acousticness\": 0.439, \"Liveness\": 0.0943, \"Tempo\": 76.968, \"Duration (ms)\": 168685.0, \"Valence\": 0.433, \"Chord\": \"G#/Ab\"}, {\"Index\": 997, \"Highest Charting Position\": 161, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"What Makes You Beautiful\", \"Streams\": 4966428, \"Artist\": \"One Direction\", \"Artist Followers\": 22536304.0, \"Song ID\": \"4cluDES4hQEUhmXj6TXkSo\", \"Genre\": \"['boy band', 'pop', 'post-teen pop', 'talent show']\", \"Release Date\": \"2012-05-25\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 82.0, \"Danceability\": 0.726, \"Energy\": 0.787, \"Loudness\": -2.494, \"Speechiness\": 0.0737, \"Acousticness\": 0.009, \"Liveness\": 0.0596, \"Tempo\": 124.99, \"Duration (ms)\": 199987.0, \"Valence\": 0.888, \"Chord\": \"E\"}, {\"Index\": 998, \"Highest Charting Position\": 174, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Shit Changed\", \"Streams\": 4823401, \"Artist\": \"Ufo361, Sonus030\", \"Artist Followers\": 1700759.0, \"Song ID\": \"6du77YHyGWoFjbuHCFBHU3\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 52.0, \"Danceability\": 0.824, \"Energy\": 0.528, \"Loudness\": -9.236, \"Speechiness\": 0.175, \"Acousticness\": 0.144, \"Liveness\": 0.104, \"Tempo\": 157.005, \"Duration (ms)\": 183839.0, \"Valence\": 0.32, \"Chord\": \"A\"}, {\"Index\": 999, \"Highest Charting Position\": 35, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Tell Me U Luv Me (with Trippie Redd)\", \"Streams\": 4798078, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5JAYDuLRkODlVt6dgoalKk\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 72.0, \"Danceability\": 0.66, \"Energy\": 0.76, \"Loudness\": -5.726, \"Speechiness\": 0.0787, \"Acousticness\": 0.291, \"Liveness\": 0.632, \"Tempo\": 127.984, \"Duration (ms)\": 180129.0, \"Valence\": 0.394, \"Chord\": \"D\"}, {\"Index\": 1000, \"Highest Charting Position\": 27, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Bad Energy\", \"Streams\": 4761155, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"7d94IqWX2UmSKMGUYSGFJG\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 72.0, \"Danceability\": 0.654, \"Energy\": 0.452, \"Loudness\": -6.36, \"Speechiness\": 0.0439, \"Acousticness\": 0.17, \"Liveness\": 0.114, \"Tempo\": 138.034, \"Duration (ms)\": 186749.0, \"Valence\": 0.532, \"Chord\": \"G\"}, {\"Index\": 1001, \"Highest Charting Position\": 24, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Titanic\", \"Streams\": 4687464, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"1YM6c2sxbf2Jacl9IFgn4I\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 71.0, \"Danceability\": 0.567, \"Energy\": 0.545, \"Loudness\": -6.668, \"Speechiness\": 0.0448, \"Acousticness\": 0.168, \"Liveness\": 0.112, \"Tempo\": 174.146, \"Duration (ms)\": 176650.0, \"Valence\": 0.234, \"Chord\": \"C#/Db\"}, {\"Index\": 1002, \"Highest Charting Position\": 31, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Skechers\", \"Streams\": 4669248, \"Artist\": \"DripReport\", \"Artist Followers\": 92356.0, \"Song ID\": \"2alc8VZAzDgdAsL2QMk3hu\", \"Genre\": \"['viral rap']\", \"Release Date\": \"2020-01-12\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 73.0, \"Danceability\": 0.903, \"Energy\": 0.327, \"Loudness\": -9.727, \"Speechiness\": 0.0877, \"Acousticness\": 0.26, \"Liveness\": 0.108, \"Tempo\": 100.008, \"Duration (ms)\": 106000.0, \"Valence\": 0.274, \"Chord\": \"C#/Db\"}, {\"Index\": 1003, \"Highest Charting Position\": 47, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"The Bigger Picture\", \"Streams\": 4629083, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"44gRhRi2OhEf7moAUj6MD1\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 70.0, \"Danceability\": 0.59, \"Energy\": 0.618, \"Loudness\": -5.756, \"Speechiness\": 0.334, \"Acousticness\": 0.0127, \"Liveness\": 0.244, \"Tempo\": 96.459, \"Duration (ms)\": 252729.0, \"Valence\": 0.153, \"Chord\": \"C#/Db\"}, {\"Index\": 1004, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Story of My Life\", \"Streams\": 4628772, \"Artist\": \"One Direction\", \"Artist Followers\": 22536304.0, \"Song ID\": \"4nVBt6MZDDP6tRVdQTgxJg\", \"Genre\": \"['boy band', 'pop', 'post-teen pop', 'talent show']\", \"Release Date\": \"2013-11-25\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 81.0, \"Danceability\": 0.6, \"Energy\": 0.663, \"Loudness\": -5.802, \"Speechiness\": 0.0477, \"Acousticness\": 0.225, \"Liveness\": 0.119, \"Tempo\": 121.07, \"Duration (ms)\": 245493.0, \"Valence\": 0.286, \"Chord\": \"D#/Eb\"}, {\"Index\": 1005, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Hit My Line\", \"Streams\": 4621205, \"Artist\": \"Logic\", \"Artist Followers\": 5449291.0, \"Song ID\": \"24FR8mXTaiGZPrxnkf1kcP\", \"Genre\": \"['conscious hip hop', 'dmv rap', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 60.0, \"Danceability\": 0.62, \"Energy\": 0.786, \"Loudness\": -5.22, \"Speechiness\": 0.167, \"Acousticness\": 0.143, \"Liveness\": 0.46, \"Tempo\": 164.057, \"Duration (ms)\": 265191.0, \"Valence\": 0.679, \"Chord\": \"A\"}, {\"Index\": 1006, \"Highest Charting Position\": 10, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Party Girl (Remix)\", \"Streams\": 15129295, \"Artist\": \"StaySolidRocky, Lil Uzi Vert\", \"Artist Followers\": 150587.0, \"Song ID\": \"0XkmeG97T4mtYlWRJcrxec\", \"Genre\": \"['melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 62.0, \"Danceability\": 0.752, \"Energy\": 0.375, \"Loudness\": -10.157, \"Speechiness\": 0.204, \"Acousticness\": 0.533, \"Liveness\": 0.175, \"Tempo\": 129.995, \"Duration (ms)\": 147673.0, \"Valence\": 0.591, \"Chord\": \"F#/Gb\"}, {\"Index\": 1007, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Up Up And Away\", \"Streams\": 6229316, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"7pbg3ABlAZv2NiIdKbBBFm\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 72.0, \"Danceability\": 0.661, \"Energy\": 0.665, \"Loudness\": -6.356, \"Speechiness\": 0.053, \"Acousticness\": 0.538, \"Liveness\": 0.0981, \"Tempo\": 75.059, \"Duration (ms)\": 147548.0, \"Valence\": 0.486, \"Chord\": \"E\"}, {\"Index\": 1008, \"Highest Charting Position\": 46, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Man Of The Year\", \"Streams\": 6223001, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"7AvprzMsRJpybaalckaT8c\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 73.0, \"Danceability\": 0.621, \"Energy\": 0.695, \"Loudness\": -5.124, \"Speechiness\": 0.0911, \"Acousticness\": 0.00584, \"Liveness\": 0.086, \"Tempo\": 173.966, \"Duration (ms)\": 136408.0, \"Valence\": 0.298, \"Chord\": \"E\"}, {\"Index\": 1009, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Fighting Demons\", \"Streams\": 5946573, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"0440JCJyIAmINA8KcYgFb5\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 70.0, \"Danceability\": 0.707, \"Energy\": 0.67, \"Loudness\": -6.328, \"Speechiness\": 0.257, \"Acousticness\": 0.0813, \"Liveness\": 0.098, \"Tempo\": 163.099, \"Duration (ms)\": 200629.0, \"Valence\": 0.235, \"Chord\": \"G\"}, {\"Index\": 1010, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Can't Die\", \"Streams\": 5777859, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4PPLJAEYBSOcnzr9TZoqf9\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 71.0, \"Danceability\": 0.652, \"Energy\": 0.671, \"Loudness\": -5.89, \"Speechiness\": 0.0756, \"Acousticness\": 0.0222, \"Liveness\": 0.107, \"Tempo\": 84.008, \"Duration (ms)\": 182922.0, \"Valence\": 0.274, \"Chord\": \"D\"}, {\"Index\": 1011, \"Highest Charting Position\": 44, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Screw Juice\", \"Streams\": 5394197, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4F6YLjakjqWFTgC5qfEwPQ\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 69.0, \"Danceability\": 0.595, \"Energy\": 0.528, \"Loudness\": -7.371, \"Speechiness\": 0.0935, \"Acousticness\": 0.082, \"Liveness\": 0.142, \"Tempo\": 150.075, \"Duration (ms)\": 179464.0, \"Valence\": 0.515, \"Chord\": \"F\"}, {\"Index\": 1012, \"Highest Charting Position\": 129, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Past Life (with Selena Gomez)\", \"Streams\": 5228433, \"Artist\": \"Trevor Daniel\", \"Artist Followers\": 632097.0, \"Song ID\": \"7MN8RYSofZsFROBlEOAzXq\", \"Genre\": \"['alternative r&b', 'melodic rap', 'pop rap']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 47.0, \"Danceability\": 0.575, \"Energy\": 0.543, \"Loudness\": -5.062, \"Speechiness\": 0.0529, \"Acousticness\": 0.102, \"Liveness\": 0.176, \"Tempo\": 159.905, \"Duration (ms)\": 186480.0, \"Valence\": 0.283, \"Chord\": \"D#/Eb\"}, {\"Index\": 1013, \"Highest Charting Position\": 45, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"I Want It\", \"Streams\": 5137482, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"2SVx3uds6jTWALFxevIWMA\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 69.0, \"Danceability\": 0.288, \"Energy\": 0.638, \"Loudness\": -6.935, \"Speechiness\": 0.0779, \"Acousticness\": 0.133, \"Liveness\": 0.14, \"Tempo\": 66.424, \"Duration (ms)\": 173114.0, \"Valence\": 0.147, \"Chord\": \"E\"}, {\"Index\": 1014, \"Highest Charting Position\": 56, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Ransom\", \"Streams\": 5097394, \"Artist\": \"Lil Tecca\", \"Artist Followers\": 4022792.0, \"Song ID\": \"1lOe9qE0vR9zwWQAOk6CoO\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-08-30\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.745, \"Energy\": 0.642, \"Loudness\": -6.257, \"Speechiness\": 0.287, \"Acousticness\": 0.0204, \"Liveness\": 0.0658, \"Tempo\": 179.974, \"Duration (ms)\": 131240.0, \"Valence\": 0.226, \"Chord\": \"G\"}, {\"Index\": 1015, \"Highest Charting Position\": 49, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Diosa\", \"Streams\": 4868180, \"Artist\": \"Myke Towers\", \"Artist Followers\": 6161098.0, \"Song ID\": \"3JHpk0DOTOzyh0777JFAky\", \"Genre\": \"['trap latino']\", \"Release Date\": \"2020-01-24\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 74.0, \"Danceability\": 0.801, \"Energy\": 0.745, \"Loudness\": -3.733, \"Speechiness\": 0.063, \"Acousticness\": 0.398, \"Liveness\": 0.153, \"Tempo\": 104.965, \"Duration (ms)\": 214013.0, \"Valence\": 0.245, \"Chord\": \"F#/Gb\"}, {\"Index\": 1016, \"Highest Charting Position\": 169, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Never Know (feat. SHIRIN DAVID)\", \"Streams\": 4803071, \"Artist\": \"Luciano\", \"Artist Followers\": 942380.0, \"Song ID\": \"5Hkj1XjMJv5QCGc9NwZm6z\", \"Genre\": \"['german drill', 'german hip hop']\", \"Release Date\": \"2020-07-16\", \"Weeks Charted\": \"2020-07-17--2020-07-24\", \"Popularity\": 60.0, \"Danceability\": 0.874, \"Energy\": 0.542, \"Loudness\": -7.064, \"Speechiness\": 0.344, \"Acousticness\": 0.0621, \"Liveness\": 0.181, \"Tempo\": 142.016, \"Duration (ms)\": 196933.0, \"Valence\": 0.481, \"Chord\": \"A#/Bb\"}, {\"Index\": 1017, \"Highest Charting Position\": 5, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"La Dif\\u00edcil\", \"Streams\": 4727554, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"6NfrH0ANGmgBXyxgV2PeXt\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 78.0, \"Danceability\": 0.685, \"Energy\": 0.848, \"Loudness\": -4.561, \"Speechiness\": 0.0858, \"Acousticness\": 0.0861, \"Liveness\": 0.0783, \"Tempo\": 179.87, \"Duration (ms)\": 163084.0, \"Valence\": 0.761, \"Chord\": \"G#/Ab\"}, {\"Index\": 1018, \"Highest Charting Position\": 20, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"TROLLZ (with Nicki Minaj)\", \"Streams\": 4700152, \"Artist\": \"6ix9ine\", \"Artist Followers\": 6514102.0, \"Song ID\": \"3dVvWnj4D8JGkKvo6Hucso\", \"Genre\": \"['emo rap', 'rap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 65.0, \"Danceability\": 0.744, \"Energy\": 0.422, \"Loudness\": -8.946, \"Speechiness\": 0.294, \"Acousticness\": 0.0319, \"Liveness\": 0.11, \"Tempo\": 180.006, \"Duration (ms)\": 202667.0, \"Valence\": 0.493, \"Chord\": \"C#/Db\"}, {\"Index\": 1019, \"Highest Charting Position\": 44, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Old Town Road - Remix\", \"Streams\": 4643817, \"Artist\": \"Lil Nas X, Billy Ray Cyrus\", \"Artist Followers\": 5488666.0, \"Song ID\": \"2YpeDb67231RjR0MgVLzsG\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.878, \"Energy\": 0.619, \"Loudness\": -5.56, \"Speechiness\": 0.102, \"Acousticness\": 0.0533, \"Liveness\": 0.113, \"Tempo\": 136.041, \"Duration (ms)\": 157067.0, \"Valence\": 0.639, \"Chord\": \"F#/Gb\"}, {\"Index\": 1020, \"Highest Charting Position\": 67, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"The Adventures of Moon Man & Slim Shady (with Eminem)\", \"Streams\": 4639929, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"38iBrrbbXyWaSPkmuDNgjZ\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 67.0, \"Danceability\": 0.88, \"Energy\": 0.787, \"Loudness\": -5.189, \"Speechiness\": 0.118, \"Acousticness\": 0.226, \"Liveness\": 0.12, \"Tempo\": 113.018, \"Duration (ms)\": 264834.0, \"Valence\": 0.588, \"Chord\": \"G#/Ab\"}, {\"Index\": 1021, \"Highest Charting Position\": 25, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"China\", \"Streams\": 4627026, \"Artist\": \"Anuel AA, Daddy Yankee, KAROL G, Ozuna, J Balvin\", \"Artist Followers\": 18306226.0, \"Song ID\": \"2ksOAxtIxY8yElEWw8RhgK\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2019-07-19\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.786, \"Energy\": 0.808, \"Loudness\": -3.702, \"Speechiness\": 0.0882, \"Acousticness\": 0.0846, \"Liveness\": 0.0822, \"Tempo\": 105.027, \"Duration (ms)\": 301714.0, \"Valence\": 0.609, \"Chord\": \"G\"}, {\"Index\": 1022, \"Highest Charting Position\": 29, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Hola - Remix\", \"Streams\": 4617726, \"Artist\": \"Dalex, Lenny Tav\\u00e1rez, Chencho Corleone, Juhn, D\\u00edmelo Flow\", \"Artist Followers\": 3600989.0, \"Song ID\": \"5stPVcRqb4qixbafP9e8lt\", \"Genre\": \"['latin', 'r&b en espanol', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-01\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.654, \"Energy\": 0.672, \"Loudness\": -5.98, \"Speechiness\": 0.311, \"Acousticness\": 0.471, \"Liveness\": 0.0781, \"Tempo\": 181.857, \"Duration (ms)\": 249520.0, \"Valence\": 0.343, \"Chord\": \"C\"}, {\"Index\": 1023, \"Highest Charting Position\": 6, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Ignorantes\", \"Streams\": 4613982, \"Artist\": \"Bad Bunny, Sech\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3wYRLYuO1M88d8woWUIxct\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 74.0, \"Danceability\": 0.85, \"Energy\": 0.536, \"Loudness\": -5.161, \"Speechiness\": 0.0599, \"Acousticness\": 0.267, \"Liveness\": 0.0996, \"Tempo\": 96.029, \"Duration (ms)\": 210607.0, \"Valence\": 0.505, \"Chord\": \"C#/Db\"}, {\"Index\": 1024, \"Highest Charting Position\": 2, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Yummy\", \"Streams\": 4599349, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"41L3O37CECZt3N7ziG2z7l\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-03\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 72.0, \"Danceability\": 0.687, \"Energy\": 0.514, \"Loudness\": -6.612, \"Speechiness\": 0.0897, \"Acousticness\": 0.366, \"Liveness\": 0.116, \"Tempo\": 145.921, \"Duration (ms)\": 210427.0, \"Valence\": 0.494, \"Chord\": \"A\"}, {\"Index\": 1025, \"Highest Charting Position\": 29, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"High Fashion (feat. Mustard)\", \"Streams\": 4592772, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6608815.0, \"Song ID\": \"07KXEDMj78x68D884wgVEm\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 77.0, \"Danceability\": 0.831, \"Energy\": 0.499, \"Loudness\": -8.442, \"Speechiness\": 0.114, \"Acousticness\": 0.269, \"Liveness\": 0.3, \"Tempo\": 97.956, \"Duration (ms)\": 220487.0, \"Valence\": 0.511, \"Chord\": \"B\"}, {\"Index\": 1026, \"Highest Charting Position\": 69, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Like That (feat. Gucci Mane)\", \"Streams\": 4565377, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"4EivmOT13NMpNSfTKn9p4s\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 77.0, \"Danceability\": 0.879, \"Energy\": 0.498, \"Loudness\": -6.027, \"Speechiness\": 0.18, \"Acousticness\": 0.239, \"Liveness\": 0.0967, \"Tempo\": 106.044, \"Duration (ms)\": 163173.0, \"Valence\": 0.405, \"Chord\": \"E\"}, {\"Index\": 1027, \"Highest Charting Position\": 132, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Goodbyes (feat. Young Thug)\", \"Streams\": 4527742, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"0t3ZvGKlmYmVsDzBJAXK8C\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 78.0, \"Danceability\": 0.548, \"Energy\": 0.653, \"Loudness\": -3.875, \"Speechiness\": 0.081, \"Acousticness\": 0.456, \"Liveness\": 0.103, \"Tempo\": 150.068, \"Duration (ms)\": 174853.0, \"Valence\": 0.163, \"Chord\": \"F\"}, {\"Index\": 1028, \"Highest Charting Position\": 23, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"BOP\", \"Streams\": 4496450, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"6Ozh9Ok6h4Oi1wUSLtBseN\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.769, \"Energy\": 0.787, \"Loudness\": -3.909, \"Speechiness\": 0.367, \"Acousticness\": 0.189, \"Liveness\": 0.129, \"Tempo\": 126.77, \"Duration (ms)\": 159715.0, \"Valence\": 0.836, \"Chord\": \"B\"}, {\"Index\": 1029, \"Highest Charting Position\": 21, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Sigues Con El\", \"Streams\": 4485060, \"Artist\": \"D\\u00edmelo Flow, Arcangel, Sech\", \"Artist Followers\": 231580.0, \"Song ID\": \"7sQKy5vlPQllr0k9IjYJv3\", \"Genre\": \"['latin', 'perreo', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.883, \"Energy\": 0.668, \"Loudness\": -2.957, \"Speechiness\": 0.113, \"Acousticness\": 0.11, \"Liveness\": 0.0734, \"Tempo\": 87.972, \"Duration (ms)\": 226533.0, \"Valence\": 0.676, \"Chord\": \"A\"}, {\"Index\": 1030, \"Highest Charting Position\": 78, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Anxiety - Intro\", \"Streams\": 8449557, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"02XcRGWPkvomFvzTamEKHg\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 60.0, \"Danceability\": 0.307, \"Energy\": 0.528, \"Loudness\": -11.337, \"Speechiness\": 0.108, \"Acousticness\": 0.972, \"Liveness\": 0.222, \"Tempo\": 174.795, \"Duration (ms)\": 70395.0, \"Valence\": 0.58, \"Chord\": \"B\"}, {\"Index\": 1031, \"Highest Charting Position\": 112, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Juice WRLD Speaks From Heaven - Outro\", \"Streams\": 6682917, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"1OjiYjgPZyxS0AiXiSnuYI\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 59.0, \"Danceability\": 0.392, \"Energy\": 0.373, \"Loudness\": -14.097, \"Speechiness\": 0.0968, \"Acousticness\": 0.991, \"Liveness\": 0.545, \"Tempo\": 121.678, \"Duration (ms)\": 30583.0, \"Valence\": 0.519, \"Chord\": \"C\"}, {\"Index\": 1032, \"Highest Charting Position\": 113, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"The Man, The Myth, The Legend - Interlude\", \"Streams\": 6640728, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4sjdZEEQvR1sXrRNSuBfbA\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 58.0, \"Danceability\": 0.667, \"Energy\": 0.447, \"Loudness\": -14.625, \"Speechiness\": 0.761, \"Acousticness\": 0.916, \"Liveness\": 0.612, \"Tempo\": 83.534, \"Duration (ms)\": 136545.0, \"Valence\": 0.829, \"Chord\": \"D\"}, {\"Index\": 1033, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Tiefschwarz (feat. Samra)\", \"Streams\": 5867111, \"Artist\": \"Kontra K\", \"Artist Followers\": 1818624.0, \"Song ID\": \"7jMMoHhgq6iwVT5ykyxsJt\", \"Genre\": \"['christlicher rap', 'german hip hop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 62.0, \"Danceability\": 0.751, \"Energy\": 0.783, \"Loudness\": -5.926, \"Speechiness\": 0.22, \"Acousticness\": 0.0715, \"Liveness\": 0.114, \"Tempo\": 94.003, \"Duration (ms)\": 189739.0, \"Valence\": 0.379, \"Chord\": \"G\"}, {\"Index\": 1034, \"Highest Charting Position\": 57, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Wash Us In The Blood\", \"Streams\": 5586085, \"Artist\": \"Kanye West, Travis Scott\", \"Artist Followers\": 14624703.0, \"Song ID\": \"7mEUjhl6aTztdHCrxoTgBG\", \"Genre\": \"['chicago rap', 'rap']\", \"Release Date\": \"2020-06-30\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 64.0, \"Danceability\": 0.67, \"Energy\": 0.847, \"Loudness\": -4.85, \"Speechiness\": 0.409, \"Acousticness\": 0.184, \"Liveness\": 0.304, \"Tempo\": 137.22, \"Duration (ms)\": 189827.0, \"Valence\": 0.381, \"Chord\": \"A#/Bb\"}, {\"Index\": 1035, \"Highest Charting Position\": 53, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Gangstas\", \"Streams\": 5104422, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"1hg3RlqFZXJb5YgRoK9qmF\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 71.0, \"Danceability\": 0.548, \"Energy\": 0.506, \"Loudness\": -7.434, \"Speechiness\": 0.102, \"Acousticness\": 0.203, \"Liveness\": 0.0788, \"Tempo\": 119.987, \"Duration (ms)\": 160000.0, \"Valence\": 0.557, \"Chord\": \"E\"}, {\"Index\": 1036, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Monster\", \"Streams\": 5030481, \"Artist\": \"Red Velvet - IRENE & SEULGI\", \"Artist Followers\": 383695.0, \"Song ID\": \"6c1QaQHdDhtFMfUkhueuXK\", \"Genre\": \"['k-pop']\", \"Release Date\": \"2020-07-06\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 70.0, \"Danceability\": 0.631, \"Energy\": 0.748, \"Loudness\": -2.569, \"Speechiness\": 0.0488, \"Acousticness\": 0.212, \"Liveness\": 0.537, \"Tempo\": 115.665, \"Duration (ms)\": 178413.0, \"Valence\": 0.351, \"Chord\": \"E\"}, {\"Index\": 1037, \"Highest Charting Position\": 139, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"YAYA\", \"Streams\": 4729070, \"Artist\": \"6ix9ine\", \"Artist Followers\": 6514102.0, \"Song ID\": \"6EfBMJQwe2xLgldra6DaYp\", \"Genre\": \"['emo rap', 'rap']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 60.0, \"Danceability\": 0.672, \"Energy\": 0.733, \"Loudness\": -5.377, \"Speechiness\": 0.0566, \"Acousticness\": 0.00289, \"Liveness\": 0.199, \"Tempo\": 105.043, \"Duration (ms)\": 149857.0, \"Valence\": 0.354, \"Chord\": \"B\"}, {\"Index\": 1038, \"Highest Charting Position\": 174, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Narcos\", \"Streams\": 4633313, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"7mcdgAXmb35dakBnfDIv3q\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 68.0, \"Danceability\": 0.614, \"Energy\": 0.746, \"Loudness\": -3.527, \"Speechiness\": 0.196, \"Acousticness\": 0.347, \"Liveness\": 0.0874, \"Tempo\": 168.072, \"Duration (ms)\": 259250.0, \"Valence\": 0.601, \"Chord\": \"A#/Bb\"}, {\"Index\": 1039, \"Highest Charting Position\": 105, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"This City\", \"Streams\": 4597406, \"Artist\": \"Sam Fischer\", \"Artist Followers\": 122883.0, \"Song ID\": \"3H3r2nKWa3Yk5gt8xgmsEt\", \"Genre\": \"['alt z', 'australian pop', 'dance pop', 'indie cafe pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2019-12-11\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 80.0, \"Danceability\": 0.605, \"Energy\": 0.377, \"Loudness\": -6.213, \"Speechiness\": 0.0443, \"Acousticness\": 0.733, \"Liveness\": 0.0808, \"Tempo\": 73.877, \"Duration (ms)\": 194853.0, \"Valence\": 0.519, \"Chord\": \"B\"}, {\"Index\": 1040, \"Highest Charting Position\": 64, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Make It Rain (feat. Rowdy Rebel)\", \"Streams\": 4594248, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"71d7LaAgPcNcUopu3OzmP7\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 62.0, \"Danceability\": 0.5, \"Energy\": 0.767, \"Loudness\": -4.105, \"Speechiness\": 0.403, \"Acousticness\": 0.162, \"Liveness\": 0.385, \"Tempo\": 159.477, \"Duration (ms)\": 202443.0, \"Valence\": 0.58, \"Chord\": \"C#/Db\"}, {\"Index\": 1041, \"Highest Charting Position\": 46, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lalala\", \"Streams\": 4541965, \"Artist\": \"Y2K, bbno$\", \"Artist Followers\": 268766.0, \"Song ID\": \"51Fjme0JiitpyXKuyQiCDo\", \"Genre\": \"['pop rap']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.843, \"Energy\": 0.39, \"Loudness\": -7.899, \"Speechiness\": 0.0846, \"Acousticness\": 0.178, \"Liveness\": 0.137, \"Tempo\": 129.972, \"Duration (ms)\": 160627.0, \"Valence\": 0.495, \"Chord\": \"D\"}, {\"Index\": 1042, \"Highest Charting Position\": 79, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Something Special\", \"Streams\": 4535580, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"5kkaSMcf4BFlhRRICCKZb6\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 72.0, \"Danceability\": 0.739, \"Energy\": 0.616, \"Loudness\": -6.963, \"Speechiness\": 0.0338, \"Acousticness\": 0.252, \"Liveness\": 0.101, \"Tempo\": 91.071, \"Duration (ms)\": 158466.0, \"Valence\": 0.654, \"Chord\": \"G\"}, {\"Index\": 1043, \"Highest Charting Position\": 58, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Aim For The Moon (feat. Quavo)\", \"Streams\": 9011502, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"6O7fPYTsb2mY0PiFt2ymDB\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 67.0, \"Danceability\": 0.713, \"Energy\": 0.605, \"Loudness\": -7.487, \"Speechiness\": 0.107, \"Acousticness\": 0.497, \"Liveness\": 0.115, \"Tempo\": 142.025, \"Duration (ms)\": 175756.0, \"Valence\": 0.432, \"Chord\": \"B\"}, {\"Index\": 1044, \"Highest Charting Position\": 63, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"44 BullDog\", \"Streams\": 8443771, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"7sjFIZ1g5QLJLGja3k592K\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 66.0, \"Danceability\": 0.8, \"Energy\": 0.564, \"Loudness\": -5.817, \"Speechiness\": 0.4, \"Acousticness\": 0.0287, \"Liveness\": 0.112, \"Tempo\": 139.989, \"Duration (ms)\": 150857.0, \"Valence\": 0.318, \"Chord\": \"G#/Ab\"}, {\"Index\": 1045, \"Highest Charting Position\": 88, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Creature (feat. Swae Lee)\", \"Streams\": 7308690, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"3eV2WT9YhfzkxbufnBF8wK\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 66.0, \"Danceability\": 0.794, \"Energy\": 0.717, \"Loudness\": -5.73, \"Speechiness\": 0.251, \"Acousticness\": 0.0511, \"Liveness\": 0.195, \"Tempo\": 141.881, \"Duration (ms)\": 202816.0, \"Valence\": 0.372, \"Chord\": \"G\"}, {\"Index\": 1046, \"Highest Charting Position\": 95, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Yea Yea\", \"Streams\": 7112419, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"0bjgQ24UZGwKikldIyEOgf\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 63.0, \"Danceability\": 0.717, \"Energy\": 0.474, \"Loudness\": -8.383, \"Speechiness\": 0.403, \"Acousticness\": 0.0509, \"Liveness\": 0.139, \"Tempo\": 123.906, \"Duration (ms)\": 185804.0, \"Valence\": 0.448, \"Chord\": \"F\"}, {\"Index\": 1047, \"Highest Charting Position\": 100, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Enjoy Yourself (feat. Karol G)\", \"Streams\": 6620040, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"3NWrHCwvyII4fTx05PN3IO\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 70.0, \"Danceability\": 0.764, \"Energy\": 0.676, \"Loudness\": -6.761, \"Speechiness\": 0.0927, \"Acousticness\": 0.389, \"Liveness\": 0.215, \"Tempo\": 97.02, \"Duration (ms)\": 197938.0, \"Valence\": 0.461, \"Chord\": \"B\"}, {\"Index\": 1048, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Bad Bitch From Tokyo (Intro)\", \"Streams\": 6144736, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"4OGIeHtYhRTJ8iW21UUyZW\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 59.0, \"Danceability\": 0.645, \"Energy\": 0.64, \"Loudness\": -6.871, \"Speechiness\": 0.179, \"Acousticness\": 0.395, \"Liveness\": 0.286, \"Tempo\": 140.248, \"Duration (ms)\": 48000.0, \"Valence\": 0.674, \"Chord\": \"A#/Bb\"}, {\"Index\": 1049, \"Highest Charting Position\": 117, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Snitching (feat. Quavo & Future)\", \"Streams\": 6102253, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"2FhEj9lvEIaJihjFprRrGt\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 59.0, \"Danceability\": 0.944, \"Energy\": 0.579, \"Loudness\": -4.961, \"Speechiness\": 0.191, \"Acousticness\": 0.0381, \"Liveness\": 0.253, \"Tempo\": 135.033, \"Duration (ms)\": 259346.0, \"Valence\": 0.769, \"Chord\": \"G#/Ab\"}, {\"Index\": 1050, \"Highest Charting Position\": 121, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"West Coast Shit (feat. Tyga & Quavo)\", \"Streams\": 5931242, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"1JDhNQ0oOT7XpclZn3aQ8F\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 61.0, \"Danceability\": 0.831, \"Energy\": 0.762, \"Loudness\": -5.656, \"Speechiness\": 0.207, \"Acousticness\": 0.0885, \"Liveness\": 0.107, \"Tempo\": 99.999, \"Duration (ms)\": 192000.0, \"Valence\": 0.495, \"Chord\": \"B\"}, {\"Index\": 1051, \"Highest Charting Position\": 72, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Deep End Freestyle\", \"Streams\": 5280810, \"Artist\": \"Sleepy Hallow, Foushe\\u00e9\", \"Artist Followers\": 411262.0, \"Song ID\": \"2AlYncTpVHKwHb55F9lF6O\", \"Genre\": \"['brooklyn drill', 'nyc rap']\", \"Release Date\": \"2020-06-05\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 72.0, \"Danceability\": 0.868, \"Energy\": 0.479, \"Loudness\": -6.687, \"Speechiness\": 0.445, \"Acousticness\": 0.703, \"Liveness\": 0.102, \"Tempo\": 133.928, \"Duration (ms)\": 115200.0, \"Valence\": 0.776, \"Chord\": \"E\"}, {\"Index\": 1052, \"Highest Charting Position\": 56, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Tommy Lee (feat. Post Malone)\", \"Streams\": 5031845, \"Artist\": \"Tyla Yaweh\", \"Artist Followers\": 359133.0, \"Song ID\": \"5QZKcQDp0tCcvMdyqEciBV\", \"Genre\": \"['cali rap', 'melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 73.0, \"Danceability\": 0.457, \"Energy\": 0.621, \"Loudness\": -5.923, \"Speechiness\": 0.138, \"Acousticness\": 0.218, \"Liveness\": 0.0944, \"Tempo\": 85.359, \"Duration (ms)\": 224638.0, \"Valence\": 0.634, \"Chord\": \"A#/Bb\"}, {\"Index\": 1053, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Tunnel Vision (Outro)\", \"Streams\": 4907751, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"2SxR5RitJdsG6wINvJLBSD\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 60.0, \"Danceability\": 0.718, \"Energy\": 0.66, \"Loudness\": -7.39, \"Speechiness\": 0.325, \"Acousticness\": 0.363, \"Liveness\": 0.159, \"Tempo\": 142.879, \"Duration (ms)\": 132587.0, \"Valence\": 0.659, \"Chord\": \"D\"}, {\"Index\": 1054, \"Highest Charting Position\": 7, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Si Veo a Tu Mam\\u00e1\", \"Streams\": 4638728, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"41wtwzCZkXwpnakmwJ239F\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 80.0, \"Danceability\": 0.9, \"Energy\": 0.603, \"Loudness\": -5.313, \"Speechiness\": 0.0646, \"Acousticness\": 0.402, \"Liveness\": 0.134, \"Tempo\": 129.928, \"Duration (ms)\": 170972.0, \"Valence\": 0.824, \"Chord\": \"D\"}, {\"Index\": 1055, \"Highest Charting Position\": 177, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Prospect (ft. Lil Baby)\", \"Streams\": 4571916, \"Artist\": \"iann dior\", \"Artist Followers\": 1276292.0, \"Song ID\": \"4iHSE5R1U8jf84tRn52xRt\", \"Genre\": \"['melodic rap', 'pop rap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 68.0, \"Danceability\": 0.816, \"Energy\": 0.579, \"Loudness\": -6.097, \"Speechiness\": 0.0867, \"Acousticness\": 0.203, \"Liveness\": 0.127, \"Tempo\": 120.078, \"Duration (ms)\": 226314.0, \"Valence\": 0.43, \"Chord\": \"C#/Db\"}, {\"Index\": 1056, \"Highest Charting Position\": 55, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"No Me Conoce - Remix\", \"Streams\": 4501188, \"Artist\": \"Jhay Cortez, J Balvin, Bad Bunny\", \"Artist Followers\": 2435159.0, \"Song ID\": \"4R8BJggjosTswLxtkw8V7P\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-05-24\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.806, \"Energy\": 0.786, \"Loudness\": -3.831, \"Speechiness\": 0.0741, \"Acousticness\": 0.145, \"Liveness\": 0.0935, \"Tempo\": 91.973, \"Duration (ms)\": 309120.0, \"Valence\": 0.58, \"Chord\": \"A#/Bb\"}, {\"Index\": 1057, \"Highest Charting Position\": 189, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"El Manual\", \"Streams\": 4470597, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"7kOf0qHO4Rcwk6QJifZDRJ\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 67.0, \"Danceability\": 0.843, \"Energy\": 0.845, \"Loudness\": -2.344, \"Speechiness\": 0.0503, \"Acousticness\": 0.35, \"Liveness\": 0.0527, \"Tempo\": 126.989, \"Duration (ms)\": 210624.0, \"Valence\": 0.898, \"Chord\": \"C\"}, {\"Index\": 1058, \"Highest Charting Position\": 181, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Thunder\", \"Streams\": 4468668, \"Artist\": \"Imagine Dragons\", \"Artist Followers\": 35299488.0, \"Song ID\": \"1zB4vmk8tFRmM9UULNzbLB\", \"Genre\": \"['modern rock', 'pop', 'rock']\", \"Release Date\": \"2017-06-23\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-05--2020-06-12\\n2020-02-07--2020-02-14\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.605, \"Energy\": 0.822, \"Loudness\": -4.833, \"Speechiness\": 0.0438, \"Acousticness\": 0.00671, \"Liveness\": 0.147, \"Tempo\": 167.997, \"Duration (ms)\": 187147.0, \"Valence\": 0.288, \"Chord\": \"C\"}, {\"Index\": 1059, \"Highest Charting Position\": 158, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"El Efecto - Remix\", \"Streams\": 4433384, \"Artist\": \"Rauw Alejandro, Chencho Corleone, KEVVO, Bryant Myers, Lyanno, Dalex\", \"Artist Followers\": 6096559.0, \"Song ID\": \"74j34STf8L6uADnTN69ohv\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 73.0, \"Danceability\": 0.771, \"Energy\": 0.769, \"Loudness\": -3.504, \"Speechiness\": 0.0694, \"Acousticness\": 0.18, \"Liveness\": 0.345, \"Tempo\": 167.969, \"Duration (ms)\": 289899.0, \"Valence\": 0.931, \"Chord\": \"C\"}, {\"Index\": 1060, \"Highest Charting Position\": 122, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Better Now\", \"Streams\": 4431571, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"7dt6x5M1jzdTEt8oCbisTK\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2018-04-27\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.68, \"Energy\": 0.578, \"Loudness\": -5.804, \"Speechiness\": 0.04, \"Acousticness\": 0.331, \"Liveness\": 0.135, \"Tempo\": 145.038, \"Duration (ms)\": 231267.0, \"Valence\": 0.341, \"Chord\": \"A#/Bb\"}, {\"Index\": 1061, \"Highest Charting Position\": 185, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Don't Stop Believin'\", \"Streams\": 4394985, \"Artist\": \"Journey\", \"Artist Followers\": 3731820.0, \"Song ID\": \"4bHsxqR3GMrXTxEPLuK5ue\", \"Genre\": \"['album rock', 'classic rock', 'hard rock', 'mellow gold', 'rock', 'soft rock']\", \"Release Date\": \"1981\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-19--2020-06-26\", \"Popularity\": 81.0, \"Danceability\": 0.5, \"Energy\": 0.748, \"Loudness\": -9.072, \"Speechiness\": 0.0363, \"Acousticness\": 0.127, \"Liveness\": 0.447, \"Tempo\": 118.852, \"Duration (ms)\": 250987.0, \"Valence\": 0.514, \"Chord\": \"E\"}, {\"Index\": 1062, \"Highest Charting Position\": 90, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"BLACK PARADE\", \"Streams\": 5474807, \"Artist\": \"Beyonc\\u00e9\", \"Artist Followers\": 28335112.0, \"Song ID\": \"2qzUpSVI4NnPyWxbXwumTj\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'r&b']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 61.0, \"Danceability\": 0.824, \"Energy\": 0.555, \"Loudness\": -5.817, \"Speechiness\": 0.05, \"Acousticness\": 0.00337, \"Liveness\": 0.217, \"Tempo\": 120.002, \"Duration (ms)\": 281273.0, \"Valence\": 0.0611, \"Chord\": \"C#/Db\"}, {\"Index\": 1063, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"XXL\", \"Streams\": 5415994, \"Artist\": \"Miksu / Macloud, Summer Cem, Luciano, Jamule\", \"Artist Followers\": 30683.0, \"Song ID\": \"0p3euGPg5LgFeQGC7bBFuR\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 64.0, \"Danceability\": 0.798, \"Energy\": 0.527, \"Loudness\": -7.671, \"Speechiness\": 0.0447, \"Acousticness\": 0.227, \"Liveness\": 0.108, \"Tempo\": 114.008, \"Duration (ms)\": 166173.0, \"Valence\": 0.548, \"Chord\": \"F\"}, {\"Index\": 1064, \"Highest Charting Position\": 70, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Salt\", \"Streams\": 4874960, \"Artist\": \"Ava Max\", \"Artist Followers\": 1251372.0, \"Song ID\": \"2o2p9xH3bkSDLcp6phIF4J\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 1.0, \"Danceability\": 0.693, \"Energy\": 0.835, \"Loudness\": -3.242, \"Speechiness\": 0.0624, \"Acousticness\": 0.131, \"Liveness\": 0.073, \"Tempo\": 128.052, \"Duration (ms)\": 180283.0, \"Valence\": 0.744, \"Chord\": \"F#/Gb\"}, {\"Index\": 1065, \"Highest Charting Position\": 52, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Daisies\", \"Streams\": 4838067, \"Artist\": \"Katy Perry\", \"Artist Followers\": 18936929.0, \"Song ID\": \"4uqh9bualXNHXXwO2wPorc\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 68.0, \"Danceability\": 0.639, \"Energy\": 0.546, \"Loudness\": -5.382, \"Speechiness\": 0.0407, \"Acousticness\": 0.0837, \"Liveness\": 0.122, \"Tempo\": 122.179, \"Duration (ms)\": 173124.0, \"Valence\": 0.149, \"Chord\": \"C#/Db\"}, {\"Index\": 1066, \"Highest Charting Position\": 142, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Emotionally Scarred\", \"Streams\": 4633237, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"7ge7BHazYbVKi8qyZUX1Bm\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 71.0, \"Danceability\": 0.585, \"Energy\": 0.641, \"Loudness\": -4.269, \"Speechiness\": 0.133, \"Acousticness\": 0.0286, \"Liveness\": 0.316, \"Tempo\": 88.284, \"Duration (ms)\": 197530.0, \"Valence\": 0.266, \"Chord\": \"F#/Gb\"}, {\"Index\": 1067, \"Highest Charting Position\": 32, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Myron\", \"Streams\": 4593309, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"56uXDJRCuoS7abX3SkzHKQ\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 76.0, \"Danceability\": 0.771, \"Energy\": 0.654, \"Loudness\": -6.976, \"Speechiness\": 0.298, \"Acousticness\": 0.055, \"Liveness\": 0.214, \"Tempo\": 155.047, \"Duration (ms)\": 224955.0, \"Valence\": 0.573, \"Chord\": \"G#/Ab\"}, {\"Index\": 1068, \"Highest Charting Position\": 67, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"MORE & MORE\", \"Streams\": 4592745, \"Artist\": \"TWICE\", \"Artist Followers\": 9998991.0, \"Song ID\": \"3omvXShuRPM3zbDpWYqf5g\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-06-01\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 70.0, \"Danceability\": 0.739, \"Energy\": 0.841, \"Loudness\": -4.162, \"Speechiness\": 0.06, \"Acousticness\": 0.0312, \"Liveness\": 0.173, \"Tempo\": 106.99, \"Duration (ms)\": 199653.0, \"Valence\": 0.562, \"Chord\": \"F\"}, {\"Index\": 1069, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Girls in the Hood\", \"Streams\": 4577209, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"6WbTTAGKrQtCQvmc5BuYfh\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 72.0, \"Danceability\": 0.821, \"Energy\": 0.863, \"Loudness\": -3.159, \"Speechiness\": 0.353, \"Acousticness\": 0.00824, \"Liveness\": 0.0377, \"Tempo\": 180.013, \"Duration (ms)\": 154324.0, \"Valence\": 0.874, \"Chord\": \"F#/Gb\"}, {\"Index\": 1070, \"Highest Charting Position\": 169, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Parasite Eve\", \"Streams\": 4545883, \"Artist\": \"Bring Me The Horizon\", \"Artist Followers\": 3912138.0, \"Song ID\": \"5OxclJsdFESni44YlpNpkR\", \"Genre\": \"['melodic metalcore', 'metalcore', 'rock', 'uk metalcore']\", \"Release Date\": \"2020-06-25\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 67.0, \"Danceability\": 0.589, \"Energy\": 0.797, \"Loudness\": -5.464, \"Speechiness\": 0.15, \"Acousticness\": 0.0289, \"Liveness\": 0.383, \"Tempo\": 102.489, \"Duration (ms)\": 291813.0, \"Valence\": 0.232, \"Chord\": \"A\"}, {\"Index\": 1071, \"Highest Charting Position\": 78, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Sucker\", \"Streams\": 4543863, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"22vgEDb5hykfaTwLuskFGD\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-06-07\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.842, \"Energy\": 0.734, \"Loudness\": -5.065, \"Speechiness\": 0.0588, \"Acousticness\": 0.0427, \"Liveness\": 0.106, \"Tempo\": 137.958, \"Duration (ms)\": 181027.0, \"Valence\": 0.952, \"Chord\": \"C#/Db\"}, {\"Index\": 1072, \"Highest Charting Position\": 147, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"I Like Me Better\", \"Streams\": 4430642, \"Artist\": \"Lauv\", \"Artist Followers\": 4442273.0, \"Song ID\": \"2P91MQbaiQOfbiz9VqhqKQ\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-05-31\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.752, \"Energy\": 0.505, \"Loudness\": -7.621, \"Speechiness\": 0.253, \"Acousticness\": 0.535, \"Liveness\": 0.104, \"Tempo\": 91.97, \"Duration (ms)\": 197437.0, \"Valence\": 0.419, \"Chord\": \"A\"}, {\"Index\": 1073, \"Highest Charting Position\": 116, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"High Hopes\", \"Streams\": 4426791, \"Artist\": \"Panic! At The Disco\", \"Artist Followers\": 10850424.0, \"Song ID\": \"1rqqCSm0Qe4I9rUvWncaom\", \"Genre\": \"['modern rock']\", \"Release Date\": \"2018-06-22\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.579, \"Energy\": 0.904, \"Loudness\": -2.729, \"Speechiness\": 0.0618, \"Acousticness\": 0.193, \"Liveness\": 0.064, \"Tempo\": 82.014, \"Duration (ms)\": 190947.0, \"Valence\": 0.681, \"Chord\": \"F\"}, {\"Index\": 1074, \"Highest Charting Position\": 88, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Money In The Grave (Drake ft. Rick Ross)\", \"Streams\": 4403348, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5ry2OE6R2zPQFDO85XkgRb\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2019-06-15\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.831, \"Energy\": 0.502, \"Loudness\": -4.045, \"Speechiness\": 0.046, \"Acousticness\": 0.101, \"Liveness\": 0.122, \"Tempo\": 100.541, \"Duration (ms)\": 205427.0, \"Valence\": 0.101, \"Chord\": \"A#/Bb\"}, {\"Index\": 1075, \"Highest Charting Position\": 25, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Say So (feat. Nicki Minaj)\", \"Streams\": 4385148, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"11VApNQCWLJdzxWrlmwzUa\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 69.0, \"Danceability\": 0.856, \"Energy\": 0.641, \"Loudness\": -4.64, \"Speechiness\": 0.204, \"Acousticness\": 0.119, \"Liveness\": 0.427, \"Tempo\": 111.004, \"Duration (ms)\": 206221.0, \"Valence\": 0.745, \"Chord\": \"B\"}, {\"Index\": 1076, \"Highest Charting Position\": 189, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Karaoke\", \"Streams\": 4374448, \"Artist\": \"Boomdabash, Alessandra Amoroso\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3n6TeHSnNhDe991nJS2S90\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-10\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 0.0, \"Danceability\": 0.929, \"Energy\": 0.625, \"Loudness\": -5.728, \"Speechiness\": 0.14, \"Acousticness\": 0.289, \"Liveness\": 0.386, \"Tempo\": 122.03, \"Duration (ms)\": 156493.0, \"Valence\": 0.578, \"Chord\": \"C#/Db\"}, {\"Index\": 1077, \"Highest Charting Position\": 36, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Know Your Worth\", \"Streams\": 4374392, \"Artist\": \"Khalid, Disclosure\", \"Artist Followers\": 14190858.0, \"Song ID\": \"0TrPqhAMoaKUFLR7iYDokf\", \"Genre\": \"['pop']\", \"Release Date\": \"2020-02-04\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 76.0, \"Danceability\": 0.79, \"Energy\": 0.694, \"Loudness\": -7.726, \"Speechiness\": 0.0708, \"Acousticness\": 0.145, \"Liveness\": 0.281, \"Tempo\": 103.007, \"Duration (ms)\": 181436.0, \"Valence\": 0.508, \"Chord\": \"A\"}, {\"Index\": 1078, \"Highest Charting Position\": 26, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"No Idea\", \"Streams\": 4369849, \"Artist\": \"Don Toliver\", \"Artist Followers\": 1606884.0, \"Song ID\": \"7AzlLxHn24DxjgQX73F9fU\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.652, \"Energy\": 0.631, \"Loudness\": -5.718, \"Speechiness\": 0.0893, \"Acousticness\": 0.524, \"Liveness\": 0.165, \"Tempo\": 127.998, \"Duration (ms)\": 154424.0, \"Valence\": 0.35, \"Chord\": \"F#/Gb\"}, {\"Index\": 1079, \"Highest Charting Position\": 145, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Airwaves\", \"Streams\": 4352767, \"Artist\": \"Pashanim\", \"Artist Followers\": 208926.0, \"Song ID\": \"5CqkgDH8QZjSqqI3HmYxDD\", \"Genre\": \"['german alternative rap', 'german drill', 'german hip hop', 'german trap']\", \"Release Date\": \"2020-05-14\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 71.0, \"Danceability\": 0.885, \"Energy\": 0.578, \"Loudness\": -7.416, \"Speechiness\": 0.0783, \"Acousticness\": 0.0739, \"Liveness\": 0.102, \"Tempo\": 131.999, \"Duration (ms)\": 178933.0, \"Valence\": 0.388, \"Chord\": \"F\"}, {\"Index\": 1080, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Kill This Love\", \"Streams\": 4341050, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"6hvczQ05jc1yGlp9zhb95V\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2019-04-05\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 76.0, \"Danceability\": 0.763, \"Energy\": 0.835, \"Loudness\": -5.234, \"Speechiness\": 0.191, \"Acousticness\": 0.323, \"Liveness\": 0.225, \"Tempo\": 131.875, \"Duration (ms)\": 191050.0, \"Valence\": 0.645, \"Chord\": \"D\"}, {\"Index\": 1081, \"Highest Charting Position\": 68, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lights Up\", \"Streams\": 4325411, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16127908.0, \"Song ID\": \"4jAIqgrPjKLTY9Gbez25Qb\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.575, \"Energy\": 0.621, \"Loudness\": -8.165, \"Speechiness\": 0.032, \"Acousticness\": 0.0392, \"Liveness\": 0.141, \"Tempo\": 101.987, \"Duration (ms)\": 172213.0, \"Valence\": 0.27, \"Chord\": \"A#/Bb\"}, {\"Index\": 1082, \"Highest Charting Position\": 14, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Lose You To Love Me\", \"Streams\": 4322088, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4l0Mvzj72xxOpRrp6h8nHi\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.488, \"Energy\": 0.343, \"Loudness\": -8.985, \"Speechiness\": 0.0436, \"Acousticness\": 0.556, \"Liveness\": 0.21, \"Tempo\": 102.819, \"Duration (ms)\": 206459.0, \"Valence\": 0.0978, \"Chord\": \"E\"}, {\"Index\": 1083, \"Highest Charting Position\": 94, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Girls Like You (feat. Cardi B)\", \"Streams\": 4318772, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32279979.0, \"Song ID\": \"6V1bu6o1Yo5ZXnsCJU8Ovk\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2018-06-15\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.851, \"Energy\": 0.541, \"Loudness\": -6.825, \"Speechiness\": 0.0505, \"Acousticness\": 0.568, \"Liveness\": 0.13, \"Tempo\": 124.959, \"Duration (ms)\": 235545.0, \"Valence\": 0.448, \"Chord\": \"C\"}, {\"Index\": 1084, \"Highest Charting Position\": 47, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"PA' ROMPERLA\", \"Streams\": 4312675, \"Artist\": \"Bad Bunny, Don Omar\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5XqCz18k96K8tx6DAYM97i\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 72.0, \"Danceability\": 0.772, \"Energy\": 0.83, \"Loudness\": -5.019, \"Speechiness\": 0.0599, \"Acousticness\": 0.016, \"Liveness\": 0.0843, \"Tempo\": 94.011, \"Duration (ms)\": 194200.0, \"Valence\": 0.697, \"Chord\": \"G\"}, {\"Index\": 1085, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"VACATION\", \"Streams\": 6883487, \"Artist\": \"Tyga\", \"Artist Followers\": 6298789.0, \"Song ID\": \"6q2uIyLqASSpv2SIv2ehWK\", \"Genre\": \"['dance pop', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 51.0, \"Danceability\": 0.821, \"Energy\": 0.61, \"Loudness\": -6.22, \"Speechiness\": 0.0959, \"Acousticness\": 0.0247, \"Liveness\": 0.185, \"Tempo\": 110.973, \"Duration (ms)\": 192936.0, \"Valence\": 0.47, \"Chord\": \"C#/Db\"}, {\"Index\": 1086, \"Highest Charting Position\": 86, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Big Body Benz\", \"Streams\": 6707101, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"2WOJ7D52Ng3myrKlEf4Azj\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-06-18\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 61.0, \"Danceability\": 0.884, \"Energy\": 0.451, \"Loudness\": -8.969, \"Speechiness\": 0.393, \"Acousticness\": 0.0731, \"Liveness\": 0.268, \"Tempo\": 94.024, \"Duration (ms)\": 148284.0, \"Valence\": 0.311, \"Chord\": \"A\"}, {\"Index\": 1087, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Ich wei\\u00df nicht mal wie sie hei\\u00dft\", \"Streams\": 5827600, \"Artist\": \"Capital Bra, Bozza\", \"Artist Followers\": 4093115.0, \"Song ID\": \"4KfL3Ne8bc9bC2PUB8QGwA\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-06-18\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 57.0, \"Danceability\": 0.498, \"Energy\": 0.836, \"Loudness\": -3.905, \"Speechiness\": 0.184, \"Acousticness\": 0.525, \"Liveness\": 0.0994, \"Tempo\": 199.846, \"Duration (ms)\": 168750.0, \"Valence\": 0.609, \"Chord\": \"A#/Bb\"}, {\"Index\": 1088, \"Highest Charting Position\": 101, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"F\\u00fatbol & Rumba (feat. Enrique Iglesias)\", \"Streams\": 5124116, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"2hDe0Ls5mVqs1XJqv7sbcM\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 67.0, \"Danceability\": 0.735, \"Energy\": 0.916, \"Loudness\": -2.082, \"Speechiness\": 0.117, \"Acousticness\": 0.397, \"Liveness\": 0.0918, \"Tempo\": 167.994, \"Duration (ms)\": 221429.0, \"Valence\": 0.691, \"Chord\": \"D\"}, {\"Index\": 1089, \"Highest Charting Position\": 131, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Bleed\", \"Streams\": 5095478, \"Artist\": \"A Boogie Wit da Hoodie\", \"Artist Followers\": 5865895.0, \"Song ID\": \"5XzombolzpiaOSTdj1W0VS\", \"Genre\": \"['melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 61.0, \"Danceability\": 0.698, \"Energy\": 0.572, \"Loudness\": -7.735, \"Speechiness\": 0.198, \"Acousticness\": 0.135, \"Liveness\": 0.154, \"Tempo\": 71.446, \"Duration (ms)\": 176959.0, \"Valence\": 0.391, \"Chord\": \"D\"}, {\"Index\": 1090, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Snow On Tha Bluff\", \"Streams\": 5060764, \"Artist\": \"J. Cole\", \"Artist Followers\": 14103694.0, \"Song ID\": \"1oOEkBNp4zWnkD7nWjJdog\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2020-06-16\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 66.0, \"Danceability\": 0.586, \"Energy\": 0.512, \"Loudness\": -8.819, \"Speechiness\": 0.0668, \"Acousticness\": 0.723, \"Liveness\": 0.119, \"Tempo\": 75.857, \"Duration (ms)\": 235480.0, \"Valence\": 0.235, \"Chord\": \"G#/Ab\"}, {\"Index\": 1091, \"Highest Charting Position\": 113, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Djomb - Bien ou quoi\", \"Streams\": 4924714, \"Artist\": \"Bosh\", \"Artist Followers\": 300500.0, \"Song ID\": \"0KBwGCY9RYD9t2zjeW4h48\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 64.0, \"Danceability\": 0.945, \"Energy\": 0.676, \"Loudness\": -6.6, \"Speechiness\": 0.207, \"Acousticness\": 0.172, \"Liveness\": 0.322, \"Tempo\": 123.109, \"Duration (ms)\": 141893.0, \"Valence\": 0.631, \"Chord\": \"C#/Db\"}, {\"Index\": 1092, \"Highest Charting Position\": 84, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"In Your Eyes (feat. Alida)\", \"Streams\": 4654587, \"Artist\": \"Alida, Robin Schulz\", \"Artist Followers\": 2786366.0, \"Song ID\": \"61ZM92T2zaXIVsqncThQzC\", \"Genre\": \"['dance pop', 'deep euro house', 'deep house', 'edm', 'german dance', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 71.0, \"Danceability\": 0.57, \"Energy\": 0.672, \"Loudness\": -5.888, \"Speechiness\": 0.0716, \"Acousticness\": 0.172, \"Liveness\": 0.0768, \"Tempo\": 120.018, \"Duration (ms)\": 208222.0, \"Valence\": 0.461, \"Chord\": \"G#/Ab\"}, {\"Index\": 1093, \"Highest Charting Position\": 13, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Stupid Love\", \"Streams\": 4609858, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 1251372.0, \"Song ID\": \"1zPwSOUc5MPtPg8EgXAGKU\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-08\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 0.0, \"Danceability\": 0.68, \"Energy\": 0.825, \"Loudness\": -4.296, \"Speechiness\": 0.0702, \"Acousticness\": 0.00173, \"Liveness\": 0.27, \"Tempo\": 117.987, \"Duration (ms)\": 193533.0, \"Valence\": 0.784, \"Chord\": \"G#/Ab\"}, {\"Index\": 1094, \"Highest Charting Position\": 93, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Shotta Flow 5\", \"Streams\": 4513982, \"Artist\": \"NLE Choppa\", \"Artist Followers\": 3372385.0, \"Song ID\": \"1orjH4IkSH9VrWmRCToKV8\", \"Genre\": \"['memphis hip hop']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 62.0, \"Danceability\": 0.806, \"Energy\": 0.749, \"Loudness\": -5.268, \"Speechiness\": 0.328, \"Acousticness\": 0.0838, \"Liveness\": 0.0621, \"Tempo\": 140.032, \"Duration (ms)\": 145167.0, \"Valence\": 0.77, \"Chord\": \"C#/Db\"}, {\"Index\": 1095, \"Highest Charting Position\": 145, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"IDK You Yet\", \"Streams\": 4473413, \"Artist\": \"Alexander 23\", \"Artist Followers\": 207170.0, \"Song ID\": \"0j1Ia2lQWrcXrQZI4AdJlk\", \"Genre\": \"['alt z', 'indie cafe pop', 'pop', 'post-teen pop', 'social media pop']\", \"Release Date\": \"2020-06-23\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 79.0, \"Danceability\": 0.648, \"Energy\": 0.308, \"Loudness\": -11.729, \"Speechiness\": 0.04, \"Acousticness\": 0.886, \"Liveness\": 0.124, \"Tempo\": 76.997, \"Duration (ms)\": 184638.0, \"Valence\": 0.198, \"Chord\": \"C#/Db\"}, {\"Index\": 1096, \"Highest Charting Position\": 75, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Piece Of Your Heart\", \"Streams\": 4422905, \"Artist\": \"MEDUZA, Goodboys\", \"Artist Followers\": 441714.0, \"Song ID\": \"1DFD5Fotzgn6yYXkYsKiGs\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop house', 'tropical house']\", \"Release Date\": \"2019-02-01\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.677, \"Energy\": 0.744, \"Loudness\": -6.806, \"Speechiness\": 0.0295, \"Acousticness\": 0.0404, \"Liveness\": 0.074, \"Tempo\": 124.08, \"Duration (ms)\": 152913.0, \"Valence\": 0.631, \"Chord\": \"A#/Bb\"}, {\"Index\": 1097, \"Highest Charting Position\": 129, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Na Raba Toma Tap\\u00e3o\", \"Streams\": 4396629, \"Artist\": \"Niack\", \"Artist Followers\": 352402.0, \"Song ID\": \"0AGS6ZRgzobrazmCi6pYMe\", \"Genre\": \"['funk carioca']\", \"Release Date\": \"2020-06-06\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 61.0, \"Danceability\": 0.962, \"Energy\": 0.787, \"Loudness\": 1.509, \"Speechiness\": 0.0554, \"Acousticness\": 0.666, \"Liveness\": 0.176, \"Tempo\": 130.003, \"Duration (ms)\": 165231.0, \"Valence\": 0.968, \"Chord\": \"D#/Eb\"}, {\"Index\": 1098, \"Highest Charting Position\": 14, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"La Santa\", \"Streams\": 4384527, \"Artist\": \"Bad Bunny, Daddy Yankee\", \"Artist Followers\": 36177712.0, \"Song ID\": \"69vlMrzHwATKzupwNcUPyK\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 79.0, \"Danceability\": 0.744, \"Energy\": 0.868, \"Loudness\": -4.524, \"Speechiness\": 0.047, \"Acousticness\": 0.0326, \"Liveness\": 0.0822, \"Tempo\": 93.037, \"Duration (ms)\": 206420.0, \"Valence\": 0.586, \"Chord\": \"C#/Db\"}, {\"Index\": 1099, \"Highest Charting Position\": 125, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Make You Mine\", \"Streams\": 4356213, \"Artist\": \"PUBLIC\", \"Artist Followers\": 165504.0, \"Song ID\": \"5iFwAOB2TFkPJk8sMlxP8g\", \"Genre\": \"['indie rockism']\", \"Release Date\": \"2019-08-09\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 77.0, \"Danceability\": 0.606, \"Energy\": 0.799, \"Loudness\": -4.452, \"Speechiness\": 0.0261, \"Acousticness\": 0.0128, \"Liveness\": 0.15, \"Tempo\": 103.014, \"Duration (ms)\": 232907.0, \"Valence\": 0.638, \"Chord\": \"A\"}, {\"Index\": 1100, \"Highest Charting Position\": 76, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"ROCKSTAR (feat. Roddy Ricch) - BLM REMIX\", \"Streams\": 7353153, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"4Aykm3xrOFSHrAnv80KUhh\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 62.0, \"Danceability\": 0.747, \"Energy\": 0.689, \"Loudness\": -7.246, \"Speechiness\": 0.242, \"Acousticness\": 0.197, \"Liveness\": 0.0884, \"Tempo\": 89.901, \"Duration (ms)\": 204547.0, \"Valence\": 0.75, \"Chord\": \"B\"}, {\"Index\": 1101, \"Highest Charting Position\": 97, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Make It Rain\", \"Streams\": 6042929, \"Artist\": \"Pop Smoke, Rowdy Rebel\", \"Artist Followers\": 6852509.0, \"Song ID\": \"4TgHt7vKCimpywaiKfl0uj\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 64.0, \"Danceability\": 0.54, \"Energy\": 0.77, \"Loudness\": -3.981, \"Speechiness\": 0.389, \"Acousticness\": 0.194, \"Liveness\": 0.372, \"Tempo\": 159.494, \"Duration (ms)\": 204000.0, \"Valence\": 0.565, \"Chord\": \"C#/Db\"}, {\"Index\": 1102, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"M' Manc (con Geolier & Sfera Ebbasta)\", \"Streams\": 5171235, \"Artist\": \"Shablo\", \"Artist Followers\": 40045.0, \"Song ID\": \"0MLu1cFYL4ikdRTdasCQT9\", \"Genre\": \"['italian hip hop']\", \"Release Date\": \"2020-06-11\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 66.0, \"Danceability\": 0.703, \"Energy\": 0.704, \"Loudness\": -6.117, \"Speechiness\": 0.0641, \"Acousticness\": 0.048, \"Liveness\": 0.41, \"Tempo\": 139.933, \"Duration (ms)\": 180000.0, \"Valence\": 0.725, \"Chord\": \"F#/Gb\"}, {\"Index\": 1103, \"Highest Charting Position\": 143, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Emotions 2.0\", \"Streams\": 5113459, \"Artist\": \"Ufo361, C\\u00c9LINE\", \"Artist Followers\": 1700759.0, \"Song ID\": \"3yZCjDTxzZxx1kll1sRjGc\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 65.0, \"Danceability\": 0.788, \"Energy\": 0.491, \"Loudness\": -9.884, \"Speechiness\": 0.109, \"Acousticness\": 0.386, \"Liveness\": 0.107, \"Tempo\": 98.543, \"Duration (ms)\": 146028.0, \"Valence\": 0.271, \"Chord\": \"G#/Ab\"}, {\"Index\": 1104, \"Highest Charting Position\": 21, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"P2\", \"Streams\": 4769996, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"3kW4z2pIj5VY5fLjBrMRL5\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 73.0, \"Danceability\": 0.775, \"Energy\": 0.72, \"Loudness\": -5.353, \"Speechiness\": 0.193, \"Acousticness\": 0.0236, \"Liveness\": 0.114, \"Tempo\": 155.086, \"Duration (ms)\": 234627.0, \"Valence\": 0.49, \"Chord\": \"B\"}, {\"Index\": 1105, \"Highest Charting Position\": 79, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Selfish\", \"Streams\": 4754830, \"Artist\": \"Madison Beer\", \"Artist Followers\": 3370013.0, \"Song ID\": \"4PV0uE5pZSh44E3NqNNDEH\", \"Genre\": \"['alt z', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 70.0, \"Danceability\": 0.375, \"Energy\": 0.461, \"Loudness\": -6.202, \"Speechiness\": 0.0279, \"Acousticness\": 0.627, \"Liveness\": 0.386, \"Tempo\": 75.217, \"Duration (ms)\": 223270.0, \"Valence\": 0.233, \"Chord\": \"A\"}, {\"Index\": 1106, \"Highest Charting Position\": 154, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Surrender\", \"Streams\": 4627942, \"Artist\": \"Natalie Taylor\", \"Artist Followers\": 120208.0, \"Song ID\": \"0ecC8p17cDNlxHXkuYqeR6\", \"Genre\": \"[]\", \"Release Date\": \"2019-10-29\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 76.0, \"Danceability\": 0.39, \"Energy\": 0.448, \"Loudness\": -8.57, \"Speechiness\": 0.0276, \"Acousticness\": 0.8, \"Liveness\": 0.107, \"Tempo\": 144.89, \"Duration (ms)\": 183103.0, \"Valence\": 0.077, \"Chord\": \"F\"}, {\"Index\": 1107, \"Highest Charting Position\": 86, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Turks (with Gunna & ft. Travis Scott)\", \"Streams\": 4623279, \"Artist\": \"NAV\", \"Artist Followers\": 2613211.0, \"Song ID\": \"7IMwEtpAiJanqF6vQteZN2\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'hip hop', 'melodic rap', 'pop rap', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 67.0, \"Danceability\": 0.894, \"Energy\": 0.618, \"Loudness\": -4.356, \"Speechiness\": 0.129, \"Acousticness\": 0.0808, \"Liveness\": 0.558, \"Tempo\": 119.1, \"Duration (ms)\": 161320.0, \"Valence\": 0.379, \"Chord\": \"G\"}, {\"Index\": 1108, \"Highest Charting Position\": 48, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"BYE ME FUI\", \"Streams\": 4567732, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0FktnzDqjClqU6iqOZVEs2\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 72.0, \"Danceability\": 0.712, \"Energy\": 0.599, \"Loudness\": -6.342, \"Speechiness\": 0.112, \"Acousticness\": 0.412, \"Liveness\": 0.103, \"Tempo\": 179.788, \"Duration (ms)\": 178000.0, \"Valence\": 0.588, \"Chord\": \"F\"}, {\"Index\": 1109, \"Highest Charting Position\": 15, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Vete\", \"Streams\": 4486408, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5DxXgozhkPLgrbKFY91w0c\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-21\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.886, \"Energy\": 0.672, \"Loudness\": -4.394, \"Speechiness\": 0.188, \"Acousticness\": 0.0363, \"Liveness\": 0.101, \"Tempo\": 91.976, \"Duration (ms)\": 192024.0, \"Valence\": 0.526, \"Chord\": \"C#/Db\"}, {\"Index\": 1110, \"Highest Charting Position\": 43, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Like It Is\", \"Streams\": 4463865, \"Artist\": \"Kygo, Zara Larsson, Tyga\", \"Artist Followers\": 7593792.0, \"Song ID\": \"3frUvGrmGcay91lvFbOgsN\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 68.0, \"Danceability\": 0.794, \"Energy\": 0.728, \"Loudness\": -6.759, \"Speechiness\": 0.114, \"Acousticness\": 0.121, \"Liveness\": 0.227, \"Tempo\": 105.024, \"Duration (ms)\": 183067.0, \"Valence\": 0.36, \"Chord\": \"C#/Db\"}, {\"Index\": 1111, \"Highest Charting Position\": 15, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"My Oh My (feat. DaBaby)\", \"Streams\": 4413457, \"Artist\": \"Camila Cabello\", \"Artist Followers\": 22698747.0, \"Song ID\": \"3yOlyBJuViE2YSGn3nVE1K\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.724, \"Energy\": 0.491, \"Loudness\": -6.024, \"Speechiness\": 0.0296, \"Acousticness\": 0.018, \"Liveness\": 0.0887, \"Tempo\": 105.046, \"Duration (ms)\": 170746.0, \"Valence\": 0.383, \"Chord\": \"G#/Ab\"}, {\"Index\": 1112, \"Highest Charting Position\": 161, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Let Me Down Slowly\", \"Streams\": 4393932, \"Artist\": \"Alec Benjamin\", \"Artist Followers\": 2808285.0, \"Song ID\": \"2qxmye6gAegTMjLKEBoR3d\", \"Genre\": \"['alt z', 'electropop', 'pop']\", \"Release Date\": \"2018-11-16\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.652, \"Energy\": 0.557, \"Loudness\": -5.714, \"Speechiness\": 0.0318, \"Acousticness\": 0.74, \"Liveness\": 0.124, \"Tempo\": 150.073, \"Duration (ms)\": 169354.0, \"Valence\": 0.483, \"Chord\": \"C#/Db\"}, {\"Index\": 1113, \"Highest Charting Position\": 22, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"BELIEVE IT\", \"Streams\": 4361970, \"Artist\": \"PARTYNEXTDOOR, Rihanna\", \"Artist Followers\": 3129968.0, \"Song ID\": \"4HDCLYli2SUdkq9OjmvhSD\", \"Genre\": \"['pop', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap', 'urban contemporary']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 74.0, \"Danceability\": 0.43, \"Energy\": 0.7, \"Loudness\": -5.35, \"Speechiness\": 0.264, \"Acousticness\": 0.0902, \"Liveness\": 0.216, \"Tempo\": 158.373, \"Duration (ms)\": 183219.0, \"Valence\": 0.731, \"Chord\": \"F#/Gb\"}, {\"Index\": 1114, \"Highest Charting Position\": 86, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Boot\", \"Streams\": 6375562, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"12KENAKQY5JvAsRURN7TzB\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2020-06-05--2020-06-12\", \"Popularity\": 54.0, \"Danceability\": 0.534, \"Energy\": 0.565, \"Loudness\": -7.546, \"Speechiness\": 0.307, \"Acousticness\": 0.0627, \"Liveness\": 0.112, \"Tempo\": 194.034, \"Duration (ms)\": 193360.0, \"Valence\": 0.529, \"Chord\": \"G#/Ab\"}, {\"Index\": 1115, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Riot\", \"Streams\": 5163633, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"4aOOExMBUyxKnEYb39SrTg\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2020-06-01\", \"Weeks Charted\": \"2020-06-05--2020-06-12\", \"Popularity\": 70.0, \"Danceability\": 0.509, \"Energy\": 0.542, \"Loudness\": -8.027, \"Speechiness\": 0.442, \"Acousticness\": 0.019, \"Liveness\": 0.23, \"Tempo\": 97.767, \"Duration (ms)\": 78681.0, \"Valence\": 0.151, \"Chord\": \"D#/Eb\"}, {\"Index\": 1116, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"VALLA NEIN (feat. Luciano)\", \"Streams\": 5029858, \"Artist\": \"KC Rebell, Summer Cem\", \"Artist Followers\": 1101597.0, \"Song ID\": \"2rxxXYtTIFKyrhJpofeoIX\", \"Genre\": \"['german drill', 'german hip hop']\", \"Release Date\": \"2020-06-05\", \"Weeks Charted\": \"2020-06-05--2020-06-12\", \"Popularity\": 55.0, \"Danceability\": 0.761, \"Energy\": 0.657, \"Loudness\": -7.246, \"Speechiness\": 0.138, \"Acousticness\": 0.114, \"Liveness\": 0.356, \"Tempo\": 135.909, \"Duration (ms)\": 182040.0, \"Valence\": 0.589, \"Chord\": \"A#/Bb\"}, {\"Index\": 1117, \"Highest Charting Position\": 27, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"I\\u2019m Ready (with Demi Lovato)\", \"Streams\": 4764355, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"1fipvP2zmef6vN2IwXfJhY\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-04-16\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 68.0, \"Danceability\": 0.501, \"Energy\": 0.674, \"Loudness\": -6.363, \"Speechiness\": 0.0408, \"Acousticness\": 0.00346, \"Liveness\": 0.282, \"Tempo\": 155.051, \"Duration (ms)\": 200838.0, \"Valence\": 0.152, \"Chord\": \"F\"}, {\"Index\": 1118, \"Highest Charting Position\": 63, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"This Is America\", \"Streams\": 4727415, \"Artist\": \"Childish Gambino\", \"Artist Followers\": 8099554.0, \"Song ID\": \"0b9oOr2ZgvyQu88wzixux9\", \"Genre\": \"['atl hip hop', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2018-05-06\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 71.0, \"Danceability\": 0.854, \"Energy\": 0.463, \"Loudness\": -6.159, \"Speechiness\": 0.137, \"Acousticness\": 0.117, \"Liveness\": 0.354, \"Tempo\": 120.024, \"Duration (ms)\": 225773.0, \"Valence\": 0.549, \"Chord\": \"F\"}, {\"Index\": 1119, \"Highest Charting Position\": 33, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Fantasias\", \"Streams\": 4432324, \"Artist\": \"Rauw Alejandro, Farruko\", \"Artist Followers\": 6096559.0, \"Song ID\": \"6mAN61JH0dzyZpWslS11jy\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2019-08-29\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.879, \"Energy\": 0.703, \"Loudness\": -4.219, \"Speechiness\": 0.0701, \"Acousticness\": 0.143, \"Liveness\": 0.0569, \"Tempo\": 94.004, \"Duration (ms)\": 199711.0, \"Valence\": 0.788, \"Chord\": \"C#/Db\"}, {\"Index\": 1120, \"Highest Charting Position\": 60, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"BAD CON NICKY\", \"Streams\": 4432210, \"Artist\": \"Bad Bunny, Nicky Jam\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5bmSver2b3ZXyuyLKtgnFI\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 71.0, \"Danceability\": 0.59, \"Energy\": 0.729, \"Loudness\": -4.95, \"Speechiness\": 0.0893, \"Acousticness\": 0.321, \"Liveness\": 0.659, \"Tempo\": 93.094, \"Duration (ms)\": 202240.0, \"Valence\": 0.712, \"Chord\": \"G\"}, {\"Index\": 1121, \"Highest Charting Position\": 145, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"If I Can't Have You\", \"Streams\": 4364166, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 33893352.0, \"Song ID\": \"6LsAAHotRLMOHfCsSfYCsz\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2019-05-03\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.692, \"Energy\": 0.809, \"Loudness\": -4.198, \"Speechiness\": 0.0602, \"Acousticness\": 0.524, \"Liveness\": 0.147, \"Tempo\": 123.911, \"Duration (ms)\": 190800.0, \"Valence\": 0.864, \"Chord\": \"D\"}, {\"Index\": 1122, \"Highest Charting Position\": 27, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"What A Man Gotta Do\", \"Streams\": 4360660, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"4wNIkl5XGiAACjFBlDWuSd\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 77.0, \"Danceability\": 0.852, \"Energy\": 0.698, \"Loudness\": -7.206, \"Speechiness\": 0.0629, \"Acousticness\": 0.00839, \"Liveness\": 0.0773, \"Tempo\": 113.039, \"Duration (ms)\": 180645.0, \"Valence\": 0.324, \"Chord\": \"A\"}, {\"Index\": 1123, \"Highest Charting Position\": 50, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Callaita\", \"Streams\": 4350496, \"Artist\": \"Bad Bunny, Tainy\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2TH65lNHgvLxCKXM3apjxI\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-05-31\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.61, \"Energy\": 0.624, \"Loudness\": -4.773, \"Speechiness\": 0.309, \"Acousticness\": 0.6, \"Liveness\": 0.243, \"Tempo\": 176.169, \"Duration (ms)\": 250534.0, \"Valence\": 0.244, \"Chord\": \"D\"}, {\"Index\": 1124, \"Highest Charting Position\": 51, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Solitaires (feat. Travis Scott)\", \"Streams\": 4334669, \"Artist\": \"Future\", \"Artist Followers\": 10491105.0, \"Song ID\": \"4kfeRwpq5KUaqTkgi4TbDF\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 67.0, \"Danceability\": 0.691, \"Energy\": 0.632, \"Loudness\": -7.598, \"Speechiness\": 0.0513, \"Acousticness\": 0.122, \"Liveness\": 0.0646, \"Tempo\": 169.982, \"Duration (ms)\": 205666.0, \"Valence\": 0.488, \"Chord\": \"C#/Db\"}, {\"Index\": 1125, \"Highest Charting Position\": 137, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"XO Tour Llif3\", \"Streams\": 4314080, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7GX5flRQZVHRAGd6B4TmDO\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2017-08-25\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-08--2020-05-15\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 82.0, \"Danceability\": 0.732, \"Energy\": 0.75, \"Loudness\": -6.366, \"Speechiness\": 0.231, \"Acousticness\": 0.00264, \"Liveness\": 0.109, \"Tempo\": 155.096, \"Duration (ms)\": 182707.0, \"Valence\": 0.401, \"Chord\": \"B\"}, {\"Index\": 1126, \"Highest Charting Position\": 189, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"changes\", \"Streams\": 4299334, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"7AFASza1mXqntmGtbxXprO\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2018-03-16\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 81.0, \"Danceability\": 0.669, \"Energy\": 0.308, \"Loudness\": -10.068, \"Speechiness\": 0.029, \"Acousticness\": 0.883, \"Liveness\": 0.0984, \"Tempo\": 64.934, \"Duration (ms)\": 121887.0, \"Valence\": 0.52, \"Chord\": \"B\"}, {\"Index\": 1127, \"Highest Charting Position\": 66, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Suicidal (Remix) [feat. Juice WRLD]\", \"Streams\": 4296154, \"Artist\": \"YNW Melly\", \"Artist Followers\": 6332535.0, \"Song ID\": \"4S2uhQE8L9V6p7rj7SiauJ\", \"Genre\": \"['melodic rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 76.0, \"Danceability\": 0.655, \"Energy\": 0.441, \"Loudness\": -5.245, \"Speechiness\": 0.0629, \"Acousticness\": 0.474, \"Liveness\": 0.099, \"Tempo\": 139.957, \"Duration (ms)\": 225857.0, \"Valence\": 0.273, \"Chord\": \"A\"}, {\"Index\": 1128, \"Highest Charting Position\": 30, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Level of Concern\", \"Streams\": 4252898, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20829526.0, \"Song ID\": \"6xZ4Q2k2ompmDppyeESIY8\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 72.0, \"Danceability\": 0.754, \"Energy\": 0.583, \"Loudness\": -7.34, \"Speechiness\": 0.0432, \"Acousticness\": 0.32, \"Liveness\": 0.144, \"Tempo\": 122.012, \"Duration (ms)\": 220051.0, \"Valence\": 0.77, \"Chord\": \"E\"}, {\"Index\": 1129, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Alice\", \"Streams\": 10342277, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"41A89rj3GoMG6ktN37L7PG\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 64.0, \"Danceability\": 0.723, \"Energy\": 0.88, \"Loudness\": -4.287, \"Speechiness\": 0.038, \"Acousticness\": 0.00334, \"Liveness\": 0.0632, \"Tempo\": 123.036, \"Duration (ms)\": 177600.0, \"Valence\": 0.323, \"Chord\": \"B\"}, {\"Index\": 1130, \"Highest Charting Position\": 58, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Free Woman\", \"Streams\": 9266945, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"4L6ihclQPu1hqP9r3WNJjQ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 63.0, \"Danceability\": 0.731, \"Energy\": 0.927, \"Loudness\": -3.634, \"Speechiness\": 0.0781, \"Acousticness\": 0.0228, \"Liveness\": 0.187, \"Tempo\": 119.006, \"Duration (ms)\": 191467.0, \"Valence\": 0.478, \"Chord\": \"C\"}, {\"Index\": 1131, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Fun Tonight\", \"Streams\": 7907329, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"6hyQVqfHFvsJDjcmj4qrHf\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.645, \"Energy\": 0.923, \"Loudness\": -4.262, \"Speechiness\": 0.0725, \"Acousticness\": 0.364, \"Liveness\": 0.14, \"Tempo\": 117.945, \"Duration (ms)\": 173427.0, \"Valence\": 0.323, \"Chord\": \"B\"}, {\"Index\": 1132, \"Highest Charting Position\": 75, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Sine From Above (with Elton John)\", \"Streams\": 7734309, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"0zzsyWc45eUcSjw4FNHxeN\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 60.0, \"Danceability\": 0.642, \"Energy\": 0.792, \"Loudness\": -5.746, \"Speechiness\": 0.0488, \"Acousticness\": 0.158, \"Liveness\": 0.68, \"Tempo\": 122.965, \"Duration (ms)\": 244880.0, \"Valence\": 0.0903, \"Chord\": \"C\"}, {\"Index\": 1133, \"Highest Charting Position\": 77, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Enigma\", \"Streams\": 7695566, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"7JDbfYUHjDzQPFSDh5lzGs\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 59.0, \"Danceability\": 0.669, \"Energy\": 0.804, \"Loudness\": -4.035, \"Speechiness\": 0.036, \"Acousticness\": 0.0306, \"Liveness\": 0.694, \"Tempo\": 116.001, \"Duration (ms)\": 179760.0, \"Valence\": 0.184, \"Chord\": \"C\"}, {\"Index\": 1134, \"Highest Charting Position\": 79, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Replay\", \"Streams\": 7479618, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"7sKbyYeJnITO1Eh9xd0lKd\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 63.0, \"Danceability\": 0.658, \"Energy\": 0.878, \"Loudness\": -3.875, \"Speechiness\": 0.123, \"Acousticness\": 0.00792, \"Liveness\": 0.944, \"Tempo\": 122.015, \"Duration (ms)\": 186653.0, \"Valence\": 0.683, \"Chord\": \"C#/Db\"}, {\"Index\": 1135, \"Highest Charting Position\": 80, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Plastic Doll\", \"Streams\": 7451452, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"3CidPLqWXqgesJlwYVJZdy\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.743, \"Energy\": 0.853, \"Loudness\": -4.842, \"Speechiness\": 0.04, \"Acousticness\": 0.0019, \"Liveness\": 0.0872, \"Tempo\": 121.028, \"Duration (ms)\": 221667.0, \"Valence\": 0.422, \"Chord\": \"C\"}, {\"Index\": 1136, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Chromatica II\", \"Streams\": 7136521, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"0oQc0F6KUE7QY7k5TU6bic\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.184, \"Energy\": 0.297, \"Loudness\": -14.534, \"Speechiness\": 0.0359, \"Acousticness\": 0.473, \"Liveness\": 0.527, \"Tempo\": 75.824, \"Duration (ms)\": 41867.0, \"Valence\": 0.113, \"Chord\": \"D\"}, {\"Index\": 1137, \"Highest Charting Position\": 91, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Babylon\", \"Streams\": 6996402, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"5DttNeiizFqWUON9hZBqTY\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 61.0, \"Danceability\": 0.698, \"Energy\": 0.799, \"Loudness\": -4.372, \"Speechiness\": 0.0342, \"Acousticness\": 0.0129, \"Liveness\": 0.215, \"Tempo\": 115.957, \"Duration (ms)\": 161733.0, \"Valence\": 0.351, \"Chord\": \"D\"}, {\"Index\": 1138, \"Highest Charting Position\": 93, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Chromatica I\", \"Streams\": 6630385, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"0oQc0F6KUE7QY7k5TU6bic\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.184, \"Energy\": 0.297, \"Loudness\": -14.534, \"Speechiness\": 0.0359, \"Acousticness\": 0.473, \"Liveness\": 0.527, \"Tempo\": 75.824, \"Duration (ms)\": 41867.0, \"Valence\": 0.113, \"Chord\": \"D\"}, {\"Index\": 1139, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"1000 Doves\", \"Streams\": 6069544, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"62hTXlVQacy3pjBW4ntRPl\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.668, \"Energy\": 0.826, \"Loudness\": -4.466, \"Speechiness\": 0.0383, \"Acousticness\": 0.0236, \"Liveness\": 0.474, \"Tempo\": 122.973, \"Duration (ms)\": 215480.0, \"Valence\": 0.388, \"Chord\": \"A\"}, {\"Index\": 1140, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Broken Glass\", \"Streams\": 5867930, \"Artist\": \"Kygo, Kim Petras\", \"Artist Followers\": 7593792.0, \"Song ID\": \"78ldtCaBRJVp2i91B715L0\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 66.0, \"Danceability\": 0.526, \"Energy\": 0.633, \"Loudness\": -7.002, \"Speechiness\": 0.134, \"Acousticness\": 0.372, \"Liveness\": 0.129, \"Tempo\": 171.044, \"Duration (ms)\": 203947.0, \"Valence\": 0.272, \"Chord\": \"G\"}, {\"Index\": 1141, \"Highest Charting Position\": 131, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"In meinem Benz\", \"Streams\": 5494500, \"Artist\": \"AK AUSSERKONTROLLE, Bonez MC\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 1142, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"FLY\", \"Streams\": 4681054, \"Artist\": \"KC Rebell, Summer Cem\", \"Artist Followers\": 1101597.0, \"Song ID\": \"1WoM4mof0Nl1xPtwf6h6ow\", \"Genre\": \"['german drill', 'german hip hop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 59.0, \"Danceability\": 0.835, \"Energy\": 0.596, \"Loudness\": -6.637, \"Speechiness\": 0.297, \"Acousticness\": 0.137, \"Liveness\": 0.164, \"Tempo\": 100.706, \"Duration (ms)\": 174893.0, \"Valence\": 0.897, \"Chord\": \"F\"}, {\"Index\": 1143, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"SKRR\", \"Streams\": 4629320, \"Artist\": \"KALIM, Ufo361\", \"Artist Followers\": 218931.0, \"Song ID\": \"2J0adlQth373uw9y0yqWAz\", \"Genre\": \"['german hip hop', 'german trap', 'german underground rap', 'hamburg hip hop']\", \"Release Date\": \"2020-09-24\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 60.0, \"Danceability\": 0.803, \"Energy\": 0.649, \"Loudness\": -6.599, \"Speechiness\": 0.132, \"Acousticness\": 0.163, \"Liveness\": 0.152, \"Tempo\": 125.038, \"Duration (ms)\": 119040.0, \"Valence\": 0.584, \"Chord\": \"A#/Bb\"}, {\"Index\": 1144, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"T.D (Lil Yachty & Tierra Whack feat. A$AP Rocky & Tyler, The Creator)\", \"Streams\": 4601709, \"Artist\": \"Lil Yachty\", \"Artist Followers\": 7358720.0, \"Song ID\": \"0gO3E51A3fqp0ypJ26QbVP\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap', 'underground hip hop', 'viral rap']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 66.0, \"Danceability\": 0.784, \"Energy\": 0.632, \"Loudness\": -6.083, \"Speechiness\": 0.347, \"Acousticness\": 0.156, \"Liveness\": 0.605, \"Tempo\": 124.603, \"Duration (ms)\": 232839.0, \"Valence\": 0.746, \"Chord\": \"A#/Bb\"}, {\"Index\": 1145, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Oprah's Bank Account (Lil Yachty & DaBaby feat. Drake)\", \"Streams\": 4598294, \"Artist\": \"Lil Yachty\", \"Artist Followers\": 7358720.0, \"Song ID\": \"7wsmIIm0xWmtP7TmACXkJn\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap', 'underground hip hop', 'viral rap']\", \"Release Date\": \"2020-03-09\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 69.0, \"Danceability\": 0.836, \"Energy\": 0.617, \"Loudness\": -4.363, \"Speechiness\": 0.0534, \"Acousticness\": 0.17, \"Liveness\": 0.319, \"Tempo\": 138.066, \"Duration (ms)\": 206702.0, \"Valence\": 0.866, \"Chord\": \"C\"}, {\"Index\": 1146, \"Highest Charting Position\": 78, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Roadrunner\", \"Streams\": 4596162, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"0atjNG0rNW2m6zPaiK4Co7\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 64.0, \"Danceability\": 0.804, \"Energy\": 0.606, \"Loudness\": -9.045, \"Speechiness\": 0.242, \"Acousticness\": 0.137, \"Liveness\": 0.111, \"Tempo\": 99.024, \"Duration (ms)\": 149028.0, \"Valence\": 0.247, \"Chord\": \"G\"}, {\"Index\": 1147, \"Highest Charting Position\": 99, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Freedom\", \"Streams\": 4573723, \"Artist\": \"Kygo, Zak Abel\", \"Artist Followers\": 7593792.0, \"Song ID\": \"5Gj1wG8b12VQdEd3hUuSwo\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-05-29--2020-06-05\\n2020-04-17--2020-04-24\", \"Popularity\": 72.0, \"Danceability\": 0.715, \"Energy\": 0.635, \"Loudness\": -6.591, \"Speechiness\": 0.0791, \"Acousticness\": 0.127, \"Liveness\": 0.0862, \"Tempo\": 112.887, \"Duration (ms)\": 198635.0, \"Valence\": 0.39, \"Chord\": \"G\"}, {\"Index\": 1148, \"Highest Charting Position\": 45, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Fame\", \"Streams\": 4556947, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"3goH7O78TLkV9RhCAyM4AT\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 62.0, \"Danceability\": 0.811, \"Energy\": 0.645, \"Loudness\": -8.008, \"Speechiness\": 0.104, \"Acousticness\": 0.184, \"Liveness\": 0.103, \"Tempo\": 129.967, \"Duration (ms)\": 173761.0, \"Valence\": 0.474, \"Chord\": \"C#/Db\"}, {\"Index\": 1149, \"Highest Charting Position\": 55, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Daechwita\", \"Streams\": 8908179, \"Artist\": \"Agust D\", \"Artist Followers\": 5564366.0, \"Song ID\": \"0H4ugk6rhnXmTl47ayy9O5\", \"Genre\": \"['k-rap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 77.0, \"Danceability\": 0.65, \"Energy\": 0.827, \"Loudness\": -4.014, \"Speechiness\": 0.0599, \"Acousticness\": 0.0229, \"Liveness\": 0.121, \"Tempo\": 144.995, \"Duration (ms)\": 225668.0, \"Valence\": 0.223, \"Chord\": \"G#/Ab\"}, {\"Index\": 1150, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"COOLER THAN A BITCH (feat. Roddy Ricch)\", \"Streams\": 6642144, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"5LHHKZOwV8XW4LJP2C64mw\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 67.0, \"Danceability\": 0.837, \"Energy\": 0.586, \"Loudness\": -8.521, \"Speechiness\": 0.0807, \"Acousticness\": 0.281, \"Liveness\": 0.134, \"Tempo\": 117.066, \"Duration (ms)\": 197000.0, \"Valence\": 0.618, \"Chord\": \"B\"}, {\"Index\": 1151, \"Highest Charting Position\": 90, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"In Your Eyes (with Doja Cat) - Remix\", \"Streams\": 6511008, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"0UnTaVkntyh3vqvLEvbpQx\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-05-21\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 67.0, \"Danceability\": 0.679, \"Energy\": 0.731, \"Loudness\": -5.522, \"Speechiness\": 0.0319, \"Acousticness\": 0.00518, \"Liveness\": 0.0614, \"Tempo\": 99.984, \"Duration (ms)\": 237912.0, \"Valence\": 0.727, \"Chord\": \"G\"}, {\"Index\": 1152, \"Highest Charting Position\": 92, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"WUNNA\", \"Streams\": 6384306, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"0y7Ao3CVJsyKFmqdjutiIF\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 60.0, \"Danceability\": 0.89, \"Energy\": 0.455, \"Loudness\": -9.0, \"Speechiness\": 0.255, \"Acousticness\": 0.0217, \"Liveness\": 0.11, \"Tempo\": 148.009, \"Duration (ms)\": 158240.0, \"Valence\": 0.313, \"Chord\": \"C\"}, {\"Index\": 1153, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Komm Komm\", \"Streams\": 5552890, \"Artist\": \"Capital Bra\", \"Artist Followers\": 4093115.0, \"Song ID\": \"3US6RbELvvrPw3DcvtJmis\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-05-21\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 53.0, \"Danceability\": 0.485, \"Energy\": 0.793, \"Loudness\": -3.836, \"Speechiness\": 0.426, \"Acousticness\": 0.251, \"Liveness\": 0.146, \"Tempo\": 87.629, \"Duration (ms)\": 160667.0, \"Valence\": 0.371, \"Chord\": \"B\"}, {\"Index\": 1154, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"TOP FLOOR (feat. Travis Scott)\", \"Streams\": 5193309, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"4YhJ3a6kBPGJWX4Ek77sDd\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 63.0, \"Danceability\": 0.823, \"Energy\": 0.504, \"Loudness\": -8.65, \"Speechiness\": 0.16, \"Acousticness\": 0.206, \"Liveness\": 0.417, \"Tempo\": 112.985, \"Duration (ms)\": 169907.0, \"Valence\": 0.481, \"Chord\": \"G#/Ab\"}, {\"Index\": 1155, \"Highest Charting Position\": 54, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Goodbyes (Feat. Young Thug)\", \"Streams\": 5134161, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"0t3ZvGKlmYmVsDzBJAXK8C\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.548, \"Energy\": 0.653, \"Loudness\": -3.875, \"Speechiness\": 0.081, \"Acousticness\": 0.456, \"Liveness\": 0.103, \"Tempo\": 150.068, \"Duration (ms)\": 174853.0, \"Valence\": 0.163, \"Chord\": \"F\"}, {\"Index\": 1156, \"Highest Charting Position\": 59, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"CANCI\\u00d3N CON YANDEL\", \"Streams\": 5132247, \"Artist\": \"Yandel, Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3pm4XtcsRIFFtH2UErk62R\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 76.0, \"Danceability\": 0.75, \"Energy\": 0.741, \"Loudness\": -4.43, \"Speechiness\": 0.402, \"Acousticness\": 0.447, \"Liveness\": 0.121, \"Tempo\": 79.968, \"Duration (ms)\": 209180.0, \"Valence\": 0.495, \"Chord\": \"A\"}, {\"Index\": 1157, \"Highest Charting Position\": 92, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"X (with KAROL G)\", \"Streams\": 5018592, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"77fvnWALKJR0ws1VUx09CY\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 70.0, \"Danceability\": 0.715, \"Energy\": 0.827, \"Loudness\": -5.09, \"Speechiness\": 0.0617, \"Acousticness\": 0.0485, \"Liveness\": 0.321, \"Tempo\": 117.977, \"Duration (ms)\": 185277.0, \"Valence\": 0.75, \"Chord\": \"E\"}, {\"Index\": 1158, \"Highest Charting Position\": 56, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"M\\u00c1S DE UNA CITA\", \"Streams\": 4987116, \"Artist\": \"Bad Bunny, Zion & Lennox\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4EJHKSnHENfjOxXWryyNtL\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 67.0, \"Danceability\": 0.865, \"Energy\": 0.5, \"Loudness\": -10.805, \"Speechiness\": 0.0861, \"Acousticness\": 0.0122, \"Liveness\": 0.098, \"Tempo\": 92.976, \"Duration (ms)\": 183520.0, \"Valence\": 0.317, \"Chord\": \"F\"}, {\"Index\": 1159, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Together\", \"Streams\": 4861870, \"Artist\": \"Sia\", \"Artist Followers\": 20528724.0, \"Song ID\": \"5id3Rqn7SPj1LX4FfY4nGz\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'pop']\", \"Release Date\": \"2020-05-20\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 71.0, \"Danceability\": 0.521, \"Energy\": 0.877, \"Loudness\": -5.444, \"Speechiness\": 0.0683, \"Acousticness\": 0.0132, \"Liveness\": 0.0929, \"Tempo\": 180.007, \"Duration (ms)\": 205208.0, \"Valence\": 0.199, \"Chord\": \"G\"}, {\"Index\": 1160, \"Highest Charting Position\": 62, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"eight(Prod.&Feat. SUGA of BTS)\", \"Streams\": 4764954, \"Artist\": \"IU\", \"Artist Followers\": 4939593.0, \"Song ID\": \"0pYacDCZuRhcrwGUA5nTBe\", \"Genre\": \"['k-pop']\", \"Release Date\": \"2020-05-06\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 75.0, \"Danceability\": 0.676, \"Energy\": 0.869, \"Loudness\": -1.573, \"Speechiness\": 0.0423, \"Acousticness\": 0.115, \"Liveness\": 0.132, \"Tempo\": 120.029, \"Duration (ms)\": 167573.0, \"Valence\": 0.594, \"Chord\": \"C#/Db\"}, {\"Index\": 1161, \"Highest Charting Position\": 16, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"You should be sad\", \"Streams\": 4761908, \"Artist\": \"Halsey\", \"Artist Followers\": 15663384.0, \"Song ID\": \"7lidXGPXPYLNThITAOTlkK\", \"Genre\": \"['dance pop', 'electropop', 'etherpop', 'indie poptimism', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 76.0, \"Danceability\": 0.591, \"Energy\": 0.585, \"Loudness\": -6.35, \"Speechiness\": 0.0277, \"Acousticness\": 0.143, \"Liveness\": 0.109, \"Tempo\": 110.94, \"Duration (ms)\": 205473.0, \"Valence\": 0.324, \"Chord\": \"D\"}, {\"Index\": 1162, \"Highest Charting Position\": 54, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"CITY OF ANGELS\", \"Streams\": 4645541, \"Artist\": \"24kGoldn\", \"Artist Followers\": 1276406.0, \"Song ID\": \"6ap9lSRJ0iLriGLqoJ44cq\", \"Genre\": \"['cali rap']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 76.0, \"Danceability\": 0.686, \"Energy\": 0.541, \"Loudness\": -4.993, \"Speechiness\": 0.0493, \"Acousticness\": 0.042, \"Liveness\": 0.0675, \"Tempo\": 120.082, \"Duration (ms)\": 112493.0, \"Valence\": 0.724, \"Chord\": \"C\"}, {\"Index\": 1163, \"Highest Charting Position\": 98, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Astronomia\", \"Streams\": 4642284, \"Artist\": \"Vicetone, Tony Igy\", \"Artist Followers\": 378114.0, \"Song ID\": \"3hWfKBt3n7j1xqIy6LA5ve\", \"Genre\": \"['edm', 'electro house', 'pop dance', 'pop edm', 'progressive electro house', 'tropical house']\", \"Release Date\": \"2016-09-16\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 71.0, \"Danceability\": 0.653, \"Energy\": 0.945, \"Loudness\": -2.634, \"Speechiness\": 0.096, \"Acousticness\": 0.00561, \"Liveness\": 0.439, \"Tempo\": 126.093, \"Duration (ms)\": 198095.0, \"Valence\": 0.326, \"Chord\": \"F\"}, {\"Index\": 1164, \"Highest Charting Position\": 7, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"After Hours\", \"Streams\": 4559855, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"2p8IUWQDrpjuFltbdgLOag\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 75.0, \"Danceability\": 0.664, \"Energy\": 0.572, \"Loudness\": -6.099, \"Speechiness\": 0.0305, \"Acousticness\": 0.0811, \"Liveness\": 0.121, \"Tempo\": 108.959, \"Duration (ms)\": 361027.0, \"Valence\": 0.143, \"Chord\": \"F\"}, {\"Index\": 1165, \"Highest Charting Position\": 51, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"BUTTERFLY EFFECT\", \"Streams\": 4537762, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"2cYqizR4lgvp4Qu6IQ3qGN\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2018-08-03\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 79.0, \"Danceability\": 0.763, \"Energy\": 0.628, \"Loudness\": -5.85, \"Speechiness\": 0.05, \"Acousticness\": 0.0531, \"Liveness\": 0.114, \"Tempo\": 140.958, \"Duration (ms)\": 190557.0, \"Valence\": 0.193, \"Chord\": \"B\"}, {\"Index\": 1166, \"Highest Charting Position\": 74, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Never Seen the Rain\", \"Streams\": 4473968, \"Artist\": \"Tones And I\", \"Artist Followers\": 1251372.0, \"Song ID\": \"1xUCDewhwnORlcFflAgml0\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.742, \"Energy\": 0.464, \"Loudness\": -5.624, \"Speechiness\": 0.0318, \"Acousticness\": 0.425, \"Liveness\": 0.284, \"Tempo\": 92.107, \"Duration (ms)\": 200742.0, \"Valence\": 0.281, \"Chord\": \"F#/Gb\"}, {\"Index\": 1167, \"Highest Charting Position\": 120, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Sigues Con El - Remix\", \"Streams\": 4440738, \"Artist\": \"Arcangel, Sech, Romeo Santos\", \"Artist Followers\": 6671084.0, \"Song ID\": \"4Pu0a2TuHOYtI4CCE3HEXI\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-04-10\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 69.0, \"Danceability\": 0.747, \"Energy\": 0.693, \"Loudness\": -2.97, \"Speechiness\": 0.298, \"Acousticness\": 0.102, \"Liveness\": 0.0872, \"Tempo\": 175.994, \"Duration (ms)\": 189567.0, \"Valence\": 0.736, \"Chord\": \"C#/Db\"}, {\"Index\": 1168, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"ANGELS & DEMONS\", \"Streams\": 4435538, \"Artist\": \"jxdn\", \"Artist Followers\": 799682.0, \"Song ID\": \"3mkz6eI4Sram8UhO3teU76\", \"Genre\": \"[]\", \"Release Date\": \"2021-07-02\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 72.0, \"Danceability\": 0.554, \"Energy\": 0.8, \"Loudness\": -3.936, \"Speechiness\": 0.0395, \"Acousticness\": 0.119, \"Liveness\": 0.629, \"Tempo\": 115.056, \"Duration (ms)\": 160120.0, \"Valence\": 0.463, \"Chord\": \"G#/Ab\"}, {\"Index\": 1169, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Conf\\u00eda\", \"Streams\": 4419295, \"Artist\": \"Sech, Daddy Yankee\", \"Artist Followers\": 8766508.0, \"Song ID\": \"5kbps8unnGH4raN5WduZuq\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-21\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 62.0, \"Danceability\": 0.722, \"Energy\": 0.757, \"Loudness\": -3.592, \"Speechiness\": 0.0782, \"Acousticness\": 0.17, \"Liveness\": 0.0657, \"Tempo\": 167.987, \"Duration (ms)\": 202308.0, \"Valence\": 0.763, \"Chord\": \"C\"}, {\"Index\": 1170, \"Highest Charting Position\": 44, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Mu\\u00e9velo\", \"Streams\": 4407165, \"Artist\": \"Nicky Jam, Daddy Yankee\", \"Artist Followers\": 14831925.0, \"Song ID\": \"4VgYtXCVJ7IbWAZ5ryfvEQ\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-01-08\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 72.0, \"Danceability\": 0.594, \"Energy\": 0.808, \"Loudness\": -2.409, \"Speechiness\": 0.0489, \"Acousticness\": 0.415, \"Liveness\": 0.565, \"Tempo\": 188.09, \"Duration (ms)\": 194892.0, \"Valence\": 0.919, \"Chord\": \"G\"}, {\"Index\": 1171, \"Highest Charting Position\": 105, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"All Bad (feat. Lil Uzi Vert)\", \"Streams\": 6194224, \"Artist\": \"Future\", \"Artist Followers\": 10491105.0, \"Song ID\": \"021lWIHJrURZrmvYQ1xcM8\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 60.0, \"Danceability\": 0.931, \"Energy\": 0.667, \"Loudness\": -7.043, \"Speechiness\": 0.318, \"Acousticness\": 0.0144, \"Liveness\": 0.15, \"Tempo\": 142.039, \"Duration (ms)\": 207739.0, \"Valence\": 0.667, \"Chord\": \"F#/Gb\"}, {\"Index\": 1172, \"Highest Charting Position\": 12, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Pain 1993 (with Playboi Carti)\", \"Streams\": 6085143, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"6Kj17Afjo1OKJYpf5VzCeo\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 67.0, \"Danceability\": 0.825, \"Energy\": 0.373, \"Loudness\": -5.532, \"Speechiness\": 0.108, \"Acousticness\": 0.163, \"Liveness\": 0.368, \"Tempo\": 77.271, \"Duration (ms)\": 149078.0, \"Valence\": 0.12, \"Chord\": \"F\"}, {\"Index\": 1173, \"Highest Charting Position\": 110, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Trillionaire (feat. Youngboy Never Broke Again)\", \"Streams\": 6057848, \"Artist\": \"Future\", \"Artist Followers\": 10491105.0, \"Song ID\": \"740kQ8xwSGloumdiKR5Cwz\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 61.0, \"Danceability\": 0.768, \"Energy\": 0.526, \"Loudness\": -7.182, \"Speechiness\": 0.209, \"Acousticness\": 0.237, \"Liveness\": 0.139, \"Tempo\": 139.999, \"Duration (ms)\": 167552.0, \"Valence\": 0.473, \"Chord\": \"C\"}, {\"Index\": 1174, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Go Stupid\", \"Streams\": 5464816, \"Artist\": \"Polo G, Stunna 4 Vegas, NLE Choppa, Mike WiLL Made-It\", \"Artist Followers\": 4849204.0, \"Song ID\": \"4PklAHGXT5ityno3IA8SKd\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 74.0, \"Danceability\": 0.92, \"Energy\": 0.833, \"Loudness\": -3.18, \"Speechiness\": 0.253, \"Acousticness\": 0.0277, \"Liveness\": 0.0596, \"Tempo\": 141.034, \"Duration (ms)\": 165726.0, \"Valence\": 0.645, \"Chord\": \"C#/Db\"}, {\"Index\": 1175, \"Highest Charting Position\": 149, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"A Gente Fez Amor - Ao Vivo\", \"Streams\": 5006457, \"Artist\": \"Gusttavo Lima\", \"Artist Followers\": 12981319.0, \"Song ID\": \"3tv697PZNnaQN0Mn2zGhS5\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2019-12-05\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-02-07--2020-02-14\\n2020-01-03--2020-01-10\", \"Popularity\": 66.0, \"Danceability\": 0.794, \"Energy\": 0.937, \"Loudness\": -2.44, \"Speechiness\": 0.0336, \"Acousticness\": 0.366, \"Liveness\": 0.962, \"Tempo\": 134.012, \"Duration (ms)\": 237517.0, \"Valence\": 0.826, \"Chord\": \"G#/Ab\"}, {\"Index\": 1176, \"Highest Charting Position\": 173, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Racks 2 Skinny\", \"Streams\": 4729629, \"Artist\": \"Migos\", \"Artist Followers\": 11692972.0, \"Song ID\": \"568OIKgeHyGRD3uWR44JbO\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-11\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 61.0, \"Danceability\": 0.814, \"Energy\": 0.584, \"Loudness\": -5.425, \"Speechiness\": 0.0819, \"Acousticness\": 0.00839, \"Liveness\": 0.0646, \"Tempo\": 141.016, \"Duration (ms)\": 178025.0, \"Valence\": 0.405, \"Chord\": \"C#/Db\"}, {\"Index\": 1177, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Be Something (feat. Lil Baby)\", \"Streams\": 4687909, \"Artist\": \"Polo G\", \"Artist Followers\": 4849204.0, \"Song ID\": \"65jw6GhwQW3Db55PxlPEpS\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 69.0, \"Danceability\": 0.829, \"Energy\": 0.52, \"Loudness\": -10.34, \"Speechiness\": 0.294, \"Acousticness\": 0.0232, \"Liveness\": 0.134, \"Tempo\": 136.103, \"Duration (ms)\": 194118.0, \"Valence\": 0.248, \"Chord\": \"G#/Ab\"}, {\"Index\": 1178, \"Highest Charting Position\": 82, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"BENDICIONES\", \"Streams\": 4639997, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2CoMYp2uIKsT09nreEZnZn\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 67.0, \"Danceability\": 0.828, \"Energy\": 0.581, \"Loudness\": -9.909, \"Speechiness\": 0.0725, \"Acousticness\": 0.0378, \"Liveness\": 0.103, \"Tempo\": 143.995, \"Duration (ms)\": 155060.0, \"Valence\": 0.843, \"Chord\": \"B\"}, {\"Index\": 1179, \"Highest Charting Position\": 126, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"PTSD\", \"Streams\": 4500903, \"Artist\": \"G Herbo, Juice WRLD, Lil Uzi Vert, Chance the Rapper\", \"Artist Followers\": 1253138.0, \"Song ID\": \"1C8ux1YWLMHCenYJFiIV4Z\", \"Genre\": \"['chicago drill', 'chicago rap', 'drill', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-02-28--2020-03-06\", \"Popularity\": 76.0, \"Danceability\": 0.883, \"Energy\": 0.808, \"Loudness\": -3.158, \"Speechiness\": 0.182, \"Acousticness\": 0.0313, \"Liveness\": 0.207, \"Tempo\": 119.01, \"Duration (ms)\": 232065.0, \"Valence\": 0.806, \"Chord\": \"C#/Db\"}, {\"Index\": 1180, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Excitement\", \"Streams\": 4416484, \"Artist\": \"Trippie Redd, PARTYNEXTDOOR\", \"Artist Followers\": 6434201.0, \"Song ID\": \"7FullO2NDkyvxLuxYVKINa\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 69.0, \"Danceability\": 0.443, \"Energy\": 0.536, \"Loudness\": -8.187, \"Speechiness\": 0.0378, \"Acousticness\": 0.0194, \"Liveness\": 0.1, \"Tempo\": 121.967, \"Duration (ms)\": 283285.0, \"Valence\": 0.0391, \"Chord\": \"E\"}, {\"Index\": 1181, \"Highest Charting Position\": 131, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Can We Kiss Forever?\", \"Streams\": 4397385, \"Artist\": \"Kina, Adriana Proenza\", \"Artist Followers\": 661863.0, \"Song ID\": \"58wyJLv6yH1La9NIZPl3ne\", \"Genre\": \"['sad rap']\", \"Release Date\": \"2018-08-31\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.522, \"Energy\": 0.128, \"Loudness\": -18.717, \"Speechiness\": 0.0357, \"Acousticness\": 0.894, \"Liveness\": 0.0941, \"Tempo\": 109.986, \"Duration (ms)\": 187932.0, \"Valence\": 0.124, \"Chord\": \"E\"}, {\"Index\": 1182, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"SI ELLA SALE\", \"Streams\": 7055918, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"1zaDh3qaGSeSmulNyWlUxm\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 63.0, \"Danceability\": 0.869, \"Energy\": 0.727, \"Loudness\": -7.397, \"Speechiness\": 0.123, \"Acousticness\": 0.0589, \"Liveness\": 0.107, \"Tempo\": 147.967, \"Duration (ms)\": 143240.0, \"Valence\": 0.92, \"Chord\": \"G\"}, {\"Index\": 1183, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"RONCA FREESTYLE\", \"Streams\": 5784075, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3XZeOzJ9tqnu58YP6cqApI\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 64.0, \"Danceability\": 0.856, \"Energy\": 0.656, \"Loudness\": -6.483, \"Speechiness\": 0.131, \"Acousticness\": 0.165, \"Liveness\": 0.0998, \"Tempo\": 90.041, \"Duration (ms)\": 150060.0, \"Valence\": 0.586, \"Chord\": \"F\"}, {\"Index\": 1184, \"Highest Charting Position\": 130, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Zoo York (feat. Fivio Foreign & Pop Smoke)\", \"Streams\": 5368705, \"Artist\": \"Lil Tjay\", \"Artist Followers\": 3559267.0, \"Song ID\": \"3Ddny34bFoYBb8dIGq5lwp\", \"Genre\": \"['brooklyn drill', 'melodic rap', 'nyc rap']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 70.0, \"Danceability\": 0.565, \"Energy\": 0.569, \"Loudness\": -6.084, \"Speechiness\": 0.379, \"Acousticness\": 0.0352, \"Liveness\": 0.106, \"Tempo\": 92.466, \"Duration (ms)\": 214825.0, \"Valence\": 0.303, \"Chord\": \"F#/Gb\"}, {\"Index\": 1185, \"Highest Charting Position\": 131, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"EN CASITA\", \"Streams\": 5364262, \"Artist\": \"Bad Bunny, Gabriela\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2DhNdoHxavs7Qtf5MnhZD0\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 62.0, \"Danceability\": 0.779, \"Energy\": 0.764, \"Loudness\": -8.217, \"Speechiness\": 0.0938, \"Acousticness\": 0.221, \"Liveness\": 0.0909, \"Tempo\": 158.093, \"Duration (ms)\": 176440.0, \"Valence\": 0.675, \"Chord\": \"C\"}, {\"Index\": 1186, \"Highest Charting Position\": 71, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Qu\\u00e9 Maldici\\u00f3n\", \"Streams\": 4971559, \"Artist\": \"Banda MS de Sergio Liz\\u00e1rraga, Snoop Dogg\", \"Artist Followers\": 12140496.0, \"Song ID\": \"2RxC2peY3FtrurYmbbmanr\", \"Genre\": \"['banda', 'corrido', 'norteno', 'regional mexican']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 69.0, \"Danceability\": 0.755, \"Energy\": 0.531, \"Loudness\": -8.051, \"Speechiness\": 0.196, \"Acousticness\": 0.213, \"Liveness\": 0.13, \"Tempo\": 177.951, \"Duration (ms)\": 203360.0, \"Valence\": 0.683, \"Chord\": \"A\"}, {\"Index\": 1187, \"Highest Charting Position\": 69, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Nicht verdient\", \"Streams\": 4912914, \"Artist\": \"Capital Bra, Loredana\", \"Artist Followers\": 4093115.0, \"Song ID\": \"7v8OynJxOxHoeS5C2UA9Y7\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-04-29\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 58.0, \"Danceability\": 0.719, \"Energy\": 0.65, \"Loudness\": -7.274, \"Speechiness\": 0.232, \"Acousticness\": 0.381, \"Liveness\": 0.167, \"Tempo\": 77.981, \"Duration (ms)\": 176953.0, \"Valence\": 0.488, \"Chord\": \"B\"}, {\"Index\": 1188, \"Highest Charting Position\": 52, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"A Tu Merced\", \"Streams\": 4909499, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4r9jkMEnArtWGH2rL2FZl0\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 82.0, \"Danceability\": 0.86, \"Energy\": 0.791, \"Loudness\": -4.784, \"Speechiness\": 0.0568, \"Acousticness\": 0.169, \"Liveness\": 0.106, \"Tempo\": 92.023, \"Duration (ms)\": 175918.0, \"Valence\": 0.887, \"Chord\": \"C\"}, {\"Index\": 1189, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Demons (feat. Fivio Foreign & Sosa Geek)\", \"Streams\": 4766829, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"05aZ9sAU1YXndHv0FMi9iW\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 63.0, \"Danceability\": 0.543, \"Energy\": 0.766, \"Loudness\": -3.387, \"Speechiness\": 0.343, \"Acousticness\": 0.423, \"Liveness\": 0.155, \"Tempo\": 106.869, \"Duration (ms)\": 204805.0, \"Valence\": 0.729, \"Chord\": \"C\"}, {\"Index\": 1190, \"Highest Charting Position\": 42, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Moral of the Story\", \"Streams\": 4609358, \"Artist\": \"Ashe\", \"Artist Followers\": 644479.0, \"Song ID\": \"2nC3QhMI9reBIOWutbU3Tj\", \"Genre\": \"['alt z', 'electropop', 'indie pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-02-14\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 75.0, \"Danceability\": 0.572, \"Energy\": 0.406, \"Loudness\": -8.624, \"Speechiness\": 0.0427, \"Acousticness\": 0.587, \"Liveness\": 0.102, \"Tempo\": 119.812, \"Duration (ms)\": 201084.0, \"Valence\": 0.265, \"Chord\": \"A#/Bb\"}, {\"Index\": 1191, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Can I\", \"Streams\": 4603243, \"Artist\": \"Kehlani\", \"Artist Followers\": 4894562.0, \"Song ID\": \"0uDdI4fAXCuNhQbmxENdsO\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop', 'r&b']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 68.0, \"Danceability\": 0.574, \"Energy\": 0.791, \"Loudness\": -3.752, \"Speechiness\": 0.11, \"Acousticness\": 0.419, \"Liveness\": 0.0982, \"Tempo\": 119.537, \"Duration (ms)\": 167810.0, \"Valence\": 0.612, \"Chord\": \"C#/Db\"}, {\"Index\": 1192, \"Highest Charting Position\": 46, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"STARGAZING\", \"Streams\": 4499820, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"7wBJfHzpfI3032CSD7CE2m\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2018-08-03\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 76.0, \"Danceability\": 0.487, \"Energy\": 0.789, \"Loudness\": -3.69, \"Speechiness\": 0.044, \"Acousticness\": 0.00947, \"Liveness\": 0.189, \"Tempo\": 150.007, \"Duration (ms)\": 270715.0, \"Valence\": 0.0564, \"Chord\": \"G#/Ab\"}, {\"Index\": 1193, \"Highest Charting Position\": 124, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Eastside (with Halsey & Khalid)\", \"Streams\": 4397708, \"Artist\": \"benny blanco\", \"Artist Followers\": 804613.0, \"Song ID\": \"0d2iYfpKoM0QCKvcLCkBao\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2018-07-12\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.56, \"Energy\": 0.68, \"Loudness\": -7.648, \"Speechiness\": 0.321, \"Acousticness\": 0.555, \"Liveness\": 0.116, \"Tempo\": 89.391, \"Duration (ms)\": 173800.0, \"Valence\": 0.319, \"Chord\": \"F#/Gb\"}, {\"Index\": 1194, \"Highest Charting Position\": 23, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Suicidal\", \"Streams\": 4320116, \"Artist\": \"YNW Melly\", \"Artist Followers\": 6332535.0, \"Song ID\": \"4S2uhQE8L9V6p7rj7SiauJ\", \"Genre\": \"['melodic rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.655, \"Energy\": 0.441, \"Loudness\": -5.245, \"Speechiness\": 0.0629, \"Acousticness\": 0.474, \"Liveness\": 0.099, \"Tempo\": 139.957, \"Duration (ms)\": 225857.0, \"Valence\": 0.273, \"Chord\": \"A\"}, {\"Index\": 1195, \"Highest Charting Position\": 39, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"How Do You Sleep?\", \"Streams\": 4313625, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"6b2RcmUt1g9N9mQ3CbjX2Y\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2019-07-19\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.477, \"Energy\": 0.682, \"Loudness\": -4.931, \"Speechiness\": 0.0925, \"Acousticness\": 0.153, \"Liveness\": 0.0763, \"Tempo\": 110.567, \"Duration (ms)\": 202205.0, \"Valence\": 0.345, \"Chord\": \"C#/Db\"}, {\"Index\": 1196, \"Highest Charting Position\": 4, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"No Time To Die\", \"Streams\": 4293009, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"73SpzrcaHk0RQPFP73vqVR\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2020-02-13\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 75.0, \"Danceability\": 0.38, \"Energy\": 0.219, \"Loudness\": -13.273, \"Speechiness\": 0.0358, \"Acousticness\": 0.917, \"Liveness\": 0.0827, \"Tempo\": 73.537, \"Duration (ms)\": 242265.0, \"Valence\": 0.0517, \"Chord\": \"E\"}, {\"Index\": 1197, \"Highest Charting Position\": 46, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"D4L\", \"Streams\": 10537097, \"Artist\": \"Future, Drake, Young Thug\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5fHrHoJKfCgBd35zwIBmUK\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 63.0, \"Danceability\": 0.718, \"Energy\": 0.706, \"Loudness\": -5.709, \"Speechiness\": 0.06, \"Acousticness\": 0.0128, \"Liveness\": 0.352, \"Tempo\": 170.004, \"Duration (ms)\": 189176.0, \"Valence\": 0.815, \"Chord\": \"C#/Db\"}, {\"Index\": 1198, \"Highest Charting Position\": 51, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Time Flies\", \"Streams\": 9904749, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5H4mXWKcicuLKDn4Jy0sK7\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 71.0, \"Danceability\": 0.864, \"Energy\": 0.477, \"Loudness\": -5.786, \"Speechiness\": 0.224, \"Acousticness\": 0.201, \"Liveness\": 0.182, \"Tempo\": 86.46, \"Duration (ms)\": 192932.0, \"Valence\": 0.5, \"Chord\": \"A#/Bb\"}, {\"Index\": 1199, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Desires (with Future)\", \"Streams\": 9628215, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"7eYAHC0RbBF9eaqWzT34Aq\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.812, \"Energy\": 0.506, \"Loudness\": -7.706, \"Speechiness\": 0.116, \"Acousticness\": 0.281, \"Liveness\": 0.325, \"Tempo\": 145.074, \"Duration (ms)\": 237946.0, \"Valence\": 0.554, \"Chord\": \"F\"}, {\"Index\": 1200, \"Highest Charting Position\": 55, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Not You Too (feat. Chris Brown)\", \"Streams\": 9284383, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"3Q4gttWQ6hxqWOa3tHoTNi\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.458, \"Energy\": 0.452, \"Loudness\": -9.299, \"Speechiness\": 0.047, \"Acousticness\": 0.342, \"Liveness\": 0.0703, \"Tempo\": 86.318, \"Duration (ms)\": 269680.0, \"Valence\": 0.316, \"Chord\": \"A\"}, {\"Index\": 1201, \"Highest Charting Position\": 67, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Landed\", \"Streams\": 8355036, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"3KixNgUEaDtrKJVzdqjU5q\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 60.0, \"Danceability\": 0.881, \"Energy\": 0.636, \"Loudness\": -4.629, \"Speechiness\": 0.287, \"Acousticness\": 0.00606, \"Liveness\": 0.111, \"Tempo\": 163.949, \"Duration (ms)\": 152195.0, \"Valence\": 0.715, \"Chord\": \"G\"}, {\"Index\": 1202, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"When To Say When\", \"Streams\": 8304928, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5TCBWmEBrin7etRa4Lswr1\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 60.0, \"Danceability\": 0.41, \"Energy\": 0.82, \"Loudness\": -6.808, \"Speechiness\": 0.533, \"Acousticness\": 0.252, \"Liveness\": 0.538, \"Tempo\": 170.718, \"Duration (ms)\": 223124.0, \"Valence\": 0.526, \"Chord\": \"C#/Db\"}, {\"Index\": 1203, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Deep Pockets\", \"Streams\": 8285754, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"3IvMYBE7A3c7to1aEcfFJk\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 58.0, \"Danceability\": 0.473, \"Energy\": 0.824, \"Loudness\": -3.68, \"Speechiness\": 0.163, \"Acousticness\": 0.482, \"Liveness\": 0.605, \"Tempo\": 77.888, \"Duration (ms)\": 222929.0, \"Valence\": 0.374, \"Chord\": \"G\"}, {\"Index\": 1204, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"War\", \"Streams\": 7821869, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"1I55Ea0zVoSKs6MqW7DQ3i\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.749, \"Energy\": 0.792, \"Loudness\": -4.151, \"Speechiness\": 0.0826, \"Acousticness\": 0.292, \"Liveness\": 0.109, \"Tempo\": 144.064, \"Duration (ms)\": 180000.0, \"Valence\": 0.239, \"Chord\": \"A#/Bb\"}, {\"Index\": 1205, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"From Florida With Love\", \"Streams\": 7216610, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"0YkUwXxnTkeJBvt5upeEtP\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.787, \"Energy\": 0.477, \"Loudness\": -7.837, \"Speechiness\": 0.199, \"Acousticness\": 0.768, \"Liveness\": 0.104, \"Tempo\": 80.506, \"Duration (ms)\": 234783.0, \"Valence\": 0.476, \"Chord\": \"F#/Gb\"}, {\"Index\": 1206, \"Highest Charting Position\": 89, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Losses\", \"Streams\": 6894756, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"6fLVTVaHWaEfVKfEgbkf4D\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 57.0, \"Danceability\": 0.551, \"Energy\": 0.57, \"Loudness\": -7.385, \"Speechiness\": 0.351, \"Acousticness\": 0.28, \"Liveness\": 0.424, \"Tempo\": 85.687, \"Duration (ms)\": 271184.0, \"Valence\": 0.505, \"Chord\": \"C#/Db\"}, {\"Index\": 1207, \"Highest Charting Position\": 25, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Turks (feat. Travis Scott)\", \"Streams\": 5594561, \"Artist\": \"NAV, Gunna\", \"Artist Followers\": 2613211.0, \"Song ID\": \"0lSZh5W0wDeurkGzLYY6hf\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'hip hop', 'melodic rap', 'pop rap', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 70.0, \"Danceability\": 0.893, \"Energy\": 0.618, \"Loudness\": -4.425, \"Speechiness\": 0.112, \"Acousticness\": 0.0827, \"Liveness\": 0.542, \"Tempo\": 119.099, \"Duration (ms)\": 161377.0, \"Valence\": 0.389, \"Chord\": \"G\"}, {\"Index\": 1208, \"Highest Charting Position\": 40, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Boyfriend\", \"Streams\": 5236730, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4QnC1bIaMSfDQvF4XDhV5M\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 62.0, \"Danceability\": 0.811, \"Energy\": 0.512, \"Loudness\": -6.381, \"Speechiness\": 0.17, \"Acousticness\": 0.218, \"Liveness\": 0.0768, \"Tempo\": 92.046, \"Duration (ms)\": 161188.0, \"Valence\": 0.346, \"Chord\": \"D\"}, {\"Index\": 1209, \"Highest Charting Position\": 29, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"What If I Told You That I Love You\", \"Streams\": 5234645, \"Artist\": \"Ali Gatie\", \"Artist Followers\": 1758300.0, \"Song ID\": \"6USdi8uX5GNAPYziFhisHb\", \"Genre\": \"['canadian hip hop', 'pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 69.0, \"Danceability\": 0.596, \"Energy\": 0.366, \"Loudness\": -11.144, \"Speechiness\": 0.115, \"Acousticness\": 0.63, \"Liveness\": 0.0554, \"Tempo\": 84.394, \"Duration (ms)\": 193668.0, \"Valence\": 0.229, \"Chord\": \"G\"}, {\"Index\": 1210, \"Highest Charting Position\": 85, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Emotions\", \"Streams\": 4901960, \"Artist\": \"Ufo361\", \"Artist Followers\": 1700759.0, \"Song ID\": \"3yZCjDTxzZxx1kll1sRjGc\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 65.0, \"Danceability\": 0.788, \"Energy\": 0.491, \"Loudness\": -9.884, \"Speechiness\": 0.109, \"Acousticness\": 0.386, \"Liveness\": 0.107, \"Tempo\": 98.543, \"Duration (ms)\": 146028.0, \"Valence\": 0.271, \"Chord\": \"G#/Ab\"}, {\"Index\": 1211, \"Highest Charting Position\": 32, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"FIND MY WAY\", \"Streams\": 4753495, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"1gVCEnryJhkdQcuC0Kbvor\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 66.0, \"Danceability\": 0.836, \"Energy\": 0.624, \"Loudness\": -6.75, \"Speechiness\": 0.184, \"Acousticness\": 0.187, \"Liveness\": 0.138, \"Tempo\": 103.0, \"Duration (ms)\": 139890.0, \"Valence\": 0.7, \"Chord\": \"E\"}, {\"Index\": 1212, \"Highest Charting Position\": 37, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Keii\", \"Streams\": 4687605, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"5eEQCfq7MXQr6aHLNRUZLs\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 67.0, \"Danceability\": 0.708, \"Energy\": 0.797, \"Loudness\": -3.095, \"Speechiness\": 0.0391, \"Acousticness\": 0.4, \"Liveness\": 0.096, \"Tempo\": 88.015, \"Duration (ms)\": 210000.0, \"Valence\": 0.51, \"Chord\": \"C\"}, {\"Index\": 1213, \"Highest Charting Position\": 130, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"God's Plan\", \"Streams\": 4565400, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"6DCZcSspjsKoFjzjrWoCdn\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2018-06-29\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.754, \"Energy\": 0.449, \"Loudness\": -9.211, \"Speechiness\": 0.109, \"Acousticness\": 0.0332, \"Liveness\": 0.552, \"Tempo\": 77.169, \"Duration (ms)\": 198973.0, \"Valence\": 0.357, \"Chord\": \"G\"}, {\"Index\": 1214, \"Highest Charting Position\": 103, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Por Primera Vez\", \"Streams\": 4478685, \"Artist\": \"Camilo, Evaluna Montaner\", \"Artist Followers\": 10580764.0, \"Song ID\": \"0gWbAFRcUyZKdfUxEOuOiD\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-09\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 70.0, \"Danceability\": 0.716, \"Energy\": 0.588, \"Loudness\": -3.952, \"Speechiness\": 0.116, \"Acousticness\": 0.152, \"Liveness\": 0.0847, \"Tempo\": 165.896, \"Duration (ms)\": 183547.0, \"Valence\": 0.707, \"Chord\": \"C#/Db\"}, {\"Index\": 1215, \"Highest Charting Position\": 32, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"@ MEH\", \"Streams\": 4420187, \"Artist\": \"Playboi Carti\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5rffvRUaCvkPnkwMVcQYgZ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 1.0, \"Danceability\": 0.877, \"Energy\": 0.492, \"Loudness\": -8.11, \"Speechiness\": 0.153, \"Acousticness\": 0.0136, \"Liveness\": 0.0678, \"Tempo\": 151.042, \"Duration (ms)\": 166799.0, \"Valence\": 0.4, \"Chord\": \"B\"}, {\"Index\": 1216, \"Highest Charting Position\": 109, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Broke In A Minute\", \"Streams\": 4402281, \"Artist\": \"Tory Lanez\", \"Artist Followers\": 3828418.0, \"Song ID\": \"4xqIYGwwZTEem9U8A42SPF\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-04-10\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-02-07--2020-02-14\", \"Popularity\": 75.0, \"Danceability\": 0.929, \"Energy\": 0.7, \"Loudness\": -5.595, \"Speechiness\": 0.0906, \"Acousticness\": 0.144, \"Liveness\": 0.349, \"Tempo\": 120.009, \"Duration (ms)\": 132024.0, \"Valence\": 0.802, \"Chord\": \"C\"}, {\"Index\": 1217, \"Highest Charting Position\": 139, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Fantasias - Remix\", \"Streams\": 4401019, \"Artist\": \"Rauw Alejandro, Anuel AA, Natti Natasha, Farruko, Lunay\", \"Artist Followers\": 6096559.0, \"Song ID\": \"0A37XY67wSdGqkGjtfW6aV\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 70.0, \"Danceability\": 0.816, \"Energy\": 0.72, \"Loudness\": -4.454, \"Speechiness\": 0.0684, \"Acousticness\": 0.206, \"Liveness\": 0.277, \"Tempo\": 94.004, \"Duration (ms)\": 267242.0, \"Valence\": 0.78, \"Chord\": \"C#/Db\"}, {\"Index\": 1218, \"Highest Charting Position\": 38, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"SUGAR\", \"Streams\": 4362442, \"Artist\": \"BROCKHAMPTON\", \"Artist Followers\": 1836564.0, \"Song ID\": \"6U0FIYXCQ3TGrk4tFpLrEA\", \"Genre\": \"['boy band', 'hip hop', 'rap']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 75.0, \"Danceability\": 0.453, \"Energy\": 0.538, \"Loudness\": -8.212, \"Speechiness\": 0.0638, \"Acousticness\": 0.449, \"Liveness\": 0.19, \"Tempo\": 122.973, \"Duration (ms)\": 204533.0, \"Valence\": 0.516, \"Chord\": \"C#/Db\"}, {\"Index\": 1219, \"Highest Charting Position\": 112, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"90-60-111\", \"Streams\": 5750861, \"Artist\": \"Shirin David\", \"Artist Followers\": 559215.0, \"Song ID\": \"3ZdDYeaZzeYnrP4crgXzPk\", \"Genre\": \"['frauenrap', 'german hip hop', 'german pop']\", \"Release Date\": \"2020-04-23\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 64.0, \"Danceability\": 0.8, \"Energy\": 0.628, \"Loudness\": -6.615, \"Speechiness\": 0.285, \"Acousticness\": 0.103, \"Liveness\": 0.391, \"Tempo\": 143.979, \"Duration (ms)\": 141387.0, \"Valence\": 0.745, \"Chord\": \"D\"}, {\"Index\": 1220, \"Highest Charting Position\": 115, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"YOSEMITE\", \"Streams\": 5686981, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"7lAK3oHbfEnvUQWosrMMpR\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2018-08-03\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 75.0, \"Danceability\": 0.785, \"Energy\": 0.554, \"Loudness\": -6.571, \"Speechiness\": 0.0409, \"Acousticness\": 0.283, \"Liveness\": 0.116, \"Tempo\": 128.047, \"Duration (ms)\": 150043.0, \"Valence\": 0.144, \"Chord\": \"C\"}, {\"Index\": 1221, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Houdini (feat. Swarmz & Tion Wayne)\", \"Streams\": 4914429, \"Artist\": \"KSI\", \"Artist Followers\": 2010879.0, \"Song ID\": \"3lay6f81Lhy0qp2Uvp4cNJ\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 58.0, \"Danceability\": 0.572, \"Energy\": 0.519, \"Loudness\": -8.054, \"Speechiness\": 0.243, \"Acousticness\": 0.000415, \"Liveness\": 0.129, \"Tempo\": 100.453, \"Duration (ms)\": 169355.0, \"Valence\": 0.704, \"Chord\": \"A#/Bb\"}, {\"Index\": 1222, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Sasuke\", \"Streams\": 4701551, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"0ROE31C8Wu4neZoR9stM9e\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 56.0, \"Danceability\": 0.859, \"Energy\": 0.477, \"Loudness\": -6.116, \"Speechiness\": 0.428, \"Acousticness\": 0.00414, \"Liveness\": 0.0819, \"Tempo\": 145.979, \"Duration (ms)\": 251336.0, \"Valence\": 0.153, \"Chord\": \"C#/Db\"}, {\"Index\": 1223, \"Highest Charting Position\": 47, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Me Gusta\", \"Streams\": 4440661, \"Artist\": \"Shakira, Anuel AA\", \"Artist Followers\": 22136717.0, \"Song ID\": \"5Xhqh4lwJPtMUTsdBztN1a\", \"Genre\": \"['colombian pop', 'dance pop', 'latin', 'latin pop', 'pop']\", \"Release Date\": \"2020-01-13\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 72.0, \"Danceability\": 0.775, \"Energy\": 0.696, \"Loudness\": -5.184, \"Speechiness\": 0.0681, \"Acousticness\": 0.0559, \"Liveness\": 0.157, \"Tempo\": 92.007, \"Duration (ms)\": 190570.0, \"Valence\": 0.775, \"Chord\": \"C#/Db\"}, {\"Index\": 1224, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"If You\\u2019re Too Shy (Let Me Know) - Edit\", \"Streams\": 4429092, \"Artist\": \"The 1975\", \"Artist Followers\": 5044278.0, \"Song ID\": \"3iEqGBZ2wcpVzhiAcwXVC6\", \"Genre\": \"['modern alternative rock', 'modern rock', 'pop', 'rock']\", \"Release Date\": \"2020-04-23\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 59.0, \"Danceability\": 0.651, \"Energy\": 0.806, \"Loudness\": -4.842, \"Speechiness\": 0.0311, \"Acousticness\": 0.00399, \"Liveness\": 0.0927, \"Tempo\": 125.641, \"Duration (ms)\": 239877.0, \"Valence\": 0.386, \"Chord\": \"D\"}, {\"Index\": 1225, \"Highest Charting Position\": 80, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Alone, Pt. II\", \"Streams\": 4395061, \"Artist\": \"Alan Walker, Ava Max\", \"Artist Followers\": 29679430.0, \"Song ID\": \"0bMbDctzMmTyK2j74j3nF3\", \"Genre\": \"['electro house']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.67, \"Energy\": 0.668, \"Loudness\": -4.306, \"Speechiness\": 0.0422, \"Acousticness\": 0.536, \"Liveness\": 0.133, \"Tempo\": 88.033, \"Duration (ms)\": 179053.0, \"Valence\": 0.608, \"Chord\": \"D#/Eb\"}, {\"Index\": 1226, \"Highest Charting Position\": 97, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Tutu\", \"Streams\": 4393037, \"Artist\": \"Camilo, Pedro Cap\\u00f3\", \"Artist Followers\": 10580764.0, \"Song ID\": \"1nocRtwyNPVtGcIJqfgdzZ\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2019-08-09\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.731, \"Energy\": 0.832, \"Loudness\": -2.592, \"Speechiness\": 0.0503, \"Acousticness\": 0.273, \"Liveness\": 0.0665, \"Tempo\": 146.013, \"Duration (ms)\": 178613.0, \"Valence\": 0.94, \"Chord\": \"A\"}, {\"Index\": 1227, \"Highest Charting Position\": 85, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Hate Me (with Juice WRLD)\", \"Streams\": 4367368, \"Artist\": \"Ellie Goulding\", \"Artist Followers\": 9747805.0, \"Song ID\": \"6kls8cSlUyHW2BUOkDJIZE\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'indietronica', 'metropopolis', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2019-06-26\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.657, \"Energy\": 0.768, \"Loudness\": -4.628, \"Speechiness\": 0.0507, \"Acousticness\": 0.108, \"Liveness\": 0.144, \"Tempo\": 75.025, \"Duration (ms)\": 186223.0, \"Valence\": 0.759, \"Chord\": \"G#/Ab\"}, {\"Index\": 1228, \"Highest Charting Position\": 109, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Still Be Friends (feat. Tory Lanez & Tyga)\", \"Streams\": 4299422, \"Artist\": \"G-Eazy\", \"Artist Followers\": 4894656.0, \"Song ID\": \"0JjM9bKm4wrwohMslcm892\", \"Genre\": \"['hip hop', 'indie pop rap', 'oakland hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 76.0, \"Danceability\": 0.803, \"Energy\": 0.759, \"Loudness\": -4.692, \"Speechiness\": 0.0494, \"Acousticness\": 0.00509, \"Liveness\": 0.0921, \"Tempo\": 104.0, \"Duration (ms)\": 213308.0, \"Valence\": 0.284, \"Chord\": \"G\"}, {\"Index\": 1229, \"Highest Charting Position\": 74, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Blanco\", \"Streams\": 4214147, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"2rc7BkzO8qepMFAxHtOrXc\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.87, \"Energy\": 0.706, \"Loudness\": -5.395, \"Speechiness\": 0.126, \"Acousticness\": 0.0253, \"Liveness\": 0.0872, \"Tempo\": 100.013, \"Duration (ms)\": 145800.0, \"Valence\": 0.593, \"Chord\": \"A\"}, {\"Index\": 1230, \"Highest Charting Position\": 78, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"PICK UP (feat. Quavo)\", \"Streams\": 7065060, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"5gNOINI5dXZVom2b36LMOd\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 65.0, \"Danceability\": 0.915, \"Energy\": 0.612, \"Loudness\": -4.535, \"Speechiness\": 0.407, \"Acousticness\": 0.0944, \"Liveness\": 0.115, \"Tempo\": 129.93, \"Duration (ms)\": 118547.0, \"Valence\": 0.758, \"Chord\": \"C#/Db\"}, {\"Index\": 1231, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"JUMP (feat. YoungBoy Never Broke Again)\", \"Streams\": 6033348, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"0oT9ElXYSxvnOOagP9efDq\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 62.0, \"Danceability\": 0.896, \"Energy\": 0.72, \"Loudness\": -6.262, \"Speechiness\": 0.355, \"Acousticness\": 0.169, \"Liveness\": 0.252, \"Tempo\": 140.1, \"Duration (ms)\": 212093.0, \"Valence\": 0.966, \"Chord\": \"C\"}, {\"Index\": 1232, \"Highest Charting Position\": 156, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"LIGHTSKIN SH*T (feat. Future & jetsonmade)\", \"Streams\": 4861875, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"16oi4OiKmkO51l60F5R9kR\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 56.0, \"Danceability\": 0.932, \"Energy\": 0.578, \"Loudness\": -4.478, \"Speechiness\": 0.366, \"Acousticness\": 0.115, \"Liveness\": 0.115, \"Tempo\": 129.991, \"Duration (ms)\": 111173.0, \"Valence\": 0.623, \"Chord\": \"A\"}, {\"Index\": 1233, \"Highest Charting Position\": 16, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"That Way - Bonus Track\", \"Streams\": 4825741, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2ajzBr7vwHTEBeqDzcsNRC\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.712, \"Energy\": 0.598, \"Loudness\": -5.368, \"Speechiness\": 0.0388, \"Acousticness\": 0.0546, \"Liveness\": 0.154, \"Tempo\": 130.007, \"Duration (ms)\": 212354.0, \"Valence\": 0.504, \"Chord\": \"G\"}, {\"Index\": 1234, \"Highest Charting Position\": 162, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"No Me Ame\", \"Streams\": 4822090, \"Artist\": \"Rvssian, Anuel AA, Juice WRLD\", \"Artist Followers\": 1397067.0, \"Song ID\": \"2AuWgceaQyfMoI3EGavwGb\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 64.0, \"Danceability\": 0.68, \"Energy\": 0.766, \"Loudness\": -4.799, \"Speechiness\": 0.0923, \"Acousticness\": 0.0411, \"Liveness\": 0.116, \"Tempo\": 160.095, \"Duration (ms)\": 180000.0, \"Valence\": 0.28, \"Chord\": \"B\"}, {\"Index\": 1235, \"Highest Charting Position\": 80, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"I'll Wait\", \"Streams\": 4674532, \"Artist\": \"Kygo, Sasha Alex Sloan\", \"Artist Followers\": 7593792.0, \"Song ID\": \"6Q3K9gVUZRMZqZKrXovbM2\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 70.0, \"Danceability\": 0.611, \"Energy\": 0.651, \"Loudness\": -6.973, \"Speechiness\": 0.0589, \"Acousticness\": 0.144, \"Liveness\": 0.105, \"Tempo\": 122.983, \"Duration (ms)\": 215361.0, \"Valence\": 0.351, \"Chord\": \"C#/Db\"}, {\"Index\": 1236, \"Highest Charting Position\": 63, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Oprah\\u2019s Bank Account (Lil Yachty & DaBaby feat. Drake)\", \"Streams\": 4618744, \"Artist\": \"Lil Yachty\", \"Artist Followers\": 7358720.0, \"Song ID\": \"7wsmIIm0xWmtP7TmACXkJn\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap', 'underground hip hop', 'viral rap']\", \"Release Date\": \"2020-03-09\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 69.0, \"Danceability\": 0.836, \"Energy\": 0.617, \"Loudness\": -4.363, \"Speechiness\": 0.0534, \"Acousticness\": 0.17, \"Liveness\": 0.319, \"Tempo\": 138.066, \"Duration (ms)\": 206702.0, \"Valence\": 0.866, \"Chord\": \"C\"}, {\"Index\": 1237, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"BLAME IT ON BABY\", \"Streams\": 4616034, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"0jWm0VyD8p3MrSInczpows\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 57.0, \"Danceability\": 0.875, \"Energy\": 0.687, \"Loudness\": -5.734, \"Speechiness\": 0.387, \"Acousticness\": 0.236, \"Liveness\": 0.141, \"Tempo\": 109.791, \"Duration (ms)\": 125907.0, \"Valence\": 0.864, \"Chord\": \"A\"}, {\"Index\": 1238, \"Highest Charting Position\": 128, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Follow\", \"Streams\": 4593449, \"Artist\": \"KAROL G, Anuel AA\", \"Artist Followers\": 17792779.0, \"Song ID\": \"2w1rq80FIrbxeJy9WYURxw\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-04-01\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 63.0, \"Danceability\": 0.735, \"Energy\": 0.787, \"Loudness\": -4.375, \"Speechiness\": 0.16, \"Acousticness\": 0.667, \"Liveness\": 0.0721, \"Tempo\": 168.997, \"Duration (ms)\": 203093.0, \"Valence\": 0.455, \"Chord\": \"G\"}, {\"Index\": 1239, \"Highest Charting Position\": 156, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"3 Nights\", \"Streams\": 4411998, \"Artist\": \"Dominic Fike\", \"Artist Followers\": 554042.0, \"Song ID\": \"1tNJrcVe6gwLEiZCtprs1u\", \"Genre\": \"['alternative pop rock', 'pop']\", \"Release Date\": \"2018-10-16\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.815, \"Energy\": 0.518, \"Loudness\": -6.594, \"Speechiness\": 0.0897, \"Acousticness\": 0.223, \"Liveness\": 0.104, \"Tempo\": 151.891, \"Duration (ms)\": 177667.0, \"Valence\": 0.877, \"Chord\": \"G\"}, {\"Index\": 1240, \"Highest Charting Position\": 163, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"The Take (feat. Chris Brown)\", \"Streams\": 4394195, \"Artist\": \"Tory Lanez\", \"Artist Followers\": 3828418.0, \"Song ID\": \"0Odu228D0yGcFySGuxU4rY\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 73.0, \"Danceability\": 0.464, \"Energy\": 0.547, \"Loudness\": -8.137, \"Speechiness\": 0.339, \"Acousticness\": 0.0511, \"Liveness\": 0.155, \"Tempo\": 67.003, \"Duration (ms)\": 221492.0, \"Valence\": 0.423, \"Chord\": \"G\"}, {\"Index\": 1241, \"Highest Charting Position\": 101, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Stupid Again\", \"Streams\": 5938996, \"Artist\": \"Tory Lanez\", \"Artist Followers\": 3828418.0, \"Song ID\": \"1fPnUpoXCpD2NDI4vPVeLw\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-04-10\", \"Weeks Charted\": \"2020-04-10--2020-04-17\", \"Popularity\": 66.0, \"Danceability\": 0.775, \"Energy\": 0.823, \"Loudness\": -4.941, \"Speechiness\": 0.0635, \"Acousticness\": 0.0881, \"Liveness\": 0.309, \"Tempo\": 120.059, \"Duration (ms)\": 174848.0, \"Valence\": 0.65, \"Chord\": \"F\"}, {\"Index\": 1242, \"Highest Charting Position\": 127, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Shotz Fired\", \"Streams\": 5291167, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"0dy5NFDnx5fuZvE8ZXEX35\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-04-10--2020-04-17\", \"Popularity\": 59.0, \"Danceability\": 0.839, \"Energy\": 0.594, \"Loudness\": -9.087, \"Speechiness\": 0.139, \"Acousticness\": 0.249, \"Liveness\": 0.165, \"Tempo\": 76.007, \"Duration (ms)\": 179844.0, \"Valence\": 0.58, \"Chord\": \"C\"}, {\"Index\": 1243, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"BaeBae\", \"Streams\": 5290730, \"Artist\": \"Samra\", \"Artist Followers\": 1045091.0, \"Song ID\": \"1yYBOIXO2H9LDqEPui42GM\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-04-10--2020-04-17\", \"Popularity\": 57.0, \"Danceability\": 0.628, \"Energy\": 0.712, \"Loudness\": -4.864, \"Speechiness\": 0.156, \"Acousticness\": 0.282, \"Liveness\": 0.156, \"Tempo\": 86.627, \"Duration (ms)\": 167827.0, \"Valence\": 0.45, \"Chord\": \"E\"}, {\"Index\": 1244, \"Highest Charting Position\": 30, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"To Die For\", \"Streams\": 4527835, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"2ZTYlnhhV1UAReg7wIGolx\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 70.0, \"Danceability\": 0.483, \"Energy\": 0.361, \"Loudness\": -7.889, \"Speechiness\": 0.0738, \"Acousticness\": 0.832, \"Liveness\": 0.098, \"Tempo\": 171.649, \"Duration (ms)\": 193795.0, \"Valence\": 0.307, \"Chord\": \"C\"}, {\"Index\": 1245, \"Highest Charting Position\": 86, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"WANNABE\", \"Streams\": 4383521, \"Artist\": \"ITZY\", \"Artist Followers\": 2384076.0, \"Song ID\": \"6tCssnvTUREcperDOUTqvA\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2020-03-09\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 75.0, \"Danceability\": 0.809, \"Energy\": 0.911, \"Loudness\": -4.41, \"Speechiness\": 0.0617, \"Acousticness\": 0.00795, \"Liveness\": 0.181, \"Tempo\": 122.035, \"Duration (ms)\": 191242.0, \"Valence\": 0.64, \"Chord\": \"F#/Gb\"}, {\"Index\": 1246, \"Highest Charting Position\": 152, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Takeaway\", \"Streams\": 4359727, \"Artist\": \"The Chainsmokers, ILLENIUM, Lennon Stella\", \"Artist Followers\": 18195884.0, \"Song ID\": \"3g0mEQx3NTanacLseoP0Gw\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.528, \"Energy\": 0.511, \"Loudness\": -8.144, \"Speechiness\": 0.0324, \"Acousticness\": 0.126, \"Liveness\": 0.101, \"Tempo\": 100.1, \"Duration (ms)\": 209880.0, \"Valence\": 0.351, \"Chord\": \"D#/Eb\"}, {\"Index\": 1247, \"Highest Charting Position\": 190, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Heart On Ice\", \"Streams\": 4324610, \"Artist\": \"Rod Wave\", \"Artist Followers\": 2203386.0, \"Song ID\": \"6fWa5CRgy0z30OeGZyMBvD\", \"Genre\": \"['florida rap']\", \"Release Date\": \"2019-06-14\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 70.0, \"Danceability\": 0.733, \"Energy\": 0.389, \"Loudness\": -8.468, \"Speechiness\": 0.0738, \"Acousticness\": 0.0513, \"Liveness\": 0.141, \"Tempo\": 157.878, \"Duration (ms)\": 159670.0, \"Valence\": 0.244, \"Chord\": \"A#/Bb\"}, {\"Index\": 1248, \"Highest Charting Position\": 194, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"La Cama - Remix\", \"Streams\": 4261965, \"Artist\": \"Lunay, Myke Towers, Ozuna, Chencho Corleone, Rauw Alejandro\", \"Artist Followers\": 4963516.0, \"Song ID\": \"2tGENA8xef0wABdHvyXwv9\", \"Genre\": \"['latin', 'latin pop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 69.0, \"Danceability\": 0.737, \"Energy\": 0.832, \"Loudness\": -2.622, \"Speechiness\": 0.0798, \"Acousticness\": 0.12, \"Liveness\": 0.255, \"Tempo\": 173.986, \"Duration (ms)\": 330240.0, \"Valence\": 0.865, \"Chord\": \"D\"}, {\"Index\": 1249, \"Highest Charting Position\": 105, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Go Stupid (feat. NLE Choppa & Mike WiLL Made-It)\", \"Streams\": 4244510, \"Artist\": \"Polo G, Stunna 4 Vegas\", \"Artist Followers\": 4849204.0, \"Song ID\": \"0L8OsjxbagaGkJI0PezdRg\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 41.0, \"Danceability\": 0.922, \"Energy\": 0.813, \"Loudness\": -3.268, \"Speechiness\": 0.251, \"Acousticness\": 0.0198, \"Liveness\": 0.0539, \"Tempo\": 141.087, \"Duration (ms)\": 165726.0, \"Valence\": 0.724, \"Chord\": \"C#/Db\"}, {\"Index\": 1250, \"Highest Charting Position\": 192, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Cradles\", \"Streams\": 4218201, \"Artist\": \"Sub Urban\", \"Artist Followers\": 908351.0, \"Song ID\": \"1y4jsQt7MjnZhiD1L6qFBC\", \"Genre\": \"['modern indie pop']\", \"Release Date\": \"2019-01-04\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 73.0, \"Danceability\": 0.534, \"Energy\": 0.589, \"Loudness\": -1.865, \"Speechiness\": 0.325, \"Acousticness\": 0.256, \"Liveness\": 0.176, \"Tempo\": 78.616, \"Duration (ms)\": 209829.0, \"Valence\": 0.632, \"Chord\": \"C#/Db\"}, {\"Index\": 1251, \"Highest Charting Position\": 117, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Good as Hell (feat. Ariana Grande)\", \"Streams\": 4176083, \"Artist\": \"Lizzo\", \"Artist Followers\": 3991674.0, \"Song ID\": \"07Oz5StQ7GRoygNLaXs2pd\", \"Genre\": \"['dance pop', 'escape room', 'minnesota hip hop', 'pop', 'pop rap', 'post-teen pop', 'trap queen']\", \"Release Date\": \"2016\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 71.0, \"Danceability\": 0.668, \"Energy\": 0.892, \"Loudness\": -3.001, \"Speechiness\": 0.0645, \"Acousticness\": 0.298, \"Liveness\": 0.735, \"Tempo\": 95.927, \"Duration (ms)\": 159011.0, \"Valence\": 0.478, \"Chord\": \"F\"}, {\"Index\": 1252, \"Highest Charting Position\": 15, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Forever (feat. Post Malone & Clever)\", \"Streams\": 6517807, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2ZlCGeK30BLRNSPC832pNZ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 68.0, \"Danceability\": 0.825, \"Energy\": 0.483, \"Loudness\": -5.746, \"Speechiness\": 0.08, \"Acousticness\": 0.538, \"Liveness\": 0.204, \"Tempo\": 139.98, \"Duration (ms)\": 219933.0, \"Valence\": 0.892, \"Chord\": \"G#/Ab\"}, {\"Index\": 1253, \"Highest Charting Position\": 46, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"I Love Me\", \"Streams\": 5449099, \"Artist\": \"Demi Lovato\", \"Artist Followers\": 20338833.0, \"Song ID\": \"2IHLaN6wwYKQ3S24NsQqpA\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.664, \"Energy\": 0.561, \"Loudness\": -7.031, \"Speechiness\": 0.0495, \"Acousticness\": 0.00261, \"Liveness\": 0.0764, \"Tempo\": 150.093, \"Duration (ms)\": 203672.0, \"Valence\": 0.713, \"Chord\": \"F#/Gb\"}, {\"Index\": 1254, \"Highest Charting Position\": 103, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Old Me\", \"Streams\": 4724056, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"58qO4dGa5SgNdtvqvpewyz\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 67.0, \"Danceability\": 0.722, \"Energy\": 0.62, \"Loudness\": -3.639, \"Speechiness\": 0.0483, \"Acousticness\": 0.313, \"Liveness\": 0.26, \"Tempo\": 127.978, \"Duration (ms)\": 186786.0, \"Valence\": 0.474, \"Chord\": \"C\"}, {\"Index\": 1255, \"Highest Charting Position\": 29, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Pero Ya No\", \"Streams\": 4666658, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"75pQqzwgCjUOSSy5CpmAjy\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 72.0, \"Danceability\": 0.882, \"Energy\": 0.612, \"Loudness\": -6.103, \"Speechiness\": 0.118, \"Acousticness\": 0.0475, \"Liveness\": 0.182, \"Tempo\": 147.982, \"Duration (ms)\": 160638.0, \"Valence\": 0.742, \"Chord\": \"E\"}, {\"Index\": 1256, \"Highest Charting Position\": 24, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Hardest To Love\", \"Streams\": 4553544, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"6kWxIqQDsKFYCJGbU4AjCX\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.467, \"Energy\": 0.608, \"Loudness\": -7.847, \"Speechiness\": 0.0707, \"Acousticness\": 0.0909, \"Liveness\": 0.125, \"Tempo\": 80.957, \"Duration (ms)\": 211400.0, \"Valence\": 0.108, \"Chord\": \"A#/Bb\"}, {\"Index\": 1257, \"Highest Charting Position\": 191, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"BRABA\", \"Streams\": 4452819, \"Artist\": \"Lu\\u00edsa Sonza\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6DEEuFNv0K3aJtFYZag8gv\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-11\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 0.0, \"Danceability\": 0.812, \"Energy\": 0.689, \"Loudness\": -5.113, \"Speechiness\": 0.0619, \"Acousticness\": 0.181, \"Liveness\": 0.0784, \"Tempo\": 144.011, \"Duration (ms)\": 129782.0, \"Valence\": 0.663, \"Chord\": \"C\"}, {\"Index\": 1258, \"Highest Charting Position\": 77, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Woah\", \"Streams\": 4425610, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"598yNsG1JFrGd4n2kMoz7F\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 69.0, \"Danceability\": 0.882, \"Energy\": 0.602, \"Loudness\": -5.554, \"Speechiness\": 0.245, \"Acousticness\": 0.0177, \"Liveness\": 0.178, \"Tempo\": 142.959, \"Duration (ms)\": 183011.0, \"Valence\": 0.43, \"Chord\": \"B\"}, {\"Index\": 1259, \"Highest Charting Position\": 69, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Pretty Please\", \"Streams\": 4305034, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"6DXZiYUbrYgrVIhfX3U9Z2\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 67.0, \"Danceability\": 0.906, \"Energy\": 0.474, \"Loudness\": -6.124, \"Speechiness\": 0.194, \"Acousticness\": 0.0311, \"Liveness\": 0.286, \"Tempo\": 106.976, \"Duration (ms)\": 194607.0, \"Valence\": 0.656, \"Chord\": \"C#/Db\"}, {\"Index\": 1260, \"Highest Charting Position\": 170, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"I.F.L.Y.\", \"Streams\": 4284951, \"Artist\": \"Bazzi\", \"Artist Followers\": 4421378.0, \"Song ID\": \"4a6q8CR2hzLk2plDkSxkfD\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-08-09\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-13--2020-03-20\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 76.0, \"Danceability\": 0.812, \"Energy\": 0.519, \"Loudness\": -4.823, \"Speechiness\": 0.0385, \"Acousticness\": 0.379, \"Liveness\": 0.13, \"Tempo\": 104.954, \"Duration (ms)\": 165714.0, \"Valence\": 0.554, \"Chord\": \"D\"}, {\"Index\": 1261, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Cool\", \"Streams\": 8136247, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"4Ulqu89XempybuL8ApUeqL\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.469, \"Energy\": 0.785, \"Loudness\": -4.015, \"Speechiness\": 0.0664, \"Acousticness\": 0.133, \"Liveness\": 0.0931, \"Tempo\": 89.719, \"Duration (ms)\": 209583.0, \"Valence\": 0.79, \"Chord\": \"F\"}, {\"Index\": 1262, \"Highest Charting Position\": 71, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Future Nostalgia\", \"Streams\": 8091754, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3iYNJX4FTRGlfMQySjlGNr\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.875, \"Energy\": 0.813, \"Loudness\": -4.502, \"Speechiness\": 0.0579, \"Acousticness\": 0.00618, \"Liveness\": 0.321, \"Tempo\": 114.993, \"Duration (ms)\": 184882.0, \"Valence\": 0.859, \"Chord\": \"G\"}, {\"Index\": 1263, \"Highest Charting Position\": 92, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Good In Bed\", \"Streams\": 6802068, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3pyodt4pb554dMz8fCv7oi\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 64.0, \"Danceability\": 0.68, \"Energy\": 0.701, \"Loudness\": -5.001, \"Speechiness\": 0.0917, \"Acousticness\": 0.138, \"Liveness\": 0.168, \"Tempo\": 94.06, \"Duration (ms)\": 218754.0, \"Valence\": 0.649, \"Chord\": \"F\"}, {\"Index\": 1264, \"Highest Charting Position\": 27, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Scared To Live\", \"Streams\": 6566099, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"4BGZF4oLbTL0pWm7C18pbv\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 66.0, \"Danceability\": 0.504, \"Energy\": 0.498, \"Loudness\": -8.24, \"Speechiness\": 0.0499, \"Acousticness\": 0.131, \"Liveness\": 0.0929, \"Tempo\": 87.221, \"Duration (ms)\": 191307.0, \"Valence\": 0.196, \"Chord\": \"C\"}, {\"Index\": 1265, \"Highest Charting Position\": 21, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Alone Again\", \"Streams\": 6055294, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"6b5P51m8xx2XA6U7sdNZ5E\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 66.0, \"Danceability\": 0.218, \"Energy\": 0.652, \"Loudness\": -7.953, \"Speechiness\": 0.0641, \"Acousticness\": 0.033, \"Liveness\": 0.172, \"Tempo\": 65.375, \"Duration (ms)\": 250053.0, \"Valence\": 0.0599, \"Chord\": \"E\"}, {\"Index\": 1266, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Boys Will Be Boys\", \"Streams\": 6015914, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"4szI7zRh7kLApCSqiB6R7b\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 63.0, \"Danceability\": 0.768, \"Energy\": 0.486, \"Loudness\": -5.954, \"Speechiness\": 0.0353, \"Acousticness\": 0.408, \"Liveness\": 0.098, \"Tempo\": 125.021, \"Duration (ms)\": 166266.0, \"Valence\": 0.519, \"Chord\": \"D#/Eb\"}, {\"Index\": 1267, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Auto Blu\", \"Streams\": 5995116, \"Artist\": \"Shiva, Eiffel 65\", \"Artist Followers\": 561372.0, \"Song ID\": \"5swpvba5YLqVDy1nbzUdog\", \"Genre\": \"['italian hip hop', 'trap italiana']\", \"Release Date\": \"2020-03-26\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 56.0, \"Danceability\": 0.82, \"Energy\": 0.783, \"Loudness\": -6.146, \"Speechiness\": 0.0621, \"Acousticness\": 0.0158, \"Liveness\": 0.0938, \"Tempo\": 130.015, \"Duration (ms)\": 166087.0, \"Valence\": 0.653, \"Chord\": \"F\"}, {\"Index\": 1268, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Du bist mein\", \"Streams\": 5878493, \"Artist\": \"Zuna, Loredana, SRNO\", \"Artist Followers\": 900975.0, \"Song ID\": \"719aY5gAzJbx2PHjyalZQu\", \"Genre\": \"['albanian hip hop', 'german hip hop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 54.0, \"Danceability\": 0.761, \"Energy\": 0.556, \"Loudness\": -6.943, \"Speechiness\": 0.364, \"Acousticness\": 0.138, \"Liveness\": 0.0976, \"Tempo\": 187.81, \"Duration (ms)\": 160357.0, \"Valence\": 0.521, \"Chord\": \"C#/Db\"}, {\"Index\": 1269, \"Highest Charting Position\": 28, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Too Late\", \"Streams\": 5867746, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"2K9Ovn1o2bTGqbsABGC6m3\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.638, \"Energy\": 0.863, \"Loudness\": -5.221, \"Speechiness\": 0.132, \"Acousticness\": 0.052, \"Liveness\": 0.685, \"Tempo\": 120.077, \"Duration (ms)\": 239973.0, \"Valence\": 0.226, \"Chord\": \"E\"}, {\"Index\": 1270, \"Highest Charting Position\": 136, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Wildflower\", \"Streams\": 5791343, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"6qlcjGJPTZEwR8nf2nSe9C\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.644, \"Energy\": 0.768, \"Loudness\": -4.316, \"Speechiness\": 0.0455, \"Acousticness\": 0.174, \"Liveness\": 0.469, \"Tempo\": 108.992, \"Duration (ms)\": 220536.0, \"Valence\": 0.598, \"Chord\": \"F#/Gb\"}, {\"Index\": 1271, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Faith\", \"Streams\": 5730081, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"3orEOtd8CPL8GFlpRpKuoE\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.375, \"Energy\": 0.605, \"Loudness\": -7.268, \"Speechiness\": 0.0729, \"Acousticness\": 0.612, \"Liveness\": 0.147, \"Tempo\": 175.946, \"Duration (ms)\": 283227.0, \"Valence\": 0.128, \"Chord\": \"C\"}, {\"Index\": 1272, \"Highest Charting Position\": 35, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Snowchild\", \"Streams\": 5423997, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"3WlbeuhfRSqU7ylK2Ui5U7\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 66.0, \"Danceability\": 0.55, \"Energy\": 0.611, \"Loudness\": -7.475, \"Speechiness\": 0.137, \"Acousticness\": 0.162, \"Liveness\": 0.121, \"Tempo\": 148.062, \"Duration (ms)\": 247187.0, \"Valence\": 0.243, \"Chord\": \"C\"}, {\"Index\": 1273, \"Highest Charting Position\": 37, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Escape From LA\", \"Streams\": 5307288, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"1sOW4PuG5X3Ie3EXUhAopJ\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.404, \"Energy\": 0.524, \"Loudness\": -8.996, \"Speechiness\": 0.0593, \"Acousticness\": 0.0456, \"Liveness\": 0.199, \"Tempo\": 145.74, \"Duration (ms)\": 355960.0, \"Valence\": 0.168, \"Chord\": \"F\"}, {\"Index\": 1274, \"Highest Charting Position\": 161, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Allein sein\", \"Streams\": 5119993, \"Artist\": \"Ufo361\", \"Artist Followers\": 1700759.0, \"Song ID\": \"2TrhpvxwuF6hrboTdRXwnS\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 54.0, \"Danceability\": 0.774, \"Energy\": 0.588, \"Loudness\": -8.529, \"Speechiness\": 0.225, \"Acousticness\": 0.0386, \"Liveness\": 0.258, \"Tempo\": 75.978, \"Duration (ms)\": 147353.0, \"Valence\": 0.392, \"Chord\": \"C#/Db\"}, {\"Index\": 1275, \"Highest Charting Position\": 44, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Bichiyal\", \"Streams\": 4946613, \"Artist\": \"Bad Bunny, Yaviah\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4j4w4CXm6BSr0s25wAWrrX\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 75.0, \"Danceability\": 0.737, \"Energy\": 0.766, \"Loudness\": -4.242, \"Speechiness\": 0.0458, \"Acousticness\": 0.31, \"Liveness\": 0.114, \"Tempo\": 93.956, \"Duration (ms)\": 196500.0, \"Valence\": 0.662, \"Chord\": \"A#/Bb\"}, {\"Index\": 1276, \"Highest Charting Position\": 85, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Medusa\", \"Streams\": 4901559, \"Artist\": \"Jhay Cortez, Anuel AA, J Balvin\", \"Artist Followers\": 2435159.0, \"Song ID\": \"3qM0vBxIe4VUbK0Z0smuVP\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-05\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 70.0, \"Danceability\": 0.886, \"Energy\": 0.604, \"Loudness\": -7.293, \"Speechiness\": 0.208, \"Acousticness\": 0.194, \"Liveness\": 0.107, \"Tempo\": 98.023, \"Duration (ms)\": 305333.0, \"Valence\": 0.383, \"Chord\": \"C\"}, {\"Index\": 1277, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Break Up Song\", \"Streams\": 4593343, \"Artist\": \"Little Mix\", \"Artist Followers\": 9398941.0, \"Song ID\": \"5HArmECc1y0lCHKVKDKXa4\", \"Genre\": \"['dance pop', 'girl group', 'pop', 'post-teen pop', 'talent show', 'uk pop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.631, \"Energy\": 0.75, \"Loudness\": -5.416, \"Speechiness\": 0.0394, \"Acousticness\": 0.00388, \"Liveness\": 0.286, \"Tempo\": 90.019, \"Duration (ms)\": 200293.0, \"Valence\": 0.593, \"Chord\": \"F\"}, {\"Index\": 1278, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Teeth\", \"Streams\": 4571612, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"26wLOs3ZuHJa2Ihhx6QIE6\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 78.0, \"Danceability\": 0.749, \"Energy\": 0.461, \"Loudness\": -2.961, \"Speechiness\": 0.0416, \"Acousticness\": 0.0516, \"Liveness\": 0.0738, \"Tempo\": 139.02, \"Duration (ms)\": 204887.0, \"Valence\": 0.42, \"Chord\": \"A#/Bb\"}, {\"Index\": 1279, \"Highest Charting Position\": 51, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Repeat After Me (Interlude)\", \"Streams\": 10058303, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"40U8d12pC5UHqmHwXjHjjl\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 63.0, \"Danceability\": 0.555, \"Energy\": 0.619, \"Loudness\": -7.918, \"Speechiness\": 0.0314, \"Acousticness\": 0.0323, \"Liveness\": 0.0917, \"Tempo\": 95.032, \"Duration (ms)\": 195813.0, \"Valence\": 0.141, \"Chord\": \"C\"}, {\"Index\": 1280, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Until I Bleed Out\", \"Streams\": 9132077, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"2BcnxwxBuar5wjCaLqm5N3\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 63.0, \"Danceability\": 0.245, \"Energy\": 0.394, \"Loudness\": -9.887, \"Speechiness\": 0.0374, \"Acousticness\": 0.423, \"Liveness\": 0.093, \"Tempo\": 115.233, \"Duration (ms)\": 190173.0, \"Valence\": 0.148, \"Chord\": \"C\"}, {\"Index\": 1281, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Rosa\", \"Streams\": 7564893, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"464uJVLmr0fDJGXOnciaDe\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 64.0, \"Danceability\": 0.651, \"Energy\": 0.561, \"Loudness\": -5.715, \"Speechiness\": 0.25, \"Acousticness\": 0.25, \"Liveness\": 0.435, \"Tempo\": 175.992, \"Duration (ms)\": 189827.0, \"Valence\": 0.369, \"Chord\": \"A\"}, {\"Index\": 1282, \"Highest Charting Position\": 88, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Gris\", \"Streams\": 7514854, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"1syf62zw48zu4FrPwMtDHk\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 65.0, \"Danceability\": 0.849, \"Energy\": 0.709, \"Loudness\": -4.717, \"Speechiness\": 0.0794, \"Acousticness\": 0.229, \"Liveness\": 0.329, \"Tempo\": 93.06, \"Duration (ms)\": 176627.0, \"Valence\": 0.916, \"Chord\": \"F#/Gb\"}, {\"Index\": 1283, \"Highest Charting Position\": 103, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Negro\", \"Streams\": 6651425, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"2hsA9YWuF3C9Gosi4dpjJN\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.795, \"Energy\": 0.911, \"Loudness\": -2.228, \"Speechiness\": 0.0875, \"Acousticness\": 0.0157, \"Liveness\": 0.131, \"Tempo\": 164.081, \"Duration (ms)\": 182093.0, \"Valence\": 0.8, \"Chord\": \"C\"}, {\"Index\": 1284, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Verde\", \"Streams\": 5745393, \"Artist\": \"J Balvin, Sky Rompiendo\", \"Artist Followers\": 29067437.0, \"Song ID\": \"3HTbI3yUJQw3fP0Po8qLcD\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 63.0, \"Danceability\": 0.828, \"Energy\": 0.738, \"Loudness\": -4.295, \"Speechiness\": 0.0516, \"Acousticness\": 0.0381, \"Liveness\": 0.0917, \"Tempo\": 94.995, \"Duration (ms)\": 142547.0, \"Valence\": 0.818, \"Chord\": \"G#/Ab\"}, {\"Index\": 1285, \"Highest Charting Position\": 15, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Baby Pluto\", \"Streams\": 5600261, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7hav1MHURQf5SAoPk0egqh\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 69.0, \"Danceability\": 0.772, \"Energy\": 0.634, \"Loudness\": -6.101, \"Speechiness\": 0.212, \"Acousticness\": 0.135, \"Liveness\": 0.432, \"Tempo\": 160.052, \"Duration (ms)\": 210261.0, \"Valence\": 0.671, \"Chord\": \"A#/Bb\"}, {\"Index\": 1286, \"Highest Charting Position\": 31, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Lo Mein\", \"Streams\": 5231134, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"6CUP2khYzdphXebxVTfPE3\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.855, \"Energy\": 0.676, \"Loudness\": -5.736, \"Speechiness\": 0.325, \"Acousticness\": 0.0888, \"Liveness\": 0.144, \"Tempo\": 133.082, \"Duration (ms)\": 195299.0, \"Valence\": 0.509, \"Chord\": \"C#/Db\"}, {\"Index\": 1287, \"Highest Charting Position\": 113, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"No Judgement\", \"Streams\": 5082563, \"Artist\": \"Niall Horan\", \"Artist Followers\": 7564659.0, \"Song ID\": \"5IUOU5xkzGHsRFOYNu3GSK\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 65.0, \"Danceability\": 0.723, \"Energy\": 0.726, \"Loudness\": -3.835, \"Speechiness\": 0.0472, \"Acousticness\": 0.0564, \"Liveness\": 0.057, \"Tempo\": 100.051, \"Duration (ms)\": 176283.0, \"Valence\": 0.962, \"Chord\": \"C#/Db\"}, {\"Index\": 1288, \"Highest Charting Position\": 57, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Futsal Shuffle 2020 - Bonus Track\", \"Streams\": 5068849, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2fOlBMkWR7lXJfqp5VTbDG\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 63.0, \"Danceability\": 0.879, \"Energy\": 0.448, \"Loudness\": -8.57, \"Speechiness\": 0.222, \"Acousticness\": 0.0346, \"Liveness\": 0.224, \"Tempo\": 136.985, \"Duration (ms)\": 198913.0, \"Valence\": 0.278, \"Chord\": \"G\"}, {\"Index\": 1289, \"Highest Charting Position\": 163, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Arco\\u00edris\", \"Streams\": 5044774, \"Artist\": \"J Balvin, Mr Eazi\", \"Artist Followers\": 29067437.0, \"Song ID\": \"5zzbORcD0GwLY0wQHP1Xs1\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 62.0, \"Danceability\": 0.731, \"Energy\": 0.787, \"Loudness\": -5.26, \"Speechiness\": 0.0721, \"Acousticness\": 0.0853, \"Liveness\": 0.316, \"Tempo\": 92.971, \"Duration (ms)\": 186693.0, \"Valence\": 0.393, \"Chord\": \"E\"}, {\"Index\": 1290, \"Highest Charting Position\": 65, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"TOES (feat. Lil Baby & Moneybagg Yo)\", \"Streams\": 4878903, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"2FvD20Z8aoWIePi7PoN8sG\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 73.0, \"Danceability\": 0.816, \"Energy\": 0.582, \"Loudness\": -4.141, \"Speechiness\": 0.341, \"Acousticness\": 0.0794, \"Liveness\": 0.0916, \"Tempo\": 160.004, \"Duration (ms)\": 136366.0, \"Valence\": 0.542, \"Chord\": \"G#/Ab\"}, {\"Index\": 1291, \"Highest Charting Position\": 42, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Feel Me\", \"Streams\": 4765672, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"6XXYdF6pJR1K3wKvuxmu7n\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 63.0, \"Danceability\": 0.71, \"Energy\": 0.808, \"Loudness\": -6.703, \"Speechiness\": 0.0433, \"Acousticness\": 0.44, \"Liveness\": 0.0734, \"Tempo\": 99.989, \"Duration (ms)\": 226003.0, \"Valence\": 0.392, \"Chord\": \"D\"}, {\"Index\": 1292, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"H <3 T E L\", \"Streams\": 4701388, \"Artist\": \"Dardan, Monet192\", \"Artist Followers\": 861082.0, \"Song ID\": \"3S1NOXjDr2A4xXXsWo8kLr\", \"Genre\": \"['albanian hip hop', 'german hip hop']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 34.0, \"Danceability\": 0.726, \"Energy\": 0.646, \"Loudness\": -6.9, \"Speechiness\": 0.0977, \"Acousticness\": 0.0495, \"Liveness\": 0.112, \"Tempo\": 134.999, \"Duration (ms)\": 163253.0, \"Valence\": 0.58, \"Chord\": \"C#/Db\"}, {\"Index\": 1293, \"Highest Charting Position\": 63, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"25/8\", \"Streams\": 4684378, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4NqQaovM14WR2hNPMFxgjb\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 71.0, \"Danceability\": 0.761, \"Energy\": 0.732, \"Loudness\": -5.469, \"Speechiness\": 0.0549, \"Acousticness\": 0.092, \"Liveness\": 0.0716, \"Tempo\": 151.982, \"Duration (ms)\": 243276.0, \"Valence\": 0.542, \"Chord\": \"E\"}, {\"Index\": 1294, \"Highest Charting Position\": 81, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Se Me Olvid\\u00f3\", \"Streams\": 4591194, \"Artist\": \"Christian Nodal\", \"Artist Followers\": 8123757.0, \"Song ID\": \"7paFC3FEu1WtPVP4Do6VZN\", \"Genre\": \"['mariachi', 'nuevo regional mexicano', 'ranchera', 'regional mexican']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 71.0, \"Danceability\": 0.65, \"Energy\": 0.558, \"Loudness\": -3.082, \"Speechiness\": 0.0309, \"Acousticness\": 0.368, \"Liveness\": 0.303, \"Tempo\": 141.82, \"Duration (ms)\": 159533.0, \"Valence\": 0.725, \"Chord\": \"C\"}, {\"Index\": 1295, \"Highest Charting Position\": 130, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"B.S. (feat. H.E.R.)\", \"Streams\": 4557817, \"Artist\": \"Jhen\\u00e9 Aiko\", \"Artist Followers\": 4720858.0, \"Song ID\": \"63wx9vdskaXbYxyDx4oJCZ\", \"Genre\": \"['alternative r&b', 'dance pop', 'pop', 'pop rap', 'r&b', 'urban contemporary']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 72.0, \"Danceability\": 0.617, \"Energy\": 0.525, \"Loudness\": -10.426, \"Speechiness\": 0.12, \"Acousticness\": 0.554, \"Liveness\": 0.135, \"Tempo\": 135.781, \"Duration (ms)\": 212867.0, \"Valence\": 0.377, \"Chord\": \"G#/Ab\"}, {\"Index\": 1296, \"Highest Charting Position\": 45, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Soli\\u00e1\", \"Streams\": 4516243, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"7sOfmPd18RWp3FoCzpa7Kw\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 72.0, \"Danceability\": 0.71, \"Energy\": 0.81, \"Loudness\": -5.507, \"Speechiness\": 0.0854, \"Acousticness\": 0.117, \"Liveness\": 0.154, \"Tempo\": 92.041, \"Duration (ms)\": 159282.0, \"Valence\": 0.184, \"Chord\": \"D\"}, {\"Index\": 1297, \"Highest Charting Position\": 55, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Est\\u00e1 Cabr\\u00f3n Ser Yo\", \"Streams\": 4438261, \"Artist\": \"Bad Bunny, Anuel AA\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4saHEjXw7O1NXJOzBkUKKG\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.81, \"Energy\": 0.854, \"Loudness\": -3.999, \"Speechiness\": 0.254, \"Acousticness\": 0.0732, \"Liveness\": 0.123, \"Tempo\": 154.083, \"Duration (ms)\": 227939.0, \"Valence\": 0.879, \"Chord\": \"A#/Bb\"}, {\"Index\": 1298, \"Highest Charting Position\": 61, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Bean (Kobe) [feat. Chief Keef]\", \"Streams\": 9039518, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"0IpnZchq8ek2A6pGEP2Qb1\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 67.0, \"Danceability\": 0.733, \"Energy\": 0.567, \"Loudness\": -6.718, \"Speechiness\": 0.319, \"Acousticness\": 0.0129, \"Liveness\": 0.382, \"Tempo\": 75.491, \"Duration (ms)\": 238816.0, \"Valence\": 0.319, \"Chord\": \"C\"}, {\"Index\": 1299, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Yessirskiii\", \"Streams\": 8374259, \"Artist\": \"Lil Uzi Vert, 21 Savage\", \"Artist Followers\": 11821805.0, \"Song ID\": \"59JWp4PjZ9TRM8cmtaDYB1\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 70.0, \"Danceability\": 0.895, \"Energy\": 0.739, \"Loudness\": -6.633, \"Speechiness\": 0.283, \"Acousticness\": 0.0183, \"Liveness\": 0.102, \"Tempo\": 140.007, \"Duration (ms)\": 219340.0, \"Valence\": 0.763, \"Chord\": \"G#/Ab\"}, {\"Index\": 1300, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Cardigan\", \"Streams\": 6586204, \"Artist\": \"Don Toliver\", \"Artist Followers\": 1606884.0, \"Song ID\": \"0Li1OuXXfi7950ilZUFGkF\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 70.0, \"Danceability\": 0.747, \"Energy\": 0.497, \"Loudness\": -6.542, \"Speechiness\": 0.0401, \"Acousticness\": 0.248, \"Liveness\": 0.138, \"Tempo\": 142.046, \"Duration (ms)\": 158709.0, \"Valence\": 0.0663, \"Chord\": \"E\"}, {\"Index\": 1301, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Silly Watch\", \"Streams\": 6442451, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"5egD7A5x9AHdVO2fMo3Wbo\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 65.0, \"Danceability\": 0.903, \"Energy\": 0.535, \"Loudness\": -6.238, \"Speechiness\": 0.286, \"Acousticness\": 0.0298, \"Liveness\": 0.0851, \"Tempo\": 130.117, \"Duration (ms)\": 195692.0, \"Valence\": 0.157, \"Chord\": \"G#/Ab\"}, {\"Index\": 1302, \"Highest Charting Position\": 70, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Hablamos Ma\\u00f1ana\", \"Streams\": 6105711, \"Artist\": \"Bad Bunny, Duki, Pablo Chill-E\", \"Artist Followers\": 36177712.0, \"Song ID\": \"1V8XneTrX6kKeoxYbk4x6h\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.683, \"Energy\": 0.677, \"Loudness\": -4.496, \"Speechiness\": 0.0469, \"Acousticness\": 0.0869, \"Liveness\": 0.0998, \"Tempo\": 156.019, \"Duration (ms)\": 240253.0, \"Valence\": 0.514, \"Chord\": \"C#/Db\"}, {\"Index\": 1303, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Lotus\", \"Streams\": 6017103, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4SnlSaLJJ7reJMCHM5YUuX\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 58.0, \"Danceability\": 0.802, \"Energy\": 0.748, \"Loudness\": -5.708, \"Speechiness\": 0.207, \"Acousticness\": 0.24, \"Liveness\": 0.165, \"Tempo\": 150.063, \"Duration (ms)\": 193861.0, \"Valence\": 0.516, \"Chord\": \"G#/Ab\"}, {\"Index\": 1304, \"Highest Charting Position\": 126, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Lettre \\u00e0 une femme\", \"Streams\": 5895243, \"Artist\": \"Ninho\", \"Artist Followers\": 4764552.0, \"Song ID\": \"10rwyGbKAWZ8JZbL7uHl28\", \"Genre\": \"['french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2020-03-07\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 54.0, \"Danceability\": 0.487, \"Energy\": 0.398, \"Loudness\": -9.901, \"Speechiness\": 0.0697, \"Acousticness\": 0.835, \"Liveness\": 0.12, \"Tempo\": 149.367, \"Duration (ms)\": 157766.0, \"Valence\": 0.905, \"Chord\": \"C#/Db\"}, {\"Index\": 1305, \"Highest Charting Position\": 57, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Que Malo\", \"Streams\": 5544180, \"Artist\": \"Bad Bunny, \\u00d1engo Flow\", \"Artist Followers\": 36177712.0, \"Song ID\": \"53v2u51nq3CxiKUNphRzP1\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.802, \"Energy\": 0.787, \"Loudness\": -6.181, \"Speechiness\": 0.0599, \"Acousticness\": 0.0832, \"Liveness\": 0.153, \"Tempo\": 94.026, \"Duration (ms)\": 167975.0, \"Valence\": 0.446, \"Chord\": \"G\"}, {\"Index\": 1306, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Leaders (feat. NAV)\", \"Streams\": 5496780, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4D7NrSeqkTarBrJ80b2sBc\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 60.0, \"Danceability\": 0.95, \"Energy\": 0.654, \"Loudness\": -5.895, \"Speechiness\": 0.307, \"Acousticness\": 0.0744, \"Liveness\": 0.138, \"Tempo\": 132.936, \"Duration (ms)\": 194844.0, \"Valence\": 0.886, \"Chord\": \"C\"}, {\"Index\": 1307, \"Highest Charting Position\": 149, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Strawberry Peels (feat. Young Thug & Gunna)\", \"Streams\": 5468083, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4lAQfuREAHG8IC0PiiigBt\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 59.0, \"Danceability\": 0.862, \"Energy\": 0.65, \"Loudness\": -6.978, \"Speechiness\": 0.355, \"Acousticness\": 0.0207, \"Liveness\": 0.568, \"Tempo\": 131.194, \"Duration (ms)\": 115350.0, \"Valence\": 0.658, \"Chord\": \"A#/Bb\"}, {\"Index\": 1308, \"Highest Charting Position\": 60, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"La Zona\", \"Streams\": 5440382, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5kqNIqFjijuzvVLhuY9B8j\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.762, \"Energy\": 0.801, \"Loudness\": -3.661, \"Speechiness\": 0.0409, \"Acousticness\": 0.2, \"Liveness\": 0.254, \"Tempo\": 93.992, \"Duration (ms)\": 136893.0, \"Valence\": 0.81, \"Chord\": \"C#/Db\"}, {\"Index\": 1309, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Wassup (feat. Future)\", \"Streams\": 5415044, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"19Ec2gbNtQTE44IizcPjtD\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 57.0, \"Danceability\": 0.762, \"Energy\": 0.622, \"Loudness\": -6.293, \"Speechiness\": 0.223, \"Acousticness\": 0.352, \"Liveness\": 0.145, \"Tempo\": 130.019, \"Duration (ms)\": 193314.0, \"Valence\": 0.626, \"Chord\": \"F\"}, {\"Index\": 1310, \"Highest Charting Position\": 69, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Una Vez\", \"Streams\": 5411302, \"Artist\": \"Bad Bunny, Mora\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5J7teKIJGtqVypgYI6sqXj\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 77.0, \"Danceability\": 0.55, \"Energy\": 0.598, \"Loudness\": -5.402, \"Speechiness\": 0.0831, \"Acousticness\": 0.132, \"Liveness\": 0.0955, \"Tempo\": 83.836, \"Duration (ms)\": 232496.0, \"Valence\": 0.543, \"Chord\": \"B\"}, {\"Index\": 1311, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Moon Relate\", \"Streams\": 5324545, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4sWGHlZGM1XA7TyWdtBAbA\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 58.0, \"Danceability\": 0.867, \"Energy\": 0.768, \"Loudness\": -3.73, \"Speechiness\": 0.0791, \"Acousticness\": 0.18, \"Liveness\": 0.254, \"Tempo\": 102.021, \"Duration (ms)\": 181826.0, \"Valence\": 0.34, \"Chord\": \"G\"}, {\"Index\": 1312, \"Highest Charting Position\": 163, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Black And White\", \"Streams\": 5204120, \"Artist\": \"Niall Horan\", \"Artist Followers\": 7564659.0, \"Song ID\": \"7rpNuuoMbid56XkDsx2FjE\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 75.0, \"Danceability\": 0.443, \"Energy\": 0.582, \"Loudness\": -6.02, \"Speechiness\": 0.0482, \"Acousticness\": 0.0301, \"Liveness\": 0.127, \"Tempo\": 147.589, \"Duration (ms)\": 193090.0, \"Valence\": 0.239, \"Chord\": \"D\"}, {\"Index\": 1313, \"Highest Charting Position\": 81, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"The Other Side (from Trolls World Tour)\", \"Streams\": 5193927, \"Artist\": \"SZA, Justin Timberlake\", \"Artist Followers\": 5888533.0, \"Song ID\": \"463PQggkmk5tTw8ug0ahOX\", \"Genre\": \"['pop', 'pop rap', 'r&b']\", \"Release Date\": \"2020-02-26\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 68.0, \"Danceability\": 0.76, \"Energy\": 0.607, \"Loudness\": -6.274, \"Speechiness\": 0.0964, \"Acousticness\": 0.00277, \"Liveness\": 0.132, \"Tempo\": 105.979, \"Duration (ms)\": 188187.0, \"Valence\": 0.709, \"Chord\": \"G\"}, {\"Index\": 1314, \"Highest Charting Position\": 53, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Whine Up\", \"Streams\": 5130783, \"Artist\": \"Nicky Jam, Anuel AA\", \"Artist Followers\": 14831925.0, \"Song ID\": \"2pWOMNQJW3g2zmGjP0Vkb0\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-01\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.817, \"Energy\": 0.665, \"Loudness\": -6.224, \"Speechiness\": 0.0758, \"Acousticness\": 0.0549, \"Liveness\": 0.103, \"Tempo\": 104.957, \"Duration (ms)\": 215460.0, \"Valence\": 0.662, \"Chord\": \"A\"}, {\"Index\": 1315, \"Highest Charting Position\": 37, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Ayy Macarena\", \"Streams\": 5046905, \"Artist\": \"Tyga\", \"Artist Followers\": 6298789.0, \"Song ID\": \"6LcauUZjF1eXQrgqMUecHX\", \"Genre\": \"['dance pop', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2019-11-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.816, \"Energy\": 0.629, \"Loudness\": -5.568, \"Speechiness\": 0.226, \"Acousticness\": 0.133, \"Liveness\": 0.0692, \"Tempo\": 96.493, \"Duration (ms)\": 131607.0, \"Valence\": 0.714, \"Chord\": \"D\"}, {\"Index\": 1316, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Trap This Way (This Way)\", \"Streams\": 5043990, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7vTspUAmMKFkUpKL9HLZNL\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 59.0, \"Danceability\": 0.71, \"Energy\": 0.586, \"Loudness\": -5.331, \"Speechiness\": 0.381, \"Acousticness\": 0.248, \"Liveness\": 0.193, \"Tempo\": 175.987, \"Duration (ms)\": 185439.0, \"Valence\": 0.207, \"Chord\": \"D\"}, {\"Index\": 1317, \"Highest Charting Position\": 113, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Who (feat. BTS)\", \"Streams\": 5004752, \"Artist\": \"Lauv\", \"Artist Followers\": 4442273.0, \"Song ID\": \"2qG81jL9UIP54uS8gYyP4k\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 74.0, \"Danceability\": 0.632, \"Energy\": 0.345, \"Loudness\": -8.0, \"Speechiness\": 0.0349, \"Acousticness\": 0.551, \"Liveness\": 0.104, \"Tempo\": 141.641, \"Duration (ms)\": 180413.0, \"Valence\": 0.0818, \"Chord\": \"B\"}, {\"Index\": 1318, \"Highest Charting Position\": 51, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Homecoming\", \"Streams\": 4988839, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"6vxU64pcIuQ38O015Zy4qj\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 63.0, \"Danceability\": 0.929, \"Energy\": 0.563, \"Loudness\": -7.428, \"Speechiness\": 0.49, \"Acousticness\": 0.000592, \"Liveness\": 0.244, \"Tempo\": 129.957, \"Duration (ms)\": 213885.0, \"Valence\": 0.353, \"Chord\": \"A\"}, {\"Index\": 1319, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Got The Guap (feat. Young Thug)\", \"Streams\": 4946997, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"1HF6P40Z7nfExGaB1Gk99v\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 58.0, \"Danceability\": 0.837, \"Energy\": 0.601, \"Loudness\": -5.628, \"Speechiness\": 0.198, \"Acousticness\": 0.21, \"Liveness\": 0.0928, \"Tempo\": 142.977, \"Duration (ms)\": 176756.0, \"Valence\": 0.749, \"Chord\": \"G#/Ab\"}, {\"Index\": 1320, \"Highest Charting Position\": 53, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Prices\", \"Streams\": 4898167, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4YcWzLSnGqLjSCycuSMHnn\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 65.0, \"Danceability\": 0.786, \"Energy\": 0.683, \"Loudness\": -5.397, \"Speechiness\": 0.205, \"Acousticness\": 0.173, \"Liveness\": 0.706, \"Tempo\": 126.002, \"Duration (ms)\": 233333.0, \"Valence\": 0.57, \"Chord\": \"G\"}, {\"Index\": 1321, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"I Can Show You\", \"Streams\": 4831405, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"0AhJag7VI8uFf3mJFsTwvf\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 57.0, \"Danceability\": 0.817, \"Energy\": 0.656, \"Loudness\": -7.086, \"Speechiness\": 0.277, \"Acousticness\": 0.051, \"Liveness\": 0.115, \"Tempo\": 139.915, \"Duration (ms)\": 120076.0, \"Valence\": 0.314, \"Chord\": \"A#/Bb\"}, {\"Index\": 1322, \"Highest Charting Position\": 52, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"I'm Sorry\", \"Streams\": 4818039, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"1xcOYJxDa5pObgxY1r0I9c\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 60.0, \"Danceability\": 0.858, \"Energy\": 0.547, \"Loudness\": -5.822, \"Speechiness\": 0.29, \"Acousticness\": 0.213, \"Liveness\": 0.104, \"Tempo\": 128.02, \"Duration (ms)\": 211883.0, \"Valence\": 0.303, \"Chord\": \"C#/Db\"}, {\"Index\": 1323, \"Highest Charting Position\": 19, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Black Swan\", \"Streams\": 4802069, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3bkkMZEAhx7rTVz1C0itRQ\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 70.0, \"Danceability\": 0.719, \"Energy\": 0.758, \"Loudness\": -5.167, \"Speechiness\": 0.0851, \"Acousticness\": 0.137, \"Liveness\": 0.129, \"Tempo\": 147.023, \"Duration (ms)\": 198261.0, \"Valence\": 0.49, \"Chord\": \"D\"}, {\"Index\": 1324, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Bad Child\", \"Streams\": 4787180, \"Artist\": \"Tones And I\", \"Artist Followers\": 1251372.0, \"Song ID\": \"2hBeHlR2d7wFJVLcj2fivL\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 0.0, \"Danceability\": 0.756, \"Energy\": 0.553, \"Loudness\": -4.24, \"Speechiness\": 0.0343, \"Acousticness\": 0.404, \"Liveness\": 0.158, \"Tempo\": 117.992, \"Duration (ms)\": 221467.0, \"Valence\": 0.597, \"Chord\": \"F#/Gb\"}, {\"Index\": 1325, \"Highest Charting Position\": 61, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Adicto (with Anuel AA & Ozuna)\", \"Streams\": 4785720, \"Artist\": \"Tainy\", \"Artist Followers\": 509411.0, \"Song ID\": \"3jbT1Y5MoPwEIpZndDDwVq\", \"Genre\": \"['latin', 'latin hip hop', 'latin pop', 'pop reggaeton', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-08-22\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.734, \"Energy\": 0.836, \"Loudness\": -4.803, \"Speechiness\": 0.0735, \"Acousticness\": 0.017, \"Liveness\": 0.179, \"Tempo\": 80.002, \"Duration (ms)\": 270741.0, \"Valence\": 0.623, \"Chord\": \"A#/Bb\"}, {\"Index\": 1326, \"Highest Charting Position\": 66, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"<3\", \"Streams\": 4755477, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4MZSqgwlE71CWZ6qQ3gkKm\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.631, \"Energy\": 0.665, \"Loudness\": -7.589, \"Speechiness\": 0.229, \"Acousticness\": 0.602, \"Liveness\": 0.152, \"Tempo\": 80.353, \"Duration (ms)\": 157967.0, \"Valence\": 0.634, \"Chord\": \"A#/Bb\"}, {\"Index\": 1327, \"Highest Charting Position\": 198, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Bad Girls, Good Vibes\", \"Streams\": 4752181, \"Artist\": \"Ufo361\", \"Artist Followers\": 1700759.0, \"Song ID\": \"7IxGslFZA5QhgXbUsDmcjf\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 53.0, \"Danceability\": 0.826, \"Energy\": 0.368, \"Loudness\": -12.761, \"Speechiness\": 0.133, \"Acousticness\": 0.516, \"Liveness\": 0.0914, \"Tempo\": 127.977, \"Duration (ms)\": 107446.0, \"Valence\": 0.158, \"Chord\": \"G\"}, {\"Index\": 1328, \"Highest Charting Position\": 120, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Liberdade Provis\\u00f3ria - Ao Vivo\", \"Streams\": 4730891, \"Artist\": \"Henrique & Juliano\", \"Artist Followers\": 13312073.0, \"Song ID\": \"3Ghyp3X5Ua9ypHnBIgOObI\", \"Genre\": \"['sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 58.0, \"Danceability\": 0.668, \"Energy\": 0.684, \"Loudness\": -5.937, \"Speechiness\": 0.0527, \"Acousticness\": 0.627, \"Liveness\": 0.923, \"Tempo\": 108.138, \"Duration (ms)\": 187986.0, \"Valence\": 0.7, \"Chord\": \"C#/Db\"}, {\"Index\": 1329, \"Highest Charting Position\": 60, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"POP\", \"Streams\": 10484727, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"1jDbQz6tr52WgScCTXMnaN\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 58.0, \"Danceability\": 0.741, \"Energy\": 0.599, \"Loudness\": -6.672, \"Speechiness\": 0.419, \"Acousticness\": 0.00961, \"Liveness\": 0.785, \"Tempo\": 139.891, \"Duration (ms)\": 227474.0, \"Valence\": 0.276, \"Chord\": \"C#/Db\"}, {\"Index\": 1330, \"Highest Charting Position\": 61, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Celebration Station\", \"Streams\": 10396969, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"25B5fGr9K0VdZJiRFsnMO4\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 61.0, \"Danceability\": 0.748, \"Energy\": 0.771, \"Loudness\": -4.156, \"Speechiness\": 0.15, \"Acousticness\": 0.101, \"Liveness\": 0.135, \"Tempo\": 142.086, \"Duration (ms)\": 195058.0, \"Valence\": 0.792, \"Chord\": \"F#/Gb\"}, {\"Index\": 1331, \"Highest Charting Position\": 64, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Bigger Than Life\", \"Streams\": 9974143, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2oHDJHNondITqbl8xZ9vPn\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 62.0, \"Danceability\": 0.776, \"Energy\": 0.752, \"Loudness\": -4.711, \"Speechiness\": 0.193, \"Acousticness\": 0.325, \"Liveness\": 0.33, \"Tempo\": 140.013, \"Duration (ms)\": 192705.0, \"Valence\": 0.716, \"Chord\": \"G#/Ab\"}, {\"Index\": 1332, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Venetia\", \"Streams\": 9824605, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"3BYIzNZ3t9lRQCACXSMLrT\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 63.0, \"Danceability\": 0.775, \"Energy\": 0.757, \"Loudness\": -4.139, \"Speechiness\": 0.175, \"Acousticness\": 0.162, \"Liveness\": 0.148, \"Tempo\": 142.933, \"Duration (ms)\": 188800.0, \"Valence\": 0.562, \"Chord\": \"A\"}, {\"Index\": 1333, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"You Better Move\", \"Streams\": 9533898, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"6YAxCn4juTWn5hWl2hzHGw\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 60.0, \"Danceability\": 0.842, \"Energy\": 0.556, \"Loudness\": -6.793, \"Speechiness\": 0.442, \"Acousticness\": 0.159, \"Liveness\": 0.204, \"Tempo\": 118.836, \"Duration (ms)\": 196639.0, \"Valence\": 0.306, \"Chord\": \"G#/Ab\"}, {\"Index\": 1334, \"Highest Charting Position\": 93, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Chrome Heart Tags\", \"Streams\": 8219307, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"46mT9NR7N9Zf5MolcrBgE3\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 57.0, \"Danceability\": 0.702, \"Energy\": 0.768, \"Loudness\": -4.055, \"Speechiness\": 0.0669, \"Acousticness\": 0.541, \"Liveness\": 0.105, \"Tempo\": 70.056, \"Duration (ms)\": 212821.0, \"Valence\": 0.574, \"Chord\": \"C\"}, {\"Index\": 1335, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Bust Me\", \"Streams\": 7828045, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4wBcaYqLPm7EtDVoJQORU4\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 57.0, \"Danceability\": 0.734, \"Energy\": 0.703, \"Loudness\": -6.256, \"Speechiness\": 0.355, \"Acousticness\": 0.237, \"Liveness\": 0.413, \"Tempo\": 151.923, \"Duration (ms)\": 194452.0, \"Valence\": 0.608, \"Chord\": \"B\"}, {\"Index\": 1336, \"Highest Charting Position\": 46, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Ren\\u00e9\", \"Streams\": 7240117, \"Artist\": \"Residente\", \"Artist Followers\": 878491.0, \"Song ID\": \"6gm12xlADJwiBbHIKBXzGW\", \"Genre\": \"['venezuelan hip hop']\", \"Release Date\": \"2020-02-27\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 65.0, \"Danceability\": 0.486, \"Energy\": 0.388, \"Loudness\": -9.326, \"Speechiness\": 0.126, \"Acousticness\": 0.435, \"Liveness\": 0.196, \"Tempo\": 90.471, \"Duration (ms)\": 457592.0, \"Valence\": 0.467, \"Chord\": \"C\"}, {\"Index\": 1337, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Secure The Bag\", \"Streams\": 7053947, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7gHZGXSJzM29WA384suYY2\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 57.0, \"Danceability\": 0.803, \"Energy\": 0.719, \"Loudness\": -4.485, \"Speechiness\": 0.392, \"Acousticness\": 0.344, \"Liveness\": 0.425, \"Tempo\": 129.945, \"Duration (ms)\": 238425.0, \"Valence\": 0.549, \"Chord\": \"C\"}, {\"Index\": 1338, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Urgency (feat. Syd)\", \"Streams\": 6224412, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"5KlPy74NOEAt8jC3FYURnQ\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 53.0, \"Danceability\": 0.619, \"Energy\": 0.784, \"Loudness\": -6.11, \"Speechiness\": 0.123, \"Acousticness\": 0.0326, \"Liveness\": 0.315, \"Tempo\": 156.035, \"Duration (ms)\": 181161.0, \"Valence\": 0.471, \"Chord\": \"C#/Db\"}, {\"Index\": 1339, \"Highest Charting Position\": 34, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"ON (Feat. Sia)\", \"Streams\": 6219276, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3IB5qOeMayvpOdHxYCL5tZ\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 64.0, \"Danceability\": 0.591, \"Energy\": 0.848, \"Loudness\": -4.397, \"Speechiness\": 0.0828, \"Acousticness\": 0.137, \"Liveness\": 0.372, \"Tempo\": 105.922, \"Duration (ms)\": 246816.0, \"Valence\": 0.386, \"Chord\": \"A\"}, {\"Index\": 1340, \"Highest Charting Position\": 99, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"P FKN R\", \"Streams\": 6041127, \"Artist\": \"Bad Bunny, Kendo Kaponi, Arcangel\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0fgsKar6uBO08vzHXkTjWi\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 66.0, \"Danceability\": 0.82, \"Energy\": 0.635, \"Loudness\": -5.749, \"Speechiness\": 0.0772, \"Acousticness\": 0.409, \"Liveness\": 0.244, \"Tempo\": 101.024, \"Duration (ms)\": 258280.0, \"Valence\": 0.528, \"Chord\": \"F\"}, {\"Index\": 1341, \"Highest Charting Position\": 108, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Modern Loneliness\", \"Streams\": 6020508, \"Artist\": \"Lauv\", \"Artist Followers\": 4442273.0, \"Song ID\": \"1eyek0KJEh2v5HQ9uQSybb\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 68.0, \"Danceability\": 0.702, \"Energy\": 0.508, \"Loudness\": -7.105, \"Speechiness\": 0.035, \"Acousticness\": 0.144, \"Liveness\": 0.108, \"Tempo\": 82.008, \"Duration (ms)\": 252337.0, \"Valence\": 0.143, \"Chord\": \"G#/Ab\"}, {\"Index\": 1342, \"Highest Charting Position\": 65, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Heatin Up (feat. Gunna)\", \"Streams\": 6004839, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"7KSSdFCBHCfq4KPzz78ghk\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 66.0, \"Danceability\": 0.788, \"Energy\": 0.436, \"Loudness\": -9.435, \"Speechiness\": 0.364, \"Acousticness\": 0.0611, \"Liveness\": 0.0979, \"Tempo\": 129.847, \"Duration (ms)\": 177314.0, \"Valence\": 0.341, \"Chord\": \"C#/Db\"}, {\"Index\": 1343, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"SKYBOX\", \"Streams\": 5846484, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"7GwYENSg87oERcW0Wacd6m\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 59.0, \"Danceability\": 0.779, \"Energy\": 0.707, \"Loudness\": -6.527, \"Speechiness\": 0.16, \"Acousticness\": 0.0991, \"Liveness\": 0.0934, \"Tempo\": 140.894, \"Duration (ms)\": 178097.0, \"Valence\": 0.343, \"Chord\": \"C#/Db\"}, {\"Index\": 1344, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Young & Alive\", \"Streams\": 5578323, \"Artist\": \"Bazzi\", \"Artist Followers\": 4421378.0, \"Song ID\": \"5RsKelNxucrDxgMbZ3vd3W\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-05\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 71.0, \"Danceability\": 0.716, \"Energy\": 0.563, \"Loudness\": -5.486, \"Speechiness\": 0.0425, \"Acousticness\": 0.326, \"Liveness\": 0.119, \"Tempo\": 86.005, \"Duration (ms)\": 160465.0, \"Valence\": 0.495, \"Chord\": \"D#/Eb\"}, {\"Index\": 1345, \"Highest Charting Position\": 169, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"i'm so tired...\", \"Streams\": 5547770, \"Artist\": \"Lauv, Troye Sivan\", \"Artist Followers\": 4442273.0, \"Song ID\": \"4vjpLMyL3ZO6aphdYr8XYw\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-01-03--2020-01-10\", \"Popularity\": 77.0, \"Danceability\": 0.599, \"Energy\": 0.733, \"Loudness\": -7.058, \"Speechiness\": 0.203, \"Acousticness\": 0.176, \"Liveness\": 0.242, \"Tempo\": 102.211, \"Duration (ms)\": 162583.0, \"Valence\": 0.534, \"Chord\": \"B\"}, {\"Index\": 1346, \"Highest Charting Position\": 53, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Numbers (feat. Roddy Ricch, Gunna and London On Da Track)\", \"Streams\": 5487069, \"Artist\": \"A Boogie Wit da Hoodie\", \"Artist Followers\": 5865895.0, \"Song ID\": \"733c1CWmIGymoQXdp7Us88\", \"Genre\": \"['melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 68.0, \"Danceability\": 0.819, \"Energy\": 0.654, \"Loudness\": -6.665, \"Speechiness\": 0.136, \"Acousticness\": 0.517, \"Liveness\": 0.0996, \"Tempo\": 133.503, \"Duration (ms)\": 188563.0, \"Valence\": 0.455, \"Chord\": \"B\"}, {\"Index\": 1347, \"Highest Charting Position\": 105, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Girl\", \"Streams\": 5434180, \"Artist\": \"Myke Towers\", \"Artist Followers\": 6161098.0, \"Song ID\": \"43NqTeL8pgBxKHPMiJKUP5\", \"Genre\": \"['trap latino']\", \"Release Date\": \"2020-01-24\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 72.0, \"Danceability\": 0.733, \"Energy\": 0.708, \"Loudness\": -4.957, \"Speechiness\": 0.0937, \"Acousticness\": 0.0325, \"Liveness\": 0.324, \"Tempo\": 93.021, \"Duration (ms)\": 186427.0, \"Valence\": 0.694, \"Chord\": \"F#/Gb\"}, {\"Index\": 1348, \"Highest Charting Position\": 104, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Puesto Pa' Guerrial\", \"Streams\": 5359969, \"Artist\": \"Bad Bunny, Myke Towers\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5gCg2qMPzKkW4jS4dBKdDs\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 64.0, \"Danceability\": 0.867, \"Energy\": 0.686, \"Loudness\": -5.342, \"Speechiness\": 0.221, \"Acousticness\": 0.311, \"Liveness\": 0.1, \"Tempo\": 139.968, \"Duration (ms)\": 190207.0, \"Valence\": 0.658, \"Chord\": \"E\"}, {\"Index\": 1349, \"Highest Charting Position\": 114, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Definitivamente\", \"Streams\": 5325447, \"Artist\": \"Daddy Yankee, Sech\", \"Artist Followers\": 23936368.0, \"Song ID\": \"113PlnpZbHd3WIqeYjhZWv\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 66.0, \"Danceability\": 0.813, \"Energy\": 0.764, \"Loudness\": -3.39, \"Speechiness\": 0.105, \"Acousticness\": 0.586, \"Liveness\": 0.253, \"Tempo\": 100.047, \"Duration (ms)\": 217773.0, \"Valence\": 0.429, \"Chord\": \"G#/Ab\"}, {\"Index\": 1350, \"Highest Charting Position\": 41, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"South of the Border (feat. Camila Cabello & Cardi B)\", \"Streams\": 5315827, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"4vUmTMuQqjdnvlZmAH61Qk\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-07-12\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.857, \"Energy\": 0.621, \"Loudness\": -6.376, \"Speechiness\": 0.0825, \"Acousticness\": 0.148, \"Liveness\": 0.0865, \"Tempo\": 97.989, \"Duration (ms)\": 204467.0, \"Valence\": 0.668, \"Chord\": \"A\"}, {\"Index\": 1351, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"I Fall Apart\", \"Streams\": 5251918, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"75ZvA4QfFiZvzhj2xkaWAh\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2016-12-09\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 80.0, \"Danceability\": 0.556, \"Energy\": 0.538, \"Loudness\": -5.408, \"Speechiness\": 0.0382, \"Acousticness\": 0.0689, \"Liveness\": 0.196, \"Tempo\": 143.95, \"Duration (ms)\": 223347.0, \"Valence\": 0.291, \"Chord\": \"G#/Ab\"}, {\"Index\": 1352, \"Highest Charting Position\": 191, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"fuck, i'm lonely (with Anne-Marie)\", \"Streams\": 5226991, \"Artist\": \"Lauv\", \"Artist Followers\": 4442273.0, \"Song ID\": \"09PGubKAMryhOWv1LHpCYz\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 74.0, \"Danceability\": 0.806, \"Energy\": 0.558, \"Loudness\": -6.46, \"Speechiness\": 0.0683, \"Acousticness\": 0.482, \"Liveness\": 0.0618, \"Tempo\": 95.016, \"Duration (ms)\": 198973.0, \"Valence\": 0.678, \"Chord\": \"A\"}, {\"Index\": 1353, \"Highest Charting Position\": 78, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Aventura\", \"Streams\": 5206102, \"Artist\": \"Lunay, Ozuna, Anuel AA\", \"Artist Followers\": 4963516.0, \"Song ID\": \"37zdqI4r1gswIzczSBkRon\", \"Genre\": \"['latin', 'latin pop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-10-25\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.729, \"Energy\": 0.726, \"Loudness\": -3.208, \"Speechiness\": 0.0422, \"Acousticness\": 0.223, \"Liveness\": 0.101, \"Tempo\": 92.025, \"Duration (ms)\": 217130.0, \"Valence\": 0.876, \"Chord\": \"F\"}, {\"Index\": 1354, \"Highest Charting Position\": 12, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Rare\", \"Streams\": 5195842, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"7HMmFQsKsljwTw8bS7lu19\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 68.0, \"Danceability\": 0.838, \"Energy\": 0.545, \"Loudness\": -6.713, \"Speechiness\": 0.0706, \"Acousticness\": 0.208, \"Liveness\": 0.103, \"Tempo\": 114.998, \"Duration (ms)\": 220590.0, \"Valence\": 0.631, \"Chord\": \"F\"}, {\"Index\": 1355, \"Highest Charting Position\": 69, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"VIBEZ\", \"Streams\": 5121486, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"0fySG6A6qLE8IvDpayb5bM\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.768, \"Energy\": 0.652, \"Loudness\": -2.708, \"Speechiness\": 0.307, \"Acousticness\": 0.113, \"Liveness\": 0.107, \"Tempo\": 154.187, \"Duration (ms)\": 144935.0, \"Valence\": 0.777, \"Chord\": \"C#/Db\"}, {\"Index\": 1356, \"Highest Charting Position\": 69, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Mean It\", \"Streams\": 5110064, \"Artist\": \"Lauv, LANY\", \"Artist Followers\": 4442273.0, \"Song ID\": \"3uc8AGNL0KbvISIrjnfRvN\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.746, \"Energy\": 0.45, \"Loudness\": -8.543, \"Speechiness\": 0.0872, \"Acousticness\": 0.0407, \"Liveness\": 0.172, \"Tempo\": 95.998, \"Duration (ms)\": 232853.0, \"Valence\": 0.336, \"Chord\": \"G\"}, {\"Index\": 1357, \"Highest Charting Position\": 49, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"That Way\", \"Streams\": 12059592, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"5raTDhlbxFDnpn89bxArdH\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-01\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 67.0, \"Danceability\": 0.719, \"Energy\": 0.611, \"Loudness\": -5.01, \"Speechiness\": 0.0403, \"Acousticness\": 0.0582, \"Liveness\": 0.155, \"Tempo\": 129.962, \"Duration (ms)\": 212354.0, \"Valence\": 0.489, \"Chord\": \"G\"}, {\"Index\": 1358, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Live Off My Closet (feat. Future)\", \"Streams\": 7410327, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"6AyWdCtEn1DdxjnxPeojR2\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 59.0, \"Danceability\": 0.807, \"Energy\": 0.678, \"Loudness\": -3.244, \"Speechiness\": 0.177, \"Acousticness\": 0.0345, \"Liveness\": 0.0986, \"Tempo\": 147.004, \"Duration (ms)\": 173061.0, \"Valence\": 0.21, \"Chord\": \"F#/Gb\"}, {\"Index\": 1359, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Commercial (feat. Lil Uzi Vert)\", \"Streams\": 6540577, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"3tDqEKKUs6gf8zMvSuLyLA\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 67.0, \"Danceability\": 0.892, \"Energy\": 0.486, \"Loudness\": -8.637, \"Speechiness\": 0.384, \"Acousticness\": 0.048, \"Liveness\": 0.146, \"Tempo\": 120.998, \"Duration (ms)\": 214215.0, \"Valence\": 0.535, \"Chord\": \"B\"}, {\"Index\": 1360, \"Highest Charting Position\": 75, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Sum 2 Prove\", \"Streams\": 6497610, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"2u3EyuCqqV31woqGvO9LBz\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 71.0, \"Danceability\": 0.823, \"Energy\": 0.552, \"Loudness\": -7.57, \"Speechiness\": 0.324, \"Acousticness\": 0.0174, \"Liveness\": 0.122, \"Tempo\": 124.038, \"Duration (ms)\": 205760.0, \"Valence\": 0.418, \"Chord\": \"E\"}, {\"Index\": 1361, \"Highest Charting Position\": 47, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Filter\", \"Streams\": 5913946, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"0ono6UCNVZ1XqOm6j78Blu\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 79.0, \"Danceability\": 0.781, \"Energy\": 0.762, \"Loudness\": -5.188, \"Speechiness\": 0.0626, \"Acousticness\": 0.0222, \"Liveness\": 0.121, \"Tempo\": 110.042, \"Duration (ms)\": 180221.0, \"Valence\": 0.86, \"Chord\": \"A#/Bb\"}, {\"Index\": 1362, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Matrix\", \"Streams\": 5724739, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"7ygVaACDENw4PgLbN1awFE\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-02-24\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 55.0, \"Danceability\": 0.789, \"Energy\": 0.509, \"Loudness\": -8.766, \"Speechiness\": 0.291, \"Acousticness\": 0.768, \"Liveness\": 0.272, \"Tempo\": 114.957, \"Duration (ms)\": 183793.0, \"Valence\": 0.418, \"Chord\": \"A\"}, {\"Index\": 1363, \"Highest Charting Position\": 91, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Bellaquita - Remix\", \"Streams\": 5676621, \"Artist\": \"Dalex, Lenny Tav\\u00e1rez, Anitta, Natti Natasha, Farruko, Justin Quiles\", \"Artist Followers\": 3600989.0, \"Song ID\": \"1Xnn1TPyr5h0hpRAT4B4EA\", \"Genre\": \"['latin', 'r&b en espanol', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.795, \"Energy\": 0.715, \"Loudness\": -3.582, \"Speechiness\": 0.0838, \"Acousticness\": 0.141, \"Liveness\": 0.179, \"Tempo\": 165.941, \"Duration (ms)\": 304733.0, \"Valence\": 0.758, \"Chord\": \"C#/Db\"}, {\"Index\": 1364, \"Highest Charting Position\": 139, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Infeliz\", \"Streams\": 5490386, \"Artist\": \"Arcangel, Bad Bunny\", \"Artist Followers\": 6671084.0, \"Song ID\": \"4z6wo6PJG4Fve45OXK6D9m\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-12-20\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 72.0, \"Danceability\": 0.713, \"Energy\": 0.798, \"Loudness\": -3.147, \"Speechiness\": 0.219, \"Acousticness\": 0.366, \"Liveness\": 0.246, \"Tempo\": 176.073, \"Duration (ms)\": 221103.0, \"Valence\": 0.721, \"Chord\": \"C#/Db\"}, {\"Index\": 1365, \"Highest Charting Position\": 60, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Que Tire Pa Lante\", \"Streams\": 5436773, \"Artist\": \"Daddy Yankee\", \"Artist Followers\": 23936368.0, \"Song ID\": \"6RyaV7owmVU6fzEPE17sF1\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-10-18\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.658, \"Energy\": 0.901, \"Loudness\": -2.814, \"Speechiness\": 0.0357, \"Acousticness\": 0.0478, \"Liveness\": 0.12, \"Tempo\": 93.979, \"Duration (ms)\": 210520.0, \"Valence\": 0.708, \"Chord\": \"G\"}, {\"Index\": 1366, \"Highest Charting Position\": 32, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Futsal Shuffle 2020\", \"Streams\": 5386512, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2Ec33AVlkTTq8BHFgBTdQs\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-12\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.881, \"Energy\": 0.457, \"Loudness\": -8.191, \"Speechiness\": 0.156, \"Acousticness\": 0.0327, \"Liveness\": 0.231, \"Tempo\": 136.97, \"Duration (ms)\": 198913.0, \"Valence\": 0.296, \"Chord\": \"G\"}, {\"Index\": 1367, \"Highest Charting Position\": 123, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"GOODMORNINGTOKYO!\", \"Streams\": 5286044, \"Artist\": \"TOKYO\\u2019S REVENGE\", \"Artist Followers\": 313480.0, \"Song ID\": \"0Q2n5yzl2XRqYbV77tZNYp\", \"Genre\": \"['meme rap', 'sad rap', 'vapor trap', 'viral rap']\", \"Release Date\": \"2019-10-18\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 74.0, \"Danceability\": 0.907, \"Energy\": 0.539, \"Loudness\": -7.782, \"Speechiness\": 0.36, \"Acousticness\": 0.0408, \"Liveness\": 0.253, \"Tempo\": 124.918, \"Duration (ms)\": 150115.0, \"Valence\": 0.664, \"Chord\": \"E\"}, {\"Index\": 1368, \"Highest Charting Position\": 58, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Own It (feat. Ed Sheeran & Burna Boy)\", \"Streams\": 5273046, \"Artist\": \"Stormzy\", \"Artist Followers\": 2317758.0, \"Song ID\": \"4QPEwDdOMhY7rNS05mTyMR\", \"Genre\": \"['grime', 'uk hip hop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.817, \"Energy\": 0.781, \"Loudness\": -4.178, \"Speechiness\": 0.112, \"Acousticness\": 0.00838, \"Liveness\": 0.123, \"Tempo\": 104.0, \"Duration (ms)\": 216707.0, \"Valence\": 0.359, \"Chord\": \"G\"}, {\"Index\": 1369, \"Highest Charting Position\": 128, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Life Is Good (feat. Drake, DaBaby & Lil Baby) - Remix\", \"Streams\": 5260351, \"Artist\": \"Future\", \"Artist Followers\": 10491105.0, \"Song ID\": \"4iiWcajF1fEUpwcUewc464\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-02-15\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 61.0, \"Danceability\": 0.81, \"Energy\": 0.566, \"Loudness\": -8.33, \"Speechiness\": 0.433, \"Acousticness\": 0.107, \"Liveness\": 0.122, \"Tempo\": 142.069, \"Duration (ms)\": 315346.0, \"Valence\": 0.582, \"Chord\": \"F\"}, {\"Index\": 1370, \"Highest Charting Position\": 58, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"My Time\", \"Streams\": 5212053, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4vTgx6h4seHvkuFh84JXYP\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 74.0, \"Danceability\": 0.674, \"Energy\": 0.64, \"Loudness\": -5.139, \"Speechiness\": 0.0339, \"Acousticness\": 0.151, \"Liveness\": 0.0925, \"Tempo\": 99.908, \"Duration (ms)\": 234458.0, \"Valence\": 0.664, \"Chord\": \"C\"}, {\"Index\": 1371, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"100k Cash\", \"Streams\": 5192813, \"Artist\": \"Capital Bra, Samra\", \"Artist Followers\": 4093115.0, \"Song ID\": \"033if6Adj8fwBYsQzHOfQ8\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-02-27\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 52.0, \"Danceability\": 0.701, \"Energy\": 0.714, \"Loudness\": -5.906, \"Speechiness\": 0.524, \"Acousticness\": 0.289, \"Liveness\": 0.0883, \"Tempo\": 86.91, \"Duration (ms)\": 173353.0, \"Valence\": 0.604, \"Chord\": \"A#/Bb\"}, {\"Index\": 1372, \"Highest Charting Position\": 185, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Drown (feat. Clinton Kane)\", \"Streams\": 5186141, \"Artist\": \"Martin Garrix\", \"Artist Followers\": 14921269.0, \"Song ID\": \"4RVtBlHFKj51Ipvpfv5ER4\", \"Genre\": \"['dance pop', 'dutch edm', 'edm', 'pop', 'pop dance', 'progressive house', 'tropical house']\", \"Release Date\": \"2020-02-27\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 74.0, \"Danceability\": 0.573, \"Energy\": 0.739, \"Loudness\": -5.455, \"Speechiness\": 0.0581, \"Acousticness\": 0.212, \"Liveness\": 0.175, \"Tempo\": 120.077, \"Duration (ms)\": 174062.0, \"Valence\": 0.363, \"Chord\": \"A\"}, {\"Index\": 1373, \"Highest Charting Position\": 103, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"me & ur ghost\", \"Streams\": 5184069, \"Artist\": \"blackbear\", \"Artist Followers\": 4272745.0, \"Song ID\": \"38KsRHYE10bG0paU78gL9r\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 71.0, \"Danceability\": 0.742, \"Energy\": 0.679, \"Loudness\": -4.594, \"Speechiness\": 0.0259, \"Acousticness\": 0.0488, \"Liveness\": 0.0754, \"Tempo\": 100.041, \"Duration (ms)\": 201398.0, \"Valence\": 0.856, \"Chord\": \"G\"}, {\"Index\": 1374, \"Highest Charting Position\": 146, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"QUE PRETENDES\", \"Streams\": 5141047, \"Artist\": \"J Balvin, Bad Bunny\", \"Artist Followers\": 29067437.0, \"Song ID\": \"25ZAibhr3bdlMCLmubZDVt\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.639, \"Energy\": 0.791, \"Loudness\": -4.443, \"Speechiness\": 0.253, \"Acousticness\": 0.0275, \"Liveness\": 0.362, \"Tempo\": 92.603, \"Duration (ms)\": 222347.0, \"Valence\": 0.939, \"Chord\": \"A#/Bb\"}, {\"Index\": 1375, \"Highest Charting Position\": 140, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"You Need To Calm Down\", \"Streams\": 5115153, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6RRNNciQGZEXnqk8SQ9yv5\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.771, \"Energy\": 0.671, \"Loudness\": -5.617, \"Speechiness\": 0.0553, \"Acousticness\": 0.00929, \"Liveness\": 0.0637, \"Tempo\": 85.026, \"Duration (ms)\": 171360.0, \"Valence\": 0.714, \"Chord\": \"D\"}, {\"Index\": 1376, \"Highest Charting Position\": 90, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Quizas\", \"Streams\": 5112244, \"Artist\": \"Rich Music LTD, Sech, Dalex, Justin Quiles, Lenny Tav\\u00e1rez, Feid, Wisin, Zion\", \"Artist Followers\": 206225.0, \"Song ID\": \"5Id5B3dxJZhPcV9GzgYZZe\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-10-11\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.727, \"Energy\": 0.815, \"Loudness\": -2.454, \"Speechiness\": 0.153, \"Acousticness\": 0.0258, \"Liveness\": 0.231, \"Tempo\": 176.075, \"Duration (ms)\": 216067.0, \"Valence\": 0.677, \"Chord\": \"D#/Eb\"}, {\"Index\": 1377, \"Highest Charting Position\": 106, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Soltera - Remix\", \"Streams\": 5078459, \"Artist\": \"Lunay, Daddy Yankee, Bad Bunny\", \"Artist Followers\": 4963516.0, \"Song ID\": \"1c0hsvHLELX6y8qymnpLKL\", \"Genre\": \"['latin', 'latin pop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-05-10\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.795, \"Energy\": 0.783, \"Loudness\": -4.271, \"Speechiness\": 0.0432, \"Acousticness\": 0.361, \"Liveness\": 0.437, \"Tempo\": 92.01, \"Duration (ms)\": 266087.0, \"Valence\": 0.799, \"Chord\": \"F\"}, {\"Index\": 1378, \"Highest Charting Position\": 46, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Trampoline (with ZAYN)\", \"Streams\": 5075520, \"Artist\": \"SHAED\", \"Artist Followers\": 139434.0, \"Song ID\": \"1iQDltZqI7BXnHrFy4Qo1k\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-09-26\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 73.0, \"Danceability\": 0.619, \"Energy\": 0.459, \"Loudness\": -5.782, \"Speechiness\": 0.0334, \"Acousticness\": 0.56, \"Liveness\": 0.137, \"Tempo\": 126.803, \"Duration (ms)\": 184280.0, \"Valence\": 0.498, \"Chord\": \"G\"}, {\"Index\": 1379, \"Highest Charting Position\": 82, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Truth Hurts\", \"Streams\": 5024683, \"Artist\": \"Lizzo\", \"Artist Followers\": 3991674.0, \"Song ID\": \"3HWzoMvoF3TQfYg4UPszDq\", \"Genre\": \"['dance pop', 'escape room', 'minnesota hip hop', 'pop', 'pop rap', 'post-teen pop', 'trap queen']\", \"Release Date\": \"2019-04-19\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.715, \"Energy\": 0.624, \"Loudness\": -3.046, \"Speechiness\": 0.114, \"Acousticness\": 0.11, \"Liveness\": 0.123, \"Tempo\": 158.087, \"Duration (ms)\": 173325.0, \"Valence\": 0.412, \"Chord\": \"E\"}, {\"Index\": 1380, \"Highest Charting Position\": 91, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"bury a friend\", \"Streams\": 5020303, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"7p6ZK1vOxKELFwlDfwkJCp\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 1.0, \"Danceability\": 0.887, \"Energy\": 0.388, \"Loudness\": -14.505, \"Speechiness\": 0.349, \"Acousticness\": 0.739, \"Liveness\": 0.106, \"Tempo\": 120.035, \"Duration (ms)\": 193143.0, \"Valence\": 0.205, \"Chord\": \"G#/Ab\"}, {\"Index\": 1381, \"Highest Charting Position\": 54, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Louder than bombs\", \"Streams\": 10016907, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3op7HNwLli54MBjFGzIlZO\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.643, \"Energy\": 0.667, \"Loudness\": -6.993, \"Speechiness\": 0.152, \"Acousticness\": 0.0433, \"Liveness\": 0.0904, \"Tempo\": 145.999, \"Duration (ms)\": 217404.0, \"Valence\": 0.485, \"Chord\": \"C\"}, {\"Index\": 1382, \"Highest Charting Position\": 56, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"UGH!\", \"Streams\": 9991177, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"1aKuG1GG76xPLUkjBbQo3W\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.72, \"Energy\": 0.824, \"Loudness\": -5.086, \"Speechiness\": 0.128, \"Acousticness\": 0.0394, \"Liveness\": 0.0509, \"Tempo\": 165.998, \"Duration (ms)\": 225012.0, \"Valence\": 0.333, \"Chord\": \"A#/Bb\"}, {\"Index\": 1383, \"Highest Charting Position\": 67, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"00:00 (Zero O\\u2019Clock)\", \"Streams\": 9372219, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4AlihYDqxXshKhvh5tnMfP\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.566, \"Energy\": 0.548, \"Loudness\": -6.456, \"Speechiness\": 0.0579, \"Acousticness\": 0.0802, \"Liveness\": 0.11, \"Tempo\": 157.999, \"Duration (ms)\": 250296.0, \"Valence\": 0.196, \"Chord\": \"C#/Db\"}, {\"Index\": 1384, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Friends\", \"Streams\": 8822365, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"7w05lsU2VLSeiT8Nukrv5M\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.55, \"Energy\": 0.747, \"Loudness\": -5.211, \"Speechiness\": 0.0407, \"Acousticness\": 0.0668, \"Liveness\": 0.0536, \"Tempo\": 79.98, \"Duration (ms)\": 199339.0, \"Valence\": 0.648, \"Chord\": \"C#/Db\"}, {\"Index\": 1385, \"Highest Charting Position\": 75, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"We are Bulletproof : the Eternal\", \"Streams\": 8516710, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"44WLOqH7QayQOQdeUHeKUK\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.526, \"Energy\": 0.575, \"Loudness\": -5.215, \"Speechiness\": 0.0309, \"Acousticness\": 0.225, \"Liveness\": 0.108, \"Tempo\": 84.047, \"Duration (ms)\": 261543.0, \"Valence\": 0.19, \"Chord\": \"A\"}, {\"Index\": 1386, \"Highest Charting Position\": 79, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Inner Child\", \"Streams\": 8312399, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4BKOjYosPhw334moS3wlbO\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 71.0, \"Danceability\": 0.589, \"Energy\": 0.696, \"Loudness\": -7.981, \"Speechiness\": 0.0725, \"Acousticness\": 0.017, \"Liveness\": 0.0808, \"Tempo\": 134.953, \"Duration (ms)\": 233266.0, \"Valence\": 0.332, \"Chord\": \"B\"}, {\"Index\": 1387, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Moon\", \"Streams\": 7850129, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"1xfXXujIlLZAx5wpu46Nyk\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.703, \"Energy\": 0.646, \"Loudness\": -6.658, \"Speechiness\": 0.0596, \"Acousticness\": 0.0104, \"Liveness\": 0.191, \"Tempo\": 141.87, \"Duration (ms)\": 208590.0, \"Valence\": 0.64, \"Chord\": \"F#/Gb\"}, {\"Index\": 1388, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Outro : Ego\", \"Streams\": 6857808, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3r9FFjLrAIQjoR8pSHVPC9\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 69.0, \"Danceability\": 0.808, \"Energy\": 0.903, \"Loudness\": -3.106, \"Speechiness\": 0.0958, \"Acousticness\": 0.0121, \"Liveness\": 0.0993, \"Tempo\": 116.988, \"Duration (ms)\": 196199.0, \"Valence\": 0.473, \"Chord\": \"C\"}, {\"Index\": 1389, \"Highest Charting Position\": 109, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Interlude : Shadow\", \"Streams\": 6655856, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"2Nib4r0saYQf2pUV4RFDhl\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 68.0, \"Danceability\": 0.385, \"Energy\": 0.798, \"Loudness\": -6.439, \"Speechiness\": 0.483, \"Acousticness\": 0.115, \"Liveness\": 0.181, \"Tempo\": 149.756, \"Duration (ms)\": 259821.0, \"Valence\": 0.141, \"Chord\": \"A\"}, {\"Index\": 1390, \"Highest Charting Position\": 120, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Respect\", \"Streams\": 6373954, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"37TSJmYKLxXmx8OehFpqMN\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 67.0, \"Danceability\": 0.661, \"Energy\": 0.84, \"Loudness\": -4.805, \"Speechiness\": 0.116, \"Acousticness\": 0.00485, \"Liveness\": 0.287, \"Tempo\": 91.457, \"Duration (ms)\": 237540.0, \"Valence\": 0.524, \"Chord\": \"C\"}, {\"Index\": 1391, \"Highest Charting Position\": 154, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Tudo Ok\", \"Streams\": 5510844, \"Artist\": \"Thiaguinho MT, Mila, JS o M\\u00e3o de Ouro\", \"Artist Followers\": 28017.0, \"Song ID\": \"4HUZBG98TYbxSR9V1V2DWS\", \"Genre\": \"['brega funk', 'funk carioca']\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 57.0, \"Danceability\": 0.814, \"Energy\": 0.755, \"Loudness\": -6.164, \"Speechiness\": 0.0942, \"Acousticness\": 0.239, \"Liveness\": 0.306, \"Tempo\": 79.976, \"Duration (ms)\": 178500.0, \"Valence\": 0.963, \"Chord\": \"B\"}, {\"Index\": 1392, \"Highest Charting Position\": 128, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Perreo en La Luna\", \"Streams\": 5135469, \"Artist\": \"Rich Music LTD, Sech, Dalex, Justin Quiles, Lenny Tav\\u00e1rez, Feid\", \"Artist Followers\": 206225.0, \"Song ID\": \"0RDgqtvOHLwcI6yz9bjsZV\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-10-11\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.711, \"Energy\": 0.757, \"Loudness\": -4.188, \"Speechiness\": 0.29, \"Acousticness\": 0.268, \"Liveness\": 0.367, \"Tempo\": 174.013, \"Duration (ms)\": 218587.0, \"Valence\": 0.724, \"Chord\": \"C#/Db\"}, {\"Index\": 1393, \"Highest Charting Position\": 129, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Lose Yourself - From \\\"8 Mile\\\" Soundtrack\", \"Streams\": 5118004, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5Z01UMMf7V1o0MzF86s6WJ\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2005-12-06\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 75.0, \"Danceability\": 0.692, \"Energy\": 0.744, \"Loudness\": -4.565, \"Speechiness\": 0.257, \"Acousticness\": 0.00868, \"Liveness\": 0.359, \"Tempo\": 171.374, \"Duration (ms)\": 326467.0, \"Valence\": 0.0612, \"Chord\": \"D\"}, {\"Index\": 1394, \"Highest Charting Position\": 118, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"all the good girls go to hell\", \"Streams\": 5074485, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"6IRdLKIyS4p7XNiP8r6rsx\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-03-29\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.726, \"Energy\": 0.444, \"Loudness\": -8.922, \"Speechiness\": 0.372, \"Acousticness\": 0.283, \"Liveness\": 0.177, \"Tempo\": 185.044, \"Duration (ms)\": 168840.0, \"Valence\": 0.569, \"Chord\": \"G#/Ab\"}, {\"Index\": 1395, \"Highest Charting Position\": 155, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"SENTAD\\u00c3O\", \"Streams\": 5013019, \"Artist\": \"PEDRO SAMPAIO, Felipe Original, JS o M\\u00e3o de Ouro\", \"Artist Followers\": 1050520.0, \"Song ID\": \"4lKuzrdZrJuCAedbIslF3A\", \"Genre\": \"['funk carioca']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2019-12-27--2020-01-03\", \"Popularity\": 64.0, \"Danceability\": 0.68, \"Energy\": 0.869, \"Loudness\": -1.94, \"Speechiness\": 0.0589, \"Acousticness\": 0.178, \"Liveness\": 0.223, \"Tempo\": 173.997, \"Duration (ms)\": 143448.0, \"Valence\": 0.924, \"Chord\": \"F#/Gb\"}, {\"Index\": 1396, \"Highest Charting Position\": 182, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Lottery (Renegade)\", \"Streams\": 4994448, \"Artist\": \"K CAMP\", \"Artist Followers\": 1347589.0, \"Song ID\": \"4dZTZbmJBCCofAExHwefda\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'pop r&b', 'pop rap', 'r&b', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 61.0, \"Danceability\": 0.915, \"Energy\": 0.556, \"Loudness\": -8.601, \"Speechiness\": 0.216, \"Acousticness\": 0.0145, \"Liveness\": 0.0733, \"Tempo\": 148.964, \"Duration (ms)\": 170947.0, \"Valence\": 0.67, \"Chord\": \"C#/Db\"}, {\"Index\": 1397, \"Highest Charting Position\": 104, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Si Te Vas\", \"Streams\": 4954292, \"Artist\": \"Sech, Ozuna\", \"Artist Followers\": 8766508.0, \"Song ID\": \"6Y4PDQv4XjYjHLeLmvyOt0\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-09-26\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.73, \"Energy\": 0.644, \"Loudness\": -4.124, \"Speechiness\": 0.132, \"Acousticness\": 0.0933, \"Liveness\": 0.143, \"Tempo\": 174.101, \"Duration (ms)\": 204907.0, \"Valence\": 0.554, \"Chord\": \"C\"}, {\"Index\": 1398, \"Highest Charting Position\": 121, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Que Calor (with J Balvin & El Alfa)\", \"Streams\": 4950254, \"Artist\": \"Major Lazer, Diplo\", \"Artist Followers\": 6223652.0, \"Song ID\": \"3iQGDAAKMrlJarnaYNgnSE\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'moombahton', 'pop', 'pop dance', 'pop rap']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 29.0, \"Danceability\": 0.873, \"Energy\": 0.656, \"Loudness\": -6.043, \"Speechiness\": 0.068, \"Acousticness\": 0.00477, \"Liveness\": 0.0726, \"Tempo\": 125.982, \"Duration (ms)\": 206811.0, \"Valence\": 0.546, \"Chord\": \"G#/Ab\"}, {\"Index\": 1399, \"Highest Charting Position\": 186, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Rich Rich\", \"Streams\": 4938864, \"Artist\": \"Ufo361\", \"Artist Followers\": 1700759.0, \"Song ID\": \"2QfmSvSMwTXcvlIkU0w1Yk\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 50.0, \"Danceability\": 0.548, \"Energy\": 0.648, \"Loudness\": -4.796, \"Speechiness\": 0.292, \"Acousticness\": 0.0842, \"Liveness\": 0.123, \"Tempo\": 141.937, \"Duration (ms)\": 204319.0, \"Valence\": 0.232, \"Chord\": \"E\"}, {\"Index\": 1400, \"Highest Charting Position\": 86, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Indeciso\", \"Streams\": 4897374, \"Artist\": \"Reik, J Balvin, Lalo Ebratt\", \"Artist Followers\": 1251372.0, \"Song ID\": \"0FnPT2g07W4aXuHjniC1of\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.738, \"Energy\": 0.748, \"Loudness\": -4.902, \"Speechiness\": 0.0453, \"Acousticness\": 0.182, \"Liveness\": 0.109, \"Tempo\": 94.949, \"Duration (ms)\": 217253.0, \"Valence\": 0.896, \"Chord\": \"C\"}, {\"Index\": 1401, \"Highest Charting Position\": 148, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"i love you\", \"Streams\": 4863910, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"0np7TYPZSum9xTxe9QTr21\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-03--2020-01-10\", \"Popularity\": 2.0, \"Danceability\": 0.42, \"Energy\": 0.131, \"Loudness\": -18.435, \"Speechiness\": 0.0382, \"Acousticness\": 0.953, \"Liveness\": 0.109, \"Tempo\": 137.421, \"Duration (ms)\": 291796.0, \"Valence\": 0.12, \"Chord\": \"C\"}, {\"Index\": 1402, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Mejor\", \"Streams\": 4851895, \"Artist\": \"Dalex, Sech\", \"Artist Followers\": 3600989.0, \"Song ID\": \"6C1jKbkCUgFws7M0M4oGCB\", \"Genre\": \"['latin', 'r&b en espanol', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 63.0, \"Danceability\": 0.524, \"Energy\": 0.577, \"Loudness\": -4.501, \"Speechiness\": 0.18, \"Acousticness\": 0.185, \"Liveness\": 0.103, \"Tempo\": 175.396, \"Duration (ms)\": 201361.0, \"Valence\": 0.19, \"Chord\": \"D\"}, {\"Index\": 1403, \"Highest Charting Position\": 57, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Give No Fxk\", \"Streams\": 9652399, \"Artist\": \"Migos, Travis Scott, Young Thug\", \"Artist Followers\": 11692972.0, \"Song ID\": \"6ZelF5APDN5r6XnFqcnvWR\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 59.0, \"Danceability\": 0.904, \"Energy\": 0.627, \"Loudness\": -5.608, \"Speechiness\": 0.222, \"Acousticness\": 0.0303, \"Liveness\": 0.0923, \"Tempo\": 145.976, \"Duration (ms)\": 224243.0, \"Valence\": 0.236, \"Chord\": \"C#/Db\"}, {\"Index\": 1404, \"Highest Charting Position\": 61, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Come Around Me\", \"Streams\": 9533583, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2o9LAypwGH4ctV0i9boo6d\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 66.0, \"Danceability\": 0.648, \"Energy\": 0.681, \"Loudness\": -8.389, \"Speechiness\": 0.0378, \"Acousticness\": 0.263, \"Liveness\": 0.0971, \"Tempo\": 157.941, \"Duration (ms)\": 200773.0, \"Valence\": 0.767, \"Chord\": \"D\"}, {\"Index\": 1405, \"Highest Charting Position\": 64, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Habitual\", \"Streams\": 9120086, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"40qyPyljksBEqlNw5sW37T\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 62.0, \"Danceability\": 0.764, \"Energy\": 0.443, \"Loudness\": -6.625, \"Speechiness\": 0.0439, \"Acousticness\": 0.52, \"Liveness\": 0.0749, \"Tempo\": 138.999, \"Duration (ms)\": 168200.0, \"Valence\": 0.63, \"Chord\": \"E\"}, {\"Index\": 1406, \"Highest Charting Position\": 65, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"All Around Me\", \"Streams\": 9010535, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5Py8zRKGkZvgHniVVtvNCN\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 63.0, \"Danceability\": 0.566, \"Energy\": 0.438, \"Loudness\": -7.564, \"Speechiness\": 0.0367, \"Acousticness\": 0.809, \"Liveness\": 0.212, \"Tempo\": 117.127, \"Duration (ms)\": 136907.0, \"Valence\": 0.692, \"Chord\": \"C\"}, {\"Index\": 1407, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Get Me (feat. Kehlani)\", \"Streams\": 8362828, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5VwwpU7KsLhgfbMEecedhJ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 61.0, \"Danceability\": 0.832, \"Energy\": 0.508, \"Loudness\": -6.913, \"Speechiness\": 0.149, \"Acousticness\": 0.0492, \"Liveness\": 0.107, \"Tempo\": 109.352, \"Duration (ms)\": 185427.0, \"Valence\": 0.75, \"Chord\": \"F#/Gb\"}, {\"Index\": 1408, \"Highest Charting Position\": 79, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Second Emotion (feat. Travis Scott)\", \"Streams\": 8109572, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"1PnAx788sAvcI3ZxTlEyX8\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 61.0, \"Danceability\": 0.796, \"Energy\": 0.777, \"Loudness\": -6.112, \"Speechiness\": 0.0567, \"Acousticness\": 0.0276, \"Liveness\": 0.095, \"Tempo\": 141.97, \"Duration (ms)\": 202720.0, \"Valence\": 0.96, \"Chord\": \"B\"}, {\"Index\": 1409, \"Highest Charting Position\": 85, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Running Over (feat. Lil Dicky)\", \"Streams\": 7493188, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"75nKBP8jQu681pTNCtrEnn\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.774, \"Energy\": 0.603, \"Loudness\": -7.319, \"Speechiness\": 0.0591, \"Acousticness\": 0.438, \"Liveness\": 0.0869, \"Tempo\": 149.982, \"Duration (ms)\": 179627.0, \"Valence\": 0.977, \"Chord\": \"B\"}, {\"Index\": 1410, \"Highest Charting Position\": 86, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Available\", \"Streams\": 7473249, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"1b6tPXXCV2fSNtR3SKWUQA\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.702, \"Energy\": 0.608, \"Loudness\": -6.843, \"Speechiness\": 0.0359, \"Acousticness\": 0.0736, \"Liveness\": 0.129, \"Tempo\": 75.012, \"Duration (ms)\": 195333.0, \"Valence\": 0.597, \"Chord\": \"D#/Eb\"}, {\"Index\": 1411, \"Highest Charting Position\": 96, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Breathe Deeper\", \"Streams\": 7142364, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"3LbZIhU0smEU5SUnxod4j4\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 66.0, \"Danceability\": 0.664, \"Energy\": 0.848, \"Loudness\": -4.51, \"Speechiness\": 0.0322, \"Acousticness\": 0.0245, \"Liveness\": 0.172, \"Tempo\": 104.998, \"Duration (ms)\": 372867.0, \"Valence\": 0.502, \"Chord\": \"B\"}, {\"Index\": 1412, \"Highest Charting Position\": 103, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Changes\", \"Streams\": 6865229, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"521Os1SMlxmsoevsqyjNmJ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 62.0, \"Danceability\": 0.485, \"Energy\": 0.412, \"Loudness\": -7.766, \"Speechiness\": 0.042, \"Acousticness\": 0.738, \"Liveness\": 0.12, \"Tempo\": 64.062, \"Duration (ms)\": 135493.0, \"Valence\": 0.612, \"Chord\": \"A\"}, {\"Index\": 1413, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Confirmation\", \"Streams\": 6520106, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"60brXKLTC15vK0av5gIldm\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.438, \"Energy\": 0.315, \"Loudness\": -8.186, \"Speechiness\": 0.0375, \"Acousticness\": 0.608, \"Liveness\": 0.151, \"Tempo\": 190.064, \"Duration (ms)\": 170587.0, \"Valence\": 0.449, \"Chord\": \"G#/Ab\"}, {\"Index\": 1414, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Mios mit Bars\", \"Streams\": 6341141, \"Artist\": \"Luciano\", \"Artist Followers\": 942380.0, \"Song ID\": \"7Ek9e3eIuktIFjpDRQfmHE\", \"Genre\": \"['german drill', 'german hip hop']\", \"Release Date\": \"2020-02-13\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 57.0, \"Danceability\": 0.677, \"Energy\": 0.633, \"Loudness\": -7.353, \"Speechiness\": 0.0467, \"Acousticness\": 0.111, \"Liveness\": 0.217, \"Tempo\": 145.012, \"Duration (ms)\": 232147.0, \"Valence\": 0.404, \"Chord\": \"A\"}, {\"Index\": 1415, \"Highest Charting Position\": 135, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"E.T.A.\", \"Streams\": 6008945, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6PzOPrXx8tJEqace76yrv2\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.465, \"Energy\": 0.494, \"Loudness\": -7.595, \"Speechiness\": 0.066, \"Acousticness\": 0.49, \"Liveness\": 0.127, \"Tempo\": 127.298, \"Duration (ms)\": 176733.0, \"Valence\": 0.457, \"Chord\": \"E\"}, {\"Index\": 1416, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Borderline\", \"Streams\": 5921044, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"5hM5arv9KDbCHS0k9uqwjr\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 77.0, \"Danceability\": 0.621, \"Energy\": 0.873, \"Loudness\": -3.067, \"Speechiness\": 0.0369, \"Acousticness\": 0.0406, \"Liveness\": 0.0824, \"Tempo\": 97.96, \"Duration (ms)\": 237800.0, \"Valence\": 0.873, \"Chord\": \"F\"}, {\"Index\": 1417, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Take It Out On Me\", \"Streams\": 5858768, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"39nTNk5MfyiiRupTwn1iyC\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 54.0, \"Danceability\": 0.772, \"Energy\": 0.616, \"Loudness\": -4.673, \"Speechiness\": 0.102, \"Acousticness\": 0.00337, \"Liveness\": 0.104, \"Tempo\": 129.967, \"Duration (ms)\": 178013.0, \"Valence\": 0.279, \"Chord\": \"G\"}, {\"Index\": 1418, \"Highest Charting Position\": 67, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"No Shame\", \"Streams\": 5835260, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"5EbidH3lGB30WuDsoR4km6\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 62.0, \"Danceability\": 0.576, \"Energy\": 0.807, \"Loudness\": -3.019, \"Speechiness\": 0.0374, \"Acousticness\": 0.0185, \"Liveness\": 0.0963, \"Tempo\": 90.932, \"Duration (ms)\": 192737.0, \"Valence\": 0.479, \"Chord\": \"G\"}, {\"Index\": 1419, \"Highest Charting Position\": 160, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Might Not Give Up (feat. Young Thug)\", \"Streams\": 5503902, \"Artist\": \"A Boogie Wit da Hoodie\", \"Artist Followers\": 5865895.0, \"Song ID\": \"4l2rsMfr20dj6nf6i6F3Y8\", \"Genre\": \"['melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 57.0, \"Danceability\": 0.687, \"Energy\": 0.592, \"Loudness\": -6.378, \"Speechiness\": 0.224, \"Acousticness\": 0.203, \"Liveness\": 0.279, \"Tempo\": 178.83, \"Duration (ms)\": 225266.0, \"Valence\": 0.246, \"Chord\": \"D\"}, {\"Index\": 1420, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"That's What Love Is\", \"Streams\": 5440037, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2hLu8L8SNfCN4yKyPdX0h3\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 59.0, \"Danceability\": 0.639, \"Energy\": 0.437, \"Loudness\": -6.959, \"Speechiness\": 0.0355, \"Acousticness\": 0.692, \"Liveness\": 0.12, \"Tempo\": 147.575, \"Duration (ms)\": 165120.0, \"Valence\": 0.751, \"Chord\": \"A\"}, {\"Index\": 1421, \"Highest Charting Position\": 80, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Forever Yours - Avicii Tribute\", \"Streams\": 5421905, \"Artist\": \"Kygo, Sandro Cavazza\", \"Artist Followers\": 1251372.0, \"Song ID\": \"418ohXmKnlngIosIn6gG0H\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-10\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 15.0, \"Danceability\": 0.53, \"Energy\": 0.612, \"Loudness\": -8.794, \"Speechiness\": 0.0518, \"Acousticness\": 0.253, \"Liveness\": 0.246, \"Tempo\": 119.255, \"Duration (ms)\": 193847.0, \"Valence\": 0.433, \"Chord\": \"A#/Bb\"}, {\"Index\": 1422, \"Highest Charting Position\": 68, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Baby\", \"Streams\": 5376451, \"Artist\": \"Joker Bra, VIZE\", \"Artist Followers\": 191521.0, \"Song ID\": \"1V7JaMp11LKGwKiVmSetf0\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-01-30\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 63.0, \"Danceability\": 0.771, \"Energy\": 0.921, \"Loudness\": -4.228, \"Speechiness\": 0.109, \"Acousticness\": 0.166, \"Liveness\": 0.119, \"Tempo\": 128.021, \"Duration (ms)\": 148125.0, \"Valence\": 0.56, \"Chord\": \"C#/Db\"}, {\"Index\": 1423, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"One More Year\", \"Streams\": 5279739, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"5ozqshq2dtU7SYCpCBu0NE\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 56.0, \"Danceability\": 0.602, \"Energy\": 0.88, \"Loudness\": -5.414, \"Speechiness\": 0.0354, \"Acousticness\": 0.057, \"Liveness\": 0.284, \"Tempo\": 114.009, \"Duration (ms)\": 324013.0, \"Valence\": 0.493, \"Chord\": \"C#/Db\"}, {\"Index\": 1424, \"Highest Charting Position\": 14, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Good News\", \"Streams\": 5210780, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"1DWZUa5Mzf2BwzpHtgbHPY\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 75.0, \"Danceability\": 0.794, \"Energy\": 0.32, \"Loudness\": -12.92, \"Speechiness\": 0.173, \"Acousticness\": 0.853, \"Liveness\": 0.112, \"Tempo\": 174.088, \"Duration (ms)\": 342040.0, \"Valence\": 0.241, \"Chord\": \"C#/Db\"}, {\"Index\": 1425, \"Highest Charting Position\": 141, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"wish you were gay\", \"Streams\": 5187997, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"3Fj47GNK2kUF0uaEDgXLaD\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-03-29\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.853, \"Energy\": 0.351, \"Loudness\": -10.198, \"Speechiness\": 0.241, \"Acousticness\": 0.39, \"Liveness\": 0.752, \"Tempo\": 118.028, \"Duration (ms)\": 221543.0, \"Valence\": 0.282, \"Chord\": \"G\"}, {\"Index\": 1426, \"Highest Charting Position\": 61, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Only The Young - Featured in Miss Americana\", \"Streams\": 5111068, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2slqvGLwzZZYsT4K4Y1GBC\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 63.0, \"Danceability\": 0.56, \"Energy\": 0.78, \"Loudness\": -4.895, \"Speechiness\": 0.0517, \"Acousticness\": 0.00244, \"Liveness\": 0.0714, \"Tempo\": 93.516, \"Duration (ms)\": 157507.0, \"Valence\": 0.602, \"Chord\": \"F\"}, {\"Index\": 1427, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Lost In Yesterday\", \"Streams\": 5096624, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"5JWPUEov2wlX7c0jhYZpeB\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 69.0, \"Danceability\": 0.569, \"Energy\": 0.84, \"Loudness\": -4.123, \"Speechiness\": 0.118, \"Acousticness\": 0.0295, \"Liveness\": 0.0995, \"Tempo\": 183.059, \"Duration (ms)\": 249587.0, \"Valence\": 0.749, \"Chord\": \"C#/Db\"}, {\"Index\": 1428, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"At Least For Now\", \"Streams\": 5033764, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6VLkgf5YmLixsabdqiCVGU\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 54.0, \"Danceability\": 0.375, \"Energy\": 0.304, \"Loudness\": -9.897, \"Speechiness\": 0.0325, \"Acousticness\": 0.683, \"Liveness\": 0.196, \"Tempo\": 83.832, \"Duration (ms)\": 149653.0, \"Valence\": 0.295, \"Chord\": \"A\"}, {\"Index\": 1429, \"Highest Charting Position\": 167, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"you should see me in a crown\", \"Streams\": 4988054, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6WbvBhwCaUuYHcHGEuVgqo\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 0.0, \"Danceability\": 0.683, \"Energy\": 0.534, \"Loudness\": -10.348, \"Speechiness\": 0.189, \"Acousticness\": 0.519, \"Liveness\": 0.148, \"Tempo\": 150.469, \"Duration (ms)\": 180567.0, \"Valence\": 0.284, \"Chord\": \"E\"}, {\"Index\": 1430, \"Highest Charting Position\": 186, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Too Good At Goodbyes\", \"Streams\": 4984764, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"3VlbOrM6nYPprVvzBZllE5\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2017-11-03\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 72.0, \"Danceability\": 0.681, \"Energy\": 0.372, \"Loudness\": -8.237, \"Speechiness\": 0.0432, \"Acousticness\": 0.64, \"Liveness\": 0.169, \"Tempo\": 91.873, \"Duration (ms)\": 201000.0, \"Valence\": 0.476, \"Chord\": \"F\"}, {\"Index\": 1431, \"Highest Charting Position\": 7, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Intentions\", \"Streams\": 28509534, \"Artist\": \"Justin Bieber, Quavo\", \"Artist Followers\": 48544923.0, \"Song ID\": \"4umIPjkehX1r7uhmGvXiSV\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-07--2020-02-14\", \"Popularity\": 77.0, \"Danceability\": 0.806, \"Energy\": 0.546, \"Loudness\": -6.637, \"Speechiness\": 0.0575, \"Acousticness\": 0.3, \"Liveness\": 0.102, \"Tempo\": 147.986, \"Duration (ms)\": 212867.0, \"Valence\": 0.874, \"Chord\": \"A\"}, {\"Index\": 1432, \"Highest Charting Position\": 105, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Yikes\", \"Streams\": 6561188, \"Artist\": \"Nicki Minaj\", \"Artist Followers\": 22170982.0, \"Song ID\": \"75dLEqanQTupF3dtP9exT5\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'pop rap', 'post-teen pop', 'queens hip hop']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-02-07--2020-02-14\", \"Popularity\": 70.0, \"Danceability\": 0.911, \"Energy\": 0.637, \"Loudness\": -8.381, \"Speechiness\": 0.447, \"Acousticness\": 0.0409, \"Liveness\": 0.238, \"Tempo\": 149.996, \"Duration (ms)\": 156882.0, \"Valence\": 0.66, \"Chord\": \"G#/Ab\"}, {\"Index\": 1433, \"Highest Charting Position\": 66, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Yellow Hearts\", \"Streams\": 6554824, \"Artist\": \"Ant Saunders\", \"Artist Followers\": 82522.0, \"Song ID\": \"2W4yABdLc4Jnds67Poi5Nl\", \"Genre\": \"['chill r&b', 'pop']\", \"Release Date\": \"2019-06-18\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.866, \"Energy\": 0.438, \"Loudness\": -8.943, \"Speechiness\": 0.0719, \"Acousticness\": 0.177, \"Liveness\": 0.0743, \"Tempo\": 129.039, \"Duration (ms)\": 223258.0, \"Valence\": 0.695, \"Chord\": \"G\"}, {\"Index\": 1434, \"Highest Charting Position\": 120, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Birthday\", \"Streams\": 6207326, \"Artist\": \"Anne-Marie\", \"Artist Followers\": 8153871.0, \"Song ID\": \"5hff5RQeE84pznOt8WEWeO\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-02-07--2020-02-14\", \"Popularity\": 65.0, \"Danceability\": 0.609, \"Energy\": 0.785, \"Loudness\": -3.32, \"Speechiness\": 0.0891, \"Acousticness\": 0.0502, \"Liveness\": 0.171, \"Tempo\": 151.995, \"Duration (ms)\": 181467.0, \"Valence\": 0.756, \"Chord\": \"B\"}, {\"Index\": 1435, \"Highest Charting Position\": 16, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"HIGHEST IN THE ROOM (feat. ROSAL\\u00cdA & Lil Baby) - REMIX\", \"Streams\": 6107499, \"Artist\": \"Travis Scott\", \"Artist Followers\": 437907.0, \"Song ID\": \"7h0d2h0fUmzbs7zeFigJPn\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.559, \"Energy\": 0.491, \"Loudness\": -6.406, \"Speechiness\": 0.0346, \"Acousticness\": 0.0567, \"Liveness\": 0.0992, \"Tempo\": 153.131, \"Duration (ms)\": 244874.0, \"Valence\": 0.114, \"Chord\": \"D\"}, {\"Index\": 1436, \"Highest Charting Position\": 65, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Good as Hell (feat. Ariana Grande) - Remix\", \"Streams\": 6066001, \"Artist\": \"Lizzo\", \"Artist Followers\": 3991674.0, \"Song ID\": \"07Oz5StQ7GRoygNLaXs2pd\", \"Genre\": \"['dance pop', 'escape room', 'minnesota hip hop', 'pop', 'pop rap', 'post-teen pop', 'trap queen']\", \"Release Date\": \"2016\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.668, \"Energy\": 0.892, \"Loudness\": -3.001, \"Speechiness\": 0.0645, \"Acousticness\": 0.298, \"Liveness\": 0.735, \"Tempo\": 95.927, \"Duration (ms)\": 159011.0, \"Valence\": 0.478, \"Chord\": \"F\"}, {\"Index\": 1437, \"Highest Charting Position\": 70, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"I Do It (ft. Big Sean, Lil Baby)\", \"Streams\": 5561205, \"Artist\": \"Lil Wayne\", \"Artist Followers\": 10710088.0, \"Song ID\": \"1bRO28yzxgO3y3UmNR29TZ\", \"Genre\": \"['hip hop', 'new orleans rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 60.0, \"Danceability\": 0.804, \"Energy\": 0.528, \"Loudness\": -3.231, \"Speechiness\": 0.378, \"Acousticness\": 0.125, \"Liveness\": 0.41, \"Tempo\": 138.005, \"Duration (ms)\": 184440.0, \"Valence\": 0.321, \"Chord\": \"C#/Db\"}, {\"Index\": 1438, \"Highest Charting Position\": 45, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Get Me\", \"Streams\": 5236560, \"Artist\": \"Justin Bieber, Kehlani\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5VwwpU7KsLhgfbMEecedhJ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 61.0, \"Danceability\": 0.832, \"Energy\": 0.508, \"Loudness\": -6.913, \"Speechiness\": 0.149, \"Acousticness\": 0.0492, \"Liveness\": 0.107, \"Tempo\": 109.352, \"Duration (ms)\": 185427.0, \"Valence\": 0.75, \"Chord\": \"F#/Gb\"}, {\"Index\": 1439, \"Highest Charting Position\": 95, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Yo x Ti, Tu x Mi\", \"Streams\": 5202210, \"Artist\": \"ROSAL\\u00cdA, Ozuna\", \"Artist Followers\": 4769627.0, \"Song ID\": \"7BlBVFwvbWvcwNcUarQmjk\", \"Genre\": \"['r&b en espanol']\", \"Release Date\": \"2019-08-15\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.78, \"Energy\": 0.759, \"Loudness\": -3.292, \"Speechiness\": 0.225, \"Acousticness\": 0.462, \"Liveness\": 0.143, \"Tempo\": 91.952, \"Duration (ms)\": 201040.0, \"Valence\": 0.579, \"Chord\": \"C#/Db\"}, {\"Index\": 1440, \"Highest Charting Position\": 161, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"DJ No Pare (feat. Zion, Dalex, Lenny Tav\\u00e1rez) - Remix\", \"Streams\": 5148516, \"Artist\": \"Justin Quiles, Natti Natasha, Farruko\", \"Artist Followers\": 2897862.0, \"Song ID\": \"1ndyl3wJCFs872XZ3ztPk6\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.743, \"Energy\": 0.709, \"Loudness\": -3.922, \"Speechiness\": 0.0879, \"Acousticness\": 0.0451, \"Liveness\": 0.0809, \"Tempo\": 170.001, \"Duration (ms)\": 258600.0, \"Valence\": 0.831, \"Chord\": \"D#/Eb\"}, {\"Index\": 1441, \"Highest Charting Position\": 160, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"EARFQUAKE\", \"Streams\": 5079657, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6782693.0, \"Song ID\": \"5hVghJ4KaYES3BFUATCYn0\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 79.0, \"Danceability\": 0.554, \"Energy\": 0.498, \"Loudness\": -8.866, \"Speechiness\": 0.0685, \"Acousticness\": 0.23, \"Liveness\": 0.795, \"Tempo\": 79.635, \"Duration (ms)\": 190067.0, \"Valence\": 0.413, \"Chord\": \"A\"}, {\"Index\": 1442, \"Highest Charting Position\": 157, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Pa' Olvidarme De Ella\", \"Streams\": 5066711, \"Artist\": \"Piso 21, Christian Nodal\", \"Artist Followers\": 7226268.0, \"Song ID\": \"1cVlW9WQiGlFdWUXFdFZGh\", \"Genre\": \"['colombian pop', 'latin', 'latin pop', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.728, \"Energy\": 0.542, \"Loudness\": -5.195, \"Speechiness\": 0.0514, \"Acousticness\": 0.259, \"Liveness\": 0.136, \"Tempo\": 90.016, \"Duration (ms)\": 227234.0, \"Valence\": 0.637, \"Chord\": \"C\"}, {\"Index\": 1443, \"Highest Charting Position\": 89, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Loco Contigo (feat. J. Balvin & Tyga)\", \"Streams\": 5013732, \"Artist\": \"DJ Snake, J Balvin\", \"Artist Followers\": 7408249.0, \"Song ID\": \"6osaMSJh9NguagEDQcZaKx\", \"Genre\": \"['dance pop', 'edm', 'electronic trap', 'pop', 'pop dance']\", \"Release Date\": \"2019-07-25\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.694, \"Energy\": 0.758, \"Loudness\": -2.986, \"Speechiness\": 0.218, \"Acousticness\": 0.278, \"Liveness\": 0.102, \"Tempo\": 192.091, \"Duration (ms)\": 185195.0, \"Valence\": 0.371, \"Chord\": \"B\"}, {\"Index\": 1444, \"Highest Charting Position\": 54, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Psycho\", \"Streams\": 4991751, \"Artist\": \"Red Velvet\", \"Artist Followers\": 5688315.0, \"Song ID\": \"3CYH422oy1cZNoo0GTG1TK\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2019-12-23\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.664, \"Energy\": 0.666, \"Loudness\": -2.203, \"Speechiness\": 0.0446, \"Acousticness\": 0.193, \"Liveness\": 0.0854, \"Tempo\": 139.987, \"Duration (ms)\": 210560.0, \"Valence\": 0.405, \"Chord\": \"G#/Ab\"}, {\"Index\": 1445, \"Highest Charting Position\": 113, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Suge\", \"Streams\": 4986299, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"2gwkD6igEhQbDQegRCcdoB\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-03-01\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.876, \"Energy\": 0.662, \"Loudness\": -6.482, \"Speechiness\": 0.426, \"Acousticness\": 0.0608, \"Liveness\": 0.127, \"Tempo\": 75.445, \"Duration (ms)\": 163320.0, \"Valence\": 0.844, \"Chord\": \"D\"}, {\"Index\": 1446, \"Highest Charting Position\": 101, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Con Altura\", \"Streams\": 4961249, \"Artist\": \"ROSAL\\u00cdA, J Balvin, El Guincho\", \"Artist Followers\": 4769627.0, \"Song ID\": \"2qG5sZ7Si6sdK74qLxedYM\", \"Genre\": \"['r&b en espanol']\", \"Release Date\": \"2019-03-28\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.882, \"Energy\": 0.689, \"Loudness\": -4.027, \"Speechiness\": 0.124, \"Acousticness\": 0.39, \"Liveness\": 0.0501, \"Tempo\": 97.963, \"Duration (ms)\": 161627.0, \"Valence\": 0.746, \"Chord\": \"F#/Gb\"}, {\"Index\": 1447, \"Highest Charting Position\": 140, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Only Human\", \"Streams\": 4953866, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"0DiDStADDVh3SvAsoJAFMk\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-06-07\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.795, \"Energy\": 0.496, \"Loudness\": -5.883, \"Speechiness\": 0.0722, \"Acousticness\": 0.108, \"Liveness\": 0.0645, \"Tempo\": 94.01, \"Duration (ms)\": 183000.0, \"Valence\": 0.874, \"Chord\": \"C\"}, {\"Index\": 1448, \"Highest Charting Position\": 51, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Eleven\", \"Streams\": 4947780, \"Artist\": \"Khalid\", \"Artist Followers\": 14190858.0, \"Song ID\": \"18O00Y7yrkJ0pRXm1n21Og\", \"Genre\": \"['pop']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 68.0, \"Danceability\": 0.679, \"Energy\": 0.408, \"Loudness\": -9.754, \"Speechiness\": 0.0882, \"Acousticness\": 0.133, \"Liveness\": 0.23, \"Tempo\": 129.079, \"Duration (ms)\": 206080.0, \"Valence\": 0.151, \"Chord\": \"E\"}, {\"Index\": 1449, \"Highest Charting Position\": 135, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Talk (feat. Disclosure)\", \"Streams\": 4940984, \"Artist\": \"Khalid\", \"Artist Followers\": 14190858.0, \"Song ID\": \"6TqXcAFInzjp0bODyvrWEq\", \"Genre\": \"['pop']\", \"Release Date\": \"2019-04-05\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.9, \"Energy\": 0.4, \"Loudness\": -8.575, \"Speechiness\": 0.127, \"Acousticness\": 0.0516, \"Liveness\": 0.0599, \"Tempo\": 135.984, \"Duration (ms)\": 197573.0, \"Valence\": 0.346, \"Chord\": \"C\"}, {\"Index\": 1450, \"Highest Charting Position\": 117, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Hot (Remix) [feat. Gunna and Travis Scott]\", \"Streams\": 4905155, \"Artist\": \"Travis Scott, Young Thug\", \"Artist Followers\": 3337982.0, \"Song ID\": \"56AMYGJzxBO6p8v0wEe9de\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-11-01\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.845, \"Energy\": 0.631, \"Loudness\": -8.206, \"Speechiness\": 0.216, \"Acousticness\": 0.188, \"Liveness\": 0.0806, \"Tempo\": 111.983, \"Duration (ms)\": 279907.0, \"Valence\": 0.545, \"Chord\": \"G\"}, {\"Index\": 1451, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Weiss\", \"Streams\": 4872077, \"Artist\": \"Samra\", \"Artist Followers\": 1045091.0, \"Song ID\": \"38YP1STiBe3AZevFFJILf4\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-02-07--2020-02-14\", \"Popularity\": 56.0, \"Danceability\": 0.6, \"Energy\": 0.525, \"Loudness\": -6.585, \"Speechiness\": 0.423, \"Acousticness\": 0.393, \"Liveness\": 0.111, \"Tempo\": 96.989, \"Duration (ms)\": 162702.0, \"Valence\": 0.436, \"Chord\": \"D\"}, {\"Index\": 1452, \"Highest Charting Position\": 105, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Con Calma\", \"Streams\": 4861378, \"Artist\": \"Daddy Yankee, Snow\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3GIhMWNecxw8GyCFwviF6v\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 3.0, \"Danceability\": 0.737, \"Energy\": 0.86, \"Loudness\": -2.652, \"Speechiness\": 0.0594, \"Acousticness\": 0.11, \"Liveness\": 0.0574, \"Tempo\": 93.989, \"Duration (ms)\": 193227.0, \"Valence\": 0.656, \"Chord\": \"G#/Ab\"}, {\"Index\": 1453, \"Highest Charting Position\": 148, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"MIDDLE CHILD\", \"Streams\": 4836113, \"Artist\": \"J. Cole\", \"Artist Followers\": 14103694.0, \"Song ID\": \"2JvzF1RMd7lE3KmFlsyZD8\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2019-01-23\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.837, \"Energy\": 0.364, \"Loudness\": -11.713, \"Speechiness\": 0.276, \"Acousticness\": 0.149, \"Liveness\": 0.271, \"Tempo\": 123.984, \"Duration (ms)\": 213594.0, \"Valence\": 0.463, \"Chord\": \"G#/Ab\"}, {\"Index\": 1454, \"Highest Charting Position\": 136, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Otro Trago - Remix\", \"Streams\": 4803294, \"Artist\": \"Sech, Ozuna, Anuel AA, Darell, Nicky Jam\", \"Artist Followers\": 8766508.0, \"Song ID\": \"4bTZeO72FwMa6wKOiqoynL\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-07-26\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.725, \"Energy\": 0.79, \"Loudness\": -2.331, \"Speechiness\": 0.197, \"Acousticness\": 0.0711, \"Liveness\": 0.0602, \"Tempo\": 175.988, \"Duration (ms)\": 287773.0, \"Valence\": 0.763, \"Chord\": \"C\"}, {\"Index\": 1455, \"Highest Charting Position\": 113, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"FML\", \"Streams\": 6350496, \"Artist\": \"Arizona Zervas\", \"Artist Followers\": 621200.0, \"Song ID\": \"6lruHh1jF7ezgbLv72xYmf\", \"Genre\": \"['pop rap', 'rhode island rap']\", \"Release Date\": \"2018-06-03\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 74.0, \"Danceability\": 0.822, \"Energy\": 0.575, \"Loudness\": -5.95, \"Speechiness\": 0.0934, \"Acousticness\": 0.113, \"Liveness\": 0.106, \"Tempo\": 100.087, \"Duration (ms)\": 223000.0, \"Valence\": 0.616, \"Chord\": \"F\"}, {\"Index\": 1456, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"King Of My City\", \"Streams\": 5922748, \"Artist\": \"A Boogie Wit da Hoodie\", \"Artist Followers\": 1251372.0, \"Song ID\": \"4JEz0Iz8PnzHe5B0CkYSjP\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 0.0, \"Danceability\": 0.679, \"Energy\": 0.679, \"Loudness\": -6.747, \"Speechiness\": 0.167, \"Acousticness\": 0.443, \"Liveness\": 0.153, \"Tempo\": 119.921, \"Duration (ms)\": 148676.0, \"Valence\": 0.245, \"Chord\": \"E\"}, {\"Index\": 1457, \"Highest Charting Position\": 22, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Those Kinda Nights (feat. Ed Sheeran)\", \"Streams\": 5823422, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"0VSzREd1OjEWJ9tXoFHRQH\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 66.0, \"Danceability\": 0.794, \"Energy\": 0.637, \"Loudness\": -6.29, \"Speechiness\": 0.339, \"Acousticness\": 0.028, \"Liveness\": 0.0919, \"Tempo\": 103.868, \"Duration (ms)\": 177693.0, \"Valence\": 0.393, \"Chord\": \"E\"}, {\"Index\": 1458, \"Highest Charting Position\": 136, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Mon Ami\", \"Streams\": 5774770, \"Artist\": \"Samra\", \"Artist Followers\": 1045091.0, \"Song ID\": \"1R4xkZXQUQ8QJtAdwHkSgC\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-01-29\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 53.0, \"Danceability\": 0.801, \"Energy\": 0.731, \"Loudness\": -3.723, \"Speechiness\": 0.383, \"Acousticness\": 0.188, \"Liveness\": 0.111, \"Tempo\": 105.666, \"Duration (ms)\": 138409.0, \"Valence\": 0.537, \"Chord\": \"G#/Ab\"}, {\"Index\": 1459, \"Highest Charting Position\": 120, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Break My Stride\", \"Streams\": 5312936, \"Artist\": \"Matthew Wilder\", \"Artist Followers\": 30386.0, \"Song ID\": \"1mCsF9Tw4AkIZOjvZbZZdT\", \"Genre\": \"['new wave pop']\", \"Release Date\": \"1983-03-19\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 73.0, \"Danceability\": 0.917, \"Energy\": 0.588, \"Loudness\": -11.047, \"Speechiness\": 0.0607, \"Acousticness\": 0.195, \"Liveness\": 0.0914, \"Tempo\": 110.077, \"Duration (ms)\": 184480.0, \"Valence\": 0.828, \"Chord\": \"A#/Bb\"}, {\"Index\": 1460, \"Highest Charting Position\": 76, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Kein Wort\", \"Streams\": 5208651, \"Artist\": \"Juju, Loredana, Miksu / Macloud\", \"Artist Followers\": 486474.0, \"Song ID\": \"1hoLUVBx0ixX3kn0EX0P5n\", \"Genre\": \"['frauenrap', 'german hip hop', 'german pop']\", \"Release Date\": \"2020-01-16\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.746, \"Energy\": 0.592, \"Loudness\": -6.861, \"Speechiness\": 0.0914, \"Acousticness\": 0.462, \"Liveness\": 0.187, \"Tempo\": 160.065, \"Duration (ms)\": 162094.0, \"Valence\": 0.629, \"Chord\": \"F#/Gb\"}, {\"Index\": 1461, \"Highest Charting Position\": 86, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Graveyard\", \"Streams\": 5044853, \"Artist\": \"Halsey\", \"Artist Followers\": 15663384.0, \"Song ID\": \"2ufmtcIFdFpuUYBPXK5f67\", \"Genre\": \"['dance pop', 'electropop', 'etherpop', 'indie poptimism', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.667, \"Energy\": 0.583, \"Loudness\": -5.127, \"Speechiness\": 0.0747, \"Acousticness\": 0.231, \"Liveness\": 0.181, \"Tempo\": 92.043, \"Duration (ms)\": 181806.0, \"Valence\": 0.187, \"Chord\": \"B\"}, {\"Index\": 1462, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Wake Up Call (feat. Trippie Redd)\", \"Streams\": 5029979, \"Artist\": \"KSI\", \"Artist Followers\": 2010879.0, \"Song ID\": \"5MYzajZVxBaPT2JUSRa99L\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2020-01-27\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 56.0, \"Danceability\": 0.642, \"Energy\": 0.669, \"Loudness\": -5.774, \"Speechiness\": 0.0486, \"Acousticness\": 0.318, \"Liveness\": 0.119, \"Tempo\": 156.084, \"Duration (ms)\": 175067.0, \"Valence\": 0.227, \"Chord\": \"F#/Gb\"}, {\"Index\": 1463, \"Highest Charting Position\": 131, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Turn Me On (feat. Vula)\", \"Streams\": 4925843, \"Artist\": \"Riton, Oliver Heldens\", \"Artist Followers\": 83743.0, \"Song ID\": \"0qaWEvPkts34WF68r8Dzx9\", \"Genre\": \"['dance pop', 'house', 'pop dance', 'tropical house', 'uk dance']\", \"Release Date\": \"2019-09-13\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.737, \"Energy\": 0.828, \"Loudness\": -4.711, \"Speechiness\": 0.0396, \"Acousticness\": 0.0149, \"Liveness\": 0.0862, \"Tempo\": 124.051, \"Duration (ms)\": 208474.0, \"Valence\": 0.517, \"Chord\": \"B\"}, {\"Index\": 1464, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Hips Don't Lie (feat. Wyclef Jean)\", \"Streams\": 4918636, \"Artist\": \"Shakira\", \"Artist Followers\": 22136717.0, \"Song ID\": \"3ZFTkvIE7kyPt6Nu3PEa7V\", \"Genre\": \"['colombian pop', 'dance pop', 'latin', 'latin pop', 'pop']\", \"Release Date\": \"2005-11-28\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 83.0, \"Danceability\": 0.778, \"Energy\": 0.824, \"Loudness\": -5.892, \"Speechiness\": 0.0707, \"Acousticness\": 0.284, \"Liveness\": 0.405, \"Tempo\": 100.024, \"Duration (ms)\": 218093.0, \"Valence\": 0.758, \"Chord\": \"A#/Bb\"}, {\"Index\": 1465, \"Highest Charting Position\": 106, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Liar\", \"Streams\": 4896939, \"Artist\": \"Camila Cabello\", \"Artist Followers\": 22698747.0, \"Song ID\": \"7LzouaWGFCy4tkXDOOnEyM\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-09-04\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 69.0, \"Danceability\": 0.74, \"Energy\": 0.498, \"Loudness\": -6.684, \"Speechiness\": 0.0456, \"Acousticness\": 0.0169, \"Liveness\": 0.319, \"Tempo\": 98.016, \"Duration (ms)\": 207039.0, \"Valence\": 0.652, \"Chord\": \"B\"}, {\"Index\": 1466, \"Highest Charting Position\": 191, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Going Bad (feat. Drake)\", \"Streams\": 4889500, \"Artist\": \"Meek Mill\", \"Artist Followers\": 5241145.0, \"Song ID\": \"2IRZnDFmlqMuOrYOLnZZyc\", \"Genre\": \"['hip hop', 'philly rap', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2018-11-30\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.889, \"Energy\": 0.496, \"Loudness\": -6.365, \"Speechiness\": 0.0905, \"Acousticness\": 0.259, \"Liveness\": 0.252, \"Tempo\": 86.003, \"Duration (ms)\": 180522.0, \"Valence\": 0.544, \"Chord\": \"E\"}, {\"Index\": 1467, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"ME! (feat. Brendon Urie of Panic! At The Disco)\", \"Streams\": 4884909, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2Rk4JlNc2TPmZe2af99d45\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 77.0, \"Danceability\": 0.61, \"Energy\": 0.83, \"Loudness\": -4.105, \"Speechiness\": 0.0571, \"Acousticness\": 0.033, \"Liveness\": 0.118, \"Tempo\": 182.162, \"Duration (ms)\": 193000.0, \"Valence\": 0.728, \"Chord\": \"C\"}, {\"Index\": 1468, \"Highest Charting Position\": 134, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Panini\", \"Streams\": 4867723, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5488666.0, \"Song ID\": \"1000nHvUdawXuUHgBod4Wv\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2019-09-13\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.703, \"Energy\": 0.594, \"Loudness\": -6.146, \"Speechiness\": 0.0752, \"Acousticness\": 0.342, \"Liveness\": 0.123, \"Tempo\": 153.848, \"Duration (ms)\": 114893.0, \"Valence\": 0.475, \"Chord\": \"F\"}, {\"Index\": 1469, \"Highest Charting Position\": 191, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"idontwannabeyouanymore\", \"Streams\": 4824483, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"41zXlQxzTi6cGAjpOXyLYH\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2017-12-22\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 78.0, \"Danceability\": 0.483, \"Energy\": 0.412, \"Loudness\": -8.461, \"Speechiness\": 0.0402, \"Acousticness\": 0.737, \"Liveness\": 0.116, \"Tempo\": 170.163, \"Duration (ms)\": 203569.0, \"Valence\": 0.247, \"Chord\": \"G\"}, {\"Index\": 1470, \"Highest Charting Position\": 158, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"The London (feat. J. Cole & Travis Scott)\", \"Streams\": 4791732, \"Artist\": \"J. Cole, Young Thug\", \"Artist Followers\": 6383275.0, \"Song ID\": \"7DcvwMAiqKJQD1rrdfxSDx\", \"Genre\": \"['atl hip hop', 'atl trap', 'gangster rap', 'hip hop', 'melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2019-05-23\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.796, \"Energy\": 0.586, \"Loudness\": -6.946, \"Speechiness\": 0.147, \"Acousticness\": 0.0247, \"Liveness\": 0.132, \"Tempo\": 97.981, \"Duration (ms)\": 200107.0, \"Valence\": 0.179, \"Chord\": \"E\"}, {\"Index\": 1471, \"Highest Charting Position\": 123, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"223's (feat. 9lokknine)\", \"Streams\": 4781697, \"Artist\": \"YNW Melly\", \"Artist Followers\": 6332535.0, \"Song ID\": \"4sjiIpEv617LDXaidKioOI\", \"Genre\": \"['melodic rap', 'trap']\", \"Release Date\": \"2019-08-09\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.932, \"Energy\": 0.547, \"Loudness\": -7.787, \"Speechiness\": 0.333, \"Acousticness\": 0.0388, \"Liveness\": 0.0924, \"Tempo\": 94.998, \"Duration (ms)\": 176640.0, \"Valence\": 0.695, \"Chord\": \"C\"}, {\"Index\": 1472, \"Highest Charting Position\": 26, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Darkness\", \"Streams\": 7618955, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5SiZJoLXp3WOl3J4C8IK0d\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 65.0, \"Danceability\": 0.671, \"Energy\": 0.623, \"Loudness\": -7.161, \"Speechiness\": 0.308, \"Acousticness\": 0.00998, \"Liveness\": 0.643, \"Tempo\": 75.055, \"Duration (ms)\": 337147.0, \"Valence\": 0.195, \"Chord\": \"D\"}, {\"Index\": 1473, \"Highest Charting Position\": 30, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"You Gon\\u2019 Learn (feat. Royce Da 5'9\\\" & White Gold)\", \"Streams\": 7157402, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"0GQ5bFTVFFKpwNPc7KwQnB\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 66.0, \"Danceability\": 0.68, \"Energy\": 0.82, \"Loudness\": -4.197, \"Speechiness\": 0.151, \"Acousticness\": 0.0614, \"Liveness\": 0.597, \"Tempo\": 140.033, \"Duration (ms)\": 234653.0, \"Valence\": 0.243, \"Chord\": \"E\"}, {\"Index\": 1474, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Blue World\", \"Streams\": 7060589, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"2hwOoMtWPtTSSn6WHV7Vp5\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 75.0, \"Danceability\": 0.742, \"Energy\": 0.553, \"Loudness\": -8.98, \"Speechiness\": 0.419, \"Acousticness\": 0.389, \"Liveness\": 0.0694, \"Tempo\": 84.931, \"Duration (ms)\": 209440.0, \"Valence\": 0.508, \"Chord\": \"G#/Ab\"}, {\"Index\": 1475, \"Highest Charting Position\": 99, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Liberdade Provis\\u00f3ria\", \"Streams\": 6442626, \"Artist\": \"Henrique & Juliano\", \"Artist Followers\": 13312073.0, \"Song ID\": \"1vG3YuKRYqPwTmNmYgqkpg\", \"Genre\": \"['sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.668, \"Energy\": 0.684, \"Loudness\": -5.937, \"Speechiness\": 0.0527, \"Acousticness\": 0.627, \"Liveness\": 0.923, \"Tempo\": 108.138, \"Duration (ms)\": 187986.0, \"Valence\": 0.7, \"Chord\": \"C#/Db\"}, {\"Index\": 1476, \"Highest Charting Position\": 32, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Unaccommodating (feat. Young M.A)\", \"Streams\": 6374807, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"0q2vG0UVuy6ajjcpkQHdZM\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 65.0, \"Danceability\": 0.852, \"Energy\": 0.752, \"Loudness\": -5.793, \"Speechiness\": 0.0597, \"Acousticness\": 0.0169, \"Liveness\": 0.394, \"Tempo\": 89.95, \"Duration (ms)\": 216600.0, \"Valence\": 0.389, \"Chord\": \"C#/Db\"}, {\"Index\": 1477, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Donuts\", \"Streams\": 6113037, \"Artist\": \"Gzuz\", \"Artist Followers\": 1140383.0, \"Song ID\": \"5XVPNr0CAoUn1jD033Ucoo\", \"Genre\": \"['deep german hip hop', 'german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-02-13\", \"Weeks Charted\": \"2020-01-24--2020-01-31\", \"Popularity\": 62.0, \"Danceability\": 0.784, \"Energy\": 0.703, \"Loudness\": -7.491, \"Speechiness\": 0.236, \"Acousticness\": 0.0973, \"Liveness\": 0.0754, \"Tempo\": 141.035, \"Duration (ms)\": 162938.0, \"Valence\": 0.556, \"Chord\": \"B\"}, {\"Index\": 1478, \"Highest Charting Position\": 44, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Leaving Heaven (feat. Skylar Grey)\", \"Streams\": 5466161, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5CpsIb7SMFHjmAG8RvIWfq\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.661, \"Energy\": 0.748, \"Loudness\": -4.809, \"Speechiness\": 0.206, \"Acousticness\": 0.175, \"Liveness\": 0.254, \"Tempo\": 171.983, \"Duration (ms)\": 265947.0, \"Valence\": 0.509, \"Chord\": \"D\"}, {\"Index\": 1479, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Zu Ende\", \"Streams\": 5297101, \"Artist\": \"Samra, ELIF\", \"Artist Followers\": 1045091.0, \"Song ID\": \"0Vl4eICpXMjtiK0RhdaWov\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-01-23\", \"Weeks Charted\": \"2020-01-24--2020-01-31\", \"Popularity\": 57.0, \"Danceability\": 0.707, \"Energy\": 0.747, \"Loudness\": -5.212, \"Speechiness\": 0.279, \"Acousticness\": 0.307, \"Liveness\": 0.183, \"Tempo\": 80.025, \"Duration (ms)\": 197861.0, \"Valence\": 0.491, \"Chord\": \"G#/Ab\"}, {\"Index\": 1480, \"Highest Charting Position\": 171, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"B.I.T.C.H.\", \"Streams\": 5215211, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"06scTb0zbkxYNgpAB3J9fN\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-01-24\", \"Weeks Charted\": \"2020-01-24--2020-01-31\", \"Popularity\": 59.0, \"Danceability\": 0.742, \"Energy\": 0.731, \"Loudness\": -4.362, \"Speechiness\": 0.306, \"Acousticness\": 0.0851, \"Liveness\": 0.131, \"Tempo\": 174.019, \"Duration (ms)\": 183143.0, \"Valence\": 0.547, \"Chord\": \"B\"}, {\"Index\": 1481, \"Highest Charting Position\": 56, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Look At Her Now\", \"Streams\": 5066377, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 1251372.0, \"Song ID\": \"2XUPkAie1nz9SYIhbdIVWb\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.753, \"Energy\": 0.564, \"Loudness\": -7.908, \"Speechiness\": 0.251, \"Acousticness\": 0.114, \"Liveness\": 0.359, \"Tempo\": 77.341, \"Duration (ms)\": 162596.0, \"Valence\": 0.55, \"Chord\": \"A#/Bb\"}, {\"Index\": 1482, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Bi Sonraki Hayat\\u0131mda Gel\", \"Streams\": 5037967, \"Artist\": \"Murda, Ezhel\", \"Artist Followers\": 862965.0, \"Song ID\": \"5SYkeNpjhJPFUMOP5TK8iw\", \"Genre\": \"['basshall', 'turkish trap']\", \"Release Date\": \"2020-08-28\", \"Weeks Charted\": \"2020-01-24--2020-01-31\", \"Popularity\": 57.0, \"Danceability\": 0.933, \"Energy\": 0.448, \"Loudness\": -4.491, \"Speechiness\": 0.136, \"Acousticness\": 0.0253, \"Liveness\": 0.104, \"Tempo\": 103.981, \"Duration (ms)\": 167350.0, \"Valence\": 0.737, \"Chord\": \"G#/Ab\"}, {\"Index\": 1483, \"Highest Charting Position\": 126, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Legends\", \"Streams\": 4922369, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"1Knctxx9vGZxpZfF66BIEa\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2018-06-22\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.594, \"Energy\": 0.798, \"Loudness\": -5.244, \"Speechiness\": 0.0844, \"Acousticness\": 0.115, \"Liveness\": 0.143, \"Tempo\": 142.049, \"Duration (ms)\": 191840.0, \"Valence\": 0.381, \"Chord\": \"E\"}, {\"Index\": 1484, \"Highest Charting Position\": 157, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"11 PM\", \"Streams\": 4891989, \"Artist\": \"Maluma\", \"Artist Followers\": 26784251.0, \"Song ID\": \"7KbF6AdprOXEEHlsq11Z6d\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.777, \"Energy\": 0.712, \"Loudness\": -4.84, \"Speechiness\": 0.277, \"Acousticness\": 0.217, \"Liveness\": 0.091, \"Tempo\": 95.692, \"Duration (ms)\": 175733.0, \"Valence\": 0.68, \"Chord\": \"A#/Bb\"}, {\"Index\": 1485, \"Highest Charting Position\": 182, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Post Malone (feat. RANI)\", \"Streams\": 4855270, \"Artist\": \"Sam Feldt\", \"Artist Followers\": 639516.0, \"Song ID\": \"0qc4QlcCxVTGyShurEv1UU\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'pop', 'pop dance', 'pop edm', 'tropical house']\", \"Release Date\": \"2019-05-24\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.59, \"Energy\": 0.642, \"Loudness\": -3.87, \"Speechiness\": 0.122, \"Acousticness\": 0.0771, \"Liveness\": 0.105, \"Tempo\": 107.356, \"Duration (ms)\": 174444.0, \"Valence\": 0.651, \"Chord\": \"G\"}, {\"Index\": 1486, \"Highest Charting Position\": 52, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"In Too Deep\", \"Streams\": 4824037, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"7Dj2wqPYXfSRFwa6qyOztr\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.72, \"Energy\": 0.767, \"Loudness\": -5.839, \"Speechiness\": 0.214, \"Acousticness\": 0.0387, \"Liveness\": 0.202, \"Tempo\": 88.966, \"Duration (ms)\": 194707.0, \"Valence\": 0.595, \"Chord\": \"A#/Bb\"}, {\"Index\": 1487, \"Highest Charting Position\": 57, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Premonition - Intro\", \"Streams\": 10830400, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"7ccTcabbJlCJiIqtrSSwBk\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.847, \"Energy\": 0.637, \"Loudness\": -5.193, \"Speechiness\": 0.367, \"Acousticness\": 0.0258, \"Liveness\": 0.382, \"Tempo\": 165.979, \"Duration (ms)\": 173893.0, \"Valence\": 0.511, \"Chord\": \"C#/Db\"}, {\"Index\": 1488, \"Highest Charting Position\": 62, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"I Can See\", \"Streams\": 10086930, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"3R8CyhJfVjvgIROd5RSGhQ\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.699, \"Energy\": 0.503, \"Loudness\": -9.922, \"Speechiness\": 0.0882, \"Acousticness\": 0.391, \"Liveness\": 0.0996, \"Tempo\": 114.86, \"Duration (ms)\": 220853.0, \"Valence\": 0.0546, \"Chord\": \"F\"}, {\"Index\": 1489, \"Highest Charting Position\": 69, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Hand Me Downs\", \"Streams\": 9521654, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"2Yv2mHzr5AQavVdwQjEokV\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.677, \"Energy\": 0.33, \"Loudness\": -11.198, \"Speechiness\": 0.149, \"Acousticness\": 0.474, \"Liveness\": 0.064, \"Tempo\": 68.985, \"Duration (ms)\": 298440.0, \"Valence\": 0.336, \"Chord\": \"D\"}, {\"Index\": 1490, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"No Regrets (feat. Don Toliver)\", \"Streams\": 9493884, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"1lO9CZo6eDrOy0S7khgryG\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 63.0, \"Danceability\": 0.756, \"Energy\": 0.747, \"Loudness\": -5.407, \"Speechiness\": 0.046, \"Acousticness\": 0.0048, \"Liveness\": 0.588, \"Tempo\": 134.935, \"Duration (ms)\": 200947.0, \"Valence\": 0.0687, \"Chord\": \"A\"}, {\"Index\": 1491, \"Highest Charting Position\": 71, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Complicated\", \"Streams\": 9443725, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"3WfSNAoj2D8C9noPSGZZFM\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.831, \"Energy\": 0.36, \"Loudness\": -8.073, \"Speechiness\": 0.052, \"Acousticness\": 0.136, \"Liveness\": 0.0703, \"Tempo\": 75.014, \"Duration (ms)\": 232212.0, \"Valence\": 0.601, \"Chord\": \"C\"}, {\"Index\": 1492, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Lock It Up (feat. Anderson .Paak)\", \"Streams\": 9328951, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"1qwMkkRiD5jqLeUUjfgblh\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.848, \"Energy\": 0.745, \"Loudness\": -3.052, \"Speechiness\": 0.221, \"Acousticness\": 0.0949, \"Liveness\": 0.0796, \"Tempo\": 137.024, \"Duration (ms)\": 170227.0, \"Valence\": 0.516, \"Chord\": \"F#/Gb\"}, {\"Index\": 1493, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Marsh\", \"Streams\": 9260007, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"34d7sGX6WUqq8f04e7CSNF\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.871, \"Energy\": 0.493, \"Loudness\": -6.356, \"Speechiness\": 0.205, \"Acousticness\": 0.0134, \"Liveness\": 0.385, \"Tempo\": 144.989, \"Duration (ms)\": 200573.0, \"Valence\": 0.0495, \"Chord\": \"C#/Db\"}, {\"Index\": 1494, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Stepdad\", \"Streams\": 9159901, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"3QVHSV8YKYq4L8tI5rnFgj\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 61.0, \"Danceability\": 0.779, \"Energy\": 0.805, \"Loudness\": -3.121, \"Speechiness\": 0.178, \"Acousticness\": 0.018, \"Liveness\": 0.321, \"Tempo\": 145.68, \"Duration (ms)\": 213413.0, \"Valence\": 0.557, \"Chord\": \"C#/Db\"}, {\"Index\": 1495, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Yah Yah (feat. Royce Da 5'9\\\", Black Thought, Q-Tip & Denaun)\", \"Streams\": 8695060, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5mZXWEH2eh8zMZGCxT5aW0\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.458, \"Energy\": 0.966, \"Loudness\": -2.107, \"Speechiness\": 0.384, \"Acousticness\": 0.14, \"Liveness\": 0.11, \"Tempo\": 183.586, \"Duration (ms)\": 286960.0, \"Valence\": 0.356, \"Chord\": \"C#/Db\"}, {\"Index\": 1496, \"Highest Charting Position\": 90, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Never Love Again\", \"Streams\": 8335790, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"40YbWniIEmqy6s58fYXLUh\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.747, \"Energy\": 0.899, \"Loudness\": -5.125, \"Speechiness\": 0.246, \"Acousticness\": 0.1, \"Liveness\": 0.486, \"Tempo\": 92.029, \"Duration (ms)\": 177547.0, \"Valence\": 0.581, \"Chord\": \"F\"}, {\"Index\": 1497, \"Highest Charting Position\": 91, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Woods\", \"Streams\": 8329349, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"3Qa944OTMZkg8DHjET8JQv\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.779, \"Energy\": 0.362, \"Loudness\": -10.847, \"Speechiness\": 0.0474, \"Acousticness\": 0.135, \"Liveness\": 0.111, \"Tempo\": 85.011, \"Duration (ms)\": 286387.0, \"Valence\": 0.46, \"Chord\": \"C\"}, {\"Index\": 1498, \"Highest Charting Position\": 94, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Farewell\", \"Streams\": 8277608, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"74gykWHknHDrg4eMdcmdRq\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 61.0, \"Danceability\": 0.89, \"Energy\": 0.664, \"Loudness\": -6.625, \"Speechiness\": 0.106, \"Acousticness\": 0.00487, \"Liveness\": 0.257, \"Tempo\": 93.007, \"Duration (ms)\": 247733.0, \"Valence\": 0.467, \"Chord\": \"E\"}, {\"Index\": 1499, \"Highest Charting Position\": 98, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Everybody\", \"Streams\": 8172098, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"1OuN92HcVG6NVpWbeESNB3\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.875, \"Energy\": 0.599, \"Loudness\": -9.077, \"Speechiness\": 0.138, \"Acousticness\": 0.0333, \"Liveness\": 0.113, \"Tempo\": 152.061, \"Duration (ms)\": 256507.0, \"Valence\": 0.112, \"Chord\": \"A\"}, {\"Index\": 1500, \"Highest Charting Position\": 100, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Alfred - Interlude\", \"Streams\": 8030151, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"4EmunTy7kNBYQivOa8F6b8\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 57.0, \"Danceability\": 0.429, \"Energy\": 0.231, \"Loudness\": -20.43, \"Speechiness\": 0.402, \"Acousticness\": 0.878, \"Liveness\": 0.279, \"Tempo\": 74.545, \"Duration (ms)\": 30133.0, \"Valence\": 0.914, \"Chord\": \"F\"}, {\"Index\": 1501, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Little Engine\", \"Streams\": 7913461, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"4qNWEOMyexn7b8Icyk29t9\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.769, \"Energy\": 0.811, \"Loudness\": -4.162, \"Speechiness\": 0.228, \"Acousticness\": 0.0234, \"Liveness\": 0.0451, \"Tempo\": 155.081, \"Duration (ms)\": 177293.0, \"Valence\": 0.76, \"Chord\": \"A#/Bb\"}, {\"Index\": 1502, \"Highest Charting Position\": 113, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"I Will (feat. KXNG Crooked, Royce Da 5'9\\\" & Joell Ortiz)\", \"Streams\": 7115414, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"3CJbxqRQ0JNCqboWDNUUeX\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.635, \"Energy\": 0.543, \"Loudness\": -5.941, \"Speechiness\": 0.067, \"Acousticness\": 0.0454, \"Liveness\": 0.272, \"Tempo\": 98.743, \"Duration (ms)\": 303000.0, \"Valence\": 0.036, \"Chord\": \"G#/Ab\"}, {\"Index\": 1503, \"Highest Charting Position\": 115, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Still Learning\", \"Streams\": 7050815, \"Artist\": \"Halsey\", \"Artist Followers\": 15663384.0, \"Song ID\": \"2Mfv5HaqnI18Q9JRv9hqnn\", \"Genre\": \"['dance pop', 'electropop', 'etherpop', 'indie poptimism', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 59.0, \"Danceability\": 0.708, \"Energy\": 0.661, \"Loudness\": -6.543, \"Speechiness\": 0.0546, \"Acousticness\": 0.0396, \"Liveness\": 0.113, \"Tempo\": 102.046, \"Duration (ms)\": 211784.0, \"Valence\": 0.317, \"Chord\": \"C\"}, {\"Index\": 1504, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Surf\", \"Streams\": 6960699, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"1kwnxJNVl7cwcU98RvMBaR\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 67.0, \"Danceability\": 0.828, \"Energy\": 0.182, \"Loudness\": -13.066, \"Speechiness\": 0.166, \"Acousticness\": 0.754, \"Liveness\": 0.15, \"Tempo\": 147.279, \"Duration (ms)\": 330507.0, \"Valence\": 0.231, \"Chord\": \"C#/Db\"}, {\"Index\": 1505, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"That's On Me\", \"Streams\": 6462701, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"0udOCZp7yk0Ml92C0k8H8D\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.583, \"Energy\": 0.499, \"Loudness\": -10.086, \"Speechiness\": 0.0261, \"Acousticness\": 0.591, \"Liveness\": 0.33, \"Tempo\": 155.199, \"Duration (ms)\": 217868.0, \"Valence\": 0.342, \"Chord\": \"A#/Bb\"}, {\"Index\": 1506, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Once A Day\", \"Streams\": 6159873, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"26G5nmIx7Yvq79bIIluyZV\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 61.0, \"Danceability\": 0.762, \"Energy\": 0.054, \"Loudness\": -16.735, \"Speechiness\": 0.0503, \"Acousticness\": 0.947, \"Liveness\": 0.124, \"Tempo\": 96.838, \"Duration (ms)\": 160267.0, \"Valence\": 0.339, \"Chord\": \"D\"}, {\"Index\": 1507, \"Highest Charting Position\": 155, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Big Drip\", \"Streams\": 6010373, \"Artist\": \"Ufo361, Future\", \"Artist Followers\": 1700759.0, \"Song ID\": \"7HZoWhGQaKg97OsqG7HLOS\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 48.0, \"Danceability\": 0.791, \"Energy\": 0.535, \"Loudness\": -6.753, \"Speechiness\": 0.311, \"Acousticness\": 0.0448, \"Liveness\": 0.129, \"Tempo\": 158.922, \"Duration (ms)\": 173785.0, \"Valence\": 0.443, \"Chord\": \"C\"}, {\"Index\": 1508, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Hands\", \"Streams\": 5934464, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"6CrnvqCxBKVWahSiQwOesM\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 58.0, \"Danceability\": 0.739, \"Energy\": 0.627, \"Loudness\": -8.608, \"Speechiness\": 0.171, \"Acousticness\": 0.0459, \"Liveness\": 0.159, \"Tempo\": 74.962, \"Duration (ms)\": 199981.0, \"Valence\": 0.542, \"Chord\": \"C\"}, {\"Index\": 1509, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Dans l'espace (feat. Heuss l'Enfoir\\u00e9)\", \"Streams\": 5678754, \"Artist\": \"Gambi\", \"Artist Followers\": 951798.0, \"Song ID\": \"2KAkkba3PaYFegfmYpUITv\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 59.0, \"Danceability\": 0.916, \"Energy\": 0.57, \"Loudness\": -6.278, \"Speechiness\": 0.18, \"Acousticness\": 0.0286, \"Liveness\": 0.0851, \"Tempo\": 110.05, \"Duration (ms)\": 169702.0, \"Valence\": 0.7, \"Chord\": \"C#/Db\"}, {\"Index\": 1510, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Blanche\", \"Streams\": 5656775, \"Artist\": \"Maes, Booba\", \"Artist Followers\": 1603670.0, \"Song ID\": \"5GyyPRvEwdI4wJSUbzxHQv\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2020-01-16\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 65.0, \"Danceability\": 0.776, \"Energy\": 0.713, \"Loudness\": -6.121, \"Speechiness\": 0.143, \"Acousticness\": 0.525, \"Liveness\": 0.306, \"Tempo\": 127.987, \"Duration (ms)\": 193453.0, \"Valence\": 0.551, \"Chord\": \"E\"}, {\"Index\": 1511, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Vulnerable\", \"Streams\": 7531094, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"11OwAR3GlBj9E35Cznf7Lj\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 55.0, \"Danceability\": 0.695, \"Energy\": 0.573, \"Loudness\": -8.882, \"Speechiness\": 0.167, \"Acousticness\": 0.132, \"Liveness\": 0.156, \"Tempo\": 100.031, \"Duration (ms)\": 192172.0, \"Valence\": 0.38, \"Chord\": \"A#/Bb\"}, {\"Index\": 1512, \"Highest Charting Position\": 90, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Dance Again\", \"Streams\": 7394604, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"5sK3o66yupTNIK6gWgzGjf\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 56.0, \"Danceability\": 0.784, \"Energy\": 0.552, \"Loudness\": -7.261, \"Speechiness\": 0.0871, \"Acousticness\": 0.0447, \"Liveness\": 0.192, \"Tempo\": 111.984, \"Duration (ms)\": 170498.0, \"Valence\": 0.465, \"Chord\": \"C#/Db\"}, {\"Index\": 1513, \"Highest Charting Position\": 107, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Ring\", \"Streams\": 6693229, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"11Ey4yJVeWEsA73KjACkVY\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 55.0, \"Danceability\": 0.873, \"Energy\": 0.51, \"Loudness\": -5.35, \"Speechiness\": 0.0661, \"Acousticness\": 0.565, \"Liveness\": 0.0738, \"Tempo\": 110.953, \"Duration (ms)\": 148776.0, \"Valence\": 0.871, \"Chord\": \"D#/Eb\"}, {\"Index\": 1514, \"Highest Charting Position\": 111, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Crowded Room (feat. 6LACK)\", \"Streams\": 6483001, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"2C0hTkdEoikhKzDCJl32QZ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 55.0, \"Danceability\": 0.724, \"Energy\": 0.415, \"Loudness\": -8.408, \"Speechiness\": 0.0518, \"Acousticness\": 0.764, \"Liveness\": 0.103, \"Tempo\": 89.999, \"Duration (ms)\": 186459.0, \"Valence\": 0.328, \"Chord\": \"G\"}, {\"Index\": 1515, \"Highest Charting Position\": 119, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"People You Know\", \"Streams\": 6255954, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"63mdJr3NMY3wReOkNE6c6W\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 54.0, \"Danceability\": 0.695, \"Energy\": 0.62, \"Loudness\": -8.082, \"Speechiness\": 0.0521, \"Acousticness\": 0.0881, \"Liveness\": 0.111, \"Tempo\": 150.032, \"Duration (ms)\": 194900.0, \"Valence\": 0.62, \"Chord\": \"G#/Ab\"}, {\"Index\": 1516, \"Highest Charting Position\": 83, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Up All Night\", \"Streams\": 5834918, \"Artist\": \"Khalid\", \"Artist Followers\": 14190858.0, \"Song ID\": \"1mpD5Q8IM32I4bF6eCpU74\", \"Genre\": \"['pop']\", \"Release Date\": \"2019-11-14\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 69.0, \"Danceability\": 0.665, \"Energy\": 0.712, \"Loudness\": -7.536, \"Speechiness\": 0.0527, \"Acousticness\": 0.00103, \"Liveness\": 0.102, \"Tempo\": 93.992, \"Duration (ms)\": 157220.0, \"Valence\": 0.669, \"Chord\": \"C#/Db\"}, {\"Index\": 1517, \"Highest Charting Position\": 111, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Nice To Meet Ya\", \"Streams\": 5730427, \"Artist\": \"Niall Horan\", \"Artist Followers\": 7564659.0, \"Song ID\": \"3cphb8kdsjElYR7r5icK3H\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.591, \"Energy\": 0.841, \"Loudness\": -4.351, \"Speechiness\": 0.0304, \"Acousticness\": 0.0119, \"Liveness\": 0.395, \"Tempo\": 109.034, \"Duration (ms)\": 158805.0, \"Valence\": 0.392, \"Chord\": \"E\"}, {\"Index\": 1518, \"Highest Charting Position\": 102, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Into the Unknown\", \"Streams\": 5705999, \"Artist\": \"Idina Menzel, AURORA\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3Z0oQ8r78OUaHvGPiDBR3W\", \"Genre\": \"[]\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.323, \"Energy\": 0.405, \"Loudness\": -8.533, \"Speechiness\": 0.0413, \"Acousticness\": 0.849, \"Liveness\": 0.138, \"Tempo\": 145.104, \"Duration (ms)\": 194848.0, \"Valence\": 0.274, \"Chord\": \"A#/Bb\"}, {\"Index\": 1519, \"Highest Charting Position\": 161, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Let Me Get Me\", \"Streams\": 5356671, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"0uFForNKQPvgSCnxlZIhQy\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 51.0, \"Danceability\": 0.826, \"Energy\": 0.571, \"Loudness\": -9.263, \"Speechiness\": 0.0426, \"Acousticness\": 0.249, \"Liveness\": 0.215, \"Tempo\": 121.06, \"Duration (ms)\": 189145.0, \"Valence\": 0.475, \"Chord\": \"D\"}, {\"Index\": 1520, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"A Sweeter Place (feat. Kid Cudi)\", \"Streams\": 5291134, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4bb94wZVF1cX66vQjNeJTX\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 52.0, \"Danceability\": 0.583, \"Energy\": 0.777, \"Loudness\": -6.991, \"Speechiness\": 0.185, \"Acousticness\": 0.109, \"Liveness\": 0.108, \"Tempo\": 190.054, \"Duration (ms)\": 263306.0, \"Valence\": 0.31, \"Chord\": \"A#/Bb\"}, {\"Index\": 1521, \"Highest Charting Position\": 131, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Stuck In A Dream (feat. Gunna)\", \"Streams\": 5258047, \"Artist\": \"Lil Mosey\", \"Artist Followers\": 3818503.0, \"Song ID\": \"7iHHxY2NLlJRAmlAmC4ahQ\", \"Genre\": \"['melodic rap', 'rap', 'rap conscient', 'trap', 'vapor trap']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.748, \"Energy\": 0.648, \"Loudness\": -6.445, \"Speechiness\": 0.0816, \"Acousticness\": 0.484, \"Liveness\": 0.126, \"Tempo\": 139.952, \"Duration (ms)\": 123560.0, \"Valence\": 0.726, \"Chord\": \"A#/Bb\"}, {\"Index\": 1522, \"Highest Charting Position\": 138, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Take What You Want (feat. Ozzy Osbourne & Travis Scott)\", \"Streams\": 5199618, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"7CZyCXKG6d5ALeq41sLzbw\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.499, \"Energy\": 0.8, \"Loudness\": -2.665, \"Speechiness\": 0.0502, \"Acousticness\": 0.0906, \"Liveness\": 0.147, \"Tempo\": 139.919, \"Duration (ms)\": 229573.0, \"Valence\": 0.272, \"Chord\": \"C#/Db\"}, {\"Index\": 1523, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Tip Toe (feat. A Boogie Wit da Hoodie)\", \"Streams\": 5150724, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6608815.0, \"Song ID\": \"6ztvsy3C6hPjVg9j4x1XKJ\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 63.0, \"Danceability\": 0.757, \"Energy\": 0.673, \"Loudness\": -8.513, \"Speechiness\": 0.141, \"Acousticness\": 0.095, \"Liveness\": 0.338, \"Tempo\": 92.958, \"Duration (ms)\": 185806.0, \"Valence\": 0.574, \"Chord\": \"C#/Db\"}, {\"Index\": 1524, \"Highest Charting Position\": 182, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Start Wit Me (feat. Gunna)\", \"Streams\": 5085706, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6608815.0, \"Song ID\": \"7A20WnLkjtZU2d7hIB6Ziu\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 68.0, \"Danceability\": 0.886, \"Energy\": 0.479, \"Loudness\": -8.054, \"Speechiness\": 0.334, \"Acousticness\": 0.077, \"Liveness\": 0.135, \"Tempo\": 130.029, \"Duration (ms)\": 158692.0, \"Valence\": 0.408, \"Chord\": \"E\"}, {\"Index\": 1525, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Diamonds (with Normani)\", \"Streams\": 4981484, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"0PQsrLxPbOBBwwmXCnGvcF\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 58.0, \"Danceability\": 0.785, \"Energy\": 0.753, \"Loudness\": -3.841, \"Speechiness\": 0.0873, \"Acousticness\": 0.188, \"Liveness\": 0.265, \"Tempo\": 94.012, \"Duration (ms)\": 199301.0, \"Valence\": 0.488, \"Chord\": \"C#/Db\"}, {\"Index\": 1526, \"Highest Charting Position\": 140, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Don't Call Me Up\", \"Streams\": 4931458, \"Artist\": \"Mabel\", \"Artist Followers\": 1374784.0, \"Song ID\": \"5WHTFyqSii0lmT9R21abT8\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2019-01-18\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.674, \"Energy\": 0.881, \"Loudness\": -2.853, \"Speechiness\": 0.147, \"Acousticness\": 0.296, \"Liveness\": 0.0793, \"Tempo\": 98.994, \"Duration (ms)\": 178480.0, \"Valence\": 0.234, \"Chord\": \"A\"}, {\"Index\": 1527, \"Highest Charting Position\": 177, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Death\", \"Streams\": 4929396, \"Artist\": \"Trippie Redd, DaBaby\", \"Artist Followers\": 6434201.0, \"Song ID\": \"3Kd6Wp3lG5HXMB2dlvuy7y\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 65.0, \"Danceability\": 0.802, \"Energy\": 0.82, \"Loudness\": -5.969, \"Speechiness\": 0.146, \"Acousticness\": 0.0579, \"Liveness\": 0.149, \"Tempo\": 164.005, \"Duration (ms)\": 172196.0, \"Valence\": 0.613, \"Chord\": \"A#/Bb\"}, {\"Index\": 1528, \"Highest Charting Position\": 133, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Calma - Remix\", \"Streams\": 4879713, \"Artist\": \"Pedro Cap\\u00f3, Farruko\", \"Artist Followers\": 1353049.0, \"Song ID\": \"5iwz1NiezX7WWjnCgY5TH4\", \"Genre\": \"['latin', 'latin pop', 'puerto rican pop']\", \"Release Date\": \"2018-10-05\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.826, \"Energy\": 0.773, \"Loudness\": -4.218, \"Speechiness\": 0.0524, \"Acousticness\": 0.323, \"Liveness\": 0.143, \"Tempo\": 126.899, \"Duration (ms)\": 238200.0, \"Valence\": 0.761, \"Chord\": \"B\"}, {\"Index\": 1529, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Cut You Off\", \"Streams\": 4874380, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4OtHGdb0KqEbaWb6edUnR9\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 51.0, \"Danceability\": 0.855, \"Energy\": 0.294, \"Loudness\": -8.676, \"Speechiness\": 0.286, \"Acousticness\": 0.3, \"Liveness\": 0.091, \"Tempo\": 139.745, \"Duration (ms)\": 182017.0, \"Valence\": 0.842, \"Chord\": \"F\"}, {\"Index\": 1530, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Kinda Crazy\", \"Streams\": 4866777, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"59iGOjPSOcPLGl3vqEStUp\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 49.0, \"Danceability\": 0.691, \"Energy\": 0.446, \"Loudness\": -10.304, \"Speechiness\": 0.0472, \"Acousticness\": 0.484, \"Liveness\": 0.183, \"Tempo\": 93.03, \"Duration (ms)\": 212436.0, \"Valence\": 0.534, \"Chord\": \"B\"}, {\"Index\": 1531, \"Highest Charting Position\": 179, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"2002\", \"Streams\": 4831644, \"Artist\": \"Anne-Marie\", \"Artist Followers\": 8153871.0, \"Song ID\": \"2BgEsaKNfHUdlh97KmvFyo\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2018-04-27\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.697, \"Energy\": 0.683, \"Loudness\": -2.881, \"Speechiness\": 0.117, \"Acousticness\": 0.0372, \"Liveness\": 0.137, \"Tempo\": 96.133, \"Duration (ms)\": 186987.0, \"Valence\": 0.603, \"Chord\": \"C#/Db\"}, {\"Index\": 1532, \"Highest Charting Position\": 153, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Taki Taki (feat. Selena Gomez, Ozuna & Cardi B)\", \"Streams\": 4816702, \"Artist\": \"DJ Snake\", \"Artist Followers\": 7408249.0, \"Song ID\": \"0KoiMHhqKLoL4xM54rcWYY\", \"Genre\": \"['dance pop', 'edm', 'electronic trap', 'pop', 'pop dance']\", \"Release Date\": \"2019-07-25\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.842, \"Energy\": 0.801, \"Loudness\": -4.167, \"Speechiness\": 0.228, \"Acousticness\": 0.157, \"Liveness\": 0.0642, \"Tempo\": 95.881, \"Duration (ms)\": 212500.0, \"Valence\": 0.617, \"Chord\": \"G#/Ab\"}, {\"Index\": 1533, \"Highest Charting Position\": 107, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Family\", \"Streams\": 6145132, \"Artist\": \"The Chainsmokers, Kygo\", \"Artist Followers\": 18195884.0, \"Song ID\": \"3TKpJrY9q49Mj1JOsM9zGL\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.584, \"Energy\": 0.607, \"Loudness\": -6.605, \"Speechiness\": 0.0356, \"Acousticness\": 0.426, \"Liveness\": 0.101, \"Tempo\": 117.817, \"Duration (ms)\": 194827.0, \"Valence\": 0.374, \"Chord\": \"B\"}, {\"Index\": 1534, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"GANG GANG\", \"Streams\": 5898484, \"Artist\": \"JACKBOYS, Sheck Wes\", \"Artist Followers\": 437907.0, \"Song ID\": \"6uJONCdr2rC65BNmCnTBWK\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 69.0, \"Danceability\": 0.859, \"Energy\": 0.6, \"Loudness\": -4.63, \"Speechiness\": 0.301, \"Acousticness\": 0.071, \"Liveness\": 0.353, \"Tempo\": 123.017, \"Duration (ms)\": 244761.0, \"Valence\": 0.568, \"Chord\": \"G\"}, {\"Index\": 1535, \"Highest Charting Position\": 39, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Had Enough (feat. Quavo & Offset)\", \"Streams\": 5748010, \"Artist\": \"Don Toliver\", \"Artist Followers\": 437907.0, \"Song ID\": \"7LGWmZaoS7jZJ5tEi9EcDi\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.75, \"Energy\": 0.789, \"Loudness\": -4.578, \"Speechiness\": 0.108, \"Acousticness\": 0.253, \"Liveness\": 0.129, \"Tempo\": 147.957, \"Duration (ms)\": 157133.0, \"Valence\": 0.673, \"Chord\": \"D\"}, {\"Index\": 1536, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"WHAT TO DO? (feat. Don Toliver)\", \"Streams\": 5586351, \"Artist\": \"JACKBOYS, Travis Scott\", \"Artist Followers\": 437907.0, \"Song ID\": \"4AO1XhrgJczQ9bNVxdfKQe\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.643, \"Energy\": 0.594, \"Loudness\": -5.191, \"Speechiness\": 0.0312, \"Acousticness\": 0.0695, \"Liveness\": 0.115, \"Tempo\": 118.037, \"Duration (ms)\": 250142.0, \"Valence\": 0.195, \"Chord\": \"A\"}, {\"Index\": 1537, \"Highest Charting Position\": 125, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Writing on the Wall (feat. Post Malone, Cardi B & Rvssian)\", \"Streams\": 5229616, \"Artist\": \"French Montana\", \"Artist Followers\": 4039037.0, \"Song ID\": \"7x9nXsowok1JszkVztI5NI\", \"Genre\": \"['gangster rap', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 59.0, \"Danceability\": 0.773, \"Energy\": 0.836, \"Loudness\": -2.326, \"Speechiness\": 0.153, \"Acousticness\": 0.283, \"Liveness\": 0.0828, \"Tempo\": 112.01, \"Duration (ms)\": 201271.0, \"Valence\": 0.497, \"Chord\": \"A\"}, {\"Index\": 1538, \"Highest Charting Position\": 169, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"VALENTINO\", \"Streams\": 4935492, \"Artist\": \"24kGoldn\", \"Artist Followers\": 1276406.0, \"Song ID\": \"6piAUJJQFD8oHDUr0b7l7q\", \"Genre\": \"['cali rap']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.746, \"Energy\": 0.717, \"Loudness\": -4.841, \"Speechiness\": 0.179, \"Acousticness\": 0.199, \"Liveness\": 0.132, \"Tempo\": 150.964, \"Duration (ms)\": 179133.0, \"Valence\": 0.523, \"Chord\": \"A\"}, {\"Index\": 1539, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"fuck, i'm lonely (with Anne-Marie) - from \\u201c13 Reasons Why: Season 3\\u201d\", \"Streams\": 4856458, \"Artist\": \"Lauv\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-01-03--2020-01-10\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 1540, \"Highest Charting Position\": 150, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Roller\", \"Streams\": 4732292, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"6hw1Sy9wZ8UCxYGdpKrU6M\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2019-10-25\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.941, \"Energy\": 0.758, \"Loudness\": -6.47, \"Speechiness\": 0.17, \"Acousticness\": 0.0256, \"Liveness\": 0.193, \"Tempo\": 128.017, \"Duration (ms)\": 157093.0, \"Valence\": 0.683, \"Chord\": \"A#/Bb\"}, {\"Index\": 1541, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Never Really Over\", \"Streams\": 4679948, \"Artist\": \"Katy Perry\", \"Artist Followers\": 18936929.0, \"Song ID\": \"5PYQUBXc7NYeI1obMKSJK0\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-05-31\", \"Weeks Charted\": \"2020-01-03--2020-01-10\", \"Popularity\": 74.0, \"Danceability\": 0.77, \"Energy\": 0.882, \"Loudness\": -4.792, \"Speechiness\": 0.0602, \"Acousticness\": 0.194, \"Liveness\": 0.316, \"Tempo\": 99.991, \"Duration (ms)\": 223523.0, \"Valence\": 0.385, \"Chord\": \"G#/Ab\"}, {\"Index\": 1542, \"Highest Charting Position\": 145, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"One Kiss (with Dua Lipa)\", \"Streams\": 4594157, \"Artist\": \"Calvin Harris\", \"Artist Followers\": 21946934.0, \"Song ID\": \"7ef4DlsgrMEH11cDZd32M6\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'house', 'pop', 'progressive house', 'uk dance']\", \"Release Date\": \"2018-04-06\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.791, \"Energy\": 0.862, \"Loudness\": -3.24, \"Speechiness\": 0.11, \"Acousticness\": 0.037, \"Liveness\": 0.0814, \"Tempo\": 123.994, \"Duration (ms)\": 214847.0, \"Valence\": 0.592, \"Chord\": \"A\"}, {\"Index\": 1543, \"Highest Charting Position\": 192, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Fantas\\u00eda\", \"Streams\": 4543012, \"Artist\": \"Ozuna\", \"Artist Followers\": 29238936.0, \"Song ID\": \"40rXWke6SnXiGkSmaT8ZUr\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-29\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 59.0, \"Danceability\": 0.695, \"Energy\": 0.719, \"Loudness\": -5.938, \"Speechiness\": 0.0903, \"Acousticness\": 0.227, \"Liveness\": 0.0884, \"Tempo\": 180.074, \"Duration (ms)\": 175187.0, \"Valence\": 0.781, \"Chord\": \"D\"}, {\"Index\": 1544, \"Highest Charting Position\": 59, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Trampoline\", \"Streams\": 8896030, \"Artist\": \"SHAED, ZAYN\", \"Artist Followers\": 139434.0, \"Song ID\": \"1iQDltZqI7BXnHrFy4Qo1k\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-09-26\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.619, \"Energy\": 0.459, \"Loudness\": -5.782, \"Speechiness\": 0.0334, \"Acousticness\": 0.56, \"Liveness\": 0.137, \"Tempo\": 126.803, \"Duration (ms)\": 184280.0, \"Valence\": 0.498, \"Chord\": \"G\"}, {\"Index\": 1545, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"GATTI\", \"Streams\": 7685470, \"Artist\": \"JACKBOYS, Pop Smoke, Travis Scott\", \"Artist Followers\": 437907.0, \"Song ID\": \"40mjsnRjCpycdUw3xhS20g\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.594, \"Energy\": 0.676, \"Loudness\": -5.808, \"Speechiness\": 0.344, \"Acousticness\": 0.135, \"Liveness\": 0.163, \"Tempo\": 143.477, \"Duration (ms)\": 181145.0, \"Valence\": 0.472, \"Chord\": \"D\"}, {\"Index\": 1546, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Candy\", \"Streams\": 5632102, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"1VJwtWR6z7SpZRwipI12be\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2018-03-30\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.689, \"Energy\": 0.516, \"Loudness\": -5.857, \"Speechiness\": 0.0444, \"Acousticness\": 0.513, \"Liveness\": 0.163, \"Tempo\": 124.876, \"Duration (ms)\": 190920.0, \"Valence\": 0.209, \"Chord\": \"G#/Ab\"}, {\"Index\": 1547, \"Highest Charting Position\": 143, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"JACKBOYS\", \"Streams\": 5363493, \"Artist\": \"JACKBOYS\", \"Artist Followers\": 437907.0, \"Song ID\": \"62zKJrpbLxz6InR3tGyr7o\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 56.0, \"Danceability\": 0.413, \"Energy\": 0.13, \"Loudness\": -25.166, \"Speechiness\": 0.0336, \"Acousticness\": 0.9, \"Liveness\": 0.111, \"Tempo\": 123.342, \"Duration (ms)\": 46837.0, \"Valence\": 0.0676, \"Chord\": \"C\"}, {\"Index\": 1548, \"Highest Charting Position\": 156, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Combatchy (feat. MC Rebecca)\", \"Streams\": 5149797, \"Artist\": \"Anitta, Lexa, Lu\\u00edsa Sonza\", \"Artist Followers\": 10741972.0, \"Song ID\": \"2bPtwnrpFNEe8N7Q85kLHw\", \"Genre\": \"['funk carioca', 'funk pop', 'pagode baiano', 'pop nacional']\", \"Release Date\": \"2019-11-20\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 64.0, \"Danceability\": 0.826, \"Energy\": 0.73, \"Loudness\": -3.032, \"Speechiness\": 0.0809, \"Acousticness\": 0.383, \"Liveness\": 0.0197, \"Tempo\": 150.134, \"Duration (ms)\": 157600.0, \"Valence\": 0.605, \"Chord\": \"C#/Db\"}, {\"Index\": 1549, \"Highest Charting Position\": 178, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Old Town Road\", \"Streams\": 4852004, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5488666.0, \"Song ID\": \"2YpeDb67231RjR0MgVLzsG\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.878, \"Energy\": 0.619, \"Loudness\": -5.56, \"Speechiness\": 0.102, \"Acousticness\": 0.0533, \"Liveness\": 0.113, \"Tempo\": 136.041, \"Duration (ms)\": 157067.0, \"Valence\": 0.639, \"Chord\": \"F#/Gb\"}, {\"Index\": 1550, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Let Me Know (I Wonder Why Freestyle)\", \"Streams\": 4701532, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"3wwo0bJvDSorOpNfzEkfXx\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2019-12-07\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.635, \"Energy\": 0.537, \"Loudness\": -7.895, \"Speechiness\": 0.0832, \"Acousticness\": 0.172, \"Liveness\": 0.418, \"Tempo\": 125.028, \"Duration (ms)\": 215381.0, \"Valence\": 0.383, \"Chord\": \"G\"}, {\"Index\": 1551, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Ne reviens pas\", \"Streams\": 4676857, \"Artist\": \"Gradur, Heuss L'enfoir\\u00e9\", \"Artist Followers\": 1390813.0, \"Song ID\": \"4TnFANpjVwVKWzkxNzIyFH\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2019-11-29\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 62.0, \"Danceability\": 0.932, \"Energy\": 0.778, \"Loudness\": -3.384, \"Speechiness\": 0.0638, \"Acousticness\": 0.212, \"Liveness\": 0.168, \"Tempo\": 124.996, \"Duration (ms)\": 188613.0, \"Valence\": 0.933, \"Chord\": \"A#/Bb\"}, {\"Index\": 1552, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"New Rules\", \"Streams\": 4630675, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"2ekn2ttSfGqwhhate0LSR0\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2017-06-02\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.762, \"Energy\": 0.7, \"Loudness\": -6.021, \"Speechiness\": 0.0694, \"Acousticness\": 0.00261, \"Liveness\": 0.153, \"Tempo\": 116.073, \"Duration (ms)\": 209320.0, \"Valence\": 0.608, \"Chord\": \"A\"}, {\"Index\": 1553, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Cheirosa - Ao Vivo\", \"Streams\": 4623030, \"Artist\": \"Jorge & Mateus\", \"Artist Followers\": 15019109.0, \"Song ID\": \"2PWjKmjyTZeDpmOUa3a5da\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2019-10-11\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.528, \"Energy\": 0.87, \"Loudness\": -3.123, \"Speechiness\": 0.0851, \"Acousticness\": 0.24, \"Liveness\": 0.333, \"Tempo\": 152.37, \"Duration (ms)\": 181930.0, \"Valence\": 0.714, \"Chord\": \"B\"}, {\"Index\": 1554, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Havana (feat. Young Thug)\", \"Streams\": 4620876, \"Artist\": \"Camila Cabello\", \"Artist Followers\": 22698747.0, \"Song ID\": \"1rfofaqEpACxVEHIZBJe6W\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-01-12\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.765, \"Energy\": 0.523, \"Loudness\": -4.333, \"Speechiness\": 0.03, \"Acousticness\": 0.184, \"Liveness\": 0.132, \"Tempo\": 104.988, \"Duration (ms)\": 217307.0, \"Valence\": 0.394, \"Chord\": \"D\"}, {\"Index\": 1555, \"Highest Charting Position\": 198, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Surtada - Remix Brega Funk\", \"Streams\": 4607385, \"Artist\": \"Dad\\u00e1 Bolad\\u00e3o, Tati Zaqui, OIK\", \"Artist Followers\": 208630.0, \"Song ID\": \"5F8ffc8KWKNawllr5WsW0r\", \"Genre\": \"['brega funk', 'funk carioca']\", \"Release Date\": \"2019-09-25\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 60.0, \"Danceability\": 0.832, \"Energy\": 0.55, \"Loudness\": -7.026, \"Speechiness\": 0.0587, \"Acousticness\": 0.249, \"Liveness\": 0.182, \"Tempo\": 154.064, \"Duration (ms)\": 152784.0, \"Valence\": 0.881, \"Chord\": \"F\"}, {\"Index\": 1556, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lover (Remix) [feat. Shawn Mendes]\", \"Streams\": 4595450, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3i9UVldZOE0aD0JnyfAZZ0\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-11-13\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.448, \"Energy\": 0.603, \"Loudness\": -7.176, \"Speechiness\": 0.064, \"Acousticness\": 0.433, \"Liveness\": 0.0862, \"Tempo\": 205.272, \"Duration (ms)\": 221307.0, \"Valence\": 0.422, \"Chord\": \"G\"}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 21,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "alt.Chart(df).mark_circle().encode(\n",
    "    x = \"Energy\",\n",
    "    y = \"Loudness\",\n",
    "    color = alt.Color('Acousticness', scale=alt.Scale(scheme='turbo',reverse=True)),\n",
    "    tooltip = [\"Artist\",\"Song Name\",\"Release Date\",\"Chord\"]\n",
    ").properties(\n",
    "    width = 720,\n",
    "    height = 450,\n",
    "    title=\"Spotify dataset from Kaggle\"\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "d7e99e15",
   "metadata": {},
   "source": [
    "```{admonition} Caution\n",
    ":class: warning\n",
    "The rest of this notebook can be skipped on a first reading.  We give some more advanced examples.\n",
    "```"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "05f5e9dc",
   "metadata": {},
   "source": [
    "### Histogram\n",
    "Here is an example of how to make a histogram using Altair.  The heights of the bars indicate how many total entries there are in that category.  The `count()` entry is not the name of a column.  Instead it is a special Altair function to count how often that entry occurs."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 22,
   "id": "a88a3a2c",
   "metadata": {
    "tags": [
     "output_scroll"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-2020284f9c37486385683df6e2b7986d\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-2020284f9c37486385683df6e2b7986d\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-2020284f9c37486385683df6e2b7986d\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-67c9fb159873386c9c7303ca2ad81ad2\"}, \"mark\": \"bar\", \"encoding\": {\"x\": {\"type\": \"nominal\", \"field\": \"Artist\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"count\"}}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-67c9fb159873386c9c7303ca2ad81ad2\": [{\"Index\": 1, \"Highest Charting Position\": 1, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Beggin'\", \"Streams\": 48633449, \"Artist\": \"M\\u00e5neskin\", \"Artist Followers\": 3377762.0, \"Song ID\": \"3Wrjm47oTz2sjIgck11l5e\", \"Genre\": \"['indie rock italiano', 'italian pop']\", \"Release Date\": \"2017-12-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 100.0, \"Danceability\": 0.714, \"Energy\": 0.8, \"Loudness\": -4.808, \"Speechiness\": 0.0504, \"Acousticness\": 0.127, \"Liveness\": 0.359, \"Tempo\": 134.002, \"Duration (ms)\": 211560.0, \"Valence\": 0.589, \"Chord\": \"B\"}, {\"Index\": 2, \"Highest Charting Position\": 2, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"STAY (with Justin Bieber)\", \"Streams\": 47248719, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2230022.0, \"Song ID\": \"5HCyWlXZPP0y6Gqq8TgA20\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 99.0, \"Danceability\": 0.591, \"Energy\": 0.764, \"Loudness\": -5.484, \"Speechiness\": 0.0483, \"Acousticness\": 0.0383, \"Liveness\": 0.103, \"Tempo\": 169.928, \"Duration (ms)\": 141806.0, \"Valence\": 0.478, \"Chord\": \"C#/Db\"}, {\"Index\": 3, \"Highest Charting Position\": 1, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"good 4 u\", \"Streams\": 40162559, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"4ZtFanR9U6ndgddUvNcjcG\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 99.0, \"Danceability\": 0.563, \"Energy\": 0.664, \"Loudness\": -5.044, \"Speechiness\": 0.154, \"Acousticness\": 0.335, \"Liveness\": 0.0849, \"Tempo\": 166.928, \"Duration (ms)\": 178147.0, \"Valence\": 0.688, \"Chord\": \"A\"}, {\"Index\": 4, \"Highest Charting Position\": 3, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Bad Habits\", \"Streams\": 37799456, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83293380.0, \"Song ID\": \"6PQ88X9TkUIAUIZJHW2upE\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 98.0, \"Danceability\": 0.808, \"Energy\": 0.897, \"Loudness\": -3.712, \"Speechiness\": 0.0348, \"Acousticness\": 0.0469, \"Liveness\": 0.364, \"Tempo\": 126.026, \"Duration (ms)\": 231041.0, \"Valence\": 0.591, \"Chord\": \"B\"}, {\"Index\": 5, \"Highest Charting Position\": 5, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"INDUSTRY BABY (feat. Jack Harlow)\", \"Streams\": 33948454, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5473565.0, \"Song ID\": \"27NovPIUIRrOZoCHxABJwK\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2021-07-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 96.0, \"Danceability\": 0.736, \"Energy\": 0.704, \"Loudness\": -7.409, \"Speechiness\": 0.0615, \"Acousticness\": 0.0203, \"Liveness\": 0.0501, \"Tempo\": 149.995, \"Duration (ms)\": 212000.0, \"Valence\": 0.894, \"Chord\": \"D#/Eb\"}, {\"Index\": 6, \"Highest Charting Position\": 1, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"MONTERO (Call Me By Your Name)\", \"Streams\": 30071134, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5473565.0, \"Song ID\": \"67BtfxlNbhBmCDR2L2l8qd\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2021-03-31\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 97.0, \"Danceability\": 0.61, \"Energy\": 0.508, \"Loudness\": -6.682, \"Speechiness\": 0.152, \"Acousticness\": 0.297, \"Liveness\": 0.384, \"Tempo\": 178.818, \"Duration (ms)\": 137876.0, \"Valence\": 0.758, \"Chord\": \"G#/Ab\"}, {\"Index\": 7, \"Highest Charting Position\": 3, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Kiss Me More (feat. SZA)\", \"Streams\": 29356736, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"748mdHapucXQri7IAO8yFK\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 94.0, \"Danceability\": 0.762, \"Energy\": 0.701, \"Loudness\": -3.541, \"Speechiness\": 0.0286, \"Acousticness\": 0.235, \"Liveness\": 0.123, \"Tempo\": 110.968, \"Duration (ms)\": 208867.0, \"Valence\": 0.742, \"Chord\": \"G#/Ab\"}, {\"Index\": 8, \"Highest Charting Position\": 2, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Todo De Ti\", \"Streams\": 26951613, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6080597.0, \"Song ID\": \"4fSIb4hdOQ151TILNsSEaF\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2021-05-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 95.0, \"Danceability\": 0.78, \"Energy\": 0.718, \"Loudness\": -3.605, \"Speechiness\": 0.0506, \"Acousticness\": 0.31, \"Liveness\": 0.0932, \"Tempo\": 127.949, \"Duration (ms)\": 199604.0, \"Valence\": 0.342, \"Chord\": \"D#/Eb\"}, {\"Index\": 9, \"Highest Charting Position\": 3, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Yonaguni\", \"Streams\": 25030128, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36142273.0, \"Song ID\": \"2JPLbjOn0wPCngEot2STUS\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 96.0, \"Danceability\": 0.644, \"Energy\": 0.648, \"Loudness\": -4.601, \"Speechiness\": 0.118, \"Acousticness\": 0.276, \"Liveness\": 0.135, \"Tempo\": 179.951, \"Duration (ms)\": 206710.0, \"Valence\": 0.44, \"Chord\": \"C#/Db\"}, {\"Index\": 10, \"Highest Charting Position\": 8, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"I WANNA BE YOUR SLAVE\", \"Streams\": 24551591, \"Artist\": \"M\\u00e5neskin\", \"Artist Followers\": 3377762.0, \"Song ID\": \"4pt5fDVTg5GhEvEtlz9dKk\", \"Genre\": \"['indie rock italiano', 'italian pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 95.0, \"Danceability\": 0.75, \"Energy\": 0.608, \"Loudness\": -4.008, \"Speechiness\": 0.0387, \"Acousticness\": 0.00165, \"Liveness\": 0.178, \"Tempo\": 132.507, \"Duration (ms)\": 173347.0, \"Valence\": 0.958, \"Chord\": \"C#/Db\"}, {\"Index\": 11, \"Highest Charting Position\": 4, \"Number of Times Charted\": 43, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Levitating (feat. DaBaby)\", \"Streams\": 23518010, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"463CkQjx2Zk1yXoBuierM9\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-10-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 89.0, \"Danceability\": 0.702, \"Energy\": 0.825, \"Loudness\": -3.787, \"Speechiness\": 0.0601, \"Acousticness\": 0.00883, \"Liveness\": 0.0674, \"Tempo\": 102.977, \"Duration (ms)\": 203064.0, \"Valence\": 0.915, \"Chord\": \"F#/Gb\"}, {\"Index\": 12, \"Highest Charting Position\": 9, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Qu\\u00e9 M\\u00e1s Pues?\", \"Streams\": 22405111, \"Artist\": \"J Balvin, Maria Becerra\", \"Artist Followers\": 29051363.0, \"Song ID\": \"6hf0RpxTbOprT5nnwzkk8e\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\", \"Popularity\": 95.0, \"Danceability\": 0.891, \"Energy\": 0.819, \"Loudness\": -3.964, \"Speechiness\": 0.106, \"Acousticness\": 0.0261, \"Liveness\": 0.173, \"Tempo\": 101.968, \"Duration (ms)\": 217773.0, \"Valence\": 0.768, \"Chord\": \"G#/Ab\"}, {\"Index\": 13, \"Highest Charting Position\": 5, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Permission to Dance\", \"Streams\": 22062812, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"0LThjFY2iTtNdd4wviwVV2\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 95.0, \"Danceability\": 0.702, \"Energy\": 0.741, \"Loudness\": -5.33, \"Speechiness\": 0.0427, \"Acousticness\": 0.00544, \"Liveness\": 0.337, \"Tempo\": 124.925, \"Duration (ms)\": 187585.0, \"Valence\": 0.646, \"Chord\": \"A\"}, {\"Index\": 14, \"Highest Charting Position\": 1, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Peaches (feat. Daniel Caesar & Giveon)\", \"Streams\": 20294457, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48504126.0, \"Song ID\": \"4iJyoBOLtHqaGxP12qzhQI\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 94.0, \"Danceability\": 0.677, \"Energy\": 0.696, \"Loudness\": -6.181, \"Speechiness\": 0.119, \"Acousticness\": 0.321, \"Liveness\": 0.42, \"Tempo\": 90.03, \"Duration (ms)\": 198082.0, \"Valence\": 0.464, \"Chord\": \"C\"}, {\"Index\": 15, \"Highest Charting Position\": 2, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Butter\", \"Streams\": 19985713, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"2bgTY4UwhfBYhGT4HUYStN\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 95.0, \"Danceability\": 0.759, \"Energy\": 0.459, \"Loudness\": -5.187, \"Speechiness\": 0.0948, \"Acousticness\": 0.00323, \"Liveness\": 0.0906, \"Tempo\": 109.997, \"Duration (ms)\": 164442.0, \"Valence\": 0.695, \"Chord\": \"G#/Ab\"}, {\"Index\": 16, \"Highest Charting Position\": 7, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"traitor\", \"Streams\": 19480679, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"5CZ40GBx1sQ9agT82CLQCT\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 94.0, \"Danceability\": 0.38, \"Energy\": 0.339, \"Loudness\": -7.885, \"Speechiness\": 0.0338, \"Acousticness\": 0.691, \"Liveness\": 0.12, \"Tempo\": 100.607, \"Duration (ms)\": 229227.0, \"Valence\": 0.0849, \"Chord\": \"D#/Eb\"}, {\"Index\": 17, \"Highest Charting Position\": 3, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"deja vu\", \"Streams\": 18571755, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"6HU7h9RYOaPRFeh0R3UeAr\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 93.0, \"Danceability\": 0.442, \"Energy\": 0.612, \"Loudness\": -7.222, \"Speechiness\": 0.112, \"Acousticness\": 0.584, \"Liveness\": 0.37, \"Tempo\": 180.917, \"Duration (ms)\": 215507.0, \"Valence\": 0.178, \"Chord\": \"D\"}, {\"Index\": 18, \"Highest Charting Position\": 5, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Save Your Tears (with Ariana Grande) (Remix)\", \"Streams\": 18053141, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"37BZB0z9T8Xu7U3e65qxFy\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 94.0, \"Danceability\": 0.65, \"Energy\": 0.825, \"Loudness\": -4.645, \"Speechiness\": 0.0325, \"Acousticness\": 0.0215, \"Liveness\": 0.0936, \"Tempo\": 118.091, \"Duration (ms)\": 191014.0, \"Valence\": 0.593, \"Chord\": \"C\"}, {\"Index\": 19, \"Highest Charting Position\": 14, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"AM Remix\", \"Streams\": 17617965, \"Artist\": \"Nio Garcia, J Balvin, Bad Bunny\", \"Artist Followers\": 2123734.0, \"Song ID\": \"05bfbizlM5AX6Mf1RRyMho\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-24\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 93.0, \"Danceability\": 0.743, \"Energy\": 0.655, \"Loudness\": -5.015, \"Speechiness\": 0.159, \"Acousticness\": 0.114, \"Liveness\": 0.0764, \"Tempo\": 172.031, \"Duration (ms)\": 261335.0, \"Valence\": 0.785, \"Chord\": \"F#/Gb\"}, {\"Index\": 20, \"Highest Charting Position\": 20, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Need To Know\", \"Streams\": 16908917, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"3Vi5XqYrmQgOYBajMWSvCi\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 90.0, \"Danceability\": 0.664, \"Energy\": 0.609, \"Loudness\": -6.509, \"Speechiness\": 0.0707, \"Acousticness\": 0.304, \"Liveness\": 0.0926, \"Tempo\": 130.041, \"Duration (ms)\": 210560.0, \"Valence\": 0.194, \"Chord\": \"C#/Db\"}, {\"Index\": 21, \"Highest Charting Position\": 19, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Volando - Remix\", \"Streams\": 16606925, \"Artist\": \"Mora, Bad Bunny, Sech\", \"Artist Followers\": 151486.0, \"Song ID\": \"0G2zPzWqVjR68iNPmx2TBe\", \"Genre\": \"['reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 91.0, \"Danceability\": 0.659, \"Energy\": 0.688, \"Loudness\": -4.649, \"Speechiness\": 0.0673, \"Acousticness\": 0.207, \"Liveness\": 0.113, \"Tempo\": 153.979, \"Duration (ms)\": 273474.0, \"Valence\": 0.632, \"Chord\": \"F#/Gb\"}, {\"Index\": 22, \"Highest Charting Position\": 22, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Ain't Shit\", \"Streams\": 16126897, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"5lAnYvAIkSDNXqfo7DyFUm\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 90.0, \"Danceability\": 0.855, \"Energy\": 0.488, \"Loudness\": -4.601, \"Speechiness\": 0.208, \"Acousticness\": 0.506, \"Liveness\": 0.347, \"Tempo\": 124.097, \"Duration (ms)\": 174253.0, \"Valence\": 0.619, \"Chord\": \"D#/Eb\"}, {\"Index\": 23, \"Highest Charting Position\": 1, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"drivers license\", \"Streams\": 15684978, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"5wANPM4fQCJwkGd4rN57mH\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 92.0, \"Danceability\": 0.561, \"Energy\": 0.431, \"Loudness\": -8.81, \"Speechiness\": 0.0578, \"Acousticness\": 0.768, \"Liveness\": 0.106, \"Tempo\": 143.875, \"Duration (ms)\": 242013.0, \"Valence\": 0.137, \"Chord\": \"A#/Bb\"}, {\"Index\": 24, \"Highest Charting Position\": 24, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Heat Waves\", \"Streams\": 15089184, \"Artist\": \"Glass Animals\", \"Artist Followers\": 1890510.0, \"Song ID\": \"3USxtqRwSYz57Ewm6wWRMp\", \"Genre\": \"['gauze pop', 'indietronica', 'shiver pop']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 85.0, \"Danceability\": 0.761, \"Energy\": 0.525, \"Loudness\": -6.9, \"Speechiness\": 0.0944, \"Acousticness\": 0.44, \"Liveness\": 0.0921, \"Tempo\": 80.87, \"Duration (ms)\": 238805.0, \"Valence\": 0.531, \"Chord\": \"B\"}, {\"Index\": 25, \"Highest Charting Position\": 1, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Blinding Lights\", \"Streams\": 15011809, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"0VjIjW4GlUZAMYd2vXMi3b\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 92.0, \"Danceability\": 0.514, \"Energy\": 0.73, \"Loudness\": -5.934, \"Speechiness\": 0.0598, \"Acousticness\": 0.00146, \"Liveness\": 0.0897, \"Tempo\": 171.005, \"Duration (ms)\": 200040.0, \"Valence\": 0.334, \"Chord\": \"C#/Db\"}, {\"Index\": 26, \"Highest Charting Position\": 12, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"happier\", \"Streams\": 14849078, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"2tGvwE8GcFKwNdAXMnlbfl\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 92.0, \"Danceability\": 0.395, \"Energy\": 0.443, \"Loudness\": -9.72, \"Speechiness\": 0.133, \"Acousticness\": 0.765, \"Liveness\": 0.0839, \"Tempo\": 168.924, \"Duration (ms)\": 175933.0, \"Valence\": 0.338, \"Chord\": \"F#/Gb\"}, {\"Index\": 27, \"Highest Charting Position\": 27, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Pepas\", \"Streams\": 14809458, \"Artist\": \"Farruko\", \"Artist Followers\": 10502148.0, \"Song ID\": \"5fwSHlTEWpluwOM0Sxnh5k\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-24\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 92.0, \"Danceability\": 0.762, \"Energy\": 0.766, \"Loudness\": -3.955, \"Speechiness\": 0.0343, \"Acousticness\": 0.00776, \"Liveness\": 0.128, \"Tempo\": 130.001, \"Duration (ms)\": 287120.0, \"Valence\": 0.442, \"Chord\": \"G\"}, {\"Index\": 28, \"Highest Charting Position\": 18, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Motley Crew\", \"Streams\": 14329162, \"Artist\": \"Post Malone\", \"Artist Followers\": 33651775.0, \"Song ID\": \"40uMIn2zJLAQhNXghRjBed\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 90.0, \"Danceability\": 0.797, \"Energy\": 0.631, \"Loudness\": -3.818, \"Speechiness\": 0.0786, \"Acousticness\": 0.0904, \"Liveness\": 0.0998, \"Tempo\": 129.915, \"Duration (ms)\": 184213.0, \"Valence\": 0.288, \"Chord\": \"D#/Eb\"}, {\"Index\": 29, \"Highest Charting Position\": 15, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Friday (feat. Mufasa & Hypeman) - Dopamine Re-Edit\", \"Streams\": 14273637, \"Artist\": \"Riton, Nightcrawlers\", \"Artist Followers\": 83689.0, \"Song ID\": \"4cG7HUWYHBV6R6tHn1gxrl\", \"Genre\": \"['dance pop', 'house', 'pop dance', 'tropical house', 'uk dance']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 92.0, \"Danceability\": 0.824, \"Energy\": 0.862, \"Loudness\": -3.424, \"Speechiness\": 0.126, \"Acousticness\": 0.0076, \"Liveness\": 0.303, \"Tempo\": 122.98, \"Duration (ms)\": 169153.0, \"Valence\": 0.801, \"Chord\": \"D\"}, {\"Index\": 30, \"Highest Charting Position\": 3, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Astronaut In The Ocean\", \"Streams\": 14174752, \"Artist\": \"Masked Wolf\", \"Artist Followers\": 365975.0, \"Song ID\": \"3Ofmpyhv5UAQ70mENzB277\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2021-01-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 89.0, \"Danceability\": 0.778, \"Energy\": 0.695, \"Loudness\": -6.865, \"Speechiness\": 0.0913, \"Acousticness\": 0.175, \"Liveness\": 0.15, \"Tempo\": 149.996, \"Duration (ms)\": 132780.0, \"Valence\": 0.472, \"Chord\": \"E\"}, {\"Index\": 31, \"Highest Charting Position\": 5, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Leave The Door Open\", \"Streams\": 13963568, \"Artist\": \"Bruno Mars, Anderson .Paak, Silk Sonic\", \"Artist Followers\": 32574754.0, \"Song ID\": \"7MAibcTli4IisCtbHKrGMh\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 92.0, \"Danceability\": 0.586, \"Energy\": 0.616, \"Loudness\": -7.964, \"Speechiness\": 0.0324, \"Acousticness\": 0.182, \"Liveness\": 0.0927, \"Tempo\": 148.088, \"Duration (ms)\": 242096.0, \"Valence\": 0.719, \"Chord\": \"F\"}, {\"Index\": 32, \"Highest Charting Position\": 32, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Don't Go Yet\", \"Streams\": 13205250, \"Artist\": \"Camila Cabello\", \"Artist Followers\": 22683756.0, \"Song ID\": \"1058fW9H3fZA6QjYCdOBad\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-07-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 88.0, \"Danceability\": 0.666, \"Energy\": 0.796, \"Loudness\": -6.967, \"Speechiness\": 0.103, \"Acousticness\": 0.0492, \"Liveness\": 0.0442, \"Tempo\": 110.108, \"Duration (ms)\": 164842.0, \"Valence\": 0.61, \"Chord\": \"A#/Bb\"}, {\"Index\": 33, \"Highest Charting Position\": 11, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"favorite crime\", \"Streams\": 12818935, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"5JCoSi02qi3jJeHdZXMmR8\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 91.0, \"Danceability\": 0.369, \"Energy\": 0.272, \"Loudness\": -10.497, \"Speechiness\": 0.0364, \"Acousticness\": 0.866, \"Liveness\": 0.147, \"Tempo\": 172.929, \"Duration (ms)\": 152667.0, \"Valence\": 0.218, \"Chord\": \"A\"}, {\"Index\": 34, \"Highest Charting Position\": 10, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Pareja Del A\\u00f1o\", \"Streams\": 12572307, \"Artist\": \"Sebastian Yatra, Myke Towers\", \"Artist Followers\": 16216789.0, \"Song ID\": \"2rCbl9naJYhaxjLsfx88uM\", \"Genre\": \"['colombian pop', 'latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 91.0, \"Danceability\": 0.715, \"Energy\": 0.622, \"Loudness\": -5.102, \"Speechiness\": 0.046, \"Acousticness\": 0.163, \"Liveness\": 0.0948, \"Tempo\": 80.015, \"Duration (ms)\": 195053.0, \"Valence\": 0.808, \"Chord\": \"E\"}, {\"Index\": 35, \"Highest Charting Position\": 4, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Watermelon Sugar\", \"Streams\": 11996689, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16112621.0, \"Song ID\": \"6UelLqGlWMcVH1E5c4H7lY\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 90.0, \"Danceability\": 0.548, \"Energy\": 0.816, \"Loudness\": -4.209, \"Speechiness\": 0.0465, \"Acousticness\": 0.122, \"Liveness\": 0.335, \"Tempo\": 95.39, \"Duration (ms)\": 174000.0, \"Valence\": 0.557, \"Chord\": \"C\"}, {\"Index\": 36, \"Highest Charting Position\": 36, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"NOT SOBER (feat. Polo G & Stunna Gambino)\", \"Streams\": 11869336, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 37, \"Highest Charting Position\": 3, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"RAPSTAR\", \"Streams\": 11683383, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"43PGPuHIlVOc04jrZVh9L6\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 89.0, \"Danceability\": 0.789, \"Energy\": 0.536, \"Loudness\": -6.862, \"Speechiness\": 0.242, \"Acousticness\": 0.41, \"Liveness\": 0.129, \"Tempo\": 81.039, \"Duration (ms)\": 165926.0, \"Valence\": 0.437, \"Chord\": \"F#/Gb\"}, {\"Index\": 38, \"Highest Charting Position\": 15, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"You Right\", \"Streams\": 11629418, \"Artist\": \"Doja Cat, The Weeknd\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0k4d5YPDr1r7FX77VdqWez\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 89.0, \"Danceability\": 0.828, \"Energy\": 0.621, \"Loudness\": -6.414, \"Speechiness\": 0.0565, \"Acousticness\": 0.0164, \"Liveness\": 0.0845, \"Tempo\": 128.986, \"Duration (ms)\": 186173.0, \"Valence\": 0.436, \"Chord\": \"G#/Ab\"}, {\"Index\": 39, \"Highest Charting Position\": 39, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"911 - Remix\", \"Streams\": 11553846, \"Artist\": \"Sech, Jhay Cortez\", \"Artist Followers\": 8758283.0, \"Song ID\": \"27RSJHEA99Y0Vsow7nA37A\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 89.0, \"Danceability\": 0.816, \"Energy\": 0.71, \"Loudness\": -3.728, \"Speechiness\": 0.0398, \"Acousticness\": 0.165, \"Liveness\": 0.292, \"Tempo\": 93.02, \"Duration (ms)\": 208631.0, \"Valence\": 0.784, \"Chord\": \"G\"}, {\"Index\": 40, \"Highest Charting Position\": 1, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"D\\u00c1KITI\", \"Streams\": 11524288, \"Artist\": \"Bad Bunny, Jhay Cortez\", \"Artist Followers\": 36142273.0, \"Song ID\": \"4MzXwWMhyBbmu6hOcLVD49\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 86.0, \"Danceability\": 0.731, \"Energy\": 0.573, \"Loudness\": -10.059, \"Speechiness\": 0.0544, \"Acousticness\": 0.401, \"Liveness\": 0.113, \"Tempo\": 109.928, \"Duration (ms)\": 205090.0, \"Valence\": 0.145, \"Chord\": \"E\"}, {\"Index\": 41, \"Highest Charting Position\": 41, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Mi\\u00e9nteme\", \"Streams\": 11477024, \"Artist\": \"TINI, Maria Becerra\", \"Artist Followers\": 2936204.0, \"Song ID\": \"0cOa970mzTWAxKtltpkpLc\", \"Genre\": \"['latin pop', 'pop argentino']\", \"Release Date\": \"2021-04-29\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 90.0, \"Danceability\": 0.85, \"Energy\": 0.541, \"Loudness\": -4.522, \"Speechiness\": 0.0674, \"Acousticness\": 0.161, \"Liveness\": 0.286, \"Tempo\": 92.003, \"Duration (ms)\": 165275.0, \"Valence\": 0.916, \"Chord\": \"D\"}, {\"Index\": 42, \"Highest Charting Position\": 17, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"jealousy, jealousy\", \"Streams\": 11287301, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"0MMyJUC3WNnFS1lit5pTjk\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 90.0, \"Danceability\": 0.695, \"Energy\": 0.575, \"Loudness\": -6.334, \"Speechiness\": 0.116, \"Acousticness\": 0.198, \"Liveness\": 0.0614, \"Tempo\": 163.929, \"Duration (ms)\": 173160.0, \"Valence\": 0.699, \"Chord\": \"A#/Bb\"}, {\"Index\": 43, \"Highest Charting Position\": 33, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Poblado - Remix\", \"Streams\": 11283626, \"Artist\": \"J Balvin, KAROL G, Nicky Jam, Crissin, Totoy El Frio, Natan & Shander\", \"Artist Followers\": 29051363.0, \"Song ID\": \"1WedZeiezCmCEOzLwhx0hV\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 89.0, \"Danceability\": 0.813, \"Energy\": 0.809, \"Loudness\": -5.382, \"Speechiness\": 0.0846, \"Acousticness\": 0.102, \"Liveness\": 0.377, \"Tempo\": 93.005, \"Duration (ms)\": 393280.0, \"Valence\": 0.646, \"Chord\": \"D#/Eb\"}, {\"Index\": 44, \"Highest Charting Position\": 2, \"Number of Times Charted\": 49, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Dynamite\", \"Streams\": 11196819, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"4saklk6nie3yiGePpBwUoc\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 89.0, \"Danceability\": 0.746, \"Energy\": 0.765, \"Loudness\": -4.41, \"Speechiness\": 0.0993, \"Acousticness\": 0.0112, \"Liveness\": 0.0936, \"Tempo\": 114.044, \"Duration (ms)\": 199054.0, \"Valence\": 0.737, \"Chord\": \"F#/Gb\"}, {\"Index\": 45, \"Highest Charting Position\": 9, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"The Business\", \"Streams\": 10739770, \"Artist\": \"Ti\\u00ebsto\", \"Artist Followers\": 5785065.0, \"Song ID\": \"6f3Slt0GbA2bPZlz0aIFXN\", \"Genre\": \"['big room', 'brostep', 'dance pop', 'dutch edm', 'edm', 'electro house', 'house', 'pop dance', 'slap house', 'trance', 'tropical house']\", \"Release Date\": \"2020-09-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 90.0, \"Danceability\": 0.798, \"Energy\": 0.62, \"Loudness\": -7.079, \"Speechiness\": 0.232, \"Acousticness\": 0.414, \"Liveness\": 0.112, \"Tempo\": 120.031, \"Duration (ms)\": 164000.0, \"Valence\": 0.235, \"Chord\": \"G#/Ab\"}, {\"Index\": 46, \"Highest Charting Position\": 46, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Heartbreak Anthem (with David Guetta & Little Mix)\", \"Streams\": 10315460, \"Artist\": \"Galantis\", \"Artist Followers\": 3120157.0, \"Song ID\": \"5K6Ssv4Z3zRvxt0P6EKUAP\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2021-05-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 89.0, \"Danceability\": 0.595, \"Energy\": 0.784, \"Loudness\": -4.878, \"Speechiness\": 0.102, \"Acousticness\": 0.216, \"Liveness\": 0.0608, \"Tempo\": 124.111, \"Duration (ms)\": 183726.0, \"Valence\": 0.479, \"Chord\": \"C#/Db\"}, {\"Index\": 47, \"Highest Charting Position\": 1, \"Number of Times Charted\": 51, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Mood (feat. iann dior)\", \"Streams\": 10222056, \"Artist\": \"24kGoldn\", \"Artist Followers\": 1274433.0, \"Song ID\": \"4jPy3l0RUwlUI9T5XHBW2m\", \"Genre\": \"['cali rap']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 89.0, \"Danceability\": 0.701, \"Energy\": 0.716, \"Loudness\": -3.671, \"Speechiness\": 0.0361, \"Acousticness\": 0.174, \"Liveness\": 0.324, \"Tempo\": 91.007, \"Duration (ms)\": 140533.0, \"Valence\": 0.732, \"Chord\": \"G\"}, {\"Index\": 48, \"Highest Charting Position\": 48, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Entre Nosotros\", \"Streams\": 10215216, \"Artist\": \"Tiago PZK, LIT killah\", \"Artist Followers\": 375865.0, \"Song ID\": \"6w8yBI2vthyN9UnwO4UBWb\", \"Genre\": \"['trap argentino']\", \"Release Date\": \"2021-07-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 89.0, \"Danceability\": 0.729, \"Energy\": 0.513, \"Loudness\": -6.345, \"Speechiness\": 0.0455, \"Acousticness\": 0.494, \"Liveness\": 0.137, \"Tempo\": 170.064, \"Duration (ms)\": 192353.0, \"Valence\": 0.789, \"Chord\": \"F\"}, {\"Index\": 49, \"Highest Charting Position\": 29, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Fiel - Remix\", \"Streams\": 10032746, \"Artist\": \"Wisin, Jhay Cortez, Anuel AA, Los Legendarios, Myke Towers\", \"Artist Followers\": 6929075.0, \"Song ID\": \"43qcs9NpJhDxtG91zxFkj7\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 89.0, \"Danceability\": 0.839, \"Energy\": 0.711, \"Loudness\": -4.733, \"Speechiness\": 0.0473, \"Acousticness\": 0.398, \"Liveness\": 0.118, \"Tempo\": 97.99, \"Duration (ms)\": 349547.0, \"Valence\": 0.573, \"Chord\": \"F#/Gb\"}, {\"Index\": 50, \"Highest Charting Position\": 20, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Build a Bitch\", \"Streams\": 9841998, \"Artist\": \"Bella Poarch\", \"Artist Followers\": 389076.0, \"Song ID\": \"7BoobGhD4x5K96Me0hqC8Q\", \"Genre\": \"[]\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 89.0, \"Danceability\": 0.855, \"Energy\": 0.463, \"Loudness\": -7.454, \"Speechiness\": 0.0367, \"Acousticness\": 0.217, \"Liveness\": 0.347, \"Tempo\": 102.931, \"Duration (ms)\": 122773.0, \"Valence\": 0.866, \"Chord\": \"D#/Eb\"}, {\"Index\": 51, \"Highest Charting Position\": 19, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Nicky Jam: Bzrp Music Sessions, Vol. 41\", \"Streams\": 9799701, \"Artist\": \"Bizarrap, Nicky Jam\", \"Artist Followers\": 3126961.0, \"Song ID\": \"03LfOYi0icz4souspZVVhq\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2021-06-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 88.0, \"Danceability\": 0.627, \"Energy\": 0.849, \"Loudness\": -3.167, \"Speechiness\": 0.153, \"Acousticness\": 0.0913, \"Liveness\": 0.145, \"Tempo\": 89.907, \"Duration (ms)\": 158087.0, \"Valence\": 0.818, \"Chord\": \"C#/Db\"}, {\"Index\": 52, \"Highest Charting Position\": 52, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Tiroteo - Remix\", \"Streams\": 9781153, \"Artist\": \"Marc Segu\\u00ed, Rauw Alejandro, Pol Granch\", \"Artist Followers\": 45362.0, \"Song ID\": \"4OwhwvKESFtuu06dTgct7i\", \"Genre\": \"[]\", \"Release Date\": \"2021-04-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 88.0, \"Danceability\": 0.75, \"Energy\": 0.522, \"Loudness\": -7.018, \"Speechiness\": 0.0293, \"Acousticness\": 0.282, \"Liveness\": 0.0743, \"Tempo\": 110.427, \"Duration (ms)\": 321556.0, \"Valence\": 0.601, \"Chord\": \"A\"}, {\"Index\": 53, \"Highest Charting Position\": 19, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"NDA\", \"Streams\": 9635619, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47014200.0, \"Song ID\": \"38GBNKZUhfBkk3oNlWzRYd\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-07-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 84.0, \"Danceability\": 0.765, \"Energy\": 0.373, \"Loudness\": -9.921, \"Speechiness\": 0.0713, \"Acousticness\": 0.341, \"Liveness\": 0.112, \"Tempo\": 85.016, \"Duration (ms)\": 195777.0, \"Valence\": 0.554, \"Chord\": \"G#/Ab\"}, {\"Index\": 54, \"Highest Charting Position\": 40, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Rasputin\", \"Streams\": 9600707, \"Artist\": \"Majestic, Boney M.\", \"Artist Followers\": 32178.0, \"Song ID\": \"6FO4K7MrMoYkc5BlpX5LNV\", \"Genre\": \"['house', 'pop dance', 'uk dance']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 49.0, \"Danceability\": 0.83, \"Energy\": 0.839, \"Loudness\": -6.985, \"Speechiness\": 0.0699, \"Acousticness\": 0.00201, \"Liveness\": 0.0353, \"Tempo\": 128.012, \"Duration (ms)\": 345543.0, \"Valence\": 0.59, \"Chord\": \"F#/Gb\"}, {\"Index\": 55, \"Highest Charting Position\": 52, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Leave Before You Love Me (with Jonas Brothers)\", \"Streams\": 9428494, \"Artist\": \"Marshmello\", \"Artist Followers\": 31541310.0, \"Song ID\": \"4qu63nuBpdn0qHUHuObEj1\", \"Genre\": \"['brostep', 'edm', 'pop', 'pop dance', 'progressive electro house']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\", \"Popularity\": 89.0, \"Danceability\": 0.721, \"Energy\": 0.738, \"Loudness\": -4.77, \"Speechiness\": 0.0403, \"Acousticness\": 0.00226, \"Liveness\": 0.118, \"Tempo\": 119.976, \"Duration (ms)\": 154983.0, \"Valence\": 0.637, \"Chord\": \"G\"}, {\"Index\": 56, \"Highest Charting Position\": 56, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Freaks\", \"Streams\": 9319465, \"Artist\": \"Surf Curse\", \"Artist Followers\": 495226.0, \"Song ID\": \"7EkWXAI1wn8Ii883ecd9xr\", \"Genre\": \"['dreamo', 'indie surf', 'surf punk', 'vegas indie']\", \"Release Date\": \"2021-05-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 89.0, \"Danceability\": 0.345, \"Energy\": 0.941, \"Loudness\": -9.918, \"Speechiness\": 0.0466, \"Acousticness\": 3.84e-05, \"Liveness\": 0.0511, \"Tempo\": 179.626, \"Duration (ms)\": 147062.0, \"Valence\": 0.407, \"Chord\": \"A\"}, {\"Index\": 57, \"Highest Charting Position\": 57, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Meu Peda\\u00e7o de Pecado\", \"Streams\": 9206366, \"Artist\": \"Jo\\u00e3o Gomes\", \"Artist Followers\": 409173.0, \"Song ID\": \"2kJRlOyrxsy7Ot3c5TZ8Q6\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 83.0, \"Danceability\": 0.668, \"Energy\": 0.887, \"Loudness\": -4.404, \"Speechiness\": 0.0564, \"Acousticness\": 0.369, \"Liveness\": 0.257, \"Tempo\": 151.92, \"Duration (ms)\": 157176.0, \"Valence\": 0.907, \"Chord\": \"B\"}, {\"Index\": 58, \"Highest Charting Position\": 31, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"2/Catorce\", \"Streams\": 9086979, \"Artist\": \"Rauw Alejandro, Mr. Naisgai\", \"Artist Followers\": 6080597.0, \"Song ID\": \"71R8HJxQk5qMiRstrlXN9t\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2021-02-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 87.0, \"Danceability\": 0.54, \"Energy\": 0.455, \"Loudness\": -5.988, \"Speechiness\": 0.224, \"Acousticness\": 0.675, \"Liveness\": 0.12, \"Tempo\": 83.876, \"Duration (ms)\": 212032.0, \"Valence\": 0.432, \"Chord\": \"D#/Eb\"}, {\"Index\": 59, \"Highest Charting Position\": 34, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Beautiful Mistakes (feat. Megan Thee Stallion)\", \"Streams\": 9048966, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32262679.0, \"Song ID\": \"5zFglKYiknIxks8geR8rcL\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 88.0, \"Danceability\": 0.713, \"Energy\": 0.676, \"Loudness\": -5.483, \"Speechiness\": 0.027, \"Acousticness\": 0.0377, \"Liveness\": 0.154, \"Tempo\": 99.048, \"Duration (ms)\": 227395.0, \"Valence\": 0.721, \"Chord\": \"A#/Bb\"}, {\"Index\": 60, \"Highest Charting Position\": 31, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Run\", \"Streams\": 9017356, \"Artist\": \"OneRepublic\", \"Artist Followers\": 12169108.0, \"Song ID\": \"2UbVnbE5FH6008mAm6Mmgw\", \"Genre\": \"['dance pop', 'piano rock', 'pop', 'pop rock']\", \"Release Date\": \"2021-05-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2020-09-25--2020-10-02\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 88.0, \"Danceability\": 0.682, \"Energy\": 0.72, \"Loudness\": -8.173, \"Speechiness\": 0.0381, \"Acousticness\": 0.326, \"Liveness\": 0.148, \"Tempo\": 117.003, \"Duration (ms)\": 169011.0, \"Valence\": 0.673, \"Chord\": \"B\"}, {\"Index\": 61, \"Highest Charting Position\": 46, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Thot Shit\", \"Streams\": 8977336, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4787261.0, \"Song ID\": \"5zNW5ARjYhJQJz1AChP33n\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 88.0, \"Danceability\": 0.95, \"Energy\": 0.693, \"Loudness\": -3.424, \"Speechiness\": 0.0898, \"Acousticness\": 0.0133, \"Liveness\": 0.173, \"Tempo\": 130.02, \"Duration (ms)\": 184635.0, \"Valence\": 0.891, \"Chord\": \"A\"}, {\"Index\": 62, \"Highest Charting Position\": 26, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Your Love (9PM)\", \"Streams\": 8935418, \"Artist\": \"ATB, Topic, A7S\", \"Artist Followers\": 291777.0, \"Song ID\": \"5YaskwnGDZFDRipaqzbwQx\", \"Genre\": \"['german dance', 'german techno', 'german trance', 'trance']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 88.0, \"Danceability\": 0.669, \"Energy\": 0.784, \"Loudness\": -5.603, \"Speechiness\": 0.112, \"Acousticness\": 0.194, \"Liveness\": 0.115, \"Tempo\": 125.993, \"Duration (ms)\": 150053.0, \"Valence\": 0.517, \"Chord\": \"G\"}, {\"Index\": 63, \"Highest Charting Position\": 9, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"brutal\", \"Streams\": 8881356, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"6SRsiMl7w1USE4mFqrOhHC\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 89.0, \"Danceability\": 0.672, \"Energy\": 0.526, \"Loudness\": -6.446, \"Speechiness\": 0.0599, \"Acousticness\": 0.0311, \"Liveness\": 0.28, \"Tempo\": 123.999, \"Duration (ms)\": 143747.0, \"Valence\": 0.28, \"Chord\": \"E\"}, {\"Index\": 64, \"Highest Charting Position\": 2, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Save Your Tears\", \"Streams\": 8843110, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"37BZB0z9T8Xu7U3e65qxFy\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 94.0, \"Danceability\": 0.65, \"Energy\": 0.825, \"Loudness\": -4.645, \"Speechiness\": 0.0325, \"Acousticness\": 0.0215, \"Liveness\": 0.0936, \"Tempo\": 118.091, \"Duration (ms)\": 191014.0, \"Valence\": 0.593, \"Chord\": \"C\"}, {\"Index\": 65, \"Highest Charting Position\": 8, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Heartbreak Anniversary\", \"Streams\": 8832945, \"Artist\": \"Giveon\", \"Artist Followers\": 1398563.0, \"Song ID\": \"3FAJ6O0NOHQV8Mc5Ri6ENp\", \"Genre\": \"['pop', 'r&b']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 87.0, \"Danceability\": 0.449, \"Energy\": 0.465, \"Loudness\": -8.964, \"Speechiness\": 0.0791, \"Acousticness\": 0.524, \"Liveness\": 0.303, \"Tempo\": 89.087, \"Duration (ms)\": 198371.0, \"Valence\": 0.543, \"Chord\": \"C\"}, {\"Index\": 66, \"Highest Charting Position\": 2, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Don't Start Now\", \"Streams\": 8821971, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 1250353.0, \"Song ID\": \"7njGslFmqBmOSSOpTyZCs9\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.793, \"Energy\": 0.793, \"Loudness\": -4.521, \"Speechiness\": 0.083, \"Acousticness\": 0.0123, \"Liveness\": 0.0951, \"Tempo\": 123.95, \"Duration (ms)\": 183290.0, \"Valence\": 0.679, \"Chord\": \"B\"}, {\"Index\": 67, \"Highest Charting Position\": 33, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Dinero\", \"Streams\": 8564775, \"Artist\": \"Trinidad Cardona\", \"Artist Followers\": 116817.0, \"Song ID\": \"3ggtU1ZOKO8ZNiqPNyXGcm\", \"Genre\": \"[]\", \"Release Date\": \"2018-02-02\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 87.0, \"Danceability\": 0.708, \"Energy\": 0.782, \"Loudness\": -4.687, \"Speechiness\": 0.0674, \"Acousticness\": 0.00772, \"Liveness\": 0.107, \"Tempo\": 119.997, \"Duration (ms)\": 160880.0, \"Valence\": 0.484, \"Chord\": \"D\"}, {\"Index\": 68, \"Highest Charting Position\": 35, \"Number of Times Charted\": 48, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Sweater Weather\", \"Streams\": 8564017, \"Artist\": \"The Neighbourhood\", \"Artist Followers\": 6662605.0, \"Song ID\": \"2QjOHCTQ1Jl3zawyYOpxh6\", \"Genre\": \"['modern alternative rock', 'modern rock', 'pop']\", \"Release Date\": \"2013-04-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 87.0, \"Danceability\": 0.612, \"Energy\": 0.807, \"Loudness\": -2.81, \"Speechiness\": 0.0336, \"Acousticness\": 0.0495, \"Liveness\": 0.101, \"Tempo\": 124.053, \"Duration (ms)\": 240400.0, \"Valence\": 0.398, \"Chord\": \"A#/Bb\"}, {\"Index\": 69, \"Highest Charting Position\": 69, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Sobrio\", \"Streams\": 8514480, \"Artist\": \"Maluma\", \"Artist Followers\": 26769304.0, \"Song ID\": \"4HzqWEdAbzcVFDv0pvxV4w\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-07-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 87.0, \"Danceability\": 0.762, \"Energy\": 0.77, \"Loudness\": -2.758, \"Speechiness\": 0.223, \"Acousticness\": 0.138, \"Liveness\": 0.15, \"Tempo\": 177.998, \"Duration (ms)\": 201181.0, \"Valence\": 0.631, \"Chord\": \"F\"}, {\"Index\": 70, \"Highest Charting Position\": 12, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Someone You Loved\", \"Streams\": 8490162, \"Artist\": \"Lewis Capaldi\", \"Artist Followers\": 8384096.0, \"Song ID\": \"7qEHsqek33rTcFNT9PFqLf\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.501, \"Energy\": 0.405, \"Loudness\": -5.679, \"Speechiness\": 0.0319, \"Acousticness\": 0.751, \"Liveness\": 0.105, \"Tempo\": 109.891, \"Duration (ms)\": 182161.0, \"Valence\": 0.446, \"Chord\": \"C#/Db\"}, {\"Index\": 71, \"Highest Charting Position\": 71, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Over The Top (feat. Drake)\", \"Streams\": 8269753, \"Artist\": \"Smiley\", \"Artist Followers\": 26131.0, \"Song ID\": \"3yaYgjEFkRw3PVjW9mV1TO\", \"Genre\": \"['canadian hip hop', 'toronto rap']\", \"Release Date\": \"2021-07-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 83.0, \"Danceability\": 0.833, \"Energy\": 0.498, \"Loudness\": -5.196, \"Speechiness\": 0.117, \"Acousticness\": 0.0493, \"Liveness\": 0.119, \"Tempo\": 139.928, \"Duration (ms)\": 153406.0, \"Valence\": 0.259, \"Chord\": \"A#/Bb\"}, {\"Index\": 72, \"Highest Charting Position\": 72, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"2055\", \"Streams\": 8133401, \"Artist\": \"Sleepy Hallow\", \"Artist Followers\": 408696.0, \"Song ID\": \"4XvcHTUfIlWfyJTRG0aqlo\", \"Genre\": \"['brooklyn drill', 'nyc rap']\", \"Release Date\": \"2021-06-02\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 85.0, \"Danceability\": 0.829, \"Energy\": 0.512, \"Loudness\": -5.865, \"Speechiness\": 0.187, \"Acousticness\": 0.492, \"Liveness\": 0.12, \"Tempo\": 80.511, \"Duration (ms)\": 123987.0, \"Valence\": 0.638, \"Chord\": \"F#/Gb\"}, {\"Index\": 73, \"Highest Charting Position\": 33, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"EL MAKINON\", \"Streams\": 8102107, \"Artist\": \"KAROL G, Mariah Angeliq\", \"Artist Followers\": 17775316.0, \"Song ID\": \"2FSGUA0gFgGeQdprjtGM2M\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 87.0, \"Danceability\": 0.635, \"Energy\": 0.706, \"Loudness\": -3.224, \"Speechiness\": 0.125, \"Acousticness\": 0.256, \"Liveness\": 0.108, \"Tempo\": 88.863, \"Duration (ms)\": 209160.0, \"Valence\": 0.443, \"Chord\": \"F\"}, {\"Index\": 74, \"Highest Charting Position\": 74, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Loco\", \"Streams\": 8093413, \"Artist\": \"Justin Quiles, Chimbala, Zion & Lennox\", \"Artist Followers\": 2895789.0, \"Song ID\": \"6PDlkWmrq2ZKiUuFt2aQsH\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 87.0, \"Danceability\": 0.77, \"Energy\": 0.899, \"Loudness\": -2.981, \"Speechiness\": 0.0494, \"Acousticness\": 0.222, \"Liveness\": 0.0894, \"Tempo\": 128.05, \"Duration (ms)\": 231604.0, \"Valence\": 0.851, \"Chord\": \"G#/Ab\"}, {\"Index\": 75, \"Highest Charting Position\": 75, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Love Tonight - Edit\", \"Streams\": 8006336, \"Artist\": \"Shouse\", \"Artist Followers\": 27116.0, \"Song ID\": \"6OufwUcCqo81guU2jAlDVP\", \"Genre\": \"['aussietronica']\", \"Release Date\": \"2017-12-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 87.0, \"Danceability\": 0.727, \"Energy\": 0.681, \"Loudness\": -7.114, \"Speechiness\": 0.0265, \"Acousticness\": 0.00214, \"Liveness\": 0.0861, \"Tempo\": 123.028, \"Duration (ms)\": 241970.0, \"Valence\": 0.448, \"Chord\": \"F\"}, {\"Index\": 76, \"Highest Charting Position\": 12, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"ZITTI E BUONI\", \"Streams\": 7975148, \"Artist\": \"M\\u00e5neskin\", \"Artist Followers\": 3377762.0, \"Song ID\": \"776AftMmFFAWUIEAb3lHhw\", \"Genre\": \"['indie rock italiano', 'italian pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-03-05--2021-03-12\", \"Popularity\": 86.0, \"Danceability\": 0.625, \"Energy\": 0.939, \"Loudness\": -3.115, \"Speechiness\": 0.0669, \"Acousticness\": 0.00138, \"Liveness\": 0.424, \"Tempo\": 102.999, \"Duration (ms)\": 194787.0, \"Valence\": 0.644, \"Chord\": \"E\"}, {\"Index\": 77, \"Highest Charting Position\": 2, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"telepat\\u00eda\", \"Streams\": 7912399, \"Artist\": \"Kali Uchis\", \"Artist Followers\": 1999954.0, \"Song ID\": \"6tDDoYIxWvMLTdKpjFkc1B\", \"Genre\": \"['colombian pop', 'pop']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 88.0, \"Danceability\": 0.653, \"Energy\": 0.524, \"Loudness\": -9.016, \"Speechiness\": 0.0502, \"Acousticness\": 0.112, \"Liveness\": 0.203, \"Tempo\": 83.97, \"Duration (ms)\": 160191.0, \"Valence\": 0.553, \"Chord\": \"B\"}, {\"Index\": 78, \"Highest Charting Position\": 9, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Botella Tras Botella\", \"Streams\": 7735223, \"Artist\": \"Gera MX, Christian Nodal\", \"Artist Followers\": 2043294.0, \"Song ID\": \"2MnLkFqY9Rpg9s3Zv6ZJdK\", \"Genre\": \"['mexican hip hop', 'rap conciencia']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 87.0, \"Danceability\": 0.727, \"Energy\": 0.546, \"Loudness\": -4.572, \"Speechiness\": 0.0437, \"Acousticness\": 0.656, \"Liveness\": 0.122, \"Tempo\": 106.891, \"Duration (ms)\": 197333.0, \"Valence\": 0.69, \"Chord\": \"C\"}, {\"Index\": 79, \"Highest Charting Position\": 7, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Fiel\", \"Streams\": 7717211, \"Artist\": \"Los Legendarios, Wisin, Jhay Cortez\", \"Artist Followers\": 31488.0, \"Song ID\": \"7Bk0uXKk1uPT0XuQbpFzvs\", \"Genre\": \"['reggaeton', 'trap latino']\", \"Release Date\": \"2021-02-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 88.0, \"Danceability\": 0.849, \"Energy\": 0.701, \"Loudness\": -4.407, \"Speechiness\": 0.06, \"Acousticness\": 0.407, \"Liveness\": 0.112, \"Tempo\": 98.005, \"Duration (ms)\": 261667.0, \"Valence\": 0.505, \"Chord\": \"F#/Gb\"}, {\"Index\": 80, \"Highest Charting Position\": 1, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Dance Monkey\", \"Streams\": 7687058, \"Artist\": \"Tones And I\", \"Artist Followers\": 2819593.0, \"Song ID\": \"2XU0oxnq2qxCpomAAuJY8K\", \"Genre\": \"['australian pop', 'pop']\", \"Release Date\": \"2019-10-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.824, \"Energy\": 0.588, \"Loudness\": -6.4, \"Speechiness\": 0.0924, \"Acousticness\": 0.692, \"Liveness\": 0.149, \"Tempo\": 98.027, \"Duration (ms)\": 209438.0, \"Valence\": 0.513, \"Chord\": \"F#/Gb\"}, {\"Index\": 81, \"Highest Charting Position\": 7, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"WITHOUT YOU\", \"Streams\": 7642130, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2230022.0, \"Song ID\": \"27OeeYzk6klgBh83TSvGMA\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 87.0, \"Danceability\": 0.662, \"Energy\": 0.413, \"Loudness\": -7.357, \"Speechiness\": 0.0299, \"Acousticness\": 0.213, \"Liveness\": 0.134, \"Tempo\": 93.005, \"Duration (ms)\": 161385.0, \"Valence\": 0.467, \"Chord\": \"C\"}, {\"Index\": 82, \"Highest Charting Position\": 6, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Wants and Needs (feat. Lil Baby)\", \"Streams\": 7637626, \"Artist\": \"Drake\", \"Artist Followers\": 56308172.0, \"Song ID\": \"65OVbaJR5O1RmwOQx0875b\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 87.0, \"Danceability\": 0.578, \"Energy\": 0.449, \"Loudness\": -6.349, \"Speechiness\": 0.286, \"Acousticness\": 0.0618, \"Liveness\": 0.119, \"Tempo\": 136.006, \"Duration (ms)\": 192956.0, \"Valence\": 0.1, \"Chord\": \"C#/Db\"}, {\"Index\": 83, \"Highest Charting Position\": 83, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Bezos I\", \"Streams\": 7516291, \"Artist\": \"Bo Burnham\", \"Artist Followers\": 1042079.0, \"Song ID\": \"0Kdj7nwaYQmvhxnqZaIQuW\", \"Genre\": \"['comic']\", \"Release Date\": \"2021-06-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 84.0, \"Danceability\": 0.694, \"Energy\": 0.948, \"Loudness\": -5.307, \"Speechiness\": 0.0361, \"Acousticness\": 0.00936, \"Liveness\": 0.139, \"Tempo\": 115.044, \"Duration (ms)\": 58149.0, \"Valence\": 0.705, \"Chord\": \"D\"}, {\"Index\": 84, \"Highest Charting Position\": 76, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Love Again\", \"Streams\": 7465445, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 1250353.0, \"Song ID\": \"2sN1pMv6d2t5GlvN6IBMlK\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2020-03-27--2020-04-03\", \"Popularity\": 0.0, \"Danceability\": 0.659, \"Energy\": 0.667, \"Loudness\": -4.668, \"Speechiness\": 0.0339, \"Acousticness\": 0.00173, \"Liveness\": 0.1, \"Tempo\": 115.982, \"Duration (ms)\": 258004.0, \"Valence\": 0.468, \"Chord\": \"B\"}, {\"Index\": 85, \"Highest Charting Position\": 32, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Goosebumps - Remix\", \"Streams\": 7452633, \"Artist\": \"Travis Scott, HVME\", \"Artist Followers\": 17719446.0, \"Song ID\": \"5uEYRdEIh9Bo4fpjDd4Na9\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 87.0, \"Danceability\": 0.841, \"Energy\": 0.593, \"Loudness\": -7.846, \"Speechiness\": 0.0379, \"Acousticness\": 0.418, \"Liveness\": 0.124, \"Tempo\": 124.917, \"Duration (ms)\": 162803.0, \"Valence\": 0.808, \"Chord\": \"C#/Db\"}, {\"Index\": 86, \"Highest Charting Position\": 11, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Head & Heart (feat. MNEK)\", \"Streams\": 7434252, \"Artist\": \"Joel Corry\", \"Artist Followers\": 207547.0, \"Song ID\": \"6cx06DFPPHchuUAcTxznu9\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance', 'tropical house', 'uk dance']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 87.0, \"Danceability\": 0.734, \"Energy\": 0.874, \"Loudness\": -3.158, \"Speechiness\": 0.0662, \"Acousticness\": 0.168, \"Liveness\": 0.0489, \"Tempo\": 122.953, \"Duration (ms)\": 166028.0, \"Valence\": 0.905, \"Chord\": \"G#/Ab\"}, {\"Index\": 87, \"Highest Charting Position\": 42, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"BED\", \"Streams\": 7383369, \"Artist\": \"Joel Corry, RAYE, David Guetta\", \"Artist Followers\": 207547.0, \"Song ID\": \"0siYMEsGrzzzlWLXK5zJfS\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance', 'tropical house', 'uk dance']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 87.0, \"Danceability\": 0.671, \"Energy\": 0.782, \"Loudness\": -4.593, \"Speechiness\": 0.0341, \"Acousticness\": 0.0142, \"Liveness\": 0.333, \"Tempo\": 123.989, \"Duration (ms)\": 178088.0, \"Valence\": 0.618, \"Chord\": \"F#/Gb\"}, {\"Index\": 88, \"Highest Charting Position\": 78, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Iko Iko (My Bestie)\", \"Streams\": 7381585, \"Artist\": \"Justin Wellington, Small Jam\", \"Artist Followers\": 18228.0, \"Song ID\": \"7MC4XR9M9amdmKQr2iDF7i\", \"Genre\": \"['melanesian pop', 'pacific islands pop', 'png pop']\", \"Release Date\": \"2019-06-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 87.0, \"Danceability\": 0.862, \"Energy\": 0.753, \"Loudness\": -5.356, \"Speechiness\": 0.0625, \"Acousticness\": 0.131, \"Liveness\": 0.077, \"Tempo\": 105.039, \"Duration (ms)\": 182857.0, \"Valence\": 0.827, \"Chord\": \"F\"}, {\"Index\": 89, \"Highest Charting Position\": 89, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Better Believe\", \"Streams\": 7365053, \"Artist\": \"Belly, The Weeknd, Young Thug\", \"Artist Followers\": 203972.0, \"Song ID\": \"3zs87EV3EZSh2UpiXxT52Y\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'pop rap', 'rap', 'southern hip hop', 'trap', 'trap soul', 'underground hip hop']\", \"Release Date\": \"2021-07-22\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 80.0, \"Danceability\": 0.797, \"Energy\": 0.573, \"Loudness\": -7.85, \"Speechiness\": 0.319, \"Acousticness\": 0.159, \"Liveness\": 0.144, \"Tempo\": 124.995, \"Duration (ms)\": 206629.0, \"Valence\": 0.445, \"Chord\": \"C\"}, {\"Index\": 90, \"Highest Charting Position\": 23, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Arcade\", \"Streams\": 7353795, \"Artist\": \"Duncan Laurence\", \"Artist Followers\": 287361.0, \"Song ID\": \"1Xi84slp6FryDSCbzq4UCD\", \"Genre\": \"['dutch pop']\", \"Release Date\": \"2019-03-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 84.0, \"Danceability\": 0.45, \"Energy\": 0.329, \"Loudness\": -12.603, \"Speechiness\": 0.0441, \"Acousticness\": 0.818, \"Liveness\": 0.135, \"Tempo\": 71.884, \"Duration (ms)\": 183624.0, \"Valence\": 0.266, \"Chord\": \"A\"}, {\"Index\": 91, \"Highest Charting Position\": 55, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"512\", \"Streams\": 7336542, \"Artist\": \"Mora, Jhay Cortez\", \"Artist Followers\": 151486.0, \"Song ID\": \"5jzEwSyyymBlf1fa1o39T2\", \"Genre\": \"['reggaeton', 'trap latino']\", \"Release Date\": \"2021-02-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 87.0, \"Danceability\": 0.818, \"Energy\": 0.673, \"Loudness\": -7.542, \"Speechiness\": 0.148, \"Acousticness\": 0.348, \"Liveness\": 0.172, \"Tempo\": 87.961, \"Duration (ms)\": 193636.0, \"Valence\": 0.695, \"Chord\": \"E\"}, {\"Index\": 92, \"Highest Charting Position\": 1, \"Number of Times Charted\": 40, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"positions\", \"Streams\": 7244853, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67158068.0, \"Song ID\": \"35mvY5S1H3J2QZyna3TFe0\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 86.0, \"Danceability\": 0.737, \"Energy\": 0.802, \"Loudness\": -4.771, \"Speechiness\": 0.0878, \"Acousticness\": 0.468, \"Liveness\": 0.0931, \"Tempo\": 144.015, \"Duration (ms)\": 172325.0, \"Valence\": 0.682, \"Chord\": \"C\"}, {\"Index\": 93, \"Highest Charting Position\": 6, \"Number of Times Charted\": 84, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Circles\", \"Streams\": 7156162, \"Artist\": \"Post Malone\", \"Artist Followers\": 33651775.0, \"Song ID\": \"21jGcNKet2qwijlDFuPiPb\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 87.0, \"Danceability\": 0.695, \"Energy\": 0.762, \"Loudness\": -3.497, \"Speechiness\": 0.0395, \"Acousticness\": 0.192, \"Liveness\": 0.0863, \"Tempo\": 120.042, \"Duration (ms)\": 215280.0, \"Valence\": 0.553, \"Chord\": \"C\"}, {\"Index\": 94, \"Highest Charting Position\": 94, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Blaues Licht\", \"Streams\": 7084292, \"Artist\": \"RAF Camora, Bonez MC\", \"Artist Followers\": 1329531.0, \"Song ID\": \"08EPQiLMyGB8GJX2EiVoCM\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 78.0, \"Danceability\": 0.819, \"Energy\": 0.835, \"Loudness\": -4.899, \"Speechiness\": 0.102, \"Acousticness\": 0.398, \"Liveness\": 0.252, \"Tempo\": 144.955, \"Duration (ms)\": 144264.0, \"Valence\": 0.703, \"Chord\": \"G#/Ab\"}, {\"Index\": 95, \"Highest Charting Position\": 75, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Ram Pam Pam\", \"Streams\": 7064003, \"Artist\": \"Natti Natasha, Becky G\", \"Artist Followers\": 6341942.0, \"Song ID\": \"4DHDIdeayp8xvlyg22wREO\", \"Genre\": \"['latin', 'latin pop', 'rap latina', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-04-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 86.0, \"Danceability\": 0.908, \"Energy\": 0.813, \"Loudness\": -2.749, \"Speechiness\": 0.0777, \"Acousticness\": 0.305, \"Liveness\": 0.278, \"Tempo\": 97.018, \"Duration (ms)\": 200785.0, \"Valence\": 0.924, \"Chord\": \"F\"}, {\"Index\": 96, \"Highest Charting Position\": 96, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"In Da Getto\", \"Streams\": 6984262, \"Artist\": \"J Balvin, Skrillex\", \"Artist Followers\": 1250353.0, \"Song ID\": \"5lGtPshEJlsJgmqKLi41LY\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 2.0, \"Danceability\": 0.915, \"Energy\": 0.72, \"Loudness\": -3.126, \"Speechiness\": 0.0459, \"Acousticness\": 0.025, \"Liveness\": 0.0942, \"Tempo\": 126.986, \"Duration (ms)\": 131067.0, \"Valence\": 0.631, \"Chord\": \"G#/Ab\"}, {\"Index\": 97, \"Highest Charting Position\": 97, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Woman\", \"Streams\": 6858466, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"6Uj1ctrBOjOas8xZXGqKk4\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-06-25--2021-07-02\", \"Popularity\": 86.0, \"Danceability\": 0.824, \"Energy\": 0.764, \"Loudness\": -4.175, \"Speechiness\": 0.0854, \"Acousticness\": 0.0888, \"Liveness\": 0.117, \"Tempo\": 107.998, \"Duration (ms)\": 172627.0, \"Valence\": 0.881, \"Chord\": \"F\"}, {\"Index\": 98, \"Highest Charting Position\": 60, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"t r a n s p a r e n t s o u l feat. Travis Barker\", \"Streams\": 6853994, \"Artist\": \"WILLOW\", \"Artist Followers\": 1521837.0, \"Song ID\": \"1QL7nSDZCwZMnbisV4KOXt\", \"Genre\": \"['afrofuturism', 'dance pop', 'electropop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2021-04-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 85.0, \"Danceability\": 0.39, \"Energy\": 0.83, \"Loudness\": -5.201, \"Speechiness\": 0.0563, \"Acousticness\": 0.0021, \"Liveness\": 0.156, \"Tempo\": 90.021, \"Duration (ms)\": 168030.0, \"Valence\": 0.191, \"Chord\": \"B\"}, {\"Index\": 99, \"Highest Charting Position\": 99, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Clash (feat. Stormzy)\", \"Streams\": 6825463, \"Artist\": \"Dave\", \"Artist Followers\": 1427540.0, \"Song ID\": \"2oUwMN5VfdGX10XeQJLBBi\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2021-07-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-09--2021-07-16\", \"Popularity\": 79.0, \"Danceability\": 0.871, \"Energy\": 0.519, \"Loudness\": -6.549, \"Speechiness\": 0.258, \"Acousticness\": 0.313, \"Liveness\": 0.0869, \"Tempo\": 140.013, \"Duration (ms)\": 251733.0, \"Valence\": 0.532, \"Chord\": \"D\"}, {\"Index\": 100, \"Highest Charting Position\": 22, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Before You Go\", \"Streams\": 6813800, \"Artist\": \"Lewis Capaldi\", \"Artist Followers\": 8384096.0, \"Song ID\": \"2gMXnyrvIjhVBUZwvLZDMP\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.459, \"Energy\": 0.575, \"Loudness\": -4.858, \"Speechiness\": 0.0573, \"Acousticness\": 0.604, \"Liveness\": 0.0885, \"Tempo\": 111.881, \"Duration (ms)\": 215107.0, \"Valence\": 0.183, \"Chord\": \"D#/Eb\"}, {\"Index\": 101, \"Highest Charting Position\": 52, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Levitating\", \"Streams\": 6799831, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"463CkQjx2Zk1yXoBuierM9\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-10-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 89.0, \"Danceability\": 0.702, \"Energy\": 0.825, \"Loudness\": -3.787, \"Speechiness\": 0.0601, \"Acousticness\": 0.00883, \"Liveness\": 0.0674, \"Tempo\": 102.977, \"Duration (ms)\": 203064.0, \"Valence\": 0.915, \"Chord\": \"F#/Gb\"}, {\"Index\": 102, \"Highest Charting Position\": 85, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Reckless\", \"Streams\": 6711375, \"Artist\": \"Madison Beer\", \"Artist Followers\": 3363988.0, \"Song ID\": \"5ajjAnNRh8bxFvaVHzpPjh\", \"Genre\": \"['alt z', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 86.0, \"Danceability\": 0.386, \"Energy\": 0.426, \"Loudness\": -6.642, \"Speechiness\": 0.0363, \"Acousticness\": 0.807, \"Liveness\": 0.14, \"Tempo\": 180.104, \"Duration (ms)\": 203385.0, \"Valence\": 0.261, \"Chord\": \"D#/Eb\"}, {\"Index\": 103, \"Highest Charting Position\": 103, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"No Me Conocen (Remix) [con DUKI, Rei & Tiago PZK]\", \"Streams\": 6709106, \"Artist\": \"BANDIDO\", \"Artist Followers\": 16074.0, \"Song ID\": \"7COGuXyTr12KvdaYXMqheC\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 85.0, \"Danceability\": 0.769, \"Energy\": 0.812, \"Loudness\": -2.088, \"Speechiness\": 0.0825, \"Acousticness\": 0.281, \"Liveness\": 0.0781, \"Tempo\": 180.003, \"Duration (ms)\": 280274.0, \"Valence\": 0.926, \"Chord\": \"C#/Db\"}, {\"Index\": 104, \"Highest Charting Position\": 88, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Believer\", \"Streams\": 6699895, \"Artist\": \"Imagine Dragons\", \"Artist Followers\": 35285425.0, \"Song ID\": \"0pqnGHJpmpxLKifKRmU6WP\", \"Genre\": \"['modern rock', 'pop', 'rock']\", \"Release Date\": \"2017-06-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.776, \"Energy\": 0.78, \"Loudness\": -4.374, \"Speechiness\": 0.128, \"Acousticness\": 0.0622, \"Liveness\": 0.081, \"Tempo\": 124.949, \"Duration (ms)\": 204347.0, \"Valence\": 0.666, \"Chord\": \"A#/Bb\"}, {\"Index\": 105, \"Highest Charting Position\": 2, \"Number of Times Charted\": 48, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Lemonade (feat. Gunna, Don Toliver & NAV)\", \"Streams\": 6697067, \"Artist\": \"Internet Money\", \"Artist Followers\": 411579.0, \"Song ID\": \"02kDW379Yfd5PzW5A6vuGt\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 82.0, \"Danceability\": 0.799, \"Energy\": 0.66, \"Loudness\": -6.153, \"Speechiness\": 0.079, \"Acousticness\": 0.256, \"Liveness\": 0.111, \"Tempo\": 140.04, \"Duration (ms)\": 195429.0, \"Valence\": 0.471, \"Chord\": \"C#/Db\"}, {\"Index\": 106, \"Highest Charting Position\": 45, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Talking to the Moon\", \"Streams\": 6660319, \"Artist\": \"Bruno Mars\", \"Artist Followers\": 32574754.0, \"Song ID\": \"161DnLWsx1i3u1JT05lzqU\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2010-10-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 83.0, \"Danceability\": 0.523, \"Energy\": 0.606, \"Loudness\": -4.754, \"Speechiness\": 0.0301, \"Acousticness\": 0.512, \"Liveness\": 0.106, \"Tempo\": 145.837, \"Duration (ms)\": 217867.0, \"Valence\": 0.065, \"Chord\": \"C#/Db\"}, {\"Index\": 107, \"Highest Charting Position\": 3, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Roses - Imanbek Remix\", \"Streams\": 6653690, \"Artist\": \"SAINt JHN\", \"Artist Followers\": 742692.0, \"Song ID\": \"0zLCBJZSiELJf02ucPP9wb\", \"Genre\": \"['melodic rap', 'pop rap', 'rap', 'slap house', 'trap']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.769, \"Energy\": 0.719, \"Loudness\": -5.472, \"Speechiness\": 0.0474, \"Acousticness\": 0.0143, \"Liveness\": 0.359, \"Tempo\": 121.955, \"Duration (ms)\": 176867.0, \"Valence\": 0.863, \"Chord\": \"G#/Ab\"}, {\"Index\": 108, \"Highest Charting Position\": 59, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Sal y Perrea\", \"Streams\": 6635076, \"Artist\": \"Sech\", \"Artist Followers\": 8758283.0, \"Song ID\": \"5u7twkeask1VIyDeNTElSU\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-04-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 86.0, \"Danceability\": 0.786, \"Energy\": 0.899, \"Loudness\": -0.515, \"Speechiness\": 0.127, \"Acousticness\": 0.192, \"Liveness\": 0.299, \"Tempo\": 90.025, \"Duration (ms)\": 216510.0, \"Valence\": 0.813, \"Chord\": \"A#/Bb\"}, {\"Index\": 109, \"Highest Charting Position\": 109, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Fulanito\", \"Streams\": 6614072, \"Artist\": \"Becky G, El Alfa\", \"Artist Followers\": 10356559.0, \"Song ID\": \"59L8x0xy8njj75vzVCPMqg\", \"Genre\": \"['dance pop', 'latin', 'latin pop', 'latin viral pop', 'pop', 'rap latina', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 86.0, \"Danceability\": 0.93, \"Energy\": 0.837, \"Loudness\": -4.632, \"Speechiness\": 0.187, \"Acousticness\": 0.256, \"Liveness\": 0.239, \"Tempo\": 111.898, \"Duration (ms)\": 158532.0, \"Valence\": 0.821, \"Chord\": \"G\"}, {\"Index\": 110, \"Highest Charting Position\": 110, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Par\\u00eds\", \"Streams\": 6584896, \"Artist\": \"Ingratax\", \"Artist Followers\": 56699.0, \"Song ID\": \"4bF2y8rR7GUjrd5LNEvej3\", \"Genre\": \"[]\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 86.0, \"Danceability\": 0.57, \"Energy\": 0.455, \"Loudness\": -5.748, \"Speechiness\": 0.0996, \"Acousticness\": 0.441, \"Liveness\": 0.0654, \"Tempo\": 167.933, \"Duration (ms)\": 151429.0, \"Valence\": 0.399, \"Chord\": \"C#/Db\"}, {\"Index\": 111, \"Highest Charting Position\": 46, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"lovely (with Khalid)\", \"Streams\": 6569547, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47014200.0, \"Song ID\": \"0u2P5u6lvoDfwTYjAADbn4\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2018-04-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.351, \"Energy\": 0.296, \"Loudness\": -10.109, \"Speechiness\": 0.0333, \"Acousticness\": 0.934, \"Liveness\": 0.095, \"Tempo\": 115.284, \"Duration (ms)\": 200186.0, \"Valence\": 0.12, \"Chord\": \"E\"}, {\"Index\": 112, \"Highest Charting Position\": 24, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Sunflower - Spider-Man: Into the Spider-Verse\", \"Streams\": 6546948, \"Artist\": \"Post Malone, Swae Lee\", \"Artist Followers\": 1250353.0, \"Song ID\": \"3KkXRkHbMCARz0aVfEt68P\", \"Genre\": \"[]\", \"Release Date\": \"2018-12-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.76, \"Energy\": 0.479, \"Loudness\": -5.574, \"Speechiness\": 0.0466, \"Acousticness\": 0.556, \"Liveness\": 0.0703, \"Tempo\": 89.911, \"Duration (ms)\": 158040.0, \"Valence\": 0.913, \"Chord\": \"D\"}, {\"Index\": 113, \"Highest Charting Position\": 113, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"double take\", \"Streams\": 6539852, \"Artist\": \"dhruv\", \"Artist Followers\": 73211.0, \"Song ID\": \"2CVChktEKBsM6v4IfdFU5k\", \"Genre\": \"['chill r&b', 'nyc pop']\", \"Release Date\": \"2019-05-24\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 86.0, \"Danceability\": 0.663, \"Energy\": 0.434, \"Loudness\": -11.177, \"Speechiness\": 0.0648, \"Acousticness\": 0.828, \"Liveness\": 0.249, \"Tempo\": 109.075, \"Duration (ms)\": 171743.0, \"Valence\": 0.225, \"Chord\": \"G#/Ab\"}, {\"Index\": 114, \"Highest Charting Position\": 9, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Streets\", \"Streams\": 6502302, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"60ynsPSSKe6O3sfwRnIBRf\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 86.0, \"Danceability\": 0.749, \"Energy\": 0.463, \"Loudness\": -8.433, \"Speechiness\": 0.0842, \"Acousticness\": 0.21, \"Liveness\": 0.338, \"Tempo\": 90.035, \"Duration (ms)\": 226987.0, \"Valence\": 0.189, \"Chord\": \"B\"}, {\"Index\": 115, \"Highest Charting Position\": 80, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"By Your Side (feat. Tom Grennan)\", \"Streams\": 6488622, \"Artist\": \"Calvin Harris\", \"Artist Followers\": 21942793.0, \"Song ID\": \"0vR2rIVORmgeKiGIgNT0fV\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'house', 'pop', 'progressive house', 'uk dance']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 85.0, \"Danceability\": 0.733, \"Energy\": 0.96, \"Loudness\": -3.597, \"Speechiness\": 0.0295, \"Acousticness\": 0.0514, \"Liveness\": 0.287, \"Tempo\": 124.01, \"Duration (ms)\": 189672.0, \"Valence\": 0.811, \"Chord\": \"G\"}, {\"Index\": 116, \"Highest Charting Position\": 116, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"MORENA\", \"Streams\": 6469500, \"Artist\": \"Luan Santana\", \"Artist Followers\": 5420471.0, \"Song ID\": \"4PQdrXMDHDPl1RczrrlADd\", \"Genre\": \"['sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2021-06-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 85.0, \"Danceability\": 0.526, \"Energy\": 0.731, \"Loudness\": -4.662, \"Speechiness\": 0.0887, \"Acousticness\": 0.18, \"Liveness\": 0.0891, \"Tempo\": 86.959, \"Duration (ms)\": 193221.0, \"Valence\": 0.476, \"Chord\": \"B\"}, {\"Index\": 117, \"Highest Charting Position\": 80, \"Number of Times Charted\": 80, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Shape of You\", \"Streams\": 6452492, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83293380.0, \"Song ID\": \"7qiZfU4dY1lWllzX7mPBI3\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2017-03-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.825, \"Energy\": 0.652, \"Loudness\": -3.183, \"Speechiness\": 0.0802, \"Acousticness\": 0.581, \"Liveness\": 0.0931, \"Tempo\": 95.977, \"Duration (ms)\": 233713.0, \"Valence\": 0.931, \"Chord\": \"C#/Db\"}, {\"Index\": 118, \"Highest Charting Position\": 9, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Se\\u00f1orita\", \"Streams\": 6317487, \"Artist\": \"Shawn Mendes, Camila Cabello\", \"Artist Followers\": 33879560.0, \"Song ID\": \"0TK2YIli7K1leLovkQiNik\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.759, \"Energy\": 0.54, \"Loudness\": -6.039, \"Speechiness\": 0.0287, \"Acousticness\": 0.037, \"Liveness\": 0.0945, \"Tempo\": 116.947, \"Duration (ms)\": 190960.0, \"Valence\": 0.75, \"Chord\": \"A\"}, {\"Index\": 119, \"Highest Charting Position\": 5, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Hold On\", \"Streams\": 6300416, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 1250353.0, \"Song ID\": \"49xx65gvlD7xXjDTavFqaJ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 0.0, \"Danceability\": 0.658, \"Energy\": 0.634, \"Loudness\": -5.797, \"Speechiness\": 0.0413, \"Acousticness\": 0.0106, \"Liveness\": 0.132, \"Tempo\": 139.98, \"Duration (ms)\": 170813.0, \"Valence\": 0.29, \"Chord\": \"C#/Db\"}, {\"Index\": 120, \"Highest Charting Position\": 99, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Perfect\", \"Streams\": 6278765, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83293380.0, \"Song ID\": \"0tgVpDi06FyKpA1z0VMD4v\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2017-03-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.599, \"Energy\": 0.448, \"Loudness\": -6.312, \"Speechiness\": 0.0232, \"Acousticness\": 0.163, \"Liveness\": 0.106, \"Tempo\": 95.05, \"Duration (ms)\": 263400.0, \"Valence\": 0.168, \"Chord\": \"G#/Ab\"}, {\"Index\": 121, \"Highest Charting Position\": 80, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"2:50 Remix\", \"Streams\": 6244011, \"Artist\": \"MYA, TINI, Duki\", \"Artist Followers\": 282045.0, \"Song ID\": \"74znaWw1hmQBusGPSOuTFy\", \"Genre\": \"['latin pop']\", \"Release Date\": \"2021-06-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 85.0, \"Danceability\": 0.818, \"Energy\": 0.812, \"Loudness\": -4.425, \"Speechiness\": 0.0475, \"Acousticness\": 0.112, \"Liveness\": 0.234, \"Tempo\": 139.966, \"Duration (ms)\": 231708.0, \"Valence\": 0.844, \"Chord\": \"A\"}, {\"Index\": 122, \"Highest Charting Position\": 2, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"LA NOCHE DE ANOCHE\", \"Streams\": 6242863, \"Artist\": \"Bad Bunny, ROSAL\\u00cdA\", \"Artist Followers\": 36142273.0, \"Song ID\": \"2XIc1pqjXV3Cr2BQUGNBck\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 86.0, \"Danceability\": 0.856, \"Energy\": 0.618, \"Loudness\": -4.892, \"Speechiness\": 0.286, \"Acousticness\": 0.0303, \"Liveness\": 0.0866, \"Tempo\": 81.993, \"Duration (ms)\": 203201.0, \"Valence\": 0.391, \"Chord\": \"G\"}, {\"Index\": 123, \"Highest Charting Position\": 1, \"Number of Times Charted\": 67, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"ROCKSTAR (feat. Roddy Ricch)\", \"Streams\": 6180056, \"Artist\": \"DaBaby\", \"Artist Followers\": 7593046.0, \"Song ID\": \"7ytR5pFWmSjzHJIeQkgog4\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 86.0, \"Danceability\": 0.746, \"Energy\": 0.69, \"Loudness\": -7.956, \"Speechiness\": 0.164, \"Acousticness\": 0.247, \"Liveness\": 0.101, \"Tempo\": 89.977, \"Duration (ms)\": 181733.0, \"Valence\": 0.497, \"Chord\": \"B\"}, {\"Index\": 124, \"Highest Charting Position\": 12, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Heather\", \"Streams\": 6164795, \"Artist\": \"Conan Gray\", \"Artist Followers\": 3794081.0, \"Song ID\": \"4xqrdfXkTW4T0RauPLv3WA\", \"Genre\": \"['alt z', 'bedroom pop', 'electropop', 'indie pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 86.0, \"Danceability\": 0.357, \"Energy\": 0.425, \"Loudness\": -7.301, \"Speechiness\": 0.0333, \"Acousticness\": 0.584, \"Liveness\": 0.322, \"Tempo\": 102.078, \"Duration (ms)\": 198040.0, \"Valence\": 0.27, \"Chord\": \"F\"}, {\"Index\": 125, \"Highest Charting Position\": 13, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"you broke me first\", \"Streams\": 6152121, \"Artist\": \"Tate McRae\", \"Artist Followers\": 1647262.0, \"Song ID\": \"45bE4HXI0AwGZXfZtMp8JR\", \"Genre\": \"['alt z', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 86.0, \"Danceability\": 0.667, \"Energy\": 0.373, \"Loudness\": -9.389, \"Speechiness\": 0.05, \"Acousticness\": 0.785, \"Liveness\": 0.0906, \"Tempo\": 124.148, \"Duration (ms)\": 169266.0, \"Valence\": 0.0823, \"Chord\": \"E\"}, {\"Index\": 126, \"Highest Charting Position\": 126, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"The Nights\", \"Streams\": 6136340, \"Artist\": \"Avicii\", \"Artist Followers\": 20270895.0, \"Song ID\": \"0ct6r3EGTcMLPtrXHDvVjc\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance']\", \"Release Date\": \"2014-01-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 85.0, \"Danceability\": 0.527, \"Energy\": 0.835, \"Loudness\": -5.298, \"Speechiness\": 0.0433, \"Acousticness\": 0.0166, \"Liveness\": 0.249, \"Tempo\": 125.983, \"Duration (ms)\": 176658.0, \"Valence\": 0.654, \"Chord\": \"F#/Gb\"}, {\"Index\": 127, \"Highest Charting Position\": 122, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Riptide\", \"Streams\": 6089242, \"Artist\": \"Vance Joy\", \"Artist Followers\": 2421254.0, \"Song ID\": \"3JvrhDOgAt6p7K8mDyZwRd\", \"Genre\": \"['folk-pop', 'modern rock', 'pop', 'pop rock']\", \"Release Date\": \"2014-09-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 78.0, \"Danceability\": 0.484, \"Energy\": 0.731, \"Loudness\": -6.694, \"Speechiness\": 0.0379, \"Acousticness\": 0.431, \"Liveness\": 0.151, \"Tempo\": 101.654, \"Duration (ms)\": 204280.0, \"Valence\": 0.51, \"Chord\": \"C#/Db\"}, {\"Index\": 128, \"Highest Charting Position\": 128, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Smells Like Teen Spirit\", \"Streams\": 6065267, \"Artist\": \"Nirvana\", \"Artist Followers\": 13261089.0, \"Song ID\": \"5ghIJDpPoe3CfHMGu71E6T\", \"Genre\": \"['grunge', 'permanent wave', 'rock']\", \"Release Date\": \"1991-09-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\", \"Popularity\": 77.0, \"Danceability\": 0.502, \"Energy\": 0.912, \"Loudness\": -4.556, \"Speechiness\": 0.0564, \"Acousticness\": 2.55e-05, \"Liveness\": 0.106, \"Tempo\": 116.761, \"Duration (ms)\": 301920.0, \"Valence\": 0.72, \"Chord\": \"C#/Db\"}, {\"Index\": 129, \"Highest Charting Position\": 11, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"enough for you\", \"Streams\": 6040918, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"2TOzTqQXNmR2zDJXihjZ2e\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 86.0, \"Danceability\": 0.638, \"Energy\": 0.259, \"Loudness\": -10.706, \"Speechiness\": 0.0898, \"Acousticness\": 0.753, \"Liveness\": 0.219, \"Tempo\": 88.485, \"Duration (ms)\": 202827.0, \"Valence\": 0.269, \"Chord\": \"G\"}, {\"Index\": 130, \"Highest Charting Position\": 99, \"Number of Times Charted\": 42, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Daddy Issues\", \"Streams\": 6014443, \"Artist\": \"The Neighbourhood\", \"Artist Followers\": 6662605.0, \"Song ID\": \"5E30LdtzQTGqRvNd7l6kG5\", \"Genre\": \"['modern alternative rock', 'modern rock', 'pop']\", \"Release Date\": \"2015-10-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 85.0, \"Danceability\": 0.588, \"Energy\": 0.521, \"Loudness\": -9.461, \"Speechiness\": 0.0329, \"Acousticness\": 0.0678, \"Liveness\": 0.123, \"Tempo\": 85.012, \"Duration (ms)\": 260173.0, \"Valence\": 0.337, \"Chord\": \"A#/Bb\"}, {\"Index\": 131, \"Highest Charting Position\": 131, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Aquelas Coisas\", \"Streams\": 6012839, \"Artist\": \"Jo\\u00e3o Gomes\", \"Artist Followers\": 409173.0, \"Song ID\": \"0FqVtQxRD3HsPltldG5v5M\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 84.0, \"Danceability\": 0.682, \"Energy\": 0.873, \"Loudness\": -4.163, \"Speechiness\": 0.0449, \"Acousticness\": 0.402, \"Liveness\": 0.0946, \"Tempo\": 150.006, \"Duration (ms)\": 147072.0, \"Valence\": 0.964, \"Chord\": \"F#/Gb\"}, {\"Index\": 132, \"Highest Charting Position\": 19, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Miss The Rage (feat. Playboi Carti)\", \"Streams\": 5952490, \"Artist\": \"Trippie Redd\", \"Artist Followers\": 6430522.0, \"Song ID\": \"2BITQ360Knh6qNAOqR7Dyq\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2021-05-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 85.0, \"Danceability\": 0.584, \"Energy\": 0.859, \"Loudness\": -5.616, \"Speechiness\": 0.121, \"Acousticness\": 0.0144, \"Liveness\": 0.847, \"Tempo\": 77.005, \"Duration (ms)\": 236883.0, \"Valence\": 0.369, \"Chord\": \"G#/Ab\"}, {\"Index\": 133, \"Highest Charting Position\": 4, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Memories\", \"Streams\": 5928329, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32262679.0, \"Song ID\": \"4cktbXiXOapiLBMprHFErI\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.775, \"Energy\": 0.327, \"Loudness\": -7.241, \"Speechiness\": 0.0557, \"Acousticness\": 0.841, \"Liveness\": 0.0821, \"Tempo\": 91.05, \"Duration (ms)\": 189486.0, \"Valence\": 0.595, \"Chord\": \"B\"}, {\"Index\": 134, \"Highest Charting Position\": 76, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Another Love\", \"Streams\": 5914661, \"Artist\": \"Tom Odell\", \"Artist Followers\": 1838616.0, \"Song ID\": \"7otCGmgp9h4CsR2LhwB6gt\", \"Genre\": \"['pop']\", \"Release Date\": \"2013-09-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 67.0, \"Danceability\": 0.445, \"Energy\": 0.537, \"Loudness\": -8.532, \"Speechiness\": 0.04, \"Acousticness\": 0.695, \"Liveness\": 0.0941, \"Tempo\": 122.764, \"Duration (ms)\": 244360.0, \"Valence\": 0.131, \"Chord\": \"E\"}, {\"Index\": 135, \"Highest Charting Position\": 135, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Here's Your Perfect\", \"Streams\": 5912784, \"Artist\": \"Jamie Miller\", \"Artist Followers\": 64288.0, \"Song ID\": \"2aTKrdenCq5qBOoJPFdn4P\", \"Genre\": \"['pop soul']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 85.0, \"Danceability\": 0.558, \"Energy\": 0.454, \"Loudness\": -5.335, \"Speechiness\": 0.0551, \"Acousticness\": 0.499, \"Liveness\": 0.146, \"Tempo\": 113.12, \"Duration (ms)\": 158594.0, \"Valence\": 0.424, \"Chord\": \"F#/Gb\"}, {\"Index\": 136, \"Highest Charting Position\": 108, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Take Me To Church\", \"Streams\": 5907750, \"Artist\": \"Hozier\", \"Artist Followers\": 4781906.0, \"Song ID\": \"1CS7Sd1u5tWkstBhpssyjP\", \"Genre\": \"['irish singer-songwriter', 'modern rock', 'pop']\", \"Release Date\": \"2014-09-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 74.0, \"Danceability\": 0.566, \"Energy\": 0.664, \"Loudness\": -5.303, \"Speechiness\": 0.0464, \"Acousticness\": 0.634, \"Liveness\": 0.116, \"Tempo\": 128.945, \"Duration (ms)\": 241693.0, \"Valence\": 0.437, \"Chord\": \"E\"}, {\"Index\": 137, \"Highest Charting Position\": 110, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Little Bit of Love\", \"Streams\": 5848466, \"Artist\": \"Tom Grennan\", \"Artist Followers\": 261225.0, \"Song ID\": \"2sX7lJXsOYGP1Us6CqM9t1\", \"Genre\": \"['modern rock', 'uk pop']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 80.0, \"Danceability\": 0.689, \"Energy\": 0.706, \"Loudness\": -4.48, \"Speechiness\": 0.0312, \"Acousticness\": 0.0833, \"Liveness\": 0.105, \"Tempo\": 106.52, \"Duration (ms)\": 226268.0, \"Valence\": 0.623, \"Chord\": \"C#/Db\"}, {\"Index\": 138, \"Highest Charting Position\": 138, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Ficha Limpa\", \"Streams\": 5847975, \"Artist\": \"Gusttavo Lima\", \"Artist Followers\": 12969190.0, \"Song ID\": \"5SwyN9hzmWjBsINlif8li8\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2021-06-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 85.0, \"Danceability\": 0.774, \"Energy\": 0.732, \"Loudness\": -4.227, \"Speechiness\": 0.0308, \"Acousticness\": 0.108, \"Liveness\": 0.243, \"Tempo\": 135.005, \"Duration (ms)\": 192725.0, \"Valence\": 0.734, \"Chord\": \"A\"}, {\"Index\": 139, \"Highest Charting Position\": 14, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Up\", \"Streams\": 5845156, \"Artist\": \"Cardi B\", \"Artist Followers\": 17353707.0, \"Song ID\": \"1XXimziG1uhM0eDNCZCrUl\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'rap']\", \"Release Date\": \"2021-02-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 83.0, \"Danceability\": 0.868, \"Energy\": 0.795, \"Loudness\": -6.044, \"Speechiness\": 0.269, \"Acousticness\": 0.0012, \"Liveness\": 0.0461, \"Tempo\": 166.0, \"Duration (ms)\": 156945.0, \"Valence\": 0.819, \"Chord\": \"B\"}, {\"Index\": 140, \"Highest Charting Position\": 2, \"Number of Times Charted\": 52, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Haw\\u00e1i\", \"Streams\": 5769714, \"Artist\": \"Maluma\", \"Artist Followers\": 26769304.0, \"Song ID\": \"0GzuHFG4Ql6DoyxFRnIk3F\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-11-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 77.0, \"Danceability\": 0.766, \"Energy\": 0.788, \"Loudness\": -3.128, \"Speechiness\": 0.312, \"Acousticness\": 0.105, \"Liveness\": 0.142, \"Tempo\": 179.984, \"Duration (ms)\": 200482.0, \"Valence\": 0.609, \"Chord\": \"F#/Gb\"}, {\"Index\": 141, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"New Normal\", \"Streams\": 5768653, \"Artist\": \"Khalid\", \"Artist Followers\": 14187747.0, \"Song ID\": \"2CIYemjFXdmCWpJnfbtrD6\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-07-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 79.0, \"Danceability\": 0.39, \"Energy\": 0.534, \"Loudness\": -9.575, \"Speechiness\": 0.0709, \"Acousticness\": 0.0807, \"Liveness\": 0.184, \"Tempo\": 92.047, \"Duration (ms)\": 198765.0, \"Valence\": 0.244, \"Chord\": \"C\"}, {\"Index\": 142, \"Highest Charting Position\": 81, \"Number of Times Charted\": 81, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Bohemian Rhapsody - Remastered 2011\", \"Streams\": 5756583, \"Artist\": \"Queen\", \"Artist Followers\": 35888760.0, \"Song ID\": \"7tFiyTwD0nx5a1eklYtX2J\", \"Genre\": \"['classic rock', 'glam rock', 'rock']\", \"Release Date\": \"1975-11-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.392, \"Energy\": 0.402, \"Loudness\": -9.961, \"Speechiness\": 0.0536, \"Acousticness\": 0.288, \"Liveness\": 0.243, \"Tempo\": 143.883, \"Duration (ms)\": 354320.0, \"Valence\": 0.228, \"Chord\": \"C\"}, {\"Index\": 143, \"Highest Charting Position\": 5, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Bandido\", \"Streams\": 5734402, \"Artist\": \"Myke Towers, Juhn\", \"Artist Followers\": 6150675.0, \"Song ID\": \"1xK1Gg9SxG8fy2Ya373oqb\", \"Genre\": \"['trap latino']\", \"Release Date\": \"2020-12-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\", \"Popularity\": 85.0, \"Danceability\": 0.713, \"Energy\": 0.617, \"Loudness\": -4.637, \"Speechiness\": 0.0887, \"Acousticness\": 0.122, \"Liveness\": 0.0962, \"Tempo\": 168.021, \"Duration (ms)\": 232853.0, \"Valence\": 0.682, \"Chord\": \"G#/Ab\"}, {\"Index\": 144, \"Highest Charting Position\": 25, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Paradise (feat. Dermot Kennedy)\", \"Streams\": 5693848, \"Artist\": \"MEDUZA\", \"Artist Followers\": 441674.0, \"Song ID\": \"6ft4hAq6yde8jPZY2i5zLr\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop house', 'tropical house']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 85.0, \"Danceability\": 0.632, \"Energy\": 0.595, \"Loudness\": -7.644, \"Speechiness\": 0.0401, \"Acousticness\": 0.0689, \"Liveness\": 0.209, \"Tempo\": 124.114, \"Duration (ms)\": 167903.0, \"Valence\": 0.435, \"Chord\": \"G#/Ab\"}, {\"Index\": 145, \"Highest Charting Position\": 13, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"goosebumps\", \"Streams\": 5691540, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17719446.0, \"Song ID\": \"5uEYRdEIh9Bo4fpjDd4Na9\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 87.0, \"Danceability\": 0.841, \"Energy\": 0.593, \"Loudness\": -7.846, \"Speechiness\": 0.0379, \"Acousticness\": 0.418, \"Liveness\": 0.124, \"Tempo\": 124.917, \"Duration (ms)\": 162803.0, \"Valence\": 0.808, \"Chord\": \"C#/Db\"}, {\"Index\": 146, \"Highest Charting Position\": 90, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Wasted Love (feat. Lagique)\", \"Streams\": 5690260, \"Artist\": \"Ofenbach\", \"Artist Followers\": 432581.0, \"Song ID\": \"2pPO9YecZimmuVQfIzfV6U\", \"Genre\": \"['edm', 'new french touch', 'pop dance', 'tropical house']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 85.0, \"Danceability\": 0.734, \"Energy\": 0.855, \"Loudness\": -4.578, \"Speechiness\": 0.135, \"Acousticness\": 0.0821, \"Liveness\": 0.0901, \"Tempo\": 121.955, \"Duration (ms)\": 139563.0, \"Valence\": 0.54, \"Chord\": \"F#/Gb\"}, {\"Index\": 147, \"Highest Charting Position\": 100, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"KESI - Remix\", \"Streams\": 5682062, \"Artist\": \"Camilo, Shawn Mendes\", \"Artist Followers\": 10561047.0, \"Song ID\": \"0IqCoZ168iRc9LqfrYgpZy\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2021-07-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 83.0, \"Danceability\": 0.871, \"Energy\": 0.815, \"Loudness\": -4.439, \"Speechiness\": 0.0477, \"Acousticness\": 0.127, \"Liveness\": 0.094, \"Tempo\": 122.959, \"Duration (ms)\": 176575.0, \"Valence\": 0.823, \"Chord\": \"E\"}, {\"Index\": 148, \"Highest Charting Position\": 59, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Shallow\", \"Streams\": 5672480, \"Artist\": \"Lady Gaga, Bradley Cooper\", \"Artist Followers\": 18572085.0, \"Song ID\": \"2VxeLyX666F8uXCJ0dZF8B\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-10-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.572, \"Energy\": 0.385, \"Loudness\": -6.362, \"Speechiness\": 0.0308, \"Acousticness\": 0.371, \"Liveness\": 0.231, \"Tempo\": 95.799, \"Duration (ms)\": 215733.0, \"Valence\": 0.323, \"Chord\": \"G\"}, {\"Index\": 149, \"Highest Charting Position\": 110, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Tell Em\", \"Streams\": 5668576, \"Artist\": \"Cochise, $NOT\", \"Artist Followers\": 159647.0, \"Song ID\": \"7nc7mlSdWYeFom84zZ8Wr8\", \"Genre\": \"['plugg', 'vapor trap', 'viral rap']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\", \"Popularity\": 85.0, \"Danceability\": 0.672, \"Energy\": 0.717, \"Loudness\": -7.476, \"Speechiness\": 0.226, \"Acousticness\": 0.103, \"Liveness\": 0.398, \"Tempo\": 157.905, \"Duration (ms)\": 180380.0, \"Valence\": 0.473, \"Chord\": \"F\"}, {\"Index\": 150, \"Highest Charting Position\": 103, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"N\\u00e3o, N\\u00e3o Vou\", \"Streams\": 5652272, \"Artist\": \"Mari Fernandez\", \"Artist Followers\": 15889.0, \"Song ID\": \"0xBQvhJAm6f7J142ympKOn\", \"Genre\": \"[]\", \"Release Date\": \"2021-04-29\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.631, \"Energy\": 0.861, \"Loudness\": -1.891, \"Speechiness\": 0.0424, \"Acousticness\": 0.427, \"Liveness\": 0.215, \"Tempo\": 149.95, \"Duration (ms)\": 173038.0, \"Valence\": 0.822, \"Chord\": \"B\"}, {\"Index\": 151, \"Highest Charting Position\": 147, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Counting Stars\", \"Streams\": 5647568, \"Artist\": \"OneRepublic\", \"Artist Followers\": 12169108.0, \"Song ID\": \"6sy3LkhNFjJWlaeSMNwQ62\", \"Genre\": \"['dance pop', 'piano rock', 'pop', 'pop rock']\", \"Release Date\": \"2014-01-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 74.0, \"Danceability\": 0.664, \"Energy\": 0.705, \"Loudness\": -4.972, \"Speechiness\": 0.0382, \"Acousticness\": 0.0654, \"Liveness\": 0.115, \"Tempo\": 122.017, \"Duration (ms)\": 257840.0, \"Valence\": 0.477, \"Chord\": \"C#/Db\"}, {\"Index\": 152, \"Highest Charting Position\": 121, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Yellow\", \"Streams\": 5628703, \"Artist\": \"Coldplay\", \"Artist Followers\": 31151294.0, \"Song ID\": \"3AJwUDP919kvQ9QcozQPxg\", \"Genre\": \"['permanent wave', 'pop']\", \"Release Date\": \"2000-07-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 85.0, \"Danceability\": 0.429, \"Energy\": 0.661, \"Loudness\": -7.227, \"Speechiness\": 0.0281, \"Acousticness\": 0.00239, \"Liveness\": 0.234, \"Tempo\": 173.372, \"Duration (ms)\": 266773.0, \"Valence\": 0.285, \"Chord\": \"B\"}, {\"Index\": 153, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Como Si No Importara\", \"Streams\": 5627257, \"Artist\": \"Emilia, Duki\", \"Artist Followers\": 205590.0, \"Song ID\": \"1GYJpuLq41vEVKXiHGEY9j\", \"Genre\": \"[]\", \"Release Date\": \"2021-07-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 83.0, \"Danceability\": 0.843, \"Energy\": 0.534, \"Loudness\": -6.658, \"Speechiness\": 0.142, \"Acousticness\": 0.467, \"Liveness\": 0.0984, \"Tempo\": 94.984, \"Duration (ms)\": 173053.0, \"Valence\": 0.528, \"Chord\": \"C#/Db\"}, {\"Index\": 154, \"Highest Charting Position\": 154, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Se For Amor\", \"Streams\": 5618268, \"Artist\": \"Jo\\u00e3o Gomes, Vitor Fernandes\", \"Artist Followers\": 409173.0, \"Song ID\": \"5F2xRvRFkxDvqdFtUNAEyw\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 81.0, \"Danceability\": 0.667, \"Energy\": 0.899, \"Loudness\": -4.402, \"Speechiness\": 0.0322, \"Acousticness\": 0.423, \"Liveness\": 0.332, \"Tempo\": 147.962, \"Duration (ms)\": 239928.0, \"Valence\": 0.835, \"Chord\": \"B\"}, {\"Index\": 155, \"Highest Charting Position\": 142, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Wake Me Up\", \"Streams\": 5607285, \"Artist\": \"Avicii\", \"Artist Followers\": 20270895.0, \"Song ID\": \"0nrRP2bk19rLc0orkWPQk2\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance']\", \"Release Date\": \"2013-01-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-01--2021-01-08\\n2020-08-07--2020-08-14\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.532, \"Energy\": 0.783, \"Loudness\": -5.697, \"Speechiness\": 0.0523, \"Acousticness\": 0.0038, \"Liveness\": 0.161, \"Tempo\": 124.08, \"Duration (ms)\": 247427.0, \"Valence\": 0.643, \"Chord\": \"D\"}, {\"Index\": 156, \"Highest Charting Position\": 128, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Baby Me Atende\", \"Streams\": 5594505, \"Artist\": \"Matheus Fernandes, Dilsinho\", \"Artist Followers\": 77034.0, \"Song ID\": \"5R9KPXQVeyqsHZoPLMgfNy\", \"Genre\": \"['forro', 'sertanejo pop']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 83.0, \"Danceability\": 0.65, \"Energy\": 0.792, \"Loudness\": -3.825, \"Speechiness\": 0.0393, \"Acousticness\": 0.607, \"Liveness\": 0.92, \"Tempo\": 154.027, \"Duration (ms)\": 225672.0, \"Valence\": 0.872, \"Chord\": \"F#/Gb\"}, {\"Index\": 157, \"Highest Charting Position\": 68, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Ramenez la coupe \\u00e0 la maison\", \"Streams\": 5576844, \"Artist\": \"Vegedream\", \"Artist Followers\": 1250353.0, \"Song ID\": \"0dqVP9CnGjaYNjya3gYbYy\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 0.0, \"Danceability\": 0.808, \"Energy\": 0.66, \"Loudness\": -6.237, \"Speechiness\": 0.0395, \"Acousticness\": 0.0358, \"Liveness\": 0.138, \"Tempo\": 107.994, \"Duration (ms)\": 235556.0, \"Valence\": 0.804, \"Chord\": \"C\"}, {\"Index\": 158, \"Highest Charting Position\": 6, \"Number of Times Charted\": 47, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"What You Know Bout Love\", \"Streams\": 5570735, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"1tkg4EHVoqnhR6iFEXb60y\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-07-03--2020-07-10\", \"Popularity\": 85.0, \"Danceability\": 0.709, \"Energy\": 0.548, \"Loudness\": -8.493, \"Speechiness\": 0.353, \"Acousticness\": 0.65, \"Liveness\": 0.133, \"Tempo\": 83.995, \"Duration (ms)\": 160000.0, \"Valence\": 0.543, \"Chord\": \"A#/Bb\"}, {\"Index\": 159, \"Highest Charting Position\": 19, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Runaway\", \"Streams\": 5566150, \"Artist\": \"AURORA\", \"Artist Followers\": 1687399.0, \"Song ID\": \"0TCmhnbMpw5zwPsTvlXTJi\", \"Genre\": \"['art pop', 'norwegian pop']\", \"Release Date\": \"2014\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 77.0, \"Danceability\": 0.521, \"Energy\": 0.277, \"Loudness\": -10.34, \"Speechiness\": 0.0356, \"Acousticness\": 0.634, \"Liveness\": 0.103, \"Tempo\": 115.01, \"Duration (ms)\": 248827.0, \"Valence\": 0.13, \"Chord\": \"B\"}, {\"Index\": 160, \"Highest Charting Position\": 121, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Red Light Green Light\", \"Streams\": 5493760, \"Artist\": \"DaBaby\", \"Artist Followers\": 7593046.0, \"Song ID\": \"1YDebgap5OFwXEBG18NJvy\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.933, \"Energy\": 0.656, \"Loudness\": -5.85, \"Speechiness\": 0.322, \"Acousticness\": 0.129, \"Liveness\": 0.161, \"Tempo\": 119.987, \"Duration (ms)\": 159083.0, \"Valence\": 0.934, \"Chord\": \"D\"}, {\"Index\": 161, \"Highest Charting Position\": 120, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Ball If I Want To\", \"Streams\": 5478055, \"Artist\": \"DaBaby\", \"Artist Followers\": 7593046.0, \"Song ID\": \"0cu0rhnlCnJ7JIeHRiLpj3\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\", \"Popularity\": 84.0, \"Danceability\": 0.902, \"Energy\": 0.669, \"Loudness\": -5.049, \"Speechiness\": 0.457, \"Acousticness\": 0.161, \"Liveness\": 0.0728, \"Tempo\": 139.949, \"Duration (ms)\": 112547.0, \"Valence\": 0.628, \"Chord\": \"C#/Db\"}, {\"Index\": 162, \"Highest Charting Position\": 31, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lucid Dreams\", \"Streams\": 5477563, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"285pBltuF7vW8TeWk8hdRR\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2018-12-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.511, \"Energy\": 0.566, \"Loudness\": -7.23, \"Speechiness\": 0.2, \"Acousticness\": 0.349, \"Liveness\": 0.34, \"Tempo\": 83.903, \"Duration (ms)\": 239836.0, \"Valence\": 0.218, \"Chord\": \"F#/Gb\"}, {\"Index\": 163, \"Highest Charting Position\": 4, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Calling My Phone\", \"Streams\": 5467753, \"Artist\": \"Lil Tjay, 6LACK\", \"Artist Followers\": 3553442.0, \"Song ID\": \"3J8EOeKLTLXORtWPpOU5bE\", \"Genre\": \"['brooklyn drill', 'melodic rap', 'nyc rap']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 85.0, \"Danceability\": 0.907, \"Energy\": 0.393, \"Loudness\": -7.636, \"Speechiness\": 0.0539, \"Acousticness\": 0.451, \"Liveness\": 0.135, \"Tempo\": 104.949, \"Duration (ms)\": 205458.0, \"Valence\": 0.202, \"Chord\": \"E\"}, {\"Index\": 164, \"Highest Charting Position\": 5, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"34+35\", \"Streams\": 5453159, \"Artist\": \"Ariana Grande\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 165, \"Highest Charting Position\": 13, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"bad guy\", \"Streams\": 5436286, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"1hewNsVmijBqjKvFRQfk4m\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.701, \"Energy\": 0.425, \"Loudness\": -10.965, \"Speechiness\": 0.375, \"Acousticness\": 0.328, \"Liveness\": 0.1, \"Tempo\": 135.128, \"Duration (ms)\": 194088.0, \"Valence\": 0.562, \"Chord\": \"G\"}, {\"Index\": 166, \"Highest Charting Position\": 59, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Cover Me In Sunshine\", \"Streams\": 5434073, \"Artist\": \"P!nk, Willow Sage Hart\", \"Artist Followers\": 11477164.0, \"Song ID\": \"6Tio0ZoDeSQnI7EBAqWer2\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-02-12\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 83.0, \"Danceability\": 0.476, \"Energy\": 0.594, \"Loudness\": -6.879, \"Speechiness\": 0.135, \"Acousticness\": 0.0599, \"Liveness\": 0.0785, \"Tempo\": 159.702, \"Duration (ms)\": 141050.0, \"Valence\": 0.314, \"Chord\": \"F\"}, {\"Index\": 167, \"Highest Charting Position\": 7, \"Number of Times Charted\": 56, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"For The Night (feat. Lil Baby & DaBaby)\", \"Streams\": 5431375, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"0PvFJmanyNQMseIFrU708S\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 84.0, \"Danceability\": 0.823, \"Energy\": 0.586, \"Loudness\": -6.606, \"Speechiness\": 0.2, \"Acousticness\": 0.114, \"Liveness\": 0.193, \"Tempo\": 125.971, \"Duration (ms)\": 190476.0, \"Valence\": 0.347, \"Chord\": \"F#/Gb\"}, {\"Index\": 168, \"Highest Charting Position\": 13, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"1 step forward, 3 steps back\", \"Streams\": 5420003, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"4wcBRRpIfesgcyUtis7PEg\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 85.0, \"Danceability\": 0.473, \"Energy\": 0.203, \"Loudness\": -12.627, \"Speechiness\": 0.102, \"Acousticness\": 0.941, \"Liveness\": 0.126, \"Tempo\": 168.884, \"Duration (ms)\": 163587.0, \"Valence\": 0.419, \"Chord\": \"D\"}, {\"Index\": 169, \"Highest Charting Position\": 1, \"Number of Times Charted\": 51, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"WAP (feat. Megan Thee Stallion)\", \"Streams\": 5386268, \"Artist\": \"Cardi B\", \"Artist Followers\": 17353707.0, \"Song ID\": \"4Oun2ylbjFKMPTiaSbbCih\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'rap']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 84.0, \"Danceability\": 0.935, \"Energy\": 0.454, \"Loudness\": -7.509, \"Speechiness\": 0.375, \"Acousticness\": 0.0194, \"Liveness\": 0.0824, \"Tempo\": 133.073, \"Duration (ms)\": 187541.0, \"Valence\": 0.357, \"Chord\": \"C#/Db\"}, {\"Index\": 170, \"Highest Charting Position\": 155, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Mr. Brightside\", \"Streams\": 5382191, \"Artist\": \"The Killers\", \"Artist Followers\": 6118063.0, \"Song ID\": \"7oK9VyNzrYvRFo7nQEYkWN\", \"Genre\": \"['dance rock', 'modern rock', 'permanent wave', 'rock']\", \"Release Date\": \"2004-06-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-12--2021-03-19\\n2021-02-26--2021-03-05\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 75.0, \"Danceability\": 0.356, \"Energy\": 0.924, \"Loudness\": -3.74, \"Speechiness\": 0.0808, \"Acousticness\": 0.00101, \"Liveness\": 0.0953, \"Tempo\": 148.017, \"Duration (ms)\": 222587.0, \"Valence\": 0.232, \"Chord\": \"C#/Db\"}, {\"Index\": 171, \"Highest Charting Position\": 144, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Every Breath You Take\", \"Streams\": 5379704, \"Artist\": \"The Police\", \"Artist Followers\": 4339245.0, \"Song ID\": \"1JSTJqkT5qHq8MDJnJbRE1\", \"Genre\": \"['album rock', 'art rock', 'classic rock', 'mellow gold', 'new wave', 'permanent wave', 'rock', 'soft rock']\", \"Release Date\": \"1983-06-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-01-01--2021-01-08\\n2020-06-19--2020-06-26\\n2020-06-05--2020-06-12\", \"Popularity\": 83.0, \"Danceability\": 0.82, \"Energy\": 0.452, \"Loudness\": -9.796, \"Speechiness\": 0.0348, \"Acousticness\": 0.543, \"Liveness\": 0.0714, \"Tempo\": 117.401, \"Duration (ms)\": 253920.0, \"Valence\": 0.74, \"Chord\": \"C#/Db\"}, {\"Index\": 172, \"Highest Charting Position\": 20, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Dreams - 2004 Remaster\", \"Streams\": 5378971, \"Artist\": \"Fleetwood Mac\", \"Artist Followers\": 6930669.0, \"Song ID\": \"0ofHAoxe9vBkTCp2UQIavz\", \"Genre\": \"['album rock', 'classic rock', 'mellow gold', 'rock', 'soft rock', 'yacht rock']\", \"Release Date\": \"1977-02-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 84.0, \"Danceability\": 0.828, \"Energy\": 0.492, \"Loudness\": -9.744, \"Speechiness\": 0.0276, \"Acousticness\": 0.0644, \"Liveness\": 0.128, \"Tempo\": 120.151, \"Duration (ms)\": 257800.0, \"Valence\": 0.789, \"Chord\": \"C\"}, {\"Index\": 173, \"Highest Charting Position\": 94, \"Number of Times Charted\": 82, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Say You Won't Let Go\", \"Streams\": 5375426, \"Artist\": \"James Arthur\", \"Artist Followers\": 8441598.0, \"Song ID\": \"5uCax9HTNlzGybIStD3vDh\", \"Genre\": \"['pop', 'post-teen pop', 'talent show', 'uk pop']\", \"Release Date\": \"2016-10-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.358, \"Energy\": 0.557, \"Loudness\": -7.398, \"Speechiness\": 0.059, \"Acousticness\": 0.695, \"Liveness\": 0.0902, \"Tempo\": 85.043, \"Duration (ms)\": 211467.0, \"Valence\": 0.494, \"Chord\": \"A#/Bb\"}, {\"Index\": 174, \"Highest Charting Position\": 110, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Wild Side (feat. Cardi B)\", \"Streams\": 5366242, \"Artist\": \"Normani\", \"Artist Followers\": 1304510.0, \"Song ID\": \"2vXgyN14LX2zl7JEASw242\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop', 'r&b', 'urban contemporary']\", \"Release Date\": \"2021-07-22\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 75.0, \"Danceability\": 0.74, \"Energy\": 0.576, \"Loudness\": -6.744, \"Speechiness\": 0.146, \"Acousticness\": 0.0249, \"Liveness\": 0.104, \"Tempo\": 110.095, \"Duration (ms)\": 209476.0, \"Valence\": 0.315, \"Chord\": \"F#/Gb\"}, {\"Index\": 175, \"Highest Charting Position\": 65, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Bout A Million (feat. 42 Dugg & 21 Savage)\", \"Streams\": 5315734, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"4LaGu95Ui2s4vprSQYWUAZ\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 81.0, \"Danceability\": 0.716, \"Energy\": 0.67, \"Loudness\": -6.995, \"Speechiness\": 0.101, \"Acousticness\": 0.526, \"Liveness\": 0.13, \"Tempo\": 145.043, \"Duration (ms)\": 203586.0, \"Valence\": 0.411, \"Chord\": \"C\"}, {\"Index\": 176, \"Highest Charting Position\": 72, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Demeanor (feat. Dua Lipa)\", \"Streams\": 5245618, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"3DMs7bahbQTnoxCjgP7qoK\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 81.0, \"Danceability\": 0.675, \"Energy\": 0.608, \"Loudness\": -6.934, \"Speechiness\": 0.103, \"Acousticness\": 0.336, \"Liveness\": 0.11, \"Tempo\": 99.865, \"Duration (ms)\": 184800.0, \"Valence\": 0.728, \"Chord\": \"D#/Eb\"}, {\"Index\": 177, \"Highest Charting Position\": 4, \"Number of Times Charted\": 76, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"death bed (coffee for your head)\", \"Streams\": 5238547, \"Artist\": \"Powfu, beabadoobee\", \"Artist Followers\": 924083.0, \"Song ID\": \"7eJMfftS33KTjuF7lTsMCx\", \"Genre\": \"['sad rap']\", \"Release Date\": \"2020-02-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 85.0, \"Danceability\": 0.726, \"Energy\": 0.431, \"Loudness\": -8.765, \"Speechiness\": 0.135, \"Acousticness\": 0.731, \"Liveness\": 0.696, \"Tempo\": 144.026, \"Duration (ms)\": 173333.0, \"Valence\": 0.348, \"Chord\": \"G#/Ab\"}, {\"Index\": 178, \"Highest Charting Position\": 100, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Our Song\", \"Streams\": 5235335, \"Artist\": \"Anne-Marie, Niall Horan\", \"Artist Followers\": 8148393.0, \"Song ID\": \"5zqObw7wjBgL9TDiAymxPn\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 83.0, \"Danceability\": 0.595, \"Energy\": 0.759, \"Loudness\": -4.245, \"Speechiness\": 0.0423, \"Acousticness\": 0.141, \"Liveness\": 0.172, \"Tempo\": 80.953, \"Duration (ms)\": 163733.0, \"Valence\": 0.515, \"Chord\": \"B\"}, {\"Index\": 179, \"Highest Charting Position\": 138, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Another One Bites The Dust - Remastered 2011\", \"Streams\": 5204983, \"Artist\": \"Queen\", \"Artist Followers\": 35888760.0, \"Song ID\": \"57JVGBtBLCfHw2muk5416J\", \"Genre\": \"['classic rock', 'glam rock', 'rock']\", \"Release Date\": \"1980-06-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.933, \"Energy\": 0.528, \"Loudness\": -6.472, \"Speechiness\": 0.162, \"Acousticness\": 0.112, \"Liveness\": 0.163, \"Tempo\": 109.975, \"Duration (ms)\": 214653.0, \"Valence\": 0.756, \"Chord\": \"F\"}, {\"Index\": 180, \"Highest Charting Position\": 149, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"One Dance\", \"Streams\": 5178490, \"Artist\": \"Drake, WizKid, Kyla\", \"Artist Followers\": 56308172.0, \"Song ID\": \"1zi7xx7UVEFkmKfv06H8x0\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2016-05-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 84.0, \"Danceability\": 0.792, \"Energy\": 0.625, \"Loudness\": -5.609, \"Speechiness\": 0.0536, \"Acousticness\": 0.00776, \"Liveness\": 0.329, \"Tempo\": 103.967, \"Duration (ms)\": 173987.0, \"Valence\": 0.37, \"Chord\": \"C#/Db\"}, {\"Index\": 181, \"Highest Charting Position\": 15, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Adore You\", \"Streams\": 5166847, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16112621.0, \"Song ID\": \"3jjujdWJ72nww5eGnfs2E7\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.676, \"Energy\": 0.771, \"Loudness\": -3.675, \"Speechiness\": 0.0483, \"Acousticness\": 0.0237, \"Liveness\": 0.102, \"Tempo\": 99.048, \"Duration (ms)\": 207133.0, \"Valence\": 0.569, \"Chord\": \"G#/Ab\"}, {\"Index\": 182, \"Highest Charting Position\": 181, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"As the World Caves In\", \"Streams\": 5145493, \"Artist\": \"Sarah Cothran\", \"Artist Followers\": 180723.0, \"Song ID\": \"2xXNLutYAOELYVObYb1C1S\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-04--2021-06-11\", \"Popularity\": 71.0, \"Danceability\": 0.422, \"Energy\": 0.25, \"Loudness\": -6.836, \"Speechiness\": 0.0351, \"Acousticness\": 0.441, \"Liveness\": 0.35, \"Tempo\": 124.026, \"Duration (ms)\": 161613.0, \"Valence\": 0.246, \"Chord\": \"C\"}, {\"Index\": 183, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Fancy Like\", \"Streams\": 5145432, \"Artist\": \"Walker Hayes\", \"Artist Followers\": 304995.0, \"Song ID\": \"3ZozFqJJlDBNIm4xqxn2ZD\", \"Genre\": \"['contemporary country', 'country', 'country road', 'modern country rock']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 83.0, \"Danceability\": 0.649, \"Energy\": 0.76, \"Loudness\": -6.487, \"Speechiness\": 0.0574, \"Acousticness\": 0.114, \"Liveness\": 0.317, \"Tempo\": 80.018, \"Duration (ms)\": 161853.0, \"Valence\": 0.843, \"Chord\": \"C#/Db\"}, {\"Index\": 184, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"C\\u00farame\", \"Streams\": 5104206, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6080597.0, \"Song ID\": \"3PwRuzdphgedcWVUOVYJ7I\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 85.0, \"Danceability\": 0.765, \"Energy\": 0.625, \"Loudness\": -3.599, \"Speechiness\": 0.0548, \"Acousticness\": 0.584, \"Liveness\": 0.112, \"Tempo\": 102.101, \"Duration (ms)\": 164706.0, \"Valence\": 0.262, \"Chord\": \"A\"}, {\"Index\": 185, \"Highest Charting Position\": 110, \"Number of Times Charted\": 78, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"All of Me\", \"Streams\": 5103014, \"Artist\": \"John Legend\", \"Artist Followers\": 5799137.0, \"Song ID\": \"3U4isOIWM3VvDubwSI3y7a\", \"Genre\": \"['neo soul', 'pop', 'pop soul', 'r&b', 'urban contemporary']\", \"Release Date\": \"2013-08-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.422, \"Energy\": 0.264, \"Loudness\": -7.064, \"Speechiness\": 0.0322, \"Acousticness\": 0.922, \"Liveness\": 0.132, \"Tempo\": 119.93, \"Duration (ms)\": 269560.0, \"Valence\": 0.331, \"Chord\": \"G#/Ab\"}, {\"Index\": 186, \"Highest Charting Position\": 80, \"Number of Times Charted\": 41, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Martin & Gina\", \"Streams\": 5098609, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"1VLtjHwRWOVJiE5Py7JxoQ\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 85.0, \"Danceability\": 0.832, \"Energy\": 0.534, \"Loudness\": -7.813, \"Speechiness\": 0.253, \"Acousticness\": 0.345, \"Liveness\": 0.165, \"Tempo\": 93.924, \"Duration (ms)\": 132833.0, \"Valence\": 0.116, \"Chord\": \"C#/Db\"}, {\"Index\": 187, \"Highest Charting Position\": 40, \"Number of Times Charted\": 65, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Dior\", \"Streams\": 5092354, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"79s5XnCN4TJKTVMSmOx8Ep\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2019-07-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-06-18--2021-06-25\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 83.0, \"Danceability\": 0.548, \"Energy\": 0.805, \"Loudness\": -5.732, \"Speechiness\": 0.351, \"Acousticness\": 0.212, \"Liveness\": 0.408, \"Tempo\": 142.094, \"Duration (ms)\": 216387.0, \"Valence\": 0.648, \"Chord\": \"G\"}, {\"Index\": 188, \"Highest Charting Position\": 45, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Best Friend (feat. Doja Cat)\", \"Streams\": 5090062, \"Artist\": \"Saweetie\", \"Artist Followers\": 1254432.0, \"Song ID\": \"2etHQJxIbV0soyPhelVs9Y\", \"Genre\": \"['cali rap', 'dance pop', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2021-01-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 83.0, \"Danceability\": 0.84, \"Energy\": 0.766, \"Loudness\": -4.12, \"Speechiness\": 0.136, \"Acousticness\": 0.00302, \"Liveness\": 0.0684, \"Tempo\": 94.018, \"Duration (ms)\": 155884.0, \"Valence\": 0.402, \"Chord\": \"E\"}, {\"Index\": 189, \"Highest Charting Position\": 52, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"The Hills\", \"Streams\": 5068864, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"7fBv7CLKzipRk6EC6TWHOB\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2015-08-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 84.0, \"Danceability\": 0.585, \"Energy\": 0.564, \"Loudness\": -7.063, \"Speechiness\": 0.0515, \"Acousticness\": 0.0671, \"Liveness\": 0.135, \"Tempo\": 113.003, \"Duration (ms)\": 242253.0, \"Valence\": 0.137, \"Chord\": \"C\"}, {\"Index\": 190, \"Highest Charting Position\": 5, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Good Days\", \"Streams\": 5065132, \"Artist\": \"SZA\", \"Artist Followers\": 5881963.0, \"Song ID\": \"3YJJjQPAbDT7mGpX3WtQ9A\", \"Genre\": \"['pop', 'pop rap', 'r&b']\", \"Release Date\": \"2020-12-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 84.0, \"Danceability\": 0.436, \"Energy\": 0.655, \"Loudness\": -8.37, \"Speechiness\": 0.0583, \"Acousticness\": 0.499, \"Liveness\": 0.688, \"Tempo\": 121.002, \"Duration (ms)\": 279204.0, \"Valence\": 0.412, \"Chord\": \"C#/Db\"}, {\"Index\": 191, \"Highest Charting Position\": 191, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Kiss My (Uh Oh)\", \"Streams\": 5063181, \"Artist\": \"Anne-Marie, Little Mix\", \"Artist Followers\": 8148393.0, \"Song ID\": \"0MWiSBKm8Avs8iDIxcertp\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2021-07-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 78.0, \"Danceability\": 0.638, \"Energy\": 0.878, \"Loudness\": -3.639, \"Speechiness\": 0.0484, \"Acousticness\": 0.0151, \"Liveness\": 0.308, \"Tempo\": 103.948, \"Duration (ms)\": 176800.0, \"Valence\": 0.481, \"Chord\": \"F\"}, {\"Index\": 192, \"Highest Charting Position\": 64, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"De Museo\", \"Streams\": 5016125, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36142273.0, \"Song ID\": \"267NGliXM8YLVZiKAD9Otm\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 83.0, \"Danceability\": 0.592, \"Energy\": 0.494, \"Loudness\": -10.618, \"Speechiness\": 0.0747, \"Acousticness\": 0.237, \"Liveness\": 0.13, \"Tempo\": 132.037, \"Duration (ms)\": 209771.0, \"Valence\": 0.231, \"Chord\": \"E\"}, {\"Index\": 193, \"Highest Charting Position\": 41, \"Number of Times Charted\": 81, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"7 rings\", \"Streams\": 5002227, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67158068.0, \"Song ID\": \"6ocbgoVGwYJhOv1GgI9NsF\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-02-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.778, \"Energy\": 0.317, \"Loudness\": -10.732, \"Speechiness\": 0.334, \"Acousticness\": 0.592, \"Liveness\": 0.0881, \"Tempo\": 140.048, \"Duration (ms)\": 178627.0, \"Valence\": 0.327, \"Chord\": \"C#/Db\"}, {\"Index\": 194, \"Highest Charting Position\": 194, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Chosen (feat. Ty Dolla $ign)\", \"Streams\": 4992405, \"Artist\": \"Blxst, Tyga\", \"Artist Followers\": 167628.0, \"Song ID\": \"1dIWPXMX4kRHj6Dt2DStUQ\", \"Genre\": \"[]\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 84.0, \"Danceability\": 0.571, \"Energy\": 0.767, \"Loudness\": -5.16, \"Speechiness\": 0.287, \"Acousticness\": 0.336, \"Liveness\": 0.0809, \"Tempo\": 93.421, \"Duration (ms)\": 161684.0, \"Valence\": 0.605, \"Chord\": \"D\"}, {\"Index\": 195, \"Highest Charting Position\": 149, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"N\\u00e3o Nasceu pra Namorar\", \"Streams\": 4978559, \"Artist\": \"MC Zaquin, MC Rick\", \"Artist Followers\": 130627.0, \"Song ID\": \"6pQKUKBpwr6GhfhcFFFozo\", \"Genre\": \"['funk bh', 'funk carioca']\", \"Release Date\": \"2021-02-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.525, \"Energy\": 0.448, \"Loudness\": -4.075, \"Speechiness\": 0.0443, \"Acousticness\": 0.14, \"Liveness\": 0.0922, \"Tempo\": 83.406, \"Duration (ms)\": 140308.0, \"Valence\": 0.527, \"Chord\": \"C#/Db\"}, {\"Index\": 196, \"Highest Charting Position\": 8, \"Number of Times Charted\": 71, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Breaking Me\", \"Streams\": 4977498, \"Artist\": \"Topic, A7S\", \"Artist Followers\": 151832.0, \"Song ID\": \"3H7ihDc1dqLriiWXwsc2po\", \"Genre\": \"['dance pop', 'edm', 'german dance', 'pop dance', 'pop edm', 'tropical house']\", \"Release Date\": \"2019-12-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 84.0, \"Danceability\": 0.789, \"Energy\": 0.72, \"Loudness\": -5.652, \"Speechiness\": 0.218, \"Acousticness\": 0.223, \"Liveness\": 0.129, \"Tempo\": 122.031, \"Duration (ms)\": 166794.0, \"Valence\": 0.664, \"Chord\": \"G#/Ab\"}, {\"Index\": 197, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"penhasco.\", \"Streams\": 4973937, \"Artist\": \"Lu\\u00edsa Sonza\", \"Artist Followers\": 1909059.0, \"Song ID\": \"5VTqW8raQYnj2avZ27nO2a\", \"Genre\": \"['funk carioca', 'pop nacional']\", \"Release Date\": \"2021-07-18\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 80.0, \"Danceability\": 0.43, \"Energy\": 0.467, \"Loudness\": -8.56, \"Speechiness\": 0.051, \"Acousticness\": 0.775, \"Liveness\": 0.0933, \"Tempo\": 77.249, \"Duration (ms)\": 186121.0, \"Valence\": 0.382, \"Chord\": \"G#/Ab\"}, {\"Index\": 198, \"Highest Charting Position\": 58, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Late At Night\", \"Streams\": 4954899, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6603627.0, \"Song ID\": \"1fxYz1s15pyZLsJT0Hdh1m\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 84.0, \"Danceability\": 0.643, \"Energy\": 0.403, \"Loudness\": -11.254, \"Speechiness\": 0.41, \"Acousticness\": 0.343, \"Liveness\": 0.138, \"Tempo\": 98.54, \"Duration (ms)\": 174682.0, \"Valence\": 0.111, \"Chord\": \"C#/Db\"}, {\"Index\": 199, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Verdansk\", \"Streams\": 4950275, \"Artist\": \"Dave\", \"Artist Followers\": 1427540.0, \"Song ID\": \"7IPKXYU2rTMnrLW5IZ7ZI5\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2021-07-22\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 77.0, \"Danceability\": 0.961, \"Energy\": 0.502, \"Loudness\": -8.605, \"Speechiness\": 0.312, \"Acousticness\": 0.28, \"Liveness\": 0.145, \"Tempo\": 117.078, \"Duration (ms)\": 182285.0, \"Valence\": 0.536, \"Chord\": \"D\"}, {\"Index\": 200, \"Highest Charting Position\": 172, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"The Real Slim Shady\", \"Streams\": 4948965, \"Artist\": \"Eminem\", \"Artist Followers\": 46785561.0, \"Song ID\": \"3yfqSUWxFvZELEM4PmlwIR\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2000-05-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 84.0, \"Danceability\": 0.949, \"Energy\": 0.661, \"Loudness\": -4.244, \"Speechiness\": 0.0572, \"Acousticness\": 0.0302, \"Liveness\": 0.0454, \"Tempo\": 104.504, \"Duration (ms)\": 284200.0, \"Valence\": 0.76, \"Chord\": \"F\"}, {\"Index\": 201, \"Highest Charting Position\": 66, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Tell The Vision (feat. Kanye West & Pusha T)\", \"Streams\": 8859168, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"1Eu51GaXEehPMrDMh5QghA\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 57.0, \"Danceability\": 0.662, \"Energy\": 0.686, \"Loudness\": -8.302, \"Speechiness\": 0.332, \"Acousticness\": 0.251, \"Liveness\": 0.349, \"Tempo\": 143.971, \"Duration (ms)\": 215000.0, \"Valence\": 0.678, \"Chord\": \"G\"}, {\"Index\": 202, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Woo Baby (feat. Chris Brown)\", \"Streams\": 7371935, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"6bsqes8Zg9gUULzuCkMUs0\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 56.0, \"Danceability\": 0.563, \"Energy\": 0.672, \"Loudness\": -7.226, \"Speechiness\": 0.0765, \"Acousticness\": 0.359, \"Liveness\": 0.0972, \"Tempo\": 99.772, \"Duration (ms)\": 156000.0, \"Valence\": 0.284, \"Chord\": \"A\"}, {\"Index\": 203, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Holy Smokes\", \"Streams\": 6464206, \"Artist\": \"Trippie Redd, Lil Uzi Vert\", \"Artist Followers\": 6430522.0, \"Song ID\": \"3EpF150nXMSNjiH0bbmXIL\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 79.0, \"Danceability\": 0.437, \"Energy\": 0.527, \"Loudness\": -6.967, \"Speechiness\": 0.465, \"Acousticness\": 0.185, \"Liveness\": 0.153, \"Tempo\": 187.815, \"Duration (ms)\": 181714.0, \"Valence\": 0.701, \"Chord\": \"F#/Gb\"}, {\"Index\": 204, \"Highest Charting Position\": 127, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"More Time\", \"Streams\": 6238351, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"7wAnRqccDr2tzcSKLR4jKl\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 55.0, \"Danceability\": 0.628, \"Energy\": 0.581, \"Loudness\": -8.377, \"Speechiness\": 0.188, \"Acousticness\": 0.46, \"Liveness\": 0.152, \"Tempo\": 145.396, \"Duration (ms)\": 120828.0, \"Valence\": 0.259, \"Chord\": \"D\"}, {\"Index\": 205, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Coupe\", \"Streams\": 6161664, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"7LB3ilSpX1mSMKKztNTnu2\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 54.0, \"Danceability\": 0.912, \"Energy\": 0.589, \"Loudness\": -7.476, \"Speechiness\": 0.2, \"Acousticness\": 0.0332, \"Liveness\": 0.0795, \"Tempo\": 135.921, \"Duration (ms)\": 123549.0, \"Valence\": 0.486, \"Chord\": \"G#/Ab\"}, {\"Index\": 206, \"Highest Charting Position\": 76, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Holiday\", \"Streams\": 5883145, \"Artist\": \"KSI\", \"Artist Followers\": 2008516.0, \"Song ID\": \"6nV2dFZXpv1JlqDWBeTXRl\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 81.0, \"Danceability\": 0.356, \"Energy\": 0.684, \"Loudness\": -7.347, \"Speechiness\": 0.0878, \"Acousticness\": 0.152, \"Liveness\": 0.101, \"Tempo\": 87.188, \"Duration (ms)\": 193733.0, \"Valence\": 0.347, \"Chord\": \"G#/Ab\"}, {\"Index\": 207, \"Highest Charting Position\": 150, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Manslaughter (feat. Rick Ross & The-Dream)\", \"Streams\": 5822266, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"4byRwLo7EmkCNBU6S8G6u0\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 55.0, \"Danceability\": 0.441, \"Energy\": 0.623, \"Loudness\": -7.331, \"Speechiness\": 0.0414, \"Acousticness\": 0.135, \"Liveness\": 0.14, \"Tempo\": 78.082, \"Duration (ms)\": 249231.0, \"Valence\": 0.285, \"Chord\": \"C#/Db\"}, {\"Index\": 208, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Genius (feat. Lil Tjay & Swae Lee)\", \"Streams\": 5702636, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"2mmRtchzDVpCj9LSyexgjS\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 53.0, \"Danceability\": 0.723, \"Energy\": 0.667, \"Loudness\": -7.524, \"Speechiness\": 0.351, \"Acousticness\": 0.256, \"Liveness\": 0.261, \"Tempo\": 143.044, \"Duration (ms)\": 208112.0, \"Valence\": 0.396, \"Chord\": \"D\"}, {\"Index\": 209, \"Highest Charting Position\": 22, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"WUSYANAME (feat. Youngboy Never Broke Again & Ty Dolla $ign)\", \"Streams\": 5696113, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"5B0kgjHULYJhAQkK5XsMoC\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.493, \"Energy\": 0.653, \"Loudness\": -5.666, \"Speechiness\": 0.0466, \"Acousticness\": 0.269, \"Liveness\": 0.511, \"Tempo\": 142.347, \"Duration (ms)\": 121573.0, \"Valence\": 0.852, \"Chord\": \"C\"}, {\"Index\": 210, \"Highest Charting Position\": 105, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Sommergewitter\", \"Streams\": 5627519, \"Artist\": \"Pashanim\", \"Artist Followers\": 208554.0, \"Song ID\": \"2H7jZg2HliuQhZjfBblLrZ\", \"Genre\": \"['german alternative rap', 'german drill', 'german hip hop', 'german trap']\", \"Release Date\": \"2021-06-24\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.787, \"Energy\": 0.531, \"Loudness\": -10.569, \"Speechiness\": 0.101, \"Acousticness\": 0.132, \"Liveness\": 0.112, \"Tempo\": 91.996, \"Duration (ms)\": 138533.0, \"Valence\": 0.721, \"Chord\": \"B\"}, {\"Index\": 211, \"Highest Charting Position\": 17, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Body (Remix) [feat. ArrDee, E1 (3x3), ZT (3x3), Bugzy Malone, Buni, Fivio Foreign & Darkoo]\", \"Streams\": 5383125, \"Artist\": \"Tion Wayne, Russ Millions\", \"Artist Followers\": 323203.0, \"Song ID\": \"6uvMKqNlrSvcC4NaKnrwjZ\", \"Genre\": \"['london rap']\", \"Release Date\": \"2021-04-22\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 84.0, \"Danceability\": 0.883, \"Energy\": 0.674, \"Loudness\": -8.043, \"Speechiness\": 0.357, \"Acousticness\": 0.21, \"Liveness\": 0.0678, \"Tempo\": 141.02, \"Duration (ms)\": 278085.0, \"Valence\": 0.73, \"Chord\": \"B\"}, {\"Index\": 212, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Brush Em (feat. Rah Swish)\", \"Streams\": 5335271, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"58aW6yZGFl7rVM7SLfLnLL\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 54.0, \"Danceability\": 0.654, \"Energy\": 0.724, \"Loudness\": -6.59, \"Speechiness\": 0.355, \"Acousticness\": 0.106, \"Liveness\": 0.655, \"Tempo\": 71.696, \"Duration (ms)\": 150449.0, \"Valence\": 0.717, \"Chord\": \"D#/Eb\"}, {\"Index\": 213, \"Highest Charting Position\": 13, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"AM\", \"Streams\": 5288927, \"Artist\": \"Nio Garcia, Flow La Movie\", \"Artist Followers\": 2123734.0, \"Song ID\": \"2dNhNlpZAtV4lwAFW45LIv\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-01-28\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 85.0, \"Danceability\": 0.83, \"Energy\": 0.517, \"Loudness\": -6.416, \"Speechiness\": 0.333, \"Acousticness\": 0.399, \"Liveness\": 0.0916, \"Tempo\": 171.959, \"Duration (ms)\": 182496.0, \"Valence\": 0.616, \"Chord\": \"F#/Gb\"}, {\"Index\": 214, \"Highest Charting Position\": 175, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"MI FAI IMPAZZIRE\", \"Streams\": 5242097, \"Artist\": \"BLANCO, Sfera Ebbasta\", \"Artist Followers\": 127364.0, \"Song ID\": \"1x3Qb8np6S1UvpSLthwEJN\", \"Genre\": \"['italian hip hop', 'italian pop']\", \"Release Date\": \"2021-06-17\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\", \"Popularity\": 83.0, \"Danceability\": 0.477, \"Energy\": 0.844, \"Loudness\": -4.87, \"Speechiness\": 0.0458, \"Acousticness\": 0.00273, \"Liveness\": 0.137, \"Tempo\": 169.941, \"Duration (ms)\": 220235.0, \"Valence\": 0.203, \"Chord\": \"B\"}, {\"Index\": 215, \"Highest Charting Position\": 20, \"Number of Times Charted\": 82, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Ride It\", \"Streams\": 5235088, \"Artist\": \"Regard\", \"Artist Followers\": 152226.0, \"Song ID\": \"2tnVG71enUj33Ic2nFN6kZ\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop edm', 'slap house', 'tropical house']\", \"Release Date\": \"2019-07-26\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.88, \"Energy\": 0.751, \"Loudness\": -4.258, \"Speechiness\": 0.0874, \"Acousticness\": 0.177, \"Liveness\": 0.106, \"Tempo\": 117.948, \"Duration (ms)\": 157606.0, \"Valence\": 0.884, \"Chord\": \"G\"}, {\"Index\": 216, \"Highest Charting Position\": 15, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Lost Cause\", \"Streams\": 5203319, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"36fhyo5QlxBW7DrDHIOn1G\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 0.0, \"Danceability\": 0.671, \"Energy\": 0.336, \"Loudness\": -8.494, \"Speechiness\": 0.241, \"Acousticness\": 0.705, \"Liveness\": 0.0577, \"Tempo\": 75.051, \"Duration (ms)\": 212496.0, \"Valence\": 0.518, \"Chord\": \"A#/Bb\"}, {\"Index\": 217, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Shot in the Dark\", \"Streams\": 5173308, \"Artist\": \"John Mayer\", \"Artist Followers\": 5178156.0, \"Song ID\": \"239yM7BAQ2CkNc61ogPGXo\", \"Genre\": \"['neo mellow', 'pop rock', 'singer-songwriter']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 76.0, \"Danceability\": 0.741, \"Energy\": 0.556, \"Loudness\": -9.184, \"Speechiness\": 0.0266, \"Acousticness\": 0.0629, \"Liveness\": 0.103, \"Tempo\": 122.008, \"Duration (ms)\": 249080.0, \"Valence\": 0.587, \"Chord\": \"D\"}, {\"Index\": 218, \"Highest Charting Position\": 71, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Wrecked\", \"Streams\": 5150909, \"Artist\": \"Imagine Dragons\", \"Artist Followers\": 35285425.0, \"Song ID\": \"2d1MywHy6FwKdzxFuSJnwl\", \"Genre\": \"['modern rock', 'pop', 'rock']\", \"Release Date\": \"2021-07-02\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 83.0, \"Danceability\": 0.626, \"Energy\": 0.56, \"Loudness\": -5.82, \"Speechiness\": 0.0288, \"Acousticness\": 0.148, \"Liveness\": 0.109, \"Tempo\": 93.989, \"Duration (ms)\": 244005.0, \"Valence\": 0.229, \"Chord\": \"C\"}, {\"Index\": 219, \"Highest Charting Position\": 79, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Bipolar\", \"Streams\": 5116589, \"Artist\": \"Mc Davi, Mc Pedrinho, Mc Don Juan\", \"Artist Followers\": 2586114.0, \"Song ID\": \"0qxLQ6opocOGyFnlXqJ53x\", \"Genre\": \"['funk carioca', 'funk ostentacao', 'funk paulista']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 84.0, \"Danceability\": 0.601, \"Energy\": 0.36, \"Loudness\": -7.791, \"Speechiness\": 0.0877, \"Acousticness\": 0.586, \"Liveness\": 0.0882, \"Tempo\": 124.993, \"Duration (ms)\": 276480.0, \"Valence\": 0.335, \"Chord\": \"A\"}, {\"Index\": 220, \"Highest Charting Position\": 122, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"His & Hers (feat. Don Toliver, Lil Uzi Vert & Gunna)\", \"Streams\": 5110475, \"Artist\": \"Internet Money\", \"Artist Followers\": 411579.0, \"Song ID\": \"2IePEfMAtqWS6rLXXFZIgI\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-05-14--2021-05-21\", \"Popularity\": 84.0, \"Danceability\": 0.792, \"Energy\": 0.707, \"Loudness\": -5.218, \"Speechiness\": 0.0623, \"Acousticness\": 0.116, \"Liveness\": 0.12, \"Tempo\": 134.997, \"Duration (ms)\": 224042.0, \"Valence\": 0.408, \"Chord\": \"G\"}, {\"Index\": 221, \"Highest Charting Position\": 75, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Follow You\", \"Streams\": 5097187, \"Artist\": \"Imagine Dragons\", \"Artist Followers\": 35285425.0, \"Song ID\": \"7FdUvDkaE24o3FPIWTvzv2\", \"Genre\": \"['modern rock', 'pop', 'rock']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 84.0, \"Danceability\": 0.542, \"Energy\": 0.732, \"Loudness\": -5.956, \"Speechiness\": 0.0521, \"Acousticness\": 0.00209, \"Liveness\": 0.496, \"Tempo\": 124.912, \"Duration (ms)\": 175644.0, \"Valence\": 0.489, \"Chord\": \"A\"}, {\"Index\": 222, \"Highest Charting Position\": 22, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"We're Good\", \"Streams\": 6318660, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"1diS6nkxMQc3wwC4G1j0bh\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 83.0, \"Danceability\": 0.722, \"Energy\": 0.588, \"Loudness\": -5.932, \"Speechiness\": 0.0544, \"Acousticness\": 0.0319, \"Liveness\": 0.183, \"Tempo\": 134.01, \"Duration (ms)\": 165507.0, \"Valence\": 0.59, \"Chord\": \"F#/Gb\"}, {\"Index\": 223, \"Highest Charting Position\": 4, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Life Goes On\", \"Streams\": 6142975, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"249gnXrbfmV8NG6jTEMSwD\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 84.0, \"Danceability\": 0.566, \"Energy\": 0.716, \"Loudness\": -5.733, \"Speechiness\": 0.0424, \"Acousticness\": 0.00691, \"Liveness\": 0.37, \"Tempo\": 81.068, \"Duration (ms)\": 207481.0, \"Valence\": 0.45, \"Chord\": \"C#/Db\"}, {\"Index\": 224, \"Highest Charting Position\": 28, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"911\", \"Streams\": 6111108, \"Artist\": \"Sech\", \"Artist Followers\": 8758283.0, \"Song ID\": \"27RSJHEA99Y0Vsow7nA37A\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2020-05-29--2020-06-05\", \"Popularity\": 89.0, \"Danceability\": 0.816, \"Energy\": 0.71, \"Loudness\": -3.728, \"Speechiness\": 0.0398, \"Acousticness\": 0.165, \"Liveness\": 0.292, \"Tempo\": 93.02, \"Duration (ms)\": 208631.0, \"Valence\": 0.784, \"Chord\": \"G\"}, {\"Index\": 225, \"Highest Charting Position\": 17, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Baila Conmigo (with Rauw Alejandro)\", \"Streams\": 5588217, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28909504.0, \"Song ID\": \"079Ey5uxL04AKPQgVQwx5h\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 84.0, \"Danceability\": 0.823, \"Energy\": 0.544, \"Loudness\": -7.132, \"Speechiness\": 0.0715, \"Acousticness\": 0.0215, \"Liveness\": 0.0966, \"Tempo\": 149.903, \"Duration (ms)\": 186088.0, \"Valence\": 0.664, \"Chord\": \"F\"}, {\"Index\": 226, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"The Jackie (with J. Cole & Lil Tjay)\", \"Streams\": 5454994, \"Artist\": \"Bas\", \"Artist Followers\": 386757.0, \"Song ID\": \"15qKrPi4Kg0z7g9HlwWyeb\", \"Genre\": \"['hip hop', 'pop rap', 'queens hip hop', 'rap', 'sudanese pop', 'underground hip hop']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-09--2021-07-16\", \"Popularity\": 76.0, \"Danceability\": 0.784, \"Energy\": 0.474, \"Loudness\": -6.139, \"Speechiness\": 0.0524, \"Acousticness\": 0.333, \"Liveness\": 0.278, \"Tempo\": 128.012, \"Duration (ms)\": 204434.0, \"Valence\": 0.64, \"Chord\": \"G#/Ab\"}, {\"Index\": 227, \"Highest Charting Position\": 22, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"hope ur ok\", \"Streams\": 5435614, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"1zejeOnykpCoyVSit6Bwp3\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 84.0, \"Danceability\": 0.443, \"Energy\": 0.298, \"Loudness\": -12.181, \"Speechiness\": 0.0644, \"Acousticness\": 0.388, \"Liveness\": 0.103, \"Tempo\": 77.253, \"Duration (ms)\": 209560.0, \"Valence\": 0.172, \"Chord\": \"C\"}, {\"Index\": 228, \"Highest Charting Position\": 169, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Faz Amor Comigo S\\u00f3 Hoje - Ao Vivo\", \"Streams\": 5269757, \"Artist\": \"Israel & Rodolffo, Wesley Safad\\u00e3o\", \"Artist Followers\": 1097789.0, \"Song ID\": \"7Kba4OaxQFQ1zlknQUpNqN\", \"Genre\": \"['sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2021-05-26\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 82.0, \"Danceability\": 0.624, \"Energy\": 0.922, \"Loudness\": -4.628, \"Speechiness\": 0.0439, \"Acousticness\": 0.3, \"Liveness\": 0.112, \"Tempo\": 164.819, \"Duration (ms)\": 148228.0, \"Valence\": 0.884, \"Chord\": \"C#/Db\"}, {\"Index\": 229, \"Highest Charting Position\": 80, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Alcohol-Free\", \"Streams\": 5259503, \"Artist\": \"TWICE\", \"Artist Followers\": 9987114.0, \"Song ID\": \"0BTaaKT4RMbs5M73tOHX5Y\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 82.0, \"Danceability\": 0.688, \"Energy\": 0.909, \"Loudness\": -1.992, \"Speechiness\": 0.0624, \"Acousticness\": 0.0474, \"Liveness\": 0.0674, \"Tempo\": 97.097, \"Duration (ms)\": 210573.0, \"Valence\": 0.702, \"Chord\": \"G#/Ab\"}, {\"Index\": 230, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"WHOLE LOTTA MONEY (feat. Nicki Minaj) - Remix\", \"Streams\": 5186354, \"Artist\": \"BIA\", \"Artist Followers\": 151870.0, \"Song ID\": \"67G6iaOw8DZqp1z8STR89R\", \"Genre\": \"['escape room', 'r&b', 'rap latina', 'trap queen']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-09--2021-07-16\", \"Popularity\": 80.0, \"Danceability\": 0.893, \"Energy\": 0.463, \"Loudness\": -5.301, \"Speechiness\": 0.36, \"Acousticness\": 0.199, \"Liveness\": 0.318, \"Tempo\": 81.026, \"Duration (ms)\": 229601.0, \"Valence\": 0.591, \"Chord\": \"C#/Db\"}, {\"Index\": 231, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Memory\", \"Streams\": 5173178, \"Artist\": \"Kane Brown, blackbear\", \"Artist Followers\": 3507622.0, \"Song ID\": \"34chhNX59Wo9HMFCsI3K8Y\", \"Genre\": \"['contemporary country', 'country road']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-09--2021-07-16\", \"Popularity\": 80.0, \"Danceability\": 0.434, \"Energy\": 0.889, \"Loudness\": -5.684, \"Speechiness\": 0.0509, \"Acousticness\": 0.395, \"Liveness\": 0.273, \"Tempo\": 113.326, \"Duration (ms)\": 153338.0, \"Valence\": 0.845, \"Chord\": \"A\"}, {\"Index\": 232, \"Highest Charting Position\": 183, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Me Fije\", \"Streams\": 5068677, \"Artist\": \"Alex Rose, Rauw Alejandro\", \"Artist Followers\": 2166191.0, \"Song ID\": \"6Et5KimMg3IXwD6lJPGmQw\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2021-03-18\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-05-07--2021-05-14\", \"Popularity\": 83.0, \"Danceability\": 0.76, \"Energy\": 0.674, \"Loudness\": -4.039, \"Speechiness\": 0.0636, \"Acousticness\": 0.396, \"Liveness\": 0.0977, \"Tempo\": 172.024, \"Duration (ms)\": 202307.0, \"Valence\": 0.735, \"Chord\": \"G\"}, {\"Index\": 233, \"Highest Charting Position\": 71, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Volta Beb\\u00ea, Volta Nen\\u00e9m\", \"Streams\": 5041120, \"Artist\": \"Dj Guuga, DJ Ivis\", \"Artist Followers\": 608109.0, \"Song ID\": \"4wQUopWk9Ed7Ng5qpKN5qd\", \"Genre\": \"['funk carioca', 'funk paulista', 'rave funk']\", \"Release Date\": \"2021-03-27\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 79.0, \"Danceability\": 0.583, \"Energy\": 0.918, \"Loudness\": -3.612, \"Speechiness\": 0.0518, \"Acousticness\": 0.288, \"Liveness\": 0.0701, \"Tempo\": 164.081, \"Duration (ms)\": 172973.0, \"Valence\": 0.836, \"Chord\": \"F#/Gb\"}, {\"Index\": 234, \"Highest Charting Position\": 95, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Aloha\", \"Streams\": 5036030, \"Artist\": \"Maluma, Be\\u00e9le, Rauw Alejandro, Mambo Kingz, DJ Luian, Darell\", \"Artist Followers\": 26769304.0, \"Song ID\": \"5RAIMjdrCEjpjaR5tBATXU\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 84.0, \"Danceability\": 0.807, \"Energy\": 0.712, \"Loudness\": -5.757, \"Speechiness\": 0.1, \"Acousticness\": 0.532, \"Liveness\": 0.163, \"Tempo\": 100.004, \"Duration (ms)\": 241659.0, \"Valence\": 0.792, \"Chord\": \"C#/Db\"}, {\"Index\": 235, \"Highest Charting Position\": 184, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Sexo Virtual\", \"Streams\": 4975786, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6080597.0, \"Song ID\": \"0giiXonRhODYy4J1iy4Lb3\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 82.0, \"Danceability\": 0.704, \"Energy\": 0.739, \"Loudness\": -3.286, \"Speechiness\": 0.112, \"Acousticness\": 0.328, \"Liveness\": 0.0856, \"Tempo\": 179.879, \"Duration (ms)\": 208292.0, \"Valence\": 0.425, \"Chord\": \"G#/Ab\"}, {\"Index\": 236, \"Highest Charting Position\": 141, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Closer\", \"Streams\": 4954679, \"Artist\": \"The Chainsmokers, Halsey\", \"Artist Followers\": 18191658.0, \"Song ID\": \"7BKLCZ1jbUBVqRi2FVlTVw\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2016-07-29\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-01--2021-01-08\\n2020-08-14--2020-08-21\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.748, \"Energy\": 0.524, \"Loudness\": -5.599, \"Speechiness\": 0.0338, \"Acousticness\": 0.414, \"Liveness\": 0.111, \"Tempo\": 95.01, \"Duration (ms)\": 244960.0, \"Valence\": 0.661, \"Chord\": \"G#/Ab\"}, {\"Index\": 237, \"Highest Charting Position\": 194, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Wonderwall - Remastered\", \"Streams\": 4938180, \"Artist\": \"Oasis\", \"Artist Followers\": 6475631.0, \"Song ID\": \"7ygpwy2qP3NbrxVkHvUhXY\", \"Genre\": \"['beatlesque', 'britpop', 'madchester', 'permanent wave', 'rock']\", \"Release Date\": \"1995\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-05-28--2021-06-04\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 78.0, \"Danceability\": 0.375, \"Energy\": 0.893, \"Loudness\": -4.097, \"Speechiness\": 0.0406, \"Acousticness\": 0.000509, \"Liveness\": 0.187, \"Tempo\": 174.323, \"Duration (ms)\": 258773.0, \"Valence\": 0.434, \"Chord\": \"D\"}, {\"Index\": 238, \"Highest Charting Position\": 101, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Wasting Time ( feat. Drake )\", \"Streams\": 6731106, \"Artist\": \"Brent Faiyaz\", \"Artist Followers\": 1724414.0, \"Song ID\": \"48WidxP9CqyYtk97pwGZ3c\", \"Genre\": \"['dmv rap', 'pop', 'r&b', 'rap']\", \"Release Date\": \"2021-07-01\", \"Weeks Charted\": \"2021-07-02--2021-07-09\", \"Popularity\": 78.0, \"Danceability\": 0.652, \"Energy\": 0.717, \"Loudness\": -3.751, \"Speechiness\": 0.0581, \"Acousticness\": 0.0694, \"Liveness\": 0.0906, \"Tempo\": 89.982, \"Duration (ms)\": 301304.0, \"Valence\": 0.377, \"Chord\": \"G\"}, {\"Index\": 239, \"Highest Charting Position\": 55, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"I Don't Do Drugs (feat. Ariana Grande)\", \"Streams\": 5912293, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0FFsgUoFibYISzMxuGS61W\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 80.0, \"Danceability\": 0.683, \"Energy\": 0.615, \"Loudness\": -5.737, \"Speechiness\": 0.0966, \"Acousticness\": 0.222, \"Liveness\": 0.154, \"Tempo\": 77.014, \"Duration (ms)\": 188893.0, \"Valence\": 0.45, \"Chord\": \"F\"}, {\"Index\": 240, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Renegade (feat. Taylor Swift)\", \"Streams\": 5876058, \"Artist\": \"Big Red Machine\", \"Artist Followers\": 98503.0, \"Song ID\": \"1aU1wpYBSpP0M6IiihY5Ue\", \"Genre\": \"['eau claire indie', 'folktronica']\", \"Release Date\": \"2021-07-02\", \"Weeks Charted\": \"2021-07-02--2021-07-09\", \"Popularity\": 77.0, \"Danceability\": 0.532, \"Energy\": 0.708, \"Loudness\": -8.121, \"Speechiness\": 0.0505, \"Acousticness\": 0.435, \"Liveness\": 0.107, \"Tempo\": 167.977, \"Duration (ms)\": 254467.0, \"Valence\": 0.586, \"Chord\": \"C\"}, {\"Index\": 241, \"Highest Charting Position\": 40, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"JUGGERNAUT (feat. Lil Uzi Vert & Pharrell Williams)\", \"Streams\": 5392334, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"7z4xW9WY86uH3gd1V9pfCM\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 80.0, \"Danceability\": 0.827, \"Energy\": 0.571, \"Loudness\": -7.949, \"Speechiness\": 0.366, \"Acousticness\": 0.0195, \"Liveness\": 0.166, \"Tempo\": 142.034, \"Duration (ms)\": 146419.0, \"Valence\": 0.62, \"Chord\": \"B\"}, {\"Index\": 242, \"Highest Charting Position\": 152, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"All Eyes On Me\", \"Streams\": 5347263, \"Artist\": \"Bo Burnham\", \"Artist Followers\": 1042079.0, \"Song ID\": \"3rV5y8rcQrwRt9fWGLmjOQ\", \"Genre\": \"['comic']\", \"Release Date\": \"2021-06-10\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 81.0, \"Danceability\": 0.352, \"Energy\": 0.424, \"Loudness\": -10.131, \"Speechiness\": 0.0394, \"Acousticness\": 0.733, \"Liveness\": 0.0664, \"Tempo\": 127.047, \"Duration (ms)\": 302951.0, \"Valence\": 0.141, \"Chord\": \"F#/Gb\"}, {\"Index\": 243, \"Highest Charting Position\": 101, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"EVERY CHANCE I GET (feat. Lil Baby & Lil Durk)\", \"Streams\": 5321544, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6278835.0, \"Song ID\": \"1EJIcDYXwSqipW5dFe4uJz\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 83.0, \"Danceability\": 0.477, \"Energy\": 0.727, \"Loudness\": -4.053, \"Speechiness\": 0.286, \"Acousticness\": 0.000866, \"Liveness\": 0.108, \"Tempo\": 150.062, \"Duration (ms)\": 236524.0, \"Valence\": 0.227, \"Chord\": \"D\"}, {\"Index\": 244, \"Highest Charting Position\": 72, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Dick (feat. Doja Cat)\", \"Streams\": 5258628, \"Artist\": \"StarBoi3\", \"Artist Followers\": 17202.0, \"Song ID\": \"3nY8AqaMNNHHLYV4380ol0\", \"Genre\": \"[]\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 83.0, \"Danceability\": 0.647, \"Energy\": 0.608, \"Loudness\": -6.831, \"Speechiness\": 0.42, \"Acousticness\": 0.13, \"Liveness\": 0.0584, \"Tempo\": 125.994, \"Duration (ms)\": 175238.0, \"Valence\": 0.474, \"Chord\": \"A\"}, {\"Index\": 245, \"Highest Charting Position\": 25, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Solar Power\", \"Streams\": 5234112, \"Artist\": \"Lorde\", \"Artist Followers\": 8083566.0, \"Song ID\": \"3KdoeNlEN0BoAKWzaRLNZa\", \"Genre\": \"['art pop', 'dance pop', 'electropop', 'metropopolis', 'nz pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-06-10\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 81.0, \"Danceability\": 0.735, \"Energy\": 0.47, \"Loudness\": -9.405, \"Speechiness\": 0.1, \"Acousticness\": 0.266, \"Liveness\": 0.32, \"Tempo\": 87.971, \"Duration (ms)\": 192621.0, \"Valence\": 0.897, \"Chord\": \"E\"}, {\"Index\": 246, \"Highest Charting Position\": 4, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Your Power\", \"Streams\": 5135380, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47014200.0, \"Song ID\": \"042Sl6Mn83JHyLEqdK7uI0\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-07-30\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 81.0, \"Danceability\": 0.632, \"Energy\": 0.284, \"Loudness\": -14.025, \"Speechiness\": 0.0801, \"Acousticness\": 0.932, \"Liveness\": 0.233, \"Tempo\": 129.642, \"Duration (ms)\": 245897.0, \"Valence\": 0.208, \"Chord\": \"A\"}, {\"Index\": 247, \"Highest Charting Position\": 189, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Lieben wir\", \"Streams\": 5029898, \"Artist\": \"Shirin David\", \"Artist Followers\": 558345.0, \"Song ID\": \"49gzU1IS1B6P3GATSZ5eCE\", \"Genre\": \"['frauenrap', 'german hip hop', 'german pop']\", \"Release Date\": \"2021-07-01\", \"Weeks Charted\": \"2021-07-02--2021-07-09\", \"Popularity\": 77.0, \"Danceability\": 0.871, \"Energy\": 0.669, \"Loudness\": -7.62, \"Speechiness\": 0.329, \"Acousticness\": 0.0113, \"Liveness\": 0.0795, \"Tempo\": 95.939, \"Duration (ms)\": 155363.0, \"Valence\": 0.806, \"Chord\": \"A#/Bb\"}, {\"Index\": 248, \"Highest Charting Position\": 8, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Whoopty\", \"Streams\": 5013017, \"Artist\": \"CJ\", \"Artist Followers\": 180454.0, \"Song ID\": \"5vGLcdRuSbUhD8ScwsGSdA\", \"Genre\": \"['nyc rap']\", \"Release Date\": \"2020-08-20\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 81.0, \"Danceability\": 0.719, \"Energy\": 0.648, \"Loudness\": -7.6, \"Speechiness\": 0.125, \"Acousticness\": 0.2, \"Liveness\": 0.127, \"Tempo\": 140.201, \"Duration (ms)\": 123263.0, \"Valence\": 0.66, \"Chord\": \"D#/Eb\"}, {\"Index\": 249, \"Highest Charting Position\": 55, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Batom de Cereja - Ao Vivo\", \"Streams\": 5011753, \"Artist\": \"Israel & Rodolffo\", \"Artist Followers\": 1097789.0, \"Song ID\": \"2MZQAvsA7aZDssppBLRxYp\", \"Genre\": \"['sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2021-01-29\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 83.0, \"Danceability\": 0.606, \"Energy\": 0.908, \"Loudness\": -6.201, \"Speechiness\": 0.0565, \"Acousticness\": 0.556, \"Liveness\": 0.19, \"Tempo\": 171.966, \"Duration (ms)\": 140942.0, \"Valence\": 0.798, \"Chord\": \"F#/Gb\"}, {\"Index\": 250, \"Highest Charting Position\": 11, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Prisoner (feat. Dua Lipa)\", \"Streams\": 5005018, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15770302.0, \"Song ID\": \"5JqZ3oqF00jkT81foAFvqg\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 79.0, \"Danceability\": 0.781, \"Energy\": 0.67, \"Loudness\": -3.912, \"Speechiness\": 0.0452, \"Acousticness\": 0.0103, \"Liveness\": 0.0761, \"Tempo\": 127.99, \"Duration (ms)\": 169333.0, \"Valence\": 0.595, \"Chord\": \"D#/Eb\"}, {\"Index\": 251, \"Highest Charting Position\": 136, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Stereo Hearts (feat. Adam Levine)\", \"Streams\": 4992345, \"Artist\": \"Gym Class Heroes\", \"Artist Followers\": 1275345.0, \"Song ID\": \"0qOnSQQF0yzuPWsXrQ9paz\", \"Genre\": \"['dance pop', 'pop rap']\", \"Release Date\": \"2011-11-11\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 82.0, \"Danceability\": 0.646, \"Energy\": 0.795, \"Loudness\": -3.293, \"Speechiness\": 0.0976, \"Acousticness\": 0.0319, \"Liveness\": 0.267, \"Tempo\": 89.99, \"Duration (ms)\": 210960.0, \"Valence\": 0.796, \"Chord\": \"A\"}, {\"Index\": 252, \"Highest Charting Position\": 32, \"Number of Times Charted\": 36, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Reloj\", \"Streams\": 4980155, \"Artist\": \"Rauw Alejandro, Anuel AA\", \"Artist Followers\": 6080597.0, \"Song ID\": \"7r9ZhitdQBONTFOiJW5mr8\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-10-22\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 79.0, \"Danceability\": 0.823, \"Energy\": 0.537, \"Loudness\": -2.639, \"Speechiness\": 0.209, \"Acousticness\": 0.176, \"Liveness\": 0.123, \"Tempo\": 175.946, \"Duration (ms)\": 231595.0, \"Valence\": 0.615, \"Chord\": \"G#/Ab\"}, {\"Index\": 253, \"Highest Charting Position\": 81, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"malibu\", \"Streams\": 4973063, \"Artist\": \"sangiovanni\", \"Artist Followers\": 384097.0, \"Song ID\": \"01hEpx8jnOG4q7nDK14Rhi\", \"Genre\": \"[]\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.733, \"Energy\": 0.736, \"Loudness\": -5.123, \"Speechiness\": 0.111, \"Acousticness\": 0.028, \"Liveness\": 0.131, \"Tempo\": 147.897, \"Duration (ms)\": 166216.0, \"Valence\": 0.669, \"Chord\": \"G\"}, {\"Index\": 254, \"Highest Charting Position\": 101, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Eladio Carrion: Bzrp Music Sessions, Vol. 40\", \"Streams\": 4965913, \"Artist\": \"Bizarrap, Eladio Carrion\", \"Artist Followers\": 3126961.0, \"Song ID\": \"1VauUM5CBX7nkLcgafQL2B\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2021-06-09\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 81.0, \"Danceability\": 0.783, \"Energy\": 0.524, \"Loudness\": -6.455, \"Speechiness\": 0.0554, \"Acousticness\": 0.241, \"Liveness\": 0.271, \"Tempo\": 117.496, \"Duration (ms)\": 164896.0, \"Valence\": 0.839, \"Chord\": \"F\"}, {\"Index\": 255, \"Highest Charting Position\": 117, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Do I Wanna Know?\", \"Streams\": 4938586, \"Artist\": \"Arctic Monkeys\", \"Artist Followers\": 12369079.0, \"Song ID\": \"5FVd6KXrgO9B3JPmC8OPst\", \"Genre\": \"['garage rock', 'permanent wave', 'rock', 'sheffield indie']\", \"Release Date\": \"2013-09-09\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 84.0, \"Danceability\": 0.548, \"Energy\": 0.532, \"Loudness\": -7.596, \"Speechiness\": 0.0323, \"Acousticness\": 0.186, \"Liveness\": 0.217, \"Tempo\": 85.03, \"Duration (ms)\": 272394.0, \"Valence\": 0.405, \"Chord\": \"F\"}, {\"Index\": 256, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"LUMBERJACK\", \"Streams\": 11756283, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"0BiK5BbYNFLb88CCOxBFJe\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 76.0, \"Danceability\": 0.386, \"Energy\": 0.762, \"Loudness\": -6.341, \"Speechiness\": 0.564, \"Acousticness\": 0.122, \"Liveness\": 0.527, \"Tempo\": 170.691, \"Duration (ms)\": 138312.0, \"Valence\": 0.433, \"Chord\": \"A\"}, {\"Index\": 257, \"Highest Charting Position\": 47, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"LEMONHEAD (feat. 42 Dugg)\", \"Streams\": 11380679, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"5fbHRCsGpFIOLRtlhCRFDR\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 78.0, \"Danceability\": 0.62, \"Energy\": 0.586, \"Loudness\": -6.612, \"Speechiness\": 0.212, \"Acousticness\": 0.155, \"Liveness\": 0.535, \"Tempo\": 137.131, \"Duration (ms)\": 130980.0, \"Valence\": 0.487, \"Chord\": \"C#/Db\"}, {\"Index\": 258, \"Highest Charting Position\": 59, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"HOT WIND BLOWS (feat. Lil Wayne)\", \"Streams\": 9889197, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"3JJL91ilRV6fXhKqu0FGXs\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 77.0, \"Danceability\": 0.371, \"Energy\": 0.75, \"Loudness\": -5.382, \"Speechiness\": 0.402, \"Acousticness\": 0.601, \"Liveness\": 0.482, \"Tempo\": 173.456, \"Duration (ms)\": 155293.0, \"Valence\": 0.729, \"Chord\": \"G\"}, {\"Index\": 259, \"Highest Charting Position\": 63, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"CORSO\", \"Streams\": 9503981, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"46oHvXwpEZOFX518we1nJD\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 77.0, \"Danceability\": 0.703, \"Energy\": 0.845, \"Loudness\": -4.851, \"Speechiness\": 0.337, \"Acousticness\": 0.169, \"Liveness\": 0.122, \"Tempo\": 97.672, \"Duration (ms)\": 146482.0, \"Valence\": 0.745, \"Chord\": \"A#/Bb\"}, {\"Index\": 260, \"Highest Charting Position\": 69, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"SWEET / I THOUGHT YOU WANTED TO DANCE (feat. Brent Faiyaz & Fana Hues)\", \"Streams\": 9142721, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"3EG9FJ0ToLfgnc1IG2Z1wz\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 79.0, \"Danceability\": 0.468, \"Energy\": 0.652, \"Loudness\": -4.912, \"Speechiness\": 0.0722, \"Acousticness\": 0.333, \"Liveness\": 0.55, \"Tempo\": 140.223, \"Duration (ms)\": 588139.0, \"Valence\": 0.39, \"Chord\": \"C\"}, {\"Index\": 261, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"SIR BAUDELAIRE (feat. DJ Drama)\", \"Streams\": 8884283, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"4ydmav4vl7hebadtfZtMrg\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 75.0, \"Danceability\": 0.467, \"Energy\": 0.635, \"Loudness\": -6.115, \"Speechiness\": 0.154, \"Acousticness\": 0.314, \"Liveness\": 0.844, \"Tempo\": 127.596, \"Duration (ms)\": 88625.0, \"Valence\": 0.51, \"Chord\": \"G\"}, {\"Index\": 262, \"Highest Charting Position\": 82, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"MASSA\", \"Streams\": 8218423, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"2goHCrsDJaflEwQ930ef0o\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 74.0, \"Danceability\": 0.685, \"Energy\": 0.855, \"Loudness\": -6.724, \"Speechiness\": 0.438, \"Acousticness\": 0.329, \"Liveness\": 0.301, \"Tempo\": 157.181, \"Duration (ms)\": 223719.0, \"Valence\": 0.46, \"Chord\": \"C#/Db\"}, {\"Index\": 263, \"Highest Charting Position\": 85, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"RUNITUP (feat. Teezo Touchdown)\", \"Streams\": 7917707, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"13HsOwrwTA5HgLuoaDHncP\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 75.0, \"Danceability\": 0.665, \"Energy\": 0.469, \"Loudness\": -7.778, \"Speechiness\": 0.13, \"Acousticness\": 0.565, \"Liveness\": 0.219, \"Tempo\": 115.852, \"Duration (ms)\": 229565.0, \"Valence\": 0.142, \"Chord\": \"A#/Bb\"}, {\"Index\": 264, \"Highest Charting Position\": 108, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"MANIFESTO (feat. Domo Genesis)\", \"Streams\": 6988886, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"6qouBO0wJtYc3k7DfKRUBx\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.454, \"Energy\": 0.866, \"Loudness\": -5.348, \"Speechiness\": 0.391, \"Acousticness\": 0.121, \"Liveness\": 0.167, \"Tempo\": 92.463, \"Duration (ms)\": 175123.0, \"Valence\": 0.518, \"Chord\": \"D\"}, {\"Index\": 265, \"Highest Charting Position\": 121, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Get Into It (Yuh)\", \"Streams\": 6503281, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0W6I02J9xcqK8MtSeosEXb\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 80.0, \"Danceability\": 0.912, \"Energy\": 0.655, \"Loudness\": -6.029, \"Speechiness\": 0.162, \"Acousticness\": 0.315, \"Liveness\": 0.0894, \"Tempo\": 91.942, \"Duration (ms)\": 138293.0, \"Valence\": 0.793, \"Chord\": \"G#/Ab\"}, {\"Index\": 266, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"WILSHIRE\", \"Streams\": 6268542, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"1pbbsI2KGPOMu0HmuGccBu\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.555, \"Energy\": 0.712, \"Loudness\": -7.446, \"Speechiness\": 0.323, \"Acousticness\": 0.0451, \"Liveness\": 0.182, \"Tempo\": 78.958, \"Duration (ms)\": 515865.0, \"Valence\": 0.555, \"Chord\": \"C#/Db\"}, {\"Index\": 267, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"RISE! (feat. DAISY WORLD)\", \"Streams\": 6034281, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"4Hta7Oy5W9HD0UgT1P8PPV\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.766, \"Energy\": 0.814, \"Loudness\": -3.367, \"Speechiness\": 0.0733, \"Acousticness\": 0.044, \"Liveness\": 0.195, \"Tempo\": 108.07, \"Duration (ms)\": 203588.0, \"Valence\": 0.481, \"Chord\": \"D\"}, {\"Index\": 268, \"Highest Charting Position\": 165, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Naked\", \"Streams\": 5527865, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0CsR9Y9SnC6ZWmekmVqSHz\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 75.0, \"Danceability\": 0.733, \"Energy\": 0.862, \"Loudness\": -5.736, \"Speechiness\": 0.197, \"Acousticness\": 0.374, \"Liveness\": 0.131, \"Tempo\": 111.076, \"Duration (ms)\": 223560.0, \"Valence\": 0.536, \"Chord\": \"G\"}, {\"Index\": 269, \"Highest Charting Position\": 50, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Having Our Way (feat. Drake)\", \"Streams\": 5424579, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"2NM0qHzx4Ohy8iXHEEgwlO\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 79.0, \"Danceability\": 0.927, \"Energy\": 0.538, \"Loudness\": -3.917, \"Speechiness\": 0.116, \"Acousticness\": 0.0312, \"Liveness\": 0.0945, \"Tempo\": 125.983, \"Duration (ms)\": 278191.0, \"Valence\": 0.221, \"Chord\": \"C#/Db\"}, {\"Index\": 270, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Payday (feat. Young Thug)\", \"Streams\": 5393789, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"2HolBGR6tpiWI80MXoV1dJ\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.619, \"Energy\": 0.707, \"Loudness\": -5.791, \"Speechiness\": 0.0499, \"Acousticness\": 0.0366, \"Liveness\": 0.13, \"Tempo\": 168.995, \"Duration (ms)\": 212947.0, \"Valence\": 0.558, \"Chord\": \"C#/Db\"}, {\"Index\": 271, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Been Like This\", \"Streams\": 5362817, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"7y3xU9vEC1s8DSuuoSYKih\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 74.0, \"Danceability\": 0.678, \"Energy\": 0.531, \"Loudness\": -5.029, \"Speechiness\": 0.0374, \"Acousticness\": 0.126, \"Liveness\": 0.377, \"Tempo\": 99.008, \"Duration (ms)\": 177373.0, \"Valence\": 0.176, \"Chord\": \"A#/Bb\"}, {\"Index\": 272, \"Highest Charting Position\": 138, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"MILLE (feat. Orietta Berti)\", \"Streams\": 5341887, \"Artist\": \"Fedez, Achille Lauro\", \"Artist Followers\": 1650683.0, \"Song ID\": \"6qdMhG7pRFi0csRlFGvLE4\", \"Genre\": \"['italian adult pop', 'italian pop']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 82.0, \"Danceability\": 0.527, \"Energy\": 0.764, \"Loudness\": -4.297, \"Speechiness\": 0.322, \"Acousticness\": 0.016, \"Liveness\": 0.0273, \"Tempo\": 184.339, \"Duration (ms)\": 175924.0, \"Valence\": 0.829, \"Chord\": \"D\"}, {\"Index\": 273, \"Highest Charting Position\": 10, \"Number of Times Charted\": 49, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"UN DIA (ONE DAY) (Feat. Tainy)\", \"Streams\": 5203364, \"Artist\": \"J Balvin, Dua Lipa, Bad Bunny\", \"Artist Followers\": 29051363.0, \"Song ID\": \"0EhpEsp4L0oRGM0vmeaN5e\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 83.0, \"Danceability\": 0.571, \"Energy\": 0.693, \"Loudness\": -8.234, \"Speechiness\": 0.0545, \"Acousticness\": 0.00536, \"Liveness\": 0.173, \"Tempo\": 168.169, \"Duration (ms)\": 232253.0, \"Valence\": 0.393, \"Chord\": \"F#/Gb\"}, {\"Index\": 274, \"Highest Charting Position\": 1, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Savage Love (Laxed - Siren Beat)\", \"Streams\": 5108950, \"Artist\": \"Jawsh 685, Jason Derulo\", \"Artist Followers\": 100604.0, \"Song ID\": \"1xQ6trAsedVPCdbtDAmk0c\", \"Genre\": \"['nz pop']\", \"Release Date\": \"2020-06-11\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 82.0, \"Danceability\": 0.767, \"Energy\": 0.481, \"Loudness\": -8.52, \"Speechiness\": 0.0803, \"Acousticness\": 0.234, \"Liveness\": 0.269, \"Tempo\": 150.076, \"Duration (ms)\": 171375.0, \"Valence\": 0.761, \"Chord\": \"C\"}, {\"Index\": 275, \"Highest Charting Position\": 59, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Poblado\", \"Streams\": 6893939, \"Artist\": \"Crissin, Totoy El Frio, Natan & Shander\", \"Artist Followers\": 29051363.0, \"Song ID\": \"1WedZeiezCmCEOzLwhx0hV\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 89.0, \"Danceability\": 0.813, \"Energy\": 0.809, \"Loudness\": -5.382, \"Speechiness\": 0.0846, \"Acousticness\": 0.102, \"Liveness\": 0.377, \"Tempo\": 93.005, \"Duration (ms)\": 393280.0, \"Valence\": 0.646, \"Chord\": \"D#/Eb\"}, {\"Index\": 276, \"Highest Charting Position\": 17, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Hecha Pa' Mi\", \"Streams\": 6308369, \"Artist\": \"Boza\", \"Artist Followers\": 278679.0, \"Song ID\": \"3VvA1wSxukMLsvXoXtlwWx\", \"Genre\": \"['reggaeton']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 83.0, \"Danceability\": 0.725, \"Energy\": 0.756, \"Loudness\": -5.013, \"Speechiness\": 0.0572, \"Acousticness\": 0.362, \"Liveness\": 0.103, \"Tempo\": 100.07, \"Duration (ms)\": 186133.0, \"Valence\": 0.828, \"Chord\": \"E\"}, {\"Index\": 277, \"Highest Charting Position\": 146, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"working\", \"Streams\": 5666770, \"Artist\": \"Tate McRae, Khalid\", \"Artist Followers\": 1647262.0, \"Song ID\": \"31sSFHIe4NaxltVFOEIcTa\", \"Genre\": \"['alt z', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-06-17\", \"Weeks Charted\": \"2021-06-18--2021-06-25\", \"Popularity\": 80.0, \"Danceability\": 0.783, \"Energy\": 0.435, \"Loudness\": -7.78, \"Speechiness\": 0.0588, \"Acousticness\": 0.282, \"Liveness\": 0.0833, \"Tempo\": 106.974, \"Duration (ms)\": 210220.0, \"Valence\": 0.512, \"Chord\": \"G\"}, {\"Index\": 278, \"Highest Charting Position\": 112, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Petrouchka (feat. PLK)\", \"Streams\": 5511544, \"Artist\": \"Soso Maness\", \"Artist Followers\": 289437.0, \"Song ID\": \"03y045SZqaC94yfXl1cU4E\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais', 'rap marseille']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 79.0, \"Danceability\": 0.624, \"Energy\": 0.802, \"Loudness\": -4.818, \"Speechiness\": 0.311, \"Acousticness\": 0.0597, \"Liveness\": 0.252, \"Tempo\": 133.888, \"Duration (ms)\": 189933.0, \"Valence\": 0.818, \"Chord\": \"F#/Gb\"}, {\"Index\": 279, \"Highest Charting Position\": 11, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"p r i d e . i s . t h e . d e v i l (with Lil Baby)\", \"Streams\": 5430260, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5W8jRrZ6tWrTrqnKRtIQBf\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.861, \"Energy\": 0.656, \"Loudness\": -7.867, \"Speechiness\": 0.425, \"Acousticness\": 0.104, \"Liveness\": 0.0986, \"Tempo\": 88.967, \"Duration (ms)\": 218210.0, \"Valence\": 0.331, \"Chord\": \"E\"}, {\"Index\": 280, \"Highest Charting Position\": 6, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"m y . l i f e (with 21 Savage & Morray)\", \"Streams\": 5246577, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"1D3z6HTiQsNmZxjl7F7eoG\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.597, \"Energy\": 0.587, \"Loudness\": -7.026, \"Speechiness\": 0.137, \"Acousticness\": 0.0622, \"Liveness\": 0.214, \"Tempo\": 140.021, \"Duration (ms)\": 218802.0, \"Valence\": 0.0753, \"Chord\": \"G\"}, {\"Index\": 281, \"Highest Charting Position\": 96, \"Number of Times Charted\": 77, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Jocelyn Flores\", \"Streams\": 5220422, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29539807.0, \"Song ID\": \"7m9OqQk4RVRkw9JJdeAw96\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2017-08-25\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.872, \"Energy\": 0.391, \"Loudness\": -9.144, \"Speechiness\": 0.242, \"Acousticness\": 0.469, \"Liveness\": 0.297, \"Tempo\": 134.021, \"Duration (ms)\": 119133.0, \"Valence\": 0.437, \"Chord\": \"C\"}, {\"Index\": 282, \"Highest Charting Position\": 66, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"No Return (with The Kid LAROI & Lil Durk)\", \"Streams\": 5189427, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"23OYT3SFtoJqhiAUqktbc1\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 80.0, \"Danceability\": 0.479, \"Energy\": 0.645, \"Loudness\": -7.336, \"Speechiness\": 0.302, \"Acousticness\": 0.135, \"Liveness\": 0.0825, \"Tempo\": 155.057, \"Duration (ms)\": 168729.0, \"Valence\": 0.381, \"Chord\": \"F\"}, {\"Index\": 283, \"Highest Charting Position\": 1, \"Number of Times Charted\": 78, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"The Box\", \"Streams\": 5145099, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6603627.0, \"Song ID\": \"0nbXyq5TXYPCO7pr3N8S4I\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.896, \"Energy\": 0.586, \"Loudness\": -6.687, \"Speechiness\": 0.0559, \"Acousticness\": 0.104, \"Liveness\": 0.79, \"Tempo\": 116.971, \"Duration (ms)\": 196653.0, \"Valence\": 0.642, \"Chord\": \"A#/Bb\"}, {\"Index\": 284, \"Highest Charting Position\": 31, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Wellerman - Sea Shanty / 220 KID x Billen Ted Remix\", \"Streams\": 5124606, \"Artist\": \"Nathan Evans\", \"Artist Followers\": 140812.0, \"Song ID\": \"3iw6V4LH7yPj1ESORX9RIN\", \"Genre\": \"[]\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 83.0, \"Danceability\": 0.722, \"Energy\": 0.893, \"Loudness\": -3.255, \"Speechiness\": 0.0475, \"Acousticness\": 0.0441, \"Liveness\": 0.0673, \"Tempo\": 119.932, \"Duration (ms)\": 116750.0, \"Valence\": 0.439, \"Chord\": \"C\"}, {\"Index\": 285, \"Highest Charting Position\": 170, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Can't Hold Us - feat. Ray Dalton\", \"Streams\": 5085147, \"Artist\": \"Macklemore & Ryan Lewis\", \"Artist Followers\": 2562082.0, \"Song ID\": \"3bidbhpOYeV4knp8AIu8Xn\", \"Genre\": \"['modern rock', 'pop rap', 'seattle hip hop']\", \"Release Date\": \"2012-10-09\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.641, \"Energy\": 0.922, \"Loudness\": -4.457, \"Speechiness\": 0.0786, \"Acousticness\": 0.0291, \"Liveness\": 0.0862, \"Tempo\": 146.078, \"Duration (ms)\": 258343.0, \"Valence\": 0.847, \"Chord\": \"D\"}, {\"Index\": 286, \"Highest Charting Position\": 6, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Anyone\", \"Streams\": 5079587, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 1250353.0, \"Song ID\": \"2RwMwWo43LapkA4raptxaB\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-01-31--2020-02-07\", \"Popularity\": 0.0, \"Danceability\": 0.686, \"Energy\": 0.538, \"Loudness\": -8.026, \"Speechiness\": 0.0345, \"Acousticness\": 0.181, \"Liveness\": 0.113, \"Tempo\": 115.884, \"Duration (ms)\": 190779.0, \"Valence\": 0.584, \"Chord\": \"D\"}, {\"Index\": 287, \"Highest Charting Position\": 39, \"Number of Times Charted\": 45, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"my ex's best friend (with blackbear)\", \"Streams\": 5048079, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3864419.0, \"Song ID\": \"7kDUspsoYfLkWnZR7qwHZl\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 83.0, \"Danceability\": 0.731, \"Energy\": 0.675, \"Loudness\": -5.134, \"Speechiness\": 0.0434, \"Acousticness\": 0.00473, \"Liveness\": 0.141, \"Tempo\": 124.939, \"Duration (ms)\": 139461.0, \"Valence\": 0.298, \"Chord\": \"F\"}, {\"Index\": 288, \"Highest Charting Position\": 133, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Just the Way You Are\", \"Streams\": 5043647, \"Artist\": \"Bruno Mars\", \"Artist Followers\": 32574754.0, \"Song ID\": \"7BqBn9nzAq8spo5e7cZ0dJ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2010-10-05\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 80.0, \"Danceability\": 0.637, \"Energy\": 0.843, \"Loudness\": -5.413, \"Speechiness\": 0.0432, \"Acousticness\": 0.0151, \"Liveness\": 0.0876, \"Tempo\": 109.012, \"Duration (ms)\": 220733.0, \"Valence\": 0.434, \"Chord\": \"F\"}, {\"Index\": 289, \"Highest Charting Position\": 17, \"Number of Times Charted\": 78, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"HIGHEST IN THE ROOM\", \"Streams\": 4975720, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17719446.0, \"Song ID\": \"3eekarcy7kvN4yt5ZFzltW\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.598, \"Energy\": 0.427, \"Loudness\": -8.764, \"Speechiness\": 0.0317, \"Acousticness\": 0.0546, \"Liveness\": 0.21, \"Tempo\": 76.469, \"Duration (ms)\": 175721.0, \"Valence\": 0.0605, \"Chord\": \"G\"}, {\"Index\": 290, \"Highest Charting Position\": 7, \"Number of Times Charted\": 65, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Break My Heart\", \"Streams\": 4971176, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"017PF4Q3l4DBUiWoXk4OWT\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 80.0, \"Danceability\": 0.73, \"Energy\": 0.729, \"Loudness\": -3.434, \"Speechiness\": 0.0884, \"Acousticness\": 0.167, \"Liveness\": 0.349, \"Tempo\": 113.011, \"Duration (ms)\": 221820.0, \"Valence\": 0.467, \"Chord\": \"E\"}, {\"Index\": 291, \"Highest Charting Position\": 2, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Laugh Now Cry Later (feat. Lil Durk)\", \"Streams\": 4916860, \"Artist\": \"Drake\", \"Artist Followers\": 56308172.0, \"Song ID\": \"2SAqBLGA283SUiwJ3xOUVI\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 83.0, \"Danceability\": 0.761, \"Energy\": 0.518, \"Loudness\": -8.871, \"Speechiness\": 0.134, \"Acousticness\": 0.244, \"Liveness\": 0.107, \"Tempo\": 133.976, \"Duration (ms)\": 261493.0, \"Valence\": 0.522, \"Chord\": \"C\"}, {\"Index\": 292, \"Highest Charting Position\": 175, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"We Are The People (feat. Bono & The Edge) - Official UEFA EURO 2020 Song\", \"Streams\": 4912036, \"Artist\": \"Martin Garrix\", \"Artist Followers\": 14917926.0, \"Song ID\": \"2iL0W5qi0ivZ9WRXbZ74cS\", \"Genre\": \"['dance pop', 'dutch edm', 'edm', 'pop', 'pop dance', 'progressive house', 'tropical house']\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.66, \"Energy\": 0.733, \"Loudness\": -4.619, \"Speechiness\": 0.0359, \"Acousticness\": 0.248, \"Liveness\": 0.17, \"Tempo\": 119.933, \"Duration (ms)\": 217000.0, \"Valence\": 0.304, \"Chord\": \"C\"}, {\"Index\": 293, \"Highest Charting Position\": 23, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Ella No Es Tuya - Remix\", \"Streams\": 4911162, \"Artist\": \"Rochy RD, Myke Towers, Nicki Nicole\", \"Artist Followers\": 319192.0, \"Song ID\": \"5YYW3yRktprLRr47WK219Y\", \"Genre\": \"['dembow', 'dominican pop', 'rap dominicano', 'trap latino']\", \"Release Date\": \"2021-02-03\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 82.0, \"Danceability\": 0.585, \"Energy\": 0.611, \"Loudness\": -4.132, \"Speechiness\": 0.288, \"Acousticness\": 0.39, \"Liveness\": 0.649, \"Tempo\": 97.041, \"Duration (ms)\": 218107.0, \"Valence\": 0.962, \"Chord\": \"F#/Gb\"}, {\"Index\": 294, \"Highest Charting Position\": 176, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"In the End\", \"Streams\": 4910070, \"Artist\": \"Linkin Park\", \"Artist Followers\": 19584111.0, \"Song ID\": \"60a0Rd6pjrkxjPbaKzXjfq\", \"Genre\": \"['alternative metal', 'nu metal', 'post-grunge', 'rap metal']\", \"Release Date\": \"2000-10-24\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-03-19--2021-03-26\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 83.0, \"Danceability\": 0.556, \"Energy\": 0.864, \"Loudness\": -5.87, \"Speechiness\": 0.0584, \"Acousticness\": 0.00958, \"Liveness\": 0.209, \"Tempo\": 105.143, \"Duration (ms)\": 216880.0, \"Valence\": 0.4, \"Chord\": \"D#/Eb\"}, {\"Index\": 295, \"Highest Charting Position\": 119, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"No Role Modelz\", \"Streams\": 4904401, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"62vpWI1CHwFy7tMIcSStl8\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2014-12-09\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 84.0, \"Danceability\": 0.692, \"Energy\": 0.521, \"Loudness\": -8.465, \"Speechiness\": 0.33, \"Acousticness\": 0.301, \"Liveness\": 0.0565, \"Tempo\": 100.45, \"Duration (ms)\": 292987.0, \"Valence\": 0.463, \"Chord\": \"A#/Bb\"}, {\"Index\": 296, \"Highest Charting Position\": 7, \"Number of Times Charted\": 74, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"SICKO MODE\", \"Streams\": 4898977, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17719446.0, \"Song ID\": \"2xLMifQCjDGFmkHkpNLD9h\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2018-08-03\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.834, \"Energy\": 0.73, \"Loudness\": -3.714, \"Speechiness\": 0.222, \"Acousticness\": 0.00513, \"Liveness\": 0.124, \"Tempo\": 155.008, \"Duration (ms)\": 312820.0, \"Valence\": 0.446, \"Chord\": \"G#/Ab\"}, {\"Index\": 297, \"Highest Charting Position\": 161, \"Number of Times Charted\": 41, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Something Just Like This\", \"Streams\": 4862683, \"Artist\": \"The Chainsmokers, Coldplay\", \"Artist Followers\": 18191658.0, \"Song ID\": \"6RUKPb4LETWmmr3iAEQktW\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2017-04-07\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-02-26--2021-03-05\\n2021-01-01--2021-01-08\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.617, \"Energy\": 0.635, \"Loudness\": -6.769, \"Speechiness\": 0.0317, \"Acousticness\": 0.0498, \"Liveness\": 0.164, \"Tempo\": 103.019, \"Duration (ms)\": 247160.0, \"Valence\": 0.446, \"Chord\": \"B\"}, {\"Index\": 298, \"Highest Charting Position\": 84, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"You\", \"Streams\": 4846549, \"Artist\": \"Regard, Troye Sivan, Tate McRae\", \"Artist Followers\": 152226.0, \"Song ID\": \"2cc8Sw1OnCuA5bV8nqWqpE\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop edm', 'slap house', 'tropical house']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 83.0, \"Danceability\": 0.691, \"Energy\": 0.695, \"Loudness\": -5.6, \"Speechiness\": 0.0367, \"Acousticness\": 0.0592, \"Liveness\": 0.0647, \"Tempo\": 106.064, \"Duration (ms)\": 233386.0, \"Valence\": 0.514, \"Chord\": \"C\"}, {\"Index\": 299, \"Highest Charting Position\": 84, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Straightenin\", \"Streams\": 7615531, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"3X2r2CnHOJeV5YekPTgBnK\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 77.0, \"Danceability\": 0.847, \"Energy\": 0.629, \"Loudness\": -5.81, \"Speechiness\": 0.102, \"Acousticness\": 0.0318, \"Liveness\": 0.152, \"Tempo\": 135.976, \"Duration (ms)\": 255532.0, \"Valence\": 0.109, \"Chord\": \"A\"}, {\"Index\": 300, \"Highest Charting Position\": 71, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"GANG GANG (with Lil Wayne)\", \"Streams\": 7506580, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"4VW44pawoOHPUjlN7DX5vk\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 78.0, \"Danceability\": 0.752, \"Energy\": 0.563, \"Loudness\": -8.066, \"Speechiness\": 0.209, \"Acousticness\": 0.146, \"Liveness\": 0.103, \"Tempo\": 145.05, \"Duration (ms)\": 178776.0, \"Valence\": 0.551, \"Chord\": \"D#/Eb\"}, {\"Index\": 301, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Black Hearted\", \"Streams\": 6989528, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"25qk9xa71F1POdI4vj7rbi\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 75.0, \"Danceability\": 0.506, \"Energy\": 0.563, \"Loudness\": -7.664, \"Speechiness\": 0.411, \"Acousticness\": 0.0326, \"Liveness\": 0.0856, \"Tempo\": 168.146, \"Duration (ms)\": 190509.0, \"Valence\": 0.153, \"Chord\": \"C#/Db\"}, {\"Index\": 302, \"Highest Charting Position\": 124, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Lost\", \"Streams\": 6410263, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32262679.0, \"Song ID\": \"18XlJEroUwFo0tLZxscgXE\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 79.0, \"Danceability\": 0.766, \"Energy\": 0.706, \"Loudness\": -6.553, \"Speechiness\": 0.16, \"Acousticness\": 0.223, \"Liveness\": 0.064, \"Tempo\": 142.989, \"Duration (ms)\": 172598.0, \"Valence\": 0.766, \"Chord\": \"G\"}, {\"Index\": 303, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Avalanche\", \"Streams\": 6323268, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"4KD0lLJ4OGonZhBeKtct9I\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 71.0, \"Danceability\": 0.917, \"Energy\": 0.623, \"Loudness\": -8.231, \"Speechiness\": 0.135, \"Acousticness\": 0.0985, \"Liveness\": 0.0833, \"Tempo\": 126.063, \"Duration (ms)\": 206272.0, \"Valence\": 0.687, \"Chord\": \"C#/Db\"}, {\"Index\": 304, \"Highest Charting Position\": 59, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"My Head & My Heart\", \"Streams\": 5470147, \"Artist\": \"Ava Max\", \"Artist Followers\": 3911473.0, \"Song ID\": \"1KixkQVDUHggZMU9dUobgm\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 83.0, \"Danceability\": 0.614, \"Energy\": 0.934, \"Loudness\": -3.709, \"Speechiness\": 0.07, \"Acousticness\": 0.0697, \"Liveness\": 0.121, \"Tempo\": 116.001, \"Duration (ms)\": 174760.0, \"Valence\": 0.436, \"Chord\": \"A\"}, {\"Index\": 305, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Malibu (feat. Polo G)\", \"Streams\": 5456648, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"3v1zVVdzNVNt7vmI9VG2gq\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 72.0, \"Danceability\": 0.831, \"Energy\": 0.719, \"Loudness\": -6.836, \"Speechiness\": 0.235, \"Acousticness\": 0.514, \"Liveness\": 0.0675, \"Tempo\": 155.038, \"Duration (ms)\": 248652.0, \"Valence\": 0.859, \"Chord\": \"A#/Bb\"}, {\"Index\": 306, \"Highest Charting Position\": 36, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"GIRL LIKE ME\", \"Streams\": 5395181, \"Artist\": \"Black Eyed Peas, Shakira\", \"Artist Followers\": 5963840.0, \"Song ID\": \"1zLBsSVxETQOfINOLYvT5m\", \"Genre\": \"['dance pop', 'pop', 'pop rap']\", \"Release Date\": \"2020-11-02\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\", \"Popularity\": 82.0, \"Danceability\": 0.965, \"Energy\": 0.485, \"Loudness\": -8.784, \"Speechiness\": 0.191, \"Acousticness\": 0.0206, \"Liveness\": 0.0655, \"Tempo\": 124.025, \"Duration (ms)\": 222523.0, \"Valence\": 0.312, \"Chord\": \"D\"}, {\"Index\": 307, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Clueless (with Pop Smoke & Fivio Foreign)\", \"Streams\": 5335308, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"4CPcZHzSvIBM8AKhdHUwnL\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 74.0, \"Danceability\": 0.734, \"Energy\": 0.712, \"Loudness\": -6.217, \"Speechiness\": 0.201, \"Acousticness\": 0.391, \"Liveness\": 0.103, \"Tempo\": 140.369, \"Duration (ms)\": 165405.0, \"Valence\": 0.674, \"Chord\": \"F#/Gb\"}, {\"Index\": 308, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Modern Day\", \"Streams\": 5322745, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"2Igem6Q4sfvXGJ3JkG7Baw\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 78.0, \"Danceability\": 0.87, \"Energy\": 0.629, \"Loudness\": -7.598, \"Speechiness\": 0.279, \"Acousticness\": 0.173, \"Liveness\": 0.101, \"Tempo\": 134.944, \"Duration (ms)\": 241790.0, \"Valence\": 0.512, \"Chord\": \"B\"}, {\"Index\": 309, \"Highest Charting Position\": 2, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Therefore I Am\", \"Streams\": 5265630, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"0aACcc1jEv2C6VSmmJbllJ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 0.0, \"Danceability\": 0.889, \"Energy\": 0.34, \"Loudness\": -7.773, \"Speechiness\": 0.0697, \"Acousticness\": 0.218, \"Liveness\": 0.055, \"Tempo\": 94.009, \"Duration (ms)\": 174321.0, \"Valence\": 0.716, \"Chord\": \"B\"}, {\"Index\": 310, \"Highest Charting Position\": 12, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"TE MUDASTE\", \"Streams\": 5242347, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36142273.0, \"Song ID\": \"5RubKOuDoPn5Kj5TLVxSxY\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 82.0, \"Danceability\": 0.811, \"Energy\": 0.637, \"Loudness\": -4.835, \"Speechiness\": 0.0591, \"Acousticness\": 0.234, \"Liveness\": 0.118, \"Tempo\": 92.025, \"Duration (ms)\": 130014.0, \"Valence\": 0.471, \"Chord\": \"A#/Bb\"}, {\"Index\": 311, \"Highest Charting Position\": 108, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Tipo Gin - Ao Vivo\", \"Streams\": 5155238, \"Artist\": \"MC Kevin o Chris\", \"Artist Followers\": 2753929.0, \"Song ID\": \"4llr8mcoauwrHBtjGb7F9S\", \"Genre\": \"['funk 150 bpm', 'funk carioca']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 81.0, \"Danceability\": 0.75, \"Energy\": 0.668, \"Loudness\": -4.49, \"Speechiness\": 0.061, \"Acousticness\": 0.78, \"Liveness\": 0.338, \"Tempo\": 94.998, \"Duration (ms)\": 159147.0, \"Valence\": 0.786, \"Chord\": \"C\"}, {\"Index\": 312, \"Highest Charting Position\": 39, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Higher Power\", \"Streams\": 5142982, \"Artist\": \"Coldplay\", \"Artist Followers\": 1250353.0, \"Song ID\": \"4rOEoKL0fHrxBMhVljpbGW\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 0.0, \"Danceability\": 0.507, \"Energy\": 0.828, \"Loudness\": -6.023, \"Speechiness\": 0.0449, \"Acousticness\": 0.00711, \"Liveness\": 0.261, \"Tempo\": 178.032, \"Duration (ms)\": 211295.0, \"Valence\": 0.489, \"Chord\": \"A#/Bb\"}, {\"Index\": 313, \"Highest Charting Position\": 54, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"SUN GOES DOWN\", \"Streams\": 5125477, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5473565.0, \"Song ID\": \"34eF4BoV8FPk0uhAAoqU7h\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 80.0, \"Danceability\": 0.551, \"Energy\": 0.636, \"Loudness\": -6.798, \"Speechiness\": 0.054, \"Acousticness\": 0.0837, \"Liveness\": 0.112, \"Tempo\": 174.065, \"Duration (ms)\": 168276.0, \"Valence\": 0.148, \"Chord\": \"D\"}, {\"Index\": 314, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Painting Pictures\", \"Streams\": 5119845, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"25uBGaikHi0DhMiGMfuXYE\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 72.0, \"Danceability\": 0.522, \"Energy\": 0.466, \"Loudness\": -8.05, \"Speechiness\": 0.458, \"Acousticness\": 0.331, \"Liveness\": 0.11, \"Tempo\": 78.43, \"Duration (ms)\": 137692.0, \"Valence\": 0.459, \"Chord\": \"D#/Eb\"}, {\"Index\": 315, \"Highest Charting Position\": 1, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Rain On Me (with Ariana Grande)\", \"Streams\": 5041656, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18572085.0, \"Song ID\": \"24ySl2hOPGCDcxBxFIqWBu\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 79.0, \"Danceability\": 0.672, \"Energy\": 0.855, \"Loudness\": -3.764, \"Speechiness\": 0.0397, \"Acousticness\": 0.021, \"Liveness\": 0.323, \"Tempo\": 123.056, \"Duration (ms)\": 182200.0, \"Valence\": 0.646, \"Chord\": \"A\"}, {\"Index\": 316, \"Highest Charting Position\": 97, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Hats Off (feat. Travis Scott)\", \"Streams\": 7324233, \"Artist\": \"Lil Baby, Lil Durk\", \"Artist Followers\": 7805880.0, \"Song ID\": \"4lUmnwRybYH7mMzf16xB0y\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-06-04--2021-06-11\", \"Popularity\": 81.0, \"Danceability\": 0.596, \"Energy\": 0.65, \"Loudness\": -5.167, \"Speechiness\": 0.337, \"Acousticness\": 0.138, \"Liveness\": 0.14, \"Tempo\": 133.997, \"Duration (ms)\": 257428.0, \"Valence\": 0.188, \"Chord\": \"A\"}, {\"Index\": 317, \"Highest Charting Position\": 117, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Last Train Home\", \"Streams\": 6439718, \"Artist\": \"John Mayer\", \"Artist Followers\": 5178156.0, \"Song ID\": \"0tgBtQ0ISnMQOKorrN9HLX\", \"Genre\": \"['neo mellow', 'pop rock', 'singer-songwriter']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-06-04--2021-06-11\", \"Popularity\": 75.0, \"Danceability\": 0.591, \"Energy\": 0.831, \"Loudness\": -6.612, \"Speechiness\": 0.0355, \"Acousticness\": 0.235, \"Liveness\": 0.0571, \"Tempo\": 93.007, \"Duration (ms)\": 187307.0, \"Valence\": 0.678, \"Chord\": \"E\"}, {\"Index\": 318, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Voice of the Heroes\", \"Streams\": 6249801, \"Artist\": \"Lil Baby, Lil Durk\", \"Artist Followers\": 7805880.0, \"Song ID\": \"4lUmnwRybYH7mMzf16xB0y\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-06-04--2021-06-11\", \"Popularity\": 81.0, \"Danceability\": 0.596, \"Energy\": 0.65, \"Loudness\": -5.167, \"Speechiness\": 0.337, \"Acousticness\": 0.138, \"Liveness\": 0.14, \"Tempo\": 133.997, \"Duration (ms)\": 257428.0, \"Valence\": 0.188, \"Chord\": \"A\"}, {\"Index\": 319, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"0X1=LOVESONG (I Know I Love you)\", \"Streams\": 6040553, \"Artist\": \"TOMORROW X TOGETHER, Seori\", \"Artist Followers\": 4136553.0, \"Song ID\": \"1Z8TPHiKeCUyClxV6WTTIf\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-05-31\", \"Weeks Charted\": \"2021-06-04--2021-06-11\", \"Popularity\": 81.0, \"Danceability\": 0.584, \"Energy\": 0.836, \"Loudness\": -4.925, \"Speechiness\": 0.079, \"Acousticness\": 0.0558, \"Liveness\": 0.0663, \"Tempo\": 104.973, \"Duration (ms)\": 202204.0, \"Valence\": 0.484, \"Chord\": \"C\"}, {\"Index\": 320, \"Highest Charting Position\": 10, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"a m a r i\", \"Streams\": 5645966, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"2cnKST6T9qUo2i907lm8zX\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 79.0, \"Danceability\": 0.725, \"Energy\": 0.713, \"Loudness\": -6.173, \"Speechiness\": 0.187, \"Acousticness\": 0.127, \"Liveness\": 0.617, \"Tempo\": 65.988, \"Duration (ms)\": 148421.0, \"Valence\": 0.207, \"Chord\": \"E\"}, {\"Index\": 321, \"Highest Charting Position\": 72, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"NEVER LEFT\", \"Streams\": 5552212, \"Artist\": \"Lil Tecca\", \"Artist Followers\": 4016497.0, \"Song ID\": \"21UkXrc9kD48rNpTMI2ecz\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2021-05-06\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 82.0, \"Danceability\": 0.807, \"Energy\": 0.659, \"Loudness\": -6.92, \"Speechiness\": 0.332, \"Acousticness\": 0.0224, \"Liveness\": 0.309, \"Tempo\": 82.465, \"Duration (ms)\": 168727.0, \"Valence\": 0.438, \"Chord\": \"B\"}, {\"Index\": 322, \"Highest Charting Position\": 27, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Solid (feat. Drake)\", \"Streams\": 5347781, \"Artist\": \"Young Stoner Life, Young Thug, Gunna\", \"Artist Followers\": 61930.0, \"Song ID\": \"6rTInqW3YECMkQsBEHw4sd\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 82.0, \"Danceability\": 0.887, \"Energy\": 0.485, \"Loudness\": -9.358, \"Speechiness\": 0.2, \"Acousticness\": 0.0392, \"Liveness\": 0.141, \"Tempo\": 125.987, \"Duration (ms)\": 215693.0, \"Valence\": 0.328, \"Chord\": \"B\"}, {\"Index\": 323, \"Highest Charting Position\": 21, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"La Nota\", \"Streams\": 5300884, \"Artist\": \"Manuel Turizo, Rauw Alejandro, Myke Towers\", \"Artist Followers\": 7904381.0, \"Song ID\": \"7ndTONDDRFGiPnnhOzOXxq\", \"Genre\": \"['colombian pop', 'latin', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2020-10-08\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 79.0, \"Danceability\": 0.736, \"Energy\": 0.632, \"Loudness\": -4.939, \"Speechiness\": 0.0648, \"Acousticness\": 0.18, \"Liveness\": 0.349, \"Tempo\": 92.03, \"Duration (ms)\": 216107.0, \"Valence\": 0.503, \"Chord\": \"B\"}, {\"Index\": 324, \"Highest Charting Position\": 47, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Golden\", \"Streams\": 5298893, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16112621.0, \"Song ID\": \"45S5WTQEGOB1VHr1Q4FuPl\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 83.0, \"Danceability\": 0.448, \"Energy\": 0.838, \"Loudness\": -5.257, \"Speechiness\": 0.0557, \"Acousticness\": 0.21, \"Liveness\": 0.131, \"Tempo\": 139.863, \"Duration (ms)\": 208907.0, \"Valence\": 0.254, \"Chord\": \"E\"}, {\"Index\": 325, \"Highest Charting Position\": 127, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"CORALINE\", \"Streams\": 5241813, \"Artist\": \"M\\u00e5neskin\", \"Artist Followers\": 3377762.0, \"Song ID\": \"7HMz8o0m7ASQ3ImFPfhWTY\", \"Genre\": \"['indie rock italiano', 'italian pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\", \"Popularity\": 81.0, \"Danceability\": 0.363, \"Energy\": 0.678, \"Loudness\": -4.939, \"Speechiness\": 0.0995, \"Acousticness\": 0.0299, \"Liveness\": 0.324, \"Tempo\": 162.124, \"Duration (ms)\": 300413.0, \"Valence\": 0.321, \"Chord\": \"D\"}, {\"Index\": 326, \"Highest Charting Position\": 3, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"BICHOTA\", \"Streams\": 5201714, \"Artist\": \"KAROL G\", \"Artist Followers\": 1250353.0, \"Song ID\": \"4nYLZSNXJyPq8Jj3cEdykP\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 0.0, \"Danceability\": 0.863, \"Energy\": 0.666, \"Loudness\": -4.158, \"Speechiness\": 0.152, \"Acousticness\": 0.212, \"Liveness\": 0.103, \"Tempo\": 163.908, \"Duration (ms)\": 178947.0, \"Valence\": 0.838, \"Chord\": \"C#/Db\"}, {\"Index\": 327, \"Highest Charting Position\": 96, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Slumber Party (feat. Princess Nokia)\", \"Streams\": 5113574, \"Artist\": \"Ashnikko\", \"Artist Followers\": 1246335.0, \"Song ID\": \"11ZulcYY4lowvcQm4oe3VJ\", \"Genre\": \"['electropop', 'escape room', 'pop']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 82.0, \"Danceability\": 0.964, \"Energy\": 0.398, \"Loudness\": -8.981, \"Speechiness\": 0.0795, \"Acousticness\": 0.00151, \"Liveness\": 0.101, \"Tempo\": 105.012, \"Duration (ms)\": 178405.0, \"Valence\": 0.563, \"Chord\": \"B\"}, {\"Index\": 328, \"Highest Charting Position\": 170, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Killer (feat. Jack Harlow & Cordae) - Remix\", \"Streams\": 5404939, \"Artist\": \"Eminem\", \"Artist Followers\": 46785561.0, \"Song ID\": \"7zl7kehxesNEo2pYkKXTSe\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-05-28--2021-06-04\", \"Popularity\": 76.0, \"Danceability\": 0.924, \"Energy\": 0.73, \"Loudness\": -6.125, \"Speechiness\": 0.274, \"Acousticness\": 0.0525, \"Liveness\": 0.113, \"Tempo\": 99.01, \"Duration (ms)\": 236666.0, \"Valence\": 0.848, \"Chord\": \"B\"}, {\"Index\": 329, \"Highest Charting Position\": 105, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Liberdade (Quando o Grave Bate Forte)\", \"Streams\": 5378350, \"Artist\": \"Alok, Mc Don Juan, Dj GBR\", \"Artist Followers\": 10334543.0, \"Song ID\": \"2QLbRVzixE282JSQjBz2DG\", \"Genre\": \"['electro house', 'pop nacional', 'slap house']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 80.0, \"Danceability\": 0.81, \"Energy\": 0.789, \"Loudness\": -4.032, \"Speechiness\": 0.0498, \"Acousticness\": 0.0254, \"Liveness\": 0.104, \"Tempo\": 129.988, \"Duration (ms)\": 150462.0, \"Valence\": 0.432, \"Chord\": \"F#/Gb\"}, {\"Index\": 330, \"Highest Charting Position\": 108, \"Number of Times Charted\": 51, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"All Girls Are The Same\", \"Streams\": 5372180, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"4VXIryQMWpIdGgYR4TrjT1\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2018-12-10\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-08--2020-05-15\\n2020-04-24--2020-05-01\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.671, \"Energy\": 0.529, \"Loudness\": -7.226, \"Speechiness\": 0.307, \"Acousticness\": 0.0769, \"Liveness\": 0.0856, \"Tempo\": 161.989, \"Duration (ms)\": 165820.0, \"Valence\": 0.203, \"Chord\": \"C\"}, {\"Index\": 331, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"734\", \"Streams\": 5368759, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"6vB8bdQCCTDDIH8fhRfuXA\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-05-28--2021-06-04\", \"Popularity\": 75.0, \"Danceability\": 0.663, \"Energy\": 0.545, \"Loudness\": -3.93, \"Speechiness\": 0.036, \"Acousticness\": 0.123, \"Liveness\": 0.106, \"Tempo\": 78.452, \"Duration (ms)\": 196147.0, \"Valence\": 0.344, \"Chord\": \"D\"}, {\"Index\": 332, \"Highest Charting Position\": 85, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Boy With Luv (feat. Halsey)\", \"Streams\": 5266625, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"5KawlOMHjWeUjQtnuRs22c\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2019-04-12\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2020-11-20--2020-11-27\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-01-17--2020-01-24\", \"Popularity\": 82.0, \"Danceability\": 0.645, \"Energy\": 0.862, \"Loudness\": -4.757, \"Speechiness\": 0.0965, \"Acousticness\": 0.0923, \"Liveness\": 0.192, \"Tempo\": 119.991, \"Duration (ms)\": 229773.0, \"Valence\": 0.798, \"Chord\": \"B\"}, {\"Index\": 333, \"Highest Charting Position\": 82, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Disco Arranhado - Funk Remix\", \"Streams\": 5207186, \"Artist\": \"Malu, DJ Lucas Beat\", \"Artist Followers\": 74814.0, \"Song ID\": \"2Gjt4rUHBUH0rMKpBg0hF4\", \"Genre\": \"[]\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 80.0, \"Danceability\": 0.747, \"Energy\": 0.725, \"Loudness\": -2.564, \"Speechiness\": 0.363, \"Acousticness\": 0.551, \"Liveness\": 0.0626, \"Tempo\": 129.96, \"Duration (ms)\": 125558.0, \"Valence\": 0.904, \"Chord\": \"D\"}, {\"Index\": 334, \"Highest Charting Position\": 4, \"Number of Times Charted\": 70, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Godzilla (feat. Juice WRLD)\", \"Streams\": 5143522, \"Artist\": \"Eminem\", \"Artist Followers\": 46785561.0, \"Song ID\": \"7FIWs0pqAYbP91WWM0vlTQ\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 83.0, \"Danceability\": 0.808, \"Energy\": 0.745, \"Loudness\": -5.26, \"Speechiness\": 0.342, \"Acousticness\": 0.145, \"Liveness\": 0.292, \"Tempo\": 165.995, \"Duration (ms)\": 210800.0, \"Valence\": 0.829, \"Chord\": \"A#/Bb\"}, {\"Index\": 335, \"Highest Charting Position\": 8, \"Number of Times Charted\": 68, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Blueberry Faygo\", \"Streams\": 5085511, \"Artist\": \"Lil Mosey\", \"Artist Followers\": 3816446.0, \"Song ID\": \"6wJYhPfqk3KGhHRG76WzOh\", \"Genre\": \"['melodic rap', 'rap', 'rap conscient', 'trap', 'vapor trap']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 79.0, \"Danceability\": 0.774, \"Energy\": 0.554, \"Loudness\": -7.909, \"Speechiness\": 0.0383, \"Acousticness\": 0.207, \"Liveness\": 0.132, \"Tempo\": 99.034, \"Duration (ms)\": 162547.0, \"Valence\": 0.349, \"Chord\": \"C\"}, {\"Index\": 336, \"Highest Charting Position\": 129, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Somebody That I Used To Know\", \"Streams\": 5068972, \"Artist\": \"Gotye, Kimbra\", \"Artist Followers\": 2263960.0, \"Song ID\": \"4wCmqSrbyCgxEXROQE6vtV\", \"Genre\": \"['australian pop']\", \"Release Date\": \"2011-01-01\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 76.0, \"Danceability\": 0.864, \"Energy\": 0.495, \"Loudness\": -7.036, \"Speechiness\": 0.037, \"Acousticness\": 0.591, \"Liveness\": 0.0992, \"Tempo\": 129.062, \"Duration (ms)\": 244973.0, \"Valence\": 0.72, \"Chord\": \"C\"}, {\"Index\": 337, \"Highest Charting Position\": 4, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Holy (feat. Chance The Rapper)\", \"Streams\": 5063015, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48504126.0, \"Song ID\": \"5u1n1kITHCxxp8twBcZxWy\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 81.0, \"Danceability\": 0.673, \"Energy\": 0.704, \"Loudness\": -8.056, \"Speechiness\": 0.36, \"Acousticness\": 0.196, \"Liveness\": 0.0898, \"Tempo\": 86.919, \"Duration (ms)\": 212093.0, \"Valence\": 0.372, \"Chord\": \"F#/Gb\"}, {\"Index\": 338, \"Highest Charting Position\": 200, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Vida Louca\", \"Streams\": 5051514, \"Artist\": \"Mc Poze do Rodo, Neo Beats, Mainstreet\", \"Artist Followers\": 448447.0, \"Song ID\": \"7IG7laqVpcvIIULrwWP5SA\", \"Genre\": \"['funk carioca', 'funk ostentacao']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-05-28--2021-06-04\", \"Popularity\": 82.0, \"Danceability\": 0.852, \"Energy\": 0.62, \"Loudness\": -5.79, \"Speechiness\": 0.227, \"Acousticness\": 0.359, \"Liveness\": 0.101, \"Tempo\": 92.464, \"Duration (ms)\": 155676.0, \"Valence\": 0.744, \"Chord\": \"F#/Gb\"}, {\"Index\": 339, \"Highest Charting Position\": 15, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"i n t e r l u d e\", \"Streams\": 7880155, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"08LwMWf5Tcfsd752EPzFV0\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 76.0, \"Danceability\": 0.77, \"Energy\": 0.574, \"Loudness\": -5.525, \"Speechiness\": 0.106, \"Acousticness\": 0.0617, \"Liveness\": 0.104, \"Tempo\": 98.962, \"Duration (ms)\": 133022.0, \"Valence\": 0.104, \"Chord\": \"C#/Db\"}, {\"Index\": 340, \"Highest Charting Position\": 95, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Butter (Instrumental)\", \"Streams\": 7450126, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"2Ol2sv6gePRdJrZC1hDVNY\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 70.0, \"Danceability\": 0.429, \"Energy\": 0.387, \"Loudness\": -7.486, \"Speechiness\": 0.0753, \"Acousticness\": 0.000178, \"Liveness\": 0.142, \"Tempo\": 109.893, \"Duration (ms)\": 162147.0, \"Valence\": 0.41, \"Chord\": \"C#/Db\"}, {\"Index\": 341, \"Highest Charting Position\": 25, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Film out\", \"Streams\": 7198095, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"3UHPGOkUcE4hE7sqBF4Snt\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-04-01\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 81.0, \"Danceability\": 0.499, \"Energy\": 0.709, \"Loudness\": -6.404, \"Speechiness\": 0.134, \"Acousticness\": 0.296, \"Liveness\": 0.331, \"Tempo\": 164.032, \"Duration (ms)\": 214621.0, \"Valence\": 0.314, \"Chord\": \"A#/Bb\"}, {\"Index\": 342, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Voil\\u00e0\", \"Streams\": 6935400, \"Artist\": \"Barbara Pravi\", \"Artist Followers\": 75496.0, \"Song ID\": \"1uAOCTevGnyKIDbgZdOCnE\", \"Genre\": \"['eurovision', 'nouvelle chanson francaise']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 72.0, \"Danceability\": 0.447, \"Energy\": 0.337, \"Loudness\": -8.665, \"Speechiness\": 0.0631, \"Acousticness\": 0.773, \"Liveness\": 0.298, \"Tempo\": 135.379, \"Duration (ms)\": 176816.0, \"Valence\": 0.603, \"Chord\": \"D\"}, {\"Index\": 343, \"Highest Charting Position\": 53, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Shy Away\", \"Streams\": 6634722, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20823062.0, \"Song ID\": \"2nG54Y4a3sH9YpfxMolOyi\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 77.0, \"Danceability\": 0.588, \"Energy\": 0.856, \"Loudness\": -5.242, \"Speechiness\": 0.0316, \"Acousticness\": 0.000818, \"Liveness\": 0.238, \"Tempo\": 96.966, \"Duration (ms)\": 175044.0, \"Valence\": 0.635, \"Chord\": \"A\"}, {\"Index\": 344, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Saturday\", \"Streams\": 6628638, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20823062.0, \"Song ID\": \"60dwJ8dnqZ4WrIdiu7LkNR\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 75.0, \"Danceability\": 0.687, \"Energy\": 0.89, \"Loudness\": -5.99, \"Speechiness\": 0.0344, \"Acousticness\": 0.00396, \"Liveness\": 0.0436, \"Tempo\": 113.06, \"Duration (ms)\": 172232.0, \"Valence\": 0.854, \"Chord\": \"G#/Ab\"}, {\"Index\": 345, \"Highest Charting Position\": 18, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"9 5 . s o u t h\", \"Streams\": 6333126, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5R691ipUYRDYW6ehapjoj6\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 75.0, \"Danceability\": 0.713, \"Energy\": 0.793, \"Loudness\": -5.277, \"Speechiness\": 0.397, \"Acousticness\": 0.271, \"Liveness\": 0.727, \"Tempo\": 71.724, \"Duration (ms)\": 196946.0, \"Valence\": 0.203, \"Chord\": \"D\"}, {\"Index\": 346, \"Highest Charting Position\": 67, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Seeing Green (with Drake & Lil Wayne)\", \"Streams\": 6299936, \"Artist\": \"Nicki Minaj\", \"Artist Followers\": 22161310.0, \"Song ID\": \"1TZv3bujNaYz646eezRE91\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'pop rap', 'post-teen pop', 'queens hip hop']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 77.0, \"Danceability\": 0.573, \"Energy\": 0.867, \"Loudness\": -2.876, \"Speechiness\": 0.168, \"Acousticness\": 0.0853, \"Liveness\": 0.38, \"Tempo\": 74.861, \"Duration (ms)\": 339506.0, \"Valence\": 0.231, \"Chord\": \"F\"}, {\"Index\": 347, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Dark Side\", \"Streams\": 6277641, \"Artist\": \"Blind Channel\", \"Artist Followers\": 121225.0, \"Song ID\": \"1ovFnZv6mUe0LzAbfVqOmh\", \"Genre\": \"['eurovision', 'oulu metal', 'trancecore']\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 72.0, \"Danceability\": 0.571, \"Energy\": 0.955, \"Loudness\": -3.795, \"Speechiness\": 0.105, \"Acousticness\": 0.00254, \"Liveness\": 0.274, \"Tempo\": 98.01, \"Duration (ms)\": 177790.0, \"Valence\": 0.437, \"Chord\": \"G\"}, {\"Index\": 348, \"Highest Charting Position\": 137, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"SHUM\", \"Streams\": 6237019, \"Artist\": \"Go_A\", \"Artist Followers\": 107553.0, \"Song ID\": \"7mEDVrAHDnQJStDo8jKJJm\", \"Genre\": \"['eurovision']\", \"Release Date\": \"2021-03-10\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 75.0, \"Danceability\": 0.527, \"Energy\": 0.737, \"Loudness\": -5.34, \"Speechiness\": 0.0642, \"Acousticness\": 0.05, \"Liveness\": 0.105, \"Tempo\": 116.431, \"Duration (ms)\": 172675.0, \"Valence\": 0.499, \"Chord\": \"E\"}, {\"Index\": 349, \"Highest Charting Position\": 69, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"In the morning\", \"Streams\": 5738325, \"Artist\": \"ITZY\", \"Artist Followers\": 2379448.0, \"Song ID\": \"2QdH0rKlV3d9Y6lWzcnlBH\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 79.0, \"Danceability\": 0.847, \"Energy\": 0.814, \"Loudness\": -4.668, \"Speechiness\": 0.152, \"Acousticness\": 0.0825, \"Liveness\": 0.0948, \"Tempo\": 140.057, \"Duration (ms)\": 172359.0, \"Valence\": 0.711, \"Chord\": \"B\"}, {\"Index\": 350, \"Highest Charting Position\": 27, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"l e t . g o . m y . h a n d (with Bas & 6LACK)\", \"Streams\": 5393643, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"0GAyuCo975IHGxxiLKDufB\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 73.0, \"Danceability\": 0.583, \"Energy\": 0.625, \"Loudness\": -8.011, \"Speechiness\": 0.277, \"Acousticness\": 0.506, \"Liveness\": 0.196, \"Tempo\": 89.812, \"Duration (ms)\": 266291.0, \"Valence\": 0.516, \"Chord\": \"C#/Db\"}, {\"Index\": 351, \"Highest Charting Position\": 2, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"What\\u2019s Next\", \"Streams\": 5335112, \"Artist\": \"Drake\", \"Artist Followers\": 56308172.0, \"Song ID\": \"3aQem4jVGdhtg116TmJnHz\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 81.0, \"Danceability\": 0.781, \"Energy\": 0.594, \"Loudness\": -6.959, \"Speechiness\": 0.0485, \"Acousticness\": 0.0136, \"Liveness\": 0.162, \"Tempo\": 129.895, \"Duration (ms)\": 178154.0, \"Valence\": 0.0628, \"Chord\": \"C\"}, {\"Index\": 352, \"Highest Charting Position\": 154, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Ramen & OJ\", \"Streams\": 5282702, \"Artist\": \"Joyner Lucas, Lil Baby\", \"Artist Followers\": 1725025.0, \"Song ID\": \"4TIqzdAssasqx3DAe6cG9J\", \"Genre\": \"['boston hip hop', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 81.0, \"Danceability\": 0.597, \"Energy\": 0.571, \"Loudness\": -6.205, \"Speechiness\": 0.293, \"Acousticness\": 0.492, \"Liveness\": 0.093, \"Tempo\": 106.196, \"Duration (ms)\": 218448.0, \"Valence\": 0.165, \"Chord\": \"C#/Db\"}, {\"Index\": 353, \"Highest Charting Position\": 91, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Cloud 9\", \"Streams\": 5252767, \"Artist\": \"Beach Bunny\", \"Artist Followers\": 618444.0, \"Song ID\": \"6vFsBXYczYsP0H3lgunZOm\", \"Genre\": \"['bubblegrunge', 'chicago indie', 'indie pop', 'pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 81.0, \"Danceability\": 0.637, \"Energy\": 0.929, \"Loudness\": -3.593, \"Speechiness\": 0.0491, \"Acousticness\": 0.00167, \"Liveness\": 0.344, \"Tempo\": 80.974, \"Duration (ms)\": 147351.0, \"Valence\": 0.902, \"Chord\": \"E\"}, {\"Index\": 354, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Tout l'univers\", \"Streams\": 5174437, \"Artist\": \"Gjon's Tears\", \"Artist Followers\": 32257.0, \"Song ID\": \"3MvY2XbGYFi6p2dgmdcOYG\", \"Genre\": \"[]\", \"Release Date\": \"2021-03-10\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 69.0, \"Danceability\": 0.534, \"Energy\": 0.365, \"Loudness\": -9.187, \"Speechiness\": 0.033, \"Acousticness\": 0.81, \"Liveness\": 0.158, \"Tempo\": 123.466, \"Duration (ms)\": 183707.0, \"Valence\": 0.237, \"Chord\": \"A\"}, {\"Index\": 355, \"Highest Charting Position\": 64, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Headshot (feat. Polo G & Fivio Foreign)\", \"Streams\": 5174298, \"Artist\": \"Lil Tjay\", \"Artist Followers\": 3553442.0, \"Song ID\": \"4eNOLmx8r2IJAVKvBBL1jv\", \"Genre\": \"['brooklyn drill', 'melodic rap', 'nyc rap']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 81.0, \"Danceability\": 0.808, \"Energy\": 0.639, \"Loudness\": -7.266, \"Speechiness\": 0.279, \"Acousticness\": 0.0802, \"Liveness\": 0.15, \"Tempo\": 118.0, \"Duration (ms)\": 144349.0, \"Valence\": 0.395, \"Chord\": \"C#/Db\"}, {\"Index\": 356, \"Highest Charting Position\": 198, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Mask\", \"Streams\": 5156496, \"Artist\": \"Dream\", \"Artist Followers\": 727731.0, \"Song ID\": \"3IxMaULfjq4IT2IN6v54PB\", \"Genre\": \"['dream smp']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 76.0, \"Danceability\": 0.636, \"Energy\": 0.749, \"Loudness\": -4.197, \"Speechiness\": 0.0631, \"Acousticness\": 0.195, \"Liveness\": 0.107, \"Tempo\": 117.904, \"Duration (ms)\": 174936.0, \"Valence\": 0.653, \"Chord\": \"C#/Db\"}, {\"Index\": 357, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"10 Years\", \"Streams\": 5152139, \"Artist\": \"Da\\u00f0i Freyr\", \"Artist Followers\": 169137.0, \"Song ID\": \"4O0LQKVT6hGmVGNwizmydg\", \"Genre\": \"['icelandic pop', 'sunnlensk tonlist']\", \"Release Date\": \"2021-03-13\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 70.0, \"Danceability\": 0.798, \"Energy\": 0.621, \"Loudness\": -6.916, \"Speechiness\": 0.0391, \"Acousticness\": 0.0141, \"Liveness\": 0.0926, \"Tempo\": 123.038, \"Duration (ms)\": 166000.0, \"Valence\": 0.443, \"Chord\": \"D\"}, {\"Index\": 358, \"Highest Charting Position\": 127, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Choker\", \"Streams\": 5150176, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20823062.0, \"Song ID\": \"732E6ibFkQR5lNIPEeiEnx\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-04-30--2021-05-07\", \"Popularity\": 72.0, \"Danceability\": 0.7, \"Energy\": 0.664, \"Loudness\": -8.211, \"Speechiness\": 0.0394, \"Acousticness\": 0.306, \"Liveness\": 0.249, \"Tempo\": 142.009, \"Duration (ms)\": 223066.0, \"Valence\": 0.585, \"Chord\": \"G\"}, {\"Index\": 359, \"Highest Charting Position\": 25, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"a p p l y i n g . p r e s s u r e\", \"Streams\": 15967986, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"1d7q712nXjG98HiwHk7HFS\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 71.0, \"Danceability\": 0.699, \"Energy\": 0.759, \"Loudness\": -5.302, \"Speechiness\": 0.311, \"Acousticness\": 0.0814, \"Liveness\": 0.312, \"Tempo\": 83.092, \"Duration (ms)\": 177337.0, \"Valence\": 0.404, \"Chord\": \"C#/Db\"}, {\"Index\": 360, \"Highest Charting Position\": 30, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"1 0 0 . m i l \\u2018 (with Bas)\", \"Streams\": 15171655, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"4n6NDfYake476trCjJRNl0\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 72.0, \"Danceability\": 0.711, \"Energy\": 0.647, \"Loudness\": -5.667, \"Speechiness\": 0.0822, \"Acousticness\": 0.334, \"Liveness\": 0.312, \"Tempo\": 125.092, \"Duration (ms)\": 163302.0, \"Valence\": 0.227, \"Chord\": \"D\"}, {\"Index\": 361, \"Highest Charting Position\": 32, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"p u n c h i n \\u2018 . t h e . c l o c k\", \"Streams\": 14051831, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"57ZUX6TNyKLBydAdVVd02x\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 70.0, \"Danceability\": 0.769, \"Energy\": 0.74, \"Loudness\": -6.579, \"Speechiness\": 0.378, \"Acousticness\": 0.197, \"Liveness\": 0.171, \"Tempo\": 94.104, \"Duration (ms)\": 112579.0, \"Valence\": 0.692, \"Chord\": \"B\"}, {\"Index\": 362, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"t h e . c l i m b . b a c k\", \"Streams\": 12648655, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5lLNBIyjp72btcnrjBG751\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.618, \"Energy\": 0.632, \"Loudness\": -6.973, \"Speechiness\": 0.346, \"Acousticness\": 0.0526, \"Liveness\": 0.353, \"Tempo\": 81.446, \"Duration (ms)\": 306257.0, \"Valence\": 0.319, \"Chord\": \"B\"}, {\"Index\": 363, \"Highest Charting Position\": 48, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"h u n g e r . o n . h i l l s i d e (with Bas)\", \"Streams\": 11647489, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5BwQjRasNcdRPuVWKcHto2\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 71.0, \"Danceability\": 0.563, \"Energy\": 0.703, \"Loudness\": -5.756, \"Speechiness\": 0.0702, \"Acousticness\": 0.126, \"Liveness\": 0.213, \"Tempo\": 94.983, \"Duration (ms)\": 238972.0, \"Valence\": 0.294, \"Chord\": \"D\"}, {\"Index\": 364, \"Highest Charting Position\": 55, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"c l o s e\", \"Streams\": 10712648, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"1D3z6HTiQsNmZxjl7F7eoG\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.597, \"Energy\": 0.587, \"Loudness\": -7.026, \"Speechiness\": 0.137, \"Acousticness\": 0.0622, \"Liveness\": 0.214, \"Tempo\": 140.021, \"Duration (ms)\": 218802.0, \"Valence\": 0.0753, \"Chord\": \"G\"}, {\"Index\": 365, \"Highest Charting Position\": 34, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"WITHOUT YOU (with Miley Cyrus)\", \"Streams\": 6081034, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2230022.0, \"Song ID\": \"1EHUQesfVKwbthtNcpBi9g\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 81.0, \"Danceability\": 0.655, \"Energy\": 0.469, \"Loudness\": -6.257, \"Speechiness\": 0.0292, \"Acousticness\": 0.173, \"Liveness\": 0.0956, \"Tempo\": 92.56, \"Duration (ms)\": 161385.0, \"Valence\": 0.467, \"Chord\": \"C\"}, {\"Index\": 366, \"Highest Charting Position\": 92, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Snow Tha Product: Bzrp Music Sessions, Vol. 39\", \"Streams\": 5595839, \"Artist\": \"Bizarrap, Snow Tha Product\", \"Artist Followers\": 3126961.0, \"Song ID\": \"3ke6it1vTmHtz2ApcIVUz5\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2021-04-28\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 78.0, \"Danceability\": 0.83, \"Energy\": 0.748, \"Loudness\": -5.362, \"Speechiness\": 0.162, \"Acousticness\": 0.354, \"Liveness\": 0.0992, \"Tempo\": 133.028, \"Duration (ms)\": 177443.0, \"Valence\": 0.523, \"Chord\": \"C#/Db\"}, {\"Index\": 367, \"Highest Charting Position\": 87, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Travesuras - Remix\", \"Streams\": 5518444, \"Artist\": \"Nio Garcia, Casper Magico, Ozuna, Wisin & Yandel, Myke Towers, Flow La Movie\", \"Artist Followers\": 2123734.0, \"Song ID\": \"0VWLId2RwPCno9s1cJm2Vy\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-03-11\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 81.0, \"Danceability\": 0.739, \"Energy\": 0.788, \"Loudness\": -5.198, \"Speechiness\": 0.0731, \"Acousticness\": 0.0513, \"Liveness\": 0.282, \"Tempo\": 175.996, \"Duration (ms)\": 324426.0, \"Valence\": 0.473, \"Chord\": \"C#/Db\"}, {\"Index\": 368, \"Highest Charting Position\": 148, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Bubblegum Bitch\", \"Streams\": 5375782, \"Artist\": \"MARINA\", \"Artist Followers\": 2918229.0, \"Song ID\": \"0ZFBKLOZLIM16RAUb5eomN\", \"Genre\": \"['dance pop', 'electropop', 'metropopolis', 'pop', 'post-teen pop', 'uk alternative pop']\", \"Release Date\": \"2012-04-30\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 73.0, \"Danceability\": 0.495, \"Energy\": 0.856, \"Loudness\": -5.123, \"Speechiness\": 0.0311, \"Acousticness\": 0.000219, \"Liveness\": 0.103, \"Tempo\": 158.024, \"Duration (ms)\": 154667.0, \"Valence\": 0.609, \"Chord\": \"C\"}, {\"Index\": 369, \"Highest Charting Position\": 5, \"Number of Times Charted\": 142, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Falling\", \"Streams\": 5294368, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16112621.0, \"Song ID\": \"1ZMiCix7XSAbfAJlEZWMCp\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.567, \"Energy\": 0.267, \"Loudness\": -6.502, \"Speechiness\": 0.0299, \"Acousticness\": 0.839, \"Liveness\": 0.089, \"Tempo\": 110.011, \"Duration (ms)\": 240133.0, \"Valence\": 0.0592, \"Chord\": \"E\"}, {\"Index\": 370, \"Highest Charting Position\": 182, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Expl\\u00edcito\", \"Streams\": 5278449, \"Artist\": \"Myke Towers\", \"Artist Followers\": 6150675.0, \"Song ID\": \"6qraVL4IJaIj0IuEexYJNa\", \"Genre\": \"['trap latino']\", \"Release Date\": \"2020-12-15\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-03-26--2021-04-02\", \"Popularity\": 81.0, \"Danceability\": 0.828, \"Energy\": 0.83, \"Loudness\": -3.371, \"Speechiness\": 0.047, \"Acousticness\": 0.348, \"Liveness\": 0.0613, \"Tempo\": 95.007, \"Duration (ms)\": 195066.0, \"Valence\": 0.422, \"Chord\": \"D\"}, {\"Index\": 371, \"Highest Charting Position\": 58, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"No Te Enamores - Remix\", \"Streams\": 5218146, \"Artist\": \"Milly, Farruko, Nio Garcia, Jay Wheeler, Amenazzy\", \"Artist Followers\": 22718.0, \"Song ID\": \"2mM3gZ0BbPwPPMelbA8vgt\", \"Genre\": \"['reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 79.0, \"Danceability\": 0.824, \"Energy\": 0.837, \"Loudness\": -4.603, \"Speechiness\": 0.107, \"Acousticness\": 0.573, \"Liveness\": 0.271, \"Tempo\": 100.021, \"Duration (ms)\": 289933.0, \"Valence\": 0.58, \"Chord\": \"F\"}, {\"Index\": 372, \"Highest Charting Position\": 110, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"PROBLEMA\", \"Streams\": 5215973, \"Artist\": \"Daddy Yankee\", \"Artist Followers\": 1250353.0, \"Song ID\": \"7vzPjsX8UzlPKKtV47qGPn\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 0.0, \"Danceability\": 0.773, \"Energy\": 0.8, \"Loudness\": -3.17, \"Speechiness\": 0.0987, \"Acousticness\": 0.0613, \"Liveness\": 0.0327, \"Tempo\": 89.988, \"Duration (ms)\": 184507.0, \"Valence\": 0.842, \"Chord\": \"A#/Bb\"}, {\"Index\": 373, \"Highest Charting Position\": 5, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Lonely (with benny blanco)\", \"Streams\": 5191697, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48504126.0, \"Song ID\": \"4y4spB9m0Q6026KfkAvy9Q\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 80.0, \"Danceability\": 0.631, \"Energy\": 0.239, \"Loudness\": -7.071, \"Speechiness\": 0.0398, \"Acousticness\": 0.864, \"Liveness\": 0.116, \"Tempo\": 79.859, \"Duration (ms)\": 149297.0, \"Valence\": 0.0927, \"Chord\": \"B\"}, {\"Index\": 374, \"Highest Charting Position\": 77, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Cupid's Chokehold / Breakfast in America\", \"Streams\": 5165035, \"Artist\": \"Gym Class Heroes\", \"Artist Followers\": 1275345.0, \"Song ID\": \"2Lhdl74nwwVGOE2Gv35QuK\", \"Genre\": \"['dance pop', 'pop rap']\", \"Release Date\": \"2005-02-22\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 81.0, \"Danceability\": 0.72, \"Energy\": 0.744, \"Loudness\": -6.938, \"Speechiness\": 0.12, \"Acousticness\": 0.237, \"Liveness\": 0.255, \"Tempo\": 78.953, \"Duration (ms)\": 243773.0, \"Valence\": 0.619, \"Chord\": \"C#/Db\"}, {\"Index\": 375, \"Highest Charting Position\": 38, \"Number of Times Charted\": 72, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"If the World Was Ending - feat. Julia Michaels\", \"Streams\": 5127736, \"Artist\": \"JP Saxe\", \"Artist Followers\": 280585.0, \"Song ID\": \"2kJwzbxV2ppxnQoYw4GLBZ\", \"Genre\": \"['alt z', 'canadian contemporary r&b', 'indie cafe pop', 'pop', 'pop rock', 'post-teen pop']\", \"Release Date\": \"2019-10-17\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.464, \"Energy\": 0.473, \"Loudness\": -10.086, \"Speechiness\": 0.129, \"Acousticness\": 0.866, \"Liveness\": 0.109, \"Tempo\": 75.801, \"Duration (ms)\": 208687.0, \"Valence\": 0.604, \"Chord\": \"C#/Db\"}, {\"Index\": 376, \"Highest Charting Position\": 47, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"I DID IT (feat. Post Malone, Megan Thee Stallion, Lil Baby & DaBaby)\", \"Streams\": 7347891, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6278835.0, \"Song ID\": \"20GrahbI4AzAOWxpYfDKkf\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 76.0, \"Danceability\": 0.757, \"Energy\": 0.721, \"Loudness\": -2.906, \"Speechiness\": 0.0691, \"Acousticness\": 0.00196, \"Liveness\": 0.647, \"Tempo\": 124.036, \"Duration (ms)\": 165366.0, \"Valence\": 0.364, \"Chord\": \"E\"}, {\"Index\": 377, \"Highest Charting Position\": 61, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Body\", \"Streams\": 5831357, \"Artist\": \"Russ Millions, Tion Wayne\", \"Artist Followers\": 323203.0, \"Song ID\": \"6uvMKqNlrSvcC4NaKnrwjZ\", \"Genre\": \"['london rap']\", \"Release Date\": \"2021-04-22\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 84.0, \"Danceability\": 0.883, \"Energy\": 0.674, \"Loudness\": -8.043, \"Speechiness\": 0.357, \"Acousticness\": 0.21, \"Liveness\": 0.0678, \"Tempo\": 141.02, \"Duration (ms)\": 278085.0, \"Valence\": 0.73, \"Chord\": \"B\"}, {\"Index\": 378, \"Highest Charting Position\": 10, \"Number of Times Charted\": 69, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"everything i wanted\", \"Streams\": 5448680, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"1OC8hMoqAuWmTWJ4heJNlO\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.704, \"Energy\": 0.225, \"Loudness\": -14.454, \"Speechiness\": 0.0994, \"Acousticness\": 0.901, \"Liveness\": 0.106, \"Tempo\": 120.006, \"Duration (ms)\": 245426.0, \"Valence\": 0.243, \"Chord\": \"F#/Gb\"}, {\"Index\": 379, \"Highest Charting Position\": 169, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"What You Need\", \"Streams\": 5346005, \"Artist\": \"Don Toliver\", \"Artist Followers\": 1605329.0, \"Song ID\": \"6LcX2hBbXaJcK4AuefE936\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2021-05-04\", \"Weeks Charted\": \"2021-05-07--2021-05-14\", \"Popularity\": 76.0, \"Danceability\": 0.664, \"Energy\": 0.655, \"Loudness\": -7.327, \"Speechiness\": 0.0461, \"Acousticness\": 0.059, \"Liveness\": 0.17, \"Tempo\": 129.987, \"Duration (ms)\": 217609.0, \"Valence\": 0.13, \"Chord\": \"A#/Bb\"}, {\"Index\": 380, \"Highest Charting Position\": 115, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"L-Gante: Bzrp Music Sessions, Vol.38\", \"Streams\": 5290877, \"Artist\": \"Bizarrap, L-Gante\", \"Artist Followers\": 3126961.0, \"Song ID\": \"1Crj1zkRMpsEjb9NOR6Zof\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2021-03-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 80.0, \"Danceability\": 0.553, \"Energy\": 0.819, \"Loudness\": -3.083, \"Speechiness\": 0.257, \"Acousticness\": 0.368, \"Liveness\": 0.0915, \"Tempo\": 87.913, \"Duration (ms)\": 192348.0, \"Valence\": 0.761, \"Chord\": \"D\"}, {\"Index\": 381, \"Highest Charting Position\": 19, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"HOLIDAY\", \"Streams\": 5264232, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5473565.0, \"Song ID\": \"6zFMeegAMYQo0mt8rXtrli\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 83.0, \"Danceability\": 0.81, \"Energy\": 0.511, \"Loudness\": -6.924, \"Speechiness\": 0.164, \"Acousticness\": 0.12, \"Liveness\": 0.0832, \"Tempo\": 151.947, \"Duration (ms)\": 154998.0, \"Valence\": 0.837, \"Chord\": \"F\"}, {\"Index\": 382, \"Highest Charting Position\": 71, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"At My Worst\", \"Streams\": 5258000, \"Artist\": \"Pink Sweat$\", \"Artist Followers\": 942628.0, \"Song ID\": \"0ri0Han4IRJhzvERHOZTMr\", \"Genre\": \"['bedroom soul', 'pop']\", \"Release Date\": \"2020-07-17\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 79.0, \"Danceability\": 0.813, \"Energy\": 0.415, \"Loudness\": -5.926, \"Speechiness\": 0.0349, \"Acousticness\": 0.777, \"Liveness\": 0.131, \"Tempo\": 91.921, \"Duration (ms)\": 170345.0, \"Valence\": 0.667, \"Chord\": \"C\"}, {\"Index\": 383, \"Highest Charting Position\": 3, \"Number of Times Charted\": 70, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Life Is Good (feat. Drake)\", \"Streams\": 5241227, \"Artist\": \"Future\", \"Artist Followers\": 10488292.0, \"Song ID\": \"5yY9lUy8nbvjM1Uyo1Uqoc\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 81.0, \"Danceability\": 0.676, \"Energy\": 0.609, \"Loudness\": -5.831, \"Speechiness\": 0.481, \"Acousticness\": 0.0706, \"Liveness\": 0.152, \"Tempo\": 142.037, \"Duration (ms)\": 237735.0, \"Valence\": 0.508, \"Chord\": \"D\"}, {\"Index\": 384, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Extasy\", \"Streams\": 5203700, \"Artist\": \"187 Strassenbande, Bonez MC, Frauenarzt\", \"Artist Followers\": 1223734.0, \"Song ID\": \"79lc69ZXfL4WmJIzVSDmWT\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-05-07--2021-05-14\", \"Popularity\": 67.0, \"Danceability\": 0.863, \"Energy\": 0.739, \"Loudness\": -5.879, \"Speechiness\": 0.153, \"Acousticness\": 0.0289, \"Liveness\": 0.0931, \"Tempo\": 129.964, \"Duration (ms)\": 174021.0, \"Valence\": 0.547, \"Chord\": \"A\"}, {\"Index\": 385, \"Highest Charting Position\": 7, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Wishing Well\", \"Streams\": 5125706, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"2U5WueTLIK5WJLD7mvDODv\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 83.0, \"Danceability\": 0.65, \"Energy\": 0.613, \"Loudness\": -6.13, \"Speechiness\": 0.128, \"Acousticness\": 0.00336, \"Liveness\": 0.267, \"Tempo\": 149.972, \"Duration (ms)\": 194621.0, \"Valence\": 0.0804, \"Chord\": \"A\"}, {\"Index\": 386, \"Highest Charting Position\": 164, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Fan de Tus Fotos\", \"Streams\": 5103863, \"Artist\": \"Nicky Jam, Romeo Santos\", \"Artist Followers\": 14826679.0, \"Song ID\": \"1mauYRwbpoGQX6itP2FAJC\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-02-08\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\", \"Popularity\": 79.0, \"Danceability\": 0.728, \"Energy\": 0.689, \"Loudness\": -5.718, \"Speechiness\": 0.0725, \"Acousticness\": 0.293, \"Liveness\": 0.109, \"Tempo\": 170.089, \"Duration (ms)\": 197647.0, \"Valence\": 0.431, \"Chord\": \"G\"}, {\"Index\": 387, \"Highest Charting Position\": 82, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Tap\\u00e3o Na Raba\", \"Streams\": 5088848, \"Artist\": \"Ra\\u00ed Saia Rodada\", \"Artist Followers\": 1260752.0, \"Song ID\": \"58pgi1RpcU2fVJsxhm7BIr\", \"Genre\": \"['forro']\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 80.0, \"Danceability\": 0.808, \"Energy\": 0.796, \"Loudness\": -3.169, \"Speechiness\": 0.0305, \"Acousticness\": 0.462, \"Liveness\": 0.155, \"Tempo\": 128.048, \"Duration (ms)\": 175047.0, \"Valence\": 0.799, \"Chord\": \"C#/Db\"}, {\"Index\": 388, \"Highest Charting Position\": 66, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Machu Picchu\", \"Streams\": 5062404, \"Artist\": \"Camilo, Evaluna Montaner\", \"Artist Followers\": 10561047.0, \"Song ID\": \"1LXb70u8SLsvBAPWHMCTMe\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2021-03-01\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 76.0, \"Danceability\": 0.788, \"Energy\": 0.789, \"Loudness\": -2.39, \"Speechiness\": 0.124, \"Acousticness\": 0.397, \"Liveness\": 0.226, \"Tempo\": 167.897, \"Duration (ms)\": 179005.0, \"Valence\": 0.867, \"Chord\": \"C\"}, {\"Index\": 389, \"Highest Charting Position\": 4, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Come & Go (with Marshmello)\", \"Streams\": 5037124, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"2Y0wPrPQBrGhoLn14xRYCG\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 83.0, \"Danceability\": 0.625, \"Energy\": 0.814, \"Loudness\": -5.181, \"Speechiness\": 0.0657, \"Acousticness\": 0.0172, \"Liveness\": 0.158, \"Tempo\": 144.991, \"Duration (ms)\": 205485.0, \"Valence\": 0.535, \"Chord\": \"C\"}, {\"Index\": 390, \"Highest Charting Position\": 71, \"Number of Times Charted\": 72, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Robbery\", \"Streams\": 5024884, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"6Hj9jySrnFppAI0sEMCZpJ\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2019-03-08\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.685, \"Energy\": 0.692, \"Loudness\": -5.122, \"Speechiness\": 0.0457, \"Acousticness\": 0.328, \"Liveness\": 0.153, \"Tempo\": 159.966, \"Duration (ms)\": 240051.0, \"Valence\": 0.578, \"Chord\": \"D\"}, {\"Index\": 391, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Paradigmas\", \"Streams\": 5018076, \"Artist\": \"Jorge & Mateus\", \"Artist Followers\": 15013645.0, \"Song ID\": \"17UfXrL7Run3GyZJW4uRjC\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2021-04-22\", \"Weeks Charted\": \"2021-05-07--2021-05-14\", \"Popularity\": 72.0, \"Danceability\": 0.686, \"Energy\": 0.789, \"Loudness\": -4.103, \"Speechiness\": 0.126, \"Acousticness\": 0.322, \"Liveness\": 0.4, \"Tempo\": 157.932, \"Duration (ms)\": 157355.0, \"Valence\": 0.822, \"Chord\": \"C#/Db\"}, {\"Index\": 392, \"Highest Charting Position\": 53, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"SugarCrash!\", \"Streams\": 5018005, \"Artist\": \"ElyOtto\", \"Artist Followers\": 85617.0, \"Song ID\": \"2ePtv8MlBO9nuuXABqAfEX\", \"Genre\": \"['weirdcore']\", \"Release Date\": \"2020-08-25\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 80.0, \"Danceability\": 0.748, \"Energy\": 0.734, \"Loudness\": -6.499, \"Speechiness\": 0.124, \"Acousticness\": 0.524, \"Liveness\": 0.0975, \"Tempo\": 97.753, \"Duration (ms)\": 80081.0, \"Valence\": 0.368, \"Chord\": \"C\"}, {\"Index\": 393, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"durag activity (with Travis Scott)\", \"Streams\": 7939784, \"Artist\": \"Baby Keem\", \"Artist Followers\": 279741.0, \"Song ID\": \"4JJcP0Rv9AgyPD6ZGaC8EE\", \"Genre\": \"['hip hop', 'rap', 'trap', 'underground hip hop']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-04-30--2021-05-07\", \"Popularity\": 75.0, \"Danceability\": 0.89, \"Energy\": 0.701, \"Loudness\": -5.712, \"Speechiness\": 0.342, \"Acousticness\": 0.00306, \"Liveness\": 0.0895, \"Tempo\": 80.462, \"Duration (ms)\": 225020.0, \"Valence\": 0.505, \"Chord\": \"C\"}, {\"Index\": 394, \"Highest Charting Position\": 113, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"love race (feat. Kellin Quinn)\", \"Streams\": 6325080, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3864419.0, \"Song ID\": \"1F9kEuwT29fgqlovIclu81\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2021-04-29\", \"Weeks Charted\": \"2021-04-30--2021-05-07\", \"Popularity\": 76.0, \"Danceability\": 0.517, \"Energy\": 0.848, \"Loudness\": -4.054, \"Speechiness\": 0.0521, \"Acousticness\": 0.00581, \"Liveness\": 0.214, \"Tempo\": 95.906, \"Duration (ms)\": 188779.0, \"Valence\": 0.429, \"Chord\": \"A#/Bb\"}, {\"Index\": 395, \"Highest Charting Position\": 7, \"Number of Times Charted\": 40, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"POPSTAR (feat. Drake)\", \"Streams\": 6127103, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6278835.0, \"Song ID\": \"6EDO9iiTtwNv6waLwa1UUq\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-07-17\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 80.0, \"Danceability\": 0.8, \"Energy\": 0.56, \"Loudness\": -4.818, \"Speechiness\": 0.261, \"Acousticness\": 0.057, \"Liveness\": 0.134, \"Tempo\": 163.071, \"Duration (ms)\": 200221.0, \"Valence\": 0.45, \"Chord\": \"F\"}, {\"Index\": 396, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"LET IT GO (feat. Justin Bieber & 21 Savage)\", \"Streams\": 6083338, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6278835.0, \"Song ID\": \"1cEhrSF6EylAEqdhUGuNpX\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-04-30--2021-05-07\", \"Popularity\": 75.0, \"Danceability\": 0.877, \"Energy\": 0.444, \"Loudness\": -7.547, \"Speechiness\": 0.172, \"Acousticness\": 0.24, \"Liveness\": 0.169, \"Tempo\": 129.06, \"Duration (ms)\": 165527.0, \"Valence\": 0.658, \"Chord\": \"G#/Ab\"}, {\"Index\": 397, \"Highest Charting Position\": 137, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Girl From Rio\", \"Streams\": 5768836, \"Artist\": \"Anitta\", \"Artist Followers\": 10740222.0, \"Song ID\": \"6CF085Ol0cVda1WqelybEQ\", \"Genre\": \"['funk carioca', 'funk pop', 'pagode baiano', 'pop nacional']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-04-30--2021-05-07\", \"Popularity\": 69.0, \"Danceability\": 0.732, \"Energy\": 0.604, \"Loudness\": -7.472, \"Speechiness\": 0.0443, \"Acousticness\": 0.0112, \"Liveness\": 0.219, \"Tempo\": 139.982, \"Duration (ms)\": 195429.0, \"Valence\": 0.732, \"Chord\": \"C\"}, {\"Index\": 398, \"Highest Charting Position\": 10, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"On The Ground\", \"Streams\": 5655879, \"Artist\": \"ROS\\u00c9\", \"Artist Followers\": 1094731.0, \"Song ID\": \"2pn8dNVSpYnAtlKFC8Q0DJ\", \"Genre\": \"[]\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 74.0, \"Danceability\": 0.311, \"Energy\": 0.607, \"Loudness\": -6.578, \"Speechiness\": 0.11, \"Acousticness\": 0.0174, \"Liveness\": 0.131, \"Tempo\": 188.7, \"Duration (ms)\": 168086.0, \"Valence\": 0.286, \"Chord\": \"C#/Db\"}, {\"Index\": 399, \"Highest Charting Position\": 20, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Mr. Perfectly Fine (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5480722, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2CYVETnhM9aytqrazYYwrK\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 74.0, \"Danceability\": 0.66, \"Energy\": 0.817, \"Loudness\": -6.269, \"Speechiness\": 0.0521, \"Acousticness\": 0.162, \"Liveness\": 0.0667, \"Tempo\": 135.942, \"Duration (ms)\": 277592.0, \"Valence\": 0.714, \"Chord\": \"B\"}, {\"Index\": 400, \"Highest Charting Position\": 42, \"Number of Times Charted\": 60, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"when the party's over\", \"Streams\": 5467596, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"5KWwUzVxubgSPmLIUAQhYt\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.484, \"Energy\": 0.103, \"Loudness\": -14.075, \"Speechiness\": 0.0627, \"Acousticness\": 0.979, \"Liveness\": 0.0895, \"Tempo\": 124.011, \"Duration (ms)\": 199931.0, \"Valence\": 0.194, \"Chord\": \"C#/Db\"}, {\"Index\": 401, \"Highest Charting Position\": 63, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Otra Noche Sin Ti\", \"Streams\": 5377794, \"Artist\": \"J Balvin, Khalid\", \"Artist Followers\": 29051363.0, \"Song ID\": \"2CdTLdDjwZdVcm0bresVWx\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 80.0, \"Danceability\": 0.503, \"Energy\": 0.548, \"Loudness\": -7.564, \"Speechiness\": 0.164, \"Acousticness\": 0.0751, \"Liveness\": 0.145, \"Tempo\": 94.036, \"Duration (ms)\": 228920.0, \"Valence\": 0.441, \"Chord\": \"C\"}, {\"Index\": 402, \"Highest Charting Position\": 33, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Met Him Last Night (feat. Ariana Grande)\", \"Streams\": 5200695, \"Artist\": \"Demi Lovato\", \"Artist Followers\": 20331923.0, \"Song ID\": \"0BI0hfbmqybnd3TezrDME3\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 72.0, \"Danceability\": 0.538, \"Energy\": 0.512, \"Loudness\": -4.548, \"Speechiness\": 0.0262, \"Acousticness\": 0.22, \"Liveness\": 0.101, \"Tempo\": 144.978, \"Duration (ms)\": 204632.0, \"Valence\": 0.12, \"Chord\": \"E\"}, {\"Index\": 403, \"Highest Charting Position\": 100, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Back In Blood (feat. Lil Durk)\", \"Streams\": 5198209, \"Artist\": \"Pooh Shiesty\", \"Artist Followers\": 423237.0, \"Song ID\": \"7JuHVG3qQKQKxC4doneXVW\", \"Genre\": \"['memphis hip hop', 'rap', 'southern hip hop', 'tennessee hip hop', 'trap']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 75.0, \"Danceability\": 0.759, \"Energy\": 0.538, \"Loudness\": -8.256, \"Speechiness\": 0.384, \"Acousticness\": 0.151, \"Liveness\": 0.126, \"Tempo\": 146.933, \"Duration (ms)\": 184490.0, \"Valence\": 0.831, \"Chord\": \"G#/Ab\"}, {\"Index\": 404, \"Highest Charting Position\": 94, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Run It Up (feat. Offset & Moneybagg Yo)\", \"Streams\": 5107084, \"Artist\": \"Lil Tjay\", \"Artist Followers\": 3553442.0, \"Song ID\": \"1dg3qy5DjoJodawfOCgrTP\", \"Genre\": \"['brooklyn drill', 'melodic rap', 'nyc rap']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 81.0, \"Danceability\": 0.88, \"Energy\": 0.575, \"Loudness\": -6.091, \"Speechiness\": 0.163, \"Acousticness\": 0.415, \"Liveness\": 0.109, \"Tempo\": 120.031, \"Duration (ms)\": 232048.0, \"Valence\": 0.671, \"Chord\": \"F#/Gb\"}, {\"Index\": 405, \"Highest Charting Position\": 37, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Mi Ni\\u00f1a\", \"Streams\": 5026961, \"Artist\": \"Wisin, Myke Towers, Los Legendarios\", \"Artist Followers\": 6929075.0, \"Song ID\": \"2bgcUk2A3jjKbCJ7KPquTi\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-23\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 79.0, \"Danceability\": 0.823, \"Energy\": 0.821, \"Loudness\": -3.402, \"Speechiness\": 0.166, \"Acousticness\": 0.31, \"Liveness\": 0.143, \"Tempo\": 99.999, \"Duration (ms)\": 213314.0, \"Valence\": 0.791, \"Chord\": \"G#/Ab\"}, {\"Index\": 406, \"Highest Charting Position\": 9, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"As I Am (feat. Khalid)\", \"Streams\": 5896065, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6F2r4HgpJnvKDmkN6JEN6J\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 72.0, \"Danceability\": 0.595, \"Energy\": 0.543, \"Loudness\": -8.149, \"Speechiness\": 0.038, \"Acousticness\": 0.127, \"Liveness\": 0.0975, \"Tempo\": 99.928, \"Duration (ms)\": 174406.0, \"Valence\": 0.109, \"Chord\": \"B\"}, {\"Index\": 407, \"Highest Charting Position\": 150, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Come Through (feat. Chris Brown)\", \"Streams\": 5531998, \"Artist\": \"H.E.R.\", \"Artist Followers\": 4138951.0, \"Song ID\": \"3krZxyBsWEHfEfJegYaWTd\", \"Genre\": \"['alternative r&b', 'dance pop', 'pop', 'r&b']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-04-23--2021-04-30\", \"Popularity\": 74.0, \"Danceability\": 0.615, \"Energy\": 0.422, \"Loudness\": -8.019, \"Speechiness\": 0.0504, \"Acousticness\": 0.604, \"Liveness\": 0.112, \"Tempo\": 135.859, \"Duration (ms)\": 214094.0, \"Valence\": 0.185, \"Chord\": \"F\"}, {\"Index\": 408, \"Highest Charting Position\": 33, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Goosebumps\", \"Streams\": 5496962, \"Artist\": \"HVME\", \"Artist Followers\": 17719446.0, \"Song ID\": \"5uEYRdEIh9Bo4fpjDd4Na9\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 87.0, \"Danceability\": 0.841, \"Energy\": 0.593, \"Loudness\": -7.846, \"Speechiness\": 0.0379, \"Acousticness\": 0.418, \"Liveness\": 0.124, \"Tempo\": 124.917, \"Duration (ms)\": 162803.0, \"Valence\": 0.808, \"Chord\": \"C#/Db\"}, {\"Index\": 409, \"Highest Charting Position\": 18, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Put Your Records On\", \"Streams\": 5181180, \"Artist\": \"Ritt Momney\", \"Artist Followers\": 100463.0, \"Song ID\": \"6AGOKlMZWLCaEJGnaROtF9\", \"Genre\": \"['bedroom pop']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 81.0, \"Danceability\": 0.399, \"Energy\": 0.491, \"Loudness\": -10.778, \"Speechiness\": 0.0538, \"Acousticness\": 0.0563, \"Liveness\": 0.11, \"Tempo\": 91.066, \"Duration (ms)\": 210463.0, \"Valence\": 0.151, \"Chord\": \"F#/Gb\"}, {\"Index\": 410, \"Highest Charting Position\": 137, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Facas - Ao Vivo\", \"Streams\": 5141640, \"Artist\": \"Diego & Victor Hugo, Bruno & Marrone\", \"Artist Followers\": 1585593.0, \"Song ID\": \"1ere9b9vDw2N3m9d4uiXxa\", \"Genre\": \"['sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2020-10-15\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 79.0, \"Danceability\": 0.443, \"Energy\": 0.509, \"Loudness\": -5.995, \"Speechiness\": 0.0536, \"Acousticness\": 0.615, \"Liveness\": 0.472, \"Tempo\": 160.984, \"Duration (ms)\": 196380.0, \"Valence\": 0.69, \"Chord\": \"D\"}, {\"Index\": 411, \"Highest Charting Position\": 62, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Train Wreck\", \"Streams\": 5081800, \"Artist\": \"James Arthur\", \"Artist Followers\": 8446147.0, \"Song ID\": \"55Am8neGJkdj2ADaM3aw5H\", \"Genre\": \"['pop', 'post-teen pop', 'talent show', 'uk pop']\", \"Release Date\": \"2016-10-28\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 82.0, \"Danceability\": 0.311, \"Energy\": 0.485, \"Loudness\": -5.726, \"Speechiness\": 0.0365, \"Acousticness\": 0.701, \"Liveness\": 0.0726, \"Tempo\": 77.355, \"Duration (ms)\": 208827.0, \"Valence\": 0.225, \"Chord\": \"F#/Gb\"}, {\"Index\": 412, \"Highest Charting Position\": 7, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Monster (Shawn Mendes & Justin Bieber)\", \"Streams\": 5069268, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 33893352.0, \"Song ID\": \"2Z8yfpFX0ZMavHkcIeHiO1\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 79.0, \"Danceability\": 0.652, \"Energy\": 0.383, \"Loudness\": -7.076, \"Speechiness\": 0.0516, \"Acousticness\": 0.0676, \"Liveness\": 0.0828, \"Tempo\": 145.765, \"Duration (ms)\": 178994.0, \"Valence\": 0.549, \"Chord\": \"D\"}, {\"Index\": 413, \"Highest Charting Position\": 6, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"In Your Eyes\", \"Streams\": 5054319, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"7szuecWAPwGoV1e5vGu8tl\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 81.0, \"Danceability\": 0.667, \"Energy\": 0.719, \"Loudness\": -5.371, \"Speechiness\": 0.0346, \"Acousticness\": 0.00285, \"Liveness\": 0.0736, \"Tempo\": 100.021, \"Duration (ms)\": 237520.0, \"Valence\": 0.717, \"Chord\": \"G\"}, {\"Index\": 414, \"Highest Charting Position\": 101, \"Number of Times Charted\": 68, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"SAD!\", \"Streams\": 5051338, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"3ee8Jmje8o58CHK66QrVC2\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2018-03-16\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.74, \"Energy\": 0.613, \"Loudness\": -4.88, \"Speechiness\": 0.145, \"Acousticness\": 0.258, \"Liveness\": 0.123, \"Tempo\": 75.023, \"Duration (ms)\": 166606.0, \"Valence\": 0.473, \"Chord\": \"G#/Ab\"}, {\"Index\": 415, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Good Without\", \"Streams\": 4998044, \"Artist\": \"Mimi Webb\", \"Artist Followers\": 130801.0, \"Song ID\": \"15OCqNPYoLziEAsbVnqRj5\", \"Genre\": \"['alt z', 'indie cafe pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-04-23--2021-04-30\", \"Popularity\": 81.0, \"Danceability\": 0.616, \"Energy\": 0.576, \"Loudness\": -5.495, \"Speechiness\": 0.0532, \"Acousticness\": 0.0723, \"Liveness\": 0.375, \"Tempo\": 89.962, \"Duration (ms)\": 182121.0, \"Valence\": 0.269, \"Chord\": \"B\"}, {\"Index\": 416, \"Highest Charting Position\": 19, \"Number of Times Charted\": 66, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"hot girl bummer\", \"Streams\": 4992396, \"Artist\": \"blackbear\", \"Artist Followers\": 4270131.0, \"Song ID\": \"2mt1IqcFyY1zmYZT8Q3xw9\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.782, \"Energy\": 0.559, \"Loudness\": -7.106, \"Speechiness\": 0.0767, \"Acousticness\": 0.125, \"Liveness\": 0.385, \"Tempo\": 129.992, \"Duration (ms)\": 188344.0, \"Valence\": 0.685, \"Chord\": \"F#/Gb\"}, {\"Index\": 417, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"When I Was Your Man\", \"Streams\": 4945935, \"Artist\": \"Bruno Mars\", \"Artist Followers\": 32603394.0, \"Song ID\": \"0nJW01T7XtvILxQgC5J7Wh\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2012-12-07\", \"Weeks Charted\": \"2021-04-23--2021-04-30\", \"Popularity\": 82.0, \"Danceability\": 0.612, \"Energy\": 0.28, \"Loudness\": -8.648, \"Speechiness\": 0.0434, \"Acousticness\": 0.932, \"Liveness\": 0.088, \"Tempo\": 72.795, \"Duration (ms)\": 213827.0, \"Valence\": 0.387, \"Chord\": \"C\"}, {\"Index\": 418, \"Highest Charting Position\": 73, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"LOCATION\", \"Streams\": 4940701, \"Artist\": \"KAROL G, Anuel AA, J Balvin\", \"Artist Followers\": 1250353.0, \"Song ID\": \"1aH3EQY5LTXjRZQLpl1Gby\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 0.0, \"Danceability\": 0.772, \"Energy\": 0.758, \"Loudness\": -3.891, \"Speechiness\": 0.0482, \"Acousticness\": 0.0433, \"Liveness\": 0.295, \"Tempo\": 115.977, \"Duration (ms)\": 265240.0, \"Valence\": 0.654, \"Chord\": \"A\"}, {\"Index\": 419, \"Highest Charting Position\": 177, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Stressed Out\", \"Streams\": 4913147, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20823062.0, \"Song ID\": \"3CRDbSIZ4r5MsZ0YwxuEkn\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2015-05-15\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 83.0, \"Danceability\": 0.734, \"Energy\": 0.637, \"Loudness\": -5.677, \"Speechiness\": 0.141, \"Acousticness\": 0.0462, \"Liveness\": 0.0602, \"Tempo\": 169.977, \"Duration (ms)\": 202333.0, \"Valence\": 0.648, \"Chord\": \"E\"}, {\"Index\": 420, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Ski\", \"Streams\": 7753784, \"Artist\": \"Young Stoner Life, Young Thug, Gunna\", \"Artist Followers\": 61930.0, \"Song ID\": \"6755DFiZ7CWe2WMdTGW5C1\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-04-16--2021-04-23\", \"Popularity\": 78.0, \"Danceability\": 0.953, \"Energy\": 0.621, \"Loudness\": -7.638, \"Speechiness\": 0.221, \"Acousticness\": 0.017, \"Liveness\": 0.0398, \"Tempo\": 123.016, \"Duration (ms)\": 152333.0, \"Valence\": 0.883, \"Chord\": \"G#/Ab\"}, {\"Index\": 421, \"Highest Charting Position\": 75, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Diamonds Dancing (feat. Travis Scott)\", \"Streams\": 7515766, \"Artist\": \"Young Stoner Life, Young Thug, Gunna\", \"Artist Followers\": 61930.0, \"Song ID\": \"7uZqvqXzzYMKrexKxdcGmd\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-04-16--2021-04-23\", \"Popularity\": 69.0, \"Danceability\": 0.851, \"Energy\": 0.703, \"Loudness\": -7.351, \"Speechiness\": 0.303, \"Acousticness\": 0.00949, \"Liveness\": 0.0895, \"Tempo\": 74.017, \"Duration (ms)\": 242600.0, \"Valence\": 0.596, \"Chord\": \"E\"}, {\"Index\": 422, \"Highest Charting Position\": 8, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Love Story (Taylor\\u2019s Version)\", \"Streams\": 6202933, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6YvqWjhGD8mB5QXcbcUKtx\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 73.0, \"Danceability\": 0.627, \"Energy\": 0.792, \"Loudness\": -4.311, \"Speechiness\": 0.031, \"Acousticness\": 0.13, \"Liveness\": 0.0845, \"Tempo\": 119.054, \"Duration (ms)\": 235767.0, \"Valence\": 0.415, \"Chord\": \"D\"}, {\"Index\": 423, \"Highest Charting Position\": 107, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Ele \\u00c9 Ele, Eu Sou Eu\", \"Streams\": 5380517, \"Artist\": \"Wesley Safad\\u00e3o, Os Bar\\u00f5es Da Pisadinha\", \"Artist Followers\": 9907270.0, \"Song ID\": \"7EWXP47VlXKO3r7mNxuWHw\", \"Genre\": \"['forro']\", \"Release Date\": \"2020-11-12\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 73.0, \"Danceability\": 0.758, \"Energy\": 0.763, \"Loudness\": -8.754, \"Speechiness\": 0.0768, \"Acousticness\": 0.23, \"Liveness\": 0.0703, \"Tempo\": 163.946, \"Duration (ms)\": 155210.0, \"Valence\": 0.854, \"Chord\": \"C#/Db\"}, {\"Index\": 424, \"Highest Charting Position\": 186, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Quero Ver \\u00e9 Me Esquecer (feat. Jorge) - Ao Vivo\", \"Streams\": 5159208, \"Artist\": \"Os Bar\\u00f5es Da Pisadinha\", \"Artist Followers\": 4271775.0, \"Song ID\": \"2SUPbyD77tJuOUbqbxct6l\", \"Genre\": \"['forro', 'piseiro']\", \"Release Date\": \"2021-02-19\", \"Weeks Charted\": \"2021-04-16--2021-04-23\", \"Popularity\": 80.0, \"Danceability\": 0.593, \"Energy\": 0.932, \"Loudness\": -2.324, \"Speechiness\": 0.0526, \"Acousticness\": 0.302, \"Liveness\": 0.133, \"Tempo\": 171.977, \"Duration (ms)\": 147876.0, \"Valence\": 0.913, \"Chord\": \"G#/Ab\"}, {\"Index\": 425, \"Highest Charting Position\": 3, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"willow\", \"Streams\": 5016865, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0lx2cLdOt3piJbcaXIV74f\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 79.0, \"Danceability\": 0.392, \"Energy\": 0.574, \"Loudness\": -9.195, \"Speechiness\": 0.17, \"Acousticness\": 0.833, \"Liveness\": 0.145, \"Tempo\": 81.112, \"Duration (ms)\": 214707.0, \"Valence\": 0.529, \"Chord\": \"G\"}, {\"Index\": 426, \"Highest Charting Position\": 104, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Why'd You Only Call Me When You're High?\", \"Streams\": 4976405, \"Artist\": \"Arctic Monkeys\", \"Artist Followers\": 12375514.0, \"Song ID\": \"086myS9r57YsLbJpU0TgK9\", \"Genre\": \"['garage rock', 'permanent wave', 'rock', 'sheffield indie']\", \"Release Date\": \"2013-09-09\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 82.0, \"Danceability\": 0.691, \"Energy\": 0.631, \"Loudness\": -6.478, \"Speechiness\": 0.0368, \"Acousticness\": 0.0483, \"Liveness\": 0.104, \"Tempo\": 92.004, \"Duration (ms)\": 161124.0, \"Valence\": 0.8, \"Chord\": \"D\"}, {\"Index\": 427, \"Highest Charting Position\": 18, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Afterglow\", \"Streams\": 4965330, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 1250353.0, \"Song ID\": \"5dA45onYgYACRp8C5xEOS9\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\", \"Popularity\": 0.0, \"Danceability\": 0.641, \"Energy\": 0.324, \"Loudness\": -5.851, \"Speechiness\": 0.0299, \"Acousticness\": 0.698, \"Liveness\": 0.328, \"Tempo\": 110.184, \"Duration (ms)\": 185487.0, \"Valence\": 0.273, \"Chord\": \"B\"}, {\"Index\": 428, \"Highest Charting Position\": 43, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"LA CANCI\\u00d3N\", \"Streams\": 4959754, \"Artist\": \"J Balvin, Bad Bunny\", \"Artist Followers\": 29051363.0, \"Song ID\": \"0fea68AdmYNygeTGI4RC18\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.754, \"Energy\": 0.646, \"Loudness\": -5.795, \"Speechiness\": 0.317, \"Acousticness\": 0.152, \"Liveness\": 0.108, \"Tempo\": 176.089, \"Duration (ms)\": 242573.0, \"Valence\": 0.429, \"Chord\": \"G\"}, {\"Index\": 429, \"Highest Charting Position\": 52, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"You Belong With Me (Taylor\\u2019s Version)\", \"Streams\": 9872084, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1qrpoAMXodY6895hGKoUpA\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 73.0, \"Danceability\": 0.632, \"Energy\": 0.773, \"Loudness\": -4.856, \"Speechiness\": 0.0346, \"Acousticness\": 0.0623, \"Liveness\": 0.0885, \"Tempo\": 130.033, \"Duration (ms)\": 231124.0, \"Valence\": 0.474, \"Chord\": \"F#/Gb\"}, {\"Index\": 430, \"Highest Charting Position\": 54, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Fearless (Taylor\\u2019s Version)\", \"Streams\": 9676024, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"77sMIMlNaSURUAXq5coCxE\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 69.0, \"Danceability\": 0.569, \"Energy\": 0.741, \"Loudness\": -4.963, \"Speechiness\": 0.0282, \"Acousticness\": 0.0122, \"Liveness\": 0.333, \"Tempo\": 100.118, \"Duration (ms)\": 241592.0, \"Valence\": 0.43, \"Chord\": \"F\"}, {\"Index\": 431, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"X Gon' Give It To Ya\", \"Streams\": 8638360, \"Artist\": \"DMX\", \"Artist Followers\": 2815928.0, \"Song ID\": \"1zzxoZVylsna2BQB65Ppcb\", \"Genre\": \"['east coast hip hop', 'gangster rap', 'hardcore hip hop', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2007-06-12\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 73.0, \"Danceability\": 0.761, \"Energy\": 0.899, \"Loudness\": -3.09, \"Speechiness\": 0.183, \"Acousticness\": 0.0135, \"Liveness\": 0.0719, \"Tempo\": 95.027, \"Duration (ms)\": 217587.0, \"Valence\": 0.673, \"Chord\": \"A#/Bb\"}, {\"Index\": 432, \"Highest Charting Position\": 80, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Fifteen (Taylor\\u2019s Version)\", \"Streams\": 7852063, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2nqio0SfWg6gh2eCtfuMa5\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 66.0, \"Danceability\": 0.559, \"Energy\": 0.646, \"Loudness\": -4.61, \"Speechiness\": 0.0272, \"Acousticness\": 0.116, \"Liveness\": 0.32, \"Tempo\": 95.466, \"Duration (ms)\": 294419.0, \"Valence\": 0.289, \"Chord\": \"G\"}, {\"Index\": 433, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"The Way I Loved You (Taylor\\u2019s Version)\", \"Streams\": 7736262, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"22bPsP2jCgbLUvh82U0Z3M\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 72.0, \"Danceability\": 0.402, \"Energy\": 0.732, \"Loudness\": -4.665, \"Speechiness\": 0.0484, \"Acousticness\": 0.0033, \"Liveness\": 0.108, \"Tempo\": 161.032, \"Duration (ms)\": 243137.0, \"Valence\": 0.472, \"Chord\": \"F\"}, {\"Index\": 434, \"Highest Charting Position\": 51, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"You All Over Me (feat. Maren Morris) (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 7712896, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5pcjystBtalYeqaiXCcgEY\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 65.0, \"Danceability\": 0.589, \"Energy\": 0.496, \"Loudness\": -7.606, \"Speechiness\": 0.0377, \"Acousticness\": 0.818, \"Liveness\": 0.101, \"Tempo\": 142.731, \"Duration (ms)\": 220839.0, \"Valence\": 0.44, \"Chord\": \"D\"}, {\"Index\": 435, \"Highest Charting Position\": 93, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Hey Stephen (Taylor\\u2019s Version)\", \"Streams\": 7385864, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"550erGcdD9n6PnwxrvYqZT\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 66.0, \"Danceability\": 0.788, \"Energy\": 0.571, \"Loudness\": -6.135, \"Speechiness\": 0.0296, \"Acousticness\": 0.106, \"Liveness\": 0.0934, \"Tempo\": 115.99, \"Duration (ms)\": 254255.0, \"Valence\": 0.797, \"Chord\": \"F#/Gb\"}, {\"Index\": 436, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"White Horse (Taylor\\u2019s Version)\", \"Streams\": 7039222, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5YL553x8sHderRBDlm3NM3\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 65.0, \"Danceability\": 0.423, \"Energy\": 0.517, \"Loudness\": -7.377, \"Speechiness\": 0.0486, \"Acousticness\": 0.369, \"Liveness\": 0.177, \"Tempo\": 185.262, \"Duration (ms)\": 234516.0, \"Valence\": 0.366, \"Chord\": \"C\"}, {\"Index\": 437, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Forever & Always (Taylor\\u2019s Version)\", \"Streams\": 6566059, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1msEuwSBneBKpVCZQcFTsU\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 66.0, \"Danceability\": 0.598, \"Energy\": 0.821, \"Loudness\": -4.433, \"Speechiness\": 0.0447, \"Acousticness\": 0.0231, \"Liveness\": 0.143, \"Tempo\": 128.03, \"Duration (ms)\": 225328.0, \"Valence\": 0.673, \"Chord\": \"A#/Bb\"}, {\"Index\": 438, \"Highest Charting Position\": 119, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Breathe (feat. Colbie Caillat) (Taylor\\u2019s Version)\", \"Streams\": 6508683, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7HC7R2D8WjXVcUHJyEGjRs\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 64.0, \"Danceability\": 0.506, \"Energy\": 0.626, \"Loudness\": -6.066, \"Speechiness\": 0.0287, \"Acousticness\": 0.156, \"Liveness\": 0.228, \"Tempo\": 148.035, \"Duration (ms)\": 263377.0, \"Valence\": 0.321, \"Chord\": \"C#/Db\"}, {\"Index\": 439, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Ruff Ryders' Anthem\", \"Streams\": 5988511, \"Artist\": \"DMX\", \"Artist Followers\": 2815928.0, \"Song ID\": \"1BKT2I9x4RGKaKqW4up34s\", \"Genre\": \"['east coast hip hop', 'gangster rap', 'hardcore hip hop', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"1998-05-01\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 72.0, \"Danceability\": 0.88, \"Energy\": 0.577, \"Loudness\": -8.093, \"Speechiness\": 0.302, \"Acousticness\": 0.0564, \"Liveness\": 0.201, \"Tempo\": 90.991, \"Duration (ms)\": 214440.0, \"Valence\": 0.74, \"Chord\": \"A#/Bb\"}, {\"Index\": 440, \"Highest Charting Position\": 146, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"That\\u2019s When (feat. Keith Urban) (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5889939, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7eResoqEJJAVTkQYSqvO3P\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 67.0, \"Danceability\": 0.588, \"Energy\": 0.608, \"Loudness\": -7.062, \"Speechiness\": 0.0365, \"Acousticness\": 0.225, \"Liveness\": 0.092, \"Tempo\": 90.201, \"Duration (ms)\": 189496.0, \"Valence\": 0.508, \"Chord\": \"F\"}, {\"Index\": 441, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Tell Me Why (Taylor\\u2019s Version)\", \"Streams\": 5885151, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0k0vFacOHNuArLWMiH60p7\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 63.0, \"Danceability\": 0.578, \"Energy\": 0.909, \"Loudness\": -3.669, \"Speechiness\": 0.0628, \"Acousticness\": 0.0222, \"Liveness\": 0.333, \"Tempo\": 100.023, \"Duration (ms)\": 200576.0, \"Valence\": 0.541, \"Chord\": \"G\"}, {\"Index\": 442, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"You\\u2019re Not Sorry (Taylor\\u2019s Version)\", \"Streams\": 5860405, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6iiAfo4wTA2CVC3Uwx9uh8\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 64.0, \"Danceability\": 0.506, \"Energy\": 0.444, \"Loudness\": -4.99, \"Speechiness\": 0.0285, \"Acousticness\": 0.0538, \"Liveness\": 0.123, \"Tempo\": 133.873, \"Duration (ms)\": 261843.0, \"Valence\": 0.241, \"Chord\": \"F#/Gb\"}, {\"Index\": 443, \"Highest Charting Position\": 40, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Chica Ideal\", \"Streams\": 5217052, \"Artist\": \"Sebastian Yatra, Guaynaa\", \"Artist Followers\": 1250353.0, \"Song ID\": \"6M3Bdl5UtQtmjnYDW69LZQ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 0.0, \"Danceability\": 0.574, \"Energy\": 0.891, \"Loudness\": -3.665, \"Speechiness\": 0.157, \"Acousticness\": 0.0847, \"Liveness\": 0.16, \"Tempo\": 100.978, \"Duration (ms)\": 183240.0, \"Valence\": 0.707, \"Chord\": \"C\"}, {\"Index\": 444, \"Highest Charting Position\": 15, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Relaci\\u00f3n - Remix\", \"Streams\": 5206614, \"Artist\": \"Sech, Daddy Yankee, J Balvin, ROSAL\\u00cdA, Farruko\", \"Artist Followers\": 8758283.0, \"Song ID\": \"35UUpTmrcFXNIVIN26ujXl\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 80.0, \"Danceability\": 0.793, \"Energy\": 0.771, \"Loudness\": -3.417, \"Speechiness\": 0.0959, \"Acousticness\": 0.0337, \"Liveness\": 0.284, \"Tempo\": 171.943, \"Duration (ms)\": 247308.0, \"Valence\": 0.835, \"Chord\": \"F\"}, {\"Index\": 445, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Don\\u2019t You (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5197564, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"4uuEGH5SVuzkkSFjo2DEiY\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 65.0, \"Danceability\": 0.563, \"Energy\": 0.473, \"Loudness\": -11.548, \"Speechiness\": 0.0503, \"Acousticness\": 0.514, \"Liveness\": 0.109, \"Tempo\": 101.934, \"Duration (ms)\": 208609.0, \"Valence\": 0.405, \"Chord\": \"D#/Eb\"}, {\"Index\": 446, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"We Were Happy (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5189423, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"34V9RiEPe8MNdU32qJsJa1\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 64.0, \"Danceability\": 0.609, \"Energy\": 0.373, \"Loudness\": -8.819, \"Speechiness\": 0.0263, \"Acousticness\": 0.849, \"Liveness\": 0.0779, \"Tempo\": 106.007, \"Duration (ms)\": 244237.0, \"Valence\": 0.13, \"Chord\": \"C\"}, {\"Index\": 447, \"Highest Charting Position\": 153, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"WACHA\", \"Streams\": 5172999, \"Artist\": \"KHEA, Duki\", \"Artist Followers\": 3198705.0, \"Song ID\": \"5RmSunLqeDqNWww8LWhAiK\", \"Genre\": \"['argentine hip hop', 'trap argentino', 'trap latino', 'trap triste']\", \"Release Date\": \"2021-04-01\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 75.0, \"Danceability\": 0.737, \"Energy\": 0.634, \"Loudness\": -4.25, \"Speechiness\": 0.0424, \"Acousticness\": 0.345, \"Liveness\": 0.111, \"Tempo\": 94.927, \"Duration (ms)\": 206360.0, \"Valence\": 0.528, \"Chord\": \"D#/Eb\"}, {\"Index\": 448, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Dancing With The Devil\", \"Streams\": 5836326, \"Artist\": \"Demi Lovato\", \"Artist Followers\": 20338833.0, \"Song ID\": \"2kONpeXXK70YEs7c0UQbmq\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-04-02--2021-04-09\", \"Popularity\": 66.0, \"Danceability\": 0.413, \"Energy\": 0.64, \"Loudness\": -5.811, \"Speechiness\": 0.0427, \"Acousticness\": 0.273, \"Liveness\": 0.11, \"Tempo\": 75.245, \"Duration (ms)\": 243992.0, \"Valence\": 0.149, \"Chord\": \"G#/Ab\"}, {\"Index\": 449, \"Highest Charting Position\": 26, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Gone\", \"Streams\": 5427638, \"Artist\": \"ROS\\u00c9\", \"Artist Followers\": 1099480.0, \"Song ID\": \"2dHoVW9AxJVSRebPRyV2aA\", \"Genre\": \"[]\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 71.0, \"Danceability\": 0.647, \"Energy\": 0.377, \"Loudness\": -6.003, \"Speechiness\": 0.0375, \"Acousticness\": 0.594, \"Liveness\": 0.0768, \"Tempo\": 79.936, \"Duration (ms)\": 207164.0, \"Valence\": 0.653, \"Chord\": \"F#/Gb\"}, {\"Index\": 450, \"Highest Charting Position\": 160, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"What Other People Say\", \"Streams\": 5413003, \"Artist\": \"Sam Fischer, Demi Lovato\", \"Artist Followers\": 122746.0, \"Song ID\": \"2h9TDNEXRhcDIV3fsoEVq9\", \"Genre\": \"['alt z', 'australian pop', 'dance pop', 'indie cafe pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2021-02-04\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\", \"Popularity\": 77.0, \"Danceability\": 0.652, \"Energy\": 0.472, \"Loudness\": -8.084, \"Speechiness\": 0.0399, \"Acousticness\": 0.158, \"Liveness\": 0.121, \"Tempo\": 126.904, \"Duration (ms)\": 194890.0, \"Valence\": 0.24, \"Chord\": \"G\"}, {\"Index\": 451, \"Highest Charting Position\": 88, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Hello (feat. A Boogie Wit da Hoodie)\", \"Streams\": 5323062, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"2r6OAV3WsYtXuXjvJ1lIDi\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-20\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 82.0, \"Danceability\": 0.905, \"Energy\": 0.647, \"Loudness\": -5.065, \"Speechiness\": 0.107, \"Acousticness\": 0.0187, \"Liveness\": 0.282, \"Tempo\": 130.97, \"Duration (ms)\": 190534.0, \"Valence\": 0.367, \"Chord\": \"A#/Bb\"}, {\"Index\": 452, \"Highest Charting Position\": 91, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Hasta Abajo\", \"Streams\": 5269163, \"Artist\": \"Kevin Roldan, Bryant Myers, Lyanno\", \"Artist Followers\": 4026643.0, \"Song ID\": \"4PEfJZpVjdclfzZ9XO8uDw\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'reggaeton colombiano', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 77.0, \"Danceability\": 0.714, \"Energy\": 0.671, \"Loudness\": -5.119, \"Speechiness\": 0.362, \"Acousticness\": 0.289, \"Liveness\": 0.325, \"Tempo\": 169.732, \"Duration (ms)\": 229827.0, \"Valence\": 0.641, \"Chord\": \"F\"}, {\"Index\": 453, \"Highest Charting Position\": 30, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Take You Dancing\", \"Streams\": 5176493, \"Artist\": \"Jason Derulo\", \"Artist Followers\": 9778632.0, \"Song ID\": \"59qrUpoplZxbIZxk6X0Bm3\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2020-07-22\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 82.0, \"Danceability\": 0.789, \"Energy\": 0.711, \"Loudness\": -4.248, \"Speechiness\": 0.041, \"Acousticness\": 0.0332, \"Liveness\": 0.0876, \"Tempo\": 112.985, \"Duration (ms)\": 190306.0, \"Valence\": 0.753, \"Chord\": \"D\"}, {\"Index\": 454, \"Highest Charting Position\": 28, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Unstable (feat. The Kid LAROI)\", \"Streams\": 5137645, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"137mSruegm1u6x9NvwiagR\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 74.0, \"Danceability\": 0.495, \"Energy\": 0.333, \"Loudness\": -10.109, \"Speechiness\": 0.0288, \"Acousticness\": 0.737, \"Liveness\": 0.112, \"Tempo\": 99.757, \"Duration (ms)\": 158324.0, \"Valence\": 0.37, \"Chord\": \"E\"}, {\"Index\": 455, \"Highest Charting Position\": 2, \"Number of Times Charted\": 48, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Stuck with U (with Justin Bieber)\", \"Streams\": 5094660, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"4HBZA5flZLE435QTztThqH\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 84.0, \"Danceability\": 0.597, \"Energy\": 0.45, \"Loudness\": -6.658, \"Speechiness\": 0.0418, \"Acousticness\": 0.223, \"Liveness\": 0.382, \"Tempo\": 178.765, \"Duration (ms)\": 228482.0, \"Valence\": 0.537, \"Chord\": \"G#/Ab\"}, {\"Index\": 456, \"Highest Charting Position\": 120, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Hayloft\", \"Streams\": 5086382, \"Artist\": \"Mother Mother\", \"Artist Followers\": 2110870.0, \"Song ID\": \"2kS6td1yvmpNgZTt1q5pQq\", \"Genre\": \"['indie pop', 'vancouver indie']\", \"Release Date\": \"2008-09-23\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 81.0, \"Danceability\": 0.527, \"Energy\": 0.922, \"Loudness\": -2.666, \"Speechiness\": 0.0728, \"Acousticness\": 0.00475, \"Liveness\": 0.422, \"Tempo\": 95.975, \"Duration (ms)\": 181680.0, \"Valence\": 0.49, \"Chord\": \"A\"}, {\"Index\": 457, \"Highest Charting Position\": 191, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Esquema Preferido (feat. Tarc\\u00edsio do Acordeon)\", \"Streams\": 5078174, \"Artist\": \"DJ Ivis\", \"Artist Followers\": 342930.0, \"Song ID\": \"0e6NlGJxYlHvAN8SKxad7N\", \"Genre\": \"['piseiro']\", \"Release Date\": \"2020-11-26\", \"Weeks Charted\": \"2021-04-02--2021-04-09\", \"Popularity\": 73.0, \"Danceability\": 0.676, \"Energy\": 0.823, \"Loudness\": -4.386, \"Speechiness\": 0.102, \"Acousticness\": 0.242, \"Liveness\": 0.0773, \"Tempo\": 160.013, \"Duration (ms)\": 190680.0, \"Valence\": 0.907, \"Chord\": \"F\"}, {\"Index\": 458, \"Highest Charting Position\": 75, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Adem\\u00e1s de M\\u00ed - Remix\", \"Streams\": 5060336, \"Artist\": \"Rusherking, KHEA, Duki, Maria Becerra, LIT killah, Tiago PZK\", \"Artist Followers\": 301217.0, \"Song ID\": \"7I8L3vYCLThw2FDrE6LuzE\", \"Genre\": \"['trap argentino', 'trap latino', 'trap triste']\", \"Release Date\": \"2021-03-04\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 78.0, \"Danceability\": 0.397, \"Energy\": 0.613, \"Loudness\": -5.077, \"Speechiness\": 0.0549, \"Acousticness\": 0.0396, \"Liveness\": 0.192, \"Tempo\": 78.4, \"Duration (ms)\": 330040.0, \"Valence\": 0.405, \"Chord\": \"F#/Gb\"}, {\"Index\": 459, \"Highest Charting Position\": 193, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Payphone\", \"Streams\": 5052717, \"Artist\": \"Maroon 5, Wiz Khalifa\", \"Artist Followers\": 32279979.0, \"Song ID\": \"1LmN9SSHISbtp9LoaR5ZVJ\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2012-01-01\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 74.0, \"Danceability\": 0.739, \"Energy\": 0.756, \"Loudness\": -4.828, \"Speechiness\": 0.0394, \"Acousticness\": 0.0136, \"Liveness\": 0.37, \"Tempo\": 110.028, \"Duration (ms)\": 231387.0, \"Valence\": 0.523, \"Chord\": \"E\"}, {\"Index\": 460, \"Highest Charting Position\": 50, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Ghost\", \"Streams\": 5013450, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6I3mqTwhRpn34SLVafSH7G\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 71.0, \"Danceability\": 0.601, \"Energy\": 0.741, \"Loudness\": -5.569, \"Speechiness\": 0.0478, \"Acousticness\": 0.185, \"Liveness\": 0.415, \"Tempo\": 153.96, \"Duration (ms)\": 153190.0, \"Valence\": 0.441, \"Chord\": \"D\"}, {\"Index\": 461, \"Highest Charting Position\": 37, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Off My Face\", \"Streams\": 5004111, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"3T03rPwlL8NVk1yIaxeD8U\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 75.0, \"Danceability\": 0.509, \"Energy\": 0.228, \"Loudness\": -8.68, \"Speechiness\": 0.0332, \"Acousticness\": 0.92, \"Liveness\": 0.104, \"Tempo\": 90.674, \"Duration (ms)\": 156468.0, \"Valence\": 0.586, \"Chord\": \"E\"}, {\"Index\": 462, \"Highest Charting Position\": 140, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Whats Poppin (feat. DaBaby, Tory Lanez & Lil Wayne) [Remix] - Bonus Track\", \"Streams\": 4972518, \"Artist\": \"Jack Harlow\", \"Artist Followers\": 1053324.0, \"Song ID\": \"0ZLuW8uOXdFNWcI40C0OC2\", \"Genre\": \"['deep underground hip hop', 'kentucky hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\", \"Popularity\": 73.0, \"Danceability\": 0.904, \"Energy\": 0.723, \"Loudness\": -5.224, \"Speechiness\": 0.26, \"Acousticness\": 0.0631, \"Liveness\": 0.185, \"Tempo\": 145.013, \"Duration (ms)\": 227478.0, \"Valence\": 0.835, \"Chord\": \"B\"}, {\"Index\": 463, \"Highest Charting Position\": 188, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Take on Me\", \"Streams\": 4969662, \"Artist\": \"a-ha\", \"Artist Followers\": 1560784.0, \"Song ID\": \"2WfaOiMkCvy7F5fcp2zZ8L\", \"Genre\": \"['new romantic', 'new wave', 'new wave pop', 'permanent wave', 'soft rock', 'synthpop']\", \"Release Date\": \"1985-06-01\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 84.0, \"Danceability\": 0.573, \"Energy\": 0.902, \"Loudness\": -7.638, \"Speechiness\": 0.054, \"Acousticness\": 0.018, \"Liveness\": 0.0928, \"Tempo\": 84.412, \"Duration (ms)\": 225280.0, \"Valence\": 0.876, \"Chord\": \"F#/Gb\"}, {\"Index\": 464, \"Highest Charting Position\": 45, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"BEB\\u00c9\", \"Streams\": 4967348, \"Artist\": \"Camilo, El Alfa\", \"Artist Followers\": 10580764.0, \"Song ID\": \"7D7EH7MGyNHWSkqrszerI1\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-11-25\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 78.0, \"Danceability\": 0.862, \"Energy\": 0.72, \"Loudness\": -4.048, \"Speechiness\": 0.0379, \"Acousticness\": 0.487, \"Liveness\": 0.0604, \"Tempo\": 129.972, \"Duration (ms)\": 198707.0, \"Valence\": 0.965, \"Chord\": \"E\"}, {\"Index\": 465, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Richer (feat. Polo G)\", \"Streams\": 6292362, \"Artist\": \"Rod Wave\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-03-26--2021-04-02\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 466, \"Highest Charting Position\": 128, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Tu Veneno\", \"Streams\": 6007541, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"5KFHrrBMyGj5MhVbZMM3ts\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 76.0, \"Danceability\": 0.664, \"Energy\": 0.659, \"Loudness\": -4.232, \"Speechiness\": 0.0873, \"Acousticness\": 0.0625, \"Liveness\": 0.0874, \"Tempo\": 175.826, \"Duration (ms)\": 157320.0, \"Valence\": 0.797, \"Chord\": \"A#/Bb\"}, {\"Index\": 467, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Deserve You\", \"Streams\": 5837372, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5NU40QTlXrDUJzDBdv79bg\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 69.0, \"Danceability\": 0.677, \"Energy\": 0.633, \"Loudness\": -7.831, \"Speechiness\": 0.0771, \"Acousticness\": 0.0314, \"Liveness\": 0.112, \"Tempo\": 89.934, \"Duration (ms)\": 187239.0, \"Valence\": 0.409, \"Chord\": \"G\"}, {\"Index\": 468, \"Highest Charting Position\": 44, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"2 Much\", \"Streams\": 5794583, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"0oaY19dUwZimIgzn3ZZLZO\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 70.0, \"Danceability\": 0.583, \"Energy\": 0.444, \"Loudness\": -8.601, \"Speechiness\": 0.0456, \"Acousticness\": 0.593, \"Liveness\": 0.353, \"Tempo\": 119.59, \"Duration (ms)\": 152796.0, \"Valence\": 0.167, \"Chord\": \"A\"}, {\"Index\": 469, \"Highest Charting Position\": 3, \"Number of Times Charted\": 66, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Tusa\", \"Streams\": 5510113, \"Artist\": \"KAROL G, Nicki Minaj\", \"Artist Followers\": 17792779.0, \"Song ID\": \"7k4t7uLgtOxPwTpFmtJNTY\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.803, \"Energy\": 0.715, \"Loudness\": -3.28, \"Speechiness\": 0.298, \"Acousticness\": 0.295, \"Liveness\": 0.0574, \"Tempo\": 101.085, \"Duration (ms)\": 200960.0, \"Valence\": 0.574, \"Chord\": \"D\"}, {\"Index\": 470, \"Highest Charting Position\": 34, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Una Locura\", \"Streams\": 5466954, \"Artist\": \"Ozuna, J Balvin, Chencho Corleone\", \"Artist Followers\": 29238936.0, \"Song ID\": \"5y7DaS3jAc9eZzcSOoUIwU\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 81.0, \"Danceability\": 0.714, \"Energy\": 0.761, \"Loudness\": -4.596, \"Speechiness\": 0.0427, \"Acousticness\": 0.139, \"Liveness\": 0.241, \"Tempo\": 168.022, \"Duration (ms)\": 230693.0, \"Valence\": 0.906, \"Chord\": \"F\"}, {\"Index\": 471, \"Highest Charting Position\": 61, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Loved By You (feat. Burna Boy)\", \"Streams\": 5419040, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2tB9OFgAHjAds3cqquLlvp\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 69.0, \"Danceability\": 0.79, \"Energy\": 0.724, \"Loudness\": -6.972, \"Speechiness\": 0.0852, \"Acousticness\": 0.0696, \"Liveness\": 0.113, \"Tempo\": 101.04, \"Duration (ms)\": 159250.0, \"Valence\": 0.642, \"Chord\": \"C#/Db\"}, {\"Index\": 472, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Girls Like Us\", \"Streams\": 5410730, \"Artist\": \"Zoe Wees\", \"Artist Followers\": 203555.0, \"Song ID\": \"5SFXOMJJ334Wn2PwBHeRZN\", \"Genre\": \"['german pop']\", \"Release Date\": \"2021-01-12\", \"Weeks Charted\": \"2021-03-26--2021-04-02\", \"Popularity\": 78.0, \"Danceability\": 0.444, \"Energy\": 0.648, \"Loudness\": -4.955, \"Speechiness\": 0.0476, \"Acousticness\": 0.288, \"Liveness\": 0.059, \"Tempo\": 125.706, \"Duration (ms)\": 189000.0, \"Valence\": 0.171, \"Chord\": \"C#/Db\"}, {\"Index\": 473, \"Highest Charting Position\": 17, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Lemon Pepper Freestyle (feat. Rick Ross)\", \"Streams\": 5365747, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"4FRW5Nza1Ym91BGV4nFWXI\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 76.0, \"Danceability\": 0.77, \"Energy\": 0.637, \"Loudness\": -5.53, \"Speechiness\": 0.345, \"Acousticness\": 0.103, \"Liveness\": 0.171, \"Tempo\": 94.966, \"Duration (ms)\": 383037.0, \"Valence\": 0.431, \"Chord\": \"C#/Db\"}, {\"Index\": 474, \"Highest Charting Position\": 97, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Esquema Preferido\", \"Streams\": 5356696, \"Artist\": \"DJ Ivis, Tarc\\u00edsio do Acordeon\", \"Artist Followers\": 342930.0, \"Song ID\": \"0e6NlGJxYlHvAN8SKxad7N\", \"Genre\": \"['piseiro']\", \"Release Date\": \"2020-11-26\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 73.0, \"Danceability\": 0.676, \"Energy\": 0.823, \"Loudness\": -4.386, \"Speechiness\": 0.102, \"Acousticness\": 0.242, \"Liveness\": 0.0773, \"Tempo\": 160.013, \"Duration (ms)\": 190680.0, \"Valence\": 0.907, \"Chord\": \"F\"}, {\"Index\": 475, \"Highest Charting Position\": 105, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Love Not War (The Tampa Beat)\", \"Streams\": 5326719, \"Artist\": \"Jason Derulo, Nuka\", \"Artist Followers\": 9778632.0, \"Song ID\": \"4Lt6GXGzYsa1tgkv3nGSTm\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 79.0, \"Danceability\": 0.738, \"Energy\": 0.85, \"Loudness\": -3.049, \"Speechiness\": 0.0642, \"Acousticness\": 0.105, \"Liveness\": 0.23, \"Tempo\": 98.013, \"Duration (ms)\": 192921.0, \"Valence\": 0.865, \"Chord\": \"G#/Ab\"}, {\"Index\": 476, \"Highest Charting Position\": 57, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Die For You (feat. Dominic Fike)\", \"Streams\": 5323412, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"7aely3H8kMj9o0gt6vXHE1\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 67.0, \"Danceability\": 0.728, \"Energy\": 0.629, \"Loudness\": -6.629, \"Speechiness\": 0.0318, \"Acousticness\": 0.00196, \"Liveness\": 0.0847, \"Tempo\": 135.031, \"Duration (ms)\": 198426.0, \"Valence\": 0.71, \"Chord\": \"C#/Db\"}, {\"Index\": 477, \"Highest Charting Position\": 64, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Starboy\", \"Streams\": 5302285, \"Artist\": \"The Weeknd, Daft Punk\", \"Artist Followers\": 35340069.0, \"Song ID\": \"7MXVkk9YMctZqd1Srtv4MB\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2016-11-25\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 83.0, \"Danceability\": 0.679, \"Energy\": 0.587, \"Loudness\": -7.015, \"Speechiness\": 0.276, \"Acousticness\": 0.141, \"Liveness\": 0.137, \"Tempo\": 186.003, \"Duration (ms)\": 230453.0, \"Valence\": 0.486, \"Chord\": \"G\"}, {\"Index\": 478, \"Highest Charting Position\": 22, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"La T\\u00f3xica\", \"Streams\": 5255393, \"Artist\": \"Farruko\", \"Artist Followers\": 10510156.0, \"Song ID\": \"15OjBeqNX3bShsGYQbteRv\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 78.0, \"Danceability\": 0.659, \"Energy\": 0.701, \"Loudness\": -4.107, \"Speechiness\": 0.164, \"Acousticness\": 0.0882, \"Liveness\": 0.0866, \"Tempo\": 91.97, \"Duration (ms)\": 180520.0, \"Valence\": 0.623, \"Chord\": \"A\"}, {\"Index\": 479, \"Highest Charting Position\": 181, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Cora\\u00e7\\u00e3o Na Cama - Ao Vivo\", \"Streams\": 5211351, \"Artist\": \"Hugo & Guilherme\", \"Artist Followers\": 435936.0, \"Song ID\": \"2nZj5YymF54qhAu7RneVP6\", \"Genre\": \"['sertanejo pop']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 77.0, \"Danceability\": 0.764, \"Energy\": 0.794, \"Loudness\": -4.096, \"Speechiness\": 0.0589, \"Acousticness\": 0.663, \"Liveness\": 0.34, \"Tempo\": 110.013, \"Duration (ms)\": 173227.0, \"Valence\": 0.721, \"Chord\": \"G#/Ab\"}, {\"Index\": 480, \"Highest Charting Position\": 60, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Love You Different (feat. BEAM)\", \"Streams\": 10024729, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"27UcQ6dAvQrgH9C880rCM3\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-19--2021-03-26\", \"Popularity\": 66.0, \"Danceability\": 0.759, \"Energy\": 0.584, \"Loudness\": -6.655, \"Speechiness\": 0.06, \"Acousticness\": 0.0652, \"Liveness\": 0.16, \"Tempo\": 127.138, \"Duration (ms)\": 186696.0, \"Valence\": 0.374, \"Chord\": \"G#/Ab\"}, {\"Index\": 481, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Somebody\", \"Streams\": 8912458, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"3rLIv187BhjyweFe89SgLn\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2010-01-01\", \"Weeks Charted\": \"2021-03-19--2021-03-26\", \"Popularity\": 67.0, \"Danceability\": 0.714, \"Energy\": 0.833, \"Loudness\": -5.239, \"Speechiness\": 0.0259, \"Acousticness\": 0.00249, \"Liveness\": 0.298, \"Tempo\": 129.964, \"Duration (ms)\": 220920.0, \"Valence\": 0.663, \"Chord\": \"F\"}, {\"Index\": 482, \"Highest Charting Position\": 152, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"White Dress\", \"Streams\": 5796978, \"Artist\": \"Lana Del Rey\", \"Artist Followers\": 13697048.0, \"Song ID\": \"4Hl9rOqYomojCmxYfr25im\", \"Genre\": \"['art pop', 'pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-19--2021-03-26\", \"Popularity\": 65.0, \"Danceability\": 0.493, \"Energy\": 0.263, \"Loudness\": -12.805, \"Speechiness\": 0.0351, \"Acousticness\": 0.926, \"Liveness\": 0.0879, \"Tempo\": 122.792, \"Duration (ms)\": 333710.0, \"Valence\": 0.158, \"Chord\": \"C\"}, {\"Index\": 483, \"Highest Charting Position\": 82, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Polvo\", \"Streams\": 5528508, \"Artist\": \"Nicky Jam, Myke Towers\", \"Artist Followers\": 14831925.0, \"Song ID\": \"68mrW6gXHgupgSiDHgaDi5\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 76.0, \"Danceability\": 0.763, \"Energy\": 0.621, \"Loudness\": -6.169, \"Speechiness\": 0.066, \"Acousticness\": 0.0105, \"Liveness\": 0.106, \"Tempo\": 82.042, \"Duration (ms)\": 211130.0, \"Valence\": 0.582, \"Chord\": \"B\"}, {\"Index\": 484, \"Highest Charting Position\": 138, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Chemtrails Over The Country Club\", \"Streams\": 5418816, \"Artist\": \"Lana Del Rey\", \"Artist Followers\": 13697048.0, \"Song ID\": \"7bPWdJgx8vek7S5i5yAtvG\", \"Genre\": \"['art pop', 'pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-01-15--2021-01-22\", \"Popularity\": 73.0, \"Danceability\": 0.334, \"Energy\": 0.276, \"Loudness\": -13.125, \"Speechiness\": 0.0643, \"Acousticness\": 0.877, \"Liveness\": 0.113, \"Tempo\": 201.025, \"Duration (ms)\": 271177.0, \"Valence\": 0.429, \"Chord\": \"E\"}, {\"Index\": 485, \"Highest Charting Position\": 37, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Parce (feat. Justin Quiles)\", \"Streams\": 5312876, \"Artist\": \"Maluma, Lenny Tav\\u00e1rez\", \"Artist Followers\": 26769304.0, \"Song ID\": \"4RJz8NfIe09gpKMiRUWKhJ\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 78.0, \"Danceability\": 0.691, \"Energy\": 0.739, \"Loudness\": -3.09, \"Speechiness\": 0.229, \"Acousticness\": 0.422, \"Liveness\": 0.11, \"Tempo\": 83.897, \"Duration (ms)\": 248345.0, \"Valence\": 0.884, \"Chord\": \"F\"}, {\"Index\": 486, \"Highest Charting Position\": 40, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Ropa Cara\", \"Streams\": 5249427, \"Artist\": \"Camilo\", \"Artist Followers\": 10580764.0, \"Song ID\": \"7BIy3EGQhg98CsRdKYHnJC\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2021-01-18\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 73.0, \"Danceability\": 0.813, \"Energy\": 0.526, \"Loudness\": -4.787, \"Speechiness\": 0.125, \"Acousticness\": 0.105, \"Liveness\": 0.11, \"Tempo\": 170.002, \"Duration (ms)\": 163320.0, \"Valence\": 0.608, \"Chord\": \"E\"}, {\"Index\": 487, \"Highest Charting Position\": 25, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Vida de Rico\", \"Streams\": 5189822, \"Artist\": \"Camilo\", \"Artist Followers\": 10580764.0, \"Song ID\": \"73nAK3HgQK8dak83Y2WQ8F\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-09-21\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 79.0, \"Danceability\": 0.824, \"Energy\": 0.457, \"Loudness\": -5.428, \"Speechiness\": 0.0543, \"Acousticness\": 0.167, \"Liveness\": 0.041, \"Tempo\": 87.977, \"Duration (ms)\": 187427.0, \"Valence\": 0.95, \"Chord\": \"F#/Gb\"}, {\"Index\": 488, \"Highest Charting Position\": 182, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Devil Eyes\", \"Streams\": 5098581, \"Artist\": \"Hippie Sabotage\", \"Artist Followers\": 713486.0, \"Song ID\": \"7MiZjKawmXTsTNePyTfPyL\", \"Genre\": \"['edm', 'electronic trap']\", \"Release Date\": \"2016-02-05\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 80.0, \"Danceability\": 0.391, \"Energy\": 0.396, \"Loudness\": -8.621, \"Speechiness\": 0.189, \"Acousticness\": 0.702, \"Liveness\": 0.315, \"Tempo\": 99.112, \"Duration (ms)\": 131272.0, \"Valence\": 0.199, \"Chord\": \"C#/Db\"}, {\"Index\": 489, \"Highest Charting Position\": 141, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Ponte Pa' Mi\", \"Streams\": 5082870, \"Artist\": \"Justin Quiles\", \"Artist Followers\": 2897862.0, \"Song ID\": \"4C6BlqqMwjFzOXzqpTeoWR\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 76.0, \"Danceability\": 0.878, \"Energy\": 0.713, \"Loudness\": -4.566, \"Speechiness\": 0.0948, \"Acousticness\": 0.0581, \"Liveness\": 0.0822, \"Tempo\": 92.028, \"Duration (ms)\": 202373.0, \"Valence\": 0.615, \"Chord\": \"F\"}, {\"Index\": 490, \"Highest Charting Position\": 109, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"D\\u00e1melo To\\u2019 (feat. Myke Towers)\", \"Streams\": 6426522, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"36CiGk9oRdwTnBDMgKEfjl\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 64.0, \"Danceability\": 0.787, \"Energy\": 0.641, \"Loudness\": -7.376, \"Speechiness\": 0.315, \"Acousticness\": 0.101, \"Liveness\": 0.07, \"Tempo\": 182.003, \"Duration (ms)\": 184134.0, \"Valence\": 0.437, \"Chord\": \"G#/Ab\"}, {\"Index\": 491, \"Highest Charting Position\": 121, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Patience (feat. YUNGBLUD & Polo G)\", \"Streams\": 6155698, \"Artist\": \"KSI\", \"Artist Followers\": 2010879.0, \"Song ID\": \"5J5CpT6bgE6KYKk23jgp9W\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 71.0, \"Danceability\": 0.616, \"Energy\": 0.741, \"Loudness\": -4.272, \"Speechiness\": 0.0426, \"Acousticness\": 0.00251, \"Liveness\": 0.307, \"Tempo\": 122.012, \"Duration (ms)\": 181720.0, \"Valence\": 0.431, \"Chord\": \"G\"}, {\"Index\": 492, \"Highest Charting Position\": 56, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Selfish Love (with Selena Gomez)\", \"Streams\": 6020785, \"Artist\": \"DJ Snake\", \"Artist Followers\": 7408249.0, \"Song ID\": \"3XoflnowYPFRPOh3uFvHcm\", \"Genre\": \"['dance pop', 'edm', 'electronic trap', 'pop', 'pop dance']\", \"Release Date\": \"2021-03-04\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 74.0, \"Danceability\": 0.723, \"Energy\": 0.646, \"Loudness\": -7.973, \"Speechiness\": 0.102, \"Acousticness\": 0.0206, \"Liveness\": 0.0994, \"Tempo\": 110.971, \"Duration (ms)\": 168649.0, \"Valence\": 0.443, \"Chord\": \"F\"}, {\"Index\": 493, \"Highest Charting Position\": 12, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Snowman\", \"Streams\": 5454807, \"Artist\": \"Sia\", \"Artist Followers\": 20528724.0, \"Song ID\": \"7uoFMmxln0GPXQ0AcCBXRq\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'pop']\", \"Release Date\": \"2018-11-01\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 77.0, \"Danceability\": 0.716, \"Energy\": 0.512, \"Loudness\": -6.257, \"Speechiness\": 0.0331, \"Acousticness\": 0.483, \"Liveness\": 0.0928, \"Tempo\": 104.957, \"Duration (ms)\": 165907.0, \"Valence\": 0.326, \"Chord\": \"C#/Db\"}, {\"Index\": 494, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"DAYWALKER! (feat. CORPSE)\", \"Streams\": 5439646, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3868320.0, \"Song ID\": \"2NnJpRXIlx35Vij3bPZO0h\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 74.0, \"Danceability\": 0.632, \"Energy\": 0.922, \"Loudness\": -2.173, \"Speechiness\": 0.0794, \"Acousticness\": 0.00558, \"Liveness\": 0.0927, \"Tempo\": 88.972, \"Duration (ms)\": 137747.0, \"Valence\": 0.497, \"Chord\": \"G\"}, {\"Index\": 495, \"Highest Charting Position\": 19, \"Number of Times Charted\": 38, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"La Curiosidad\", \"Streams\": 5198514, \"Artist\": \"Jay Wheeler, DJ Nelson, Myke Towers\", \"Artist Followers\": 1650912.0, \"Song ID\": \"4HYDUMY0xSpeBr0AMY9cUz\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 82.0, \"Danceability\": 0.845, \"Energy\": 0.677, \"Loudness\": -4.798, \"Speechiness\": 0.136, \"Acousticness\": 0.269, \"Liveness\": 0.108, \"Tempo\": 90.013, \"Duration (ms)\": 219048.0, \"Valence\": 0.68, \"Chord\": \"B\"}, {\"Index\": 496, \"Highest Charting Position\": 86, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"All We Got (feat. KIDDO)\", \"Streams\": 5156937, \"Artist\": \"Robin Schulz\", \"Artist Followers\": 2786366.0, \"Song ID\": \"1FP9s72rDYty6mfoOEYKnE\", \"Genre\": \"['dance pop', 'deep euro house', 'deep house', 'edm', 'german dance', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 74.0, \"Danceability\": 0.504, \"Energy\": 0.76, \"Loudness\": -4.246, \"Speechiness\": 0.0426, \"Acousticness\": 0.286, \"Liveness\": 0.151, \"Tempo\": 183.933, \"Duration (ms)\": 190218.0, \"Valence\": 0.64, \"Chord\": \"E\"}, {\"Index\": 497, \"Highest Charting Position\": 6, \"Number of Times Charted\": 60, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Say So\", \"Streams\": 5103528, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"3Dv1eDb0MEgF93GpLXlucZ\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-02-26--2021-03-05\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.787, \"Energy\": 0.673, \"Loudness\": -4.583, \"Speechiness\": 0.159, \"Acousticness\": 0.264, \"Liveness\": 0.0904, \"Tempo\": 110.962, \"Duration (ms)\": 237893.0, \"Valence\": 0.779, \"Chord\": \"B\"}, {\"Index\": 498, \"Highest Charting Position\": 157, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Hope\", \"Streams\": 5085527, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"2ZRo7axmMPeSVUvDbGkJah\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2018-03-16\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 84.0, \"Danceability\": 0.592, \"Energy\": 0.457, \"Loudness\": -6.081, \"Speechiness\": 0.0603, \"Acousticness\": 0.661, \"Liveness\": 0.146, \"Tempo\": 146.04, \"Duration (ms)\": 110886.0, \"Valence\": 0.225, \"Chord\": \"A\"}, {\"Index\": 499, \"Highest Charting Position\": 149, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"The Less I Know The Better\", \"Streams\": 5084635, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"6K4t31amVTZDgR3sKmwUJJ\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2015-07-17\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-01-03--2020-01-10\", \"Popularity\": 84.0, \"Danceability\": 0.64, \"Energy\": 0.74, \"Loudness\": -4.083, \"Speechiness\": 0.0284, \"Acousticness\": 0.0115, \"Liveness\": 0.167, \"Tempo\": 116.879, \"Duration (ms)\": 216320.0, \"Valence\": 0.785, \"Chord\": \"E\"}, {\"Index\": 500, \"Highest Charting Position\": 109, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"I Feel It Coming\", \"Streams\": 5079857, \"Artist\": \"The Weeknd, Daft Punk\", \"Artist Followers\": 35340069.0, \"Song ID\": \"3dhjNA0jGA8vHBQ1VdD6vV\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2016-11-25\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 80.0, \"Danceability\": 0.773, \"Energy\": 0.819, \"Loudness\": -5.946, \"Speechiness\": 0.118, \"Acousticness\": 0.428, \"Liveness\": 0.0679, \"Tempo\": 92.987, \"Duration (ms)\": 269187.0, \"Valence\": 0.585, \"Chord\": \"C\"}, {\"Index\": 501, \"Highest Charting Position\": 12, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Mood Swings (feat. Lil Tjay)\", \"Streams\": 5068349, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"5rZlwNFl01HqLWBQGryKSm\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 82.0, \"Danceability\": 0.48, \"Energy\": 0.602, \"Loudness\": -6.335, \"Speechiness\": 0.368, \"Acousticness\": 0.487, \"Liveness\": 0.0848, \"Tempo\": 179.798, \"Duration (ms)\": 213333.0, \"Valence\": 0.269, \"Chord\": \"A#/Bb\"}, {\"Index\": 502, \"Highest Charting Position\": 123, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Someone To You\", \"Streams\": 5054881, \"Artist\": \"BANNERS\", \"Artist Followers\": 419151.0, \"Song ID\": \"2f0pn9DkEJwAzXApnFh5cr\", \"Genre\": \"['indie cafe pop', 'indie poptimism', 'modern rock', 'pop', 'pop rock']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 79.0, \"Danceability\": 0.52, \"Energy\": 0.903, \"Loudness\": -5.497, \"Speechiness\": 0.042, \"Acousticness\": 0.00517, \"Liveness\": 0.254, \"Tempo\": 74.988, \"Duration (ms)\": 219801.0, \"Valence\": 0.652, \"Chord\": \"D\"}, {\"Index\": 503, \"Highest Charting Position\": 198, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"To the Bone\", \"Streams\": 5052557, \"Artist\": \"Pamungkas\", \"Artist Followers\": 1643882.0, \"Song ID\": \"3pCt2wRdBDa2kCisIdHWgF\", \"Genre\": \"['indonesian pop']\", \"Release Date\": \"2019-06-14\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 81.0, \"Danceability\": 0.668, \"Energy\": 0.727, \"Loudness\": -6.55, \"Speechiness\": 0.027, \"Acousticness\": 0.514, \"Liveness\": 0.1, \"Tempo\": 139.991, \"Duration (ms)\": 344571.0, \"Valence\": 0.939, \"Chord\": \"G\"}, {\"Index\": 504, \"Highest Charting Position\": 4, \"Number of Times Charted\": 38, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"How You Like That\", \"Streams\": 5023592, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"4SFknyjLcyTLJFPKD2m96o\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 79.0, \"Danceability\": 0.812, \"Energy\": 0.761, \"Loudness\": -5.222, \"Speechiness\": 0.0812, \"Acousticness\": 0.0465, \"Liveness\": 0.0601, \"Tempo\": 130.032, \"Duration (ms)\": 182956.0, \"Valence\": 0.344, \"Chord\": \"B\"}, {\"Index\": 505, \"Highest Charting Position\": 200, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"LOST\", \"Streams\": 5013851, \"Artist\": \"NF, Hopsin\", \"Artist Followers\": 5831194.0, \"Song ID\": \"2MZrOmrVxRmmOoFW6dhenG\", \"Genre\": \"['hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2021-03-11\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 66.0, \"Danceability\": 0.637, \"Energy\": 0.912, \"Loudness\": -3.123, \"Speechiness\": 0.308, \"Acousticness\": 0.352, \"Liveness\": 0.0657, \"Tempo\": 116.919, \"Duration (ms)\": 234852.0, \"Valence\": 0.451, \"Chord\": \"F\"}, {\"Index\": 506, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"VOCE\", \"Streams\": 5510906, \"Artist\": \"Madame\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6CAVxdHTkls5loqUmfM52V\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 0.0, \"Danceability\": 0.615, \"Energy\": 0.834, \"Loudness\": -5.471, \"Speechiness\": 0.0667, \"Acousticness\": 0.105, \"Liveness\": 0.157, \"Tempo\": 112.602, \"Duration (ms)\": 211411.0, \"Valence\": 0.341, \"Chord\": \"G#/Ab\"}, {\"Index\": 507, \"Highest Charting Position\": 64, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"AP - Music from the film Boogie\", \"Streams\": 5462333, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"17vGPZ5EsdvtgAOCD4FLWI\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\", \"Popularity\": 75.0, \"Danceability\": 0.751, \"Energy\": 0.744, \"Loudness\": -6.859, \"Speechiness\": 0.177, \"Acousticness\": 0.152, \"Liveness\": 0.252, \"Tempo\": 148.014, \"Duration (ms)\": 171892.0, \"Valence\": 0.634, \"Chord\": \"C#/Db\"}, {\"Index\": 508, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Life's A Mess II (with Clever & Post Malone)\", \"Streams\": 5393459, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4O3RwH1TFG1EjPezLIYehI\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 72.0, \"Danceability\": 0.53, \"Energy\": 0.37, \"Loudness\": -9.989, \"Speechiness\": 0.0279, \"Acousticness\": 0.806, \"Liveness\": 0.112, \"Tempo\": 140.061, \"Duration (ms)\": 206734.0, \"Valence\": 0.701, \"Chord\": \"F#/Gb\"}, {\"Index\": 509, \"Highest Charting Position\": 170, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"CHIAMAMI PER NOME\", \"Streams\": 5321946, \"Artist\": \"Francesca Michielin, Fedez\", \"Artist Followers\": 568711.0, \"Song ID\": \"0ZqHo6eTBHUcOVjZzPvftT\", \"Genre\": \"['italian adult pop', 'italian indie pop', 'italian pop', 'italian pop rock']\", \"Release Date\": \"2021-03-03\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 67.0, \"Danceability\": 0.641, \"Energy\": 0.636, \"Loudness\": -4.318, \"Speechiness\": 0.0414, \"Acousticness\": 0.289, \"Liveness\": 0.125, \"Tempo\": 89.826, \"Duration (ms)\": 222667.0, \"Valence\": 0.285, \"Chord\": \"A#/Bb\"}, {\"Index\": 510, \"Highest Charting Position\": 54, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Antes\", \"Streams\": 5232377, \"Artist\": \"Anuel AA, Ozuna\", \"Artist Followers\": 18306226.0, \"Song ID\": \"73O30uMI7n6DuzBmbtO7kC\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 73.0, \"Danceability\": 0.817, \"Energy\": 0.737, \"Loudness\": -5.453, \"Speechiness\": 0.102, \"Acousticness\": 0.046, \"Liveness\": 0.092, \"Tempo\": 93.985, \"Duration (ms)\": 206587.0, \"Valence\": 0.67, \"Chord\": \"F#/Gb\"}, {\"Index\": 511, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Mona Lisa\", \"Streams\": 5208787, \"Artist\": \"Booba, JSX\", \"Artist Followers\": 2161609.0, \"Song ID\": \"5LYRIyhmlrDAQsYdHEvP0f\", \"Genre\": \"['french hip hop', 'old school rap francais', 'pop urbaine', 'rap conscient']\", \"Release Date\": \"2021-03-04\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 72.0, \"Danceability\": 0.784, \"Energy\": 0.529, \"Loudness\": -7.681, \"Speechiness\": 0.0742, \"Acousticness\": 0.683, \"Liveness\": 0.118, \"Tempo\": 134.041, \"Duration (ms)\": 187362.0, \"Valence\": 0.246, \"Chord\": \"B\"}, {\"Index\": 512, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Real As It Gets (feat. EST Gee)\", \"Streams\": 5170861, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"7eX3um6NpOQKWJMGCi97XD\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2021-03-04\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 74.0, \"Danceability\": 0.779, \"Energy\": 0.705, \"Loudness\": -5.891, \"Speechiness\": 0.163, \"Acousticness\": 0.00471, \"Liveness\": 0.0971, \"Tempo\": 140.005, \"Duration (ms)\": 192804.0, \"Valence\": 0.196, \"Chord\": \"F#/Gb\"}, {\"Index\": 513, \"Highest Charting Position\": 24, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Se Te Nota (with Guaynaa)\", \"Streams\": 5168240, \"Artist\": \"Lele Pons\", \"Artist Followers\": 786461.0, \"Song ID\": \"11EnQRgRMJwMAesfkB5pnu\", \"Genre\": \"['latin pop', 'viral pop']\", \"Release Date\": \"2020-09-02\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 77.0, \"Danceability\": 0.905, \"Energy\": 0.686, \"Loudness\": -3.152, \"Speechiness\": 0.0664, \"Acousticness\": 0.0907, \"Liveness\": 0.266, \"Tempo\": 103.013, \"Duration (ms)\": 155825.0, \"Valence\": 0.963, \"Chord\": \"C\"}, {\"Index\": 514, \"Highest Charting Position\": 91, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Head Shoulders Knees & Toes (feat. Norma Jean Martine)\", \"Streams\": 5093408, \"Artist\": \"Ofenbach, Quarterhead\", \"Artist Followers\": 432511.0, \"Song ID\": \"6i7zAdNhzUN2k1HcrBxPHG\", \"Genre\": \"['edm', 'new french touch', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 79.0, \"Danceability\": 0.798, \"Energy\": 0.828, \"Loudness\": -5.36, \"Speechiness\": 0.193, \"Acousticness\": 0.0247, \"Liveness\": 0.121, \"Tempo\": 124.962, \"Duration (ms)\": 156960.0, \"Valence\": 0.6, \"Chord\": \"D\"}, {\"Index\": 515, \"Highest Charting Position\": 152, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Star Shopping\", \"Streams\": 5073657, \"Artist\": \"Lil Peep\", \"Artist Followers\": 7535054.0, \"Song ID\": \"30bqVoKjX479ab90a8Pafp\", \"Genre\": \"['emo rap', 'lgbtq+ hip hop']\", \"Release Date\": \"2015\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 82.0, \"Danceability\": 0.585, \"Energy\": 0.471, \"Loudness\": -9.934, \"Speechiness\": 0.0616, \"Acousticness\": 0.0967, \"Liveness\": 0.115, \"Tempo\": 93.099, \"Duration (ms)\": 142000.0, \"Valence\": 0.323, \"Chord\": \"E\"}, {\"Index\": 516, \"Highest Charting Position\": 61, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Electric Love\", \"Streams\": 5060903, \"Artist\": \"B\\u00d8RNS\", \"Artist Followers\": 1027085.0, \"Song ID\": \"2GiJYvgVaD2HtM8GqD9EgQ\", \"Genre\": \"['modern alternative rock', 'modern rock', 'pop']\", \"Release Date\": \"2015-10-16\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 83.0, \"Danceability\": 0.611, \"Energy\": 0.797, \"Loudness\": -7.627, \"Speechiness\": 0.0533, \"Acousticness\": 0.00543, \"Liveness\": 0.26, \"Tempo\": 120.041, \"Duration (ms)\": 218107.0, \"Valence\": 0.518, \"Chord\": \"F#/Gb\"}, {\"Index\": 517, \"Highest Charting Position\": 112, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Maniac\", \"Streams\": 5044929, \"Artist\": \"Conan Gray\", \"Artist Followers\": 3799104.0, \"Song ID\": \"6KfoDhO4XUWSbnyKjNp9c4\", \"Genre\": \"['alt z', 'bedroom pop', 'electropop', 'indie pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.628, \"Energy\": 0.639, \"Loudness\": -5.46, \"Speechiness\": 0.0435, \"Acousticness\": 0.00162, \"Liveness\": 0.354, \"Tempo\": 108.045, \"Duration (ms)\": 185773.0, \"Valence\": 0.493, \"Chord\": \"G#/Ab\"}, {\"Index\": 518, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Only Wanna Be With You - Pok\\u00e9mon 25 Version\", \"Streams\": 7464020, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"3SawmGBjjq8EOYZJV11cJm\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2021-02-25\", \"Weeks Charted\": \"2021-02-26--2021-03-05\", \"Popularity\": 72.0, \"Danceability\": 0.47, \"Energy\": 0.709, \"Loudness\": -4.563, \"Speechiness\": 0.0299, \"Acousticness\": 0.00124, \"Liveness\": 0.302, \"Tempo\": 98.036, \"Duration (ms)\": 241360.0, \"Valence\": 0.247, \"Chord\": \"G\"}, {\"Index\": 519, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"test drive\", \"Streams\": 6591829, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3eZYOQO4UzKrUDYDghtnFw\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-02-19\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 71.0, \"Danceability\": 0.698, \"Energy\": 0.708, \"Loudness\": -4.943, \"Speechiness\": 0.0454, \"Acousticness\": 0.0251, \"Liveness\": 0.124, \"Tempo\": 115.036, \"Duration (ms)\": 122174.0, \"Valence\": 0.322, \"Chord\": \"A\"}, {\"Index\": 520, \"Highest Charting Position\": 42, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"T\\u00fa Me Dejaste De Querer\", \"Streams\": 5874460, \"Artist\": \"C. Tangana, Ni\\u00f1o de Elche, La H\\u00fangara\", \"Artist Followers\": 1453875.0, \"Song ID\": \"5ddFjrPG8NgQQ6xlOQIVd2\", \"Genre\": \"['urbano espanol']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 75.0, \"Danceability\": 0.823, \"Energy\": 0.723, \"Loudness\": -4.778, \"Speechiness\": 0.229, \"Acousticness\": 0.311, \"Liveness\": 0.0998, \"Tempo\": 83.97, \"Duration (ms)\": 198493.0, \"Valence\": 0.505, \"Chord\": \"E\"}, {\"Index\": 521, \"Highest Charting Position\": 46, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"SO DONE\", \"Streams\": 5440707, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"5psEZhQu6lukjhavJo4AbC\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-10-23\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 74.0, \"Danceability\": 0.719, \"Energy\": 0.598, \"Loudness\": -6.254, \"Speechiness\": 0.077, \"Acousticness\": 0.232, \"Liveness\": 0.115, \"Tempo\": 142.592, \"Duration (ms)\": 126521.0, \"Valence\": 0.303, \"Chord\": \"A\"}, {\"Index\": 522, \"Highest Charting Position\": 35, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Jeans\", \"Streams\": 5145966, \"Artist\": \"Justin Quiles\", \"Artist Followers\": 2897862.0, \"Song ID\": \"3GtnId3Cm1Xa6joCj08nzW\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 75.0, \"Danceability\": 0.807, \"Energy\": 0.656, \"Loudness\": -4.395, \"Speechiness\": 0.105, \"Acousticness\": 0.0165, \"Liveness\": 0.0693, \"Tempo\": 83.943, \"Duration (ms)\": 185840.0, \"Valence\": 0.89, \"Chord\": \"D#/Eb\"}, {\"Index\": 523, \"Highest Charting Position\": 2, \"Number of Times Charted\": 61, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"ROXANNE\", \"Streams\": 5124742, \"Artist\": \"Arizona Zervas\", \"Artist Followers\": 621200.0, \"Song ID\": \"696DnlkuDOXcMAnKlTgXXK\", \"Genre\": \"['pop rap', 'rhode island rap']\", \"Release Date\": \"2019-10-10\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.621, \"Energy\": 0.601, \"Loudness\": -5.616, \"Speechiness\": 0.148, \"Acousticness\": 0.0522, \"Liveness\": 0.46, \"Tempo\": 116.735, \"Duration (ms)\": 163636.0, \"Valence\": 0.457, \"Chord\": \"F#/Gb\"}, {\"Index\": 524, \"Highest Charting Position\": 83, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"rockstar (feat. 21 Savage)\", \"Streams\": 5115990, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"0e7ipj03S05BNilyu5bRzt\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2018-04-27\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-01-29--2021-02-05\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.585, \"Energy\": 0.52, \"Loudness\": -6.136, \"Speechiness\": 0.0712, \"Acousticness\": 0.124, \"Liveness\": 0.131, \"Tempo\": 159.801, \"Duration (ms)\": 218147.0, \"Valence\": 0.129, \"Chord\": \"F\"}, {\"Index\": 525, \"Highest Charting Position\": 185, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"P\\u00e1rteme La Cara\", \"Streams\": 5079580, \"Artist\": \"C. Tangana, Ed Maverick\", \"Artist Followers\": 1453875.0, \"Song ID\": \"5gEUDNQvoQjdjklrwPdGwD\", \"Genre\": \"['urbano espanol']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-02-26--2021-03-05\", \"Popularity\": 70.0, \"Danceability\": 0.761, \"Energy\": 0.296, \"Loudness\": -10.22, \"Speechiness\": 0.0484, \"Acousticness\": 0.551, \"Liveness\": 0.134, \"Tempo\": 127.938, \"Duration (ms)\": 167867.0, \"Valence\": 0.579, \"Chord\": \"C\"}, {\"Index\": 526, \"Highest Charting Position\": 80, \"Number of Times Charted\": 57, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Without Me\", \"Streams\": 5016283, \"Artist\": \"Halsey\", \"Artist Followers\": 15663384.0, \"Song ID\": \"5p7ujcrUXASCNwRaWNHR1C\", \"Genre\": \"['dance pop', 'electropop', 'etherpop', 'indie poptimism', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-10-04\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.752, \"Energy\": 0.488, \"Loudness\": -7.05, \"Speechiness\": 0.0705, \"Acousticness\": 0.297, \"Liveness\": 0.0936, \"Tempo\": 136.041, \"Duration (ms)\": 201661.0, \"Valence\": 0.533, \"Chord\": \"F#/Gb\"}, {\"Index\": 527, \"Highest Charting Position\": 33, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"BOOKER T\", \"Streams\": 4995965, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"26w9NTiE9NGjW1ZvIOd1So\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 77.0, \"Danceability\": 0.883, \"Energy\": 0.6, \"Loudness\": -7.188, \"Speechiness\": 0.37, \"Acousticness\": 0.114, \"Liveness\": 0.0931, \"Tempo\": 113.903, \"Duration (ms)\": 156430.0, \"Valence\": 0.691, \"Chord\": \"G\"}, {\"Index\": 528, \"Highest Charting Position\": 5, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Intentions (feat. Quavo)\", \"Streams\": 4994138, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"4umIPjkehX1r7uhmGvXiSV\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 77.0, \"Danceability\": 0.806, \"Energy\": 0.546, \"Loudness\": -6.637, \"Speechiness\": 0.0575, \"Acousticness\": 0.3, \"Liveness\": 0.102, \"Tempo\": 147.986, \"Duration (ms)\": 212867.0, \"Valence\": 0.874, \"Chord\": \"A\"}, {\"Index\": 529, \"Highest Charting Position\": 49, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Sofia\", \"Streams\": 4982892, \"Artist\": \"Clairo\", \"Artist Followers\": 2722638.0, \"Song ID\": \"7B3z0ySL9Rr0XvZEAjWZzM\", \"Genre\": \"['bedroom pop', 'indie pop', 'pop']\", \"Release Date\": \"2019-08-02\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 81.0, \"Danceability\": 0.744, \"Energy\": 0.619, \"Loudness\": -9.805, \"Speechiness\": 0.039, \"Acousticness\": 0.598, \"Liveness\": 0.231, \"Tempo\": 112.997, \"Duration (ms)\": 188387.0, \"Valence\": 0.641, \"Chord\": \"C\"}, {\"Index\": 530, \"Highest Charting Position\": 176, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Photograph\", \"Streams\": 4974880, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"1HNkqx9Ahdgi1Ixy2xkKkL\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2014-06-21\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-02-07--2020-02-14\\n2020-01-03--2020-01-10\", \"Popularity\": 83.0, \"Danceability\": 0.614, \"Energy\": 0.379, \"Loudness\": -10.48, \"Speechiness\": 0.0476, \"Acousticness\": 0.607, \"Liveness\": 0.0986, \"Tempo\": 107.989, \"Duration (ms)\": 258987.0, \"Valence\": 0.201, \"Chord\": \"E\"}, {\"Index\": 531, \"Highest Charting Position\": 20, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"34+35 Remix (feat. Doja Cat, Megan Thee Stallion) - Remix\", \"Streams\": 6162453, \"Artist\": \"Ariana Grande\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 532, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"Madonna\", \"Streams\": 5936752, \"Artist\": \"Bausa, Apache 207\", \"Artist Followers\": 961181.0, \"Song ID\": \"6a3kNt1UlUOapDKmEr3JzZ\", \"Genre\": \"['german hip hop', 'german pop']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-02-19--2021-02-26\", \"Popularity\": 68.0, \"Danceability\": 0.806, \"Energy\": 0.565, \"Loudness\": -8.96, \"Speechiness\": 0.113, \"Acousticness\": 0.47, \"Liveness\": 0.0824, \"Tempo\": 116.963, \"Duration (ms)\": 195734.0, \"Valence\": 0.311, \"Chord\": \"B\"}, {\"Index\": 533, \"Highest Charting Position\": 144, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"CLOUDS\", \"Streams\": 5897983, \"Artist\": \"NF\", \"Artist Followers\": 5831194.0, \"Song ID\": \"5UMMPHPp6vRP6ghPpSUOzp\", \"Genre\": \"['hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2021-02-18\", \"Weeks Charted\": \"2021-02-19--2021-02-26\", \"Popularity\": 69.0, \"Danceability\": 0.793, \"Energy\": 0.65, \"Loudness\": -3.944, \"Speechiness\": 0.397, \"Acousticness\": 0.371, \"Liveness\": 0.854, \"Tempo\": 128.111, \"Duration (ms)\": 243750.0, \"Valence\": 0.809, \"Chord\": \"C#/Db\"}, {\"Index\": 534, \"Highest Charting Position\": 12, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Wonder\", \"Streams\": 5535339, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 1251372.0, \"Song ID\": \"7jjS2fSD9zuzbEHeVEFJ2w\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 0.0, \"Danceability\": 0.333, \"Energy\": 0.637, \"Loudness\": -4.904, \"Speechiness\": 0.0581, \"Acousticness\": 0.131, \"Liveness\": 0.149, \"Tempo\": 139.898, \"Duration (ms)\": 172693.0, \"Valence\": 0.132, \"Chord\": \"C#/Db\"}, {\"Index\": 535, \"Highest Charting Position\": 50, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Skin\", \"Streams\": 5497942, \"Artist\": \"Sabrina Carpenter\", \"Artist Followers\": 3689546.0, \"Song ID\": \"03B2SfXuvDh1m9F4tqrX07\", \"Genre\": \"['alt z', 'dance pop', 'electropop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 76.0, \"Danceability\": 0.557, \"Energy\": 0.457, \"Loudness\": -5.372, \"Speechiness\": 0.0335, \"Acousticness\": 0.428, \"Liveness\": 0.0567, \"Tempo\": 105.918, \"Duration (ms)\": 177500.0, \"Valence\": 0.328, \"Chord\": \"G\"}, {\"Index\": 536, \"Highest Charting Position\": 62, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Tyler Herro\", \"Streams\": 5168107, \"Artist\": \"Jack Harlow\", \"Artist Followers\": 1053324.0, \"Song ID\": \"4DuUwzP4ALMqpquHU0ltAB\", \"Genre\": \"['deep underground hip hop', 'kentucky hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-10-22\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 76.0, \"Danceability\": 0.794, \"Energy\": 0.756, \"Loudness\": -7.16, \"Speechiness\": 0.136, \"Acousticness\": 0.11, \"Liveness\": 0.247, \"Tempo\": 123.066, \"Duration (ms)\": 156498.0, \"Valence\": 0.775, \"Chord\": \"F\"}, {\"Index\": 537, \"Highest Charting Position\": 173, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Remember That Night?\", \"Streams\": 5116325, \"Artist\": \"Sara Kays\", \"Artist Followers\": 251549.0, \"Song ID\": \"1nYzjrdVQ8RpF93M0jPFW7\", \"Genre\": \"['alt z', 'indie cafe pop', 'modern indie pop', 'pop', 'social media pop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 78.0, \"Danceability\": 0.679, \"Energy\": 0.61, \"Loudness\": -10.936, \"Speechiness\": 0.0305, \"Acousticness\": 0.585, \"Liveness\": 0.156, \"Tempo\": 123.978, \"Duration (ms)\": 227186.0, \"Valence\": 0.554, \"Chord\": \"G\"}, {\"Index\": 538, \"Highest Charting Position\": 128, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Lifestyle (feat. Adam Levine)\", \"Streams\": 5059891, \"Artist\": \"Jason Derulo, Maroon 5\", \"Artist Followers\": 9778632.0, \"Song ID\": \"0osvOdeD3YXZiWkT8MKolJ\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 78.0, \"Danceability\": 0.749, \"Energy\": 0.674, \"Loudness\": -5.128, \"Speechiness\": 0.0366, \"Acousticness\": 0.0209, \"Liveness\": 0.169, \"Tempo\": 123.055, \"Duration (ms)\": 153865.0, \"Valence\": 0.711, \"Chord\": \"A#/Bb\"}, {\"Index\": 539, \"Highest Charting Position\": 177, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Fly Away\", \"Streams\": 5053713, \"Artist\": \"Tones And I\", \"Artist Followers\": 2820477.0, \"Song ID\": \"5ri4zqtWhG07hIuNNDWP76\", \"Genre\": \"['australian pop', 'pop']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 79.0, \"Danceability\": 0.806, \"Energy\": 0.513, \"Loudness\": -6.208, \"Speechiness\": 0.0685, \"Acousticness\": 0.217, \"Liveness\": 0.217, \"Tempo\": 124.988, \"Duration (ms)\": 178157.0, \"Valence\": 0.503, \"Chord\": \"E\"}, {\"Index\": 540, \"Highest Charting Position\": 37, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Despeinada\", \"Streams\": 5004462, \"Artist\": \"Ozuna, Camilo\", \"Artist Followers\": 29238936.0, \"Song ID\": \"0JAZWvvqttGFm4UMDsPQXC\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 75.0, \"Danceability\": 0.734, \"Energy\": 0.775, \"Loudness\": -3.855, \"Speechiness\": 0.0614, \"Acousticness\": 0.186, \"Liveness\": 0.123, \"Tempo\": 166.039, \"Duration (ms)\": 224187.0, \"Valence\": 0.72, \"Chord\": \"G#/Ab\"}, {\"Index\": 541, \"Highest Charting Position\": 14, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"motive (with Doja Cat)\", \"Streams\": 4986037, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"5GkQIP5mWPi4KZLLXeuFTT\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 80.0, \"Danceability\": 0.789, \"Energy\": 0.742, \"Loudness\": -5.664, \"Speechiness\": 0.0652, \"Acousticness\": 0.0681, \"Liveness\": 0.166, \"Tempo\": 116.965, \"Duration (ms)\": 167990.0, \"Valence\": 0.661, \"Chord\": \"A#/Bb\"}, {\"Index\": 542, \"Highest Charting Position\": 28, \"Number of Times Charted\": 57, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"I Don't Care (with Justin Bieber)\", \"Streams\": 4984399, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"3HVWdVOQ0ZA45FuZGSfvns\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-05-10\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.798, \"Energy\": 0.675, \"Loudness\": -5.041, \"Speechiness\": 0.0442, \"Acousticness\": 0.0912, \"Liveness\": 0.0894, \"Tempo\": 101.956, \"Duration (ms)\": 219947.0, \"Valence\": 0.842, \"Chord\": \"F#/Gb\"}, {\"Index\": 543, \"Highest Charting Position\": 14, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Ay, DiOs M\\u00edo!\", \"Streams\": 5344862, \"Artist\": \"KAROL G\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3PF1mUoD0NgK4ykdt5sk3g\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 0.0, \"Danceability\": 0.715, \"Energy\": 0.706, \"Loudness\": -4.423, \"Speechiness\": 0.195, \"Acousticness\": 0.496, \"Liveness\": 0.106, \"Tempo\": 179.997, \"Duration (ms)\": 189840.0, \"Valence\": 0.522, \"Chord\": \"B\"}, {\"Index\": 544, \"Highest Charting Position\": 83, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Nathy Peluso: Bzrp Music Sessions, Vol. 36\", \"Streams\": 5232509, \"Artist\": \"Bizarrap, Nathy Peluso\", \"Artist Followers\": 3134041.0, \"Song ID\": \"78SeXVRJ7KCqVmOwTiFjnI\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 77.0, \"Danceability\": 0.65, \"Energy\": 0.655, \"Loudness\": -3.71, \"Speechiness\": 0.405, \"Acousticness\": 0.25, \"Liveness\": 0.0691, \"Tempo\": 94.059, \"Duration (ms)\": 171215.0, \"Valence\": 0.735, \"Chord\": \"C#/Db\"}, {\"Index\": 545, \"Highest Charting Position\": 17, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Haw\\u00e1i - Remix\", \"Streams\": 5163323, \"Artist\": \"Maluma, The Weeknd\", \"Artist Followers\": 26784251.0, \"Song ID\": \"0GzuHFG4Ql6DoyxFRnIk3F\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-11-05\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 77.0, \"Danceability\": 0.766, \"Energy\": 0.788, \"Loudness\": -3.128, \"Speechiness\": 0.312, \"Acousticness\": 0.105, \"Liveness\": 0.142, \"Tempo\": 179.984, \"Duration (ms)\": 200482.0, \"Valence\": 0.609, \"Chord\": \"F#/Gb\"}, {\"Index\": 546, \"Highest Charting Position\": 22, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Tattoo - Remix with Camilo\", \"Streams\": 5120753, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6096559.0, \"Song ID\": \"4ZRrLHqzhGRXYj2qcB4s5S\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-07-09\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 78.0, \"Danceability\": 0.848, \"Energy\": 0.637, \"Loudness\": -5.132, \"Speechiness\": 0.156, \"Acousticness\": 0.0413, \"Liveness\": 0.0521, \"Tempo\": 96.988, \"Duration (ms)\": 222680.0, \"Valence\": 0.698, \"Chord\": \"A\"}, {\"Index\": 547, \"Highest Charting Position\": 151, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Meia Noite (Voc\\u00ea tem meu Whatsapp)\", \"Streams\": 5044252, \"Artist\": \"Tarc\\u00edsio do Acordeon\", \"Artist Followers\": 1200248.0, \"Song ID\": \"6sPBi0qLI6KM3yXX56NxsA\", \"Genre\": \"[]\", \"Release Date\": \"2020-12-17\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 67.0, \"Danceability\": 0.709, \"Energy\": 0.816, \"Loudness\": -4.787, \"Speechiness\": 0.0346, \"Acousticness\": 0.685, \"Liveness\": 0.146, \"Tempo\": 150.06, \"Duration (ms)\": 237900.0, \"Valence\": 0.921, \"Chord\": \"B\"}, {\"Index\": 548, \"Highest Charting Position\": 143, \"Number of Times Charted\": 42, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Moonlight\", \"Streams\": 5003825, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"0JP9xo3adEtGSdUEISiszL\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2018-03-16\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2020-09-18--2020-09-25\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.921, \"Energy\": 0.537, \"Loudness\": -5.723, \"Speechiness\": 0.0804, \"Acousticness\": 0.556, \"Liveness\": 0.102, \"Tempo\": 128.009, \"Duration (ms)\": 135090.0, \"Valence\": 0.711, \"Chord\": \"A\"}, {\"Index\": 549, \"Highest Charting Position\": 182, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Thinking out Loud\", \"Streams\": 4995623, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"34gCuhDGsG4bRPIf9bb02f\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2014-06-21\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 82.0, \"Danceability\": 0.781, \"Energy\": 0.445, \"Loudness\": -6.061, \"Speechiness\": 0.0295, \"Acousticness\": 0.474, \"Liveness\": 0.184, \"Tempo\": 78.998, \"Duration (ms)\": 281560.0, \"Valence\": 0.591, \"Chord\": \"D\"}, {\"Index\": 550, \"Highest Charting Position\": 2, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Toosie Slide\", \"Streams\": 4966878, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"127QTOFJsJQp5LbJbu3A1y\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 78.0, \"Danceability\": 0.834, \"Energy\": 0.454, \"Loudness\": -9.75, \"Speechiness\": 0.201, \"Acousticness\": 0.321, \"Liveness\": 0.114, \"Tempo\": 81.618, \"Duration (ms)\": 247059.0, \"Valence\": 0.837, \"Chord\": \"C#/Db\"}, {\"Index\": 551, \"Highest Charting Position\": 167, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Earned It (Fifty Shades Of Grey)\", \"Streams\": 4929647, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"4frLb7nWtsz2ymBE6k2GRP\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2015-08-28\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 69.0, \"Danceability\": 0.659, \"Energy\": 0.291, \"Loudness\": -8.275, \"Speechiness\": 0.0348, \"Acousticness\": 0.405, \"Liveness\": 0.0771, \"Tempo\": 119.829, \"Duration (ms)\": 277680.0, \"Valence\": 0.406, \"Chord\": \"D\"}, {\"Index\": 552, \"Highest Charting Position\": 9, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"ily (i love you baby) (feat. Emilee)\", \"Streams\": 4908929, \"Artist\": \"Surf Mesa\", \"Artist Followers\": 132855.0, \"Song ID\": \"62aP9fBQKYKxi7PDXwcUAS\", \"Genre\": \"['tropical house']\", \"Release Date\": \"2019-11-26\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 81.0, \"Danceability\": 0.674, \"Energy\": 0.774, \"Loudness\": -7.567, \"Speechiness\": 0.0892, \"Acousticness\": 0.0686, \"Liveness\": 0.393, \"Tempo\": 112.05, \"Duration (ms)\": 176547.0, \"Valence\": 0.33, \"Chord\": \"B\"}, {\"Index\": 553, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Wonderwall\", \"Streams\": 4902737, \"Artist\": \"Oasis\", \"Artist Followers\": 6478565.0, \"Song ID\": \"7ygpwy2qP3NbrxVkHvUhXY\", \"Genre\": \"['beatlesque', 'britpop', 'madchester', 'permanent wave', 'rock']\", \"Release Date\": \"1995\", \"Weeks Charted\": \"2021-02-12--2021-02-19\", \"Popularity\": 78.0, \"Danceability\": 0.375, \"Energy\": 0.893, \"Loudness\": -4.097, \"Speechiness\": 0.0406, \"Acousticness\": 0.000509, \"Liveness\": 0.187, \"Tempo\": 174.323, \"Duration (ms)\": 258773.0, \"Valence\": 0.434, \"Chord\": \"D\"}, {\"Index\": 554, \"Highest Charting Position\": 181, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Everybody Dies In Their Nightmares\", \"Streams\": 4847224, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"3GVkPk8mqxz0itaAriG1L7\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2017-08-25\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\", \"Popularity\": 83.0, \"Danceability\": 0.734, \"Energy\": 0.57, \"Loudness\": -7.066, \"Speechiness\": 0.133, \"Acousticness\": 0.847, \"Liveness\": 0.112, \"Tempo\": 129.953, \"Duration (ms)\": 95467.0, \"Valence\": 0.689, \"Chord\": \"G\"}, {\"Index\": 555, \"Highest Charting Position\": 27, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Bad Boy (with Young Thug)\", \"Streams\": 6011642, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"43CIWpJaJHRcI4mUSjqgc2\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 76.0, \"Danceability\": 0.697, \"Energy\": 0.674, \"Loudness\": -6.326, \"Speechiness\": 0.0533, \"Acousticness\": 0.00215, \"Liveness\": 0.138, \"Tempo\": 81.535, \"Duration (ms)\": 157355.0, \"Valence\": 0.198, \"Chord\": \"C#/Db\"}, {\"Index\": 556, \"Highest Charting Position\": 19, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Lo Vas A Olvidar (with ROSAL\\u00cdA)\", \"Streams\": 5963380, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"0psS4i5YooJrXfDnGvWRLi\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 68.0, \"Danceability\": 0.343, \"Energy\": 0.243, \"Loudness\": -14.66, \"Speechiness\": 0.0777, \"Acousticness\": 0.721, \"Liveness\": 0.0668, \"Tempo\": 135.154, \"Duration (ms)\": 203464.0, \"Valence\": 0.032, \"Chord\": \"E\"}, {\"Index\": 557, \"Highest Charting Position\": 152, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Floating Through Space\", \"Streams\": 5579697, \"Artist\": \"Sia, David Guetta\", \"Artist Followers\": 20528724.0, \"Song ID\": \"2AceGjiX9isUbXmMZa0Dl1\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'pop']\", \"Release Date\": \"2021-02-04\", \"Weeks Charted\": \"2021-02-05--2021-02-12\", \"Popularity\": 78.0, \"Danceability\": 0.575, \"Energy\": 0.844, \"Loudness\": -4.89, \"Speechiness\": 0.072, \"Acousticness\": 0.00172, \"Liveness\": 0.114, \"Tempo\": 104.914, \"Duration (ms)\": 177801.0, \"Valence\": 0.277, \"Chord\": \"F#/Gb\"}, {\"Index\": 558, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Can't Feel My Face\", \"Streams\": 5479407, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"22VdIZQfgXJea34mQxlt81\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2015-08-28\", \"Weeks Charted\": \"2021-02-05--2021-02-12\", \"Popularity\": 80.0, \"Danceability\": 0.705, \"Energy\": 0.769, \"Loudness\": -5.526, \"Speechiness\": 0.0425, \"Acousticness\": 0.113, \"Liveness\": 0.105, \"Tempo\": 107.949, \"Duration (ms)\": 213520.0, \"Valence\": 0.583, \"Chord\": \"A\"}, {\"Index\": 559, \"Highest Charting Position\": 89, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"You (with Marshmello & Vance Joy)\", \"Streams\": 5342938, \"Artist\": \"benny blanco\", \"Artist Followers\": 804613.0, \"Song ID\": \"1GkHyypTFkUf0QQKwYoXH4\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2021-01-29\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 73.0, \"Danceability\": 0.668, \"Energy\": 0.563, \"Loudness\": -6.433, \"Speechiness\": 0.0522, \"Acousticness\": 0.0493, \"Liveness\": 0.119, \"Tempo\": 103.116, \"Duration (ms)\": 169632.0, \"Valence\": 0.305, \"Chord\": \"B\"}, {\"Index\": 560, \"Highest Charting Position\": 168, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Call Out My Name\", \"Streams\": 5233359, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"09mEdoA6zrmBPgTEN5qXmN\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2018-03-30\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\", \"Popularity\": 80.0, \"Danceability\": 0.461, \"Energy\": 0.593, \"Loudness\": -4.954, \"Speechiness\": 0.0356, \"Acousticness\": 0.17, \"Liveness\": 0.307, \"Tempo\": 134.17, \"Duration (ms)\": 228373.0, \"Valence\": 0.175, \"Chord\": \"C#/Db\"}, {\"Index\": 561, \"Highest Charting Position\": 14, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Midnight Sky\", \"Streams\": 5208100, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"27ycaQnQAxaPiyeg3nr2aB\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 76.0, \"Danceability\": 0.705, \"Energy\": 0.814, \"Loudness\": -5.466, \"Speechiness\": 0.0346, \"Acousticness\": 0.00115, \"Liveness\": 0.203, \"Tempo\": 110.0, \"Duration (ms)\": 223279.0, \"Valence\": 0.259, \"Chord\": \"E\"}, {\"Index\": 562, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Pressure (feat. Tove Lo)\", \"Streams\": 5197587, \"Artist\": \"Martin Garrix\", \"Artist Followers\": 14921269.0, \"Song ID\": \"4ga4WvRNhMsIL38pkBbnIN\", \"Genre\": \"['dance pop', 'dutch edm', 'edm', 'pop', 'pop dance', 'progressive house', 'tropical house']\", \"Release Date\": \"2021-02-05\", \"Weeks Charted\": \"2021-02-05--2021-02-12\", \"Popularity\": 76.0, \"Danceability\": 0.859, \"Energy\": 0.558, \"Loudness\": -8.991, \"Speechiness\": 0.0902, \"Acousticness\": 0.659, \"Liveness\": 0.124, \"Tempo\": 114.978, \"Duration (ms)\": 144391.0, \"Valence\": 0.357, \"Chord\": \"G\"}, {\"Index\": 563, \"Highest Charting Position\": 140, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Can You Feel My Heart\", \"Streams\": 5092250, \"Artist\": \"Bring Me The Horizon\", \"Artist Followers\": 3912138.0, \"Song ID\": \"0WSa1sucoNRcEeULlZVQXj\", \"Genre\": \"['melodic metalcore', 'metalcore', 'rock', 'uk metalcore']\", \"Release Date\": \"2013-04-01\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 77.0, \"Danceability\": 0.15, \"Energy\": 0.859, \"Loudness\": -2.827, \"Speechiness\": 0.0595, \"Acousticness\": 0.00201, \"Liveness\": 0.387, \"Tempo\": 170.527, \"Duration (ms)\": 228147.0, \"Valence\": 0.354, \"Chord\": \"E\"}, {\"Index\": 564, \"Highest Charting Position\": 167, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Agua de Jamaica\", \"Streams\": 5072462, \"Artist\": \"Maluma\", \"Artist Followers\": 26784251.0, \"Song ID\": \"41BzKiCrKpUQHS3TP0jmdr\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-01-28\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 75.0, \"Danceability\": 0.664, \"Energy\": 0.665, \"Loudness\": -3.616, \"Speechiness\": 0.0879, \"Acousticness\": 0.123, \"Liveness\": 0.411, \"Tempo\": 173.961, \"Duration (ms)\": 176970.0, \"Valence\": 0.726, \"Chord\": \"A#/Bb\"}, {\"Index\": 565, \"Highest Charting Position\": 162, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Mds\", \"Streams\": 5046418, \"Artist\": \"Kawe, Mc Lele JP\", \"Artist Followers\": 444736.0, \"Song ID\": \"0QglpM23kl9ldvVdoYNZwF\", \"Genre\": \"['brazilian hip hop', 'funk ostentacao']\", \"Release Date\": \"2020-05-19\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 72.0, \"Danceability\": 0.885, \"Energy\": 0.561, \"Loudness\": -5.331, \"Speechiness\": 0.249, \"Acousticness\": 0.261, \"Liveness\": 0.121, \"Tempo\": 140.02, \"Duration (ms)\": 125143.0, \"Valence\": 0.644, \"Chord\": \"F#/Gb\"}, {\"Index\": 566, \"Highest Charting Position\": 18, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Heartless\", \"Streams\": 4995578, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"6bnF93Rx87YqUBLSgjiMU8\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.537, \"Energy\": 0.746, \"Loudness\": -5.507, \"Speechiness\": 0.15, \"Acousticness\": 0.0236, \"Liveness\": 0.156, \"Tempo\": 170.062, \"Duration (ms)\": 198267.0, \"Valence\": 0.252, \"Chord\": \"A#/Bb\"}, {\"Index\": 567, \"Highest Charting Position\": 20, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"pov\", \"Streams\": 4906738, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3UoULw70kMsiVXxW0L3A33\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 79.0, \"Danceability\": 0.487, \"Energy\": 0.534, \"Loudness\": -5.664, \"Speechiness\": 0.0555, \"Acousticness\": 0.36, \"Liveness\": 0.1, \"Tempo\": 131.798, \"Duration (ms)\": 201882.0, \"Valence\": 0.173, \"Chord\": \"C\"}, {\"Index\": 568, \"Highest Charting Position\": 138, \"Number of Times Charted\": 49, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Be Alright\", \"Streams\": 4900492, \"Artist\": \"Dean Lewis\", \"Artist Followers\": 1692635.0, \"Song ID\": \"3EPXxR3ImUwfayaurPi3cm\", \"Genre\": \"['australian pop', 'indie cafe pop', 'pop', 'pop rock', 'post-teen pop']\", \"Release Date\": \"2018-06-29\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.553, \"Energy\": 0.586, \"Loudness\": -6.319, \"Speechiness\": 0.0362, \"Acousticness\": 0.697, \"Liveness\": 0.0813, \"Tempo\": 126.684, \"Duration (ms)\": 196373.0, \"Valence\": 0.443, \"Chord\": \"B\"}, {\"Index\": 569, \"Highest Charting Position\": 174, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Cry Baby (feat. DaBaby)\", \"Streams\": 4884711, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"4aarlAfLKVCTxUDNgbwhjH\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 76.0, \"Danceability\": 0.957, \"Energy\": 0.437, \"Loudness\": -7.882, \"Speechiness\": 0.359, \"Acousticness\": 0.00402, \"Liveness\": 0.219, \"Tempo\": 130.058, \"Duration (ms)\": 137984.0, \"Valence\": 0.616, \"Chord\": \"B\"}, {\"Index\": 570, \"Highest Charting Position\": 47, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Mi Cuarto\", \"Streams\": 4873380, \"Artist\": \"Jerry Di\", \"Artist Followers\": 149682.0, \"Song ID\": \"6fmQjRuo7XvRFCK2qex5hQ\", \"Genre\": \"['cubaton', 'dominican pop', 'pop venezolano', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 76.0, \"Danceability\": 0.854, \"Energy\": 0.525, \"Loudness\": -4.426, \"Speechiness\": 0.214, \"Acousticness\": 0.819, \"Liveness\": 0.146, \"Tempo\": 97.054, \"Duration (ms)\": 197587.0, \"Valence\": 0.63, \"Chord\": \"C#/Db\"}, {\"Index\": 571, \"Highest Charting Position\": 99, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Ohne Dich\", \"Streams\": 5487774, \"Artist\": \"KASIMIR1441, badm\\u00f3mzjay, WILDBWOYS\", \"Artist Followers\": 197320.0, \"Song ID\": \"4hSJUp6k7QeHLxU32MrLIU\", \"Genre\": \"['german alternative rap', 'german hip hop', 'german trap', 'tekk']\", \"Release Date\": \"2021-01-14\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 70.0, \"Danceability\": 0.807, \"Energy\": 0.535, \"Loudness\": -6.519, \"Speechiness\": 0.349, \"Acousticness\": 0.191, \"Liveness\": 0.125, \"Tempo\": 156.013, \"Duration (ms)\": 125720.0, \"Valence\": 0.925, \"Chord\": \"B\"}, {\"Index\": 572, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Gravity (feat. Tyler, The Creator)\", \"Streams\": 5136895, \"Artist\": \"Brent Faiyaz, DJ Dahi\", \"Artist Followers\": 1726216.0, \"Song ID\": \"6u3CPnFMKANYgfdiifFOiJ\", \"Genre\": \"['dmv rap', 'pop', 'r&b', 'rap']\", \"Release Date\": \"2021-01-29\", \"Weeks Charted\": \"2021-01-29--2021-02-05\", \"Popularity\": 76.0, \"Danceability\": 0.539, \"Energy\": 0.615, \"Loudness\": -8.746, \"Speechiness\": 0.252, \"Acousticness\": 0.173, \"Liveness\": 0.144, \"Tempo\": 163.924, \"Duration (ms)\": 214693.0, \"Valence\": 0.493, \"Chord\": \"C#/Db\"}, {\"Index\": 573, \"Highest Charting Position\": 55, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Vibez\", \"Streams\": 5071718, \"Artist\": \"ZAYN\", \"Artist Followers\": 16655692.0, \"Song ID\": \"709F3MwiVvLD0LQXeKs5Cz\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 69.0, \"Danceability\": 0.635, \"Energy\": 0.659, \"Loudness\": -7.499, \"Speechiness\": 0.116, \"Acousticness\": 0.242, \"Liveness\": 0.105, \"Tempo\": 96.855, \"Duration (ms)\": 163127.0, \"Valence\": 0.34, \"Chord\": \"G\"}, {\"Index\": 574, \"Highest Charting Position\": 103, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"All I Want - From \\\"High School Musical: The Musical: The Series\\\"\", \"Streams\": 5052801, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6313514.0, \"Song ID\": \"4Yxc55NX3tAXC2mHRAhtcW\", \"Genre\": \"['pop']\", \"Release Date\": \"2019-11-27\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 76.0, \"Danceability\": 0.376, \"Energy\": 0.43, \"Loudness\": -6.585, \"Speechiness\": 0.0328, \"Acousticness\": 0.0902, \"Liveness\": 0.0912, \"Tempo\": 77.599, \"Duration (ms)\": 177323.0, \"Valence\": 0.129, \"Chord\": \"C\"}, {\"Index\": 575, \"Highest Charting Position\": 45, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Daisy\", \"Streams\": 5030670, \"Artist\": \"Ashnikko\", \"Artist Followers\": 1248499.0, \"Song ID\": \"0AUvWawuP0ibk4SQ3sIZjk\", \"Genre\": \"['electropop', 'escape room', 'pop']\", \"Release Date\": \"2020-07-09\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 76.0, \"Danceability\": 0.834, \"Energy\": 0.663, \"Loudness\": -6.143, \"Speechiness\": 0.133, \"Acousticness\": 0.235, \"Liveness\": 0.372, \"Tempo\": 121.876, \"Duration (ms)\": 146523.0, \"Valence\": 0.774, \"Chord\": \"G#/Ab\"}, {\"Index\": 576, \"Highest Charting Position\": 83, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Wasted On You\", \"Streams\": 4948563, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"3cBsEDNhFI9E82vPj3kvi3\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 76.0, \"Danceability\": 0.505, \"Energy\": 0.657, \"Loudness\": -5.24, \"Speechiness\": 0.0318, \"Acousticness\": 0.373, \"Liveness\": 0.126, \"Tempo\": 196.0, \"Duration (ms)\": 178520.0, \"Valence\": 0.252, \"Chord\": \"B\"}, {\"Index\": 577, \"Highest Charting Position\": 13, \"Number of Times Charted\": 38, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"La Jeepeta - Remix\", \"Streams\": 4942545, \"Artist\": \"Nio Garcia, Anuel AA, Myke Towers, Brray, Juanka\", \"Artist Followers\": 2127531.0, \"Song ID\": \"1mohfLaTJtB2RplHLQVM70\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 75.0, \"Danceability\": 0.815, \"Energy\": 0.715, \"Loudness\": -4.65, \"Speechiness\": 0.207, \"Acousticness\": 0.3, \"Liveness\": 0.091, \"Tempo\": 176.007, \"Duration (ms)\": 345241.0, \"Valence\": 0.786, \"Chord\": \"E\"}, {\"Index\": 578, \"Highest Charting Position\": 137, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Los Dioses\", \"Streams\": 5929507, \"Artist\": \"Anuel AA, Ozuna\", \"Artist Followers\": 18306226.0, \"Song ID\": \"73O30uMI7n6DuzBmbtO7kC\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-01-22--2021-01-29\", \"Popularity\": 73.0, \"Danceability\": 0.817, \"Energy\": 0.737, \"Loudness\": -5.453, \"Speechiness\": 0.102, \"Acousticness\": 0.046, \"Liveness\": 0.092, \"Tempo\": 93.985, \"Duration (ms)\": 206587.0, \"Valence\": 0.67, \"Chord\": \"F#/Gb\"}, {\"Index\": 579, \"Highest Charting Position\": 132, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Si Me Tomo Una Cerveza\", \"Streams\": 5427534, \"Artist\": \"Migrantes, Alico\", \"Artist Followers\": 114348.0, \"Song ID\": \"3lCbsHaN1wCxyDzcNN2x4N\", \"Genre\": \"['cumbia pop']\", \"Release Date\": \"2020-11-07\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 74.0, \"Danceability\": 0.72, \"Energy\": 0.613, \"Loudness\": -6.899, \"Speechiness\": 0.0572, \"Acousticness\": 0.185, \"Liveness\": 0.155, \"Tempo\": 84.974, \"Duration (ms)\": 182199.0, \"Valence\": 0.857, \"Chord\": \"C#/Db\"}, {\"Index\": 580, \"Highest Charting Position\": 90, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Somebody\\u2019s Problem\", \"Streams\": 5332437, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"0SErdEdRcVX1uJCf1eTGYH\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2020-11-20--2020-11-27\", \"Popularity\": 70.0, \"Danceability\": 0.657, \"Energy\": 0.54, \"Loudness\": -7.675, \"Speechiness\": 0.0287, \"Acousticness\": 0.662, \"Liveness\": 0.123, \"Tempo\": 136.97, \"Duration (ms)\": 161773.0, \"Valence\": 0.625, \"Chord\": \"F\"}, {\"Index\": 581, \"Highest Charting Position\": 66, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"De Una Vez\", \"Streams\": 5186567, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"1v3lhrZEsOcazqR2QIyyRu\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 70.0, \"Danceability\": 0.659, \"Energy\": 0.479, \"Loudness\": -6.79, \"Speechiness\": 0.2, \"Acousticness\": 0.152, \"Liveness\": 0.268, \"Tempo\": 163.882, \"Duration (ms)\": 155956.0, \"Valence\": 0.0395, \"Chord\": \"B\"}, {\"Index\": 582, \"Highest Charting Position\": 121, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Way Out (feat. Big Sean)\", \"Streams\": 4962949, \"Artist\": \"Jack Harlow\", \"Artist Followers\": 1053324.0, \"Song ID\": \"6rLi6PyWXu1rPlShuIZpj6\", \"Genre\": \"['deep underground hip hop', 'kentucky hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-09\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 72.0, \"Danceability\": 0.945, \"Energy\": 0.582, \"Loudness\": -8.357, \"Speechiness\": 0.0719, \"Acousticness\": 0.114, \"Liveness\": 0.103, \"Tempo\": 108.025, \"Duration (ms)\": 168906.0, \"Valence\": 0.907, \"Chord\": \"B\"}, {\"Index\": 583, \"Highest Charting Position\": 42, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Diamonds\", \"Streams\": 4931163, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"5hvwx5i67IwnCkjl9VHkNv\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-09-17\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 77.0, \"Danceability\": 0.653, \"Energy\": 0.667, \"Loudness\": -6.764, \"Speechiness\": 0.0423, \"Acousticness\": 0.154, \"Liveness\": 0.107, \"Tempo\": 104.181, \"Duration (ms)\": 213869.0, \"Valence\": 0.556, \"Chord\": \"A#/Bb\"}, {\"Index\": 584, \"Highest Charting Position\": 190, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Dancing in My Room\", \"Streams\": 4914093, \"Artist\": \"347aidan\", \"Artist Followers\": 211500.0, \"Song ID\": \"6Pgmqg15yVexuOgtzuxwoX\", \"Genre\": \"['sad rap']\", \"Release Date\": \"2020-10-26\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\", \"Popularity\": 79.0, \"Danceability\": 0.98, \"Energy\": 0.413, \"Loudness\": -11.052, \"Speechiness\": 0.101, \"Acousticness\": 0.671, \"Liveness\": 0.17, \"Tempo\": 119.993, \"Duration (ms)\": 180139.0, \"Valence\": 0.764, \"Chord\": \"G#/Ab\"}, {\"Index\": 585, \"Highest Charting Position\": 116, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"De Cora <3\", \"Streams\": 4864544, \"Artist\": \"Rauw Alejandro, J Balvin\", \"Artist Followers\": 6096559.0, \"Song ID\": \"22Sh5dlwbERqJAq1fZk5b2\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 73.0, \"Danceability\": 0.811, \"Energy\": 0.683, \"Loudness\": -2.028, \"Speechiness\": 0.241, \"Acousticness\": 0.46, \"Liveness\": 0.128, \"Tempo\": 176.037, \"Duration (ms)\": 190101.0, \"Valence\": 0.571, \"Chord\": \"B\"}, {\"Index\": 586, \"Highest Charting Position\": 10, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"champagne problems\", \"Streams\": 4848954, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0sY6ZUTh4yoctD8VIXz339\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 75.0, \"Danceability\": 0.462, \"Energy\": 0.24, \"Loudness\": -12.077, \"Speechiness\": 0.0377, \"Acousticness\": 0.92, \"Liveness\": 0.113, \"Tempo\": 171.319, \"Duration (ms)\": 244000.0, \"Valence\": 0.32, \"Chord\": \"C\"}, {\"Index\": 587, \"Highest Charting Position\": 37, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Go Crazy\", \"Streams\": 4833081, \"Artist\": \"Chris Brown, Young Thug\", \"Artist Followers\": 14073083.0, \"Song ID\": \"1IIKrJVP1C9N7iPtG6eOsK\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'r&b', 'rap']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 80.0, \"Danceability\": 0.755, \"Energy\": 0.578, \"Loudness\": -8.932, \"Speechiness\": 0.145, \"Acousticness\": 0.316, \"Liveness\": 0.25, \"Tempo\": 94.148, \"Duration (ms)\": 176960.0, \"Valence\": 0.581, \"Chord\": \"C\"}, {\"Index\": 588, \"Highest Charting Position\": 73, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Reminds Me Of You\", \"Streams\": 5942551, \"Artist\": \"Juice WRLD, The Kid LAROI\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5YSHygGN9D0mID1NsVd5my\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-12-08\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 75.0, \"Danceability\": 0.613, \"Energy\": 0.631, \"Loudness\": -6.965, \"Speechiness\": 0.12, \"Acousticness\": 0.0663, \"Liveness\": 0.169, \"Tempo\": 149.992, \"Duration (ms)\": 158033.0, \"Valence\": 0.33, \"Chord\": \"E\"}, {\"Index\": 589, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Don't Play\", \"Streams\": 5119828, \"Artist\": \"Anne-Marie, KSI, Digital Farm Animals\", \"Artist Followers\": 8153871.0, \"Song ID\": \"4I5bvu2KDsrCg0EWHIcvul\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-01-15--2021-01-22\", \"Popularity\": 73.0, \"Danceability\": 0.695, \"Energy\": 0.784, \"Loudness\": -6.564, \"Speechiness\": 0.0402, \"Acousticness\": 0.0889, \"Liveness\": 0.0843, \"Tempo\": 128.031, \"Duration (ms)\": 188581.0, \"Valence\": 0.52, \"Chord\": \"F#/Gb\"}, {\"Index\": 590, \"Highest Charting Position\": 108, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"MODO TURBO\", \"Streams\": 4983557, \"Artist\": \"Lu\\u00edsa Sonza, Pabllo Vittar, Anitta\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5217tPOJfhVUY8q9TCKHO1\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-11\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 1.0, \"Danceability\": 0.655, \"Energy\": 0.726, \"Loudness\": -7.628, \"Speechiness\": 0.0796, \"Acousticness\": 0.334, \"Liveness\": 0.232, \"Tempo\": 160.064, \"Duration (ms)\": 150260.0, \"Valence\": 0.766, \"Chord\": \"A#/Bb\"}, {\"Index\": 591, \"Highest Charting Position\": 191, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Buss It\", \"Streams\": 4915403, \"Artist\": \"Erica Banks\", \"Artist Followers\": 41551.0, \"Song ID\": \"25j0Sape7qZbq6ZPLFefTT\", \"Genre\": \"['trap queen']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2021-01-15--2021-01-22\", \"Popularity\": 72.0, \"Danceability\": 0.956, \"Energy\": 0.502, \"Loudness\": -5.995, \"Speechiness\": 0.213, \"Acousticness\": 0.0593, \"Liveness\": 0.238, \"Tempo\": 110.003, \"Duration (ms)\": 187000.0, \"Valence\": 0.795, \"Chord\": \"A\"}, {\"Index\": 592, \"Highest Charting Position\": 41, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Kings & Queens\", \"Streams\": 4855690, \"Artist\": \"Ava Max\", \"Artist Followers\": 3916979.0, \"Song ID\": \"7a53HqqArd4b9NF4XAmlbI\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 82.0, \"Danceability\": 0.637, \"Energy\": 0.69, \"Loudness\": -4.057, \"Speechiness\": 0.0405, \"Acousticness\": 0.00786, \"Liveness\": 0.124, \"Tempo\": 129.857, \"Duration (ms)\": 162399.0, \"Valence\": 0.457, \"Chord\": \"C#/Db\"}, {\"Index\": 593, \"Highest Charting Position\": 6, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Lovesick Girls\", \"Streams\": 4796365, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"4Ws314Ylb27BVsvlZOy30C\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 75.0, \"Danceability\": 0.654, \"Energy\": 0.707, \"Loudness\": -5.661, \"Speechiness\": 0.0664, \"Acousticness\": 0.00559, \"Liveness\": 0.0873, \"Tempo\": 127.97, \"Duration (ms)\": 194765.0, \"Valence\": 0.448, \"Chord\": \"F#/Gb\"}, {\"Index\": 594, \"Highest Charting Position\": 17, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Caramelo\", \"Streams\": 4790233, \"Artist\": \"Ozuna\", \"Artist Followers\": 29238936.0, \"Song ID\": \"3gD4J3RUHy4OUuZ3qAiaiG\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-06-11\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 74.0, \"Danceability\": 0.728, \"Energy\": 0.806, \"Loudness\": -3.766, \"Speechiness\": 0.0623, \"Acousticness\": 0.0531, \"Liveness\": 0.153, \"Tempo\": 168.084, \"Duration (ms)\": 217547.0, \"Valence\": 0.698, \"Chord\": \"F#/Gb\"}, {\"Index\": 595, \"Highest Charting Position\": 67, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Deep End\", \"Streams\": 5622565, \"Artist\": \"Foushe\\u00e9\", \"Artist Followers\": 411262.0, \"Song ID\": \"2AlYncTpVHKwHb55F9lF6O\", \"Genre\": \"['brooklyn drill', 'nyc rap']\", \"Release Date\": \"2020-06-05\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 72.0, \"Danceability\": 0.868, \"Energy\": 0.479, \"Loudness\": -6.687, \"Speechiness\": 0.445, \"Acousticness\": 0.703, \"Liveness\": 0.102, \"Tempo\": 133.928, \"Duration (ms)\": 115200.0, \"Valence\": 0.776, \"Chord\": \"E\"}, {\"Index\": 596, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Sand In My Boots\", \"Streams\": 5446609, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"0uRrG2jRR5tuifsYIJHEao\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\", \"Popularity\": 75.0, \"Danceability\": 0.403, \"Energy\": 0.537, \"Loudness\": -6.628, \"Speechiness\": 0.031, \"Acousticness\": 0.59, \"Liveness\": 0.112, \"Tempo\": 69.877, \"Duration (ms)\": 202133.0, \"Valence\": 0.414, \"Chord\": \"D#/Eb\"}, {\"Index\": 597, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"865\", \"Streams\": 5160123, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"0sKEilrw1GrBlG6qsTCrP4\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\", \"Popularity\": 70.0, \"Danceability\": 0.532, \"Energy\": 0.584, \"Loudness\": -5.254, \"Speechiness\": 0.0248, \"Acousticness\": 0.723, \"Liveness\": 0.101, \"Tempo\": 88.003, \"Duration (ms)\": 190680.0, \"Valence\": 0.367, \"Chord\": \"G#/Ab\"}, {\"Index\": 598, \"Highest Charting Position\": 53, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"7 Summers\", \"Streams\": 5064504, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"4obHzpwGrjoTuZh2DItEMZ\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2020-09-11--2020-09-18\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 73.0, \"Danceability\": 0.466, \"Energy\": 0.786, \"Loudness\": -5.13, \"Speechiness\": 0.0328, \"Acousticness\": 0.417, \"Liveness\": 0.125, \"Tempo\": 203.903, \"Duration (ms)\": 210507.0, \"Valence\": 0.571, \"Chord\": \"C\"}, {\"Index\": 599, \"Highest Charting Position\": 21, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"HACIENDO QUE ME AMAS\", \"Streams\": 4935633, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"26QApq0cuO9brJigr0C0W4\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 78.0, \"Danceability\": 0.584, \"Energy\": 0.411, \"Loudness\": -7.147, \"Speechiness\": 0.0838, \"Acousticness\": 0.869, \"Liveness\": 0.0955, \"Tempo\": 169.934, \"Duration (ms)\": 217769.0, \"Valence\": 0.412, \"Chord\": \"A#/Bb\"}, {\"Index\": 600, \"Highest Charting Position\": 65, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"La Luz\", \"Streams\": 4906324, \"Artist\": \"Sech, J Balvin\", \"Artist Followers\": 8766508.0, \"Song ID\": \"5zj8WNkBrEzlI5FKeYV4ol\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-10-31\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 70.0, \"Danceability\": 0.665, \"Energy\": 0.697, \"Loudness\": -4.819, \"Speechiness\": 0.154, \"Acousticness\": 0.427, \"Liveness\": 0.599, \"Tempo\": 94.053, \"Duration (ms)\": 216747.0, \"Valence\": 0.556, \"Chord\": \"A\"}, {\"Index\": 601, \"Highest Charting Position\": 17, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"The Woo (feat. 50 Cent & Roddy Ricch)\", \"Streams\": 4892682, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"1H7KnK26kc1YyellpbINEn\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 79.0, \"Danceability\": 0.49, \"Energy\": 0.618, \"Loudness\": -5.655, \"Speechiness\": 0.104, \"Acousticness\": 0.0221, \"Liveness\": 0.259, \"Tempo\": 99.7, \"Duration (ms)\": 201600.0, \"Valence\": 0.286, \"Chord\": \"C#/Db\"}, {\"Index\": 602, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"More Than My Hometown\", \"Streams\": 4879971, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"5OELUCYgOHKFAvCERnAvfS\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\", \"Popularity\": 75.0, \"Danceability\": 0.62, \"Energy\": 0.869, \"Loudness\": -5.479, \"Speechiness\": 0.0462, \"Acousticness\": 0.615, \"Liveness\": 0.131, \"Tempo\": 126.019, \"Duration (ms)\": 216573.0, \"Valence\": 0.597, \"Chord\": \"F#/Gb\"}, {\"Index\": 603, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Warning\", \"Streams\": 4860714, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"64SCQtbRtmO28ks1QhS3w5\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\", \"Popularity\": 68.0, \"Danceability\": 0.633, \"Energy\": 0.664, \"Loudness\": -5.037, \"Speechiness\": 0.0294, \"Acousticness\": 0.46, \"Liveness\": 0.108, \"Tempo\": 115.058, \"Duration (ms)\": 156747.0, \"Valence\": 0.268, \"Chord\": \"A#/Bb\"}, {\"Index\": 604, \"Highest Charting Position\": 117, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Recairei - Ao Vivo\", \"Streams\": 4815342, \"Artist\": \"Os Bar\\u00f5es Da Pisadinha\", \"Artist Followers\": 4281787.0, \"Song ID\": \"71FrGl0XcpL3VId65tB5mg\", \"Genre\": \"['forro', 'piseiro']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-27--2020-12-04\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 69.0, \"Danceability\": 0.582, \"Energy\": 0.937, \"Loudness\": -2.118, \"Speechiness\": 0.0858, \"Acousticness\": 0.449, \"Liveness\": 0.684, \"Tempo\": 168.096, \"Duration (ms)\": 166838.0, \"Valence\": 0.939, \"Chord\": \"A#/Bb\"}, {\"Index\": 605, \"Highest Charting Position\": 5, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Ice Cream (with Selena Gomez)\", \"Streams\": 4812765, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"4JUPEh2DVSXFGExu4Uxevz\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 71.0, \"Danceability\": 0.79, \"Energy\": 0.701, \"Loudness\": -4.81, \"Speechiness\": 0.365, \"Acousticness\": 0.0317, \"Liveness\": 0.0311, \"Tempo\": 159.972, \"Duration (ms)\": 177813.0, \"Valence\": 0.91, \"Chord\": \"A\"}, {\"Index\": 606, \"Highest Charting Position\": 22, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Be Kind (with Halsey)\", \"Streams\": 4790427, \"Artist\": \"Marshmello\", \"Artist Followers\": 31552500.0, \"Song ID\": \"3Z8FwOEN59mRMxDCtb8N0A\", \"Genre\": \"['brostep', 'edm', 'pop', 'pop dance', 'progressive electro house']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 80.0, \"Danceability\": 0.63, \"Energy\": 0.633, \"Loudness\": -7.088, \"Speechiness\": 0.0457, \"Acousticness\": 0.00776, \"Liveness\": 0.0541, \"Tempo\": 93.995, \"Duration (ms)\": 172762.0, \"Valence\": 0.452, \"Chord\": \"E\"}, {\"Index\": 607, \"Highest Charting Position\": 76, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Fever\", \"Streams\": 4769618, \"Artist\": \"Dua Lipa, Ang\\u00e8le\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3wJVBz7gvGTwTWVAxFa6ny\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-10-29\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 73.0, \"Danceability\": 0.868, \"Energy\": 0.693, \"Loudness\": -7.052, \"Speechiness\": 0.181, \"Acousticness\": 0.0597, \"Liveness\": 0.106, \"Tempo\": 114.999, \"Duration (ms)\": 156911.0, \"Valence\": 0.396, \"Chord\": \"F#/Gb\"}, {\"Index\": 608, \"Highest Charting Position\": 141, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Angst\", \"Streams\": 5317174, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"5yUzqd3H7cmJ1no6B4uTzu\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2021-01-01\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.599, \"Energy\": 0.79, \"Loudness\": -4.352, \"Speechiness\": 0.386, \"Acousticness\": 0.0213, \"Liveness\": 0.0778, \"Tempo\": 100.119, \"Duration (ms)\": 201501.0, \"Valence\": 0.528, \"Chord\": \"A\"}, {\"Index\": 609, \"Highest Charting Position\": 15, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"no body, no crime (feat. HAIM)\", \"Streams\": 4986214, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3RaT22zZsxVYxxKR7TAaYF\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 68.0, \"Danceability\": 0.546, \"Energy\": 0.613, \"Loudness\": -7.589, \"Speechiness\": 0.0264, \"Acousticness\": 0.418, \"Liveness\": 0.103, \"Tempo\": 79.015, \"Duration (ms)\": 215627.0, \"Valence\": 0.535, \"Chord\": \"G\"}, {\"Index\": 610, \"Highest Charting Position\": 13, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Sunday Best\", \"Streams\": 4858392, \"Artist\": \"Surfaces\", \"Artist Followers\": 724903.0, \"Song ID\": \"1Cv1YLb4q0RzL6pybtaMLo\", \"Genre\": \"['bedroom soul', 'pop']\", \"Release Date\": \"2019-01-06\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 80.0, \"Danceability\": 0.878, \"Energy\": 0.525, \"Loudness\": -6.832, \"Speechiness\": 0.0578, \"Acousticness\": 0.183, \"Liveness\": 0.0714, \"Tempo\": 112.022, \"Duration (ms)\": 158571.0, \"Valence\": 0.694, \"Chord\": \"F\"}, {\"Index\": 611, \"Highest Charting Position\": 171, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Amor ou o Litr\\u00e3o\", \"Streams\": 4848222, \"Artist\": \"Petter Ferraz, Menor Nico\", \"Artist Followers\": 14122.0, \"Song ID\": \"7qmnP8Woc47dLSrMD5MxL1\", \"Genre\": \"[]\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 66.0, \"Danceability\": 0.934, \"Energy\": 0.707, \"Loudness\": -4.214, \"Speechiness\": 0.0646, \"Acousticness\": 0.437, \"Liveness\": 0.0628, \"Tempo\": 138.023, \"Duration (ms)\": 173913.0, \"Valence\": 0.961, \"Chord\": \"A\"}, {\"Index\": 612, \"Highest Charting Position\": 66, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Happier\", \"Streams\": 4655272, \"Artist\": \"Marshmello, Bastille\", \"Artist Followers\": 31552500.0, \"Song ID\": \"2dpaYNEQHiRxtZbfNsse99\", \"Genre\": \"['brostep', 'edm', 'pop', 'pop dance', 'progressive electro house']\", \"Release Date\": \"2018-08-17\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-11-13--2020-11-20\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.687, \"Energy\": 0.792, \"Loudness\": -2.749, \"Speechiness\": 0.0452, \"Acousticness\": 0.191, \"Liveness\": 0.167, \"Tempo\": 100.015, \"Duration (ms)\": 214290.0, \"Valence\": 0.671, \"Chord\": \"F\"}, {\"Index\": 613, \"Highest Charting Position\": 138, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Don't Stop Me Now - Remastered 2011\", \"Streams\": 4630572, \"Artist\": \"Queen\", \"Artist Followers\": 35910149.0, \"Song ID\": \"7hQJA50XrCWABAu5v6QZ4i\", \"Genre\": \"['classic rock', 'glam rock', 'rock']\", \"Release Date\": \"1978-11-10\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-15--2020-05-22\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.563, \"Energy\": 0.865, \"Loudness\": -5.277, \"Speechiness\": 0.16, \"Acousticness\": 0.0472, \"Liveness\": 0.77, \"Tempo\": 156.271, \"Duration (ms)\": 209413.0, \"Valence\": 0.601, \"Chord\": \"F\"}, {\"Index\": 614, \"Highest Charting Position\": 61, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Azul\", \"Streams\": 4606011, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"2lCkncy6bIB0LTMT7kvrD1\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 77.0, \"Danceability\": 0.843, \"Energy\": 0.836, \"Loudness\": -2.474, \"Speechiness\": 0.0695, \"Acousticness\": 0.0816, \"Liveness\": 0.0532, \"Tempo\": 94.018, \"Duration (ms)\": 205933.0, \"Valence\": 0.65, \"Chord\": \"B\"}, {\"Index\": 615, \"Highest Charting Position\": 183, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Basta Voc\\u00ea Me Ligar - Ao Vivo\", \"Streams\": 4580123, \"Artist\": \"Os Bar\\u00f5es Da Pisadinha, Xand Avi\\u00e3o\", \"Artist Followers\": 4281787.0, \"Song ID\": \"3AV1KI22k1jGMz792lDrj1\", \"Genre\": \"['forro', 'piseiro']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 68.0, \"Danceability\": 0.599, \"Energy\": 0.914, \"Loudness\": -2.415, \"Speechiness\": 0.0629, \"Acousticness\": 0.5, \"Liveness\": 0.694, \"Tempo\": 168.008, \"Duration (ms)\": 182977.0, \"Valence\": 0.831, \"Chord\": \"F\"}, {\"Index\": 616, \"Highest Charting Position\": 49, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Tequila Shots\", \"Streams\": 4540781, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"30KctD1WsHKTIYczXjip5a\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 74.0, \"Danceability\": 0.712, \"Energy\": 0.556, \"Loudness\": -7.214, \"Speechiness\": 0.0531, \"Acousticness\": 0.084, \"Liveness\": 0.527, \"Tempo\": 90.494, \"Duration (ms)\": 193293.0, \"Valence\": 0.22, \"Chord\": \"F\"}, {\"Index\": 617, \"Highest Charting Position\": 27, \"Number of Times Charted\": 45, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Lose Control\", \"Streams\": 4516053, \"Artist\": \"MEDUZA, Becky Hill, Goodboys\", \"Artist Followers\": 441714.0, \"Song ID\": \"7CHi4DtfK4heMlQaudCuHK\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop house', 'tropical house']\", \"Release Date\": \"2019-10-11\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.598, \"Energy\": 0.526, \"Loudness\": -8.659, \"Speechiness\": 0.0415, \"Acousticness\": 0.129, \"Liveness\": 0.14, \"Tempo\": 123.935, \"Duration (ms)\": 168387.0, \"Valence\": 0.529, \"Chord\": \"A#/Bb\"}, {\"Index\": 618, \"Highest Charting Position\": 68, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"I CAN'T STOP ME\", \"Streams\": 4504304, \"Artist\": \"TWICE\", \"Artist Followers\": 9998991.0, \"Song ID\": \"37ZtpRBkHcaq6hHy0X98zn\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-26\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 76.0, \"Danceability\": 0.657, \"Energy\": 0.88, \"Loudness\": -3.672, \"Speechiness\": 0.102, \"Acousticness\": 0.121, \"Liveness\": 0.463, \"Tempo\": 150.084, \"Duration (ms)\": 205493.0, \"Valence\": 0.769, \"Chord\": \"A#/Bb\"}, {\"Index\": 619, \"Highest Charting Position\": 158, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"E-GIRLS ARE RUINING MY LIFE!\", \"Streams\": 4488125, \"Artist\": \"CORPSE, Savage Ga$p\", \"Artist Followers\": 1777797.0, \"Song ID\": \"7bCfHiRcfUjG0YVVNUL7Ve\", \"Genre\": \"['dream smp', 'viral rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 77.0, \"Danceability\": 0.614, \"Energy\": 0.937, \"Loudness\": -7.443, \"Speechiness\": 0.115, \"Acousticness\": 0.00161, \"Liveness\": 0.103, \"Tempo\": 84.98, \"Duration (ms)\": 105176.0, \"Valence\": 0.386, \"Chord\": \"C#/Db\"}, {\"Index\": 620, \"Highest Charting Position\": 1, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"All I Want for Christmas Is You\", \"Streams\": 23235257, \"Artist\": \"Mariah Carey\", \"Artist Followers\": 6931357.0, \"Song ID\": \"0bYg9bo50gSsH3LtXe2SQn\", \"Genre\": \"['dance pop', 'pop', 'r&b', 'urban contemporary']\", \"Release Date\": \"1994-11-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2019-12-27--2020-01-03\", \"Popularity\": 65.0, \"Danceability\": 0.336, \"Energy\": 0.627, \"Loudness\": -7.463, \"Speechiness\": 0.0384, \"Acousticness\": 0.164, \"Liveness\": 0.0708, \"Tempo\": 150.273, \"Duration (ms)\": 241107.0, \"Valence\": 0.35, \"Chord\": \"G\"}, {\"Index\": 621, \"Highest Charting Position\": 2, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Last Christmas\", \"Streams\": 20709328, \"Artist\": \"Wham!\", \"Artist Followers\": 1631876.0, \"Song ID\": \"2FRnf9qhLbvw8fu4IBXx78\", \"Genre\": \"['disco', 'europop', 'new romantic', 'new wave', 'new wave pop', 'soft rock', 'synthpop']\", \"Release Date\": \"1984-11-29\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 63.0, \"Danceability\": 0.735, \"Energy\": 0.478, \"Loudness\": -12.472, \"Speechiness\": 0.0293, \"Acousticness\": 0.189, \"Liveness\": 0.355, \"Tempo\": 107.682, \"Duration (ms)\": 262960.0, \"Valence\": 0.947, \"Chord\": \"D\"}, {\"Index\": 622, \"Highest Charting Position\": 3, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Tell Me\", \"Streams\": 16657592, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"0lizgQ7Qw35od7CYaoMBZb\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2014-11-24\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 61.0, \"Danceability\": 0.525, \"Energy\": 0.621, \"Loudness\": -7.364, \"Speechiness\": 0.116, \"Acousticness\": 0.0489, \"Liveness\": 0.294, \"Tempo\": 191.9, \"Duration (ms)\": 204093.0, \"Valence\": 0.591, \"Chord\": \"G\"}, {\"Index\": 623, \"Highest Charting Position\": 5, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Rockin' Around The Christmas Tree\", \"Streams\": 16613649, \"Artist\": \"Brenda Lee\", \"Artist Followers\": 222627.0, \"Song ID\": \"2EjXfH91m7f8HiJN1yQg97\", \"Genre\": \"['adult standards', 'brill building pop', 'easy listening', 'lounge', 'rockabilly', 'vocal jazz']\", \"Release Date\": \"1964-10-19\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 58.0, \"Danceability\": 0.589, \"Energy\": 0.472, \"Loudness\": -8.749, \"Speechiness\": 0.0502, \"Acousticness\": 0.614, \"Liveness\": 0.505, \"Tempo\": 67.196, \"Duration (ms)\": 126267.0, \"Valence\": 0.898, \"Chord\": \"G#/Ab\"}, {\"Index\": 624, \"Highest Charting Position\": 7, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Jingle Bell Rock\", \"Streams\": 16527404, \"Artist\": \"Bobby Helms\", \"Artist Followers\": 20637.0, \"Song ID\": \"7vQbuQcyTflfCIOu3Uzzya\", \"Genre\": \"[]\", \"Release Date\": \"1957-12-02\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 56.0, \"Danceability\": 0.754, \"Energy\": 0.424, \"Loudness\": -8.463, \"Speechiness\": 0.0363, \"Acousticness\": 0.643, \"Liveness\": 0.0652, \"Tempo\": 119.705, \"Duration (ms)\": 130973.0, \"Valence\": 0.806, \"Chord\": \"D\"}, {\"Index\": 625, \"Highest Charting Position\": 6, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"It's Beginning to Look a Lot like Christmas\", \"Streams\": 15424001, \"Artist\": \"Michael Bubl\\u00e9\", \"Artist Followers\": 4702232.0, \"Song ID\": \"5a1iz510sv2W9Dt1MvFd5R\", \"Genre\": \"['adult standards', 'canadian pop', 'jazz pop', 'lounge']\", \"Release Date\": \"2012-11-09\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 55.0, \"Danceability\": 0.339, \"Energy\": 0.214, \"Loudness\": -11.714, \"Speechiness\": 0.0375, \"Acousticness\": 0.908, \"Liveness\": 0.341, \"Tempo\": 94.775, \"Duration (ms)\": 206640.0, \"Valence\": 0.363, \"Chord\": \"E\"}, {\"Index\": 626, \"Highest Charting Position\": 8, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"It's the Most Wonderful Time of the Year\", \"Streams\": 14582001, \"Artist\": \"Andy Williams\", \"Artist Followers\": 369548.0, \"Song ID\": \"5hslUAKq9I9CG2bAulFkHN\", \"Genre\": \"['adult standards', 'brill building pop', 'easy listening', 'lounge', 'mellow gold', 'vocal jazz']\", \"Release Date\": \"1963-11-24\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 55.0, \"Danceability\": 0.24, \"Energy\": 0.598, \"Loudness\": -8.435, \"Speechiness\": 0.0369, \"Acousticness\": 0.766, \"Liveness\": 0.117, \"Tempo\": 201.629, \"Duration (ms)\": 151933.0, \"Valence\": 0.776, \"Chord\": \"G\"}, {\"Index\": 627, \"Highest Charting Position\": 9, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Underneath the Tree\", \"Streams\": 12266990, \"Artist\": \"Kelly Clarkson\", \"Artist Followers\": 7869617.0, \"Song ID\": \"3YZE5qDV7u1ZD1gZc47ZeR\", \"Genre\": \"['dance pop', 'neo mellow', 'pop', 'pop rock', 'post-teen pop', 'talent show']\", \"Release Date\": \"2013-10-29\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 49.0, \"Danceability\": 0.509, \"Energy\": 0.812, \"Loudness\": -5.439, \"Speechiness\": 0.0537, \"Acousticness\": 0.00128, \"Liveness\": 0.214, \"Tempo\": 159.878, \"Duration (ms)\": 229640.0, \"Valence\": 0.689, \"Chord\": \"G#/Ab\"}, {\"Index\": 628, \"Highest Charting Position\": 14, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Feliz Navidad\", \"Streams\": 11664490, \"Artist\": \"Jos\\u00e9 Feliciano\", \"Artist Followers\": 239129.0, \"Song ID\": \"0oPdaY4dXtc3ZsaG17V972\", \"Genre\": \"['latin pop', 'puerto rican pop']\", \"Release Date\": \"2002-09-24\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 49.0, \"Danceability\": 0.513, \"Energy\": 0.831, \"Loudness\": -9.004, \"Speechiness\": 0.0383, \"Acousticness\": 0.55, \"Liveness\": 0.336, \"Tempo\": 148.837, \"Duration (ms)\": 182067.0, \"Valence\": 0.963, \"Chord\": \"D\"}, {\"Index\": 629, \"Highest Charting Position\": 11, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Let It Snow! Let It Snow! Let It Snow!\", \"Streams\": 10884855, \"Artist\": \"Dean Martin\", \"Artist Followers\": 1139096.0, \"Song ID\": \"2uFaJJtFpPDc5Pa95XzTvg\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"1959-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 54.0, \"Danceability\": 0.451, \"Energy\": 0.24, \"Loudness\": -14.014, \"Speechiness\": 0.0351, \"Acousticness\": 0.912, \"Liveness\": 0.175, \"Tempo\": 134.009, \"Duration (ms)\": 117147.0, \"Valence\": 0.701, \"Chord\": \"C#/Db\"}, {\"Index\": 630, \"Highest Charting Position\": 19, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Let It Snow! Let It Snow! Let It Snow! (with The B. Swanson Quartet)\", \"Streams\": 10787165, \"Artist\": \"Frank Sinatra\", \"Artist Followers\": 4953667.0, \"Song ID\": \"4kKdvXD0ez7jp1296JmAts\", \"Genre\": \"['adult standards', 'easy listening', 'lounge']\", \"Release Date\": \"1994-11-08\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 53.0, \"Danceability\": 0.652, \"Energy\": 0.259, \"Loudness\": -13.336, \"Speechiness\": 0.0595, \"Acousticness\": 0.903, \"Liveness\": 0.362, \"Tempo\": 142.169, \"Duration (ms)\": 155453.0, \"Valence\": 0.836, \"Chord\": \"D\"}, {\"Index\": 631, \"Highest Charting Position\": 15, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Mistletoe\", \"Streams\": 10609206, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"7xapw9Oy21WpfEcib2ErSA\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2011-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 59.0, \"Danceability\": 0.657, \"Energy\": 0.56, \"Loudness\": -9.049, \"Speechiness\": 0.0467, \"Acousticness\": 0.498, \"Liveness\": 0.0794, \"Tempo\": 161.993, \"Duration (ms)\": 182947.0, \"Valence\": 0.854, \"Chord\": \"F#/Gb\"}, {\"Index\": 632, \"Highest Charting Position\": 16, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Sleigh Ride\", \"Streams\": 10508459, \"Artist\": \"The Ronettes\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5ASM6Qjiav2xPe7gRkQMsQ\", \"Genre\": \"[]\", \"Release Date\": \"1963\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 50.0, \"Danceability\": 0.529, \"Energy\": 0.772, \"Loudness\": -7.013, \"Speechiness\": 0.0287, \"Acousticness\": 0.403, \"Liveness\": 0.316, \"Tempo\": 91.751, \"Duration (ms)\": 181267.0, \"Valence\": 0.853, \"Chord\": \"D\"}, {\"Index\": 633, \"Highest Charting Position\": 17, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Do They Know It's Christmas? - 1984 Version\", \"Streams\": 10476212, \"Artist\": \"Band Aid\", \"Artist Followers\": 4883.0, \"Song ID\": \"0247StOpd3AkeBQzANX4Zf\", \"Genre\": \"['musical advocacy']\", \"Release Date\": \"2004-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 51.0, \"Danceability\": 0.599, \"Energy\": 0.642, \"Loudness\": -6.936, \"Speechiness\": 0.0363, \"Acousticness\": 0.164, \"Liveness\": 0.0992, \"Tempo\": 115.412, \"Duration (ms)\": 222533.0, \"Valence\": 0.349, \"Chord\": \"C\"}, {\"Index\": 634, \"Highest Charting Position\": 23, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Wonderful Christmastime - Edited Version / Remastered 2011\", \"Streams\": 9882989, \"Artist\": \"Paul McCartney\", \"Artist Followers\": 3609658.0, \"Song ID\": \"1SV1fxF65n9NhRHp3KlBuu\", \"Genre\": \"['album rock', 'art rock', 'beatlesque', 'classic rock', 'mellow gold', 'rock', 'soft rock']\", \"Release Date\": \"1980-05-16\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 51.0, \"Danceability\": 0.774, \"Energy\": 0.511, \"Loudness\": -8.914, \"Speechiness\": 0.0319, \"Acousticness\": 0.322, \"Liveness\": 0.0672, \"Tempo\": 94.736, \"Duration (ms)\": 227653.0, \"Valence\": 0.771, \"Chord\": \"B\"}, {\"Index\": 635, \"Highest Charting Position\": 21, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Holly Jolly Christmas\", \"Streams\": 9852792, \"Artist\": \"Michael Bubl\\u00e9\", \"Artist Followers\": 4702232.0, \"Song ID\": \"5PuKlCjfEVIXl0ZBp5ZW9g\", \"Genre\": \"['adult standards', 'canadian pop', 'jazz pop', 'lounge']\", \"Release Date\": \"2012-11-09\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 48.0, \"Danceability\": 0.647, \"Energy\": 0.465, \"Loudness\": -8.308, \"Speechiness\": 0.0428, \"Acousticness\": 0.865, \"Liveness\": 0.0882, \"Tempo\": 151.251, \"Duration (ms)\": 119787.0, \"Valence\": 0.699, \"Chord\": \"G\"}, {\"Index\": 636, \"Highest Charting Position\": 24, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Happy Xmas (War Is Over) - Remastered 2010\", \"Streams\": 9509781, \"Artist\": \"John Lennon, Yoko Ono\", \"Artist Followers\": 4313100.0, \"Song ID\": \"27RYrbL6S02LNVhDWVl38b\", \"Genre\": \"['album rock', 'art rock', 'beatlesque', 'classic rock', 'folk rock', 'mellow gold', 'rock']\", \"Release Date\": \"2010-10-05\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 53.0, \"Danceability\": 0.321, \"Energy\": 0.64, \"Loudness\": -10.023, \"Speechiness\": 0.0324, \"Acousticness\": 0.28, \"Liveness\": 0.718, \"Tempo\": 146.172, \"Duration (ms)\": 214333.0, \"Valence\": 0.414, \"Chord\": \"D\"}, {\"Index\": 637, \"Highest Charting Position\": 22, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Driving Home for Christmas - 2019 Remaster\", \"Streams\": 8804531, \"Artist\": \"Chris Rea\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 638, \"Highest Charting Position\": 32, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"The Christmas Song (Merry Christmas To You)\", \"Streams\": 8478518, \"Artist\": \"Nat King Cole\", \"Artist Followers\": 1634288.0, \"Song ID\": \"4PS1e8f2LvuTFgUs1Cn3ON\", \"Genre\": \"['adult standards', 'lounge', 'soul', 'vocal jazz']\", \"Release Date\": \"1962\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 53.0, \"Danceability\": 0.319, \"Energy\": 0.21, \"Loudness\": -15.231, \"Speechiness\": 0.0341, \"Acousticness\": 0.92, \"Liveness\": 0.138, \"Tempo\": 78.696, \"Duration (ms)\": 192160.0, \"Valence\": 0.209, \"Chord\": \"C#/Db\"}, {\"Index\": 639, \"Highest Charting Position\": 39, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"White Christmas\", \"Streams\": 7045348, \"Artist\": \"Bing Crosby, Ken Darby Singers, John Scott Trotter & His Orchestra\", \"Artist Followers\": 359973.0, \"Song ID\": \"4so0Wek9Ig1p6CRCHuINwW\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'swing', 'vocal jazz']\", \"Release Date\": \"1942-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 51.0, \"Danceability\": 0.317, \"Energy\": 0.158, \"Loudness\": -16.485, \"Speechiness\": 0.0381, \"Acousticness\": 0.673, \"Liveness\": 0.338, \"Tempo\": 130.503, \"Duration (ms)\": 177480.0, \"Valence\": 0.247, \"Chord\": \"A\"}, {\"Index\": 640, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Slay3r\", \"Streams\": 6912271, \"Artist\": \"Playboi Carti\", \"Artist Followers\": 4958353.0, \"Song ID\": \"1eMNW1HQjF1dbb4GtnmpaX\", \"Genre\": \"['atl hip hop', 'plugg', 'rap', 'trap']\", \"Release Date\": \"2020-12-25\", \"Weeks Charted\": \"2020-12-25--2021-01-01\", \"Popularity\": 63.0, \"Danceability\": 0.885, \"Energy\": 0.661, \"Loudness\": -5.062, \"Speechiness\": 0.141, \"Acousticness\": 0.165, \"Liveness\": 0.334, \"Tempo\": 140.028, \"Duration (ms)\": 164591.0, \"Valence\": 0.436, \"Chord\": \"E\"}, {\"Index\": 641, \"Highest Charting Position\": 42, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"A Holly Jolly Christmas - Single Version\", \"Streams\": 6716353, \"Artist\": \"Burl Ives\", \"Artist Followers\": 58479.0, \"Song ID\": \"77khP2fIVhSW23NwxrRluh\", \"Genre\": \"['adult standards', 'american folk revival']\", \"Release Date\": \"1965-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 49.0, \"Danceability\": 0.683, \"Energy\": 0.375, \"Loudness\": -13.056, \"Speechiness\": 0.0303, \"Acousticness\": 0.579, \"Liveness\": 0.076, \"Tempo\": 140.467, \"Duration (ms)\": 135533.0, \"Valence\": 0.888, \"Chord\": \"C\"}, {\"Index\": 642, \"Highest Charting Position\": 47, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Fairytale of New York (feat. Kirsty MacColl)\", \"Streams\": 6404964, \"Artist\": \"The Pogues\", \"Artist Followers\": 382997.0, \"Song ID\": \"3VTNVsTTu05dmTsVFrmGpK\", \"Genre\": \"['celtic', 'celtic punk', 'celtic rock', 'folk punk', 'irish folk', 'punk']\", \"Release Date\": \"1988-09-05\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 55.0, \"Danceability\": 0.271, \"Energy\": 0.551, \"Loudness\": -7.48, \"Speechiness\": 0.0457, \"Acousticness\": 0.582, \"Liveness\": 0.256, \"Tempo\": 78.111, \"Duration (ms)\": 272467.0, \"Valence\": 0.428, \"Chord\": \"D\"}, {\"Index\": 643, \"Highest Charting Position\": 38, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Merry Christmas Everyone\", \"Streams\": 6052105, \"Artist\": \"Shakin' Stevens\", \"Artist Followers\": 99249.0, \"Song ID\": \"2TE4xW3ImvpltVU0cPcKUn\", \"Genre\": \"['classic uk pop', 'new wave pop', 'rock-and-roll', 'rockabilly', 'soft rock']\", \"Release Date\": \"1991-11-25\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 47.0, \"Danceability\": 0.534, \"Energy\": 0.904, \"Loudness\": -3.315, \"Speechiness\": 0.0369, \"Acousticness\": 0.129, \"Liveness\": 0.128, \"Tempo\": 202.899, \"Duration (ms)\": 220160.0, \"Valence\": 0.96, \"Chord\": \"A\"}, {\"Index\": 644, \"Highest Charting Position\": 62, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Blue Christmas\", \"Streams\": 6007011, \"Artist\": \"Elvis Presley\", \"Artist Followers\": 5698788.0, \"Song ID\": \"3QiAAp20rPC3dcAtKtMaqQ\", \"Genre\": \"['rock-and-roll', 'rockabilly']\", \"Release Date\": \"1957-10-15\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 49.0, \"Danceability\": 0.465, \"Energy\": 0.27, \"Loudness\": -16.661, \"Speechiness\": 0.0425, \"Acousticness\": 0.9, \"Liveness\": 0.145, \"Tempo\": 94.518, \"Duration (ms)\": 129173.0, \"Valence\": 0.58, \"Chord\": \"E\"}, {\"Index\": 645, \"Highest Charting Position\": 65, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Run Rudolph Run - Single Version\", \"Streams\": 5802508, \"Artist\": \"Chuck Berry\", \"Artist Followers\": 1251372.0, \"Song ID\": \"47CIT5hMphuMQkpeyfGQTL\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 0.0, \"Danceability\": 0.647, \"Energy\": 0.876, \"Loudness\": -5.662, \"Speechiness\": 0.185, \"Acousticness\": 0.881, \"Liveness\": 0.26, \"Tempo\": 151.925, \"Duration (ms)\": 162897.0, \"Valence\": 0.949, \"Chord\": \"A#/Bb\"}, {\"Index\": 646, \"Highest Charting Position\": 59, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Claus Is Coming To Town\", \"Streams\": 5801639, \"Artist\": \"The Jackson 5\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5Gz7EYD7JAmItA7FbhKgKb\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 0.0, \"Danceability\": 0.691, \"Energy\": 0.776, \"Loudness\": -4.177, \"Speechiness\": 0.0341, \"Acousticness\": 0.458, \"Liveness\": 0.33, \"Tempo\": 146.861, \"Duration (ms)\": 144080.0, \"Valence\": 0.961, \"Chord\": \"C\"}, {\"Index\": 647, \"Highest Charting Position\": 52, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Baby\", \"Streams\": 5687085, \"Artist\": \"Kylie Minogue\", \"Artist Followers\": 1324920.0, \"Song ID\": \"0cM5URUqqQTpJWonmdzF1J\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'electropop', 'eurodance', 'europop', 'new wave pop', 'pop']\", \"Release Date\": \"2010-11-30\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 42.0, \"Danceability\": 0.685, \"Energy\": 0.391, \"Loudness\": -7.183, \"Speechiness\": 0.0435, \"Acousticness\": 0.744, \"Liveness\": 0.142, \"Tempo\": 87.101, \"Duration (ms)\": 202547.0, \"Valence\": 0.443, \"Chord\": \"C#/Db\"}, {\"Index\": 648, \"Highest Charting Position\": 60, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"It's Beginning to Look a Lot Like Christmas (with Mitchell Ayres & His Orchestra)\", \"Streams\": 5422082, \"Artist\": \"Perry Como, The Fontane Sisters\", \"Artist Followers\": 336373.0, \"Song ID\": \"2pXpURmn6zC5ZYDMms6fwa\", \"Genre\": \"['adult standards', 'brill building pop', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"1999-08-20\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 49.0, \"Danceability\": 0.724, \"Energy\": 0.276, \"Loudness\": -12.25, \"Speechiness\": 0.0599, \"Acousticness\": 0.76, \"Liveness\": 0.116, \"Tempo\": 112.874, \"Duration (ms)\": 155933.0, \"Valence\": 0.718, \"Chord\": \"G\"}, {\"Index\": 649, \"Highest Charting Position\": 69, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas (Baby Please Come Home)\", \"Streams\": 5394054, \"Artist\": \"Darlene Love\", \"Artist Followers\": 1251372.0, \"Song ID\": \"46pF1zFimM582ss1PrMy68\", \"Genre\": \"[]\", \"Release Date\": \"1963\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-12-04--2020-12-11\", \"Popularity\": 45.0, \"Danceability\": 0.325, \"Energy\": 0.759, \"Loudness\": -7.146, \"Speechiness\": 0.053, \"Acousticness\": 0.395, \"Liveness\": 0.0773, \"Tempo\": 126.627, \"Duration (ms)\": 166453.0, \"Valence\": 0.36, \"Chord\": \"G#/Ab\"}, {\"Index\": 650, \"Highest Charting Position\": 66, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Step Into Christmas\", \"Streams\": 5353591, \"Artist\": \"Elton John\", \"Artist Followers\": 7504724.0, \"Song ID\": \"6sBWmE23q6xQHlnEZ8jYPT\", \"Genre\": \"['glam rock', 'mellow gold', 'piano rock']\", \"Release Date\": \"1973-10-05\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 43.0, \"Danceability\": 0.526, \"Energy\": 0.925, \"Loudness\": -5.584, \"Speechiness\": 0.0363, \"Acousticness\": 0.102, \"Liveness\": 0.305, \"Tempo\": 140.308, \"Duration (ms)\": 272394.0, \"Valence\": 0.819, \"Chord\": \"D\"}, {\"Index\": 651, \"Highest Charting Position\": 54, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Show Out (with Skepta & Pop Smoke)\", \"Streams\": 5209372, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"5CFJRZRq6sdKKtRwNPWbYv\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 76.0, \"Danceability\": 0.619, \"Energy\": 0.589, \"Loudness\": -6.531, \"Speechiness\": 0.124, \"Acousticness\": 0.43, \"Liveness\": 0.378, \"Tempo\": 143.896, \"Duration (ms)\": 174960.0, \"Valence\": 0.158, \"Chord\": \"C#/Db\"}, {\"Index\": 652, \"Highest Charting Position\": 166, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Investe Em Mim\", \"Streams\": 5191001, \"Artist\": \"Jonas Esticado\", \"Artist Followers\": 1293055.0, \"Song ID\": \"15k1TDabqSEmyXOwMq9RM7\", \"Genre\": \"['forro', 'sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 72.0, \"Danceability\": 0.632, \"Energy\": 0.953, \"Loudness\": -1.283, \"Speechiness\": 0.0325, \"Acousticness\": 0.317, \"Liveness\": 0.125, \"Tempo\": 160.061, \"Duration (ms)\": 186533.0, \"Valence\": 0.798, \"Chord\": \"A\"}, {\"Index\": 653, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Lance Individual\", \"Streams\": 5152906, \"Artist\": \"Jorge & Mateus\", \"Artist Followers\": 15019109.0, \"Song ID\": \"7GLWWrk1YlkPYqJK3ynIA0\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-12-25--2021-01-01\", \"Popularity\": 72.0, \"Danceability\": 0.752, \"Energy\": 0.62, \"Loudness\": -5.536, \"Speechiness\": 0.0509, \"Acousticness\": 0.309, \"Liveness\": 0.075, \"Tempo\": 117.399, \"Duration (ms)\": 164459.0, \"Valence\": 0.962, \"Chord\": \"F\"}, {\"Index\": 654, \"Highest Charting Position\": 71, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Jingle Bell Rock - Daryl's Version\", \"Streams\": 10522305, \"Artist\": \"Daryl Hall & John Oates\", \"Artist Followers\": 1549216.0, \"Song ID\": \"6pVW5LRWgeLaHudxauOTJU\", \"Genre\": \"['album rock', 'classic rock', 'mellow gold', 'rock', 'soft rock', 'yacht rock']\", \"Release Date\": \"1983-11-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 43.0, \"Danceability\": 0.666, \"Energy\": 0.841, \"Loudness\": -3.592, \"Speechiness\": 0.0312, \"Acousticness\": 0.613, \"Liveness\": 0.113, \"Tempo\": 128.706, \"Duration (ms)\": 126360.0, \"Valence\": 0.84, \"Chord\": \"D\"}, {\"Index\": 655, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Thank God It's Christmas - Non-Album Single\", \"Streams\": 10509961, \"Artist\": \"Queen\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 656, \"Highest Charting Position\": 74, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas Lights\", \"Streams\": 10455065, \"Artist\": \"Coldplay\", \"Artist Followers\": 31161671.0, \"Song ID\": \"4QVdnpSO5JGMFOEl6ys4RQ\", \"Genre\": \"['permanent wave', 'pop']\", \"Release Date\": \"2016-12-16\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 53.0, \"Danceability\": 0.295, \"Energy\": 0.496, \"Loudness\": -9.478, \"Speechiness\": 0.0327, \"Acousticness\": 0.207, \"Liveness\": 0.858, \"Tempo\": 132.062, \"Duration (ms)\": 268521.0, \"Valence\": 0.224, \"Chord\": \"G\"}, {\"Index\": 657, \"Highest Charting Position\": 83, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Have Yourself A Merry Little Christmas\", \"Streams\": 9548924, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"1Qi2wh8fFgDV7tl4Sj3f2K\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2014-12-05\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 46.0, \"Danceability\": 0.438, \"Energy\": 0.178, \"Loudness\": -9.402, \"Speechiness\": 0.0414, \"Acousticness\": 0.957, \"Liveness\": 0.316, \"Tempo\": 75.248, \"Duration (ms)\": 170964.0, \"Valence\": 0.344, \"Chord\": \"F\"}, {\"Index\": 658, \"Highest Charting Position\": 85, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa's Coming for Us\", \"Streams\": 9474711, \"Artist\": \"Sia\", \"Artist Followers\": 20528724.0, \"Song ID\": \"1N1ZpYUJc9fwrqk53FGgWv\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'pop']\", \"Release Date\": \"2018-11-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 49.0, \"Danceability\": 0.547, \"Energy\": 0.814, \"Loudness\": -6.191, \"Speechiness\": 0.12, \"Acousticness\": 0.0215, \"Liveness\": 0.0475, \"Tempo\": 92.986, \"Duration (ms)\": 205267.0, \"Valence\": 0.724, \"Chord\": \"C#/Db\"}, {\"Index\": 659, \"Highest Charting Position\": 86, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"My Only Wish (This Year)\", \"Streams\": 9457199, \"Artist\": \"Britney Spears\", \"Artist Followers\": 9470311.0, \"Song ID\": \"0YWUHZPJVg4iujddsJDwhM\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2000-11-14\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-04--2020-12-11\", \"Popularity\": 43.0, \"Danceability\": 0.669, \"Energy\": 0.843, \"Loudness\": -3.766, \"Speechiness\": 0.0268, \"Acousticness\": 0.169, \"Liveness\": 0.195, \"Tempo\": 147.08, \"Duration (ms)\": 255400.0, \"Valence\": 0.702, \"Chord\": \"C\"}, {\"Index\": 660, \"Highest Charting Position\": 89, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Baby, It's Cold Outside (feat. Meghan Trainor)\", \"Streams\": 9270017, \"Artist\": \"Brett Eldredge\", \"Artist Followers\": 1298537.0, \"Song ID\": \"5Q2P43CJra0uRAogjHyJDK\", \"Genre\": \"['contemporary country', 'country', 'country road', 'modern country rock']\", \"Release Date\": \"2016-10-28\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 44.0, \"Danceability\": 0.583, \"Energy\": 0.572, \"Loudness\": -4.776, \"Speechiness\": 0.0366, \"Acousticness\": 0.738, \"Liveness\": 0.266, \"Tempo\": 113.998, \"Duration (ms)\": 173560.0, \"Valence\": 0.684, \"Chord\": \"C#/Db\"}, {\"Index\": 661, \"Highest Charting Position\": 92, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Like It's Christmas\", \"Streams\": 9167304, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"1OjmlSFuzYflWjSMTCyTJv\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-04--2020-12-11\", \"Popularity\": 47.0, \"Danceability\": 0.725, \"Energy\": 0.571, \"Loudness\": -6.007, \"Speechiness\": 0.102, \"Acousticness\": 0.0183, \"Liveness\": 0.0519, \"Tempo\": 146.035, \"Duration (ms)\": 200880.0, \"Valence\": 0.61, \"Chord\": \"C#/Db\"}, {\"Index\": 662, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas Without You\", \"Streams\": 8813922, \"Artist\": \"Ava Max\", \"Artist Followers\": 3916979.0, \"Song ID\": \"1QLZKzC2pjP4ySf4ALrNhm\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-10-15\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 45.0, \"Danceability\": 0.654, \"Energy\": 0.596, \"Loudness\": -4.68, \"Speechiness\": 0.0458, \"Acousticness\": 0.424, \"Liveness\": 0.11, \"Tempo\": 118.078, \"Duration (ms)\": 169245.0, \"Valence\": 0.382, \"Chord\": \"C#/Db\"}, {\"Index\": 663, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"You Make It Feel Like Christmas (feat. Blake Shelton)\", \"Streams\": 8696354, \"Artist\": \"Gwen Stefani\", \"Artist Followers\": 4805333.0, \"Song ID\": \"2OQ6a4CfUeYskpTTgyawyJ\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'post-teen pop', 'urban contemporary']\", \"Release Date\": \"2017-10-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.635, \"Energy\": 0.87, \"Loudness\": -4.291, \"Speechiness\": 0.04, \"Acousticness\": 0.0156, \"Liveness\": 0.118, \"Tempo\": 93.0, \"Duration (ms)\": 156773.0, \"Valence\": 0.912, \"Chord\": \"D\"}, {\"Index\": 664, \"Highest Charting Position\": 107, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Gnat\", \"Streams\": 8614955, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"6cS9PmLky2NhLOhpIsUlow\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 70.0, \"Danceability\": 0.835, \"Energy\": 0.869, \"Loudness\": -4.582, \"Speechiness\": 0.27, \"Acousticness\": 0.248, \"Liveness\": 0.462, \"Tempo\": 140.945, \"Duration (ms)\": 224656.0, \"Valence\": 0.82, \"Chord\": \"A#/Bb\"}, {\"Index\": 665, \"Highest Charting Position\": 111, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Joy To The World\", \"Streams\": 8387899, \"Artist\": \"Nat King Cole\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5oWFPbd340pwiXKMO1CQRy\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 0.0, \"Danceability\": 0.59, \"Energy\": 0.305, \"Loudness\": -12.955, \"Speechiness\": 0.032, \"Acousticness\": 0.894, \"Liveness\": 0.14, \"Tempo\": 102.103, \"Duration (ms)\": 86760.0, \"Valence\": 0.545, \"Chord\": \"A#/Bb\"}, {\"Index\": 666, \"Highest Charting Position\": 117, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Claus Is Coming to Town\", \"Streams\": 8177832, \"Artist\": \"Michael Bubl\\u00e9\", \"Artist Followers\": 4702232.0, \"Song ID\": \"1RMDXedcRno6rDBCbNHDJf\", \"Genre\": \"['adult standards', 'canadian pop', 'jazz pop', 'lounge']\", \"Release Date\": \"2012-11-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.594, \"Energy\": 0.389, \"Loudness\": -7.109, \"Speechiness\": 0.0517, \"Acousticness\": 0.785, \"Liveness\": 0.0313, \"Tempo\": 122.331, \"Duration (ms)\": 171093.0, \"Valence\": 0.396, \"Chord\": \"A#/Bb\"}, {\"Index\": 667, \"Highest Charting Position\": 119, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Baby It's Cold Outside (duet with Michael Bubl\\u00e9)\", \"Streams\": 8160534, \"Artist\": \"Idina Menzel\", \"Artist Followers\": 353571.0, \"Song ID\": \"0Ie5uiv54KgCr7P4sYDTHl\", \"Genre\": \"['hollywood', 'show tunes']\", \"Release Date\": \"2014-10-10\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 47.0, \"Danceability\": 0.553, \"Energy\": 0.476, \"Loudness\": -8.869, \"Speechiness\": 0.0649, \"Acousticness\": 0.647, \"Liveness\": 0.281, \"Tempo\": 113.401, \"Duration (ms)\": 166147.0, \"Valence\": 0.558, \"Chord\": \"C\"}, {\"Index\": 668, \"Highest Charting Position\": 22, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"\\u2018tis the damn season\", \"Streams\": 8115520, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7dW84mWkdWE5a6lFWxJCBG\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.575, \"Energy\": 0.434, \"Loudness\": -8.193, \"Speechiness\": 0.0312, \"Acousticness\": 0.735, \"Liveness\": 0.105, \"Tempo\": 145.916, \"Duration (ms)\": 229840.0, \"Valence\": 0.348, \"Chord\": \"F\"}, {\"Index\": 669, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"I Saw Mommy Kissing Santa Claus\", \"Streams\": 8064361, \"Artist\": \"The Jackson 5\", \"Artist Followers\": 1151360.0, \"Song ID\": \"15sxLiiChE5dCW3Y756oas\", \"Genre\": \"['motown', 'soul']\", \"Release Date\": \"1970-10-15\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.583, \"Energy\": 0.712, \"Loudness\": -8.222, \"Speechiness\": 0.0538, \"Acousticness\": 0.263, \"Liveness\": 0.817, \"Tempo\": 128.897, \"Duration (ms)\": 181267.0, \"Valence\": 0.614, \"Chord\": \"D#/Eb\"}, {\"Index\": 670, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Baby (with Henri Ren\\u00e9 & His Orchestra)\", \"Streams\": 8022773, \"Artist\": \"Eartha Kitt, Henri Rene & His Orchestra\", \"Artist Followers\": 127251.0, \"Song ID\": \"1foCxQtxBweJtZmdxhEHVO\", \"Genre\": \"['adult standards', 'lounge', 'torch song', 'vocal jazz']\", \"Release Date\": \"2002\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.7, \"Energy\": 0.139, \"Loudness\": -12.346, \"Speechiness\": 0.0607, \"Acousticness\": 0.902, \"Liveness\": 0.185, \"Tempo\": 84.485, \"Duration (ms)\": 206067.0, \"Valence\": 0.49, \"Chord\": \"G#/Ab\"}, {\"Index\": 671, \"Highest Charting Position\": 127, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Carol of the Bells\", \"Streams\": 7993078, \"Artist\": \"Mykola Dmytrovych Leontovych, John Williams\", \"Artist Followers\": 1024868.0, \"Song ID\": \"4tHqQMWSqmL6YjXwsqthDI\", \"Genre\": \"['soundtrack']\", \"Release Date\": \"1990\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 51.0, \"Danceability\": 0.418, \"Energy\": 0.106, \"Loudness\": -22.507, \"Speechiness\": 0.0448, \"Acousticness\": 0.994, \"Liveness\": 0.179, \"Tempo\": 46.718, \"Duration (ms)\": 85267.0, \"Valence\": 0.8, \"Chord\": \"G#/Ab\"}, {\"Index\": 672, \"Highest Charting Position\": 19, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"gold rush\", \"Streams\": 7901968, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5BK0uqwY9DNfZ630STAEaq\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 70.0, \"Danceability\": 0.512, \"Energy\": 0.462, \"Loudness\": -10.491, \"Speechiness\": 0.0408, \"Acousticness\": 0.83, \"Liveness\": 0.121, \"Tempo\": 112.05, \"Duration (ms)\": 185320.0, \"Valence\": 0.353, \"Chord\": \"A\"}, {\"Index\": 673, \"Highest Charting Position\": 133, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"What Christmas Means To Me\", \"Streams\": 7792643, \"Artist\": \"Stevie Wonder\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6Wn9zkkbWdK42uXCcADkRq\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 0.0, \"Danceability\": 0.545, \"Energy\": 0.7, \"Loudness\": -6.961, \"Speechiness\": 0.0323, \"Acousticness\": 0.0982, \"Liveness\": 0.1, \"Tempo\": 83.506, \"Duration (ms)\": 148147.0, \"Valence\": 0.799, \"Chord\": \"F\"}, {\"Index\": 674, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"The Christmas Song (Shawn Mendes & Camila Cabello)\", \"Streams\": 7536851, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 33893352.0, \"Song ID\": \"0fwxmtpxpMmEMphmJbCAEx\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2020-12-07\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 42.0, \"Danceability\": 0.341, \"Energy\": 0.181, \"Loudness\": -12.073, \"Speechiness\": 0.0366, \"Acousticness\": 0.888, \"Liveness\": 0.137, \"Tempo\": 83.608, \"Duration (ms)\": 196254.0, \"Valence\": 0.212, \"Chord\": \"D\"}, {\"Index\": 675, \"Highest Charting Position\": 144, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Baby, It's Cold Outside\", \"Streams\": 7367482, \"Artist\": \"Dean Martin\", \"Artist Followers\": 1139096.0, \"Song ID\": \"4MrfQL4TYQXJBlZYpAHTuE\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"1959-01-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.469, \"Energy\": 0.196, \"Loudness\": -16.093, \"Speechiness\": 0.0571, \"Acousticness\": 0.882, \"Liveness\": 0.0513, \"Tempo\": 130.036, \"Duration (ms)\": 143733.0, \"Valence\": 0.537, \"Chord\": \"C\"}, {\"Index\": 676, \"Highest Charting Position\": 145, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Claus Is Comin' to Town - Live at C.W. Post College, Greenvale, NY - December 1975\", \"Streams\": 7363913, \"Artist\": \"Bruce Springsteen\", \"Artist Followers\": 4224071.0, \"Song ID\": \"6s2wpWPFPAgKg2LXxi1Oee\", \"Genre\": \"['classic rock', 'heartland rock', 'mellow gold', 'permanent wave', 'rock', 'singer-songwriter']\", \"Release Date\": \"1981\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.357, \"Energy\": 0.668, \"Loudness\": -8.444, \"Speechiness\": 0.0479, \"Acousticness\": 0.362, \"Liveness\": 0.727, \"Tempo\": 139.986, \"Duration (ms)\": 267600.0, \"Valence\": 0.407, \"Chord\": \"C\"}, {\"Index\": 677, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"One More Sleep\", \"Streams\": 7350024, \"Artist\": \"Leona Lewis\", \"Artist Followers\": 2877234.0, \"Song ID\": \"78pn8k7RogKo2oxl0DyX6d\", \"Genre\": \"['british soul', 'dance pop', 'europop', 'pop', 'post-teen pop', 'talent show']\", \"Release Date\": \"2013-12-02\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 42.0, \"Danceability\": 0.638, \"Energy\": 0.813, \"Loudness\": -3.849, \"Speechiness\": 0.0362, \"Acousticness\": 0.464, \"Liveness\": 0.344, \"Tempo\": 112.986, \"Duration (ms)\": 239587.0, \"Valence\": 0.754, \"Chord\": \"B\"}, {\"Index\": 678, \"Highest Charting Position\": 149, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Little Saint Nick - 1991 Remix\", \"Streams\": 7301381, \"Artist\": \"The Beach Boys\", \"Artist Followers\": 1251372.0, \"Song ID\": \"63Lk6VuXdj7S58R3wLdv9r\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 0.0, \"Danceability\": 0.602, \"Energy\": 0.553, \"Loudness\": -9.336, \"Speechiness\": 0.0328, \"Acousticness\": 0.108, \"Liveness\": 0.0512, \"Tempo\": 130.594, \"Duration (ms)\": 118840.0, \"Valence\": 0.971, \"Chord\": \"B\"}, {\"Index\": 679, \"Highest Charting Position\": 150, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Naughty List (with Dixie)\", \"Streams\": 7299201, \"Artist\": \"Liam Payne\", \"Artist Followers\": 8037861.0, \"Song ID\": \"2Y0ktCGrGoGcQFXsGztvhi\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 51.0, \"Danceability\": 0.619, \"Energy\": 0.771, \"Loudness\": -2.204, \"Speechiness\": 0.0601, \"Acousticness\": 0.0318, \"Liveness\": 0.114, \"Tempo\": 81.966, \"Duration (ms)\": 154747.0, \"Valence\": 0.704, \"Chord\": \"A\"}, {\"Index\": 680, \"Highest Charting Position\": 152, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"I'll Be Home\", \"Streams\": 7281773, \"Artist\": \"Meghan Trainor\", \"Artist Followers\": 10606572.0, \"Song ID\": \"0lTurWECr2XL607eJAj1A3\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2015-01-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 45.0, \"Danceability\": 0.542, \"Energy\": 0.37, \"Loudness\": -7.779, \"Speechiness\": 0.0257, \"Acousticness\": 0.318, \"Liveness\": 0.108, \"Tempo\": 84.796, \"Duration (ms)\": 219653.0, \"Valence\": 0.289, \"Chord\": \"D\"}, {\"Index\": 681, \"Highest Charting Position\": 156, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Rudolph The Red-Nosed Reindeer\", \"Streams\": 7227612, \"Artist\": \"Dean Martin\", \"Artist Followers\": 1139096.0, \"Song ID\": \"2L9QLAhrvtP4EYg1lY0Tnw\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"1959-01-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.478, \"Energy\": 0.201, \"Loudness\": -16.768, \"Speechiness\": 0.0332, \"Acousticness\": 0.919, \"Liveness\": 0.0854, \"Tempo\": 136.471, \"Duration (ms)\": 135760.0, \"Valence\": 0.857, \"Chord\": \"G\"}, {\"Index\": 682, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Mistletoe And Holly - Remastered 1999\", \"Streams\": 7225080, \"Artist\": \"Frank Sinatra\", \"Artist Followers\": 4953667.0, \"Song ID\": \"7faDzZnZYqTyYThx2sbHVQ\", \"Genre\": \"['adult standards', 'easy listening', 'lounge']\", \"Release Date\": \"1957-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 38.0, \"Danceability\": 0.607, \"Energy\": 0.103, \"Loudness\": -14.405, \"Speechiness\": 0.0404, \"Acousticness\": 0.804, \"Liveness\": 0.076, \"Tempo\": 110.378, \"Duration (ms)\": 136427.0, \"Valence\": 0.341, \"Chord\": \"A\"}, {\"Index\": 683, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Jingle Bells - Remastered 1999\", \"Streams\": 7182262, \"Artist\": \"Frank Sinatra\", \"Artist Followers\": 4953667.0, \"Song ID\": \"4HEOgBHRCExyYVeTyrXsnL\", \"Genre\": \"['adult standards', 'easy listening', 'lounge']\", \"Release Date\": \"1957-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 36.0, \"Danceability\": 0.512, \"Energy\": 0.339, \"Loudness\": -13.119, \"Speechiness\": 0.0498, \"Acousticness\": 0.727, \"Liveness\": 0.0977, \"Tempo\": 174.609, \"Duration (ms)\": 120693.0, \"Valence\": 0.951, \"Chord\": \"G#/Ab\"}, {\"Index\": 684, \"Highest Charting Position\": 160, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Oh Santa! (feat. Ariana Grande & Jennifer Hudson)\", \"Streams\": 7170169, \"Artist\": \"Mariah Carey\", \"Artist Followers\": 6931357.0, \"Song ID\": \"1Ri9P0ZPrqr6h0REDRdJBd\", \"Genre\": \"['dance pop', 'pop', 'r&b', 'urban contemporary']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 47.0, \"Danceability\": 0.648, \"Energy\": 0.938, \"Loudness\": -3.298, \"Speechiness\": 0.115, \"Acousticness\": 0.0339, \"Liveness\": 0.0564, \"Tempo\": 78.496, \"Duration (ms)\": 200467.0, \"Valence\": 0.849, \"Chord\": \"C#/Db\"}, {\"Index\": 685, \"Highest Charting Position\": 161, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Do You Hear What I Hear? - Remastered 2006\", \"Streams\": 7149158, \"Artist\": \"Bing Crosby\", \"Artist Followers\": 359973.0, \"Song ID\": \"5aDoUmxBsbdpS16alksb5Z\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'swing', 'vocal jazz']\", \"Release Date\": \"2006-01-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.566, \"Energy\": 0.246, \"Loudness\": -15.499, \"Speechiness\": 0.0276, \"Acousticness\": 0.813, \"Liveness\": 0.195, \"Tempo\": 101.529, \"Duration (ms)\": 165667.0, \"Valence\": 0.412, \"Chord\": \"A#/Bb\"}, {\"Index\": 686, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Hallelujah\", \"Streams\": 6985392, \"Artist\": \"Pentatonix\", \"Artist Followers\": 3083825.0, \"Song ID\": \"0HZk0QsXPhMNAWNDR3rYE8\", \"Genre\": \"['a cappella']\", \"Release Date\": \"2017-12-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 60.0, \"Danceability\": 0.364, \"Energy\": 0.378, \"Loudness\": -7.381, \"Speechiness\": 0.0331, \"Acousticness\": 0.47, \"Liveness\": 0.339, \"Tempo\": 89.918, \"Duration (ms)\": 268960.0, \"Valence\": 0.366, \"Chord\": \"G\"}, {\"Index\": 687, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"This Christmas\", \"Streams\": 6809438, \"Artist\": \"Donny Hathaway\", \"Artist Followers\": 424935.0, \"Song ID\": \"38xhBO2AKrJnjdjVnhJES6\", \"Genre\": \"['chicago soul', 'classic soul', 'funk', 'motown', 'neo soul', 'quiet storm', 'soul', 'southern soul']\", \"Release Date\": \"1990-04-03\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 42.0, \"Danceability\": 0.634, \"Energy\": 0.645, \"Loudness\": -9.2, \"Speechiness\": 0.0376, \"Acousticness\": 0.292, \"Liveness\": 0.246, \"Tempo\": 93.047, \"Duration (ms)\": 231173.0, \"Valence\": 0.677, \"Chord\": \"F\"}, {\"Index\": 688, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Winter Wonderland\", \"Streams\": 6680928, \"Artist\": \"Tony Bennett\", \"Artist Followers\": 659472.0, \"Song ID\": \"6kkJlaBYdyFcwCg67hW40t\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"2014-12-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 29.0, \"Danceability\": 0.604, \"Energy\": 0.497, \"Loudness\": -6.676, \"Speechiness\": 0.0319, \"Acousticness\": 0.727, \"Liveness\": 0.102, \"Tempo\": 126.011, \"Duration (ms)\": 149307.0, \"Valence\": 0.72, \"Chord\": \"C#/Db\"}, {\"Index\": 689, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas Tree Farm\", \"Streams\": 6657404, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2mvabkN1i2gLnGAPUVdwek\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 52.0, \"Danceability\": 0.598, \"Energy\": 0.68, \"Loudness\": -4.505, \"Speechiness\": 0.0331, \"Acousticness\": 0.06, \"Liveness\": 0.324, \"Tempo\": 134.002, \"Duration (ms)\": 228027.0, \"Valence\": 0.437, \"Chord\": \"G\"}, {\"Index\": 690, \"Highest Charting Position\": 182, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Cozy Little Christmas\", \"Streams\": 6652130, \"Artist\": \"Katy Perry\", \"Artist Followers\": 18936929.0, \"Song ID\": \"02FaKXXL7KUtRc7K0k54tL\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-11-15\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.774, \"Energy\": 0.608, \"Loudness\": -6.264, \"Speechiness\": 0.128, \"Acousticness\": 0.128, \"Liveness\": 0.0895, \"Tempo\": 137.494, \"Duration (ms)\": 182521.0, \"Valence\": 0.56, \"Chord\": \"G\"}, {\"Index\": 691, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Merry Christmas, Happy Holidays\", \"Streams\": 6635128, \"Artist\": \"*NSYNC\", \"Artist Followers\": 1564750.0, \"Song ID\": \"4v9WbaxW8HdjqfUiWYWsII\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"1998-10-30\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.643, \"Energy\": 0.939, \"Loudness\": -3.967, \"Speechiness\": 0.0463, \"Acousticness\": 0.104, \"Liveness\": 0.881, \"Tempo\": 104.999, \"Duration (ms)\": 255307.0, \"Valence\": 0.756, \"Chord\": \"F\"}, {\"Index\": 692, \"Highest Charting Position\": 24, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"tolerate it\", \"Streams\": 6635109, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0PurA4JVJ8YQgSVopY8fn6\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 67.0, \"Danceability\": 0.316, \"Energy\": 0.361, \"Loudness\": -10.381, \"Speechiness\": 0.0488, \"Acousticness\": 0.878, \"Liveness\": 0.0797, \"Tempo\": 74.952, \"Duration (ms)\": 245440.0, \"Valence\": 0.221, \"Chord\": \"A\"}, {\"Index\": 693, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Please Come Home for Christmas - 2013 Remaster\", \"Streams\": 6400108, \"Artist\": \"Eagles\", \"Artist Followers\": 6896776.0, \"Song ID\": \"3QIoEi8Enr9uHffwInGIsC\", \"Genre\": \"['album rock', 'classic rock', 'country rock', 'folk rock', 'heartland rock', 'mellow gold', 'rock', 'soft rock', 'yacht rock']\", \"Release Date\": \"1994\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.612, \"Energy\": 0.289, \"Loudness\": -11.568, \"Speechiness\": 0.0421, \"Acousticness\": 0.599, \"Liveness\": 0.0561, \"Tempo\": 183.18, \"Duration (ms)\": 177440.0, \"Valence\": 0.466, \"Chord\": \"A\"}, {\"Index\": 694, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"My Kind Of Present\", \"Streams\": 6278993, \"Artist\": \"Meghan Trainor\", \"Artist Followers\": 10606572.0, \"Song ID\": \"2rkb8ijsPapKDMEh0cSe8I\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.485, \"Energy\": 0.444, \"Loudness\": -6.232, \"Speechiness\": 0.195, \"Acousticness\": 0.373, \"Liveness\": 0.0969, \"Tempo\": 179.967, \"Duration (ms)\": 161013.0, \"Valence\": 0.777, \"Chord\": \"C#/Db\"}, {\"Index\": 695, \"Highest Charting Position\": 28, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"happiness\", \"Streams\": 16213589, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"73YUReisjb3A9ActdLLjJQ\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 65.0, \"Danceability\": 0.559, \"Energy\": 0.334, \"Loudness\": -10.733, \"Speechiness\": 0.0376, \"Acousticness\": 0.87, \"Liveness\": 0.114, \"Tempo\": 122.079, \"Duration (ms)\": 315147.0, \"Valence\": 0.211, \"Chord\": \"B\"}, {\"Index\": 696, \"Highest Charting Position\": 34, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"ivy\", \"Streams\": 14519547, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"19CSr8rwW05VJL2F91KFNK\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.515, \"Energy\": 0.545, \"Loudness\": -9.277, \"Speechiness\": 0.0353, \"Acousticness\": 0.855, \"Liveness\": 0.0921, \"Tempo\": 88.856, \"Duration (ms)\": 260440.0, \"Valence\": 0.535, \"Chord\": \"D\"}, {\"Index\": 697, \"Highest Charting Position\": 38, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"dorothea\", \"Streams\": 14392788, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"670fUmXf4KQekzbEgaXyPA\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.605, \"Energy\": 0.488, \"Loudness\": -8.322, \"Speechiness\": 0.0264, \"Acousticness\": 0.696, \"Liveness\": 0.129, \"Tempo\": 119.966, \"Duration (ms)\": 225880.0, \"Valence\": 0.354, \"Chord\": \"E\"}, {\"Index\": 698, \"Highest Charting Position\": 39, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"coney island (feat. The National)\", \"Streams\": 14385703, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3k7ne7VmH43ZPWxPdvPUgR\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.537, \"Energy\": 0.537, \"Loudness\": -11.266, \"Speechiness\": 0.0617, \"Acousticness\": 0.819, \"Liveness\": 0.142, \"Tempo\": 107.895, \"Duration (ms)\": 275320.0, \"Valence\": 0.292, \"Chord\": \"G#/Ab\"}, {\"Index\": 699, \"Highest Charting Position\": 43, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"evermore (feat. Bon Iver)\", \"Streams\": 13810722, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3O5osWf1rSoKMwe6E9ZaXP\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.39, \"Energy\": 0.27, \"Loudness\": -10.673, \"Speechiness\": 0.0308, \"Acousticness\": 0.937, \"Liveness\": 0.111, \"Tempo\": 125.177, \"Duration (ms)\": 304107.0, \"Valence\": 0.32, \"Chord\": \"C#/Db\"}, {\"Index\": 700, \"Highest Charting Position\": 45, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"long story short\", \"Streams\": 13583538, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2o2sgVJIgFXk8GQjWTgI6U\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.546, \"Energy\": 0.73, \"Loudness\": -7.704, \"Speechiness\": 0.0417, \"Acousticness\": 0.66, \"Liveness\": 0.0972, \"Tempo\": 157.895, \"Duration (ms)\": 215920.0, \"Valence\": 0.573, \"Chord\": \"C\"}, {\"Index\": 701, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"cowboy like me\", \"Streams\": 12782098, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1XjHRolIXL2M1EEOUsGGR4\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.604, \"Energy\": 0.517, \"Loudness\": -9.014, \"Speechiness\": 0.0347, \"Acousticness\": 0.768, \"Liveness\": 0.123, \"Tempo\": 127.967, \"Duration (ms)\": 275040.0, \"Valence\": 0.511, \"Chord\": \"C\"}, {\"Index\": 702, \"Highest Charting Position\": 57, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"marjorie\", \"Streams\": 12234761, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"12ntTeqEeTg7GAVpe8Mhpl\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.535, \"Energy\": 0.561, \"Loudness\": -11.609, \"Speechiness\": 0.0484, \"Acousticness\": 0.876, \"Liveness\": 0.115, \"Tempo\": 96.103, \"Duration (ms)\": 257773.0, \"Valence\": 0.287, \"Chord\": \"F\"}, {\"Index\": 703, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"closure\", \"Streams\": 11245393, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"35rdVq36LMHQX0Suw9a6tK\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 62.0, \"Danceability\": 0.689, \"Energy\": 0.704, \"Loudness\": -10.813, \"Speechiness\": 0.245, \"Acousticness\": 0.835, \"Liveness\": 0.134, \"Tempo\": 151.884, \"Duration (ms)\": 180653.0, \"Valence\": 0.92, \"Chord\": \"A\"}, {\"Index\": 704, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"She Knows This\", \"Streams\": 10561183, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"1xzUQMiCoY5pdego0pHMeV\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.39, \"Energy\": 0.724, \"Loudness\": -7.607, \"Speechiness\": 0.0889, \"Acousticness\": 0.162, \"Liveness\": 0.393, \"Tempo\": 165.945, \"Duration (ms)\": 216560.0, \"Valence\": 0.312, \"Chord\": \"F#/Gb\"}, {\"Index\": 705, \"Highest Charting Position\": 97, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Another Day\", \"Streams\": 8901697, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"6myUpr3GDR80Dg3zqNTmmG\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 63.0, \"Danceability\": 0.646, \"Energy\": 0.758, \"Loudness\": -7.75, \"Speechiness\": 0.0708, \"Acousticness\": 0.556, \"Liveness\": 0.335, \"Tempo\": 172.995, \"Duration (ms)\": 199787.0, \"Valence\": 0.0642, \"Chord\": \"E\"}, {\"Index\": 706, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Solo Dolo, Pt. III\", \"Streams\": 7655623, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"27oVCAziETRbNuo5A8LNpg\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 61.0, \"Danceability\": 0.589, \"Energy\": 0.727, \"Loudness\": -6.907, \"Speechiness\": 0.0866, \"Acousticness\": 0.239, \"Liveness\": 0.164, \"Tempo\": 152.058, \"Duration (ms)\": 242267.0, \"Valence\": 0.52, \"Chord\": \"A#/Bb\"}, {\"Index\": 707, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Dive\", \"Streams\": 7524738, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"7Hc3YL8oDiAzbiAW32KXrw\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 60.0, \"Danceability\": 0.64, \"Energy\": 0.621, \"Loudness\": -8.269, \"Speechiness\": 0.0679, \"Acousticness\": 0.67, \"Liveness\": 0.36, \"Tempo\": 123.105, \"Duration (ms)\": 148707.0, \"Valence\": 0.332, \"Chord\": \"A\"}, {\"Index\": 708, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Heaven On Earth\", \"Streams\": 7117347, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"2koUj1Fn5TKFEkChSmBPIb\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 59.0, \"Danceability\": 0.786, \"Energy\": 0.61, \"Loudness\": -6.736, \"Speechiness\": 0.0558, \"Acousticness\": 0.379, \"Liveness\": 0.0765, \"Tempo\": 130.036, \"Duration (ms)\": 201093.0, \"Valence\": 0.228, \"Chord\": \"C\"}, {\"Index\": 709, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Sad People\", \"Streams\": 6865689, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"4nuAslShoN77tq12fzwjUq\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 62.0, \"Danceability\": 0.636, \"Energy\": 0.647, \"Loudness\": -6.971, \"Speechiness\": 0.0381, \"Acousticness\": 0.247, \"Liveness\": 0.113, \"Tempo\": 158.073, \"Duration (ms)\": 176027.0, \"Valence\": 0.416, \"Chord\": \"F\"}, {\"Index\": 710, \"Highest Charting Position\": 152, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Damaged\", \"Streams\": 6763705, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"2n7Ao4nyESBa5ti8gcAbBt\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 57.0, \"Danceability\": 0.625, \"Energy\": 0.581, \"Loudness\": -7.1, \"Speechiness\": 0.0316, \"Acousticness\": 0.553, \"Liveness\": 0.254, \"Tempo\": 142.04, \"Duration (ms)\": 150853.0, \"Valence\": 0.267, \"Chord\": \"G#/Ab\"}, {\"Index\": 711, \"Highest Charting Position\": 17, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"YO VISTO AS\\u00cd\", \"Streams\": 6388079, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5fROvzNghPid8mbKNDYvpJ\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 73.0, \"Danceability\": 0.688, \"Energy\": 0.881, \"Loudness\": -4.889, \"Speechiness\": 0.0474, \"Acousticness\": 0.0947, \"Liveness\": 0.0804, \"Tempo\": 123.013, \"Duration (ms)\": 191526.0, \"Valence\": 0.677, \"Chord\": \"G\"}, {\"Index\": 712, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Beautiful Trip\", \"Streams\": 6108393, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"4IIuCotvqijraSdnVLaFnM\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 54.0, \"Danceability\": 0.331, \"Energy\": 0.513, \"Loudness\": -15.392, \"Speechiness\": 0.632, \"Acousticness\": 0.972, \"Liveness\": 0.882, \"Tempo\": 133.971, \"Duration (ms)\": 37013.0, \"Valence\": 0.42, \"Chord\": \"B\"}, {\"Index\": 713, \"Highest Charting Position\": 185, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"The Void\", \"Streams\": 6068816, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"2yg7MXp8nSPaf61HVkhEr3\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 61.0, \"Danceability\": 0.464, \"Energy\": 0.459, \"Loudness\": -8.736, \"Speechiness\": 0.0314, \"Acousticness\": 0.365, \"Liveness\": 0.117, \"Tempo\": 142.017, \"Duration (ms)\": 325413.0, \"Valence\": 0.0786, \"Chord\": \"G\"}, {\"Index\": 714, \"Highest Charting Position\": 1, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"cardigan\", \"Streams\": 5845457, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"4R2kfaDFhslZEMJqAFNpdd\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-12-11--2020-12-18\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 79.0, \"Danceability\": 0.613, \"Energy\": 0.581, \"Loudness\": -8.588, \"Speechiness\": 0.0424, \"Acousticness\": 0.537, \"Liveness\": 0.25, \"Tempo\": 130.033, \"Duration (ms)\": 239560.0, \"Valence\": 0.551, \"Chord\": \"C\"}, {\"Index\": 715, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Real Shit (with benny blanco)\", \"Streams\": 9325928, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"3uVPLtkmDu8pDkYEAVqbgS\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-12-02\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 70.0, \"Danceability\": 0.703, \"Energy\": 0.703, \"Loudness\": -4.672, \"Speechiness\": 0.133, \"Acousticness\": 0.605, \"Liveness\": 0.12, \"Tempo\": 76.017, \"Duration (ms)\": 183783.0, \"Valence\": 0.697, \"Chord\": \"C#/Db\"}, {\"Index\": 716, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Teach Me How To Love\", \"Streams\": 7932101, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 33893352.0, \"Song ID\": \"5LZtB6nxvjIhUoElp3Zqk0\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 68.0, \"Danceability\": 0.592, \"Energy\": 0.885, \"Loudness\": -4.944, \"Speechiness\": 0.0807, \"Acousticness\": 0.0505, \"Liveness\": 0.0843, \"Tempo\": 98.991, \"Duration (ms)\": 202357.0, \"Valence\": 0.731, \"Chord\": \"A\"}, {\"Index\": 717, \"Highest Charting Position\": 138, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Blinding Lights (with ROSAL\\u00cdA) - Remix\", \"Streams\": 6653913, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"7MXgrcOQAJ5VwSNUL0lDd3\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 64.0, \"Danceability\": 0.49, \"Energy\": 0.694, \"Loudness\": -5.793, \"Speechiness\": 0.0618, \"Acousticness\": 0.0133, \"Liveness\": 0.0946, \"Tempo\": 170.903, \"Duration (ms)\": 216123.0, \"Valence\": 0.249, \"Chord\": \"F\"}, {\"Index\": 718, \"Highest Charting Position\": 15, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"WHATS POPPIN (feat. DaBaby, Tory Lanez & Lil Wayne) - Remix\", \"Streams\": 6567755, \"Artist\": \"Tory Lanez, Jack Harlow\", \"Artist Followers\": 3828418.0, \"Song ID\": \"2MbdDtCv5LUVjYy9RuGTgC\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-06-24\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 80.0, \"Danceability\": 0.904, \"Energy\": 0.723, \"Loudness\": -5.224, \"Speechiness\": 0.26, \"Acousticness\": 0.0631, \"Liveness\": 0.185, \"Tempo\": 145.013, \"Duration (ms)\": 227478.0, \"Valence\": 0.835, \"Chord\": \"B\"}, {\"Index\": 719, \"Highest Charting Position\": 29, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"TE DESEO LO MEJOR\", \"Streams\": 6204228, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"23XjN1s3DZC8Q9ZwuorYY4\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.763, \"Energy\": 0.597, \"Loudness\": -5.054, \"Speechiness\": 0.0416, \"Acousticness\": 0.158, \"Liveness\": 0.111, \"Tempo\": 126.054, \"Duration (ms)\": 139576.0, \"Valence\": 0.194, \"Chord\": \"C#/Db\"}, {\"Index\": 720, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Errbody\", \"Streams\": 5929516, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"6eVxH9Kyanzrw636zJRPcw\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-12-03\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 68.0, \"Danceability\": 0.887, \"Energy\": 0.606, \"Loudness\": -6.572, \"Speechiness\": 0.324, \"Acousticness\": 0.000407, \"Liveness\": 0.151, \"Tempo\": 139.995, \"Duration (ms)\": 210699.0, \"Valence\": 0.272, \"Chord\": \"D\"}, {\"Index\": 721, \"Highest Charting Position\": 86, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"Angels Like You\", \"Streams\": 5884221, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"1daDRI9ahBonbWD8YcxOIB\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 77.0, \"Danceability\": 0.672, \"Energy\": 0.642, \"Loudness\": -4.035, \"Speechiness\": 0.0313, \"Acousticness\": 0.0981, \"Liveness\": 0.1, \"Tempo\": 121.981, \"Duration (ms)\": 196453.0, \"Valence\": 0.494, \"Chord\": \"F\"}, {\"Index\": 722, \"Highest Charting Position\": 18, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Blue & Grey\", \"Streams\": 5698275, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"0n2moJpAEWHwaPYYjkzMDl\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 77.0, \"Danceability\": 0.547, \"Energy\": 0.605, \"Loudness\": -6.755, \"Speechiness\": 0.0415, \"Acousticness\": 0.42, \"Liveness\": 0.125, \"Tempo\": 121.953, \"Duration (ms)\": 254950.0, \"Valence\": 0.364, \"Chord\": \"G#/Ab\"}, {\"Index\": 723, \"Highest Charting Position\": 46, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Mad at Disney\", \"Streams\": 5436450, \"Artist\": \"salem ilese\", \"Artist Followers\": 133998.0, \"Song ID\": \"7aGyRfJWtLqgJaZoG9lJhE\", \"Genre\": \"['alt z', 'modern indie pop', 'social media pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 76.0, \"Danceability\": 0.738, \"Energy\": 0.621, \"Loudness\": -7.313, \"Speechiness\": 0.0486, \"Acousticness\": 0.424, \"Liveness\": 0.692, \"Tempo\": 113.968, \"Duration (ms)\": 136839.0, \"Valence\": 0.715, \"Chord\": \"C\"}, {\"Index\": 724, \"Highest Charting Position\": 9, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Safaera\", \"Streams\": 5390363, \"Artist\": \"Bad Bunny, Jowell & Randy, \\u00d1engo Flow\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2DEZmgHKAvm41k4J3R2E9Y\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 79.0, \"Danceability\": 0.607, \"Energy\": 0.829, \"Loudness\": -4.074, \"Speechiness\": 0.379, \"Acousticness\": 0.0103, \"Liveness\": 0.107, \"Tempo\": 96.172, \"Duration (ms)\": 295177.0, \"Valence\": 0.685, \"Chord\": \"D\"}, {\"Index\": 725, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"LA DROGA\", \"Streams\": 5375449, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"67ACYA3UI6QMNtHX6b34wX\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.643, \"Energy\": 0.727, \"Loudness\": -5.506, \"Speechiness\": 0.0389, \"Acousticness\": 0.0439, \"Liveness\": 0.123, \"Tempo\": 90.019, \"Duration (ms)\": 162299.0, \"Valence\": 0.295, \"Chord\": \"C#/Db\"}, {\"Index\": 726, \"Highest Charting Position\": 60, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"GO (feat. Juice WRLD)\", \"Streams\": 5370330, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"2rPHUAeUPbNgTmK18FPTiZ\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-06--2020-11-13\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 78.0, \"Danceability\": 0.487, \"Energy\": 0.74, \"Loudness\": -4.973, \"Speechiness\": 0.0944, \"Acousticness\": 0.157, \"Liveness\": 0.612, \"Tempo\": 73.779, \"Duration (ms)\": 181688.0, \"Valence\": 0.522, \"Chord\": \"F#/Gb\"}, {\"Index\": 727, \"Highest Charting Position\": 180, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"Jenny (I Wanna Ruin Our Friendship)\", \"Streams\": 5364223, \"Artist\": \"Studio Killers\", \"Artist Followers\": 181236.0, \"Song ID\": \"4JLBDUYSaOMPYND0iWeSWQ\", \"Genre\": \"[]\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 72.0, \"Danceability\": 0.668, \"Energy\": 0.798, \"Loudness\": -5.701, \"Speechiness\": 0.0334, \"Acousticness\": 0.00305, \"Liveness\": 0.277, \"Tempo\": 133.928, \"Duration (ms)\": 215280.0, \"Valence\": 0.575, \"Chord\": \"B\"}, {\"Index\": 728, \"Highest Charting Position\": 35, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Mood (Remix) feat. Justin Bieber, J Balvin & iann dior\", \"Streams\": 5314734, \"Artist\": \"24kGoldn\", \"Artist Followers\": 1276406.0, \"Song ID\": \"6FuGJB290AQMAHTfjOYVaK\", \"Genre\": \"['cali rap']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 77.0, \"Danceability\": 0.721, \"Energy\": 0.745, \"Loudness\": -3.508, \"Speechiness\": 0.0366, \"Acousticness\": 0.151, \"Liveness\": 0.372, \"Tempo\": 90.988, \"Duration (ms)\": 192745.0, \"Valence\": 0.699, \"Chord\": \"G\"}, {\"Index\": 729, \"Highest Charting Position\": 41, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"HOY COBR\\u00c9\", \"Streams\": 12914431, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0tjZv2hChdHZCW1zFXpy1J\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.86, \"Energy\": 0.725, \"Loudness\": -6.7, \"Speechiness\": 0.249, \"Acousticness\": 0.0464, \"Liveness\": 0.0994, \"Tempo\": 145.001, \"Duration (ms)\": 162151.0, \"Valence\": 0.375, \"Chord\": \"B\"}, {\"Index\": 730, \"Highest Charting Position\": 44, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"MALDITA POBREZA\", \"Streams\": 12660806, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0Lsis3LB0XAK6XlTHXaJk2\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 67.0, \"Danceability\": 0.762, \"Energy\": 0.861, \"Loudness\": -4.075, \"Speechiness\": 0.0652, \"Acousticness\": 0.139, \"Liveness\": 0.0956, \"Tempo\": 133.037, \"Duration (ms)\": 213609.0, \"Valence\": 0.588, \"Chord\": \"E\"}, {\"Index\": 731, \"Highest Charting Position\": 48, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"EL MUNDO ES M\\u00cdO\", \"Streams\": 12507010, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"36DHxTW2xdr9GG15T9oK9L\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 67.0, \"Danceability\": 0.716, \"Energy\": 0.522, \"Loudness\": -6.834, \"Speechiness\": 0.0582, \"Acousticness\": 0.166, \"Liveness\": 0.113, \"Tempo\": 76.993, \"Duration (ms)\": 165199.0, \"Valence\": 0.224, \"Chord\": \"F\"}, {\"Index\": 732, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"ANTES QUE SE ACABE\", \"Streams\": 11298839, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"7kjEqI6eZ7YlFrGhxixnlN\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 76.0, \"Danceability\": 0.693, \"Energy\": 0.549, \"Loudness\": -6.098, \"Speechiness\": 0.0577, \"Acousticness\": 0.505, \"Liveness\": 0.324, \"Tempo\": 139.988, \"Duration (ms)\": 221187.0, \"Valence\": 0.473, \"Chord\": \"D\"}, {\"Index\": 733, \"Highest Charting Position\": 59, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"SORRY PAPI\", \"Streams\": 11066606, \"Artist\": \"Bad Bunny, ABRA\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5jZ32WOU7sqzDYbzINwMUk\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.612, \"Energy\": 0.561, \"Loudness\": -6.054, \"Speechiness\": 0.0851, \"Acousticness\": 0.0601, \"Liveness\": 0.145, \"Tempo\": 191.911, \"Duration (ms)\": 163053.0, \"Valence\": 0.393, \"Chord\": \"C#/Db\"}, {\"Index\": 734, \"Highest Charting Position\": 63, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"120\", \"Streams\": 10957181, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3KJ3opyV29269SXkPrc19l\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 72.0, \"Danceability\": 0.636, \"Energy\": 0.656, \"Loudness\": -5.542, \"Speechiness\": 0.0676, \"Acousticness\": 0.451, \"Liveness\": 0.287, \"Tempo\": 171.918, \"Duration (ms)\": 151506.0, \"Valence\": 0.439, \"Chord\": \"D\"}, {\"Index\": 735, \"Highest Charting Position\": 66, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"TRELLAS\", \"Streams\": 10733416, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"09WAnxdBuebQopKhJT3oZS\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 66.0, \"Danceability\": 0.43, \"Energy\": 0.412, \"Loudness\": -5.372, \"Speechiness\": 0.0281, \"Acousticness\": 0.2, \"Liveness\": 0.324, \"Tempo\": 90.872, \"Duration (ms)\": 157673.0, \"Valence\": 0.0508, \"Chord\": \"D\"}, {\"Index\": 736, \"Highest Charting Position\": 83, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"Wonderful Christmastime [Edited Version] - Remastered 2011 / Edited Version\", \"Streams\": 9624871, \"Artist\": \"Paul McCartney\", \"Artist Followers\": 3609658.0, \"Song ID\": \"1SV1fxF65n9NhRHp3KlBuu\", \"Genre\": \"['album rock', 'art rock', 'beatlesque', 'classic rock', 'mellow gold', 'rock', 'soft rock']\", \"Release Date\": \"1980-05-16\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 51.0, \"Danceability\": 0.774, \"Energy\": 0.511, \"Loudness\": -8.914, \"Speechiness\": 0.0319, \"Acousticness\": 0.322, \"Liveness\": 0.0672, \"Tempo\": 94.736, \"Duration (ms)\": 227653.0, \"Valence\": 0.771, \"Chord\": \"B\"}, {\"Index\": 737, \"Highest Charting Position\": 16, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Fly To My Room\", \"Streams\": 8413330, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3QH8rQGNFX8VLbCgZ7uPTS\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 76.0, \"Danceability\": 0.764, \"Energy\": 0.526, \"Loudness\": -7.355, \"Speechiness\": 0.212, \"Acousticness\": 0.0484, \"Liveness\": 0.0718, \"Tempo\": 114.91, \"Duration (ms)\": 222243.0, \"Valence\": 0.588, \"Chord\": \"B\"}, {\"Index\": 738, \"Highest Charting Position\": 24, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Telepathy\", \"Streams\": 7703744, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"2FVpOsjT1iquZ3SpCjZ9Ne\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 77.0, \"Danceability\": 0.787, \"Energy\": 0.669, \"Loudness\": -4.333, \"Speechiness\": 0.0428, \"Acousticness\": 0.00782, \"Liveness\": 0.123, \"Tempo\": 104.994, \"Duration (ms)\": 202313.0, \"Valence\": 0.57, \"Chord\": \"F\"}, {\"Index\": 739, \"Highest Charting Position\": 26, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Dis-ease\", \"Streams\": 7165808, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"54DmTIv86D3sYdiawjULQ0\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 75.0, \"Danceability\": 0.731, \"Energy\": 0.845, \"Loudness\": -5.352, \"Speechiness\": 0.132, \"Acousticness\": 0.0132, \"Liveness\": 0.0782, \"Tempo\": 101.085, \"Duration (ms)\": 239722.0, \"Valence\": 0.484, \"Chord\": \"G#/Ab\"}, {\"Index\": 740, \"Highest Charting Position\": 27, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Stay\", \"Streams\": 7010227, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3ndCsZfq8OVwwkz9mmZvUz\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 76.0, \"Danceability\": 0.582, \"Energy\": 0.693, \"Loudness\": -5.048, \"Speechiness\": 0.0465, \"Acousticness\": 0.114, \"Liveness\": 0.13, \"Tempo\": 125.904, \"Duration (ms)\": 204800.0, \"Valence\": 0.341, \"Chord\": \"F#/Gb\"}, {\"Index\": 741, \"Highest Charting Position\": 151, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Heart Of Glass (Live from the iHeart Festival)\", \"Streams\": 6006877, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"5i7ThJfYLAzp2DyZuFpF6j\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-09-29\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 71.0, \"Danceability\": 0.58, \"Energy\": 0.908, \"Loudness\": -5.303, \"Speechiness\": 0.0341, \"Acousticness\": 0.000335, \"Liveness\": 0.087, \"Tempo\": 115.016, \"Duration (ms)\": 213672.0, \"Valence\": 0.427, \"Chord\": \"E\"}, {\"Index\": 742, \"Highest Charting Position\": 171, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"CANTARES DE NAVIDAD\", \"Streams\": 5842320, \"Artist\": \"Trio Vegabaje\\u00f1o\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2Iv6YBslkxslMJQsxshZh5\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 56.0, \"Danceability\": 0.764, \"Energy\": 0.523, \"Loudness\": -7.371, \"Speechiness\": 0.0406, \"Acousticness\": 0.777, \"Liveness\": 0.352, \"Tempo\": 118.671, \"Duration (ms)\": 199720.0, \"Valence\": 0.962, \"Chord\": \"D\"}, {\"Index\": 743, \"Highest Charting Position\": 172, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"Plastic Hearts\", \"Streams\": 5816739, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"6qCsKKS7Ol63SJW3LOIX5R\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 74.0, \"Danceability\": 0.551, \"Energy\": 0.756, \"Loudness\": -4.948, \"Speechiness\": 0.0652, \"Acousticness\": 0.0511, \"Liveness\": 0.0765, \"Tempo\": 175.984, \"Duration (ms)\": 205733.0, \"Valence\": 0.618, \"Chord\": \"D\"}, {\"Index\": 744, \"Highest Charting Position\": 63, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"C\\u00d3MO SE SIENTE - Remix\", \"Streams\": 5463964, \"Artist\": \"Jhay Cortez, Bad Bunny\", \"Artist Followers\": 2435159.0, \"Song ID\": \"2tFwfmceQa1Y6nRPhYbEtC\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-09\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 81.0, \"Danceability\": 0.807, \"Energy\": 0.606, \"Loudness\": -8.871, \"Speechiness\": 0.088, \"Acousticness\": 0.0946, \"Liveness\": 0.119, \"Tempo\": 92.988, \"Duration (ms)\": 227520.0, \"Valence\": 0.304, \"Chord\": \"D#/Eb\"}, {\"Index\": 745, \"Highest Charting Position\": 78, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Skit\", \"Streams\": 8392247, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4GVwjLRT7oSsKby7Vy8EHr\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 60.0, \"Danceability\": 0.703, \"Energy\": 0.321, \"Loudness\": -13.135, \"Speechiness\": 0.884, \"Acousticness\": 0.864, \"Liveness\": 0.908, \"Tempo\": 114.822, \"Duration (ms)\": 179548.0, \"Valence\": 0.544, \"Chord\": \"E\"}, {\"Index\": 746, \"Highest Charting Position\": 105, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Baby (with J Balvin)\", \"Streams\": 7276896, \"Artist\": \"Sfera Ebbasta\", \"Artist Followers\": 4430628.0, \"Song ID\": \"3eblNP3Zd5b5J3JaOckl8Y\", \"Genre\": \"['italian hip hop', 'italian pop', 'trap italiana']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 69.0, \"Danceability\": 0.755, \"Energy\": 0.882, \"Loudness\": -1.957, \"Speechiness\": 0.0532, \"Acousticness\": 0.125, \"Liveness\": 0.103, \"Tempo\": 99.984, \"Duration (ms)\": 193555.0, \"Valence\": 0.606, \"Chord\": \"A#/Bb\"}, {\"Index\": 747, \"Highest Charting Position\": 82, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Tick Tock (feat. 24kGoldn)\", \"Streams\": 6241923, \"Artist\": \"Clean Bandit, Mabel\", \"Artist Followers\": 4431309.0, \"Song ID\": \"27u7t9d7ZQoyjsCROHuZJ3\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk dance', 'uk funky']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 78.0, \"Danceability\": 0.779, \"Energy\": 0.705, \"Loudness\": -3.895, \"Speechiness\": 0.0344, \"Acousticness\": 0.369, \"Liveness\": 0.124, \"Tempo\": 101.022, \"Duration (ms)\": 178374.0, \"Valence\": 0.946, \"Chord\": \"C\"}, {\"Index\": 748, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Dime C\\u00f3mo Quieres\", \"Streams\": 6152821, \"Artist\": \"Christian Nodal, \\u00c1ngela Aguilar\", \"Artist Followers\": 8123757.0, \"Song ID\": \"4jcxBTrNvyqMJdMDyyjdYV\", \"Genre\": \"['mariachi', 'nuevo regional mexicano', 'ranchera', 'regional mexican']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 75.0, \"Danceability\": 0.839, \"Energy\": 0.667, \"Loudness\": -3.961, \"Speechiness\": 0.031, \"Acousticness\": 0.322, \"Liveness\": 0.244, \"Tempo\": 124.889, \"Duration (ms)\": 171360.0, \"Valence\": 0.878, \"Chord\": \"B\"}, {\"Index\": 749, \"Highest Charting Position\": 162, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Tik Tok (feat. Marracash & Gu\\u00e8 Pequeno)\", \"Streams\": 5504912, \"Artist\": \"Sfera Ebbasta\", \"Artist Followers\": 4430628.0, \"Song ID\": \"3tkYK45AZC0PqJ7MSe6IyJ\", \"Genre\": \"['italian hip hop', 'italian pop', 'trap italiana']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 59.0, \"Danceability\": 0.723, \"Energy\": 0.673, \"Loudness\": -7.636, \"Speechiness\": 0.137, \"Acousticness\": 0.0985, \"Liveness\": 0.323, \"Tempo\": 120.046, \"Duration (ms)\": 230389.0, \"Valence\": 0.302, \"Chord\": \"A\"}, {\"Index\": 750, \"Highest Charting Position\": 88, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Jerusalema (feat. Nomcebo Zikode)\", \"Streams\": 5362508, \"Artist\": \"Master KG\", \"Artist Followers\": 247480.0, \"Song ID\": \"2MlOUXmcofMackX3bxfSwi\", \"Genre\": \"['south african house']\", \"Release Date\": \"2020-01-24\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 78.0, \"Danceability\": 0.88, \"Energy\": 0.483, \"Loudness\": -7.012, \"Speechiness\": 0.0505, \"Acousticness\": 0.0185, \"Liveness\": 0.0607, \"Tempo\": 124.009, \"Duration (ms)\": 342613.0, \"Valence\": 0.827, \"Chord\": \"C#/Db\"}, {\"Index\": 751, \"Highest Charting Position\": 19, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Agua (with J Balvin) - Music From \\\"Sponge On The Run\\\" Movie\", \"Streams\": 5358940, \"Artist\": \"Tainy\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 752, \"Highest Charting Position\": 174, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Abracadabra (feat. Future)\", \"Streams\": 5263469, \"Artist\": \"Sfera Ebbasta\", \"Artist Followers\": 4430628.0, \"Song ID\": \"2GuLouaDNgLGxdJoe0vYf6\", \"Genre\": \"['italian hip hop', 'italian pop', 'trap italiana']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 55.0, \"Danceability\": 0.846, \"Energy\": 0.681, \"Loudness\": -7.091, \"Speechiness\": 0.174, \"Acousticness\": 0.0461, \"Liveness\": 0.112, \"Tempo\": 131.988, \"Duration (ms)\": 192965.0, \"Valence\": 0.809, \"Chord\": \"F\"}, {\"Index\": 753, \"Highest Charting Position\": 36, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Djadja (feat. Maluma) - Remix\", \"Streams\": 5203423, \"Artist\": \"Aya Nakamura\", \"Artist Followers\": 2953525.0, \"Song ID\": \"6AzKhCHOms83jvNVLsz0Bt\", \"Genre\": \"['basshall', 'francoton']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 72.0, \"Danceability\": 0.791, \"Energy\": 0.682, \"Loudness\": -7.328, \"Speechiness\": 0.158, \"Acousticness\": 0.175, \"Liveness\": 0.0926, \"Tempo\": 98.031, \"Duration (ms)\": 166851.0, \"Valence\": 0.672, \"Chord\": \"F\"}, {\"Index\": 754, \"Highest Charting Position\": 140, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"ALWAYS DO\", \"Streams\": 5196635, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"3QCU8BT0zDS9LPVfEhRFEE\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 76.0, \"Danceability\": 0.762, \"Energy\": 0.426, \"Loudness\": -6.865, \"Speechiness\": 0.113, \"Acousticness\": 0.0442, \"Liveness\": 0.0858, \"Tempo\": 167.827, \"Duration (ms)\": 151705.0, \"Valence\": 0.582, \"Chord\": \"G#/Ab\"}, {\"Index\": 755, \"Highest Charting Position\": 7, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Smile (with The Weeknd)\", \"Streams\": 5164187, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"6wQlQrTY5mVS8EGaFZVwVF\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 75.0, \"Danceability\": 0.694, \"Energy\": 0.685, \"Loudness\": -6.535, \"Speechiness\": 0.133, \"Acousticness\": 0.224, \"Liveness\": 0.124, \"Tempo\": 158.831, \"Duration (ms)\": 196180.0, \"Valence\": 0.306, \"Chord\": \"F#/Gb\"}, {\"Index\": 756, \"Highest Charting Position\": 22, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Pretty Savage\", \"Streams\": 5039047, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"1XnpzbOGptRwfJhZgLbmSr\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 75.0, \"Danceability\": 0.701, \"Energy\": 0.556, \"Loudness\": -7.42, \"Speechiness\": 0.0414, \"Acousticness\": 0.00886, \"Liveness\": 0.106, \"Tempo\": 152.045, \"Duration (ms)\": 201122.0, \"Valence\": 0.333, \"Chord\": \"A\"}, {\"Index\": 757, \"Highest Charting Position\": 41, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Savage Love (Laxed \\u2013 Siren Beat) [BTS Remix]\", \"Streams\": 4995203, \"Artist\": \"Jawsh 685, Jason Derulo\", \"Artist Followers\": 100635.0, \"Song ID\": \"4TgxFMOn5yoESW6zCidCXL\", \"Genre\": \"['nz pop']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 76.0, \"Danceability\": 0.758, \"Energy\": 0.598, \"Loudness\": -5.695, \"Speechiness\": 0.0868, \"Acousticness\": 0.16, \"Liveness\": 0.295, \"Tempo\": 149.836, \"Duration (ms)\": 184905.0, \"Valence\": 0.658, \"Chord\": \"C\"}, {\"Index\": 758, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Mirrors\", \"Streams\": 4988571, \"Artist\": \"Justin Timberlake\", \"Artist Followers\": 11034144.0, \"Song ID\": \"4rHZZAmHpZrA3iH5zx8frV\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2013-03-15\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 78.0, \"Danceability\": 0.574, \"Energy\": 0.512, \"Loudness\": -6.664, \"Speechiness\": 0.0503, \"Acousticness\": 0.234, \"Liveness\": 0.0946, \"Tempo\": 76.899, \"Duration (ms)\": 484147.0, \"Valence\": 0.512, \"Chord\": \"F\"}, {\"Index\": 759, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Hollywood (feat. Diplo)\", \"Streams\": 4920218, \"Artist\": \"Sfera Ebbasta\", \"Artist Followers\": 4430628.0, \"Song ID\": \"0WXU7I74NEN1DMLIT406Wx\", \"Genre\": \"['italian hip hop', 'italian pop', 'trap italiana']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 63.0, \"Danceability\": 0.848, \"Energy\": 0.708, \"Loudness\": -6.336, \"Speechiness\": 0.0366, \"Acousticness\": 0.153, \"Liveness\": 0.0948, \"Tempo\": 137.973, \"Duration (ms)\": 191869.0, \"Valence\": 0.926, \"Chord\": \"D\"}, {\"Index\": 760, \"Highest Charting Position\": 24, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Runnin\", \"Streams\": 4914682, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"5SWnsxjhdcEDc7LJjq9UHk\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 78.0, \"Danceability\": 0.819, \"Energy\": 0.626, \"Loudness\": -4.574, \"Speechiness\": 0.202, \"Acousticness\": 0.00748, \"Liveness\": 0.167, \"Tempo\": 143.01, \"Duration (ms)\": 195906.0, \"Valence\": 0.415, \"Chord\": \"A#/Bb\"}, {\"Index\": 761, \"Highest Charting Position\": 105, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Are You Bored Yet? (feat. Clairo)\", \"Streams\": 4911995, \"Artist\": \"Wallows\", \"Artist Followers\": 1963296.0, \"Song ID\": \"57RA3JGafJm5zRtKJiKPIm\", \"Genre\": \"['indie pop', 'modern rock', 'pop', 'rock']\", \"Release Date\": \"2019-03-22\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 81.0, \"Danceability\": 0.682, \"Energy\": 0.683, \"Loudness\": -6.444, \"Speechiness\": 0.0287, \"Acousticness\": 0.156, \"Liveness\": 0.273, \"Tempo\": 120.023, \"Duration (ms)\": 178000.0, \"Valence\": 0.64, \"Chord\": \"G#/Ab\"}, {\"Index\": 762, \"Highest Charting Position\": 44, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"10,000 Hours (with Justin Bieber)\", \"Streams\": 4911749, \"Artist\": \"Dan + Shay\", \"Artist Followers\": 2334615.0, \"Song ID\": \"2wrJq5XKLnmhRXHIAf9xBa\", \"Genre\": \"['contemporary country', 'country', 'pop']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.654, \"Energy\": 0.63, \"Loudness\": -4.644, \"Speechiness\": 0.0259, \"Acousticness\": 0.153, \"Liveness\": 0.111, \"Tempo\": 89.991, \"Duration (ms)\": 167693.0, \"Valence\": 0.43, \"Chord\": \"A#/Bb\"}, {\"Index\": 763, \"Highest Charting Position\": 87, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"You Got It\", \"Streams\": 4907925, \"Artist\": \"Vedo\", \"Artist Followers\": 260236.0, \"Song ID\": \"4lsHZ92XCFOQfzJFBTluk8\", \"Genre\": \"['pop r&b', 'r&b']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 79.0, \"Danceability\": 0.762, \"Energy\": 0.433, \"Loudness\": -8.937, \"Speechiness\": 0.187, \"Acousticness\": 0.143, \"Liveness\": 0.118, \"Tempo\": 122.074, \"Duration (ms)\": 203145.0, \"Valence\": 0.394, \"Chord\": \"F\"}, {\"Index\": 764, \"Highest Charting Position\": 129, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Qui\\u00e9reme Mientras Se Pueda\", \"Streams\": 4899440, \"Artist\": \"Manuel Turizo\", \"Artist Followers\": 7909963.0, \"Song ID\": \"34LI7rwi9H8w2S5KTHnv1M\", \"Genre\": \"['colombian pop', 'latin', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 74.0, \"Danceability\": 0.793, \"Energy\": 0.782, \"Loudness\": -3.945, \"Speechiness\": 0.0582, \"Acousticness\": 0.447, \"Liveness\": 0.124, \"Tempo\": 143.86, \"Duration (ms)\": 191945.0, \"Valence\": 0.81, \"Chord\": \"E\"}, {\"Index\": 765, \"Highest Charting Position\": 9, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Party Girl\", \"Streams\": 4878286, \"Artist\": \"StaySolidRocky\", \"Artist Followers\": 150587.0, \"Song ID\": \"5RqR4ZCCKJDcBLIn4sih9l\", \"Genre\": \"['melodic rap']\", \"Release Date\": \"2020-04-21\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 77.0, \"Danceability\": 0.728, \"Energy\": 0.431, \"Loudness\": -9.966, \"Speechiness\": 0.0622, \"Acousticness\": 0.749, \"Liveness\": 0.0996, \"Tempo\": 130.022, \"Duration (ms)\": 147800.0, \"Valence\": 0.629, \"Chord\": \"F#/Gb\"}, {\"Index\": 766, \"Highest Charting Position\": 95, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Drankin N Smokin\", \"Streams\": 7292247, \"Artist\": \"Future, Lil Uzi Vert\", \"Artist Followers\": 10491105.0, \"Song ID\": \"0k7wmahjkn389wAZdz19Cv\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-11-13--2020-11-20\", \"Popularity\": 78.0, \"Danceability\": 0.752, \"Energy\": 0.658, \"Loudness\": -6.297, \"Speechiness\": 0.342, \"Acousticness\": 0.0421, \"Liveness\": 0.0927, \"Tempo\": 151.951, \"Duration (ms)\": 213520.0, \"Valence\": 0.387, \"Chord\": \"C\"}, {\"Index\": 767, \"Highest Charting Position\": 86, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Be Like That - feat. Swae Lee & Khalid\", \"Streams\": 5929062, \"Artist\": \"Kane Brown\", \"Artist Followers\": 3509653.0, \"Song ID\": \"5f1joOtoMeyppIcJGZQvqJ\", \"Genre\": \"['contemporary country', 'country road']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 79.0, \"Danceability\": 0.727, \"Energy\": 0.626, \"Loudness\": -8.415, \"Speechiness\": 0.0726, \"Acousticness\": 0.0469, \"Liveness\": 0.126, \"Tempo\": 86.97, \"Duration (ms)\": 191406.0, \"Valence\": 0.322, \"Chord\": \"G\"}, {\"Index\": 768, \"Highest Charting Position\": 74, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"MORE\", \"Streams\": 5602168, \"Artist\": \"K/DA, Madison Beer, (G)I-DLE, Lexie Liu, Jaira Burns, Seraphine, League of Legends\", \"Artist Followers\": 1245965.0, \"Song ID\": \"6juLaduD4STCUDWT0AYun4\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2020-10-28\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 73.0, \"Danceability\": 0.66, \"Energy\": 0.787, \"Loudness\": -4.592, \"Speechiness\": 0.032, \"Acousticness\": 0.00257, \"Liveness\": 0.323, \"Tempo\": 142.018, \"Duration (ms)\": 217088.0, \"Valence\": 0.199, \"Chord\": \"C#/Db\"}, {\"Index\": 769, \"Highest Charting Position\": 140, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Enchule\", \"Streams\": 5561227, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6096559.0, \"Song ID\": \"3ThrfRAmijYU098H9q9tAs\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 70.0, \"Danceability\": 0.763, \"Energy\": 0.666, \"Loudness\": -3.316, \"Speechiness\": 0.194, \"Acousticness\": 0.153, \"Liveness\": 0.301, \"Tempo\": 90.086, \"Duration (ms)\": 185719.0, \"Valence\": 0.587, \"Chord\": \"G\"}, {\"Index\": 770, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Stripes Like Burberry\", \"Streams\": 5445204, \"Artist\": \"Future, Lil Uzi Vert\", \"Artist Followers\": 10491105.0, \"Song ID\": \"6lt8iodSkYWEV0ifKCSlfg\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-11-13--2020-11-20\", \"Popularity\": 56.0, \"Danceability\": 0.758, \"Energy\": 0.574, \"Loudness\": -7.833, \"Speechiness\": 0.217, \"Acousticness\": 0.216, \"Liveness\": 0.144, \"Tempo\": 144.081, \"Duration (ms)\": 274313.0, \"Valence\": 0.706, \"Chord\": \"A\"}, {\"Index\": 771, \"Highest Charting Position\": 117, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Papi Chulo\", \"Streams\": 5361669, \"Artist\": \"Octavian, Skepta\", \"Artist Followers\": 213344.0, \"Song ID\": \"6Juv5N0dNU1imms9c9u1dA\", \"Genre\": \"['afroswing', 'london rap', 'uk alternative hip hop', 'uk hip hop']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 73.0, \"Danceability\": 0.866, \"Energy\": 0.563, \"Loudness\": -6.964, \"Speechiness\": 0.108, \"Acousticness\": 0.185, \"Liveness\": 0.0889, \"Tempo\": 127.954, \"Duration (ms)\": 161668.0, \"Valence\": 0.307, \"Chord\": \"B\"}, {\"Index\": 772, \"Highest Charting Position\": 20, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"off the table (with The Weeknd)\", \"Streams\": 5308945, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"7E1jVNoWuemqUryI4FxsVD\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 67.0, \"Danceability\": 0.411, \"Energy\": 0.522, \"Loudness\": -7.295, \"Speechiness\": 0.0981, \"Acousticness\": 0.519, \"Liveness\": 0.398, \"Tempo\": 88.332, \"Duration (ms)\": 239949.0, \"Valence\": 0.382, \"Chord\": \"C\"}, {\"Index\": 773, \"Highest Charting Position\": 52, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Spicy (feat. Post Malone)\", \"Streams\": 5303146, \"Artist\": \"Ty Dolla $ign\", \"Artist Followers\": 3866304.0, \"Song ID\": \"5IUtvfNvOyVYZUa6AJFrnP\", \"Genre\": \"['hip hop', 'pop', 'pop rap', 'r&b', 'southern hip hop', 'trap', 'trap soul']\", \"Release Date\": \"2020-10-23\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 80.0, \"Danceability\": 0.782, \"Energy\": 0.51, \"Loudness\": -5.724, \"Speechiness\": 0.0419, \"Acousticness\": 0.143, \"Liveness\": 0.115, \"Tempo\": 99.993, \"Duration (ms)\": 143375.0, \"Valence\": 0.118, \"Chord\": \"E\"}, {\"Index\": 774, \"Highest Charting Position\": 124, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Sweet Melody\", \"Streams\": 5201322, \"Artist\": \"Little Mix\", \"Artist Followers\": 9398941.0, \"Song ID\": \"76Tuo484SLohJakHLnGI3B\", \"Genre\": \"['dance pop', 'girl group', 'pop', 'post-teen pop', 'talent show', 'uk pop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\", \"Popularity\": 73.0, \"Danceability\": 0.448, \"Energy\": 0.824, \"Loudness\": -4.249, \"Speechiness\": 0.057, \"Acousticness\": 0.0739, \"Liveness\": 0.113, \"Tempo\": 119.965, \"Duration (ms)\": 213693.0, \"Valence\": 0.419, \"Chord\": \"F\"}, {\"Index\": 775, \"Highest Charting Position\": 144, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Blueberry Eyes (feat. SUGA of BTS)\", \"Streams\": 5158896, \"Artist\": \"MAX\", \"Artist Followers\": 689627.0, \"Song ID\": \"5dn6QANKbf76pANGjMBida\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'pop rap', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2020-09-15\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 72.0, \"Danceability\": 0.746, \"Energy\": 0.611, \"Loudness\": -7.034, \"Speechiness\": 0.101, \"Acousticness\": 0.454, \"Liveness\": 0.133, \"Tempo\": 149.967, \"Duration (ms)\": 172245.0, \"Valence\": 0.411, \"Chord\": \"C\"}, {\"Index\": 776, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"That\\u2019s It\", \"Streams\": 5151014, \"Artist\": \"Future, Lil Uzi Vert\", \"Artist Followers\": 10491105.0, \"Song ID\": \"5n6gBhdEjCuj3obgCoTEFD\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-11-13--2020-11-20\", \"Popularity\": 64.0, \"Danceability\": 0.94, \"Energy\": 0.532, \"Loudness\": -5.998, \"Speechiness\": 0.358, \"Acousticness\": 0.12, \"Liveness\": 0.0925, \"Tempo\": 123.043, \"Duration (ms)\": 228796.0, \"Valence\": 0.599, \"Chord\": \"B\"}, {\"Index\": 777, \"Highest Charting Position\": 157, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Promiscuous\", \"Streams\": 5083648, \"Artist\": \"Nelly Furtado, Timbaland\", \"Artist Followers\": 2688557.0, \"Song ID\": \"2gam98EZKrF9XuOkU13ApN\", \"Genre\": \"['canadian latin', 'canadian pop', 'dance pop', 'pop', 'pop rap']\", \"Release Date\": \"2006-01-01\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 82.0, \"Danceability\": 0.808, \"Energy\": 0.97, \"Loudness\": -6.098, \"Speechiness\": 0.0506, \"Acousticness\": 0.0569, \"Liveness\": 0.154, \"Tempo\": 114.328, \"Duration (ms)\": 242293.0, \"Valence\": 0.868, \"Chord\": \"A#/Bb\"}, {\"Index\": 778, \"Highest Charting Position\": 22, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"GREECE (feat. Drake)\", \"Streams\": 5043665, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6281829.0, \"Song ID\": \"35RJhm1pEovTBwnNR0zWad\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-07-16\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 77.0, \"Danceability\": 0.695, \"Energy\": 0.343, \"Loudness\": -10.798, \"Speechiness\": 0.0432, \"Acousticness\": 0.0743, \"Liveness\": 0.107, \"Tempo\": 85.84, \"Duration (ms)\": 218902.0, \"Valence\": 0.229, \"Chord\": \"F\"}, {\"Index\": 779, \"Highest Charting Position\": 25, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"just like magic\", \"Streams\": 4980571, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"7Dx9Z6Aon1qPS2N0rHSWTe\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 69.0, \"Danceability\": 0.719, \"Energy\": 0.607, \"Loudness\": -5.156, \"Speechiness\": 0.165, \"Acousticness\": 0.08, \"Liveness\": 0.125, \"Tempo\": 128.006, \"Duration (ms)\": 149900.0, \"Valence\": 0.464, \"Chord\": \"G#/Ab\"}, {\"Index\": 780, \"Highest Charting Position\": 53, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Still Don't Know My Name\", \"Streams\": 4926802, \"Artist\": \"Labrinth\", \"Artist Followers\": 1685215.0, \"Song ID\": \"6N22FZs2ZhPBYi3b9XPajV\", \"Genre\": \"['indie poptimism', 'pop']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 80.0, \"Danceability\": 0.316, \"Energy\": 0.63, \"Loudness\": -5.963, \"Speechiness\": 0.117, \"Acousticness\": 0.471, \"Liveness\": 0.205, \"Tempo\": 89.643, \"Duration (ms)\": 153294.0, \"Valence\": 0.313, \"Chord\": \"F\"}, {\"Index\": 781, \"Highest Charting Position\": 32, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Hasta Que Dios Diga\", \"Streams\": 4899099, \"Artist\": \"Anuel AA, Bad Bunny\", \"Artist Followers\": 18306226.0, \"Song ID\": \"06s3QtMJVXw1AJX3UfvZG1\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 76.0, \"Danceability\": 0.691, \"Energy\": 0.765, \"Loudness\": -4.727, \"Speechiness\": 0.111, \"Acousticness\": 0.464, \"Liveness\": 0.203, \"Tempo\": 174.021, \"Duration (ms)\": 246000.0, \"Valence\": 0.855, \"Chord\": \"G#/Ab\"}, {\"Index\": 782, \"Highest Charting Position\": 102, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Get You The Moon (feat. Sn\\u00f8w)\", \"Streams\": 4872409, \"Artist\": \"Kina\", \"Artist Followers\": 661863.0, \"Song ID\": \"4ZLzoOkj0MPWrTLvooIuaa\", \"Genre\": \"['sad rap']\", \"Release Date\": \"2018-10-08\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.498, \"Energy\": 0.235, \"Loudness\": -16.541, \"Speechiness\": 0.188, \"Acousticness\": 0.72, \"Liveness\": 0.144, \"Tempo\": 118.917, \"Duration (ms)\": 179080.0, \"Valence\": 0.0895, \"Chord\": \"C#/Db\"}, {\"Index\": 783, \"Highest Charting Position\": 162, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Moonwalking in Calabasas (feat. Blueface) - Remix\", \"Streams\": 4863053, \"Artist\": \"DDG\", \"Artist Followers\": 486194.0, \"Song ID\": \"7o4gBbTM6UBLkOYPw9xMCz\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2020-12-02\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 74.0, \"Danceability\": 0.928, \"Energy\": 0.341, \"Loudness\": -10.196, \"Speechiness\": 0.103, \"Acousticness\": 0.0614, \"Liveness\": 0.162, \"Tempo\": 129.966, \"Duration (ms)\": 170233.0, \"Valence\": 0.745, \"Chord\": \"B\"}, {\"Index\": 784, \"Highest Charting Position\": 29, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Forever After All\", \"Streams\": 4746415, \"Artist\": \"Luke Combs\", \"Artist Followers\": 5371000.0, \"Song ID\": \"6IBcOGPsniK3Pso1wHIhew\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2020-10-23\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 80.0, \"Danceability\": 0.487, \"Energy\": 0.65, \"Loudness\": -5.195, \"Speechiness\": 0.0253, \"Acousticness\": 0.191, \"Liveness\": 0.0933, \"Tempo\": 151.964, \"Duration (ms)\": 232533.0, \"Valence\": 0.456, \"Chord\": \"C\"}, {\"Index\": 785, \"Highest Charting Position\": 76, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Lean (feat. Towy, Osquel, Beltito & Sammy & Falsetto)\", \"Streams\": 4739241, \"Artist\": \"Super Yei, Jone Quest\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 786, \"Highest Charting Position\": 156, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"SLOW DANCING IN THE DARK\", \"Streams\": 4732343, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"0rKtyWc8bvkriBthvHKY8d\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2018-10-26\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-05-08--2020-05-15\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.515, \"Energy\": 0.479, \"Loudness\": -7.458, \"Speechiness\": 0.0261, \"Acousticness\": 0.544, \"Liveness\": 0.191, \"Tempo\": 88.964, \"Duration (ms)\": 209274.0, \"Valence\": 0.284, \"Chord\": \"D#/Eb\"}, {\"Index\": 787, \"Highest Charting Position\": 92, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Don Don\", \"Streams\": 4731423, \"Artist\": \"Daddy Yankee, Anuel AA, Kendo Kaponi\", \"Artist Followers\": 23936368.0, \"Song ID\": \"3kml9ZdpT7UYk1ugkjqOzt\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-11\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 69.0, \"Danceability\": 0.838, \"Energy\": 0.819, \"Loudness\": -4.681, \"Speechiness\": 0.211, \"Acousticness\": 0.285, \"Liveness\": 0.224, \"Tempo\": 105.027, \"Duration (ms)\": 275893.0, \"Valence\": 0.656, \"Chord\": \"F\"}, {\"Index\": 788, \"Highest Charting Position\": 5, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"my future\", \"Streams\": 4721082, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"3YUMWmx8EJq0DurfuIwoGh\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-07-30\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 80.0, \"Danceability\": 0.456, \"Energy\": 0.285, \"Loudness\": -10.755, \"Speechiness\": 0.0979, \"Acousticness\": 0.814, \"Liveness\": 0.307, \"Tempo\": 104.89, \"Duration (ms)\": 210005.0, \"Valence\": 0.0809, \"Chord\": \"G#/Ab\"}, {\"Index\": 789, \"Highest Charting Position\": 163, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Nada\", \"Streams\": 4713873, \"Artist\": \"Cali Y El Dandee, Danna Paola\", \"Artist Followers\": 3152313.0, \"Song ID\": \"4K8cyoCDovlc4FvtUr2Hfx\", \"Genre\": \"['champeta', 'colombian pop', 'electro latino', 'latin', 'latin pop', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 76.0, \"Danceability\": 0.684, \"Energy\": 0.808, \"Loudness\": -2.737, \"Speechiness\": 0.061, \"Acousticness\": 0.0518, \"Liveness\": 0.0858, \"Tempo\": 173.905, \"Duration (ms)\": 174027.0, \"Valence\": 0.712, \"Chord\": \"C\"}, {\"Index\": 790, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"safety net (feat. Ty Dolla $ign)\", \"Streams\": 5798744, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"14gkWVFMwdxBMyqBw1wmIg\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 70.0, \"Danceability\": 0.552, \"Energy\": 0.599, \"Loudness\": -5.75, \"Speechiness\": 0.0404, \"Acousticness\": 0.0703, \"Liveness\": 0.0986, \"Tempo\": 161.884, \"Duration (ms)\": 208457.0, \"Valence\": 0.0916, \"Chord\": \"C#/Db\"}, {\"Index\": 791, \"Highest Charting Position\": 31, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"shut up\", \"Streams\": 5282490, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3ko9jEHNt4O5fjKN65ULJp\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 63.0, \"Danceability\": 0.499, \"Energy\": 0.462, \"Loudness\": -5.308, \"Speechiness\": 0.0312, \"Acousticness\": 0.801, \"Liveness\": 0.0946, \"Tempo\": 127.698, \"Duration (ms)\": 157710.0, \"Valence\": 0.599, \"Chord\": \"C\"}, {\"Index\": 792, \"Highest Charting Position\": 42, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"nasty\", \"Streams\": 5249342, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"0sci7ppTZFm4mjcH3nu8yO\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 69.0, \"Danceability\": 0.772, \"Energy\": 0.506, \"Loudness\": -6.558, \"Speechiness\": 0.139, \"Acousticness\": 0.0814, \"Liveness\": 0.182, \"Tempo\": 127.894, \"Duration (ms)\": 200733.0, \"Valence\": 0.456, \"Chord\": \"F#/Gb\"}, {\"Index\": 793, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"TRAGIC (feat. Youngboy Never Broke Again & Internet Money)\", \"Streams\": 5226940, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"13EW51DKru044OJDJ9Bm8o\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-11-06--2020-11-13\", \"Popularity\": 76.0, \"Danceability\": 0.779, \"Energy\": 0.642, \"Loudness\": -6.321, \"Speechiness\": 0.116, \"Acousticness\": 0.0383, \"Liveness\": 0.2, \"Tempo\": 82.363, \"Duration (ms)\": 153147.0, \"Valence\": 0.388, \"Chord\": \"G#/Ab\"}, {\"Index\": 794, \"Highest Charting Position\": 49, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Ayer Me Llam\\u00f3 Mi Ex (feat. Lenny Santos)\", \"Streams\": 5220504, \"Artist\": \"KHEA\", \"Artist Followers\": 3198705.0, \"Song ID\": \"6C6mUonH6MNdSg5pw7kOc9\", \"Genre\": \"['argentine hip hop', 'trap argentino', 'trap latino', 'trap triste']\", \"Release Date\": \"2020-08-20\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 71.0, \"Danceability\": 0.752, \"Energy\": 0.716, \"Loudness\": -5.2, \"Speechiness\": 0.0325, \"Acousticness\": 0.254, \"Liveness\": 0.243, \"Tempo\": 117.007, \"Duration (ms)\": 206760.0, \"Valence\": 0.553, \"Chord\": \"A#/Bb\"}, {\"Index\": 795, \"Highest Charting Position\": 119, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Madrid (feat. Myke Towers)\", \"Streams\": 5064484, \"Artist\": \"Maluma\", \"Artist Followers\": 26784251.0, \"Song ID\": \"19OXtYzrJyCrQvTbfukt4H\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 73.0, \"Danceability\": 0.764, \"Energy\": 0.741, \"Loudness\": -3.617, \"Speechiness\": 0.101, \"Acousticness\": 0.239, \"Liveness\": 0.107, \"Tempo\": 170.081, \"Duration (ms)\": 198570.0, \"Valence\": 0.802, \"Chord\": \"A\"}, {\"Index\": 796, \"Highest Charting Position\": 85, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Caramelo - Remix\", \"Streams\": 5033798, \"Artist\": \"Ozuna, KAROL G, Myke Towers\", \"Artist Followers\": 29238936.0, \"Song ID\": \"2uu2aGqA2UblCg581Q7l1g\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-08-17\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 72.0, \"Danceability\": 0.754, \"Energy\": 0.796, \"Loudness\": -3.743, \"Speechiness\": 0.139, \"Acousticness\": 0.062, \"Liveness\": 0.204, \"Tempo\": 168.045, \"Duration (ms)\": 233160.0, \"Valence\": 0.62, \"Chord\": \"D#/Eb\"}, {\"Index\": 797, \"Highest Charting Position\": 25, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Mr. Right Now (feat. Drake)\", \"Streams\": 4951481, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"4Q34FP1AT7GEl9oLgNtiWj\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 75.0, \"Danceability\": 0.647, \"Energy\": 0.667, \"Loudness\": -5.563, \"Speechiness\": 0.304, \"Acousticness\": 0.231, \"Liveness\": 0.133, \"Tempo\": 172.08, \"Duration (ms)\": 193839.0, \"Valence\": 0.704, \"Chord\": \"F\"}, {\"Index\": 798, \"Highest Charting Position\": 41, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Got It On Me\", \"Streams\": 4924030, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"25zlnOAzbVoOzIeXSvQFf1\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 78.0, \"Danceability\": 0.688, \"Energy\": 0.647, \"Loudness\": -7.258, \"Speechiness\": 0.19, \"Acousticness\": 0.00815, \"Liveness\": 0.095, \"Tempo\": 88.834, \"Duration (ms)\": 164580.0, \"Valence\": 0.195, \"Chord\": \"D\"}, {\"Index\": 799, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"my hair\", \"Streams\": 4896521, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"6u7gmPOz7pzzaeR9xSBpsR\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 66.0, \"Danceability\": 0.686, \"Energy\": 0.526, \"Loudness\": -6.842, \"Speechiness\": 0.0374, \"Acousticness\": 0.0815, \"Liveness\": 0.144, \"Tempo\": 92.013, \"Duration (ms)\": 158436.0, \"Valence\": 0.372, \"Chord\": \"C\"}, {\"Index\": 800, \"Highest Charting Position\": 59, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"obvious\", \"Streams\": 4865084, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"0q85C1JiECyYIQthz1posA\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 65.0, \"Danceability\": 0.624, \"Energy\": 0.672, \"Loudness\": -5.334, \"Speechiness\": 0.106, \"Acousticness\": 0.0967, \"Liveness\": 0.155, \"Tempo\": 159.852, \"Duration (ms)\": 146959.0, \"Valence\": 0.26, \"Chord\": \"C\"}, {\"Index\": 801, \"Highest Charting Position\": 30, \"Number of Times Charted\": 45, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Beautiful People (feat. Khalid)\", \"Streams\": 4813796, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"4evmHXcjt3bTUHD1cvny97\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.64, \"Energy\": 0.648, \"Loudness\": -8.113, \"Speechiness\": 0.187, \"Acousticness\": 0.124, \"Liveness\": 0.0802, \"Tempo\": 92.977, \"Duration (ms)\": 197867.0, \"Valence\": 0.548, \"Chord\": \"F\"}, {\"Index\": 802, \"Highest Charting Position\": 29, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Favorito\", \"Streams\": 4787127, \"Artist\": \"Camilo\", \"Artist Followers\": 10580764.0, \"Song ID\": \"0Snbzbd74RLfL0i4nn1vU5\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-26\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 73.0, \"Danceability\": 0.611, \"Energy\": 0.851, \"Loudness\": -2.982, \"Speechiness\": 0.0598, \"Acousticness\": 0.229, \"Liveness\": 0.232, \"Tempo\": 178.032, \"Duration (ms)\": 211613.0, \"Valence\": 0.823, \"Chord\": \"A\"}, {\"Index\": 803, \"Highest Charting Position\": 42, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"After Party\", \"Streams\": 4784580, \"Artist\": \"Don Toliver\", \"Artist Followers\": 1606884.0, \"Song ID\": \"527k23H0A4Q0UJN3vGs0Da\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 80.0, \"Danceability\": 0.629, \"Energy\": 0.692, \"Loudness\": -8.045, \"Speechiness\": 0.0376, \"Acousticness\": 0.00981, \"Liveness\": 0.603, \"Tempo\": 162.948, \"Duration (ms)\": 167916.0, \"Valence\": 0.453, \"Chord\": \"F\"}, {\"Index\": 804, \"Highest Charting Position\": 14, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Rojo\", \"Streams\": 4773792, \"Artist\": \"J Balvin\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3zR9JVqHsILrkNyCOqA6jM\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 0.0, \"Danceability\": 0.652, \"Energy\": 0.595, \"Loudness\": -4.04, \"Speechiness\": 0.117, \"Acousticness\": 0.15, \"Liveness\": 0.0836, \"Tempo\": 172.277, \"Duration (ms)\": 151147.0, \"Valence\": 0.421, \"Chord\": \"B\"}, {\"Index\": 805, \"Highest Charting Position\": 51, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"six thirty\", \"Streams\": 10941573, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"2IKJtXeR5UsaUjZB46fTOK\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 63.0, \"Danceability\": 0.739, \"Energy\": 0.516, \"Loudness\": -7.154, \"Speechiness\": 0.0539, \"Acousticness\": 0.67, \"Liveness\": 0.151, \"Tempo\": 120.109, \"Duration (ms)\": 183874.0, \"Valence\": 0.434, \"Chord\": \"C\"}, {\"Index\": 806, \"Highest Charting Position\": 65, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"love language\", \"Streams\": 9399230, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"6NYtLvyThMT0oALFdJFdzq\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 62.0, \"Danceability\": 0.688, \"Energy\": 0.573, \"Loudness\": -5.03, \"Speechiness\": 0.208, \"Acousticness\": 0.0686, \"Liveness\": 0.0749, \"Tempo\": 110.034, \"Duration (ms)\": 179861.0, \"Valence\": 0.553, \"Chord\": \"A#/Bb\"}, {\"Index\": 807, \"Highest Charting Position\": 66, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"west side\", \"Streams\": 9397167, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"1whfVLMKWqAX3uk97VXsNN\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 62.0, \"Danceability\": 0.688, \"Energy\": 0.455, \"Loudness\": -8.632, \"Speechiness\": 0.199, \"Acousticness\": 0.186, \"Liveness\": 0.0794, \"Tempo\": 87.865, \"Duration (ms)\": 132279.0, \"Valence\": 0.557, \"Chord\": \"B\"}, {\"Index\": 808, \"Highest Charting Position\": 146, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Thriller\", \"Streams\": 5605234, \"Artist\": \"Michael Jackson\", \"Artist Followers\": 19345579.0, \"Song ID\": \"7azo4rpSUh8nXgtonC6Pkq\", \"Genre\": \"['pop', 'r&b', 'soul']\", \"Release Date\": \"2017-09-27\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 68.0, \"Danceability\": 0.764, \"Energy\": 0.887, \"Loudness\": -3.726, \"Speechiness\": 0.0744, \"Acousticness\": 0.0816, \"Liveness\": 0.847, \"Tempo\": 118.427, \"Duration (ms)\": 358053.0, \"Valence\": 0.72, \"Chord\": \"B\"}, {\"Index\": 809, \"Highest Charting Position\": 105, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Dancing With A Stranger (with Normani)\", \"Streams\": 5229835, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"6Qs4SXO9dwPj5GKvVOv8Ki\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2019-01-11\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.741, \"Energy\": 0.52, \"Loudness\": -7.513, \"Speechiness\": 0.0656, \"Acousticness\": 0.45, \"Liveness\": 0.222, \"Tempo\": 102.998, \"Duration (ms)\": 171030.0, \"Valence\": 0.347, \"Chord\": \"G#/Ab\"}, {\"Index\": 810, \"Highest Charting Position\": 91, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Angeklagt\", \"Streams\": 5226264, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"5eu4Lxm5TlI0tKSTTDWJAT\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-10-29\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 60.0, \"Danceability\": 0.658, \"Energy\": 0.624, \"Loudness\": -9.155, \"Speechiness\": 0.0915, \"Acousticness\": 0.171, \"Liveness\": 0.116, \"Tempo\": 181.942, \"Duration (ms)\": 168991.0, \"Valence\": 0.314, \"Chord\": \"C#/Db\"}, {\"Index\": 811, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Kids Again\", \"Streams\": 5103194, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"1ABS9lKaZ1uXkXCqr9zFO7\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 62.0, \"Danceability\": 0.666, \"Energy\": 0.726, \"Loudness\": -2.998, \"Speechiness\": 0.0262, \"Acousticness\": 0.486, \"Liveness\": 0.0892, \"Tempo\": 128.044, \"Duration (ms)\": 207528.0, \"Valence\": 0.468, \"Chord\": \"B\"}, {\"Index\": 812, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Highway to Hell\", \"Streams\": 5096618, \"Artist\": \"AC/DC\", \"Artist Followers\": 20110171.0, \"Song ID\": \"2zYzyRzz6pRmhPzyfMEC8s\", \"Genre\": \"['australian rock', 'hard rock', 'rock']\", \"Release Date\": \"1979-07-27\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 83.0, \"Danceability\": 0.574, \"Energy\": 0.913, \"Loudness\": -4.793, \"Speechiness\": 0.133, \"Acousticness\": 0.061, \"Liveness\": 0.156, \"Tempo\": 115.728, \"Duration (ms)\": 208400.0, \"Valence\": 0.423, \"Chord\": \"F#/Gb\"}, {\"Index\": 813, \"Highest Charting Position\": 38, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Me Gusta (with Cardi B & Myke Towers)\", \"Streams\": 4914412, \"Artist\": \"Anitta\", \"Artist Followers\": 10741972.0, \"Song ID\": \"7e1VoRlNumuEkXlITMHKLE\", \"Genre\": \"['funk carioca', 'funk pop', 'pagode baiano', 'pop nacional']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 72.0, \"Danceability\": 0.91, \"Energy\": 0.604, \"Loudness\": -4.392, \"Speechiness\": 0.082, \"Acousticness\": 0.448, \"Liveness\": 0.0863, \"Tempo\": 110.075, \"Duration (ms)\": 180788.0, \"Valence\": 0.807, \"Chord\": \"F#/Gb\"}, {\"Index\": 814, \"Highest Charting Position\": 133, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"24 (feat. Lil Baby)\", \"Streams\": 4904772, \"Artist\": \"Money Man\", \"Artist Followers\": 345027.0, \"Song ID\": \"0xUvi7wldroBzaZCengPa5\", \"Genre\": \"['memphis hip hop', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 74.0, \"Danceability\": 0.868, \"Energy\": 0.638, \"Loudness\": -7.746, \"Speechiness\": 0.0736, \"Acousticness\": 0.146, \"Liveness\": 0.0931, \"Tempo\": 126.03, \"Duration (ms)\": 182857.0, \"Valence\": 0.459, \"Chord\": \"D\"}, {\"Index\": 815, \"Highest Charting Position\": 23, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Relaci\\u00f3n\", \"Streams\": 4825749, \"Artist\": \"Sech\", \"Artist Followers\": 8766508.0, \"Song ID\": \"35UUpTmrcFXNIVIN26ujXl\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-04-10--2020-04-17\", \"Popularity\": 80.0, \"Danceability\": 0.793, \"Energy\": 0.771, \"Loudness\": -3.417, \"Speechiness\": 0.0959, \"Acousticness\": 0.0337, \"Liveness\": 0.284, \"Tempo\": 171.943, \"Duration (ms)\": 247308.0, \"Valence\": 0.835, \"Chord\": \"F\"}, {\"Index\": 816, \"Highest Charting Position\": 14, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"FRANCHISE (feat. Young Thug & M.I.A.)\", \"Streams\": 4821213, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"4jVBIpuOiMj1crqd8LoCrJ\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 74.0, \"Danceability\": 0.835, \"Energy\": 0.699, \"Loudness\": -5.405, \"Speechiness\": 0.277, \"Acousticness\": 0.00671, \"Liveness\": 0.195, \"Tempo\": 154.981, \"Duration (ms)\": 202795.0, \"Valence\": 0.547, \"Chord\": \"G#/Ab\"}, {\"Index\": 817, \"Highest Charting Position\": 11, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Bet You Wanna (feat. Cardi B)\", \"Streams\": 6846771, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"7iAgNZdotu40NwtoIWJHFe\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 67.0, \"Danceability\": 0.653, \"Energy\": 0.662, \"Loudness\": -6.168, \"Speechiness\": 0.162, \"Acousticness\": 0.00465, \"Liveness\": 0.0626, \"Tempo\": 111.712, \"Duration (ms)\": 161168.0, \"Valence\": 0.674, \"Chord\": \"G\"}, {\"Index\": 818, \"Highest Charting Position\": 82, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Wolves (feat. Post Malone)\", \"Streams\": 5547002, \"Artist\": \"Big Sean\", \"Artist Followers\": 8673345.0, \"Song ID\": \"33gwZOGJWEZ7dRWPqPxBEZ\", \"Genre\": \"['detroit hip hop', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 79.0, \"Danceability\": 0.724, \"Energy\": 0.675, \"Loudness\": -5.267, \"Speechiness\": 0.0867, \"Acousticness\": 0.0978, \"Liveness\": 0.351, \"Tempo\": 160.048, \"Duration (ms)\": 199758.0, \"Valence\": 0.325, \"Chord\": \"D\"}, {\"Index\": 819, \"Highest Charting Position\": 88, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"thank u, next\", \"Streams\": 5079328, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3e9HZxeyfWwjeyPAMmWSSQ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-02-08\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.717, \"Energy\": 0.653, \"Loudness\": -5.634, \"Speechiness\": 0.0658, \"Acousticness\": 0.229, \"Liveness\": 0.101, \"Tempo\": 106.966, \"Duration (ms)\": 207320.0, \"Valence\": 0.412, \"Chord\": \"C#/Db\"}, {\"Index\": 820, \"Highest Charting Position\": 19, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"MAMACITA\", \"Streams\": 5016343, \"Artist\": \"Black Eyed Peas, Ozuna, J. Rey Soul\", \"Artist Followers\": 5966748.0, \"Song ID\": \"14wf185UxfNbSy8dwt4r4q\", \"Genre\": \"['dance pop', 'pop', 'pop rap']\", \"Release Date\": \"2020-04-10\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 74.0, \"Danceability\": 0.894, \"Energy\": 0.635, \"Loudness\": -6.929, \"Speechiness\": 0.0473, \"Acousticness\": 0.193, \"Liveness\": 0.0823, \"Tempo\": 105.013, \"Duration (ms)\": 249143.0, \"Valence\": 0.428, \"Chord\": \"D\"}, {\"Index\": 821, \"Highest Charting Position\": 137, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Fake\", \"Streams\": 5010179, \"Artist\": \"Lauv, Conan Gray\", \"Artist Followers\": 4442273.0, \"Song ID\": \"4Gt2kh3QbAGU6yquOWn4aW\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-13\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 73.0, \"Danceability\": 0.703, \"Energy\": 0.657, \"Loudness\": -5.363, \"Speechiness\": 0.0783, \"Acousticness\": 0.139, \"Liveness\": 0.093, \"Tempo\": 82.96, \"Duration (ms)\": 146375.0, \"Valence\": 0.455, \"Chord\": \"E\"}, {\"Index\": 822, \"Highest Charting Position\": 56, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"OK Not To Be OK\", \"Streams\": 4980744, \"Artist\": \"Marshmello, Demi Lovato\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6PiO7fUEPKnJfaCQbPrIyg\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 0.0, \"Danceability\": 0.743, \"Energy\": 0.837, \"Loudness\": -5.025, \"Speechiness\": 0.0649, \"Acousticness\": 0.0172, \"Liveness\": 0.0743, \"Tempo\": 103.072, \"Duration (ms)\": 159863.0, \"Valence\": 0.263, \"Chord\": \"C#/Db\"}, {\"Index\": 823, \"Highest Charting Position\": 1, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"THE SCOTTS\", \"Streams\": 4941592, \"Artist\": \"THE SCOTTS, Travis Scott, Kid Cudi\", \"Artist Followers\": 179193.0, \"Song ID\": \"39Yp9wwQiSRIDOvrVg7mbk\", \"Genre\": \"['pop rap']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 79.0, \"Danceability\": 0.716, \"Energy\": 0.537, \"Loudness\": -7.648, \"Speechiness\": 0.0514, \"Acousticness\": 0.233, \"Liveness\": 0.157, \"Tempo\": 129.979, \"Duration (ms)\": 165978.0, \"Valence\": 0.28, \"Chord\": \"C\"}, {\"Index\": 824, \"Highest Charting Position\": 37, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Mamichula - con Nicki Nicole\", \"Streams\": 4817969, \"Artist\": \"Trueno, Bizarrap, Taiu, TATOOL\", \"Artist Followers\": 2172969.0, \"Song ID\": \"0TUW9faHNaBmi89wsYGp9y\", \"Genre\": \"['argentine hip hop', 'trap argentino', 'trap latino']\", \"Release Date\": \"2020-07-23\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 75.0, \"Danceability\": 0.696, \"Energy\": 0.678, \"Loudness\": -5.893, \"Speechiness\": 0.0735, \"Acousticness\": 0.582, \"Liveness\": 0.134, \"Tempo\": 91.985, \"Duration (ms)\": 219202.0, \"Valence\": 0.346, \"Chord\": \"E\"}, {\"Index\": 825, \"Highest Charting Position\": 172, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Let Her Go\", \"Streams\": 4765198, \"Artist\": \"Passenger\", \"Artist Followers\": 2819406.0, \"Song ID\": \"0JmiBCpWc1IAc0et7Xm7FL\", \"Genre\": \"['folk-pop', 'neo mellow', 'pop', 'pop rock']\", \"Release Date\": \"2013-02-17\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 75.0, \"Danceability\": 0.479, \"Energy\": 0.545, \"Loudness\": -7.346, \"Speechiness\": 0.0688, \"Acousticness\": 0.365, \"Liveness\": 0.0963, \"Tempo\": 74.897, \"Duration (ms)\": 252733.0, \"Valence\": 0.243, \"Chord\": \"G\"}, {\"Index\": 826, \"Highest Charting Position\": 26, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Play Date\", \"Streams\": 4745568, \"Artist\": \"Melanie Martinez\", \"Artist Followers\": 10925614.0, \"Song ID\": \"4DpNNXFMMxQEKl7r0ykkWA\", \"Genre\": \"['alt z', 'electropop', 'modern rock', 'pop']\", \"Release Date\": \"2015-08-14\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 80.0, \"Danceability\": 0.68, \"Energy\": 0.729, \"Loudness\": -5.077, \"Speechiness\": 0.0475, \"Acousticness\": 0.612, \"Liveness\": 0.224, \"Tempo\": 123.97, \"Duration (ms)\": 179867.0, \"Valence\": 0.446, \"Chord\": \"F\"}, {\"Index\": 827, \"Highest Charting Position\": 32, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Lose Somebody\", \"Streams\": 4709053, \"Artist\": \"Kygo, OneRepublic\", \"Artist Followers\": 7593792.0, \"Song ID\": \"1sgDyuLooyvEML4oHspNza\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 75.0, \"Danceability\": 0.58, \"Energy\": 0.586, \"Loudness\": -6.883, \"Speechiness\": 0.0357, \"Acousticness\": 0.344, \"Liveness\": 0.0755, \"Tempo\": 147.988, \"Duration (ms)\": 199549.0, \"Valence\": 0.507, \"Chord\": \"C#/Db\"}, {\"Index\": 828, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Someone Like You\", \"Streams\": 4703672, \"Artist\": \"Adele\", \"Artist Followers\": 28335338.0, \"Song ID\": \"1zwMYTA5nlNjZxYrvBB2pV\", \"Genre\": \"['british soul', 'pop', 'pop soul', 'uk pop']\", \"Release Date\": \"2011-01-24\", \"Weeks Charted\": \"2020-10-23--2020-10-30\", \"Popularity\": 77.0, \"Danceability\": 0.556, \"Energy\": 0.319, \"Loudness\": -8.251, \"Speechiness\": 0.0281, \"Acousticness\": 0.893, \"Liveness\": 0.0996, \"Tempo\": 135.187, \"Duration (ms)\": 285240.0, \"Valence\": 0.294, \"Chord\": \"A\"}, {\"Index\": 829, \"Highest Charting Position\": 73, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"It's You\", \"Streams\": 4674658, \"Artist\": \"Ali Gatie\", \"Artist Followers\": 1758300.0, \"Song ID\": \"5DqdesEfbRyOlSS3Tf6c29\", \"Genre\": \"['canadian hip hop', 'pop']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.732, \"Energy\": 0.463, \"Loudness\": -6.972, \"Speechiness\": 0.0287, \"Acousticness\": 0.374, \"Liveness\": 0.194, \"Tempo\": 95.971, \"Duration (ms)\": 212607.0, \"Valence\": 0.397, \"Chord\": \"B\"}, {\"Index\": 830, \"Highest Charting Position\": 68, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Stunnin' (feat. Harm Franklin)\", \"Streams\": 5183246, \"Artist\": \"Curtis Waters\", \"Artist Followers\": 68875.0, \"Song ID\": \"2JSmxLqt8h7ZpJJkfuLJvK\", \"Genre\": \"[]\", \"Release Date\": \"2020-10-09\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 68.0, \"Danceability\": 0.885, \"Energy\": 0.685, \"Loudness\": -6.429, \"Speechiness\": 0.0627, \"Acousticness\": 0.33, \"Liveness\": 0.148, \"Tempo\": 99.954, \"Duration (ms)\": 144000.0, \"Valence\": 0.937, \"Chord\": \"B\"}, {\"Index\": 831, \"Highest Charting Position\": 35, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Love To Hate Me\", \"Streams\": 5125708, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"7iKDsPfLT0d5mu2htfMKBZ\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 69.0, \"Danceability\": 0.686, \"Energy\": 0.64, \"Loudness\": -5.491, \"Speechiness\": 0.159, \"Acousticness\": 0.0334, \"Liveness\": 0.0801, \"Tempo\": 162.225, \"Duration (ms)\": 171798.0, \"Valence\": 0.597, \"Chord\": \"G#/Ab\"}, {\"Index\": 832, \"Highest Charting Position\": 165, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Hate The Way (feat. blackbear)\", \"Streams\": 5116071, \"Artist\": \"G-Eazy\", \"Artist Followers\": 4894656.0, \"Song ID\": \"3QGppKBPd9gHOgHJzRbVIw\", \"Genre\": \"['hip hop', 'indie pop rap', 'oakland hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2020-10-16--2020-10-23\", \"Popularity\": 68.0, \"Danceability\": 0.569, \"Energy\": 0.865, \"Loudness\": -3.844, \"Speechiness\": 0.266, \"Acousticness\": 0.0673, \"Liveness\": 0.312, \"Tempo\": 82.011, \"Duration (ms)\": 214363.0, \"Valence\": 0.361, \"Chord\": \"E\"}, {\"Index\": 833, \"Highest Charting Position\": 89, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Bande organis\\u00e9e\", \"Streams\": 5112572, \"Artist\": \"13 Organis\\u00e9, SCH, Kofs, Jul, Naps, Soso Maness, Elams, Solda, Houari\", \"Artist Followers\": 249910.0, \"Song ID\": \"205HNJ73cgpC0LAOnuQiWT\", \"Genre\": \"['french hip hop', 'pop urbaine', 'rap francais', 'rap marseille']\", \"Release Date\": \"2020-08-15\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 72.0, \"Danceability\": 0.901, \"Energy\": 0.939, \"Loudness\": -2.762, \"Speechiness\": 0.274, \"Acousticness\": 0.117, \"Liveness\": 0.0643, \"Tempo\": 142.948, \"Duration (ms)\": 356347.0, \"Valence\": 0.805, \"Chord\": \"F#/Gb\"}, {\"Index\": 834, \"Highest Charting Position\": 32, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Crazy Over You\", \"Streams\": 5056387, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"7qq0EOPW4RRlqdvMBmdd73\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 68.0, \"Danceability\": 0.804, \"Energy\": 0.633, \"Loudness\": -6.186, \"Speechiness\": 0.0612, \"Acousticness\": 0.0371, \"Liveness\": 0.102, \"Tempo\": 115.002, \"Duration (ms)\": 163946.0, \"Valence\": 0.67, \"Chord\": \"E\"}, {\"Index\": 835, \"Highest Charting Position\": 109, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Baby, I'm Jealous (feat. Doja Cat)\", \"Streams\": 4870203, \"Artist\": \"Bebe Rexha\", \"Artist Followers\": 6569150.0, \"Song ID\": \"2fTdRdN73RgIgcUZN33dvt\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-09\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 69.0, \"Danceability\": 0.737, \"Energy\": 0.867, \"Loudness\": -2.259, \"Speechiness\": 0.0458, \"Acousticness\": 0.0398, \"Liveness\": 0.32, \"Tempo\": 98.05, \"Duration (ms)\": 175873.0, \"Valence\": 0.506, \"Chord\": \"B\"}, {\"Index\": 836, \"Highest Charting Position\": 15, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"TKN (feat. Travis Scott)\", \"Streams\": 4752289, \"Artist\": \"ROSAL\\u00cdA\", \"Artist Followers\": 4769627.0, \"Song ID\": \"4w47S36wQGBhGg073q3nt7\", \"Genre\": \"['r&b en espanol']\", \"Release Date\": \"2020-05-28\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 75.0, \"Danceability\": 0.776, \"Energy\": 0.509, \"Loudness\": -6.266, \"Speechiness\": 0.467, \"Acousticness\": 0.192, \"Liveness\": 0.115, \"Tempo\": 94.634, \"Duration (ms)\": 129371.0, \"Valence\": 0.485, \"Chord\": \"C\"}, {\"Index\": 837, \"Highest Charting Position\": 135, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"El Mismo Aire - con Pablo Albor\\u00e1n\", \"Streams\": 4705484, \"Artist\": \"Camilo\", \"Artist Followers\": 10580764.0, \"Song ID\": \"5EbtodsuLbxrFDH6j5avVS\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-06-10\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 75.0, \"Danceability\": 0.483, \"Energy\": 0.492, \"Loudness\": -6.591, \"Speechiness\": 0.295, \"Acousticness\": 0.603, \"Liveness\": 0.323, \"Tempo\": 144.511, \"Duration (ms)\": 188213.0, \"Valence\": 0.66, \"Chord\": \"C\"}, {\"Index\": 838, \"Highest Charting Position\": 18, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Yo Perreo Sola\", \"Streams\": 4680447, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0SqqAgdovOE24BzxIClpjw\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 78.0, \"Danceability\": 0.86, \"Energy\": 0.758, \"Loudness\": -5.16, \"Speechiness\": 0.0695, \"Acousticness\": 0.021, \"Liveness\": 0.344, \"Tempo\": 97.014, \"Duration (ms)\": 172127.0, \"Valence\": 0.453, \"Chord\": \"B\"}, {\"Index\": 839, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Let Me Love You Like A Woman\", \"Streams\": 4665053, \"Artist\": \"Lana Del Rey\", \"Artist Followers\": 13697048.0, \"Song ID\": \"1gxdWpeOUBpvB908fiZs4D\", \"Genre\": \"['art pop', 'pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2020-10-16--2020-10-23\", \"Popularity\": 67.0, \"Danceability\": 0.303, \"Energy\": 0.249, \"Loudness\": -11.715, \"Speechiness\": 0.111, \"Acousticness\": 0.97, \"Liveness\": 0.117, \"Tempo\": 66.932, \"Duration (ms)\": 200661.0, \"Valence\": 0.131, \"Chord\": \"C\"}, {\"Index\": 840, \"Highest Charting Position\": 69, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"DOLLAZ ON MY HEAD (feat. Young Thug)\", \"Streams\": 4652712, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"3nS9a01VvXHQriLqJYwRqG\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 76.0, \"Danceability\": 0.825, \"Energy\": 0.458, \"Loudness\": -7.47, \"Speechiness\": 0.0577, \"Acousticness\": 0.114, \"Liveness\": 0.102, \"Tempo\": 145.115, \"Duration (ms)\": 197760.0, \"Valence\": 0.161, \"Chord\": \"C\"}, {\"Index\": 841, \"Highest Charting Position\": 54, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Eleg\\u00ed (feat. D\\u00edmelo Flow)\", \"Streams\": 4607003, \"Artist\": \"Rauw Alejandro, Dalex, Lenny Tav\\u00e1rez\", \"Artist Followers\": 6096559.0, \"Song ID\": \"50ZC4PM7hywH27RcCfViau\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-03-26\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 75.0, \"Danceability\": 0.824, \"Energy\": 0.631, \"Loudness\": -2.791, \"Speechiness\": 0.0809, \"Acousticness\": 0.237, \"Liveness\": 0.0531, \"Tempo\": 171.965, \"Duration (ms)\": 197721.0, \"Valence\": 0.678, \"Chord\": \"C\"}, {\"Index\": 842, \"Highest Charting Position\": 77, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"July\", \"Streams\": 4598766, \"Artist\": \"Noah Cyrus\", \"Artist Followers\": 891555.0, \"Song ID\": \"6J2LdBN97cDWn0MLxYh9HB\", \"Genre\": \"['alt z', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.708, \"Energy\": 0.186, \"Loudness\": -8.953, \"Speechiness\": 0.042, \"Acousticness\": 0.868, \"Liveness\": 0.0779, \"Tempo\": 72.541, \"Duration (ms)\": 156106.0, \"Valence\": 0.322, \"Chord\": \"A\"}, {\"Index\": 843, \"Highest Charting Position\": 93, \"Number of Times Charted\": 38, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Bruises\", \"Streams\": 4560503, \"Artist\": \"Lewis Capaldi\", \"Artist Followers\": 8388838.0, \"Song ID\": \"4Of7rzpRpV1mWRbhp5rAqG\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.736, \"Energy\": 0.308, \"Loudness\": -7.83, \"Speechiness\": 0.0677, \"Acousticness\": 0.946, \"Liveness\": 0.186, \"Tempo\": 111.202, \"Duration (ms)\": 220492.0, \"Valence\": 0.361, \"Chord\": \"E\"}, {\"Index\": 844, \"Highest Charting Position\": 46, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"You Never Know\", \"Streams\": 5304382, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"3b7trEcKoglybN5MxGuSaw\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2021-08-03\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 54.0, \"Danceability\": 0.535, \"Energy\": 0.434, \"Loudness\": -5.768, \"Speechiness\": 0.0505, \"Acousticness\": 0.405, \"Liveness\": 0.253, \"Tempo\": 144.497, \"Duration (ms)\": 229236.0, \"Valence\": 0.271, \"Chord\": \"F\"}, {\"Index\": 845, \"Highest Charting Position\": 12, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Supalonely\", \"Streams\": 5089970, \"Artist\": \"BENEE, Gus Dapperton\", \"Artist Followers\": 638337.0, \"Song ID\": \"4nK5YrxbMGZstTLbvj6Gxw\", \"Genre\": \"['alt z', 'nz pop', 'pop']\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 77.0, \"Danceability\": 0.863, \"Energy\": 0.631, \"Loudness\": -4.689, \"Speechiness\": 0.0534, \"Acousticness\": 0.305, \"Liveness\": 0.123, \"Tempo\": 128.977, \"Duration (ms)\": 223480.0, \"Valence\": 0.817, \"Chord\": \"G\"}, {\"Index\": 846, \"Highest Charting Position\": 53, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Glock In My Lap\", \"Streams\": 4947593, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"6pcywuOeGGWeOQzdUyti6k\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 69.0, \"Danceability\": 0.847, \"Energy\": 0.733, \"Loudness\": -6.439, \"Speechiness\": 0.16, \"Acousticness\": 0.00574, \"Liveness\": 0.151, \"Tempo\": 130.029, \"Duration (ms)\": 193591.0, \"Valence\": 0.202, \"Chord\": \"A#/Bb\"}, {\"Index\": 847, \"Highest Charting Position\": 49, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Better\", \"Streams\": 4933462, \"Artist\": \"ZAYN\", \"Artist Followers\": 16655692.0, \"Song ID\": \"1dLXLETYiZohIZWnse4ypG\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-01-03--2020-01-10\", \"Popularity\": 68.0, \"Danceability\": 0.637, \"Energy\": 0.418, \"Loudness\": -7.137, \"Speechiness\": 0.301, \"Acousticness\": 0.353, \"Liveness\": 0.131, \"Tempo\": 84.295, \"Duration (ms)\": 174517.0, \"Valence\": 0.0807, \"Chord\": \"D\"}, {\"Index\": 848, \"Highest Charting Position\": 59, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"forget me too (feat. Halsey)\", \"Streams\": 4751756, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3868320.0, \"Song ID\": \"1VSuFS7PahCN3SWbOcQ98m\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 78.0, \"Danceability\": 0.654, \"Energy\": 0.875, \"Loudness\": -4.845, \"Speechiness\": 0.0744, \"Acousticness\": 0.000417, \"Liveness\": 0.194, \"Tempo\": 99.975, \"Duration (ms)\": 171621.0, \"Valence\": 0.522, \"Chord\": \"C#/Db\"}, {\"Index\": 849, \"Highest Charting Position\": 110, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Oh Juliana\", \"Streams\": 4751064, \"Artist\": \"Niack\", \"Artist Followers\": 352402.0, \"Song ID\": \"4xWzZmX4K1yyrdtRfbUvjt\", \"Genre\": \"['funk carioca']\", \"Release Date\": \"2020-06-30\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 66.0, \"Danceability\": 0.799, \"Energy\": 0.568, \"Loudness\": -3.089, \"Speechiness\": 0.25, \"Acousticness\": 0.387, \"Liveness\": 0.0892, \"Tempo\": 129.63, \"Duration (ms)\": 153078.0, \"Valence\": 0.963, \"Chord\": \"F#/Gb\"}, {\"Index\": 850, \"Highest Charting Position\": 81, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"PORFA Remix ( Feat. Maluma, Nicky Jam, Sech) - Remix\", \"Streams\": 4727923, \"Artist\": \"Feid, J Balvin, Justin Quiles\", \"Artist Followers\": 613348.0, \"Song ID\": \"7lUdbnz7wsv3C9zzf4WHl9\", \"Genre\": \"['colombian pop', 'latin', 'pop reggaeton', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 70.0, \"Danceability\": 0.793, \"Energy\": 0.737, \"Loudness\": -4.731, \"Speechiness\": 0.0785, \"Acousticness\": 0.0765, \"Liveness\": 0.0747, \"Tempo\": 167.969, \"Duration (ms)\": 333800.0, \"Valence\": 0.697, \"Chord\": \"F#/Gb\"}, {\"Index\": 851, \"Highest Charting Position\": 108, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"No Guidance (feat. Drake)\", \"Streams\": 4641393, \"Artist\": \"Chris Brown\", \"Artist Followers\": 14073083.0, \"Song ID\": \"6XHVuErjQ4XNm6nDPVCxVX\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'r&b', 'rap']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.696, \"Energy\": 0.454, \"Loudness\": -6.756, \"Speechiness\": 0.153, \"Acousticness\": 0.123, \"Liveness\": 0.155, \"Tempo\": 92.928, \"Duration (ms)\": 260640.0, \"Valence\": 0.136, \"Chord\": \"C#/Db\"}, {\"Index\": 852, \"Highest Charting Position\": 65, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Rich Nigga Shit (feat. Young Thug)\", \"Streams\": 9129562, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"3ruoIF2UnoXdzK8mR61ebq\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 73.0, \"Danceability\": 0.825, \"Energy\": 0.733, \"Loudness\": -5.625, \"Speechiness\": 0.0969, \"Acousticness\": 0.349, \"Liveness\": 0.112, \"Tempo\": 97.974, \"Duration (ms)\": 190331.0, \"Valence\": 0.62, \"Chord\": \"C#/Db\"}, {\"Index\": 853, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Many Men\", \"Streams\": 8675173, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"3CDVMejYHnB1SkEEx0T1N4\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 65.0, \"Danceability\": 0.635, \"Energy\": 0.793, \"Loudness\": -4.333, \"Speechiness\": 0.0322, \"Acousticness\": 0.000647, \"Liveness\": 0.113, \"Tempo\": 77.594, \"Duration (ms)\": 201856.0, \"Valence\": 0.281, \"Chord\": \"A#/Bb\"}, {\"Index\": 854, \"Highest Charting Position\": 77, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Slidin\", \"Streams\": 8243488, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"7fxSLnklnayJNBIKntXedZ\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 64.0, \"Danceability\": 0.774, \"Energy\": 0.706, \"Loudness\": -6.494, \"Speechiness\": 0.355, \"Acousticness\": 0.00163, \"Liveness\": 0.104, \"Tempo\": 152.891, \"Duration (ms)\": 185037.0, \"Valence\": 0.382, \"Chord\": \"D\"}, {\"Index\": 855, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Outta Time (feat. Drake)\", \"Streams\": 7762934, \"Artist\": \"Bryson Tiller\", \"Artist Followers\": 5019909.0, \"Song ID\": \"4SCnCPOUOUXUmCX2uHb3r7\", \"Genre\": \"['kentucky hip hop', 'pop', 'pop rap', 'r&b', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 68.0, \"Danceability\": 0.714, \"Energy\": 0.582, \"Loudness\": -7.272, \"Speechiness\": 0.0808, \"Acousticness\": 0.0129, \"Liveness\": 0.0774, \"Tempo\": 92.819, \"Duration (ms)\": 198822.0, \"Valence\": 0.338, \"Chord\": \"F\"}, {\"Index\": 856, \"Highest Charting Position\": 131, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"My Dawg\", \"Streams\": 6029118, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"42Tohunwlh34o0mgxYx5iq\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 60.0, \"Danceability\": 0.831, \"Energy\": 0.532, \"Loudness\": -5.319, \"Speechiness\": 0.301, \"Acousticness\": 0.0652, \"Liveness\": 0.464, \"Tempo\": 140.105, \"Duration (ms)\": 181716.0, \"Valence\": 0.364, \"Chord\": \"C\"}, {\"Index\": 857, \"Highest Charting Position\": 138, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Snitches & Rats (feat. Young Nudy)\", \"Streams\": 5846760, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"3WaDoMDQRqDdgtCDLxanpN\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 57.0, \"Danceability\": 0.821, \"Energy\": 0.671, \"Loudness\": -5.893, \"Speechiness\": 0.18, \"Acousticness\": 0.00843, \"Liveness\": 0.0972, \"Tempo\": 145.953, \"Duration (ms)\": 187773.0, \"Valence\": 0.494, \"Chord\": \"A\"}, {\"Index\": 858, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Brand New Draco\", \"Streams\": 5841110, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"4V9ynsDPwHtdItksqjuRu0\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 63.0, \"Danceability\": 0.697, \"Energy\": 0.709, \"Loudness\": -6.642, \"Speechiness\": 0.298, \"Acousticness\": 0.041, \"Liveness\": 0.0886, \"Tempo\": 155.023, \"Duration (ms)\": 202420.0, \"Valence\": 0.439, \"Chord\": \"B\"}, {\"Index\": 859, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Lemonade (Feat. Roddy Ricch & Don Toliver) [Remix]\", \"Streams\": 5550390, \"Artist\": \"Internet Money\", \"Artist Followers\": 412466.0, \"Song ID\": \"5sBplhIrmzA4kQGyIOpmDf\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-09-30\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 69.0, \"Danceability\": 0.832, \"Energy\": 0.549, \"Loudness\": -8.259, \"Speechiness\": 0.0602, \"Acousticness\": 0.168, \"Liveness\": 0.11, \"Tempo\": 140.045, \"Duration (ms)\": 181496.0, \"Valence\": 0.384, \"Chord\": \"C#/Db\"}, {\"Index\": 860, \"Highest Charting Position\": 77, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Your Man\", \"Streams\": 5233336, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"6Vgtvd7I5yopJdBuxqjBd2\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-24\", \"Weeks Charted\": \"2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 68.0, \"Danceability\": 0.785, \"Energy\": 0.818, \"Loudness\": -8.711, \"Speechiness\": 0.099, \"Acousticness\": 0.624, \"Liveness\": 0.149, \"Tempo\": 117.98, \"Duration (ms)\": 163759.0, \"Valence\": 0.0503, \"Chord\": \"G\"}, {\"Index\": 861, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"No Opp Left Behind\", \"Streams\": 5154955, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"50I7FNN2rl2rWiNwGxS146\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 61.0, \"Danceability\": 0.823, \"Energy\": 0.703, \"Loudness\": -2.691, \"Speechiness\": 0.298, \"Acousticness\": 0.0161, \"Liveness\": 0.294, \"Tempo\": 178.043, \"Duration (ms)\": 194214.0, \"Valence\": 0.26, \"Chord\": \"G#/Ab\"}, {\"Index\": 862, \"Highest Charting Position\": 106, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Lets Link\", \"Streams\": 5109038, \"Artist\": \"WhoHeem\", \"Artist Followers\": 25417.0, \"Song ID\": \"6fMzgFFGzWCwiHMzDzNpp5\", \"Genre\": \"['viral rap']\", \"Release Date\": \"2020-08-20\", \"Weeks Charted\": \"2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 61.0, \"Danceability\": 0.839, \"Energy\": 0.683, \"Loudness\": -9.232, \"Speechiness\": 0.165, \"Acousticness\": 0.00667, \"Liveness\": 0.241, \"Tempo\": 120.003, \"Duration (ms)\": 159955.0, \"Valence\": 0.522, \"Chord\": \"A#/Bb\"}, {\"Index\": 863, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"RIP Luv\", \"Streams\": 4915080, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"1wGnp7ejkCuXRsehXx0PNP\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 62.0, \"Danceability\": 0.63, \"Energy\": 0.399, \"Loudness\": -9.869, \"Speechiness\": 0.178, \"Acousticness\": 0.105, \"Liveness\": 0.234, \"Tempo\": 183.016, \"Duration (ms)\": 214192.0, \"Valence\": 0.0657, \"Chord\": \"F\"}, {\"Index\": 864, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Steppin On Niggas\", \"Streams\": 4853661, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"7FtZFla3ZH6PqsAJ9MvVCM\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 57.0, \"Danceability\": 0.849, \"Energy\": 0.635, \"Loudness\": -4.068, \"Speechiness\": 0.254, \"Acousticness\": 0.000608, \"Liveness\": 0.062, \"Tempo\": 89.484, \"Duration (ms)\": 140833.0, \"Valence\": 0.798, \"Chord\": \"G\"}, {\"Index\": 865, \"Highest Charting Position\": 58, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Gimme Love\", \"Streams\": 7471309, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"2hfoyc7ve6xM4ZEiNIiU1B\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-04-16\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 69.0, \"Danceability\": 0.482, \"Energy\": 0.631, \"Loudness\": -6.917, \"Speechiness\": 0.0986, \"Acousticness\": 0.696, \"Liveness\": 0.209, \"Tempo\": 126.576, \"Duration (ms)\": 214558.0, \"Valence\": 0.0743, \"Chord\": \"F\"}, {\"Index\": 866, \"Highest Charting Position\": 97, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Ew\", \"Streams\": 6936305, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"7xcUWyLh6fIMsYjoVI7NnZ\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 67.0, \"Danceability\": 0.48, \"Energy\": 0.373, \"Loudness\": -9.297, \"Speechiness\": 0.0278, \"Acousticness\": 0.804, \"Liveness\": 0.12, \"Tempo\": 114.078, \"Duration (ms)\": 207710.0, \"Valence\": 0.0376, \"Chord\": \"A#/Bb\"}, {\"Index\": 867, \"Highest Charting Position\": 99, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Daylight\", \"Streams\": 6819838, \"Artist\": \"Joji, Diplo\", \"Artist Followers\": 4759367.0, \"Song ID\": \"6Ed1q0X8oSKSm4IIhiQbYg\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-08-06\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-08-07--2020-08-14\", \"Popularity\": 72.0, \"Danceability\": 0.528, \"Energy\": 0.749, \"Loudness\": -7.571, \"Speechiness\": 0.0479, \"Acousticness\": 0.00488, \"Liveness\": 0.0949, \"Tempo\": 163.944, \"Duration (ms)\": 163906.0, \"Valence\": 0.729, \"Chord\": \"G\"}, {\"Index\": 868, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Epidemic\", \"Streams\": 6292620, \"Artist\": \"Polo G\", \"Artist Followers\": 4849204.0, \"Song ID\": \"170DNUSnQRp1tGpppF26pA\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 71.0, \"Danceability\": 0.616, \"Energy\": 0.617, \"Loudness\": -8.431, \"Speechiness\": 0.52, \"Acousticness\": 0.128, \"Liveness\": 0.177, \"Tempo\": 175.929, \"Duration (ms)\": 177273.0, \"Valence\": 0.476, \"Chord\": \"C#/Db\"}, {\"Index\": 869, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"bloody valentine\", \"Streams\": 6032935, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3868320.0, \"Song ID\": \"6mADjHs6FXdroPzEGW6KVJ\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 77.0, \"Danceability\": 0.533, \"Energy\": 0.858, \"Loudness\": -4.212, \"Speechiness\": 0.0766, \"Acousticness\": 0.00021, \"Liveness\": 0.148, \"Tempo\": 160.057, \"Duration (ms)\": 205159.0, \"Valence\": 0.506, \"Chord\": \"D\"}, {\"Index\": 870, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"MODUS\", \"Streams\": 6013371, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"5SjtAe7xzUgHDtNTmt8zS7\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 66.0, \"Danceability\": 0.738, \"Energy\": 0.533, \"Loudness\": -7.617, \"Speechiness\": 0.0492, \"Acousticness\": 0.183, \"Liveness\": 0.115, \"Tempo\": 132.008, \"Duration (ms)\": 207265.0, \"Valence\": 0.262, \"Chord\": \"G\"}, {\"Index\": 871, \"Highest Charting Position\": 145, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Tick Tock\", \"Streams\": 5547939, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"5E7p95xh9Ul4vZp4LEoJwi\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 65.0, \"Danceability\": 0.781, \"Energy\": 0.613, \"Loudness\": -5.582, \"Speechiness\": 0.0524, \"Acousticness\": 0.0399, \"Liveness\": 0.0976, \"Tempo\": 80.53, \"Duration (ms)\": 132215.0, \"Valence\": 0.613, \"Chord\": \"E\"}, {\"Index\": 872, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Sanctuary\", \"Streams\": 5482390, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"3xaugmCyXrVkrDTXbFkMW3\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2019-06-14\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 69.0, \"Danceability\": 0.552, \"Energy\": 0.65, \"Loudness\": -7.199, \"Speechiness\": 0.128, \"Acousticness\": 0.422, \"Liveness\": 0.372, \"Tempo\": 167.788, \"Duration (ms)\": 180019.0, \"Valence\": 0.316, \"Chord\": \"C#/Db\"}, {\"Index\": 873, \"Highest Charting Position\": 112, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"feel something\", \"Streams\": 5463424, \"Artist\": \"Bea Miller\", \"Artist Followers\": 2396662.0, \"Song ID\": \"7JDWhC422Gtk1Bq0mL3OTC\", \"Genre\": \"['alt z', 'dance pop', 'electropop', 'indie cafe pop', 'indie poptimism', 'modern rock', 'pop', 'pop rap', 'post-teen pop', 'talent show']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 75.0, \"Danceability\": 0.74, \"Energy\": 0.415, \"Loudness\": -8.914, \"Speechiness\": 0.0707, \"Acousticness\": 0.242, \"Liveness\": 0.319, \"Tempo\": 136.029, \"Duration (ms)\": 180161.0, \"Valence\": 0.156, \"Chord\": \"C\"}, {\"Index\": 874, \"Highest Charting Position\": 86, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Tap In\", \"Streams\": 5220309, \"Artist\": \"Saweetie\", \"Artist Followers\": 1255573.0, \"Song ID\": \"4Hpib09wXgD84w4uwTPnYD\", \"Genre\": \"['cali rap', 'dance pop', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-06-17\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 73.0, \"Danceability\": 0.954, \"Energy\": 0.696, \"Loudness\": -7.117, \"Speechiness\": 0.204, \"Acousticness\": 0.00576, \"Liveness\": 0.0754, \"Tempo\": 100.036, \"Duration (ms)\": 139413.0, \"Valence\": 0.432, \"Chord\": \"A#/Bb\"}, {\"Index\": 875, \"Highest Charting Position\": 171, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Pretty Boy (feat. Lil Yachty)\", \"Streams\": 5141212, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"0f1G5SHFoFC9lO03gHCGVS\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 66.0, \"Danceability\": 0.656, \"Energy\": 0.776, \"Loudness\": -6.184, \"Speechiness\": 0.0672, \"Acousticness\": 0.16, \"Liveness\": 0.372, \"Tempo\": 156.049, \"Duration (ms)\": 156759.0, \"Valence\": 0.638, \"Chord\": \"F#/Gb\"}, {\"Index\": 876, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Afterthought\", \"Streams\": 4977405, \"Artist\": \"Joji, BENEE\", \"Artist Followers\": 4759367.0, \"Song ID\": \"6zvqq50PL7io0rprbkrYc9\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 67.0, \"Danceability\": 0.668, \"Energy\": 0.547, \"Loudness\": -8.024, \"Speechiness\": 0.0353, \"Acousticness\": 0.398, \"Liveness\": 0.0931, \"Tempo\": 83.5, \"Duration (ms)\": 194871.0, \"Valence\": 0.192, \"Chord\": \"C#/Db\"}, {\"Index\": 877, \"Highest Charting Position\": 164, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"+Linda\", \"Streams\": 4964708, \"Artist\": \"Dalex\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-08-28--2020-09-04\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 878, \"Highest Charting Position\": 24, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Over Now (with The Weeknd)\", \"Streams\": 4867620, \"Artist\": \"Calvin Harris\", \"Artist Followers\": 21946934.0, \"Song ID\": \"58AGoOGbwsQMhBbH0eFLRR\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'house', 'pop', 'progressive house', 'uk dance']\", \"Release Date\": \"2020-08-28\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 72.0, \"Danceability\": 0.612, \"Energy\": 0.884, \"Loudness\": -4.113, \"Speechiness\": 0.0454, \"Acousticness\": 0.0759, \"Liveness\": 0.247, \"Tempo\": 178.043, \"Duration (ms)\": 210795.0, \"Valence\": 0.679, \"Chord\": \"E\"}, {\"Index\": 879, \"Highest Charting Position\": 14, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Hate The Other Side (with Marshmello & The Kid Laroi)\", \"Streams\": 4851997, \"Artist\": \"Juice WRLD, Polo G\", \"Artist Followers\": 19102888.0, \"Song ID\": \"0ada5XsQGLPUVbmTCkAP49\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 78.0, \"Danceability\": 0.701, \"Energy\": 0.65, \"Loudness\": -6.313, \"Speechiness\": 0.104, \"Acousticness\": 0.291, \"Liveness\": 0.112, \"Tempo\": 90.003, \"Duration (ms)\": 160212.0, \"Valence\": 0.647, \"Chord\": \"F#/Gb\"}, {\"Index\": 880, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"drunk face\", \"Streams\": 4834258, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3868320.0, \"Song ID\": \"3k0YJnqMKRZb8swo86vCkq\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 72.0, \"Danceability\": 0.691, \"Energy\": 0.77, \"Loudness\": -4.578, \"Speechiness\": 0.0367, \"Acousticness\": 0.0282, \"Liveness\": 0.497, \"Tempo\": 90.024, \"Duration (ms)\": 143901.0, \"Valence\": 0.344, \"Chord\": \"G\"}, {\"Index\": 881, \"Highest Charting Position\": 76, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Tak Tiki Tak\", \"Streams\": 4761286, \"Artist\": \"Harry Nach\", \"Artist Followers\": 134339.0, \"Song ID\": \"7gwwt1IaAWwmB7af0AcuBM\", \"Genre\": \"['trap chileno', 'trap latino']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\", \"Popularity\": 71.0, \"Danceability\": 0.801, \"Energy\": 0.579, \"Loudness\": -4.78, \"Speechiness\": 0.0813, \"Acousticness\": 0.333, \"Liveness\": 0.172, \"Tempo\": 99.994, \"Duration (ms)\": 212406.0, \"Valence\": 0.231, \"Chord\": \"B\"}, {\"Index\": 882, \"Highest Charting Position\": 26, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"WHATS POPPIN\", \"Streams\": 4745752, \"Artist\": \"Jack Harlow\", \"Artist Followers\": 3828418.0, \"Song ID\": \"2MbdDtCv5LUVjYy9RuGTgC\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-06-24\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 80.0, \"Danceability\": 0.904, \"Energy\": 0.723, \"Loudness\": -5.224, \"Speechiness\": 0.26, \"Acousticness\": 0.0631, \"Liveness\": 0.185, \"Tempo\": 145.013, \"Duration (ms)\": 227478.0, \"Valence\": 0.835, \"Chord\": \"B\"}, {\"Index\": 883, \"Highest Charting Position\": 143, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Money Trees\", \"Streams\": 4632724, \"Artist\": \"Kendrick Lamar, Jay Rock\", \"Artist Followers\": 17931101.0, \"Song ID\": \"2HbKqm4o0w5wEeEFXm2sD4\", \"Genre\": \"['conscious hip hop', 'hip hop', 'rap', 'west coast rap']\", \"Release Date\": \"2012\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 75.0, \"Danceability\": 0.716, \"Energy\": 0.531, \"Loudness\": -7.355, \"Speechiness\": 0.122, \"Acousticness\": 0.0703, \"Liveness\": 0.224, \"Tempo\": 71.994, \"Duration (ms)\": 386907.0, \"Valence\": 0.344, \"Chord\": \"G\"}, {\"Index\": 884, \"Highest Charting Position\": 65, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Blastoff (feat. Juice Wrld & Trippie Redd)\", \"Streams\": 4628159, \"Artist\": \"Internet Money, Diplo\", \"Artist Followers\": 412466.0, \"Song ID\": \"2rFsFjq0D9JAmc0APpCO6P\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-08-29\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 70.0, \"Danceability\": 0.761, \"Energy\": 0.517, \"Loudness\": -6.916, \"Speechiness\": 0.0927, \"Acousticness\": 0.114, \"Liveness\": 0.157, \"Tempo\": 147.912, \"Duration (ms)\": 174730.0, \"Valence\": 0.46, \"Chord\": \"F\"}, {\"Index\": 885, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"September\", \"Streams\": 5329256, \"Artist\": \"Earth, Wind & Fire\", \"Artist Followers\": 3008916.0, \"Song ID\": \"2grjqo0Frpf2okIBiifQKs\", \"Genre\": \"['disco', 'funk', 'jazz funk', 'motown', 'quiet storm', 'soul']\", \"Release Date\": \"1978-11-23\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 80.0, \"Danceability\": 0.697, \"Energy\": 0.832, \"Loudness\": -7.264, \"Speechiness\": 0.0298, \"Acousticness\": 0.168, \"Liveness\": 0.269, \"Tempo\": 125.926, \"Duration (ms)\": 215093.0, \"Valence\": 0.979, \"Chord\": \"A\"}, {\"Index\": 886, \"Highest Charting Position\": 64, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Secrets\", \"Streams\": 5178107, \"Artist\": \"Regard, RAYE\", \"Artist Followers\": 152237.0, \"Song ID\": \"66W1rVTnEv86dIkFhoiElg\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop edm', 'slap house', 'tropical house']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 78.0, \"Danceability\": 0.848, \"Energy\": 0.768, \"Loudness\": -5.386, \"Speechiness\": 0.0373, \"Acousticness\": 0.0412, \"Liveness\": 0.195, \"Tempo\": 118.961, \"Duration (ms)\": 176767.0, \"Valence\": 0.777, \"Chord\": \"F#/Gb\"}, {\"Index\": 887, \"Highest Charting Position\": 150, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"21\", \"Streams\": 5151406, \"Artist\": \"Polo G\", \"Artist Followers\": 4849204.0, \"Song ID\": \"3JKgcAa7r07ocVWcV8bS0H\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 80.0, \"Danceability\": 0.783, \"Energy\": 0.479, \"Loudness\": -10.646, \"Speechiness\": 0.541, \"Acousticness\": 0.149, \"Liveness\": 0.101, \"Tempo\": 176.027, \"Duration (ms)\": 163798.0, \"Valence\": 0.533, \"Chord\": \"G\"}, {\"Index\": 888, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"BXL ZOO\", \"Streams\": 5101640, \"Artist\": \"Damso, Hamza\", \"Artist Followers\": 3071170.0, \"Song ID\": \"1VBt9dPtYfLnVeKaa6CQPr\", \"Genre\": \"['belgian hip hop', 'french hip hop', 'pop urbaine', 'rap belge', 'rap conscient']\", \"Release Date\": \"2021-04-28\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 62.0, \"Danceability\": 0.745, \"Energy\": 0.656, \"Loudness\": -6.829, \"Speechiness\": 0.203, \"Acousticness\": 0.0604, \"Liveness\": 0.11, \"Tempo\": 137.997, \"Duration (ms)\": 201333.0, \"Valence\": 0.405, \"Chord\": \"B\"}, {\"Index\": 889, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"DEUX TOILES DE MER\", \"Streams\": 5094137, \"Artist\": \"Damso\", \"Artist Followers\": 3071170.0, \"Song ID\": \"6vw0mOQ5vm3C5RPm7Rvl2w\", \"Genre\": \"['belgian hip hop', 'french hip hop', 'pop urbaine', 'rap belge', 'rap conscient']\", \"Release Date\": \"2021-04-28\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 62.0, \"Danceability\": 0.521, \"Energy\": 0.39, \"Loudness\": -9.726, \"Speechiness\": 0.128, \"Acousticness\": 0.582, \"Liveness\": 0.112, \"Tempo\": 104.106, \"Duration (ms)\": 315640.0, \"Valence\": 0.157, \"Chord\": \"G#/Ab\"}, {\"Index\": 890, \"Highest Charting Position\": 4, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"exile (feat. Bon Iver)\", \"Streams\": 4924533, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"4pvb0WLRcMtbPGmtejJJ6y\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 77.0, \"Danceability\": 0.298, \"Energy\": 0.38, \"Loudness\": -8.426, \"Speechiness\": 0.0287, \"Acousticness\": 0.778, \"Liveness\": 0.11, \"Tempo\": 75.602, \"Duration (ms)\": 285634.0, \"Valence\": 0.152, \"Chord\": \"F#/Gb\"}, {\"Index\": 891, \"Highest Charting Position\": 10, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Righteous\", \"Streams\": 4819362, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5dOxHHMOFAbG3VH23t0xNm\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 78.0, \"Danceability\": 0.706, \"Energy\": 0.625, \"Loudness\": -7.426, \"Speechiness\": 0.0314, \"Acousticness\": 0.0417, \"Liveness\": 0.129, \"Tempo\": 142.948, \"Duration (ms)\": 242181.0, \"Valence\": 0.225, \"Chord\": \"C\"}, {\"Index\": 892, \"Highest Charting Position\": 9, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Conversations\", \"Streams\": 4805366, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4K06PO78fW4mnBVenxGNob\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 75.0, \"Danceability\": 0.747, \"Energy\": 0.622, \"Loudness\": -5.825, \"Speechiness\": 0.0838, \"Acousticness\": 0.176, \"Liveness\": 0.151, \"Tempo\": 159.93, \"Duration (ms)\": 181661.0, \"Valence\": 0.57, \"Chord\": \"B\"}, {\"Index\": 893, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Dolly (with Lil Uzi Vert)\", \"Streams\": 4800543, \"Artist\": \"Lil Tecca\", \"Artist Followers\": 4022792.0, \"Song ID\": \"77Xwqkw7VrV8E5FCq9JhO8\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 63.0, \"Danceability\": 0.664, \"Energy\": 0.586, \"Loudness\": -7.813, \"Speechiness\": 0.238, \"Acousticness\": 0.212, \"Liveness\": 0.216, \"Tempo\": 88.502, \"Duration (ms)\": 179813.0, \"Valence\": 0.589, \"Chord\": \"G\"}, {\"Index\": 894, \"Highest Charting Position\": 23, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Chicago Freestyle (feat. Giveon)\", \"Streams\": 4799038, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"4wVOKKEHUJxHCFFNUWDn0B\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 80.0, \"Danceability\": 0.735, \"Energy\": 0.449, \"Loudness\": -7.507, \"Speechiness\": 0.347, \"Acousticness\": 0.629, \"Liveness\": 0.113, \"Tempo\": 122.947, \"Duration (ms)\": 220488.0, \"Valence\": 0.0397, \"Chord\": \"A#/Bb\"}, {\"Index\": 895, \"Highest Charting Position\": 4, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"GOOBA\", \"Streams\": 4690955, \"Artist\": \"6ix9ine\", \"Artist Followers\": 6514102.0, \"Song ID\": \"4NhDYoQTYCdWHTvlbGVgwo\", \"Genre\": \"['emo rap', 'rap']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 70.0, \"Danceability\": 0.611, \"Energy\": 0.688, \"Loudness\": -5.688, \"Speechiness\": 0.341, \"Acousticness\": 0.0264, \"Liveness\": 0.251, \"Tempo\": 178.462, \"Duration (ms)\": 132303.0, \"Valence\": 0.393, \"Chord\": \"C#/Db\"}, {\"Index\": 896, \"Highest Charting Position\": 12, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Physical\", \"Streams\": 4599807, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3AzjcOeAmA57TIOr9zF1ZW\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 77.0, \"Danceability\": 0.647, \"Energy\": 0.844, \"Loudness\": -3.756, \"Speechiness\": 0.0457, \"Acousticness\": 0.0137, \"Liveness\": 0.102, \"Tempo\": 146.967, \"Duration (ms)\": 193829.0, \"Valence\": 0.746, \"Chord\": \"C\"}, {\"Index\": 897, \"Highest Charting Position\": 194, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Hot Stuff\", \"Streams\": 4569978, \"Artist\": \"Kygo, Donna Summer\", \"Artist Followers\": 7593792.0, \"Song ID\": \"00ETaeHUQ6lops3oWU1Wrt\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 71.0, \"Danceability\": 0.681, \"Energy\": 0.773, \"Loudness\": -5.749, \"Speechiness\": 0.148, \"Acousticness\": 0.019, \"Liveness\": 0.11, \"Tempo\": 119.961, \"Duration (ms)\": 199008.0, \"Valence\": 0.429, \"Chord\": \"F\"}, {\"Index\": 898, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Who's Laughing Now\", \"Streams\": 4526982, \"Artist\": \"Ava Max\", \"Artist Followers\": 3916979.0, \"Song ID\": \"1Pmp486RrLRkaEkE3HFHXP\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 73.0, \"Danceability\": 0.648, \"Energy\": 0.641, \"Loudness\": -5.521, \"Speechiness\": 0.0389, \"Acousticness\": 0.00565, \"Liveness\": 0.109, \"Tempo\": 184.021, \"Duration (ms)\": 180348.0, \"Valence\": 0.505, \"Chord\": \"G\"}, {\"Index\": 899, \"Highest Charting Position\": 91, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Sweet but Psycho\", \"Streams\": 4502853, \"Artist\": \"Ava Max\", \"Artist Followers\": 3916979.0, \"Song ID\": \"7DnAm9FOTWE3cUvso43HhI\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.72, \"Energy\": 0.706, \"Loudness\": -4.719, \"Speechiness\": 0.0473, \"Acousticness\": 0.0684, \"Liveness\": 0.166, \"Tempo\": 133.002, \"Duration (ms)\": 187436.0, \"Valence\": 0.62, \"Chord\": \"C#/Db\"}, {\"Index\": 900, \"Highest Charting Position\": 83, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Del Mar\", \"Streams\": 5698099, \"Artist\": \"Ozuna, Doja Cat, Sia\", \"Artist Followers\": 29238936.0, \"Song ID\": \"5cpJFiNwYyWwFLH0V6B3N8\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 79.0, \"Danceability\": 0.759, \"Energy\": 0.636, \"Loudness\": -5.585, \"Speechiness\": 0.0369, \"Acousticness\": 0.0224, \"Liveness\": 0.166, \"Tempo\": 109.976, \"Duration (ms)\": 214507.0, \"Valence\": 0.536, \"Chord\": \"F#/Gb\"}, {\"Index\": 901, \"Highest Charting Position\": 72, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Hit Different\", \"Streams\": 5049863, \"Artist\": \"SZA, The Neptunes, Pharrell Williams, Ty Dolla $ign\", \"Artist Followers\": 5888533.0, \"Song ID\": \"7Bar1kLTmsRmH6FCKKMEyU\", \"Genre\": \"['pop', 'pop rap', 'r&b']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 74.0, \"Danceability\": 0.679, \"Energy\": 0.516, \"Loudness\": -6.371, \"Speechiness\": 0.0452, \"Acousticness\": 0.199, \"Liveness\": 0.0965, \"Tempo\": 120.074, \"Duration (ms)\": 202008.0, \"Valence\": 0.716, \"Chord\": \"C\"}, {\"Index\": 902, \"Highest Charting Position\": 65, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Nobody's Love\", \"Streams\": 4957966, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32279979.0, \"Song ID\": \"2ST72jD2KVe7f3fbcGyX1b\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 73.0, \"Danceability\": 0.485, \"Energy\": 0.567, \"Loudness\": -6.456, \"Speechiness\": 0.0388, \"Acousticness\": 0.316, \"Liveness\": 0.0949, \"Tempo\": 93.676, \"Duration (ms)\": 211254.0, \"Valence\": 0.157, \"Chord\": \"C#/Db\"}, {\"Index\": 903, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"M\\u00e1quina do Tempo\", \"Streams\": 4938139, \"Artist\": \"Matu\\u00ea\", \"Artist Followers\": 3263283.0, \"Song ID\": \"5oI9blwsXC8AkTWw6wASY8\", \"Genre\": \"['r&b brasileiro', 'rap cearense', 'trap brasileiro']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-09-11--2020-09-18\", \"Popularity\": 70.0, \"Danceability\": 0.629, \"Energy\": 0.727, \"Loudness\": -4.387, \"Speechiness\": 0.0499, \"Acousticness\": 0.0647, \"Liveness\": 0.138, \"Tempo\": 149.978, \"Duration (ms)\": 230400.0, \"Valence\": 0.132, \"Chord\": \"E\"}, {\"Index\": 904, \"Highest Charting Position\": 112, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Fuckst mich nur ab\", \"Streams\": 4898520, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"0y8mJFmm4ogCHnfe0oTuT6\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 63.0, \"Danceability\": 0.817, \"Energy\": 0.468, \"Loudness\": -10.945, \"Speechiness\": 0.287, \"Acousticness\": 0.233, \"Liveness\": 0.0905, \"Tempo\": 104.875, \"Duration (ms)\": 182931.0, \"Valence\": 0.237, \"Chord\": \"C#/Db\"}, {\"Index\": 905, \"Highest Charting Position\": 122, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Jangueo\", \"Streams\": 4877753, \"Artist\": \"Alex Rose, Rafa Pab\\u00f6n\", \"Artist Followers\": 2168452.0, \"Song ID\": \"1bRpSCFv6P2OUhciByeRYR\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 74.0, \"Danceability\": 0.861, \"Energy\": 0.678, \"Loudness\": -4.157, \"Speechiness\": 0.0536, \"Acousticness\": 0.253, \"Liveness\": 0.106, \"Tempo\": 103.994, \"Duration (ms)\": 259600.0, \"Valence\": 0.723, \"Chord\": \"G#/Ab\"}, {\"Index\": 906, \"Highest Charting Position\": 68, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"We Paid (feat. 42 Dugg)\", \"Streams\": 4776686, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"6gxKUmycQX7uyMwJcweFjp\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 76.0, \"Danceability\": 0.926, \"Energy\": 0.542, \"Loudness\": -5.064, \"Speechiness\": 0.293, \"Acousticness\": 0.135, \"Liveness\": 0.0877, \"Tempo\": 135.14, \"Duration (ms)\": 181929.0, \"Valence\": 0.564, \"Chord\": \"C#/Db\"}, {\"Index\": 907, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Ihr Hobby\", \"Streams\": 4723116, \"Artist\": \"Bonez MC, Maxwell\", \"Artist Followers\": 1683006.0, \"Song ID\": \"4aZfvvgfoSfmSZpfwQYzC0\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-09-11--2020-09-18\", \"Popularity\": 59.0, \"Danceability\": 0.774, \"Energy\": 0.814, \"Loudness\": -6.145, \"Speechiness\": 0.0584, \"Acousticness\": 0.204, \"Liveness\": 0.118, \"Tempo\": 109.019, \"Duration (ms)\": 185330.0, \"Valence\": 0.254, \"Chord\": \"A#/Bb\"}, {\"Index\": 908, \"Highest Charting Position\": 150, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"When I Look At You\", \"Streams\": 4652583, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"7ywzEdEuVG1lsjsRCGJfLy\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2009-01-01\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 63.0, \"Danceability\": 0.459, \"Energy\": 0.545, \"Loudness\": -4.874, \"Speechiness\": 0.0282, \"Acousticness\": 0.142, \"Liveness\": 0.105, \"Tempo\": 137.941, \"Duration (ms)\": 248587.0, \"Valence\": 0.194, \"Chord\": \"F#/Gb\"}, {\"Index\": 909, \"Highest Charting Position\": 21, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Boss Bitch\", \"Streams\": 4620838, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"78qd8dvwea0Gosb6Fe6j3k\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-01-23\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 81.0, \"Danceability\": 0.707, \"Energy\": 0.955, \"Loudness\": -4.593, \"Speechiness\": 0.222, \"Acousticness\": 0.127, \"Liveness\": 0.202, \"Tempo\": 125.989, \"Duration (ms)\": 134240.0, \"Valence\": 0.575, \"Chord\": \"A#/Bb\"}, {\"Index\": 910, \"Highest Charting Position\": 142, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Ain't It Different (feat. AJ Tracey & Stormzy)\", \"Streams\": 4602336, \"Artist\": \"Headie One\", \"Artist Followers\": 328877.0, \"Song ID\": \"6NJfIydBMYrXvlaXsFxmc8\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2020-08-20\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 69.0, \"Danceability\": 0.767, \"Energy\": 0.569, \"Loudness\": -6.805, \"Speechiness\": 0.216, \"Acousticness\": 0.00988, \"Liveness\": 0.109, \"Tempo\": 77.052, \"Duration (ms)\": 196363.0, \"Valence\": 0.524, \"Chord\": \"E\"}, {\"Index\": 911, \"Highest Charting Position\": 75, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Some Say - Felix Jaehn Remix\", \"Streams\": 4598325, \"Artist\": \"Nea\", \"Artist Followers\": 38111.0, \"Song ID\": \"7C1trmcQQ5n5RNy4l6ziCv\", \"Genre\": \"['scandipop', 'swedish pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 77.0, \"Danceability\": 0.682, \"Energy\": 0.7, \"Loudness\": -5.591, \"Speechiness\": 0.0397, \"Acousticness\": 0.406, \"Liveness\": 0.174, \"Tempo\": 120.03, \"Duration (ms)\": 186878.0, \"Valence\": 0.637, \"Chord\": \"F#/Gb\"}, {\"Index\": 912, \"Highest Charting Position\": 13, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Savage Remix (feat. Beyonc\\u00e9)\", \"Streams\": 4568308, \"Artist\": \"Beyonc\\u00e9, Megan Thee Stallion\", \"Artist Followers\": 28335112.0, \"Song ID\": \"5v4GgrXPMghOnBBLmveLac\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'r&b']\", \"Release Date\": \"2020-04-29\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 73.0, \"Danceability\": 0.822, \"Energy\": 0.743, \"Loudness\": -4.772, \"Speechiness\": 0.28, \"Acousticness\": 0.016, \"Liveness\": 0.127, \"Tempo\": 84.459, \"Duration (ms)\": 242001.0, \"Valence\": 0.636, \"Chord\": \"A#/Bb\"}, {\"Index\": 913, \"Highest Charting Position\": 115, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Lithuania (feat. Travis Scott)\", \"Streams\": 5949270, \"Artist\": \"Big Sean\", \"Artist Followers\": 8673345.0, \"Song ID\": \"4VLTxHOyFX5FRtkpsFm5Pc\", \"Genre\": \"['detroit hip hop', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-09-04--2020-09-11\", \"Popularity\": 62.0, \"Danceability\": 0.676, \"Energy\": 0.82, \"Loudness\": -5.217, \"Speechiness\": 0.0554, \"Acousticness\": 0.0493, \"Liveness\": 0.615, \"Tempo\": 152.028, \"Duration (ms)\": 199250.0, \"Valence\": 0.618, \"Chord\": \"G\"}, {\"Index\": 914, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Tap In (feat. Post Malone, DaBaby & Jack Harlow)\", \"Streams\": 5117128, \"Artist\": \"Saweetie\", \"Artist Followers\": 1255573.0, \"Song ID\": \"5woaU1FNkqCwg6WzWiQPW5\", \"Genre\": \"['cali rap', 'dance pop', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-08-28\", \"Weeks Charted\": \"2020-09-04--2020-09-11\", \"Popularity\": 64.0, \"Danceability\": 0.948, \"Energy\": 0.63, \"Loudness\": -7.011, \"Speechiness\": 0.219, \"Acousticness\": 0.00647, \"Liveness\": 0.0737, \"Tempo\": 100.032, \"Duration (ms)\": 253569.0, \"Valence\": 0.425, \"Chord\": \"C#/Db\"}, {\"Index\": 915, \"Highest Charting Position\": 91, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Not Shy\", \"Streams\": 4982232, \"Artist\": \"ITZY\", \"Artist Followers\": 2384076.0, \"Song ID\": \"4ecVWqbtW6phQGpZMAyqIU\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2020-08-17\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 73.0, \"Danceability\": 0.776, \"Energy\": 0.911, \"Loudness\": -3.08, \"Speechiness\": 0.131, \"Acousticness\": 0.155, \"Liveness\": 0.268, \"Tempo\": 101.027, \"Duration (ms)\": 177728.0, \"Valence\": 0.56, \"Chord\": \"D\"}, {\"Index\": 916, \"Highest Charting Position\": 71, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"The Plan - From the Motion Picture \\\"TENET\\\"\", \"Streams\": 4876238, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"551xyaSJsg8hILXFq9JdST\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2020-08-22\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 67.0, \"Danceability\": 0.433, \"Energy\": 0.443, \"Loudness\": -10.568, \"Speechiness\": 0.0361, \"Acousticness\": 0.0922, \"Liveness\": 0.117, \"Tempo\": 79.903, \"Duration (ms)\": 185851.0, \"Valence\": 0.0363, \"Chord\": \"C#/Db\"}, {\"Index\": 917, \"Highest Charting Position\": 152, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"ADMV\", \"Streams\": 4737291, \"Artist\": \"Maluma\", \"Artist Followers\": 26784251.0, \"Song ID\": \"3eJMSq78dDaFb7VvhNFnq6\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-04-23\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 72.0, \"Danceability\": 0.565, \"Energy\": 0.39, \"Loudness\": -4.959, \"Speechiness\": 0.0556, \"Acousticness\": 0.817, \"Liveness\": 0.126, \"Tempo\": 163.781, \"Duration (ms)\": 193700.0, \"Valence\": 0.708, \"Chord\": \"A\"}, {\"Index\": 918, \"Highest Charting Position\": 122, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Alane\", \"Streams\": 4668193, \"Artist\": \"Robin Schulz, Wes\", \"Artist Followers\": 2786366.0, \"Song ID\": \"2u6Jm2klS4yvAlbSHlxUwI\", \"Genre\": \"['dance pop', 'deep euro house', 'deep house', 'edm', 'german dance', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 67.0, \"Danceability\": 0.581, \"Energy\": 0.799, \"Loudness\": -6.66, \"Speechiness\": 0.164, \"Acousticness\": 0.0419, \"Liveness\": 0.11, \"Tempo\": 124.002, \"Duration (ms)\": 175016.0, \"Valence\": 0.662, \"Chord\": \"D#/Eb\"}, {\"Index\": 919, \"Highest Charting Position\": 82, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"THE BADDEST\", \"Streams\": 4642057, \"Artist\": \"K/DA, (G)I-DLE, Wolftyla, Bea Miller, League of Legends\", \"Artist Followers\": 1245965.0, \"Song ID\": \"2V4Fx72svQRxrFvNT1eq5f\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2020-08-27\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 70.0, \"Danceability\": 0.676, \"Energy\": 0.857, \"Loudness\": -4.368, \"Speechiness\": 0.0438, \"Acousticness\": 0.0215, \"Liveness\": 0.254, \"Tempo\": 149.981, \"Duration (ms)\": 162600.0, \"Valence\": 0.717, \"Chord\": \"A#/Bb\"}, {\"Index\": 920, \"Highest Charting Position\": 112, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Desce Pro Play (PA PA PA)\", \"Streams\": 4615520, \"Artist\": \"Mc Zaac, Anitta, Tyga\", \"Artist Followers\": 1555628.0, \"Song ID\": \"4zGtfOglDBfVUypabBwIjQ\", \"Genre\": \"['funk carioca', 'funk pop']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 68.0, \"Danceability\": 0.935, \"Energy\": 0.71, \"Loudness\": -5.085, \"Speechiness\": 0.158, \"Acousticness\": 0.0769, \"Liveness\": 0.173, \"Tempo\": 100.009, \"Duration (ms)\": 168507.0, \"Valence\": 0.635, \"Chord\": \"B\"}, {\"Index\": 921, \"Highest Charting Position\": 103, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Mariposa\", \"Streams\": 4593366, \"Artist\": \"Peach Tree Rascals\", \"Artist Followers\": 177972.0, \"Song ID\": \"4ja2gzrNh9VNigzoXfmbwD\", \"Genre\": \"['alternative r&b', 'chill r&b', 'indie r&b', 'pop']\", \"Release Date\": \"2019-08-28\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 76.0, \"Danceability\": 0.676, \"Energy\": 0.525, \"Loudness\": -5.88, \"Speechiness\": 0.028, \"Acousticness\": 0.617, \"Liveness\": 0.356, \"Tempo\": 112.011, \"Duration (ms)\": 210000.0, \"Valence\": 0.421, \"Chord\": \"A\"}, {\"Index\": 922, \"Highest Charting Position\": 5, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"the 1\", \"Streams\": 4587573, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0Jlcvv8IykzHaSmj49uNW8\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 75.0, \"Danceability\": 0.777, \"Energy\": 0.357, \"Loudness\": -6.942, \"Speechiness\": 0.0522, \"Acousticness\": 0.757, \"Liveness\": 0.108, \"Tempo\": 139.883, \"Duration (ms)\": 210252.0, \"Valence\": 0.172, \"Chord\": \"C\"}, {\"Index\": 923, \"Highest Charting Position\": 11, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"RITMO (Bad Boys For Life)\", \"Streams\": 4585895, \"Artist\": \"Black Eyed Peas, J Balvin\", \"Artist Followers\": 5966748.0, \"Song ID\": \"6cy3ki60hLwimwIje7tALf\", \"Genre\": \"['dance pop', 'pop', 'pop rap']\", \"Release Date\": \"2019-10-12\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.721, \"Energy\": 0.716, \"Loudness\": -7.037, \"Speechiness\": 0.0657, \"Acousticness\": 0.0334, \"Liveness\": 0.237, \"Tempo\": 104.994, \"Duration (ms)\": 221714.0, \"Valence\": 0.667, \"Chord\": \"A#/Bb\"}, {\"Index\": 924, \"Highest Charting Position\": 134, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Unterwegs\", \"Streams\": 4572706, \"Artist\": \"KitschKrieg, Jamule, SFR\", \"Artist Followers\": 166517.0, \"Song ID\": \"7mrWTjhYctgEQb0lJKrVWy\", \"Genre\": \"['german hip hop', 'german pop', 'hamburg hip hop']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 68.0, \"Danceability\": 0.88, \"Energy\": 0.607, \"Loudness\": -7.067, \"Speechiness\": 0.0777, \"Acousticness\": 0.195, \"Liveness\": 0.15, \"Tempo\": 126.039, \"Duration (ms)\": 233905.0, \"Valence\": 0.823, \"Chord\": \"F#/Gb\"}, {\"Index\": 925, \"Highest Charting Position\": 86, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"What's Love Got to Do with It\", \"Streams\": 4538382, \"Artist\": \"Kygo, Tina Turner\", \"Artist Followers\": 7593792.0, \"Song ID\": \"3Be7CLdHZpyzsVijme39cW\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-07-17\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 74.0, \"Danceability\": 0.75, \"Energy\": 0.664, \"Loudness\": -5.908, \"Speechiness\": 0.154, \"Acousticness\": 0.275, \"Liveness\": 0.0632, \"Tempo\": 105.023, \"Duration (ms)\": 208156.0, \"Valence\": 0.617, \"Chord\": \"G#/Ab\"}, {\"Index\": 926, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Cry About It Later\", \"Streams\": 5306994, \"Artist\": \"Katy Perry\", \"Artist Followers\": 18936929.0, \"Song ID\": \"43WYPxyEfIxlIjNlxQGYzc\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2020-08-28--2020-09-04\", \"Popularity\": 67.0, \"Danceability\": 0.676, \"Energy\": 0.794, \"Loudness\": -4.78, \"Speechiness\": 0.0366, \"Acousticness\": 0.0513, \"Liveness\": 0.0723, \"Tempo\": 125.957, \"Duration (ms)\": 159286.0, \"Valence\": 0.161, \"Chord\": \"D\"}, {\"Index\": 927, \"Highest Charting Position\": 71, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Banana (feat. Shaggy) - DJ FLe - Minisiren Remix\", \"Streams\": 4624448, \"Artist\": \"Conkarah\", \"Artist Followers\": 67074.0, \"Song ID\": \"0dZpw3h6KZhcHec61qwevZ\", \"Genre\": \"['jawaiian']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 70.0, \"Danceability\": 0.824, \"Energy\": 0.854, \"Loudness\": -5.312, \"Speechiness\": 0.177, \"Acousticness\": 0.016, \"Liveness\": 0.117, \"Tempo\": 95.114, \"Duration (ms)\": 210329.0, \"Valence\": 0.896, \"Chord\": \"G#/Ab\"}, {\"Index\": 928, \"Highest Charting Position\": 185, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Gifted (feat. Roddy Ricch)\", \"Streams\": 4609169, \"Artist\": \"Cordae\", \"Artist Followers\": 1492551.0, \"Song ID\": \"0mb3uDw5vfFUcZfJYFOMRu\", \"Genre\": \"['dmv rap', 'hip hop', 'pop rap', 'rap', 'trap', 'underground hip hop', 'vapor trap']\", \"Release Date\": \"2020-08-27\", \"Weeks Charted\": \"2020-08-28--2020-09-04\", \"Popularity\": 65.0, \"Danceability\": 0.653, \"Energy\": 0.603, \"Loudness\": -5.697, \"Speechiness\": 0.171, \"Acousticness\": 0.175, \"Liveness\": 0.18, \"Tempo\": 151.016, \"Duration (ms)\": 168477.0, \"Valence\": 0.551, \"Chord\": \"F\"}, {\"Index\": 929, \"Highest Charting Position\": 27, \"Number of Times Charted\": 36, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"OUT WEST (feat. Young Thug)\", \"Streams\": 4597001, \"Artist\": \"JACKBOYS, Travis Scott\", \"Artist Followers\": 437907.0, \"Song ID\": \"6gi6y1xwmVszDWkUqab1qw\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.802, \"Energy\": 0.591, \"Loudness\": -4.895, \"Speechiness\": 0.225, \"Acousticness\": 0.0104, \"Liveness\": 0.196, \"Tempo\": 139.864, \"Duration (ms)\": 157712.0, \"Valence\": 0.309, \"Chord\": \"G#/Ab\"}, {\"Index\": 930, \"Highest Charting Position\": 174, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Anaranjado\", \"Streams\": 4575403, \"Artist\": \"Jowell & Randy, J Balvin\", \"Artist Followers\": 2919696.0, \"Song ID\": \"5iw28wvyHgj4ppOu5AdcEU\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-07-16\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 66.0, \"Danceability\": 0.763, \"Energy\": 0.58, \"Loudness\": -6.196, \"Speechiness\": 0.144, \"Acousticness\": 0.0466, \"Liveness\": 0.154, \"Tempo\": 175.937, \"Duration (ms)\": 212011.0, \"Valence\": 0.608, \"Chord\": \"G#/Ab\"}, {\"Index\": 931, \"Highest Charting Position\": 111, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Reggaetonera\", \"Streams\": 4564331, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"6yVkakCN460KOVol9ZazjH\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-05-29--2020-06-05\", \"Popularity\": 69.0, \"Danceability\": 0.694, \"Energy\": 0.796, \"Loudness\": -4.164, \"Speechiness\": 0.0565, \"Acousticness\": 0.48, \"Liveness\": 0.108, \"Tempo\": 93.064, \"Duration (ms)\": 212312.0, \"Valence\": 0.515, \"Chord\": \"F#/Gb\"}, {\"Index\": 932, \"Highest Charting Position\": 5, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Sour Candy (with BLACKPINK)\", \"Streams\": 4556900, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"6R6ZoHTypt5lt68MWbzZXv\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-28\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 70.0, \"Danceability\": 0.752, \"Energy\": 0.87, \"Loudness\": -3.812, \"Speechiness\": 0.0623, \"Acousticness\": 0.0604, \"Liveness\": 0.489, \"Tempo\": 120.006, \"Duration (ms)\": 157707.0, \"Valence\": 0.784, \"Chord\": \"A\"}, {\"Index\": 933, \"Highest Charting Position\": 113, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Rags2Riches 2 (feat. Lil Baby)\", \"Streams\": 4547965, \"Artist\": \"Rod Wave\", \"Artist Followers\": 2203386.0, \"Song ID\": \"40TPiJpvwGIyvPjJMDTKfy\", \"Genre\": \"['florida rap']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 60.0, \"Danceability\": 0.874, \"Energy\": 0.443, \"Loudness\": -9.628, \"Speechiness\": 0.241, \"Acousticness\": 0.147, \"Liveness\": 0.124, \"Tempo\": 118.004, \"Duration (ms)\": 235988.0, \"Valence\": 0.298, \"Chord\": \"F\"}, {\"Index\": 934, \"Highest Charting Position\": 31, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Bandit (with YoungBoy Never Broke Again)\", \"Streams\": 4514763, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"6Gg1gjgKi2AK4e0qzsR7sd\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.474, \"Energy\": 0.631, \"Loudness\": -5.884, \"Speechiness\": 0.343, \"Acousticness\": 0.0687, \"Liveness\": 0.132, \"Tempo\": 180.051, \"Duration (ms)\": 189323.0, \"Valence\": 0.425, \"Chord\": \"F\"}, {\"Index\": 935, \"Highest Charting Position\": 117, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"PAM\", \"Streams\": 4501441, \"Artist\": \"Justin Quiles, Daddy Yankee, El Alfa\", \"Artist Followers\": 2897862.0, \"Song ID\": \"0eeKDrQxjqNl5bX5VCHDcn\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 73.0, \"Danceability\": 0.889, \"Energy\": 0.863, \"Loudness\": -3.011, \"Speechiness\": 0.0757, \"Acousticness\": 0.289, \"Liveness\": 0.0798, \"Tempo\": 112.953, \"Duration (ms)\": 201000.0, \"Valence\": 0.776, \"Chord\": \"B\"}, {\"Index\": 936, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Lemonade\", \"Streams\": 11373347, \"Artist\": \"Internet Money, Gunna, Don Toliver, NAV\", \"Artist Followers\": 412466.0, \"Song ID\": \"02kDW379Yfd5PzW5A6vuGt\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 82.0, \"Danceability\": 0.799, \"Energy\": 0.66, \"Loudness\": -6.153, \"Speechiness\": 0.079, \"Acousticness\": 0.256, \"Liveness\": 0.111, \"Tempo\": 140.04, \"Duration (ms)\": 195429.0, \"Valence\": 0.471, \"Chord\": \"C#/Db\"}, {\"Index\": 937, \"Highest Charting Position\": 145, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Fr\\u00fchst\\u00fcck in Paris\", \"Streams\": 5440253, \"Artist\": \"Capital Bra, Cro\", \"Artist Followers\": 4093115.0, \"Song ID\": \"1ddbNJwDjjmCYz1GFGYnsw\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-09-17\", \"Weeks Charted\": \"2020-08-21--2020-08-28\", \"Popularity\": 56.0, \"Danceability\": 0.744, \"Energy\": 0.644, \"Loudness\": -5.562, \"Speechiness\": 0.0641, \"Acousticness\": 0.229, \"Liveness\": 0.204, \"Tempo\": 96.852, \"Duration (ms)\": 151360.0, \"Valence\": 0.577, \"Chord\": \"G#/Ab\"}, {\"Index\": 938, \"Highest Charting Position\": 22, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"ON\", \"Streams\": 5391018, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"2QyuXBcV1LJ2rq01KhreMF\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 77.0, \"Danceability\": 0.583, \"Energy\": 0.817, \"Loudness\": -5.146, \"Speechiness\": 0.0987, \"Acousticness\": 0.118, \"Liveness\": 0.338, \"Tempo\": 105.936, \"Duration (ms)\": 246381.0, \"Valence\": 0.438, \"Chord\": \"A\"}, {\"Index\": 939, \"Highest Charting Position\": 106, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"My Oasis (feat. Burna Boy)\", \"Streams\": 4887204, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"2KoHxhRyWxJzA0VafWd5Nk\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-07-30\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 69.0, \"Danceability\": 0.691, \"Energy\": 0.474, \"Loudness\": -8.742, \"Speechiness\": 0.0583, \"Acousticness\": 0.569, \"Liveness\": 0.099, \"Tempo\": 143.783, \"Duration (ms)\": 179917.0, \"Valence\": 0.381, \"Chord\": \"A#/Bb\"}, {\"Index\": 940, \"Highest Charting Position\": 8, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Life's A Mess (feat. Halsey)\", \"Streams\": 4883202, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5wWAwzGp2OaaoIkwcz6wZs\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 74.0, \"Danceability\": 0.63, \"Energy\": 0.446, \"Loudness\": -8.9, \"Speechiness\": 0.0351, \"Acousticness\": 0.337, \"Liveness\": 0.166, \"Tempo\": 143.078, \"Duration (ms)\": 202193.0, \"Valence\": 0.177, \"Chord\": \"C#/Db\"}, {\"Index\": 941, \"Highest Charting Position\": 56, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"PORFA\", \"Streams\": 4702117, \"Artist\": \"Feid, Justin Quiles\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5PwAiSk3ufe0YwOHRFPHEG\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 0.0, \"Danceability\": 0.843, \"Energy\": 0.549, \"Loudness\": -8.018, \"Speechiness\": 0.164, \"Acousticness\": 0.0948, \"Liveness\": 0.155, \"Tempo\": 83.982, \"Duration (ms)\": 233000.0, \"Valence\": 0.542, \"Chord\": \"F#/Gb\"}, {\"Index\": 942, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"2012\", \"Streams\": 4685894, \"Artist\": \"Bausa, Juju\", \"Artist Followers\": 961181.0, \"Song ID\": \"6bM4daGlfZHtKMQp8tEqVz\", \"Genre\": \"['german hip hop', 'german pop']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-08-21--2020-08-28\", \"Popularity\": 62.0, \"Danceability\": 0.805, \"Energy\": 0.619, \"Loudness\": -7.907, \"Speechiness\": 0.0771, \"Acousticness\": 0.218, \"Liveness\": 0.114, \"Tempo\": 98.995, \"Duration (ms)\": 170200.0, \"Valence\": 0.476, \"Chord\": \"F\"}, {\"Index\": 943, \"Highest Charting Position\": 11, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"august\", \"Streams\": 4586236, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3hUxzQpSfdDqwM3ZTFQY0K\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 76.0, \"Danceability\": 0.532, \"Energy\": 0.623, \"Loudness\": -9.208, \"Speechiness\": 0.0331, \"Acousticness\": 0.538, \"Liveness\": 0.0925, \"Tempo\": 89.937, \"Duration (ms)\": 261923.0, \"Valence\": 0.403, \"Chord\": \"F\"}, {\"Index\": 944, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"if i were u (with Lauv)\", \"Streams\": 4561189, \"Artist\": \"blackbear\", \"Artist Followers\": 4272745.0, \"Song ID\": \"0CF1RH8dQKuK2lQPSQw2lZ\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2020-08-19\", \"Weeks Charted\": \"2020-08-21--2020-08-28\", \"Popularity\": 64.0, \"Danceability\": 0.666, \"Energy\": 0.628, \"Loudness\": -5.613, \"Speechiness\": 0.0623, \"Acousticness\": 0.144, \"Liveness\": 0.189, \"Tempo\": 82.992, \"Duration (ms)\": 186468.0, \"Valence\": 0.767, \"Chord\": \"G#/Ab\"}, {\"Index\": 945, \"Highest Charting Position\": 37, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Ballin' (with Roddy Ricch)\", \"Streams\": 4436934, \"Artist\": \"Mustard\", \"Artist Followers\": 881797.0, \"Song ID\": \"3QzAOrNlsabgbMwlZt7TAY\", \"Genre\": \"['cali rap', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.809, \"Energy\": 0.545, \"Loudness\": -6.678, \"Speechiness\": 0.0735, \"Acousticness\": 0.392, \"Liveness\": 0.151, \"Tempo\": 97.008, \"Duration (ms)\": 180435.0, \"Valence\": 0.244, \"Chord\": \"G\"}, {\"Index\": 946, \"Highest Charting Position\": 72, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Stay Gold\", \"Streams\": 4405338, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3Ys2PYl1wyPKQIwyqhP9cQ\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-07-14\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-07-10--2020-07-17\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 73.0, \"Danceability\": 0.723, \"Energy\": 0.634, \"Loudness\": -5.415, \"Speechiness\": 0.0542, \"Acousticness\": 0.0892, \"Liveness\": 0.0787, \"Tempo\": 129.017, \"Duration (ms)\": 243267.0, \"Valence\": 0.582, \"Chord\": \"C#/Db\"}, {\"Index\": 947, \"Highest Charting Position\": 186, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"I'm Yours\", \"Streams\": 4391666, \"Artist\": \"Jason Mraz\", \"Artist Followers\": 6167871.0, \"Song ID\": \"1EzrEOXmMH3G43AXT1y7pA\", \"Genre\": \"['acoustic pop', 'neo mellow', 'pop', 'pop rock']\", \"Release Date\": \"2008-05-12\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\", \"Popularity\": 80.0, \"Danceability\": 0.686, \"Energy\": 0.457, \"Loudness\": -8.322, \"Speechiness\": 0.0468, \"Acousticness\": 0.595, \"Liveness\": 0.105, \"Tempo\": 150.953, \"Duration (ms)\": 242187.0, \"Valence\": 0.718, \"Chord\": \"B\"}, {\"Index\": 948, \"Highest Charting Position\": 136, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Youngblood\", \"Streams\": 4390823, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"2iUXsYOEPhVqEBwsqP70rE\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-06-15\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.596, \"Energy\": 0.854, \"Loudness\": -5.114, \"Speechiness\": 0.463, \"Acousticness\": 0.0169, \"Liveness\": 0.124, \"Tempo\": 120.274, \"Duration (ms)\": 203418.0, \"Valence\": 0.152, \"Chord\": \"G\"}, {\"Index\": 949, \"Highest Charting Position\": 8, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"the last great american dynasty\", \"Streams\": 4389670, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2Eeur20xVqfUoM3Q7EFPFt\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.686, \"Energy\": 0.662, \"Loudness\": -8.505, \"Speechiness\": 0.0413, \"Acousticness\": 0.467, \"Liveness\": 0.109, \"Tempo\": 147.922, \"Duration (ms)\": 230999.0, \"Valence\": 0.706, \"Chord\": \"G\"}, {\"Index\": 950, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Levitating (feat. Madonna and Missy Elliott) [The Blessed Madonna Remix]\", \"Streams\": 5254969, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"0pk1hxhJLBSZZ5RKBhcwOa\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-08-13\", \"Weeks Charted\": \"2020-08-14--2020-08-21\", \"Popularity\": 62.0, \"Danceability\": 0.808, \"Energy\": 0.655, \"Loudness\": -7.34, \"Speechiness\": 0.139, \"Acousticness\": 0.0373, \"Liveness\": 0.208, \"Tempo\": 116.029, \"Duration (ms)\": 250280.0, \"Valence\": 0.56, \"Chord\": \"B\"}, {\"Index\": 951, \"Highest Charting Position\": 10, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"my tears ricochet\", \"Streams\": 5111416, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1MgV7FIyNxIG7WzMRJV5HC\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.456, \"Energy\": 0.263, \"Loudness\": -10.63, \"Speechiness\": 0.0332, \"Acousticness\": 0.806, \"Liveness\": 0.0749, \"Tempo\": 129.86, \"Duration (ms)\": 255894.0, \"Valence\": 0.111, \"Chord\": \"C\"}, {\"Index\": 952, \"Highest Charting Position\": 59, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Rags2Riches (feat. ATR Son Son)\", \"Streams\": 4737306, \"Artist\": \"Rod Wave\", \"Artist Followers\": 2203386.0, \"Song ID\": \"0qg0GJp7HSewRCVPP4fKGk\", \"Genre\": \"['florida rap']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 55.0, \"Danceability\": 0.904, \"Energy\": 0.26, \"Loudness\": -17.57, \"Speechiness\": 0.101, \"Acousticness\": 0.277, \"Liveness\": 0.121, \"Tempo\": 117.967, \"Duration (ms)\": 167147.0, \"Valence\": 0.231, \"Chord\": \"F\"}, {\"Index\": 953, \"Highest Charting Position\": 79, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Flex (feat. Juice WRLD)\", \"Streams\": 4664281, \"Artist\": \"Polo G\", \"Artist Followers\": 4849204.0, \"Song ID\": \"2QqJTIlGKRLJC3onkavYEz\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 76.0, \"Danceability\": 0.752, \"Energy\": 0.673, \"Loudness\": -5.792, \"Speechiness\": 0.153, \"Acousticness\": 0.0538, \"Liveness\": 0.133, \"Tempo\": 164.009, \"Duration (ms)\": 163902.0, \"Valence\": 0.35, \"Chord\": \"A#/Bb\"}, {\"Index\": 954, \"Highest Charting Position\": 77, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Rover (feat. DTG)\", \"Streams\": 4488631, \"Artist\": \"S1mba\", \"Artist Followers\": 46992.0, \"Song ID\": \"4slSrbTK1sNK4I1mDYEthf\", \"Genre\": \"['afroswing', 'social media pop']\", \"Release Date\": \"2020-03-04\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 73.0, \"Danceability\": 0.613, \"Energy\": 0.624, \"Loudness\": -6.66, \"Speechiness\": 0.206, \"Acousticness\": 0.496, \"Liveness\": 0.283, \"Tempo\": 62.948, \"Duration (ms)\": 167917.0, \"Valence\": 0.804, \"Chord\": \"B\"}, {\"Index\": 955, \"Highest Charting Position\": 74, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Only You Freestyle\", \"Streams\": 4480780, \"Artist\": \"Headie One, Drake\", \"Artist Followers\": 328877.0, \"Song ID\": \"4OENnoidV0h8gJV6bhrw7r\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2020-07-20\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 68.0, \"Danceability\": 0.68, \"Energy\": 0.826, \"Loudness\": -2.561, \"Speechiness\": 0.27, \"Acousticness\": 0.562, \"Liveness\": 0.254, \"Tempo\": 146.95, \"Duration (ms)\": 248937.0, \"Valence\": 0.804, \"Chord\": \"F\"}, {\"Index\": 956, \"Highest Charting Position\": 55, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Hallucinate\", \"Streams\": 4472669, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"1nYeVF5vIBxMxfPoL0SIWg\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 72.0, \"Danceability\": 0.627, \"Energy\": 0.69, \"Loudness\": -5.396, \"Speechiness\": 0.139, \"Acousticness\": 0.033, \"Liveness\": 0.0742, \"Tempo\": 122.053, \"Duration (ms)\": 208505.0, \"Valence\": 0.627, \"Chord\": \"A#/Bb\"}, {\"Index\": 957, \"Highest Charting Position\": 100, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"El Efecto\", \"Streams\": 4466143, \"Artist\": \"Rauw Alejandro, Chencho Corleone\", \"Artist Followers\": 6096559.0, \"Song ID\": \"4SJHHpKhcuXwDsCsPqshXj\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2019-03-15\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 76.0, \"Danceability\": 0.849, \"Energy\": 0.781, \"Loudness\": -4.635, \"Speechiness\": 0.159, \"Acousticness\": 0.406, \"Liveness\": 0.0801, \"Tempo\": 84.041, \"Duration (ms)\": 217143.0, \"Valence\": 0.893, \"Chord\": \"C\"}, {\"Index\": 958, \"Highest Charting Position\": 176, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Co\\u00f1o\", \"Streams\": 4462411, \"Artist\": \"Jason Derulo, Puri, Jhorrmountain\", \"Artist Followers\": 9778632.0, \"Song ID\": \"5DV4ZSCqbFv74ui3ZhimXo\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 69.0, \"Danceability\": 0.899, \"Energy\": 0.528, \"Loudness\": -5.442, \"Speechiness\": 0.181, \"Acousticness\": 0.000554, \"Liveness\": 0.105, \"Tempo\": 100.037, \"Duration (ms)\": 111852.0, \"Valence\": 0.456, \"Chord\": \"A\"}, {\"Index\": 959, \"Highest Charting Position\": 126, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Jolie nana\", \"Streams\": 4449437, \"Artist\": \"Aya Nakamura\", \"Artist Followers\": 2953525.0, \"Song ID\": \"65RWVU6N81CeH65nu52K1U\", \"Genre\": \"['basshall', 'francoton']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 69.0, \"Danceability\": 0.813, \"Energy\": 0.64, \"Loudness\": -5.908, \"Speechiness\": 0.272, \"Acousticness\": 0.269, \"Liveness\": 0.131, \"Tempo\": 92.989, \"Duration (ms)\": 147076.0, \"Valence\": 0.488, \"Chord\": \"D\"}, {\"Index\": 960, \"Highest Charting Position\": 189, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Lovefool\", \"Streams\": 4439790, \"Artist\": \"twocolors\", \"Artist Followers\": 36369.0, \"Song ID\": \"51Of5p3lKZeOg6itfs4og4\", \"Genre\": \"['edm', 'pop dance', 'pop edm', 'tropical house']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 79.0, \"Danceability\": 0.677, \"Energy\": 0.766, \"Loudness\": -6.896, \"Speechiness\": 0.0568, \"Acousticness\": 0.0219, \"Liveness\": 0.129, \"Tempo\": 123.062, \"Duration (ms)\": 190488.0, \"Valence\": 0.198, \"Chord\": \"F#/Gb\"}, {\"Index\": 961, \"Highest Charting Position\": 17, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"invisible string\", \"Streams\": 4424118, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6VsvKPJ4xjVNKpI8VVZ3SV\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.653, \"Energy\": 0.452, \"Loudness\": -11.143, \"Speechiness\": 0.055, \"Acousticness\": 0.838, \"Liveness\": 0.108, \"Tempo\": 83.433, \"Duration (ms)\": 252881.0, \"Valence\": 0.45, \"Chord\": \"E\"}, {\"Index\": 962, \"Highest Charting Position\": 118, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Higher Love\", \"Streams\": 4392936, \"Artist\": \"Kygo, Whitney Houston\", \"Artist Followers\": 7593792.0, \"Song ID\": \"6oJ6le65B3SEqPwMRNXWjY\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.693, \"Energy\": 0.678, \"Loudness\": -7.159, \"Speechiness\": 0.0324, \"Acousticness\": 0.0151, \"Liveness\": 0.101, \"Tempo\": 103.952, \"Duration (ms)\": 228267.0, \"Valence\": 0.404, \"Chord\": \"G#/Ab\"}, {\"Index\": 963, \"Highest Charting Position\": 185, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Como Llora\", \"Streams\": 4380308, \"Artist\": \"Juanfran\", \"Artist Followers\": 117894.0, \"Song ID\": \"52zq2a71SGs3f1vJuv59ui\", \"Genre\": \"['dominican pop', 'pop reggaeton', 'urbano espanol']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 67.0, \"Danceability\": 0.827, \"Energy\": 0.629, \"Loudness\": -3.966, \"Speechiness\": 0.185, \"Acousticness\": 0.183, \"Liveness\": 0.084, \"Tempo\": 88.064, \"Duration (ms)\": 187500.0, \"Valence\": 0.486, \"Chord\": \"F#/Gb\"}, {\"Index\": 964, \"Highest Charting Position\": 50, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Walk Em Down (feat. Roddy Ricch)\", \"Streams\": 4371370, \"Artist\": \"NLE Choppa\", \"Artist Followers\": 6608815.0, \"Song ID\": \"4cSSL3YafYjM3yjgFO1vJg\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 74.0, \"Danceability\": 0.867, \"Energy\": 0.744, \"Loudness\": -5.171, \"Speechiness\": 0.227, \"Acousticness\": 0.268, \"Liveness\": 0.0713, \"Tempo\": 84.005, \"Duration (ms)\": 173288.0, \"Valence\": 0.645, \"Chord\": \"D\"}, {\"Index\": 965, \"Highest Charting Position\": 74, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Wow.\", \"Streams\": 4351784, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"7xQAfvXzm3AkraOtGPWIZg\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.829, \"Energy\": 0.539, \"Loudness\": -7.359, \"Speechiness\": 0.208, \"Acousticness\": 0.136, \"Liveness\": 0.103, \"Tempo\": 99.96, \"Duration (ms)\": 149547.0, \"Valence\": 0.388, \"Chord\": \"B\"}, {\"Index\": 966, \"Highest Charting Position\": 13, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"mirrorball\", \"Streams\": 5564072, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0ZNU020wNYvgW84iljPkPP\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.553, \"Energy\": 0.413, \"Loudness\": -10.037, \"Speechiness\": 0.0334, \"Acousticness\": 0.687, \"Liveness\": 0.0594, \"Tempo\": 110.107, \"Duration (ms)\": 208978.0, \"Valence\": 0.379, \"Chord\": \"D\"}, {\"Index\": 967, \"Highest Charting Position\": 15, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"seven\", \"Streams\": 5459423, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6KJqZcs9XDgVck7Lg9QOTC\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 69.0, \"Danceability\": 0.596, \"Energy\": 0.488, \"Loudness\": -10.769, \"Speechiness\": 0.0274, \"Acousticness\": 0.9, \"Liveness\": 0.091, \"Tempo\": 94.926, \"Duration (ms)\": 208907.0, \"Valence\": 0.415, \"Chord\": \"E\"}, {\"Index\": 968, \"Highest Charting Position\": 18, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"this is me trying\", \"Streams\": 5128412, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7kt9e9LFSpN1zQtYEl19o1\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.515, \"Energy\": 0.476, \"Loudness\": -9.843, \"Speechiness\": 0.0328, \"Acousticness\": 0.314, \"Liveness\": 0.171, \"Tempo\": 135.886, \"Duration (ms)\": 195097.0, \"Valence\": 0.412, \"Chord\": \"A\"}, {\"Index\": 969, \"Highest Charting Position\": 24, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"betty\", \"Streams\": 5112180, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5kI4eCXXzyuIUXjQra0Cxi\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.593, \"Energy\": 0.377, \"Loudness\": -8.761, \"Speechiness\": 0.0253, \"Acousticness\": 0.6, \"Liveness\": 0.0976, \"Tempo\": 95.939, \"Duration (ms)\": 294521.0, \"Valence\": 0.502, \"Chord\": \"C\"}, {\"Index\": 970, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"BLIND (feat. Young Thug)\", \"Streams\": 5074613, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"2T5NBwKRySiCR78vVk08vr\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-08-04\", \"Weeks Charted\": \"2020-08-07--2020-08-14\", \"Popularity\": 69.0, \"Danceability\": 0.709, \"Energy\": 0.679, \"Loudness\": -6.503, \"Speechiness\": 0.346, \"Acousticness\": 0.0115, \"Liveness\": 0.0971, \"Tempo\": 162.973, \"Duration (ms)\": 153467.0, \"Valence\": 0.754, \"Chord\": \"B\"}, {\"Index\": 971, \"Highest Charting Position\": 20, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"illicit affairs\", \"Streams\": 5053658, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2NmsngXHeC1GQ9wWrzhOMf\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.559, \"Energy\": 0.31, \"Loudness\": -10.445, \"Speechiness\": 0.0338, \"Acousticness\": 0.881, \"Liveness\": 0.106, \"Tempo\": 119.845, \"Duration (ms)\": 190898.0, \"Valence\": 0.46, \"Chord\": \"A#/Bb\"}, {\"Index\": 972, \"Highest Charting Position\": 170, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Freak\", \"Streams\": 4736059, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"3aA6xB0tOilDDX17fIJ0Bl\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2020-08-07--2020-08-14\", \"Popularity\": 75.0, \"Danceability\": 0.688, \"Energy\": 0.716, \"Loudness\": -5.702, \"Speechiness\": 0.0385, \"Acousticness\": 0.0969, \"Liveness\": 0.0989, \"Tempo\": 116.912, \"Duration (ms)\": 284480.0, \"Valence\": 0.373, \"Chord\": \"G\"}, {\"Index\": 973, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"PUNANI\", \"Streams\": 4625985, \"Artist\": \"6ix9ine\", \"Artist Followers\": 6514102.0, \"Song ID\": \"41xKiK40e7MFu1bqcGSz1d\", \"Genre\": \"['emo rap', 'rap']\", \"Release Date\": \"2020-08-02\", \"Weeks Charted\": \"2020-08-07--2020-08-14\", \"Popularity\": 58.0, \"Danceability\": 0.841, \"Energy\": 0.541, \"Loudness\": -7.121, \"Speechiness\": 0.229, \"Acousticness\": 0.0186, \"Liveness\": 0.123, \"Tempo\": 97.961, \"Duration (ms)\": 115255.0, \"Valence\": 0.42, \"Chord\": \"A\"}, {\"Index\": 974, \"Highest Charting Position\": 50, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Bl\\u00e4ulich\", \"Streams\": 4599408, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"2WRTnY0slmFgWcrmEr8dPj\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 60.0, \"Danceability\": 0.79, \"Energy\": 0.704, \"Loudness\": -7.935, \"Speechiness\": 0.417, \"Acousticness\": 0.069, \"Liveness\": 0.113, \"Tempo\": 154.007, \"Duration (ms)\": 196213.0, \"Valence\": 0.212, \"Chord\": \"A#/Bb\"}, {\"Index\": 975, \"Highest Charting Position\": 170, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Never Let Me Down\", \"Streams\": 4522005, \"Artist\": \"VIZE, Tom Gregory\", \"Artist Followers\": 141016.0, \"Song ID\": \"3bXiWZWR3CoZbhcsqfsMNa\", \"Genre\": \"['dance pop', 'german dance', 'pop dance', 'slap house', 'tropical house']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 61.0, \"Danceability\": 0.758, \"Energy\": 0.848, \"Loudness\": -3.84, \"Speechiness\": 0.0457, \"Acousticness\": 0.21, \"Liveness\": 0.114, \"Tempo\": 127.96, \"Duration (ms)\": 153149.0, \"Valence\": 0.706, \"Chord\": \"A#/Bb\"}, {\"Index\": 976, \"Highest Charting Position\": 16, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Savage\", \"Streams\": 4510218, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"55CHeLEfn5iJ0IIkgaa4si\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 75.0, \"Danceability\": 0.843, \"Energy\": 0.741, \"Loudness\": -5.609, \"Speechiness\": 0.334, \"Acousticness\": 0.0252, \"Liveness\": 0.096, \"Tempo\": 168.983, \"Duration (ms)\": 155497.0, \"Valence\": 0.68, \"Chord\": \"B\"}, {\"Index\": 977, \"Highest Charting Position\": 29, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"mad woman\", \"Streams\": 6796343, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2QDyYdZyhlP2fp79KZX8Bi\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 67.0, \"Danceability\": 0.592, \"Energy\": 0.699, \"Loudness\": -8.995, \"Speechiness\": 0.0471, \"Acousticness\": 0.655, \"Liveness\": 0.114, \"Tempo\": 141.916, \"Duration (ms)\": 237258.0, \"Valence\": 0.506, \"Chord\": \"D#/Eb\"}, {\"Index\": 978, \"Highest Charting Position\": 33, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"epiphany\", \"Streams\": 6085522, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"08fa9LFcFBTcilB3iq2e2A\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 66.0, \"Danceability\": 0.354, \"Energy\": 0.267, \"Loudness\": -13.69, \"Speechiness\": 0.0281, \"Acousticness\": 0.731, \"Liveness\": 0.0858, \"Tempo\": 94.219, \"Duration (ms)\": 289749.0, \"Valence\": 0.113, \"Chord\": \"C#/Db\"}, {\"Index\": 979, \"Highest Charting Position\": 41, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"peace\", \"Streams\": 5943851, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7MbT4I8qGntX4fMdqMQgke\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 67.0, \"Danceability\": 0.647, \"Energy\": 0.272, \"Loudness\": -12.906, \"Speechiness\": 0.0916, \"Acousticness\": 0.918, \"Liveness\": 0.0918, \"Tempo\": 150.044, \"Duration (ms)\": 234000.0, \"Valence\": 0.339, \"Chord\": \"F\"}, {\"Index\": 980, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Move Ya Hips (feat. Nicki Minaj & MadeinTYO)\", \"Streams\": 5768616, \"Artist\": \"A$AP Ferg\", \"Artist Followers\": 3037935.0, \"Song ID\": \"13v5IXnvO2BccWwOx5rb4s\", \"Genre\": \"['hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap', 'underground hip hop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 61.0, \"Danceability\": 0.808, \"Energy\": 0.676, \"Loudness\": -4.902, \"Speechiness\": 0.223, \"Acousticness\": 0.0618, \"Liveness\": 0.11, \"Tempo\": 144.018, \"Duration (ms)\": 144973.0, \"Valence\": 0.0763, \"Chord\": \"E\"}, {\"Index\": 981, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Sie ruft\", \"Streams\": 5752169, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"4CyCHkhRsDXUeP5K4Y3xjU\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 59.0, \"Danceability\": 0.819, \"Energy\": 0.507, \"Loudness\": -7.336, \"Speechiness\": 0.0881, \"Acousticness\": 0.482, \"Liveness\": 0.105, \"Tempo\": 130.009, \"Duration (ms)\": 152013.0, \"Valence\": 0.634, \"Chord\": \"C#/Db\"}, {\"Index\": 982, \"Highest Charting Position\": 144, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Tilidin Weg\", \"Streams\": 5674945, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"7idxewQZ24F0gQy2EWE6Ug\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 60.0, \"Danceability\": 0.882, \"Energy\": 0.526, \"Loudness\": -8.553, \"Speechiness\": 0.237, \"Acousticness\": 0.118, \"Liveness\": 0.0835, \"Tempo\": 109.075, \"Duration (ms)\": 180950.0, \"Valence\": 0.182, \"Chord\": \"A#/Bb\"}, {\"Index\": 983, \"Highest Charting Position\": 149, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Over Your Head\", \"Streams\": 5534361, \"Artist\": \"Future, Lil Uzi Vert\", \"Artist Followers\": 10491105.0, \"Song ID\": \"0Tcw8w9pvPrZoORgxsNASW\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 59.0, \"Danceability\": 0.773, \"Energy\": 0.742, \"Loudness\": -5.453, \"Speechiness\": 0.162, \"Acousticness\": 0.00198, \"Liveness\": 0.558, \"Tempo\": 148.949, \"Duration (ms)\": 186843.0, \"Valence\": 0.35, \"Chord\": \"F\"}, {\"Index\": 984, \"Highest Charting Position\": 47, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"hoax\", \"Streams\": 5375944, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6MWoRt97mnSTXZhu3ggi9C\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 66.0, \"Danceability\": 0.662, \"Energy\": 0.181, \"Loudness\": -15.065, \"Speechiness\": 0.0415, \"Acousticness\": 0.966, \"Liveness\": 0.133, \"Tempo\": 118.819, \"Duration (ms)\": 220043.0, \"Valence\": 0.429, \"Chord\": \"G#/Ab\"}, {\"Index\": 985, \"Highest Charting Position\": 25, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Blood On My Jeans\", \"Streams\": 4978899, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"0fCwrjKfWxF3xQhZrYUw4T\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 73.0, \"Danceability\": 0.868, \"Energy\": 0.55, \"Loudness\": -6.417, \"Speechiness\": 0.226, \"Acousticness\": 0.183, \"Liveness\": 0.109, \"Tempo\": 117.943, \"Duration (ms)\": 154767.0, \"Valence\": 0.464, \"Chord\": \"F#/Gb\"}, {\"Index\": 986, \"Highest Charting Position\": 171, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Narrow Road (feat. Lil Baby)\", \"Streams\": 4828004, \"Artist\": \"NLE Choppa\", \"Artist Followers\": 3372385.0, \"Song ID\": \"3GZd1aDsgKL71Kt3VIp0hc\", \"Genre\": \"['memphis hip hop']\", \"Release Date\": \"2020-07-30\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 64.0, \"Danceability\": 0.614, \"Energy\": 0.553, \"Loudness\": -8.225, \"Speechiness\": 0.169, \"Acousticness\": 0.0306, \"Liveness\": 0.203, \"Tempo\": 159.999, \"Duration (ms)\": 240297.0, \"Valence\": 0.161, \"Chord\": \"G\"}, {\"Index\": 987, \"Highest Charting Position\": 26, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Amarillo\", \"Streams\": 4695091, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"6zEgnpM0qYmHLDnh8WPejL\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 73.0, \"Danceability\": 0.641, \"Energy\": 0.857, \"Loudness\": -5.725, \"Speechiness\": 0.301, \"Acousticness\": 0.013, \"Liveness\": 0.0695, \"Tempo\": 122.728, \"Duration (ms)\": 157733.0, \"Valence\": 0.961, \"Chord\": \"C#/Db\"}, {\"Index\": 988, \"Highest Charting Position\": 179, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Singapur\", \"Streams\": 4661170, \"Artist\": \"El Alfa, Chael Produciendo\", \"Artist Followers\": 1779640.0, \"Song ID\": \"4QfZYDhGZc0T2RDvGiI69E\", \"Genre\": \"['dembow', 'latin', 'rap dominicano', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 69.0, \"Danceability\": 0.853, \"Energy\": 0.909, \"Loudness\": -2.473, \"Speechiness\": 0.229, \"Acousticness\": 0.0522, \"Liveness\": 0.129, \"Tempo\": 112.987, \"Duration (ms)\": 178407.0, \"Valence\": 0.803, \"Chord\": \"G\"}, {\"Index\": 989, \"Highest Charting Position\": 42, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Tattoo\", \"Streams\": 4588064, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6096559.0, \"Song ID\": \"4ZRrLHqzhGRXYj2qcB4s5S\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-07-09\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 78.0, \"Danceability\": 0.848, \"Energy\": 0.637, \"Loudness\": -5.132, \"Speechiness\": 0.156, \"Acousticness\": 0.0413, \"Liveness\": 0.0521, \"Tempo\": 96.988, \"Duration (ms)\": 222680.0, \"Valence\": 0.698, \"Chord\": \"A\"}, {\"Index\": 990, \"Highest Charting Position\": 86, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Ego Death (feat. Kanye West, FKA twigs & Skrillex)\", \"Streams\": 4583475, \"Artist\": \"Ty Dolla $ign\", \"Artist Followers\": 3866304.0, \"Song ID\": \"3Q5cLvkKsHJvYltf8k7HkO\", \"Genre\": \"['hip hop', 'pop', 'pop rap', 'r&b', 'southern hip hop', 'trap', 'trap soul']\", \"Release Date\": \"2020-10-22\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 71.0, \"Danceability\": 0.818, \"Energy\": 0.598, \"Loudness\": -5.948, \"Speechiness\": 0.113, \"Acousticness\": 0.0573, \"Liveness\": 0.634, \"Tempo\": 111.052, \"Duration (ms)\": 231618.0, \"Valence\": 0.331, \"Chord\": \"A#/Bb\"}, {\"Index\": 991, \"Highest Charting Position\": 33, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Morado\", \"Streams\": 4561936, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"3mQ6SLdxxaL52Yte7KF2Ks\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-01-09\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 71.0, \"Danceability\": 0.881, \"Energy\": 0.696, \"Loudness\": -3.838, \"Speechiness\": 0.0797, \"Acousticness\": 0.137, \"Liveness\": 0.0927, \"Tempo\": 97.002, \"Duration (ms)\": 200667.0, \"Valence\": 0.781, \"Chord\": \"B\"}, {\"Index\": 992, \"Highest Charting Position\": 101, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"ocean eyes\", \"Streams\": 4476954, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6pFTDHGJtKOxrQ85xRZ8Ue\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 1.0, \"Danceability\": 0.358, \"Energy\": 0.372, \"Loudness\": -7.664, \"Speechiness\": 0.0464, \"Acousticness\": 0.81, \"Liveness\": 0.0877, \"Tempo\": 144.833, \"Duration (ms)\": 200387.0, \"Valence\": 0.16, \"Chord\": \"E\"}, {\"Index\": 993, \"Highest Charting Position\": 82, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Lion King On Ice\", \"Streams\": 8293983, \"Artist\": \"J. Cole\", \"Artist Followers\": 14103694.0, \"Song ID\": \"1ZvBVbsaNqHEP6ymXaPGlj\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2020-07-22\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 64.0, \"Danceability\": 0.732, \"Energy\": 0.663, \"Loudness\": -7.616, \"Speechiness\": 0.192, \"Acousticness\": 0.0819, \"Liveness\": 0.115, \"Tempo\": 139.964, \"Duration (ms)\": 210587.0, \"Valence\": 0.227, \"Chord\": \"F#/Gb\"}, {\"Index\": 994, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Andere Welt\", \"Streams\": 5600868, \"Artist\": \"Capital Bra, Clueso, KC Rebell\", \"Artist Followers\": 4093115.0, \"Song ID\": \"5PAAUJTKLT0nCmHUlLdPXb\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-07-23\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 60.0, \"Danceability\": 0.692, \"Energy\": 0.764, \"Loudness\": -5.233, \"Speechiness\": 0.113, \"Acousticness\": 0.574, \"Liveness\": 0.106, \"Tempo\": 84.029, \"Duration (ms)\": 189686.0, \"Valence\": 0.564, \"Chord\": \"F\"}, {\"Index\": 995, \"Highest Charting Position\": 163, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"TELL ME WHY\", \"Streams\": 5056986, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"3jlxX3VXPiY3lvBBbppQD3\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.6, \"Energy\": 0.723, \"Loudness\": -4.928, \"Speechiness\": 0.158, \"Acousticness\": 0.109, \"Liveness\": 0.167, \"Tempo\": 149.881, \"Duration (ms)\": 195268.0, \"Valence\": 0.463, \"Chord\": \"F#/Gb\"}, {\"Index\": 996, \"Highest Charting Position\": 37, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Stay High\", \"Streams\": 5047752, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"21CkzgKCBCq5V4XKjiGSIj\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 75.0, \"Danceability\": 0.745, \"Energy\": 0.5, \"Loudness\": -6.184, \"Speechiness\": 0.135, \"Acousticness\": 0.439, \"Liveness\": 0.0943, \"Tempo\": 76.968, \"Duration (ms)\": 168685.0, \"Valence\": 0.433, \"Chord\": \"G#/Ab\"}, {\"Index\": 997, \"Highest Charting Position\": 161, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"What Makes You Beautiful\", \"Streams\": 4966428, \"Artist\": \"One Direction\", \"Artist Followers\": 22536304.0, \"Song ID\": \"4cluDES4hQEUhmXj6TXkSo\", \"Genre\": \"['boy band', 'pop', 'post-teen pop', 'talent show']\", \"Release Date\": \"2012-05-25\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 82.0, \"Danceability\": 0.726, \"Energy\": 0.787, \"Loudness\": -2.494, \"Speechiness\": 0.0737, \"Acousticness\": 0.009, \"Liveness\": 0.0596, \"Tempo\": 124.99, \"Duration (ms)\": 199987.0, \"Valence\": 0.888, \"Chord\": \"E\"}, {\"Index\": 998, \"Highest Charting Position\": 174, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Shit Changed\", \"Streams\": 4823401, \"Artist\": \"Ufo361, Sonus030\", \"Artist Followers\": 1700759.0, \"Song ID\": \"6du77YHyGWoFjbuHCFBHU3\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 52.0, \"Danceability\": 0.824, \"Energy\": 0.528, \"Loudness\": -9.236, \"Speechiness\": 0.175, \"Acousticness\": 0.144, \"Liveness\": 0.104, \"Tempo\": 157.005, \"Duration (ms)\": 183839.0, \"Valence\": 0.32, \"Chord\": \"A\"}, {\"Index\": 999, \"Highest Charting Position\": 35, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Tell Me U Luv Me (with Trippie Redd)\", \"Streams\": 4798078, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5JAYDuLRkODlVt6dgoalKk\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 72.0, \"Danceability\": 0.66, \"Energy\": 0.76, \"Loudness\": -5.726, \"Speechiness\": 0.0787, \"Acousticness\": 0.291, \"Liveness\": 0.632, \"Tempo\": 127.984, \"Duration (ms)\": 180129.0, \"Valence\": 0.394, \"Chord\": \"D\"}, {\"Index\": 1000, \"Highest Charting Position\": 27, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Bad Energy\", \"Streams\": 4761155, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"7d94IqWX2UmSKMGUYSGFJG\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 72.0, \"Danceability\": 0.654, \"Energy\": 0.452, \"Loudness\": -6.36, \"Speechiness\": 0.0439, \"Acousticness\": 0.17, \"Liveness\": 0.114, \"Tempo\": 138.034, \"Duration (ms)\": 186749.0, \"Valence\": 0.532, \"Chord\": \"G\"}, {\"Index\": 1001, \"Highest Charting Position\": 24, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Titanic\", \"Streams\": 4687464, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"1YM6c2sxbf2Jacl9IFgn4I\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 71.0, \"Danceability\": 0.567, \"Energy\": 0.545, \"Loudness\": -6.668, \"Speechiness\": 0.0448, \"Acousticness\": 0.168, \"Liveness\": 0.112, \"Tempo\": 174.146, \"Duration (ms)\": 176650.0, \"Valence\": 0.234, \"Chord\": \"C#/Db\"}, {\"Index\": 1002, \"Highest Charting Position\": 31, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Skechers\", \"Streams\": 4669248, \"Artist\": \"DripReport\", \"Artist Followers\": 92356.0, \"Song ID\": \"2alc8VZAzDgdAsL2QMk3hu\", \"Genre\": \"['viral rap']\", \"Release Date\": \"2020-01-12\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 73.0, \"Danceability\": 0.903, \"Energy\": 0.327, \"Loudness\": -9.727, \"Speechiness\": 0.0877, \"Acousticness\": 0.26, \"Liveness\": 0.108, \"Tempo\": 100.008, \"Duration (ms)\": 106000.0, \"Valence\": 0.274, \"Chord\": \"C#/Db\"}, {\"Index\": 1003, \"Highest Charting Position\": 47, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"The Bigger Picture\", \"Streams\": 4629083, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"44gRhRi2OhEf7moAUj6MD1\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 70.0, \"Danceability\": 0.59, \"Energy\": 0.618, \"Loudness\": -5.756, \"Speechiness\": 0.334, \"Acousticness\": 0.0127, \"Liveness\": 0.244, \"Tempo\": 96.459, \"Duration (ms)\": 252729.0, \"Valence\": 0.153, \"Chord\": \"C#/Db\"}, {\"Index\": 1004, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Story of My Life\", \"Streams\": 4628772, \"Artist\": \"One Direction\", \"Artist Followers\": 22536304.0, \"Song ID\": \"4nVBt6MZDDP6tRVdQTgxJg\", \"Genre\": \"['boy band', 'pop', 'post-teen pop', 'talent show']\", \"Release Date\": \"2013-11-25\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 81.0, \"Danceability\": 0.6, \"Energy\": 0.663, \"Loudness\": -5.802, \"Speechiness\": 0.0477, \"Acousticness\": 0.225, \"Liveness\": 0.119, \"Tempo\": 121.07, \"Duration (ms)\": 245493.0, \"Valence\": 0.286, \"Chord\": \"D#/Eb\"}, {\"Index\": 1005, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Hit My Line\", \"Streams\": 4621205, \"Artist\": \"Logic\", \"Artist Followers\": 5449291.0, \"Song ID\": \"24FR8mXTaiGZPrxnkf1kcP\", \"Genre\": \"['conscious hip hop', 'dmv rap', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 60.0, \"Danceability\": 0.62, \"Energy\": 0.786, \"Loudness\": -5.22, \"Speechiness\": 0.167, \"Acousticness\": 0.143, \"Liveness\": 0.46, \"Tempo\": 164.057, \"Duration (ms)\": 265191.0, \"Valence\": 0.679, \"Chord\": \"A\"}, {\"Index\": 1006, \"Highest Charting Position\": 10, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Party Girl (Remix)\", \"Streams\": 15129295, \"Artist\": \"StaySolidRocky, Lil Uzi Vert\", \"Artist Followers\": 150587.0, \"Song ID\": \"0XkmeG97T4mtYlWRJcrxec\", \"Genre\": \"['melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 62.0, \"Danceability\": 0.752, \"Energy\": 0.375, \"Loudness\": -10.157, \"Speechiness\": 0.204, \"Acousticness\": 0.533, \"Liveness\": 0.175, \"Tempo\": 129.995, \"Duration (ms)\": 147673.0, \"Valence\": 0.591, \"Chord\": \"F#/Gb\"}, {\"Index\": 1007, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Up Up And Away\", \"Streams\": 6229316, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"7pbg3ABlAZv2NiIdKbBBFm\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 72.0, \"Danceability\": 0.661, \"Energy\": 0.665, \"Loudness\": -6.356, \"Speechiness\": 0.053, \"Acousticness\": 0.538, \"Liveness\": 0.0981, \"Tempo\": 75.059, \"Duration (ms)\": 147548.0, \"Valence\": 0.486, \"Chord\": \"E\"}, {\"Index\": 1008, \"Highest Charting Position\": 46, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Man Of The Year\", \"Streams\": 6223001, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"7AvprzMsRJpybaalckaT8c\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 73.0, \"Danceability\": 0.621, \"Energy\": 0.695, \"Loudness\": -5.124, \"Speechiness\": 0.0911, \"Acousticness\": 0.00584, \"Liveness\": 0.086, \"Tempo\": 173.966, \"Duration (ms)\": 136408.0, \"Valence\": 0.298, \"Chord\": \"E\"}, {\"Index\": 1009, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Fighting Demons\", \"Streams\": 5946573, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"0440JCJyIAmINA8KcYgFb5\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 70.0, \"Danceability\": 0.707, \"Energy\": 0.67, \"Loudness\": -6.328, \"Speechiness\": 0.257, \"Acousticness\": 0.0813, \"Liveness\": 0.098, \"Tempo\": 163.099, \"Duration (ms)\": 200629.0, \"Valence\": 0.235, \"Chord\": \"G\"}, {\"Index\": 1010, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Can't Die\", \"Streams\": 5777859, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4PPLJAEYBSOcnzr9TZoqf9\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 71.0, \"Danceability\": 0.652, \"Energy\": 0.671, \"Loudness\": -5.89, \"Speechiness\": 0.0756, \"Acousticness\": 0.0222, \"Liveness\": 0.107, \"Tempo\": 84.008, \"Duration (ms)\": 182922.0, \"Valence\": 0.274, \"Chord\": \"D\"}, {\"Index\": 1011, \"Highest Charting Position\": 44, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Screw Juice\", \"Streams\": 5394197, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4F6YLjakjqWFTgC5qfEwPQ\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 69.0, \"Danceability\": 0.595, \"Energy\": 0.528, \"Loudness\": -7.371, \"Speechiness\": 0.0935, \"Acousticness\": 0.082, \"Liveness\": 0.142, \"Tempo\": 150.075, \"Duration (ms)\": 179464.0, \"Valence\": 0.515, \"Chord\": \"F\"}, {\"Index\": 1012, \"Highest Charting Position\": 129, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Past Life (with Selena Gomez)\", \"Streams\": 5228433, \"Artist\": \"Trevor Daniel\", \"Artist Followers\": 632097.0, \"Song ID\": \"7MN8RYSofZsFROBlEOAzXq\", \"Genre\": \"['alternative r&b', 'melodic rap', 'pop rap']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 47.0, \"Danceability\": 0.575, \"Energy\": 0.543, \"Loudness\": -5.062, \"Speechiness\": 0.0529, \"Acousticness\": 0.102, \"Liveness\": 0.176, \"Tempo\": 159.905, \"Duration (ms)\": 186480.0, \"Valence\": 0.283, \"Chord\": \"D#/Eb\"}, {\"Index\": 1013, \"Highest Charting Position\": 45, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"I Want It\", \"Streams\": 5137482, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"2SVx3uds6jTWALFxevIWMA\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 69.0, \"Danceability\": 0.288, \"Energy\": 0.638, \"Loudness\": -6.935, \"Speechiness\": 0.0779, \"Acousticness\": 0.133, \"Liveness\": 0.14, \"Tempo\": 66.424, \"Duration (ms)\": 173114.0, \"Valence\": 0.147, \"Chord\": \"E\"}, {\"Index\": 1014, \"Highest Charting Position\": 56, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Ransom\", \"Streams\": 5097394, \"Artist\": \"Lil Tecca\", \"Artist Followers\": 4022792.0, \"Song ID\": \"1lOe9qE0vR9zwWQAOk6CoO\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-08-30\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.745, \"Energy\": 0.642, \"Loudness\": -6.257, \"Speechiness\": 0.287, \"Acousticness\": 0.0204, \"Liveness\": 0.0658, \"Tempo\": 179.974, \"Duration (ms)\": 131240.0, \"Valence\": 0.226, \"Chord\": \"G\"}, {\"Index\": 1015, \"Highest Charting Position\": 49, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Diosa\", \"Streams\": 4868180, \"Artist\": \"Myke Towers\", \"Artist Followers\": 6161098.0, \"Song ID\": \"3JHpk0DOTOzyh0777JFAky\", \"Genre\": \"['trap latino']\", \"Release Date\": \"2020-01-24\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 74.0, \"Danceability\": 0.801, \"Energy\": 0.745, \"Loudness\": -3.733, \"Speechiness\": 0.063, \"Acousticness\": 0.398, \"Liveness\": 0.153, \"Tempo\": 104.965, \"Duration (ms)\": 214013.0, \"Valence\": 0.245, \"Chord\": \"F#/Gb\"}, {\"Index\": 1016, \"Highest Charting Position\": 169, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Never Know (feat. SHIRIN DAVID)\", \"Streams\": 4803071, \"Artist\": \"Luciano\", \"Artist Followers\": 942380.0, \"Song ID\": \"5Hkj1XjMJv5QCGc9NwZm6z\", \"Genre\": \"['german drill', 'german hip hop']\", \"Release Date\": \"2020-07-16\", \"Weeks Charted\": \"2020-07-17--2020-07-24\", \"Popularity\": 60.0, \"Danceability\": 0.874, \"Energy\": 0.542, \"Loudness\": -7.064, \"Speechiness\": 0.344, \"Acousticness\": 0.0621, \"Liveness\": 0.181, \"Tempo\": 142.016, \"Duration (ms)\": 196933.0, \"Valence\": 0.481, \"Chord\": \"A#/Bb\"}, {\"Index\": 1017, \"Highest Charting Position\": 5, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"La Dif\\u00edcil\", \"Streams\": 4727554, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"6NfrH0ANGmgBXyxgV2PeXt\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 78.0, \"Danceability\": 0.685, \"Energy\": 0.848, \"Loudness\": -4.561, \"Speechiness\": 0.0858, \"Acousticness\": 0.0861, \"Liveness\": 0.0783, \"Tempo\": 179.87, \"Duration (ms)\": 163084.0, \"Valence\": 0.761, \"Chord\": \"G#/Ab\"}, {\"Index\": 1018, \"Highest Charting Position\": 20, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"TROLLZ (with Nicki Minaj)\", \"Streams\": 4700152, \"Artist\": \"6ix9ine\", \"Artist Followers\": 6514102.0, \"Song ID\": \"3dVvWnj4D8JGkKvo6Hucso\", \"Genre\": \"['emo rap', 'rap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 65.0, \"Danceability\": 0.744, \"Energy\": 0.422, \"Loudness\": -8.946, \"Speechiness\": 0.294, \"Acousticness\": 0.0319, \"Liveness\": 0.11, \"Tempo\": 180.006, \"Duration (ms)\": 202667.0, \"Valence\": 0.493, \"Chord\": \"C#/Db\"}, {\"Index\": 1019, \"Highest Charting Position\": 44, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Old Town Road - Remix\", \"Streams\": 4643817, \"Artist\": \"Lil Nas X, Billy Ray Cyrus\", \"Artist Followers\": 5488666.0, \"Song ID\": \"2YpeDb67231RjR0MgVLzsG\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.878, \"Energy\": 0.619, \"Loudness\": -5.56, \"Speechiness\": 0.102, \"Acousticness\": 0.0533, \"Liveness\": 0.113, \"Tempo\": 136.041, \"Duration (ms)\": 157067.0, \"Valence\": 0.639, \"Chord\": \"F#/Gb\"}, {\"Index\": 1020, \"Highest Charting Position\": 67, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"The Adventures of Moon Man & Slim Shady (with Eminem)\", \"Streams\": 4639929, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"38iBrrbbXyWaSPkmuDNgjZ\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 67.0, \"Danceability\": 0.88, \"Energy\": 0.787, \"Loudness\": -5.189, \"Speechiness\": 0.118, \"Acousticness\": 0.226, \"Liveness\": 0.12, \"Tempo\": 113.018, \"Duration (ms)\": 264834.0, \"Valence\": 0.588, \"Chord\": \"G#/Ab\"}, {\"Index\": 1021, \"Highest Charting Position\": 25, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"China\", \"Streams\": 4627026, \"Artist\": \"Anuel AA, Daddy Yankee, KAROL G, Ozuna, J Balvin\", \"Artist Followers\": 18306226.0, \"Song ID\": \"2ksOAxtIxY8yElEWw8RhgK\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2019-07-19\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.786, \"Energy\": 0.808, \"Loudness\": -3.702, \"Speechiness\": 0.0882, \"Acousticness\": 0.0846, \"Liveness\": 0.0822, \"Tempo\": 105.027, \"Duration (ms)\": 301714.0, \"Valence\": 0.609, \"Chord\": \"G\"}, {\"Index\": 1022, \"Highest Charting Position\": 29, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Hola - Remix\", \"Streams\": 4617726, \"Artist\": \"Dalex, Lenny Tav\\u00e1rez, Chencho Corleone, Juhn, D\\u00edmelo Flow\", \"Artist Followers\": 3600989.0, \"Song ID\": \"5stPVcRqb4qixbafP9e8lt\", \"Genre\": \"['latin', 'r&b en espanol', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-01\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.654, \"Energy\": 0.672, \"Loudness\": -5.98, \"Speechiness\": 0.311, \"Acousticness\": 0.471, \"Liveness\": 0.0781, \"Tempo\": 181.857, \"Duration (ms)\": 249520.0, \"Valence\": 0.343, \"Chord\": \"C\"}, {\"Index\": 1023, \"Highest Charting Position\": 6, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Ignorantes\", \"Streams\": 4613982, \"Artist\": \"Bad Bunny, Sech\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3wYRLYuO1M88d8woWUIxct\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 74.0, \"Danceability\": 0.85, \"Energy\": 0.536, \"Loudness\": -5.161, \"Speechiness\": 0.0599, \"Acousticness\": 0.267, \"Liveness\": 0.0996, \"Tempo\": 96.029, \"Duration (ms)\": 210607.0, \"Valence\": 0.505, \"Chord\": \"C#/Db\"}, {\"Index\": 1024, \"Highest Charting Position\": 2, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Yummy\", \"Streams\": 4599349, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"41L3O37CECZt3N7ziG2z7l\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-03\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 72.0, \"Danceability\": 0.687, \"Energy\": 0.514, \"Loudness\": -6.612, \"Speechiness\": 0.0897, \"Acousticness\": 0.366, \"Liveness\": 0.116, \"Tempo\": 145.921, \"Duration (ms)\": 210427.0, \"Valence\": 0.494, \"Chord\": \"A\"}, {\"Index\": 1025, \"Highest Charting Position\": 29, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"High Fashion (feat. Mustard)\", \"Streams\": 4592772, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6608815.0, \"Song ID\": \"07KXEDMj78x68D884wgVEm\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 77.0, \"Danceability\": 0.831, \"Energy\": 0.499, \"Loudness\": -8.442, \"Speechiness\": 0.114, \"Acousticness\": 0.269, \"Liveness\": 0.3, \"Tempo\": 97.956, \"Duration (ms)\": 220487.0, \"Valence\": 0.511, \"Chord\": \"B\"}, {\"Index\": 1026, \"Highest Charting Position\": 69, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Like That (feat. Gucci Mane)\", \"Streams\": 4565377, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"4EivmOT13NMpNSfTKn9p4s\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 77.0, \"Danceability\": 0.879, \"Energy\": 0.498, \"Loudness\": -6.027, \"Speechiness\": 0.18, \"Acousticness\": 0.239, \"Liveness\": 0.0967, \"Tempo\": 106.044, \"Duration (ms)\": 163173.0, \"Valence\": 0.405, \"Chord\": \"E\"}, {\"Index\": 1027, \"Highest Charting Position\": 132, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Goodbyes (feat. Young Thug)\", \"Streams\": 4527742, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"0t3ZvGKlmYmVsDzBJAXK8C\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 78.0, \"Danceability\": 0.548, \"Energy\": 0.653, \"Loudness\": -3.875, \"Speechiness\": 0.081, \"Acousticness\": 0.456, \"Liveness\": 0.103, \"Tempo\": 150.068, \"Duration (ms)\": 174853.0, \"Valence\": 0.163, \"Chord\": \"F\"}, {\"Index\": 1028, \"Highest Charting Position\": 23, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"BOP\", \"Streams\": 4496450, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"6Ozh9Ok6h4Oi1wUSLtBseN\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.769, \"Energy\": 0.787, \"Loudness\": -3.909, \"Speechiness\": 0.367, \"Acousticness\": 0.189, \"Liveness\": 0.129, \"Tempo\": 126.77, \"Duration (ms)\": 159715.0, \"Valence\": 0.836, \"Chord\": \"B\"}, {\"Index\": 1029, \"Highest Charting Position\": 21, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Sigues Con El\", \"Streams\": 4485060, \"Artist\": \"D\\u00edmelo Flow, Arcangel, Sech\", \"Artist Followers\": 231580.0, \"Song ID\": \"7sQKy5vlPQllr0k9IjYJv3\", \"Genre\": \"['latin', 'perreo', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.883, \"Energy\": 0.668, \"Loudness\": -2.957, \"Speechiness\": 0.113, \"Acousticness\": 0.11, \"Liveness\": 0.0734, \"Tempo\": 87.972, \"Duration (ms)\": 226533.0, \"Valence\": 0.676, \"Chord\": \"A\"}, {\"Index\": 1030, \"Highest Charting Position\": 78, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Anxiety - Intro\", \"Streams\": 8449557, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"02XcRGWPkvomFvzTamEKHg\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 60.0, \"Danceability\": 0.307, \"Energy\": 0.528, \"Loudness\": -11.337, \"Speechiness\": 0.108, \"Acousticness\": 0.972, \"Liveness\": 0.222, \"Tempo\": 174.795, \"Duration (ms)\": 70395.0, \"Valence\": 0.58, \"Chord\": \"B\"}, {\"Index\": 1031, \"Highest Charting Position\": 112, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Juice WRLD Speaks From Heaven - Outro\", \"Streams\": 6682917, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"1OjiYjgPZyxS0AiXiSnuYI\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 59.0, \"Danceability\": 0.392, \"Energy\": 0.373, \"Loudness\": -14.097, \"Speechiness\": 0.0968, \"Acousticness\": 0.991, \"Liveness\": 0.545, \"Tempo\": 121.678, \"Duration (ms)\": 30583.0, \"Valence\": 0.519, \"Chord\": \"C\"}, {\"Index\": 1032, \"Highest Charting Position\": 113, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"The Man, The Myth, The Legend - Interlude\", \"Streams\": 6640728, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4sjdZEEQvR1sXrRNSuBfbA\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 58.0, \"Danceability\": 0.667, \"Energy\": 0.447, \"Loudness\": -14.625, \"Speechiness\": 0.761, \"Acousticness\": 0.916, \"Liveness\": 0.612, \"Tempo\": 83.534, \"Duration (ms)\": 136545.0, \"Valence\": 0.829, \"Chord\": \"D\"}, {\"Index\": 1033, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Tiefschwarz (feat. Samra)\", \"Streams\": 5867111, \"Artist\": \"Kontra K\", \"Artist Followers\": 1818624.0, \"Song ID\": \"7jMMoHhgq6iwVT5ykyxsJt\", \"Genre\": \"['christlicher rap', 'german hip hop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 62.0, \"Danceability\": 0.751, \"Energy\": 0.783, \"Loudness\": -5.926, \"Speechiness\": 0.22, \"Acousticness\": 0.0715, \"Liveness\": 0.114, \"Tempo\": 94.003, \"Duration (ms)\": 189739.0, \"Valence\": 0.379, \"Chord\": \"G\"}, {\"Index\": 1034, \"Highest Charting Position\": 57, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Wash Us In The Blood\", \"Streams\": 5586085, \"Artist\": \"Kanye West, Travis Scott\", \"Artist Followers\": 14624703.0, \"Song ID\": \"7mEUjhl6aTztdHCrxoTgBG\", \"Genre\": \"['chicago rap', 'rap']\", \"Release Date\": \"2020-06-30\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 64.0, \"Danceability\": 0.67, \"Energy\": 0.847, \"Loudness\": -4.85, \"Speechiness\": 0.409, \"Acousticness\": 0.184, \"Liveness\": 0.304, \"Tempo\": 137.22, \"Duration (ms)\": 189827.0, \"Valence\": 0.381, \"Chord\": \"A#/Bb\"}, {\"Index\": 1035, \"Highest Charting Position\": 53, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Gangstas\", \"Streams\": 5104422, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"1hg3RlqFZXJb5YgRoK9qmF\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 71.0, \"Danceability\": 0.548, \"Energy\": 0.506, \"Loudness\": -7.434, \"Speechiness\": 0.102, \"Acousticness\": 0.203, \"Liveness\": 0.0788, \"Tempo\": 119.987, \"Duration (ms)\": 160000.0, \"Valence\": 0.557, \"Chord\": \"E\"}, {\"Index\": 1036, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Monster\", \"Streams\": 5030481, \"Artist\": \"Red Velvet - IRENE & SEULGI\", \"Artist Followers\": 383695.0, \"Song ID\": \"6c1QaQHdDhtFMfUkhueuXK\", \"Genre\": \"['k-pop']\", \"Release Date\": \"2020-07-06\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 70.0, \"Danceability\": 0.631, \"Energy\": 0.748, \"Loudness\": -2.569, \"Speechiness\": 0.0488, \"Acousticness\": 0.212, \"Liveness\": 0.537, \"Tempo\": 115.665, \"Duration (ms)\": 178413.0, \"Valence\": 0.351, \"Chord\": \"E\"}, {\"Index\": 1037, \"Highest Charting Position\": 139, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"YAYA\", \"Streams\": 4729070, \"Artist\": \"6ix9ine\", \"Artist Followers\": 6514102.0, \"Song ID\": \"6EfBMJQwe2xLgldra6DaYp\", \"Genre\": \"['emo rap', 'rap']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 60.0, \"Danceability\": 0.672, \"Energy\": 0.733, \"Loudness\": -5.377, \"Speechiness\": 0.0566, \"Acousticness\": 0.00289, \"Liveness\": 0.199, \"Tempo\": 105.043, \"Duration (ms)\": 149857.0, \"Valence\": 0.354, \"Chord\": \"B\"}, {\"Index\": 1038, \"Highest Charting Position\": 174, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Narcos\", \"Streams\": 4633313, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"7mcdgAXmb35dakBnfDIv3q\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 68.0, \"Danceability\": 0.614, \"Energy\": 0.746, \"Loudness\": -3.527, \"Speechiness\": 0.196, \"Acousticness\": 0.347, \"Liveness\": 0.0874, \"Tempo\": 168.072, \"Duration (ms)\": 259250.0, \"Valence\": 0.601, \"Chord\": \"A#/Bb\"}, {\"Index\": 1039, \"Highest Charting Position\": 105, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"This City\", \"Streams\": 4597406, \"Artist\": \"Sam Fischer\", \"Artist Followers\": 122883.0, \"Song ID\": \"3H3r2nKWa3Yk5gt8xgmsEt\", \"Genre\": \"['alt z', 'australian pop', 'dance pop', 'indie cafe pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2019-12-11\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 80.0, \"Danceability\": 0.605, \"Energy\": 0.377, \"Loudness\": -6.213, \"Speechiness\": 0.0443, \"Acousticness\": 0.733, \"Liveness\": 0.0808, \"Tempo\": 73.877, \"Duration (ms)\": 194853.0, \"Valence\": 0.519, \"Chord\": \"B\"}, {\"Index\": 1040, \"Highest Charting Position\": 64, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Make It Rain (feat. Rowdy Rebel)\", \"Streams\": 4594248, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"71d7LaAgPcNcUopu3OzmP7\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 62.0, \"Danceability\": 0.5, \"Energy\": 0.767, \"Loudness\": -4.105, \"Speechiness\": 0.403, \"Acousticness\": 0.162, \"Liveness\": 0.385, \"Tempo\": 159.477, \"Duration (ms)\": 202443.0, \"Valence\": 0.58, \"Chord\": \"C#/Db\"}, {\"Index\": 1041, \"Highest Charting Position\": 46, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lalala\", \"Streams\": 4541965, \"Artist\": \"Y2K, bbno$\", \"Artist Followers\": 268766.0, \"Song ID\": \"51Fjme0JiitpyXKuyQiCDo\", \"Genre\": \"['pop rap']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.843, \"Energy\": 0.39, \"Loudness\": -7.899, \"Speechiness\": 0.0846, \"Acousticness\": 0.178, \"Liveness\": 0.137, \"Tempo\": 129.972, \"Duration (ms)\": 160627.0, \"Valence\": 0.495, \"Chord\": \"D\"}, {\"Index\": 1042, \"Highest Charting Position\": 79, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Something Special\", \"Streams\": 4535580, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"5kkaSMcf4BFlhRRICCKZb6\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 72.0, \"Danceability\": 0.739, \"Energy\": 0.616, \"Loudness\": -6.963, \"Speechiness\": 0.0338, \"Acousticness\": 0.252, \"Liveness\": 0.101, \"Tempo\": 91.071, \"Duration (ms)\": 158466.0, \"Valence\": 0.654, \"Chord\": \"G\"}, {\"Index\": 1043, \"Highest Charting Position\": 58, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Aim For The Moon (feat. Quavo)\", \"Streams\": 9011502, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"6O7fPYTsb2mY0PiFt2ymDB\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 67.0, \"Danceability\": 0.713, \"Energy\": 0.605, \"Loudness\": -7.487, \"Speechiness\": 0.107, \"Acousticness\": 0.497, \"Liveness\": 0.115, \"Tempo\": 142.025, \"Duration (ms)\": 175756.0, \"Valence\": 0.432, \"Chord\": \"B\"}, {\"Index\": 1044, \"Highest Charting Position\": 63, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"44 BullDog\", \"Streams\": 8443771, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"7sjFIZ1g5QLJLGja3k592K\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 66.0, \"Danceability\": 0.8, \"Energy\": 0.564, \"Loudness\": -5.817, \"Speechiness\": 0.4, \"Acousticness\": 0.0287, \"Liveness\": 0.112, \"Tempo\": 139.989, \"Duration (ms)\": 150857.0, \"Valence\": 0.318, \"Chord\": \"G#/Ab\"}, {\"Index\": 1045, \"Highest Charting Position\": 88, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Creature (feat. Swae Lee)\", \"Streams\": 7308690, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"3eV2WT9YhfzkxbufnBF8wK\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 66.0, \"Danceability\": 0.794, \"Energy\": 0.717, \"Loudness\": -5.73, \"Speechiness\": 0.251, \"Acousticness\": 0.0511, \"Liveness\": 0.195, \"Tempo\": 141.881, \"Duration (ms)\": 202816.0, \"Valence\": 0.372, \"Chord\": \"G\"}, {\"Index\": 1046, \"Highest Charting Position\": 95, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Yea Yea\", \"Streams\": 7112419, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"0bjgQ24UZGwKikldIyEOgf\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 63.0, \"Danceability\": 0.717, \"Energy\": 0.474, \"Loudness\": -8.383, \"Speechiness\": 0.403, \"Acousticness\": 0.0509, \"Liveness\": 0.139, \"Tempo\": 123.906, \"Duration (ms)\": 185804.0, \"Valence\": 0.448, \"Chord\": \"F\"}, {\"Index\": 1047, \"Highest Charting Position\": 100, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Enjoy Yourself (feat. Karol G)\", \"Streams\": 6620040, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"3NWrHCwvyII4fTx05PN3IO\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 70.0, \"Danceability\": 0.764, \"Energy\": 0.676, \"Loudness\": -6.761, \"Speechiness\": 0.0927, \"Acousticness\": 0.389, \"Liveness\": 0.215, \"Tempo\": 97.02, \"Duration (ms)\": 197938.0, \"Valence\": 0.461, \"Chord\": \"B\"}, {\"Index\": 1048, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Bad Bitch From Tokyo (Intro)\", \"Streams\": 6144736, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"4OGIeHtYhRTJ8iW21UUyZW\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 59.0, \"Danceability\": 0.645, \"Energy\": 0.64, \"Loudness\": -6.871, \"Speechiness\": 0.179, \"Acousticness\": 0.395, \"Liveness\": 0.286, \"Tempo\": 140.248, \"Duration (ms)\": 48000.0, \"Valence\": 0.674, \"Chord\": \"A#/Bb\"}, {\"Index\": 1049, \"Highest Charting Position\": 117, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Snitching (feat. Quavo & Future)\", \"Streams\": 6102253, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"2FhEj9lvEIaJihjFprRrGt\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 59.0, \"Danceability\": 0.944, \"Energy\": 0.579, \"Loudness\": -4.961, \"Speechiness\": 0.191, \"Acousticness\": 0.0381, \"Liveness\": 0.253, \"Tempo\": 135.033, \"Duration (ms)\": 259346.0, \"Valence\": 0.769, \"Chord\": \"G#/Ab\"}, {\"Index\": 1050, \"Highest Charting Position\": 121, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"West Coast Shit (feat. Tyga & Quavo)\", \"Streams\": 5931242, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"1JDhNQ0oOT7XpclZn3aQ8F\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 61.0, \"Danceability\": 0.831, \"Energy\": 0.762, \"Loudness\": -5.656, \"Speechiness\": 0.207, \"Acousticness\": 0.0885, \"Liveness\": 0.107, \"Tempo\": 99.999, \"Duration (ms)\": 192000.0, \"Valence\": 0.495, \"Chord\": \"B\"}, {\"Index\": 1051, \"Highest Charting Position\": 72, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Deep End Freestyle\", \"Streams\": 5280810, \"Artist\": \"Sleepy Hallow, Foushe\\u00e9\", \"Artist Followers\": 411262.0, \"Song ID\": \"2AlYncTpVHKwHb55F9lF6O\", \"Genre\": \"['brooklyn drill', 'nyc rap']\", \"Release Date\": \"2020-06-05\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 72.0, \"Danceability\": 0.868, \"Energy\": 0.479, \"Loudness\": -6.687, \"Speechiness\": 0.445, \"Acousticness\": 0.703, \"Liveness\": 0.102, \"Tempo\": 133.928, \"Duration (ms)\": 115200.0, \"Valence\": 0.776, \"Chord\": \"E\"}, {\"Index\": 1052, \"Highest Charting Position\": 56, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Tommy Lee (feat. Post Malone)\", \"Streams\": 5031845, \"Artist\": \"Tyla Yaweh\", \"Artist Followers\": 359133.0, \"Song ID\": \"5QZKcQDp0tCcvMdyqEciBV\", \"Genre\": \"['cali rap', 'melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 73.0, \"Danceability\": 0.457, \"Energy\": 0.621, \"Loudness\": -5.923, \"Speechiness\": 0.138, \"Acousticness\": 0.218, \"Liveness\": 0.0944, \"Tempo\": 85.359, \"Duration (ms)\": 224638.0, \"Valence\": 0.634, \"Chord\": \"A#/Bb\"}, {\"Index\": 1053, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Tunnel Vision (Outro)\", \"Streams\": 4907751, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"2SxR5RitJdsG6wINvJLBSD\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 60.0, \"Danceability\": 0.718, \"Energy\": 0.66, \"Loudness\": -7.39, \"Speechiness\": 0.325, \"Acousticness\": 0.363, \"Liveness\": 0.159, \"Tempo\": 142.879, \"Duration (ms)\": 132587.0, \"Valence\": 0.659, \"Chord\": \"D\"}, {\"Index\": 1054, \"Highest Charting Position\": 7, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Si Veo a Tu Mam\\u00e1\", \"Streams\": 4638728, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"41wtwzCZkXwpnakmwJ239F\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 80.0, \"Danceability\": 0.9, \"Energy\": 0.603, \"Loudness\": -5.313, \"Speechiness\": 0.0646, \"Acousticness\": 0.402, \"Liveness\": 0.134, \"Tempo\": 129.928, \"Duration (ms)\": 170972.0, \"Valence\": 0.824, \"Chord\": \"D\"}, {\"Index\": 1055, \"Highest Charting Position\": 177, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Prospect (ft. Lil Baby)\", \"Streams\": 4571916, \"Artist\": \"iann dior\", \"Artist Followers\": 1276292.0, \"Song ID\": \"4iHSE5R1U8jf84tRn52xRt\", \"Genre\": \"['melodic rap', 'pop rap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 68.0, \"Danceability\": 0.816, \"Energy\": 0.579, \"Loudness\": -6.097, \"Speechiness\": 0.0867, \"Acousticness\": 0.203, \"Liveness\": 0.127, \"Tempo\": 120.078, \"Duration (ms)\": 226314.0, \"Valence\": 0.43, \"Chord\": \"C#/Db\"}, {\"Index\": 1056, \"Highest Charting Position\": 55, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"No Me Conoce - Remix\", \"Streams\": 4501188, \"Artist\": \"Jhay Cortez, J Balvin, Bad Bunny\", \"Artist Followers\": 2435159.0, \"Song ID\": \"4R8BJggjosTswLxtkw8V7P\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-05-24\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.806, \"Energy\": 0.786, \"Loudness\": -3.831, \"Speechiness\": 0.0741, \"Acousticness\": 0.145, \"Liveness\": 0.0935, \"Tempo\": 91.973, \"Duration (ms)\": 309120.0, \"Valence\": 0.58, \"Chord\": \"A#/Bb\"}, {\"Index\": 1057, \"Highest Charting Position\": 189, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"El Manual\", \"Streams\": 4470597, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"7kOf0qHO4Rcwk6QJifZDRJ\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 67.0, \"Danceability\": 0.843, \"Energy\": 0.845, \"Loudness\": -2.344, \"Speechiness\": 0.0503, \"Acousticness\": 0.35, \"Liveness\": 0.0527, \"Tempo\": 126.989, \"Duration (ms)\": 210624.0, \"Valence\": 0.898, \"Chord\": \"C\"}, {\"Index\": 1058, \"Highest Charting Position\": 181, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Thunder\", \"Streams\": 4468668, \"Artist\": \"Imagine Dragons\", \"Artist Followers\": 35299488.0, \"Song ID\": \"1zB4vmk8tFRmM9UULNzbLB\", \"Genre\": \"['modern rock', 'pop', 'rock']\", \"Release Date\": \"2017-06-23\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-05--2020-06-12\\n2020-02-07--2020-02-14\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.605, \"Energy\": 0.822, \"Loudness\": -4.833, \"Speechiness\": 0.0438, \"Acousticness\": 0.00671, \"Liveness\": 0.147, \"Tempo\": 167.997, \"Duration (ms)\": 187147.0, \"Valence\": 0.288, \"Chord\": \"C\"}, {\"Index\": 1059, \"Highest Charting Position\": 158, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"El Efecto - Remix\", \"Streams\": 4433384, \"Artist\": \"Rauw Alejandro, Chencho Corleone, KEVVO, Bryant Myers, Lyanno, Dalex\", \"Artist Followers\": 6096559.0, \"Song ID\": \"74j34STf8L6uADnTN69ohv\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 73.0, \"Danceability\": 0.771, \"Energy\": 0.769, \"Loudness\": -3.504, \"Speechiness\": 0.0694, \"Acousticness\": 0.18, \"Liveness\": 0.345, \"Tempo\": 167.969, \"Duration (ms)\": 289899.0, \"Valence\": 0.931, \"Chord\": \"C\"}, {\"Index\": 1060, \"Highest Charting Position\": 122, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Better Now\", \"Streams\": 4431571, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"7dt6x5M1jzdTEt8oCbisTK\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2018-04-27\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.68, \"Energy\": 0.578, \"Loudness\": -5.804, \"Speechiness\": 0.04, \"Acousticness\": 0.331, \"Liveness\": 0.135, \"Tempo\": 145.038, \"Duration (ms)\": 231267.0, \"Valence\": 0.341, \"Chord\": \"A#/Bb\"}, {\"Index\": 1061, \"Highest Charting Position\": 185, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Don't Stop Believin'\", \"Streams\": 4394985, \"Artist\": \"Journey\", \"Artist Followers\": 3731820.0, \"Song ID\": \"4bHsxqR3GMrXTxEPLuK5ue\", \"Genre\": \"['album rock', 'classic rock', 'hard rock', 'mellow gold', 'rock', 'soft rock']\", \"Release Date\": \"1981\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-19--2020-06-26\", \"Popularity\": 81.0, \"Danceability\": 0.5, \"Energy\": 0.748, \"Loudness\": -9.072, \"Speechiness\": 0.0363, \"Acousticness\": 0.127, \"Liveness\": 0.447, \"Tempo\": 118.852, \"Duration (ms)\": 250987.0, \"Valence\": 0.514, \"Chord\": \"E\"}, {\"Index\": 1062, \"Highest Charting Position\": 90, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"BLACK PARADE\", \"Streams\": 5474807, \"Artist\": \"Beyonc\\u00e9\", \"Artist Followers\": 28335112.0, \"Song ID\": \"2qzUpSVI4NnPyWxbXwumTj\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'r&b']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 61.0, \"Danceability\": 0.824, \"Energy\": 0.555, \"Loudness\": -5.817, \"Speechiness\": 0.05, \"Acousticness\": 0.00337, \"Liveness\": 0.217, \"Tempo\": 120.002, \"Duration (ms)\": 281273.0, \"Valence\": 0.0611, \"Chord\": \"C#/Db\"}, {\"Index\": 1063, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"XXL\", \"Streams\": 5415994, \"Artist\": \"Miksu / Macloud, Summer Cem, Luciano, Jamule\", \"Artist Followers\": 30683.0, \"Song ID\": \"0p3euGPg5LgFeQGC7bBFuR\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 64.0, \"Danceability\": 0.798, \"Energy\": 0.527, \"Loudness\": -7.671, \"Speechiness\": 0.0447, \"Acousticness\": 0.227, \"Liveness\": 0.108, \"Tempo\": 114.008, \"Duration (ms)\": 166173.0, \"Valence\": 0.548, \"Chord\": \"F\"}, {\"Index\": 1064, \"Highest Charting Position\": 70, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Salt\", \"Streams\": 4874960, \"Artist\": \"Ava Max\", \"Artist Followers\": 1251372.0, \"Song ID\": \"2o2p9xH3bkSDLcp6phIF4J\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 1.0, \"Danceability\": 0.693, \"Energy\": 0.835, \"Loudness\": -3.242, \"Speechiness\": 0.0624, \"Acousticness\": 0.131, \"Liveness\": 0.073, \"Tempo\": 128.052, \"Duration (ms)\": 180283.0, \"Valence\": 0.744, \"Chord\": \"F#/Gb\"}, {\"Index\": 1065, \"Highest Charting Position\": 52, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Daisies\", \"Streams\": 4838067, \"Artist\": \"Katy Perry\", \"Artist Followers\": 18936929.0, \"Song ID\": \"4uqh9bualXNHXXwO2wPorc\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 68.0, \"Danceability\": 0.639, \"Energy\": 0.546, \"Loudness\": -5.382, \"Speechiness\": 0.0407, \"Acousticness\": 0.0837, \"Liveness\": 0.122, \"Tempo\": 122.179, \"Duration (ms)\": 173124.0, \"Valence\": 0.149, \"Chord\": \"C#/Db\"}, {\"Index\": 1066, \"Highest Charting Position\": 142, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Emotionally Scarred\", \"Streams\": 4633237, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"7ge7BHazYbVKi8qyZUX1Bm\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 71.0, \"Danceability\": 0.585, \"Energy\": 0.641, \"Loudness\": -4.269, \"Speechiness\": 0.133, \"Acousticness\": 0.0286, \"Liveness\": 0.316, \"Tempo\": 88.284, \"Duration (ms)\": 197530.0, \"Valence\": 0.266, \"Chord\": \"F#/Gb\"}, {\"Index\": 1067, \"Highest Charting Position\": 32, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Myron\", \"Streams\": 4593309, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"56uXDJRCuoS7abX3SkzHKQ\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 76.0, \"Danceability\": 0.771, \"Energy\": 0.654, \"Loudness\": -6.976, \"Speechiness\": 0.298, \"Acousticness\": 0.055, \"Liveness\": 0.214, \"Tempo\": 155.047, \"Duration (ms)\": 224955.0, \"Valence\": 0.573, \"Chord\": \"G#/Ab\"}, {\"Index\": 1068, \"Highest Charting Position\": 67, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"MORE & MORE\", \"Streams\": 4592745, \"Artist\": \"TWICE\", \"Artist Followers\": 9998991.0, \"Song ID\": \"3omvXShuRPM3zbDpWYqf5g\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-06-01\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 70.0, \"Danceability\": 0.739, \"Energy\": 0.841, \"Loudness\": -4.162, \"Speechiness\": 0.06, \"Acousticness\": 0.0312, \"Liveness\": 0.173, \"Tempo\": 106.99, \"Duration (ms)\": 199653.0, \"Valence\": 0.562, \"Chord\": \"F\"}, {\"Index\": 1069, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Girls in the Hood\", \"Streams\": 4577209, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"6WbTTAGKrQtCQvmc5BuYfh\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 72.0, \"Danceability\": 0.821, \"Energy\": 0.863, \"Loudness\": -3.159, \"Speechiness\": 0.353, \"Acousticness\": 0.00824, \"Liveness\": 0.0377, \"Tempo\": 180.013, \"Duration (ms)\": 154324.0, \"Valence\": 0.874, \"Chord\": \"F#/Gb\"}, {\"Index\": 1070, \"Highest Charting Position\": 169, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Parasite Eve\", \"Streams\": 4545883, \"Artist\": \"Bring Me The Horizon\", \"Artist Followers\": 3912138.0, \"Song ID\": \"5OxclJsdFESni44YlpNpkR\", \"Genre\": \"['melodic metalcore', 'metalcore', 'rock', 'uk metalcore']\", \"Release Date\": \"2020-06-25\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 67.0, \"Danceability\": 0.589, \"Energy\": 0.797, \"Loudness\": -5.464, \"Speechiness\": 0.15, \"Acousticness\": 0.0289, \"Liveness\": 0.383, \"Tempo\": 102.489, \"Duration (ms)\": 291813.0, \"Valence\": 0.232, \"Chord\": \"A\"}, {\"Index\": 1071, \"Highest Charting Position\": 78, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Sucker\", \"Streams\": 4543863, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"22vgEDb5hykfaTwLuskFGD\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-06-07\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.842, \"Energy\": 0.734, \"Loudness\": -5.065, \"Speechiness\": 0.0588, \"Acousticness\": 0.0427, \"Liveness\": 0.106, \"Tempo\": 137.958, \"Duration (ms)\": 181027.0, \"Valence\": 0.952, \"Chord\": \"C#/Db\"}, {\"Index\": 1072, \"Highest Charting Position\": 147, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"I Like Me Better\", \"Streams\": 4430642, \"Artist\": \"Lauv\", \"Artist Followers\": 4442273.0, \"Song ID\": \"2P91MQbaiQOfbiz9VqhqKQ\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-05-31\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.752, \"Energy\": 0.505, \"Loudness\": -7.621, \"Speechiness\": 0.253, \"Acousticness\": 0.535, \"Liveness\": 0.104, \"Tempo\": 91.97, \"Duration (ms)\": 197437.0, \"Valence\": 0.419, \"Chord\": \"A\"}, {\"Index\": 1073, \"Highest Charting Position\": 116, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"High Hopes\", \"Streams\": 4426791, \"Artist\": \"Panic! At The Disco\", \"Artist Followers\": 10850424.0, \"Song ID\": \"1rqqCSm0Qe4I9rUvWncaom\", \"Genre\": \"['modern rock']\", \"Release Date\": \"2018-06-22\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.579, \"Energy\": 0.904, \"Loudness\": -2.729, \"Speechiness\": 0.0618, \"Acousticness\": 0.193, \"Liveness\": 0.064, \"Tempo\": 82.014, \"Duration (ms)\": 190947.0, \"Valence\": 0.681, \"Chord\": \"F\"}, {\"Index\": 1074, \"Highest Charting Position\": 88, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Money In The Grave (Drake ft. Rick Ross)\", \"Streams\": 4403348, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5ry2OE6R2zPQFDO85XkgRb\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2019-06-15\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.831, \"Energy\": 0.502, \"Loudness\": -4.045, \"Speechiness\": 0.046, \"Acousticness\": 0.101, \"Liveness\": 0.122, \"Tempo\": 100.541, \"Duration (ms)\": 205427.0, \"Valence\": 0.101, \"Chord\": \"A#/Bb\"}, {\"Index\": 1075, \"Highest Charting Position\": 25, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Say So (feat. Nicki Minaj)\", \"Streams\": 4385148, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"11VApNQCWLJdzxWrlmwzUa\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 69.0, \"Danceability\": 0.856, \"Energy\": 0.641, \"Loudness\": -4.64, \"Speechiness\": 0.204, \"Acousticness\": 0.119, \"Liveness\": 0.427, \"Tempo\": 111.004, \"Duration (ms)\": 206221.0, \"Valence\": 0.745, \"Chord\": \"B\"}, {\"Index\": 1076, \"Highest Charting Position\": 189, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Karaoke\", \"Streams\": 4374448, \"Artist\": \"Boomdabash, Alessandra Amoroso\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3n6TeHSnNhDe991nJS2S90\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-10\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 0.0, \"Danceability\": 0.929, \"Energy\": 0.625, \"Loudness\": -5.728, \"Speechiness\": 0.14, \"Acousticness\": 0.289, \"Liveness\": 0.386, \"Tempo\": 122.03, \"Duration (ms)\": 156493.0, \"Valence\": 0.578, \"Chord\": \"C#/Db\"}, {\"Index\": 1077, \"Highest Charting Position\": 36, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Know Your Worth\", \"Streams\": 4374392, \"Artist\": \"Khalid, Disclosure\", \"Artist Followers\": 14190858.0, \"Song ID\": \"0TrPqhAMoaKUFLR7iYDokf\", \"Genre\": \"['pop']\", \"Release Date\": \"2020-02-04\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 76.0, \"Danceability\": 0.79, \"Energy\": 0.694, \"Loudness\": -7.726, \"Speechiness\": 0.0708, \"Acousticness\": 0.145, \"Liveness\": 0.281, \"Tempo\": 103.007, \"Duration (ms)\": 181436.0, \"Valence\": 0.508, \"Chord\": \"A\"}, {\"Index\": 1078, \"Highest Charting Position\": 26, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"No Idea\", \"Streams\": 4369849, \"Artist\": \"Don Toliver\", \"Artist Followers\": 1606884.0, \"Song ID\": \"7AzlLxHn24DxjgQX73F9fU\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.652, \"Energy\": 0.631, \"Loudness\": -5.718, \"Speechiness\": 0.0893, \"Acousticness\": 0.524, \"Liveness\": 0.165, \"Tempo\": 127.998, \"Duration (ms)\": 154424.0, \"Valence\": 0.35, \"Chord\": \"F#/Gb\"}, {\"Index\": 1079, \"Highest Charting Position\": 145, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Airwaves\", \"Streams\": 4352767, \"Artist\": \"Pashanim\", \"Artist Followers\": 208926.0, \"Song ID\": \"5CqkgDH8QZjSqqI3HmYxDD\", \"Genre\": \"['german alternative rap', 'german drill', 'german hip hop', 'german trap']\", \"Release Date\": \"2020-05-14\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 71.0, \"Danceability\": 0.885, \"Energy\": 0.578, \"Loudness\": -7.416, \"Speechiness\": 0.0783, \"Acousticness\": 0.0739, \"Liveness\": 0.102, \"Tempo\": 131.999, \"Duration (ms)\": 178933.0, \"Valence\": 0.388, \"Chord\": \"F\"}, {\"Index\": 1080, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Kill This Love\", \"Streams\": 4341050, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"6hvczQ05jc1yGlp9zhb95V\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2019-04-05\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 76.0, \"Danceability\": 0.763, \"Energy\": 0.835, \"Loudness\": -5.234, \"Speechiness\": 0.191, \"Acousticness\": 0.323, \"Liveness\": 0.225, \"Tempo\": 131.875, \"Duration (ms)\": 191050.0, \"Valence\": 0.645, \"Chord\": \"D\"}, {\"Index\": 1081, \"Highest Charting Position\": 68, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lights Up\", \"Streams\": 4325411, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16127908.0, \"Song ID\": \"4jAIqgrPjKLTY9Gbez25Qb\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.575, \"Energy\": 0.621, \"Loudness\": -8.165, \"Speechiness\": 0.032, \"Acousticness\": 0.0392, \"Liveness\": 0.141, \"Tempo\": 101.987, \"Duration (ms)\": 172213.0, \"Valence\": 0.27, \"Chord\": \"A#/Bb\"}, {\"Index\": 1082, \"Highest Charting Position\": 14, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Lose You To Love Me\", \"Streams\": 4322088, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4l0Mvzj72xxOpRrp6h8nHi\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.488, \"Energy\": 0.343, \"Loudness\": -8.985, \"Speechiness\": 0.0436, \"Acousticness\": 0.556, \"Liveness\": 0.21, \"Tempo\": 102.819, \"Duration (ms)\": 206459.0, \"Valence\": 0.0978, \"Chord\": \"E\"}, {\"Index\": 1083, \"Highest Charting Position\": 94, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Girls Like You (feat. Cardi B)\", \"Streams\": 4318772, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32279979.0, \"Song ID\": \"6V1bu6o1Yo5ZXnsCJU8Ovk\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2018-06-15\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.851, \"Energy\": 0.541, \"Loudness\": -6.825, \"Speechiness\": 0.0505, \"Acousticness\": 0.568, \"Liveness\": 0.13, \"Tempo\": 124.959, \"Duration (ms)\": 235545.0, \"Valence\": 0.448, \"Chord\": \"C\"}, {\"Index\": 1084, \"Highest Charting Position\": 47, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"PA' ROMPERLA\", \"Streams\": 4312675, \"Artist\": \"Bad Bunny, Don Omar\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5XqCz18k96K8tx6DAYM97i\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 72.0, \"Danceability\": 0.772, \"Energy\": 0.83, \"Loudness\": -5.019, \"Speechiness\": 0.0599, \"Acousticness\": 0.016, \"Liveness\": 0.0843, \"Tempo\": 94.011, \"Duration (ms)\": 194200.0, \"Valence\": 0.697, \"Chord\": \"G\"}, {\"Index\": 1085, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"VACATION\", \"Streams\": 6883487, \"Artist\": \"Tyga\", \"Artist Followers\": 6298789.0, \"Song ID\": \"6q2uIyLqASSpv2SIv2ehWK\", \"Genre\": \"['dance pop', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 51.0, \"Danceability\": 0.821, \"Energy\": 0.61, \"Loudness\": -6.22, \"Speechiness\": 0.0959, \"Acousticness\": 0.0247, \"Liveness\": 0.185, \"Tempo\": 110.973, \"Duration (ms)\": 192936.0, \"Valence\": 0.47, \"Chord\": \"C#/Db\"}, {\"Index\": 1086, \"Highest Charting Position\": 86, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Big Body Benz\", \"Streams\": 6707101, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"2WOJ7D52Ng3myrKlEf4Azj\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-06-18\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 61.0, \"Danceability\": 0.884, \"Energy\": 0.451, \"Loudness\": -8.969, \"Speechiness\": 0.393, \"Acousticness\": 0.0731, \"Liveness\": 0.268, \"Tempo\": 94.024, \"Duration (ms)\": 148284.0, \"Valence\": 0.311, \"Chord\": \"A\"}, {\"Index\": 1087, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Ich wei\\u00df nicht mal wie sie hei\\u00dft\", \"Streams\": 5827600, \"Artist\": \"Capital Bra, Bozza\", \"Artist Followers\": 4093115.0, \"Song ID\": \"4KfL3Ne8bc9bC2PUB8QGwA\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-06-18\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 57.0, \"Danceability\": 0.498, \"Energy\": 0.836, \"Loudness\": -3.905, \"Speechiness\": 0.184, \"Acousticness\": 0.525, \"Liveness\": 0.0994, \"Tempo\": 199.846, \"Duration (ms)\": 168750.0, \"Valence\": 0.609, \"Chord\": \"A#/Bb\"}, {\"Index\": 1088, \"Highest Charting Position\": 101, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"F\\u00fatbol & Rumba (feat. Enrique Iglesias)\", \"Streams\": 5124116, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"2hDe0Ls5mVqs1XJqv7sbcM\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 67.0, \"Danceability\": 0.735, \"Energy\": 0.916, \"Loudness\": -2.082, \"Speechiness\": 0.117, \"Acousticness\": 0.397, \"Liveness\": 0.0918, \"Tempo\": 167.994, \"Duration (ms)\": 221429.0, \"Valence\": 0.691, \"Chord\": \"D\"}, {\"Index\": 1089, \"Highest Charting Position\": 131, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Bleed\", \"Streams\": 5095478, \"Artist\": \"A Boogie Wit da Hoodie\", \"Artist Followers\": 5865895.0, \"Song ID\": \"5XzombolzpiaOSTdj1W0VS\", \"Genre\": \"['melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 61.0, \"Danceability\": 0.698, \"Energy\": 0.572, \"Loudness\": -7.735, \"Speechiness\": 0.198, \"Acousticness\": 0.135, \"Liveness\": 0.154, \"Tempo\": 71.446, \"Duration (ms)\": 176959.0, \"Valence\": 0.391, \"Chord\": \"D\"}, {\"Index\": 1090, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Snow On Tha Bluff\", \"Streams\": 5060764, \"Artist\": \"J. Cole\", \"Artist Followers\": 14103694.0, \"Song ID\": \"1oOEkBNp4zWnkD7nWjJdog\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2020-06-16\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 66.0, \"Danceability\": 0.586, \"Energy\": 0.512, \"Loudness\": -8.819, \"Speechiness\": 0.0668, \"Acousticness\": 0.723, \"Liveness\": 0.119, \"Tempo\": 75.857, \"Duration (ms)\": 235480.0, \"Valence\": 0.235, \"Chord\": \"G#/Ab\"}, {\"Index\": 1091, \"Highest Charting Position\": 113, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Djomb - Bien ou quoi\", \"Streams\": 4924714, \"Artist\": \"Bosh\", \"Artist Followers\": 300500.0, \"Song ID\": \"0KBwGCY9RYD9t2zjeW4h48\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 64.0, \"Danceability\": 0.945, \"Energy\": 0.676, \"Loudness\": -6.6, \"Speechiness\": 0.207, \"Acousticness\": 0.172, \"Liveness\": 0.322, \"Tempo\": 123.109, \"Duration (ms)\": 141893.0, \"Valence\": 0.631, \"Chord\": \"C#/Db\"}, {\"Index\": 1092, \"Highest Charting Position\": 84, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"In Your Eyes (feat. Alida)\", \"Streams\": 4654587, \"Artist\": \"Alida, Robin Schulz\", \"Artist Followers\": 2786366.0, \"Song ID\": \"61ZM92T2zaXIVsqncThQzC\", \"Genre\": \"['dance pop', 'deep euro house', 'deep house', 'edm', 'german dance', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 71.0, \"Danceability\": 0.57, \"Energy\": 0.672, \"Loudness\": -5.888, \"Speechiness\": 0.0716, \"Acousticness\": 0.172, \"Liveness\": 0.0768, \"Tempo\": 120.018, \"Duration (ms)\": 208222.0, \"Valence\": 0.461, \"Chord\": \"G#/Ab\"}, {\"Index\": 1093, \"Highest Charting Position\": 13, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Stupid Love\", \"Streams\": 4609858, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 1251372.0, \"Song ID\": \"1zPwSOUc5MPtPg8EgXAGKU\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-08\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 0.0, \"Danceability\": 0.68, \"Energy\": 0.825, \"Loudness\": -4.296, \"Speechiness\": 0.0702, \"Acousticness\": 0.00173, \"Liveness\": 0.27, \"Tempo\": 117.987, \"Duration (ms)\": 193533.0, \"Valence\": 0.784, \"Chord\": \"G#/Ab\"}, {\"Index\": 1094, \"Highest Charting Position\": 93, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Shotta Flow 5\", \"Streams\": 4513982, \"Artist\": \"NLE Choppa\", \"Artist Followers\": 3372385.0, \"Song ID\": \"1orjH4IkSH9VrWmRCToKV8\", \"Genre\": \"['memphis hip hop']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 62.0, \"Danceability\": 0.806, \"Energy\": 0.749, \"Loudness\": -5.268, \"Speechiness\": 0.328, \"Acousticness\": 0.0838, \"Liveness\": 0.0621, \"Tempo\": 140.032, \"Duration (ms)\": 145167.0, \"Valence\": 0.77, \"Chord\": \"C#/Db\"}, {\"Index\": 1095, \"Highest Charting Position\": 145, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"IDK You Yet\", \"Streams\": 4473413, \"Artist\": \"Alexander 23\", \"Artist Followers\": 207170.0, \"Song ID\": \"0j1Ia2lQWrcXrQZI4AdJlk\", \"Genre\": \"['alt z', 'indie cafe pop', 'pop', 'post-teen pop', 'social media pop']\", \"Release Date\": \"2020-06-23\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 79.0, \"Danceability\": 0.648, \"Energy\": 0.308, \"Loudness\": -11.729, \"Speechiness\": 0.04, \"Acousticness\": 0.886, \"Liveness\": 0.124, \"Tempo\": 76.997, \"Duration (ms)\": 184638.0, \"Valence\": 0.198, \"Chord\": \"C#/Db\"}, {\"Index\": 1096, \"Highest Charting Position\": 75, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Piece Of Your Heart\", \"Streams\": 4422905, \"Artist\": \"MEDUZA, Goodboys\", \"Artist Followers\": 441714.0, \"Song ID\": \"1DFD5Fotzgn6yYXkYsKiGs\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop house', 'tropical house']\", \"Release Date\": \"2019-02-01\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.677, \"Energy\": 0.744, \"Loudness\": -6.806, \"Speechiness\": 0.0295, \"Acousticness\": 0.0404, \"Liveness\": 0.074, \"Tempo\": 124.08, \"Duration (ms)\": 152913.0, \"Valence\": 0.631, \"Chord\": \"A#/Bb\"}, {\"Index\": 1097, \"Highest Charting Position\": 129, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Na Raba Toma Tap\\u00e3o\", \"Streams\": 4396629, \"Artist\": \"Niack\", \"Artist Followers\": 352402.0, \"Song ID\": \"0AGS6ZRgzobrazmCi6pYMe\", \"Genre\": \"['funk carioca']\", \"Release Date\": \"2020-06-06\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 61.0, \"Danceability\": 0.962, \"Energy\": 0.787, \"Loudness\": 1.509, \"Speechiness\": 0.0554, \"Acousticness\": 0.666, \"Liveness\": 0.176, \"Tempo\": 130.003, \"Duration (ms)\": 165231.0, \"Valence\": 0.968, \"Chord\": \"D#/Eb\"}, {\"Index\": 1098, \"Highest Charting Position\": 14, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"La Santa\", \"Streams\": 4384527, \"Artist\": \"Bad Bunny, Daddy Yankee\", \"Artist Followers\": 36177712.0, \"Song ID\": \"69vlMrzHwATKzupwNcUPyK\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 79.0, \"Danceability\": 0.744, \"Energy\": 0.868, \"Loudness\": -4.524, \"Speechiness\": 0.047, \"Acousticness\": 0.0326, \"Liveness\": 0.0822, \"Tempo\": 93.037, \"Duration (ms)\": 206420.0, \"Valence\": 0.586, \"Chord\": \"C#/Db\"}, {\"Index\": 1099, \"Highest Charting Position\": 125, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Make You Mine\", \"Streams\": 4356213, \"Artist\": \"PUBLIC\", \"Artist Followers\": 165504.0, \"Song ID\": \"5iFwAOB2TFkPJk8sMlxP8g\", \"Genre\": \"['indie rockism']\", \"Release Date\": \"2019-08-09\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 77.0, \"Danceability\": 0.606, \"Energy\": 0.799, \"Loudness\": -4.452, \"Speechiness\": 0.0261, \"Acousticness\": 0.0128, \"Liveness\": 0.15, \"Tempo\": 103.014, \"Duration (ms)\": 232907.0, \"Valence\": 0.638, \"Chord\": \"A\"}, {\"Index\": 1100, \"Highest Charting Position\": 76, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"ROCKSTAR (feat. Roddy Ricch) - BLM REMIX\", \"Streams\": 7353153, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"4Aykm3xrOFSHrAnv80KUhh\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 62.0, \"Danceability\": 0.747, \"Energy\": 0.689, \"Loudness\": -7.246, \"Speechiness\": 0.242, \"Acousticness\": 0.197, \"Liveness\": 0.0884, \"Tempo\": 89.901, \"Duration (ms)\": 204547.0, \"Valence\": 0.75, \"Chord\": \"B\"}, {\"Index\": 1101, \"Highest Charting Position\": 97, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Make It Rain\", \"Streams\": 6042929, \"Artist\": \"Pop Smoke, Rowdy Rebel\", \"Artist Followers\": 6852509.0, \"Song ID\": \"4TgHt7vKCimpywaiKfl0uj\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 64.0, \"Danceability\": 0.54, \"Energy\": 0.77, \"Loudness\": -3.981, \"Speechiness\": 0.389, \"Acousticness\": 0.194, \"Liveness\": 0.372, \"Tempo\": 159.494, \"Duration (ms)\": 204000.0, \"Valence\": 0.565, \"Chord\": \"C#/Db\"}, {\"Index\": 1102, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"M' Manc (con Geolier & Sfera Ebbasta)\", \"Streams\": 5171235, \"Artist\": \"Shablo\", \"Artist Followers\": 40045.0, \"Song ID\": \"0MLu1cFYL4ikdRTdasCQT9\", \"Genre\": \"['italian hip hop']\", \"Release Date\": \"2020-06-11\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 66.0, \"Danceability\": 0.703, \"Energy\": 0.704, \"Loudness\": -6.117, \"Speechiness\": 0.0641, \"Acousticness\": 0.048, \"Liveness\": 0.41, \"Tempo\": 139.933, \"Duration (ms)\": 180000.0, \"Valence\": 0.725, \"Chord\": \"F#/Gb\"}, {\"Index\": 1103, \"Highest Charting Position\": 143, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Emotions 2.0\", \"Streams\": 5113459, \"Artist\": \"Ufo361, C\\u00c9LINE\", \"Artist Followers\": 1700759.0, \"Song ID\": \"3yZCjDTxzZxx1kll1sRjGc\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 65.0, \"Danceability\": 0.788, \"Energy\": 0.491, \"Loudness\": -9.884, \"Speechiness\": 0.109, \"Acousticness\": 0.386, \"Liveness\": 0.107, \"Tempo\": 98.543, \"Duration (ms)\": 146028.0, \"Valence\": 0.271, \"Chord\": \"G#/Ab\"}, {\"Index\": 1104, \"Highest Charting Position\": 21, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"P2\", \"Streams\": 4769996, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"3kW4z2pIj5VY5fLjBrMRL5\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 73.0, \"Danceability\": 0.775, \"Energy\": 0.72, \"Loudness\": -5.353, \"Speechiness\": 0.193, \"Acousticness\": 0.0236, \"Liveness\": 0.114, \"Tempo\": 155.086, \"Duration (ms)\": 234627.0, \"Valence\": 0.49, \"Chord\": \"B\"}, {\"Index\": 1105, \"Highest Charting Position\": 79, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Selfish\", \"Streams\": 4754830, \"Artist\": \"Madison Beer\", \"Artist Followers\": 3370013.0, \"Song ID\": \"4PV0uE5pZSh44E3NqNNDEH\", \"Genre\": \"['alt z', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 70.0, \"Danceability\": 0.375, \"Energy\": 0.461, \"Loudness\": -6.202, \"Speechiness\": 0.0279, \"Acousticness\": 0.627, \"Liveness\": 0.386, \"Tempo\": 75.217, \"Duration (ms)\": 223270.0, \"Valence\": 0.233, \"Chord\": \"A\"}, {\"Index\": 1106, \"Highest Charting Position\": 154, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Surrender\", \"Streams\": 4627942, \"Artist\": \"Natalie Taylor\", \"Artist Followers\": 120208.0, \"Song ID\": \"0ecC8p17cDNlxHXkuYqeR6\", \"Genre\": \"[]\", \"Release Date\": \"2019-10-29\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 76.0, \"Danceability\": 0.39, \"Energy\": 0.448, \"Loudness\": -8.57, \"Speechiness\": 0.0276, \"Acousticness\": 0.8, \"Liveness\": 0.107, \"Tempo\": 144.89, \"Duration (ms)\": 183103.0, \"Valence\": 0.077, \"Chord\": \"F\"}, {\"Index\": 1107, \"Highest Charting Position\": 86, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Turks (with Gunna & ft. Travis Scott)\", \"Streams\": 4623279, \"Artist\": \"NAV\", \"Artist Followers\": 2613211.0, \"Song ID\": \"7IMwEtpAiJanqF6vQteZN2\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'hip hop', 'melodic rap', 'pop rap', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 67.0, \"Danceability\": 0.894, \"Energy\": 0.618, \"Loudness\": -4.356, \"Speechiness\": 0.129, \"Acousticness\": 0.0808, \"Liveness\": 0.558, \"Tempo\": 119.1, \"Duration (ms)\": 161320.0, \"Valence\": 0.379, \"Chord\": \"G\"}, {\"Index\": 1108, \"Highest Charting Position\": 48, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"BYE ME FUI\", \"Streams\": 4567732, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0FktnzDqjClqU6iqOZVEs2\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 72.0, \"Danceability\": 0.712, \"Energy\": 0.599, \"Loudness\": -6.342, \"Speechiness\": 0.112, \"Acousticness\": 0.412, \"Liveness\": 0.103, \"Tempo\": 179.788, \"Duration (ms)\": 178000.0, \"Valence\": 0.588, \"Chord\": \"F\"}, {\"Index\": 1109, \"Highest Charting Position\": 15, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Vete\", \"Streams\": 4486408, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5DxXgozhkPLgrbKFY91w0c\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-21\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.886, \"Energy\": 0.672, \"Loudness\": -4.394, \"Speechiness\": 0.188, \"Acousticness\": 0.0363, \"Liveness\": 0.101, \"Tempo\": 91.976, \"Duration (ms)\": 192024.0, \"Valence\": 0.526, \"Chord\": \"C#/Db\"}, {\"Index\": 1110, \"Highest Charting Position\": 43, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Like It Is\", \"Streams\": 4463865, \"Artist\": \"Kygo, Zara Larsson, Tyga\", \"Artist Followers\": 7593792.0, \"Song ID\": \"3frUvGrmGcay91lvFbOgsN\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 68.0, \"Danceability\": 0.794, \"Energy\": 0.728, \"Loudness\": -6.759, \"Speechiness\": 0.114, \"Acousticness\": 0.121, \"Liveness\": 0.227, \"Tempo\": 105.024, \"Duration (ms)\": 183067.0, \"Valence\": 0.36, \"Chord\": \"C#/Db\"}, {\"Index\": 1111, \"Highest Charting Position\": 15, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"My Oh My (feat. DaBaby)\", \"Streams\": 4413457, \"Artist\": \"Camila Cabello\", \"Artist Followers\": 22698747.0, \"Song ID\": \"3yOlyBJuViE2YSGn3nVE1K\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.724, \"Energy\": 0.491, \"Loudness\": -6.024, \"Speechiness\": 0.0296, \"Acousticness\": 0.018, \"Liveness\": 0.0887, \"Tempo\": 105.046, \"Duration (ms)\": 170746.0, \"Valence\": 0.383, \"Chord\": \"G#/Ab\"}, {\"Index\": 1112, \"Highest Charting Position\": 161, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Let Me Down Slowly\", \"Streams\": 4393932, \"Artist\": \"Alec Benjamin\", \"Artist Followers\": 2808285.0, \"Song ID\": \"2qxmye6gAegTMjLKEBoR3d\", \"Genre\": \"['alt z', 'electropop', 'pop']\", \"Release Date\": \"2018-11-16\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.652, \"Energy\": 0.557, \"Loudness\": -5.714, \"Speechiness\": 0.0318, \"Acousticness\": 0.74, \"Liveness\": 0.124, \"Tempo\": 150.073, \"Duration (ms)\": 169354.0, \"Valence\": 0.483, \"Chord\": \"C#/Db\"}, {\"Index\": 1113, \"Highest Charting Position\": 22, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"BELIEVE IT\", \"Streams\": 4361970, \"Artist\": \"PARTYNEXTDOOR, Rihanna\", \"Artist Followers\": 3129968.0, \"Song ID\": \"4HDCLYli2SUdkq9OjmvhSD\", \"Genre\": \"['pop', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap', 'urban contemporary']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 74.0, \"Danceability\": 0.43, \"Energy\": 0.7, \"Loudness\": -5.35, \"Speechiness\": 0.264, \"Acousticness\": 0.0902, \"Liveness\": 0.216, \"Tempo\": 158.373, \"Duration (ms)\": 183219.0, \"Valence\": 0.731, \"Chord\": \"F#/Gb\"}, {\"Index\": 1114, \"Highest Charting Position\": 86, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Boot\", \"Streams\": 6375562, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"12KENAKQY5JvAsRURN7TzB\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2020-06-05--2020-06-12\", \"Popularity\": 54.0, \"Danceability\": 0.534, \"Energy\": 0.565, \"Loudness\": -7.546, \"Speechiness\": 0.307, \"Acousticness\": 0.0627, \"Liveness\": 0.112, \"Tempo\": 194.034, \"Duration (ms)\": 193360.0, \"Valence\": 0.529, \"Chord\": \"G#/Ab\"}, {\"Index\": 1115, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Riot\", \"Streams\": 5163633, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"4aOOExMBUyxKnEYb39SrTg\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2020-06-01\", \"Weeks Charted\": \"2020-06-05--2020-06-12\", \"Popularity\": 70.0, \"Danceability\": 0.509, \"Energy\": 0.542, \"Loudness\": -8.027, \"Speechiness\": 0.442, \"Acousticness\": 0.019, \"Liveness\": 0.23, \"Tempo\": 97.767, \"Duration (ms)\": 78681.0, \"Valence\": 0.151, \"Chord\": \"D#/Eb\"}, {\"Index\": 1116, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"VALLA NEIN (feat. Luciano)\", \"Streams\": 5029858, \"Artist\": \"KC Rebell, Summer Cem\", \"Artist Followers\": 1101597.0, \"Song ID\": \"2rxxXYtTIFKyrhJpofeoIX\", \"Genre\": \"['german drill', 'german hip hop']\", \"Release Date\": \"2020-06-05\", \"Weeks Charted\": \"2020-06-05--2020-06-12\", \"Popularity\": 55.0, \"Danceability\": 0.761, \"Energy\": 0.657, \"Loudness\": -7.246, \"Speechiness\": 0.138, \"Acousticness\": 0.114, \"Liveness\": 0.356, \"Tempo\": 135.909, \"Duration (ms)\": 182040.0, \"Valence\": 0.589, \"Chord\": \"A#/Bb\"}, {\"Index\": 1117, \"Highest Charting Position\": 27, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"I\\u2019m Ready (with Demi Lovato)\", \"Streams\": 4764355, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"1fipvP2zmef6vN2IwXfJhY\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-04-16\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 68.0, \"Danceability\": 0.501, \"Energy\": 0.674, \"Loudness\": -6.363, \"Speechiness\": 0.0408, \"Acousticness\": 0.00346, \"Liveness\": 0.282, \"Tempo\": 155.051, \"Duration (ms)\": 200838.0, \"Valence\": 0.152, \"Chord\": \"F\"}, {\"Index\": 1118, \"Highest Charting Position\": 63, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"This Is America\", \"Streams\": 4727415, \"Artist\": \"Childish Gambino\", \"Artist Followers\": 8099554.0, \"Song ID\": \"0b9oOr2ZgvyQu88wzixux9\", \"Genre\": \"['atl hip hop', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2018-05-06\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 71.0, \"Danceability\": 0.854, \"Energy\": 0.463, \"Loudness\": -6.159, \"Speechiness\": 0.137, \"Acousticness\": 0.117, \"Liveness\": 0.354, \"Tempo\": 120.024, \"Duration (ms)\": 225773.0, \"Valence\": 0.549, \"Chord\": \"F\"}, {\"Index\": 1119, \"Highest Charting Position\": 33, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Fantasias\", \"Streams\": 4432324, \"Artist\": \"Rauw Alejandro, Farruko\", \"Artist Followers\": 6096559.0, \"Song ID\": \"6mAN61JH0dzyZpWslS11jy\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2019-08-29\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.879, \"Energy\": 0.703, \"Loudness\": -4.219, \"Speechiness\": 0.0701, \"Acousticness\": 0.143, \"Liveness\": 0.0569, \"Tempo\": 94.004, \"Duration (ms)\": 199711.0, \"Valence\": 0.788, \"Chord\": \"C#/Db\"}, {\"Index\": 1120, \"Highest Charting Position\": 60, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"BAD CON NICKY\", \"Streams\": 4432210, \"Artist\": \"Bad Bunny, Nicky Jam\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5bmSver2b3ZXyuyLKtgnFI\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 71.0, \"Danceability\": 0.59, \"Energy\": 0.729, \"Loudness\": -4.95, \"Speechiness\": 0.0893, \"Acousticness\": 0.321, \"Liveness\": 0.659, \"Tempo\": 93.094, \"Duration (ms)\": 202240.0, \"Valence\": 0.712, \"Chord\": \"G\"}, {\"Index\": 1121, \"Highest Charting Position\": 145, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"If I Can't Have You\", \"Streams\": 4364166, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 33893352.0, \"Song ID\": \"6LsAAHotRLMOHfCsSfYCsz\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2019-05-03\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.692, \"Energy\": 0.809, \"Loudness\": -4.198, \"Speechiness\": 0.0602, \"Acousticness\": 0.524, \"Liveness\": 0.147, \"Tempo\": 123.911, \"Duration (ms)\": 190800.0, \"Valence\": 0.864, \"Chord\": \"D\"}, {\"Index\": 1122, \"Highest Charting Position\": 27, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"What A Man Gotta Do\", \"Streams\": 4360660, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"4wNIkl5XGiAACjFBlDWuSd\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 77.0, \"Danceability\": 0.852, \"Energy\": 0.698, \"Loudness\": -7.206, \"Speechiness\": 0.0629, \"Acousticness\": 0.00839, \"Liveness\": 0.0773, \"Tempo\": 113.039, \"Duration (ms)\": 180645.0, \"Valence\": 0.324, \"Chord\": \"A\"}, {\"Index\": 1123, \"Highest Charting Position\": 50, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Callaita\", \"Streams\": 4350496, \"Artist\": \"Bad Bunny, Tainy\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2TH65lNHgvLxCKXM3apjxI\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-05-31\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.61, \"Energy\": 0.624, \"Loudness\": -4.773, \"Speechiness\": 0.309, \"Acousticness\": 0.6, \"Liveness\": 0.243, \"Tempo\": 176.169, \"Duration (ms)\": 250534.0, \"Valence\": 0.244, \"Chord\": \"D\"}, {\"Index\": 1124, \"Highest Charting Position\": 51, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Solitaires (feat. Travis Scott)\", \"Streams\": 4334669, \"Artist\": \"Future\", \"Artist Followers\": 10491105.0, \"Song ID\": \"4kfeRwpq5KUaqTkgi4TbDF\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 67.0, \"Danceability\": 0.691, \"Energy\": 0.632, \"Loudness\": -7.598, \"Speechiness\": 0.0513, \"Acousticness\": 0.122, \"Liveness\": 0.0646, \"Tempo\": 169.982, \"Duration (ms)\": 205666.0, \"Valence\": 0.488, \"Chord\": \"C#/Db\"}, {\"Index\": 1125, \"Highest Charting Position\": 137, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"XO Tour Llif3\", \"Streams\": 4314080, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7GX5flRQZVHRAGd6B4TmDO\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2017-08-25\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-08--2020-05-15\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 82.0, \"Danceability\": 0.732, \"Energy\": 0.75, \"Loudness\": -6.366, \"Speechiness\": 0.231, \"Acousticness\": 0.00264, \"Liveness\": 0.109, \"Tempo\": 155.096, \"Duration (ms)\": 182707.0, \"Valence\": 0.401, \"Chord\": \"B\"}, {\"Index\": 1126, \"Highest Charting Position\": 189, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"changes\", \"Streams\": 4299334, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"7AFASza1mXqntmGtbxXprO\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2018-03-16\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 81.0, \"Danceability\": 0.669, \"Energy\": 0.308, \"Loudness\": -10.068, \"Speechiness\": 0.029, \"Acousticness\": 0.883, \"Liveness\": 0.0984, \"Tempo\": 64.934, \"Duration (ms)\": 121887.0, \"Valence\": 0.52, \"Chord\": \"B\"}, {\"Index\": 1127, \"Highest Charting Position\": 66, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Suicidal (Remix) [feat. Juice WRLD]\", \"Streams\": 4296154, \"Artist\": \"YNW Melly\", \"Artist Followers\": 6332535.0, \"Song ID\": \"4S2uhQE8L9V6p7rj7SiauJ\", \"Genre\": \"['melodic rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 76.0, \"Danceability\": 0.655, \"Energy\": 0.441, \"Loudness\": -5.245, \"Speechiness\": 0.0629, \"Acousticness\": 0.474, \"Liveness\": 0.099, \"Tempo\": 139.957, \"Duration (ms)\": 225857.0, \"Valence\": 0.273, \"Chord\": \"A\"}, {\"Index\": 1128, \"Highest Charting Position\": 30, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Level of Concern\", \"Streams\": 4252898, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20829526.0, \"Song ID\": \"6xZ4Q2k2ompmDppyeESIY8\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 72.0, \"Danceability\": 0.754, \"Energy\": 0.583, \"Loudness\": -7.34, \"Speechiness\": 0.0432, \"Acousticness\": 0.32, \"Liveness\": 0.144, \"Tempo\": 122.012, \"Duration (ms)\": 220051.0, \"Valence\": 0.77, \"Chord\": \"E\"}, {\"Index\": 1129, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Alice\", \"Streams\": 10342277, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"41A89rj3GoMG6ktN37L7PG\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 64.0, \"Danceability\": 0.723, \"Energy\": 0.88, \"Loudness\": -4.287, \"Speechiness\": 0.038, \"Acousticness\": 0.00334, \"Liveness\": 0.0632, \"Tempo\": 123.036, \"Duration (ms)\": 177600.0, \"Valence\": 0.323, \"Chord\": \"B\"}, {\"Index\": 1130, \"Highest Charting Position\": 58, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Free Woman\", \"Streams\": 9266945, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"4L6ihclQPu1hqP9r3WNJjQ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 63.0, \"Danceability\": 0.731, \"Energy\": 0.927, \"Loudness\": -3.634, \"Speechiness\": 0.0781, \"Acousticness\": 0.0228, \"Liveness\": 0.187, \"Tempo\": 119.006, \"Duration (ms)\": 191467.0, \"Valence\": 0.478, \"Chord\": \"C\"}, {\"Index\": 1131, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Fun Tonight\", \"Streams\": 7907329, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"6hyQVqfHFvsJDjcmj4qrHf\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.645, \"Energy\": 0.923, \"Loudness\": -4.262, \"Speechiness\": 0.0725, \"Acousticness\": 0.364, \"Liveness\": 0.14, \"Tempo\": 117.945, \"Duration (ms)\": 173427.0, \"Valence\": 0.323, \"Chord\": \"B\"}, {\"Index\": 1132, \"Highest Charting Position\": 75, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Sine From Above (with Elton John)\", \"Streams\": 7734309, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"0zzsyWc45eUcSjw4FNHxeN\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 60.0, \"Danceability\": 0.642, \"Energy\": 0.792, \"Loudness\": -5.746, \"Speechiness\": 0.0488, \"Acousticness\": 0.158, \"Liveness\": 0.68, \"Tempo\": 122.965, \"Duration (ms)\": 244880.0, \"Valence\": 0.0903, \"Chord\": \"C\"}, {\"Index\": 1133, \"Highest Charting Position\": 77, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Enigma\", \"Streams\": 7695566, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"7JDbfYUHjDzQPFSDh5lzGs\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 59.0, \"Danceability\": 0.669, \"Energy\": 0.804, \"Loudness\": -4.035, \"Speechiness\": 0.036, \"Acousticness\": 0.0306, \"Liveness\": 0.694, \"Tempo\": 116.001, \"Duration (ms)\": 179760.0, \"Valence\": 0.184, \"Chord\": \"C\"}, {\"Index\": 1134, \"Highest Charting Position\": 79, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Replay\", \"Streams\": 7479618, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"7sKbyYeJnITO1Eh9xd0lKd\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 63.0, \"Danceability\": 0.658, \"Energy\": 0.878, \"Loudness\": -3.875, \"Speechiness\": 0.123, \"Acousticness\": 0.00792, \"Liveness\": 0.944, \"Tempo\": 122.015, \"Duration (ms)\": 186653.0, \"Valence\": 0.683, \"Chord\": \"C#/Db\"}, {\"Index\": 1135, \"Highest Charting Position\": 80, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Plastic Doll\", \"Streams\": 7451452, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"3CidPLqWXqgesJlwYVJZdy\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.743, \"Energy\": 0.853, \"Loudness\": -4.842, \"Speechiness\": 0.04, \"Acousticness\": 0.0019, \"Liveness\": 0.0872, \"Tempo\": 121.028, \"Duration (ms)\": 221667.0, \"Valence\": 0.422, \"Chord\": \"C\"}, {\"Index\": 1136, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Chromatica II\", \"Streams\": 7136521, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"0oQc0F6KUE7QY7k5TU6bic\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.184, \"Energy\": 0.297, \"Loudness\": -14.534, \"Speechiness\": 0.0359, \"Acousticness\": 0.473, \"Liveness\": 0.527, \"Tempo\": 75.824, \"Duration (ms)\": 41867.0, \"Valence\": 0.113, \"Chord\": \"D\"}, {\"Index\": 1137, \"Highest Charting Position\": 91, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Babylon\", \"Streams\": 6996402, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"5DttNeiizFqWUON9hZBqTY\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 61.0, \"Danceability\": 0.698, \"Energy\": 0.799, \"Loudness\": -4.372, \"Speechiness\": 0.0342, \"Acousticness\": 0.0129, \"Liveness\": 0.215, \"Tempo\": 115.957, \"Duration (ms)\": 161733.0, \"Valence\": 0.351, \"Chord\": \"D\"}, {\"Index\": 1138, \"Highest Charting Position\": 93, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Chromatica I\", \"Streams\": 6630385, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"0oQc0F6KUE7QY7k5TU6bic\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.184, \"Energy\": 0.297, \"Loudness\": -14.534, \"Speechiness\": 0.0359, \"Acousticness\": 0.473, \"Liveness\": 0.527, \"Tempo\": 75.824, \"Duration (ms)\": 41867.0, \"Valence\": 0.113, \"Chord\": \"D\"}, {\"Index\": 1139, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"1000 Doves\", \"Streams\": 6069544, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"62hTXlVQacy3pjBW4ntRPl\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.668, \"Energy\": 0.826, \"Loudness\": -4.466, \"Speechiness\": 0.0383, \"Acousticness\": 0.0236, \"Liveness\": 0.474, \"Tempo\": 122.973, \"Duration (ms)\": 215480.0, \"Valence\": 0.388, \"Chord\": \"A\"}, {\"Index\": 1140, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Broken Glass\", \"Streams\": 5867930, \"Artist\": \"Kygo, Kim Petras\", \"Artist Followers\": 7593792.0, \"Song ID\": \"78ldtCaBRJVp2i91B715L0\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 66.0, \"Danceability\": 0.526, \"Energy\": 0.633, \"Loudness\": -7.002, \"Speechiness\": 0.134, \"Acousticness\": 0.372, \"Liveness\": 0.129, \"Tempo\": 171.044, \"Duration (ms)\": 203947.0, \"Valence\": 0.272, \"Chord\": \"G\"}, {\"Index\": 1141, \"Highest Charting Position\": 131, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"In meinem Benz\", \"Streams\": 5494500, \"Artist\": \"AK AUSSERKONTROLLE, Bonez MC\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 1142, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"FLY\", \"Streams\": 4681054, \"Artist\": \"KC Rebell, Summer Cem\", \"Artist Followers\": 1101597.0, \"Song ID\": \"1WoM4mof0Nl1xPtwf6h6ow\", \"Genre\": \"['german drill', 'german hip hop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 59.0, \"Danceability\": 0.835, \"Energy\": 0.596, \"Loudness\": -6.637, \"Speechiness\": 0.297, \"Acousticness\": 0.137, \"Liveness\": 0.164, \"Tempo\": 100.706, \"Duration (ms)\": 174893.0, \"Valence\": 0.897, \"Chord\": \"F\"}, {\"Index\": 1143, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"SKRR\", \"Streams\": 4629320, \"Artist\": \"KALIM, Ufo361\", \"Artist Followers\": 218931.0, \"Song ID\": \"2J0adlQth373uw9y0yqWAz\", \"Genre\": \"['german hip hop', 'german trap', 'german underground rap', 'hamburg hip hop']\", \"Release Date\": \"2020-09-24\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 60.0, \"Danceability\": 0.803, \"Energy\": 0.649, \"Loudness\": -6.599, \"Speechiness\": 0.132, \"Acousticness\": 0.163, \"Liveness\": 0.152, \"Tempo\": 125.038, \"Duration (ms)\": 119040.0, \"Valence\": 0.584, \"Chord\": \"A#/Bb\"}, {\"Index\": 1144, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"T.D (Lil Yachty & Tierra Whack feat. A$AP Rocky & Tyler, The Creator)\", \"Streams\": 4601709, \"Artist\": \"Lil Yachty\", \"Artist Followers\": 7358720.0, \"Song ID\": \"0gO3E51A3fqp0ypJ26QbVP\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap', 'underground hip hop', 'viral rap']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 66.0, \"Danceability\": 0.784, \"Energy\": 0.632, \"Loudness\": -6.083, \"Speechiness\": 0.347, \"Acousticness\": 0.156, \"Liveness\": 0.605, \"Tempo\": 124.603, \"Duration (ms)\": 232839.0, \"Valence\": 0.746, \"Chord\": \"A#/Bb\"}, {\"Index\": 1145, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Oprah's Bank Account (Lil Yachty & DaBaby feat. Drake)\", \"Streams\": 4598294, \"Artist\": \"Lil Yachty\", \"Artist Followers\": 7358720.0, \"Song ID\": \"7wsmIIm0xWmtP7TmACXkJn\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap', 'underground hip hop', 'viral rap']\", \"Release Date\": \"2020-03-09\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 69.0, \"Danceability\": 0.836, \"Energy\": 0.617, \"Loudness\": -4.363, \"Speechiness\": 0.0534, \"Acousticness\": 0.17, \"Liveness\": 0.319, \"Tempo\": 138.066, \"Duration (ms)\": 206702.0, \"Valence\": 0.866, \"Chord\": \"C\"}, {\"Index\": 1146, \"Highest Charting Position\": 78, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Roadrunner\", \"Streams\": 4596162, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"0atjNG0rNW2m6zPaiK4Co7\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 64.0, \"Danceability\": 0.804, \"Energy\": 0.606, \"Loudness\": -9.045, \"Speechiness\": 0.242, \"Acousticness\": 0.137, \"Liveness\": 0.111, \"Tempo\": 99.024, \"Duration (ms)\": 149028.0, \"Valence\": 0.247, \"Chord\": \"G\"}, {\"Index\": 1147, \"Highest Charting Position\": 99, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Freedom\", \"Streams\": 4573723, \"Artist\": \"Kygo, Zak Abel\", \"Artist Followers\": 7593792.0, \"Song ID\": \"5Gj1wG8b12VQdEd3hUuSwo\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-05-29--2020-06-05\\n2020-04-17--2020-04-24\", \"Popularity\": 72.0, \"Danceability\": 0.715, \"Energy\": 0.635, \"Loudness\": -6.591, \"Speechiness\": 0.0791, \"Acousticness\": 0.127, \"Liveness\": 0.0862, \"Tempo\": 112.887, \"Duration (ms)\": 198635.0, \"Valence\": 0.39, \"Chord\": \"G\"}, {\"Index\": 1148, \"Highest Charting Position\": 45, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Fame\", \"Streams\": 4556947, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"3goH7O78TLkV9RhCAyM4AT\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 62.0, \"Danceability\": 0.811, \"Energy\": 0.645, \"Loudness\": -8.008, \"Speechiness\": 0.104, \"Acousticness\": 0.184, \"Liveness\": 0.103, \"Tempo\": 129.967, \"Duration (ms)\": 173761.0, \"Valence\": 0.474, \"Chord\": \"C#/Db\"}, {\"Index\": 1149, \"Highest Charting Position\": 55, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Daechwita\", \"Streams\": 8908179, \"Artist\": \"Agust D\", \"Artist Followers\": 5564366.0, \"Song ID\": \"0H4ugk6rhnXmTl47ayy9O5\", \"Genre\": \"['k-rap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 77.0, \"Danceability\": 0.65, \"Energy\": 0.827, \"Loudness\": -4.014, \"Speechiness\": 0.0599, \"Acousticness\": 0.0229, \"Liveness\": 0.121, \"Tempo\": 144.995, \"Duration (ms)\": 225668.0, \"Valence\": 0.223, \"Chord\": \"G#/Ab\"}, {\"Index\": 1150, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"COOLER THAN A BITCH (feat. Roddy Ricch)\", \"Streams\": 6642144, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"5LHHKZOwV8XW4LJP2C64mw\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 67.0, \"Danceability\": 0.837, \"Energy\": 0.586, \"Loudness\": -8.521, \"Speechiness\": 0.0807, \"Acousticness\": 0.281, \"Liveness\": 0.134, \"Tempo\": 117.066, \"Duration (ms)\": 197000.0, \"Valence\": 0.618, \"Chord\": \"B\"}, {\"Index\": 1151, \"Highest Charting Position\": 90, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"In Your Eyes (with Doja Cat) - Remix\", \"Streams\": 6511008, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"0UnTaVkntyh3vqvLEvbpQx\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-05-21\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 67.0, \"Danceability\": 0.679, \"Energy\": 0.731, \"Loudness\": -5.522, \"Speechiness\": 0.0319, \"Acousticness\": 0.00518, \"Liveness\": 0.0614, \"Tempo\": 99.984, \"Duration (ms)\": 237912.0, \"Valence\": 0.727, \"Chord\": \"G\"}, {\"Index\": 1152, \"Highest Charting Position\": 92, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"WUNNA\", \"Streams\": 6384306, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"0y7Ao3CVJsyKFmqdjutiIF\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 60.0, \"Danceability\": 0.89, \"Energy\": 0.455, \"Loudness\": -9.0, \"Speechiness\": 0.255, \"Acousticness\": 0.0217, \"Liveness\": 0.11, \"Tempo\": 148.009, \"Duration (ms)\": 158240.0, \"Valence\": 0.313, \"Chord\": \"C\"}, {\"Index\": 1153, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Komm Komm\", \"Streams\": 5552890, \"Artist\": \"Capital Bra\", \"Artist Followers\": 4093115.0, \"Song ID\": \"3US6RbELvvrPw3DcvtJmis\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-05-21\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 53.0, \"Danceability\": 0.485, \"Energy\": 0.793, \"Loudness\": -3.836, \"Speechiness\": 0.426, \"Acousticness\": 0.251, \"Liveness\": 0.146, \"Tempo\": 87.629, \"Duration (ms)\": 160667.0, \"Valence\": 0.371, \"Chord\": \"B\"}, {\"Index\": 1154, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"TOP FLOOR (feat. Travis Scott)\", \"Streams\": 5193309, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"4YhJ3a6kBPGJWX4Ek77sDd\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 63.0, \"Danceability\": 0.823, \"Energy\": 0.504, \"Loudness\": -8.65, \"Speechiness\": 0.16, \"Acousticness\": 0.206, \"Liveness\": 0.417, \"Tempo\": 112.985, \"Duration (ms)\": 169907.0, \"Valence\": 0.481, \"Chord\": \"G#/Ab\"}, {\"Index\": 1155, \"Highest Charting Position\": 54, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Goodbyes (Feat. Young Thug)\", \"Streams\": 5134161, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"0t3ZvGKlmYmVsDzBJAXK8C\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.548, \"Energy\": 0.653, \"Loudness\": -3.875, \"Speechiness\": 0.081, \"Acousticness\": 0.456, \"Liveness\": 0.103, \"Tempo\": 150.068, \"Duration (ms)\": 174853.0, \"Valence\": 0.163, \"Chord\": \"F\"}, {\"Index\": 1156, \"Highest Charting Position\": 59, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"CANCI\\u00d3N CON YANDEL\", \"Streams\": 5132247, \"Artist\": \"Yandel, Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3pm4XtcsRIFFtH2UErk62R\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 76.0, \"Danceability\": 0.75, \"Energy\": 0.741, \"Loudness\": -4.43, \"Speechiness\": 0.402, \"Acousticness\": 0.447, \"Liveness\": 0.121, \"Tempo\": 79.968, \"Duration (ms)\": 209180.0, \"Valence\": 0.495, \"Chord\": \"A\"}, {\"Index\": 1157, \"Highest Charting Position\": 92, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"X (with KAROL G)\", \"Streams\": 5018592, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"77fvnWALKJR0ws1VUx09CY\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 70.0, \"Danceability\": 0.715, \"Energy\": 0.827, \"Loudness\": -5.09, \"Speechiness\": 0.0617, \"Acousticness\": 0.0485, \"Liveness\": 0.321, \"Tempo\": 117.977, \"Duration (ms)\": 185277.0, \"Valence\": 0.75, \"Chord\": \"E\"}, {\"Index\": 1158, \"Highest Charting Position\": 56, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"M\\u00c1S DE UNA CITA\", \"Streams\": 4987116, \"Artist\": \"Bad Bunny, Zion & Lennox\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4EJHKSnHENfjOxXWryyNtL\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 67.0, \"Danceability\": 0.865, \"Energy\": 0.5, \"Loudness\": -10.805, \"Speechiness\": 0.0861, \"Acousticness\": 0.0122, \"Liveness\": 0.098, \"Tempo\": 92.976, \"Duration (ms)\": 183520.0, \"Valence\": 0.317, \"Chord\": \"F\"}, {\"Index\": 1159, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Together\", \"Streams\": 4861870, \"Artist\": \"Sia\", \"Artist Followers\": 20528724.0, \"Song ID\": \"5id3Rqn7SPj1LX4FfY4nGz\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'pop']\", \"Release Date\": \"2020-05-20\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 71.0, \"Danceability\": 0.521, \"Energy\": 0.877, \"Loudness\": -5.444, \"Speechiness\": 0.0683, \"Acousticness\": 0.0132, \"Liveness\": 0.0929, \"Tempo\": 180.007, \"Duration (ms)\": 205208.0, \"Valence\": 0.199, \"Chord\": \"G\"}, {\"Index\": 1160, \"Highest Charting Position\": 62, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"eight(Prod.&Feat. SUGA of BTS)\", \"Streams\": 4764954, \"Artist\": \"IU\", \"Artist Followers\": 4939593.0, \"Song ID\": \"0pYacDCZuRhcrwGUA5nTBe\", \"Genre\": \"['k-pop']\", \"Release Date\": \"2020-05-06\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 75.0, \"Danceability\": 0.676, \"Energy\": 0.869, \"Loudness\": -1.573, \"Speechiness\": 0.0423, \"Acousticness\": 0.115, \"Liveness\": 0.132, \"Tempo\": 120.029, \"Duration (ms)\": 167573.0, \"Valence\": 0.594, \"Chord\": \"C#/Db\"}, {\"Index\": 1161, \"Highest Charting Position\": 16, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"You should be sad\", \"Streams\": 4761908, \"Artist\": \"Halsey\", \"Artist Followers\": 15663384.0, \"Song ID\": \"7lidXGPXPYLNThITAOTlkK\", \"Genre\": \"['dance pop', 'electropop', 'etherpop', 'indie poptimism', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 76.0, \"Danceability\": 0.591, \"Energy\": 0.585, \"Loudness\": -6.35, \"Speechiness\": 0.0277, \"Acousticness\": 0.143, \"Liveness\": 0.109, \"Tempo\": 110.94, \"Duration (ms)\": 205473.0, \"Valence\": 0.324, \"Chord\": \"D\"}, {\"Index\": 1162, \"Highest Charting Position\": 54, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"CITY OF ANGELS\", \"Streams\": 4645541, \"Artist\": \"24kGoldn\", \"Artist Followers\": 1276406.0, \"Song ID\": \"6ap9lSRJ0iLriGLqoJ44cq\", \"Genre\": \"['cali rap']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 76.0, \"Danceability\": 0.686, \"Energy\": 0.541, \"Loudness\": -4.993, \"Speechiness\": 0.0493, \"Acousticness\": 0.042, \"Liveness\": 0.0675, \"Tempo\": 120.082, \"Duration (ms)\": 112493.0, \"Valence\": 0.724, \"Chord\": \"C\"}, {\"Index\": 1163, \"Highest Charting Position\": 98, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Astronomia\", \"Streams\": 4642284, \"Artist\": \"Vicetone, Tony Igy\", \"Artist Followers\": 378114.0, \"Song ID\": \"3hWfKBt3n7j1xqIy6LA5ve\", \"Genre\": \"['edm', 'electro house', 'pop dance', 'pop edm', 'progressive electro house', 'tropical house']\", \"Release Date\": \"2016-09-16\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 71.0, \"Danceability\": 0.653, \"Energy\": 0.945, \"Loudness\": -2.634, \"Speechiness\": 0.096, \"Acousticness\": 0.00561, \"Liveness\": 0.439, \"Tempo\": 126.093, \"Duration (ms)\": 198095.0, \"Valence\": 0.326, \"Chord\": \"F\"}, {\"Index\": 1164, \"Highest Charting Position\": 7, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"After Hours\", \"Streams\": 4559855, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"2p8IUWQDrpjuFltbdgLOag\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 75.0, \"Danceability\": 0.664, \"Energy\": 0.572, \"Loudness\": -6.099, \"Speechiness\": 0.0305, \"Acousticness\": 0.0811, \"Liveness\": 0.121, \"Tempo\": 108.959, \"Duration (ms)\": 361027.0, \"Valence\": 0.143, \"Chord\": \"F\"}, {\"Index\": 1165, \"Highest Charting Position\": 51, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"BUTTERFLY EFFECT\", \"Streams\": 4537762, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"2cYqizR4lgvp4Qu6IQ3qGN\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2018-08-03\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 79.0, \"Danceability\": 0.763, \"Energy\": 0.628, \"Loudness\": -5.85, \"Speechiness\": 0.05, \"Acousticness\": 0.0531, \"Liveness\": 0.114, \"Tempo\": 140.958, \"Duration (ms)\": 190557.0, \"Valence\": 0.193, \"Chord\": \"B\"}, {\"Index\": 1166, \"Highest Charting Position\": 74, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Never Seen the Rain\", \"Streams\": 4473968, \"Artist\": \"Tones And I\", \"Artist Followers\": 1251372.0, \"Song ID\": \"1xUCDewhwnORlcFflAgml0\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.742, \"Energy\": 0.464, \"Loudness\": -5.624, \"Speechiness\": 0.0318, \"Acousticness\": 0.425, \"Liveness\": 0.284, \"Tempo\": 92.107, \"Duration (ms)\": 200742.0, \"Valence\": 0.281, \"Chord\": \"F#/Gb\"}, {\"Index\": 1167, \"Highest Charting Position\": 120, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Sigues Con El - Remix\", \"Streams\": 4440738, \"Artist\": \"Arcangel, Sech, Romeo Santos\", \"Artist Followers\": 6671084.0, \"Song ID\": \"4Pu0a2TuHOYtI4CCE3HEXI\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-04-10\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 69.0, \"Danceability\": 0.747, \"Energy\": 0.693, \"Loudness\": -2.97, \"Speechiness\": 0.298, \"Acousticness\": 0.102, \"Liveness\": 0.0872, \"Tempo\": 175.994, \"Duration (ms)\": 189567.0, \"Valence\": 0.736, \"Chord\": \"C#/Db\"}, {\"Index\": 1168, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"ANGELS & DEMONS\", \"Streams\": 4435538, \"Artist\": \"jxdn\", \"Artist Followers\": 799682.0, \"Song ID\": \"3mkz6eI4Sram8UhO3teU76\", \"Genre\": \"[]\", \"Release Date\": \"2021-07-02\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 72.0, \"Danceability\": 0.554, \"Energy\": 0.8, \"Loudness\": -3.936, \"Speechiness\": 0.0395, \"Acousticness\": 0.119, \"Liveness\": 0.629, \"Tempo\": 115.056, \"Duration (ms)\": 160120.0, \"Valence\": 0.463, \"Chord\": \"G#/Ab\"}, {\"Index\": 1169, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Conf\\u00eda\", \"Streams\": 4419295, \"Artist\": \"Sech, Daddy Yankee\", \"Artist Followers\": 8766508.0, \"Song ID\": \"5kbps8unnGH4raN5WduZuq\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-21\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 62.0, \"Danceability\": 0.722, \"Energy\": 0.757, \"Loudness\": -3.592, \"Speechiness\": 0.0782, \"Acousticness\": 0.17, \"Liveness\": 0.0657, \"Tempo\": 167.987, \"Duration (ms)\": 202308.0, \"Valence\": 0.763, \"Chord\": \"C\"}, {\"Index\": 1170, \"Highest Charting Position\": 44, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Mu\\u00e9velo\", \"Streams\": 4407165, \"Artist\": \"Nicky Jam, Daddy Yankee\", \"Artist Followers\": 14831925.0, \"Song ID\": \"4VgYtXCVJ7IbWAZ5ryfvEQ\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-01-08\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 72.0, \"Danceability\": 0.594, \"Energy\": 0.808, \"Loudness\": -2.409, \"Speechiness\": 0.0489, \"Acousticness\": 0.415, \"Liveness\": 0.565, \"Tempo\": 188.09, \"Duration (ms)\": 194892.0, \"Valence\": 0.919, \"Chord\": \"G\"}, {\"Index\": 1171, \"Highest Charting Position\": 105, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"All Bad (feat. Lil Uzi Vert)\", \"Streams\": 6194224, \"Artist\": \"Future\", \"Artist Followers\": 10491105.0, \"Song ID\": \"021lWIHJrURZrmvYQ1xcM8\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 60.0, \"Danceability\": 0.931, \"Energy\": 0.667, \"Loudness\": -7.043, \"Speechiness\": 0.318, \"Acousticness\": 0.0144, \"Liveness\": 0.15, \"Tempo\": 142.039, \"Duration (ms)\": 207739.0, \"Valence\": 0.667, \"Chord\": \"F#/Gb\"}, {\"Index\": 1172, \"Highest Charting Position\": 12, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Pain 1993 (with Playboi Carti)\", \"Streams\": 6085143, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"6Kj17Afjo1OKJYpf5VzCeo\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 67.0, \"Danceability\": 0.825, \"Energy\": 0.373, \"Loudness\": -5.532, \"Speechiness\": 0.108, \"Acousticness\": 0.163, \"Liveness\": 0.368, \"Tempo\": 77.271, \"Duration (ms)\": 149078.0, \"Valence\": 0.12, \"Chord\": \"F\"}, {\"Index\": 1173, \"Highest Charting Position\": 110, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Trillionaire (feat. Youngboy Never Broke Again)\", \"Streams\": 6057848, \"Artist\": \"Future\", \"Artist Followers\": 10491105.0, \"Song ID\": \"740kQ8xwSGloumdiKR5Cwz\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 61.0, \"Danceability\": 0.768, \"Energy\": 0.526, \"Loudness\": -7.182, \"Speechiness\": 0.209, \"Acousticness\": 0.237, \"Liveness\": 0.139, \"Tempo\": 139.999, \"Duration (ms)\": 167552.0, \"Valence\": 0.473, \"Chord\": \"C\"}, {\"Index\": 1174, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Go Stupid\", \"Streams\": 5464816, \"Artist\": \"Polo G, Stunna 4 Vegas, NLE Choppa, Mike WiLL Made-It\", \"Artist Followers\": 4849204.0, \"Song ID\": \"4PklAHGXT5ityno3IA8SKd\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 74.0, \"Danceability\": 0.92, \"Energy\": 0.833, \"Loudness\": -3.18, \"Speechiness\": 0.253, \"Acousticness\": 0.0277, \"Liveness\": 0.0596, \"Tempo\": 141.034, \"Duration (ms)\": 165726.0, \"Valence\": 0.645, \"Chord\": \"C#/Db\"}, {\"Index\": 1175, \"Highest Charting Position\": 149, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"A Gente Fez Amor - Ao Vivo\", \"Streams\": 5006457, \"Artist\": \"Gusttavo Lima\", \"Artist Followers\": 12981319.0, \"Song ID\": \"3tv697PZNnaQN0Mn2zGhS5\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2019-12-05\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-02-07--2020-02-14\\n2020-01-03--2020-01-10\", \"Popularity\": 66.0, \"Danceability\": 0.794, \"Energy\": 0.937, \"Loudness\": -2.44, \"Speechiness\": 0.0336, \"Acousticness\": 0.366, \"Liveness\": 0.962, \"Tempo\": 134.012, \"Duration (ms)\": 237517.0, \"Valence\": 0.826, \"Chord\": \"G#/Ab\"}, {\"Index\": 1176, \"Highest Charting Position\": 173, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Racks 2 Skinny\", \"Streams\": 4729629, \"Artist\": \"Migos\", \"Artist Followers\": 11692972.0, \"Song ID\": \"568OIKgeHyGRD3uWR44JbO\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-11\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 61.0, \"Danceability\": 0.814, \"Energy\": 0.584, \"Loudness\": -5.425, \"Speechiness\": 0.0819, \"Acousticness\": 0.00839, \"Liveness\": 0.0646, \"Tempo\": 141.016, \"Duration (ms)\": 178025.0, \"Valence\": 0.405, \"Chord\": \"C#/Db\"}, {\"Index\": 1177, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Be Something (feat. Lil Baby)\", \"Streams\": 4687909, \"Artist\": \"Polo G\", \"Artist Followers\": 4849204.0, \"Song ID\": \"65jw6GhwQW3Db55PxlPEpS\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 69.0, \"Danceability\": 0.829, \"Energy\": 0.52, \"Loudness\": -10.34, \"Speechiness\": 0.294, \"Acousticness\": 0.0232, \"Liveness\": 0.134, \"Tempo\": 136.103, \"Duration (ms)\": 194118.0, \"Valence\": 0.248, \"Chord\": \"G#/Ab\"}, {\"Index\": 1178, \"Highest Charting Position\": 82, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"BENDICIONES\", \"Streams\": 4639997, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2CoMYp2uIKsT09nreEZnZn\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 67.0, \"Danceability\": 0.828, \"Energy\": 0.581, \"Loudness\": -9.909, \"Speechiness\": 0.0725, \"Acousticness\": 0.0378, \"Liveness\": 0.103, \"Tempo\": 143.995, \"Duration (ms)\": 155060.0, \"Valence\": 0.843, \"Chord\": \"B\"}, {\"Index\": 1179, \"Highest Charting Position\": 126, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"PTSD\", \"Streams\": 4500903, \"Artist\": \"G Herbo, Juice WRLD, Lil Uzi Vert, Chance the Rapper\", \"Artist Followers\": 1253138.0, \"Song ID\": \"1C8ux1YWLMHCenYJFiIV4Z\", \"Genre\": \"['chicago drill', 'chicago rap', 'drill', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-02-28--2020-03-06\", \"Popularity\": 76.0, \"Danceability\": 0.883, \"Energy\": 0.808, \"Loudness\": -3.158, \"Speechiness\": 0.182, \"Acousticness\": 0.0313, \"Liveness\": 0.207, \"Tempo\": 119.01, \"Duration (ms)\": 232065.0, \"Valence\": 0.806, \"Chord\": \"C#/Db\"}, {\"Index\": 1180, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Excitement\", \"Streams\": 4416484, \"Artist\": \"Trippie Redd, PARTYNEXTDOOR\", \"Artist Followers\": 6434201.0, \"Song ID\": \"7FullO2NDkyvxLuxYVKINa\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 69.0, \"Danceability\": 0.443, \"Energy\": 0.536, \"Loudness\": -8.187, \"Speechiness\": 0.0378, \"Acousticness\": 0.0194, \"Liveness\": 0.1, \"Tempo\": 121.967, \"Duration (ms)\": 283285.0, \"Valence\": 0.0391, \"Chord\": \"E\"}, {\"Index\": 1181, \"Highest Charting Position\": 131, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Can We Kiss Forever?\", \"Streams\": 4397385, \"Artist\": \"Kina, Adriana Proenza\", \"Artist Followers\": 661863.0, \"Song ID\": \"58wyJLv6yH1La9NIZPl3ne\", \"Genre\": \"['sad rap']\", \"Release Date\": \"2018-08-31\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.522, \"Energy\": 0.128, \"Loudness\": -18.717, \"Speechiness\": 0.0357, \"Acousticness\": 0.894, \"Liveness\": 0.0941, \"Tempo\": 109.986, \"Duration (ms)\": 187932.0, \"Valence\": 0.124, \"Chord\": \"E\"}, {\"Index\": 1182, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"SI ELLA SALE\", \"Streams\": 7055918, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"1zaDh3qaGSeSmulNyWlUxm\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 63.0, \"Danceability\": 0.869, \"Energy\": 0.727, \"Loudness\": -7.397, \"Speechiness\": 0.123, \"Acousticness\": 0.0589, \"Liveness\": 0.107, \"Tempo\": 147.967, \"Duration (ms)\": 143240.0, \"Valence\": 0.92, \"Chord\": \"G\"}, {\"Index\": 1183, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"RONCA FREESTYLE\", \"Streams\": 5784075, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3XZeOzJ9tqnu58YP6cqApI\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 64.0, \"Danceability\": 0.856, \"Energy\": 0.656, \"Loudness\": -6.483, \"Speechiness\": 0.131, \"Acousticness\": 0.165, \"Liveness\": 0.0998, \"Tempo\": 90.041, \"Duration (ms)\": 150060.0, \"Valence\": 0.586, \"Chord\": \"F\"}, {\"Index\": 1184, \"Highest Charting Position\": 130, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Zoo York (feat. Fivio Foreign & Pop Smoke)\", \"Streams\": 5368705, \"Artist\": \"Lil Tjay\", \"Artist Followers\": 3559267.0, \"Song ID\": \"3Ddny34bFoYBb8dIGq5lwp\", \"Genre\": \"['brooklyn drill', 'melodic rap', 'nyc rap']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 70.0, \"Danceability\": 0.565, \"Energy\": 0.569, \"Loudness\": -6.084, \"Speechiness\": 0.379, \"Acousticness\": 0.0352, \"Liveness\": 0.106, \"Tempo\": 92.466, \"Duration (ms)\": 214825.0, \"Valence\": 0.303, \"Chord\": \"F#/Gb\"}, {\"Index\": 1185, \"Highest Charting Position\": 131, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"EN CASITA\", \"Streams\": 5364262, \"Artist\": \"Bad Bunny, Gabriela\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2DhNdoHxavs7Qtf5MnhZD0\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 62.0, \"Danceability\": 0.779, \"Energy\": 0.764, \"Loudness\": -8.217, \"Speechiness\": 0.0938, \"Acousticness\": 0.221, \"Liveness\": 0.0909, \"Tempo\": 158.093, \"Duration (ms)\": 176440.0, \"Valence\": 0.675, \"Chord\": \"C\"}, {\"Index\": 1186, \"Highest Charting Position\": 71, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Qu\\u00e9 Maldici\\u00f3n\", \"Streams\": 4971559, \"Artist\": \"Banda MS de Sergio Liz\\u00e1rraga, Snoop Dogg\", \"Artist Followers\": 12140496.0, \"Song ID\": \"2RxC2peY3FtrurYmbbmanr\", \"Genre\": \"['banda', 'corrido', 'norteno', 'regional mexican']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 69.0, \"Danceability\": 0.755, \"Energy\": 0.531, \"Loudness\": -8.051, \"Speechiness\": 0.196, \"Acousticness\": 0.213, \"Liveness\": 0.13, \"Tempo\": 177.951, \"Duration (ms)\": 203360.0, \"Valence\": 0.683, \"Chord\": \"A\"}, {\"Index\": 1187, \"Highest Charting Position\": 69, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Nicht verdient\", \"Streams\": 4912914, \"Artist\": \"Capital Bra, Loredana\", \"Artist Followers\": 4093115.0, \"Song ID\": \"7v8OynJxOxHoeS5C2UA9Y7\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-04-29\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 58.0, \"Danceability\": 0.719, \"Energy\": 0.65, \"Loudness\": -7.274, \"Speechiness\": 0.232, \"Acousticness\": 0.381, \"Liveness\": 0.167, \"Tempo\": 77.981, \"Duration (ms)\": 176953.0, \"Valence\": 0.488, \"Chord\": \"B\"}, {\"Index\": 1188, \"Highest Charting Position\": 52, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"A Tu Merced\", \"Streams\": 4909499, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4r9jkMEnArtWGH2rL2FZl0\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 82.0, \"Danceability\": 0.86, \"Energy\": 0.791, \"Loudness\": -4.784, \"Speechiness\": 0.0568, \"Acousticness\": 0.169, \"Liveness\": 0.106, \"Tempo\": 92.023, \"Duration (ms)\": 175918.0, \"Valence\": 0.887, \"Chord\": \"C\"}, {\"Index\": 1189, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Demons (feat. Fivio Foreign & Sosa Geek)\", \"Streams\": 4766829, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"05aZ9sAU1YXndHv0FMi9iW\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 63.0, \"Danceability\": 0.543, \"Energy\": 0.766, \"Loudness\": -3.387, \"Speechiness\": 0.343, \"Acousticness\": 0.423, \"Liveness\": 0.155, \"Tempo\": 106.869, \"Duration (ms)\": 204805.0, \"Valence\": 0.729, \"Chord\": \"C\"}, {\"Index\": 1190, \"Highest Charting Position\": 42, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Moral of the Story\", \"Streams\": 4609358, \"Artist\": \"Ashe\", \"Artist Followers\": 644479.0, \"Song ID\": \"2nC3QhMI9reBIOWutbU3Tj\", \"Genre\": \"['alt z', 'electropop', 'indie pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-02-14\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 75.0, \"Danceability\": 0.572, \"Energy\": 0.406, \"Loudness\": -8.624, \"Speechiness\": 0.0427, \"Acousticness\": 0.587, \"Liveness\": 0.102, \"Tempo\": 119.812, \"Duration (ms)\": 201084.0, \"Valence\": 0.265, \"Chord\": \"A#/Bb\"}, {\"Index\": 1191, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Can I\", \"Streams\": 4603243, \"Artist\": \"Kehlani\", \"Artist Followers\": 4894562.0, \"Song ID\": \"0uDdI4fAXCuNhQbmxENdsO\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop', 'r&b']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 68.0, \"Danceability\": 0.574, \"Energy\": 0.791, \"Loudness\": -3.752, \"Speechiness\": 0.11, \"Acousticness\": 0.419, \"Liveness\": 0.0982, \"Tempo\": 119.537, \"Duration (ms)\": 167810.0, \"Valence\": 0.612, \"Chord\": \"C#/Db\"}, {\"Index\": 1192, \"Highest Charting Position\": 46, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"STARGAZING\", \"Streams\": 4499820, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"7wBJfHzpfI3032CSD7CE2m\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2018-08-03\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 76.0, \"Danceability\": 0.487, \"Energy\": 0.789, \"Loudness\": -3.69, \"Speechiness\": 0.044, \"Acousticness\": 0.00947, \"Liveness\": 0.189, \"Tempo\": 150.007, \"Duration (ms)\": 270715.0, \"Valence\": 0.0564, \"Chord\": \"G#/Ab\"}, {\"Index\": 1193, \"Highest Charting Position\": 124, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Eastside (with Halsey & Khalid)\", \"Streams\": 4397708, \"Artist\": \"benny blanco\", \"Artist Followers\": 804613.0, \"Song ID\": \"0d2iYfpKoM0QCKvcLCkBao\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2018-07-12\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.56, \"Energy\": 0.68, \"Loudness\": -7.648, \"Speechiness\": 0.321, \"Acousticness\": 0.555, \"Liveness\": 0.116, \"Tempo\": 89.391, \"Duration (ms)\": 173800.0, \"Valence\": 0.319, \"Chord\": \"F#/Gb\"}, {\"Index\": 1194, \"Highest Charting Position\": 23, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Suicidal\", \"Streams\": 4320116, \"Artist\": \"YNW Melly\", \"Artist Followers\": 6332535.0, \"Song ID\": \"4S2uhQE8L9V6p7rj7SiauJ\", \"Genre\": \"['melodic rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.655, \"Energy\": 0.441, \"Loudness\": -5.245, \"Speechiness\": 0.0629, \"Acousticness\": 0.474, \"Liveness\": 0.099, \"Tempo\": 139.957, \"Duration (ms)\": 225857.0, \"Valence\": 0.273, \"Chord\": \"A\"}, {\"Index\": 1195, \"Highest Charting Position\": 39, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"How Do You Sleep?\", \"Streams\": 4313625, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"6b2RcmUt1g9N9mQ3CbjX2Y\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2019-07-19\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.477, \"Energy\": 0.682, \"Loudness\": -4.931, \"Speechiness\": 0.0925, \"Acousticness\": 0.153, \"Liveness\": 0.0763, \"Tempo\": 110.567, \"Duration (ms)\": 202205.0, \"Valence\": 0.345, \"Chord\": \"C#/Db\"}, {\"Index\": 1196, \"Highest Charting Position\": 4, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"No Time To Die\", \"Streams\": 4293009, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"73SpzrcaHk0RQPFP73vqVR\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2020-02-13\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 75.0, \"Danceability\": 0.38, \"Energy\": 0.219, \"Loudness\": -13.273, \"Speechiness\": 0.0358, \"Acousticness\": 0.917, \"Liveness\": 0.0827, \"Tempo\": 73.537, \"Duration (ms)\": 242265.0, \"Valence\": 0.0517, \"Chord\": \"E\"}, {\"Index\": 1197, \"Highest Charting Position\": 46, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"D4L\", \"Streams\": 10537097, \"Artist\": \"Future, Drake, Young Thug\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5fHrHoJKfCgBd35zwIBmUK\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 63.0, \"Danceability\": 0.718, \"Energy\": 0.706, \"Loudness\": -5.709, \"Speechiness\": 0.06, \"Acousticness\": 0.0128, \"Liveness\": 0.352, \"Tempo\": 170.004, \"Duration (ms)\": 189176.0, \"Valence\": 0.815, \"Chord\": \"C#/Db\"}, {\"Index\": 1198, \"Highest Charting Position\": 51, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Time Flies\", \"Streams\": 9904749, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5H4mXWKcicuLKDn4Jy0sK7\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 71.0, \"Danceability\": 0.864, \"Energy\": 0.477, \"Loudness\": -5.786, \"Speechiness\": 0.224, \"Acousticness\": 0.201, \"Liveness\": 0.182, \"Tempo\": 86.46, \"Duration (ms)\": 192932.0, \"Valence\": 0.5, \"Chord\": \"A#/Bb\"}, {\"Index\": 1199, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Desires (with Future)\", \"Streams\": 9628215, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"7eYAHC0RbBF9eaqWzT34Aq\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.812, \"Energy\": 0.506, \"Loudness\": -7.706, \"Speechiness\": 0.116, \"Acousticness\": 0.281, \"Liveness\": 0.325, \"Tempo\": 145.074, \"Duration (ms)\": 237946.0, \"Valence\": 0.554, \"Chord\": \"F\"}, {\"Index\": 1200, \"Highest Charting Position\": 55, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Not You Too (feat. Chris Brown)\", \"Streams\": 9284383, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"3Q4gttWQ6hxqWOa3tHoTNi\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.458, \"Energy\": 0.452, \"Loudness\": -9.299, \"Speechiness\": 0.047, \"Acousticness\": 0.342, \"Liveness\": 0.0703, \"Tempo\": 86.318, \"Duration (ms)\": 269680.0, \"Valence\": 0.316, \"Chord\": \"A\"}, {\"Index\": 1201, \"Highest Charting Position\": 67, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Landed\", \"Streams\": 8355036, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"3KixNgUEaDtrKJVzdqjU5q\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 60.0, \"Danceability\": 0.881, \"Energy\": 0.636, \"Loudness\": -4.629, \"Speechiness\": 0.287, \"Acousticness\": 0.00606, \"Liveness\": 0.111, \"Tempo\": 163.949, \"Duration (ms)\": 152195.0, \"Valence\": 0.715, \"Chord\": \"G\"}, {\"Index\": 1202, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"When To Say When\", \"Streams\": 8304928, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5TCBWmEBrin7etRa4Lswr1\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 60.0, \"Danceability\": 0.41, \"Energy\": 0.82, \"Loudness\": -6.808, \"Speechiness\": 0.533, \"Acousticness\": 0.252, \"Liveness\": 0.538, \"Tempo\": 170.718, \"Duration (ms)\": 223124.0, \"Valence\": 0.526, \"Chord\": \"C#/Db\"}, {\"Index\": 1203, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Deep Pockets\", \"Streams\": 8285754, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"3IvMYBE7A3c7to1aEcfFJk\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 58.0, \"Danceability\": 0.473, \"Energy\": 0.824, \"Loudness\": -3.68, \"Speechiness\": 0.163, \"Acousticness\": 0.482, \"Liveness\": 0.605, \"Tempo\": 77.888, \"Duration (ms)\": 222929.0, \"Valence\": 0.374, \"Chord\": \"G\"}, {\"Index\": 1204, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"War\", \"Streams\": 7821869, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"1I55Ea0zVoSKs6MqW7DQ3i\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.749, \"Energy\": 0.792, \"Loudness\": -4.151, \"Speechiness\": 0.0826, \"Acousticness\": 0.292, \"Liveness\": 0.109, \"Tempo\": 144.064, \"Duration (ms)\": 180000.0, \"Valence\": 0.239, \"Chord\": \"A#/Bb\"}, {\"Index\": 1205, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"From Florida With Love\", \"Streams\": 7216610, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"0YkUwXxnTkeJBvt5upeEtP\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.787, \"Energy\": 0.477, \"Loudness\": -7.837, \"Speechiness\": 0.199, \"Acousticness\": 0.768, \"Liveness\": 0.104, \"Tempo\": 80.506, \"Duration (ms)\": 234783.0, \"Valence\": 0.476, \"Chord\": \"F#/Gb\"}, {\"Index\": 1206, \"Highest Charting Position\": 89, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Losses\", \"Streams\": 6894756, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"6fLVTVaHWaEfVKfEgbkf4D\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 57.0, \"Danceability\": 0.551, \"Energy\": 0.57, \"Loudness\": -7.385, \"Speechiness\": 0.351, \"Acousticness\": 0.28, \"Liveness\": 0.424, \"Tempo\": 85.687, \"Duration (ms)\": 271184.0, \"Valence\": 0.505, \"Chord\": \"C#/Db\"}, {\"Index\": 1207, \"Highest Charting Position\": 25, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Turks (feat. Travis Scott)\", \"Streams\": 5594561, \"Artist\": \"NAV, Gunna\", \"Artist Followers\": 2613211.0, \"Song ID\": \"0lSZh5W0wDeurkGzLYY6hf\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'hip hop', 'melodic rap', 'pop rap', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 70.0, \"Danceability\": 0.893, \"Energy\": 0.618, \"Loudness\": -4.425, \"Speechiness\": 0.112, \"Acousticness\": 0.0827, \"Liveness\": 0.542, \"Tempo\": 119.099, \"Duration (ms)\": 161377.0, \"Valence\": 0.389, \"Chord\": \"G\"}, {\"Index\": 1208, \"Highest Charting Position\": 40, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Boyfriend\", \"Streams\": 5236730, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4QnC1bIaMSfDQvF4XDhV5M\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 62.0, \"Danceability\": 0.811, \"Energy\": 0.512, \"Loudness\": -6.381, \"Speechiness\": 0.17, \"Acousticness\": 0.218, \"Liveness\": 0.0768, \"Tempo\": 92.046, \"Duration (ms)\": 161188.0, \"Valence\": 0.346, \"Chord\": \"D\"}, {\"Index\": 1209, \"Highest Charting Position\": 29, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"What If I Told You That I Love You\", \"Streams\": 5234645, \"Artist\": \"Ali Gatie\", \"Artist Followers\": 1758300.0, \"Song ID\": \"6USdi8uX5GNAPYziFhisHb\", \"Genre\": \"['canadian hip hop', 'pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 69.0, \"Danceability\": 0.596, \"Energy\": 0.366, \"Loudness\": -11.144, \"Speechiness\": 0.115, \"Acousticness\": 0.63, \"Liveness\": 0.0554, \"Tempo\": 84.394, \"Duration (ms)\": 193668.0, \"Valence\": 0.229, \"Chord\": \"G\"}, {\"Index\": 1210, \"Highest Charting Position\": 85, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Emotions\", \"Streams\": 4901960, \"Artist\": \"Ufo361\", \"Artist Followers\": 1700759.0, \"Song ID\": \"3yZCjDTxzZxx1kll1sRjGc\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 65.0, \"Danceability\": 0.788, \"Energy\": 0.491, \"Loudness\": -9.884, \"Speechiness\": 0.109, \"Acousticness\": 0.386, \"Liveness\": 0.107, \"Tempo\": 98.543, \"Duration (ms)\": 146028.0, \"Valence\": 0.271, \"Chord\": \"G#/Ab\"}, {\"Index\": 1211, \"Highest Charting Position\": 32, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"FIND MY WAY\", \"Streams\": 4753495, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"1gVCEnryJhkdQcuC0Kbvor\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 66.0, \"Danceability\": 0.836, \"Energy\": 0.624, \"Loudness\": -6.75, \"Speechiness\": 0.184, \"Acousticness\": 0.187, \"Liveness\": 0.138, \"Tempo\": 103.0, \"Duration (ms)\": 139890.0, \"Valence\": 0.7, \"Chord\": \"E\"}, {\"Index\": 1212, \"Highest Charting Position\": 37, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Keii\", \"Streams\": 4687605, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"5eEQCfq7MXQr6aHLNRUZLs\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 67.0, \"Danceability\": 0.708, \"Energy\": 0.797, \"Loudness\": -3.095, \"Speechiness\": 0.0391, \"Acousticness\": 0.4, \"Liveness\": 0.096, \"Tempo\": 88.015, \"Duration (ms)\": 210000.0, \"Valence\": 0.51, \"Chord\": \"C\"}, {\"Index\": 1213, \"Highest Charting Position\": 130, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"God's Plan\", \"Streams\": 4565400, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"6DCZcSspjsKoFjzjrWoCdn\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2018-06-29\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.754, \"Energy\": 0.449, \"Loudness\": -9.211, \"Speechiness\": 0.109, \"Acousticness\": 0.0332, \"Liveness\": 0.552, \"Tempo\": 77.169, \"Duration (ms)\": 198973.0, \"Valence\": 0.357, \"Chord\": \"G\"}, {\"Index\": 1214, \"Highest Charting Position\": 103, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Por Primera Vez\", \"Streams\": 4478685, \"Artist\": \"Camilo, Evaluna Montaner\", \"Artist Followers\": 10580764.0, \"Song ID\": \"0gWbAFRcUyZKdfUxEOuOiD\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-09\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 70.0, \"Danceability\": 0.716, \"Energy\": 0.588, \"Loudness\": -3.952, \"Speechiness\": 0.116, \"Acousticness\": 0.152, \"Liveness\": 0.0847, \"Tempo\": 165.896, \"Duration (ms)\": 183547.0, \"Valence\": 0.707, \"Chord\": \"C#/Db\"}, {\"Index\": 1215, \"Highest Charting Position\": 32, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"@ MEH\", \"Streams\": 4420187, \"Artist\": \"Playboi Carti\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5rffvRUaCvkPnkwMVcQYgZ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 1.0, \"Danceability\": 0.877, \"Energy\": 0.492, \"Loudness\": -8.11, \"Speechiness\": 0.153, \"Acousticness\": 0.0136, \"Liveness\": 0.0678, \"Tempo\": 151.042, \"Duration (ms)\": 166799.0, \"Valence\": 0.4, \"Chord\": \"B\"}, {\"Index\": 1216, \"Highest Charting Position\": 109, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Broke In A Minute\", \"Streams\": 4402281, \"Artist\": \"Tory Lanez\", \"Artist Followers\": 3828418.0, \"Song ID\": \"4xqIYGwwZTEem9U8A42SPF\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-04-10\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-02-07--2020-02-14\", \"Popularity\": 75.0, \"Danceability\": 0.929, \"Energy\": 0.7, \"Loudness\": -5.595, \"Speechiness\": 0.0906, \"Acousticness\": 0.144, \"Liveness\": 0.349, \"Tempo\": 120.009, \"Duration (ms)\": 132024.0, \"Valence\": 0.802, \"Chord\": \"C\"}, {\"Index\": 1217, \"Highest Charting Position\": 139, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Fantasias - Remix\", \"Streams\": 4401019, \"Artist\": \"Rauw Alejandro, Anuel AA, Natti Natasha, Farruko, Lunay\", \"Artist Followers\": 6096559.0, \"Song ID\": \"0A37XY67wSdGqkGjtfW6aV\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 70.0, \"Danceability\": 0.816, \"Energy\": 0.72, \"Loudness\": -4.454, \"Speechiness\": 0.0684, \"Acousticness\": 0.206, \"Liveness\": 0.277, \"Tempo\": 94.004, \"Duration (ms)\": 267242.0, \"Valence\": 0.78, \"Chord\": \"C#/Db\"}, {\"Index\": 1218, \"Highest Charting Position\": 38, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"SUGAR\", \"Streams\": 4362442, \"Artist\": \"BROCKHAMPTON\", \"Artist Followers\": 1836564.0, \"Song ID\": \"6U0FIYXCQ3TGrk4tFpLrEA\", \"Genre\": \"['boy band', 'hip hop', 'rap']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 75.0, \"Danceability\": 0.453, \"Energy\": 0.538, \"Loudness\": -8.212, \"Speechiness\": 0.0638, \"Acousticness\": 0.449, \"Liveness\": 0.19, \"Tempo\": 122.973, \"Duration (ms)\": 204533.0, \"Valence\": 0.516, \"Chord\": \"C#/Db\"}, {\"Index\": 1219, \"Highest Charting Position\": 112, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"90-60-111\", \"Streams\": 5750861, \"Artist\": \"Shirin David\", \"Artist Followers\": 559215.0, \"Song ID\": \"3ZdDYeaZzeYnrP4crgXzPk\", \"Genre\": \"['frauenrap', 'german hip hop', 'german pop']\", \"Release Date\": \"2020-04-23\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 64.0, \"Danceability\": 0.8, \"Energy\": 0.628, \"Loudness\": -6.615, \"Speechiness\": 0.285, \"Acousticness\": 0.103, \"Liveness\": 0.391, \"Tempo\": 143.979, \"Duration (ms)\": 141387.0, \"Valence\": 0.745, \"Chord\": \"D\"}, {\"Index\": 1220, \"Highest Charting Position\": 115, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"YOSEMITE\", \"Streams\": 5686981, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"7lAK3oHbfEnvUQWosrMMpR\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2018-08-03\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 75.0, \"Danceability\": 0.785, \"Energy\": 0.554, \"Loudness\": -6.571, \"Speechiness\": 0.0409, \"Acousticness\": 0.283, \"Liveness\": 0.116, \"Tempo\": 128.047, \"Duration (ms)\": 150043.0, \"Valence\": 0.144, \"Chord\": \"C\"}, {\"Index\": 1221, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Houdini (feat. Swarmz & Tion Wayne)\", \"Streams\": 4914429, \"Artist\": \"KSI\", \"Artist Followers\": 2010879.0, \"Song ID\": \"3lay6f81Lhy0qp2Uvp4cNJ\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 58.0, \"Danceability\": 0.572, \"Energy\": 0.519, \"Loudness\": -8.054, \"Speechiness\": 0.243, \"Acousticness\": 0.000415, \"Liveness\": 0.129, \"Tempo\": 100.453, \"Duration (ms)\": 169355.0, \"Valence\": 0.704, \"Chord\": \"A#/Bb\"}, {\"Index\": 1222, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Sasuke\", \"Streams\": 4701551, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"0ROE31C8Wu4neZoR9stM9e\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 56.0, \"Danceability\": 0.859, \"Energy\": 0.477, \"Loudness\": -6.116, \"Speechiness\": 0.428, \"Acousticness\": 0.00414, \"Liveness\": 0.0819, \"Tempo\": 145.979, \"Duration (ms)\": 251336.0, \"Valence\": 0.153, \"Chord\": \"C#/Db\"}, {\"Index\": 1223, \"Highest Charting Position\": 47, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Me Gusta\", \"Streams\": 4440661, \"Artist\": \"Shakira, Anuel AA\", \"Artist Followers\": 22136717.0, \"Song ID\": \"5Xhqh4lwJPtMUTsdBztN1a\", \"Genre\": \"['colombian pop', 'dance pop', 'latin', 'latin pop', 'pop']\", \"Release Date\": \"2020-01-13\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 72.0, \"Danceability\": 0.775, \"Energy\": 0.696, \"Loudness\": -5.184, \"Speechiness\": 0.0681, \"Acousticness\": 0.0559, \"Liveness\": 0.157, \"Tempo\": 92.007, \"Duration (ms)\": 190570.0, \"Valence\": 0.775, \"Chord\": \"C#/Db\"}, {\"Index\": 1224, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"If You\\u2019re Too Shy (Let Me Know) - Edit\", \"Streams\": 4429092, \"Artist\": \"The 1975\", \"Artist Followers\": 5044278.0, \"Song ID\": \"3iEqGBZ2wcpVzhiAcwXVC6\", \"Genre\": \"['modern alternative rock', 'modern rock', 'pop', 'rock']\", \"Release Date\": \"2020-04-23\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 59.0, \"Danceability\": 0.651, \"Energy\": 0.806, \"Loudness\": -4.842, \"Speechiness\": 0.0311, \"Acousticness\": 0.00399, \"Liveness\": 0.0927, \"Tempo\": 125.641, \"Duration (ms)\": 239877.0, \"Valence\": 0.386, \"Chord\": \"D\"}, {\"Index\": 1225, \"Highest Charting Position\": 80, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Alone, Pt. II\", \"Streams\": 4395061, \"Artist\": \"Alan Walker, Ava Max\", \"Artist Followers\": 29679430.0, \"Song ID\": \"0bMbDctzMmTyK2j74j3nF3\", \"Genre\": \"['electro house']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.67, \"Energy\": 0.668, \"Loudness\": -4.306, \"Speechiness\": 0.0422, \"Acousticness\": 0.536, \"Liveness\": 0.133, \"Tempo\": 88.033, \"Duration (ms)\": 179053.0, \"Valence\": 0.608, \"Chord\": \"D#/Eb\"}, {\"Index\": 1226, \"Highest Charting Position\": 97, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Tutu\", \"Streams\": 4393037, \"Artist\": \"Camilo, Pedro Cap\\u00f3\", \"Artist Followers\": 10580764.0, \"Song ID\": \"1nocRtwyNPVtGcIJqfgdzZ\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2019-08-09\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.731, \"Energy\": 0.832, \"Loudness\": -2.592, \"Speechiness\": 0.0503, \"Acousticness\": 0.273, \"Liveness\": 0.0665, \"Tempo\": 146.013, \"Duration (ms)\": 178613.0, \"Valence\": 0.94, \"Chord\": \"A\"}, {\"Index\": 1227, \"Highest Charting Position\": 85, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Hate Me (with Juice WRLD)\", \"Streams\": 4367368, \"Artist\": \"Ellie Goulding\", \"Artist Followers\": 9747805.0, \"Song ID\": \"6kls8cSlUyHW2BUOkDJIZE\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'indietronica', 'metropopolis', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2019-06-26\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.657, \"Energy\": 0.768, \"Loudness\": -4.628, \"Speechiness\": 0.0507, \"Acousticness\": 0.108, \"Liveness\": 0.144, \"Tempo\": 75.025, \"Duration (ms)\": 186223.0, \"Valence\": 0.759, \"Chord\": \"G#/Ab\"}, {\"Index\": 1228, \"Highest Charting Position\": 109, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Still Be Friends (feat. Tory Lanez & Tyga)\", \"Streams\": 4299422, \"Artist\": \"G-Eazy\", \"Artist Followers\": 4894656.0, \"Song ID\": \"0JjM9bKm4wrwohMslcm892\", \"Genre\": \"['hip hop', 'indie pop rap', 'oakland hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 76.0, \"Danceability\": 0.803, \"Energy\": 0.759, \"Loudness\": -4.692, \"Speechiness\": 0.0494, \"Acousticness\": 0.00509, \"Liveness\": 0.0921, \"Tempo\": 104.0, \"Duration (ms)\": 213308.0, \"Valence\": 0.284, \"Chord\": \"G\"}, {\"Index\": 1229, \"Highest Charting Position\": 74, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Blanco\", \"Streams\": 4214147, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"2rc7BkzO8qepMFAxHtOrXc\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.87, \"Energy\": 0.706, \"Loudness\": -5.395, \"Speechiness\": 0.126, \"Acousticness\": 0.0253, \"Liveness\": 0.0872, \"Tempo\": 100.013, \"Duration (ms)\": 145800.0, \"Valence\": 0.593, \"Chord\": \"A\"}, {\"Index\": 1230, \"Highest Charting Position\": 78, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"PICK UP (feat. Quavo)\", \"Streams\": 7065060, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"5gNOINI5dXZVom2b36LMOd\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 65.0, \"Danceability\": 0.915, \"Energy\": 0.612, \"Loudness\": -4.535, \"Speechiness\": 0.407, \"Acousticness\": 0.0944, \"Liveness\": 0.115, \"Tempo\": 129.93, \"Duration (ms)\": 118547.0, \"Valence\": 0.758, \"Chord\": \"C#/Db\"}, {\"Index\": 1231, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"JUMP (feat. YoungBoy Never Broke Again)\", \"Streams\": 6033348, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"0oT9ElXYSxvnOOagP9efDq\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 62.0, \"Danceability\": 0.896, \"Energy\": 0.72, \"Loudness\": -6.262, \"Speechiness\": 0.355, \"Acousticness\": 0.169, \"Liveness\": 0.252, \"Tempo\": 140.1, \"Duration (ms)\": 212093.0, \"Valence\": 0.966, \"Chord\": \"C\"}, {\"Index\": 1232, \"Highest Charting Position\": 156, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"LIGHTSKIN SH*T (feat. Future & jetsonmade)\", \"Streams\": 4861875, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"16oi4OiKmkO51l60F5R9kR\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 56.0, \"Danceability\": 0.932, \"Energy\": 0.578, \"Loudness\": -4.478, \"Speechiness\": 0.366, \"Acousticness\": 0.115, \"Liveness\": 0.115, \"Tempo\": 129.991, \"Duration (ms)\": 111173.0, \"Valence\": 0.623, \"Chord\": \"A\"}, {\"Index\": 1233, \"Highest Charting Position\": 16, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"That Way - Bonus Track\", \"Streams\": 4825741, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2ajzBr7vwHTEBeqDzcsNRC\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.712, \"Energy\": 0.598, \"Loudness\": -5.368, \"Speechiness\": 0.0388, \"Acousticness\": 0.0546, \"Liveness\": 0.154, \"Tempo\": 130.007, \"Duration (ms)\": 212354.0, \"Valence\": 0.504, \"Chord\": \"G\"}, {\"Index\": 1234, \"Highest Charting Position\": 162, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"No Me Ame\", \"Streams\": 4822090, \"Artist\": \"Rvssian, Anuel AA, Juice WRLD\", \"Artist Followers\": 1397067.0, \"Song ID\": \"2AuWgceaQyfMoI3EGavwGb\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 64.0, \"Danceability\": 0.68, \"Energy\": 0.766, \"Loudness\": -4.799, \"Speechiness\": 0.0923, \"Acousticness\": 0.0411, \"Liveness\": 0.116, \"Tempo\": 160.095, \"Duration (ms)\": 180000.0, \"Valence\": 0.28, \"Chord\": \"B\"}, {\"Index\": 1235, \"Highest Charting Position\": 80, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"I'll Wait\", \"Streams\": 4674532, \"Artist\": \"Kygo, Sasha Alex Sloan\", \"Artist Followers\": 7593792.0, \"Song ID\": \"6Q3K9gVUZRMZqZKrXovbM2\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 70.0, \"Danceability\": 0.611, \"Energy\": 0.651, \"Loudness\": -6.973, \"Speechiness\": 0.0589, \"Acousticness\": 0.144, \"Liveness\": 0.105, \"Tempo\": 122.983, \"Duration (ms)\": 215361.0, \"Valence\": 0.351, \"Chord\": \"C#/Db\"}, {\"Index\": 1236, \"Highest Charting Position\": 63, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Oprah\\u2019s Bank Account (Lil Yachty & DaBaby feat. Drake)\", \"Streams\": 4618744, \"Artist\": \"Lil Yachty\", \"Artist Followers\": 7358720.0, \"Song ID\": \"7wsmIIm0xWmtP7TmACXkJn\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap', 'underground hip hop', 'viral rap']\", \"Release Date\": \"2020-03-09\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 69.0, \"Danceability\": 0.836, \"Energy\": 0.617, \"Loudness\": -4.363, \"Speechiness\": 0.0534, \"Acousticness\": 0.17, \"Liveness\": 0.319, \"Tempo\": 138.066, \"Duration (ms)\": 206702.0, \"Valence\": 0.866, \"Chord\": \"C\"}, {\"Index\": 1237, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"BLAME IT ON BABY\", \"Streams\": 4616034, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"0jWm0VyD8p3MrSInczpows\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 57.0, \"Danceability\": 0.875, \"Energy\": 0.687, \"Loudness\": -5.734, \"Speechiness\": 0.387, \"Acousticness\": 0.236, \"Liveness\": 0.141, \"Tempo\": 109.791, \"Duration (ms)\": 125907.0, \"Valence\": 0.864, \"Chord\": \"A\"}, {\"Index\": 1238, \"Highest Charting Position\": 128, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Follow\", \"Streams\": 4593449, \"Artist\": \"KAROL G, Anuel AA\", \"Artist Followers\": 17792779.0, \"Song ID\": \"2w1rq80FIrbxeJy9WYURxw\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-04-01\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 63.0, \"Danceability\": 0.735, \"Energy\": 0.787, \"Loudness\": -4.375, \"Speechiness\": 0.16, \"Acousticness\": 0.667, \"Liveness\": 0.0721, \"Tempo\": 168.997, \"Duration (ms)\": 203093.0, \"Valence\": 0.455, \"Chord\": \"G\"}, {\"Index\": 1239, \"Highest Charting Position\": 156, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"3 Nights\", \"Streams\": 4411998, \"Artist\": \"Dominic Fike\", \"Artist Followers\": 554042.0, \"Song ID\": \"1tNJrcVe6gwLEiZCtprs1u\", \"Genre\": \"['alternative pop rock', 'pop']\", \"Release Date\": \"2018-10-16\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.815, \"Energy\": 0.518, \"Loudness\": -6.594, \"Speechiness\": 0.0897, \"Acousticness\": 0.223, \"Liveness\": 0.104, \"Tempo\": 151.891, \"Duration (ms)\": 177667.0, \"Valence\": 0.877, \"Chord\": \"G\"}, {\"Index\": 1240, \"Highest Charting Position\": 163, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"The Take (feat. Chris Brown)\", \"Streams\": 4394195, \"Artist\": \"Tory Lanez\", \"Artist Followers\": 3828418.0, \"Song ID\": \"0Odu228D0yGcFySGuxU4rY\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 73.0, \"Danceability\": 0.464, \"Energy\": 0.547, \"Loudness\": -8.137, \"Speechiness\": 0.339, \"Acousticness\": 0.0511, \"Liveness\": 0.155, \"Tempo\": 67.003, \"Duration (ms)\": 221492.0, \"Valence\": 0.423, \"Chord\": \"G\"}, {\"Index\": 1241, \"Highest Charting Position\": 101, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Stupid Again\", \"Streams\": 5938996, \"Artist\": \"Tory Lanez\", \"Artist Followers\": 3828418.0, \"Song ID\": \"1fPnUpoXCpD2NDI4vPVeLw\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-04-10\", \"Weeks Charted\": \"2020-04-10--2020-04-17\", \"Popularity\": 66.0, \"Danceability\": 0.775, \"Energy\": 0.823, \"Loudness\": -4.941, \"Speechiness\": 0.0635, \"Acousticness\": 0.0881, \"Liveness\": 0.309, \"Tempo\": 120.059, \"Duration (ms)\": 174848.0, \"Valence\": 0.65, \"Chord\": \"F\"}, {\"Index\": 1242, \"Highest Charting Position\": 127, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Shotz Fired\", \"Streams\": 5291167, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"0dy5NFDnx5fuZvE8ZXEX35\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-04-10--2020-04-17\", \"Popularity\": 59.0, \"Danceability\": 0.839, \"Energy\": 0.594, \"Loudness\": -9.087, \"Speechiness\": 0.139, \"Acousticness\": 0.249, \"Liveness\": 0.165, \"Tempo\": 76.007, \"Duration (ms)\": 179844.0, \"Valence\": 0.58, \"Chord\": \"C\"}, {\"Index\": 1243, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"BaeBae\", \"Streams\": 5290730, \"Artist\": \"Samra\", \"Artist Followers\": 1045091.0, \"Song ID\": \"1yYBOIXO2H9LDqEPui42GM\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-04-10--2020-04-17\", \"Popularity\": 57.0, \"Danceability\": 0.628, \"Energy\": 0.712, \"Loudness\": -4.864, \"Speechiness\": 0.156, \"Acousticness\": 0.282, \"Liveness\": 0.156, \"Tempo\": 86.627, \"Duration (ms)\": 167827.0, \"Valence\": 0.45, \"Chord\": \"E\"}, {\"Index\": 1244, \"Highest Charting Position\": 30, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"To Die For\", \"Streams\": 4527835, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"2ZTYlnhhV1UAReg7wIGolx\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 70.0, \"Danceability\": 0.483, \"Energy\": 0.361, \"Loudness\": -7.889, \"Speechiness\": 0.0738, \"Acousticness\": 0.832, \"Liveness\": 0.098, \"Tempo\": 171.649, \"Duration (ms)\": 193795.0, \"Valence\": 0.307, \"Chord\": \"C\"}, {\"Index\": 1245, \"Highest Charting Position\": 86, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"WANNABE\", \"Streams\": 4383521, \"Artist\": \"ITZY\", \"Artist Followers\": 2384076.0, \"Song ID\": \"6tCssnvTUREcperDOUTqvA\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2020-03-09\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 75.0, \"Danceability\": 0.809, \"Energy\": 0.911, \"Loudness\": -4.41, \"Speechiness\": 0.0617, \"Acousticness\": 0.00795, \"Liveness\": 0.181, \"Tempo\": 122.035, \"Duration (ms)\": 191242.0, \"Valence\": 0.64, \"Chord\": \"F#/Gb\"}, {\"Index\": 1246, \"Highest Charting Position\": 152, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Takeaway\", \"Streams\": 4359727, \"Artist\": \"The Chainsmokers, ILLENIUM, Lennon Stella\", \"Artist Followers\": 18195884.0, \"Song ID\": \"3g0mEQx3NTanacLseoP0Gw\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.528, \"Energy\": 0.511, \"Loudness\": -8.144, \"Speechiness\": 0.0324, \"Acousticness\": 0.126, \"Liveness\": 0.101, \"Tempo\": 100.1, \"Duration (ms)\": 209880.0, \"Valence\": 0.351, \"Chord\": \"D#/Eb\"}, {\"Index\": 1247, \"Highest Charting Position\": 190, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Heart On Ice\", \"Streams\": 4324610, \"Artist\": \"Rod Wave\", \"Artist Followers\": 2203386.0, \"Song ID\": \"6fWa5CRgy0z30OeGZyMBvD\", \"Genre\": \"['florida rap']\", \"Release Date\": \"2019-06-14\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 70.0, \"Danceability\": 0.733, \"Energy\": 0.389, \"Loudness\": -8.468, \"Speechiness\": 0.0738, \"Acousticness\": 0.0513, \"Liveness\": 0.141, \"Tempo\": 157.878, \"Duration (ms)\": 159670.0, \"Valence\": 0.244, \"Chord\": \"A#/Bb\"}, {\"Index\": 1248, \"Highest Charting Position\": 194, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"La Cama - Remix\", \"Streams\": 4261965, \"Artist\": \"Lunay, Myke Towers, Ozuna, Chencho Corleone, Rauw Alejandro\", \"Artist Followers\": 4963516.0, \"Song ID\": \"2tGENA8xef0wABdHvyXwv9\", \"Genre\": \"['latin', 'latin pop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 69.0, \"Danceability\": 0.737, \"Energy\": 0.832, \"Loudness\": -2.622, \"Speechiness\": 0.0798, \"Acousticness\": 0.12, \"Liveness\": 0.255, \"Tempo\": 173.986, \"Duration (ms)\": 330240.0, \"Valence\": 0.865, \"Chord\": \"D\"}, {\"Index\": 1249, \"Highest Charting Position\": 105, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Go Stupid (feat. NLE Choppa & Mike WiLL Made-It)\", \"Streams\": 4244510, \"Artist\": \"Polo G, Stunna 4 Vegas\", \"Artist Followers\": 4849204.0, \"Song ID\": \"0L8OsjxbagaGkJI0PezdRg\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 41.0, \"Danceability\": 0.922, \"Energy\": 0.813, \"Loudness\": -3.268, \"Speechiness\": 0.251, \"Acousticness\": 0.0198, \"Liveness\": 0.0539, \"Tempo\": 141.087, \"Duration (ms)\": 165726.0, \"Valence\": 0.724, \"Chord\": \"C#/Db\"}, {\"Index\": 1250, \"Highest Charting Position\": 192, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Cradles\", \"Streams\": 4218201, \"Artist\": \"Sub Urban\", \"Artist Followers\": 908351.0, \"Song ID\": \"1y4jsQt7MjnZhiD1L6qFBC\", \"Genre\": \"['modern indie pop']\", \"Release Date\": \"2019-01-04\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 73.0, \"Danceability\": 0.534, \"Energy\": 0.589, \"Loudness\": -1.865, \"Speechiness\": 0.325, \"Acousticness\": 0.256, \"Liveness\": 0.176, \"Tempo\": 78.616, \"Duration (ms)\": 209829.0, \"Valence\": 0.632, \"Chord\": \"C#/Db\"}, {\"Index\": 1251, \"Highest Charting Position\": 117, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Good as Hell (feat. Ariana Grande)\", \"Streams\": 4176083, \"Artist\": \"Lizzo\", \"Artist Followers\": 3991674.0, \"Song ID\": \"07Oz5StQ7GRoygNLaXs2pd\", \"Genre\": \"['dance pop', 'escape room', 'minnesota hip hop', 'pop', 'pop rap', 'post-teen pop', 'trap queen']\", \"Release Date\": \"2016\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 71.0, \"Danceability\": 0.668, \"Energy\": 0.892, \"Loudness\": -3.001, \"Speechiness\": 0.0645, \"Acousticness\": 0.298, \"Liveness\": 0.735, \"Tempo\": 95.927, \"Duration (ms)\": 159011.0, \"Valence\": 0.478, \"Chord\": \"F\"}, {\"Index\": 1252, \"Highest Charting Position\": 15, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Forever (feat. Post Malone & Clever)\", \"Streams\": 6517807, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2ZlCGeK30BLRNSPC832pNZ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 68.0, \"Danceability\": 0.825, \"Energy\": 0.483, \"Loudness\": -5.746, \"Speechiness\": 0.08, \"Acousticness\": 0.538, \"Liveness\": 0.204, \"Tempo\": 139.98, \"Duration (ms)\": 219933.0, \"Valence\": 0.892, \"Chord\": \"G#/Ab\"}, {\"Index\": 1253, \"Highest Charting Position\": 46, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"I Love Me\", \"Streams\": 5449099, \"Artist\": \"Demi Lovato\", \"Artist Followers\": 20338833.0, \"Song ID\": \"2IHLaN6wwYKQ3S24NsQqpA\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.664, \"Energy\": 0.561, \"Loudness\": -7.031, \"Speechiness\": 0.0495, \"Acousticness\": 0.00261, \"Liveness\": 0.0764, \"Tempo\": 150.093, \"Duration (ms)\": 203672.0, \"Valence\": 0.713, \"Chord\": \"F#/Gb\"}, {\"Index\": 1254, \"Highest Charting Position\": 103, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Old Me\", \"Streams\": 4724056, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"58qO4dGa5SgNdtvqvpewyz\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 67.0, \"Danceability\": 0.722, \"Energy\": 0.62, \"Loudness\": -3.639, \"Speechiness\": 0.0483, \"Acousticness\": 0.313, \"Liveness\": 0.26, \"Tempo\": 127.978, \"Duration (ms)\": 186786.0, \"Valence\": 0.474, \"Chord\": \"C\"}, {\"Index\": 1255, \"Highest Charting Position\": 29, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Pero Ya No\", \"Streams\": 4666658, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"75pQqzwgCjUOSSy5CpmAjy\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 72.0, \"Danceability\": 0.882, \"Energy\": 0.612, \"Loudness\": -6.103, \"Speechiness\": 0.118, \"Acousticness\": 0.0475, \"Liveness\": 0.182, \"Tempo\": 147.982, \"Duration (ms)\": 160638.0, \"Valence\": 0.742, \"Chord\": \"E\"}, {\"Index\": 1256, \"Highest Charting Position\": 24, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Hardest To Love\", \"Streams\": 4553544, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"6kWxIqQDsKFYCJGbU4AjCX\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.467, \"Energy\": 0.608, \"Loudness\": -7.847, \"Speechiness\": 0.0707, \"Acousticness\": 0.0909, \"Liveness\": 0.125, \"Tempo\": 80.957, \"Duration (ms)\": 211400.0, \"Valence\": 0.108, \"Chord\": \"A#/Bb\"}, {\"Index\": 1257, \"Highest Charting Position\": 191, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"BRABA\", \"Streams\": 4452819, \"Artist\": \"Lu\\u00edsa Sonza\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6DEEuFNv0K3aJtFYZag8gv\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-11\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 0.0, \"Danceability\": 0.812, \"Energy\": 0.689, \"Loudness\": -5.113, \"Speechiness\": 0.0619, \"Acousticness\": 0.181, \"Liveness\": 0.0784, \"Tempo\": 144.011, \"Duration (ms)\": 129782.0, \"Valence\": 0.663, \"Chord\": \"C\"}, {\"Index\": 1258, \"Highest Charting Position\": 77, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Woah\", \"Streams\": 4425610, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"598yNsG1JFrGd4n2kMoz7F\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 69.0, \"Danceability\": 0.882, \"Energy\": 0.602, \"Loudness\": -5.554, \"Speechiness\": 0.245, \"Acousticness\": 0.0177, \"Liveness\": 0.178, \"Tempo\": 142.959, \"Duration (ms)\": 183011.0, \"Valence\": 0.43, \"Chord\": \"B\"}, {\"Index\": 1259, \"Highest Charting Position\": 69, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Pretty Please\", \"Streams\": 4305034, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"6DXZiYUbrYgrVIhfX3U9Z2\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 67.0, \"Danceability\": 0.906, \"Energy\": 0.474, \"Loudness\": -6.124, \"Speechiness\": 0.194, \"Acousticness\": 0.0311, \"Liveness\": 0.286, \"Tempo\": 106.976, \"Duration (ms)\": 194607.0, \"Valence\": 0.656, \"Chord\": \"C#/Db\"}, {\"Index\": 1260, \"Highest Charting Position\": 170, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"I.F.L.Y.\", \"Streams\": 4284951, \"Artist\": \"Bazzi\", \"Artist Followers\": 4421378.0, \"Song ID\": \"4a6q8CR2hzLk2plDkSxkfD\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-08-09\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-13--2020-03-20\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 76.0, \"Danceability\": 0.812, \"Energy\": 0.519, \"Loudness\": -4.823, \"Speechiness\": 0.0385, \"Acousticness\": 0.379, \"Liveness\": 0.13, \"Tempo\": 104.954, \"Duration (ms)\": 165714.0, \"Valence\": 0.554, \"Chord\": \"D\"}, {\"Index\": 1261, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Cool\", \"Streams\": 8136247, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"4Ulqu89XempybuL8ApUeqL\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.469, \"Energy\": 0.785, \"Loudness\": -4.015, \"Speechiness\": 0.0664, \"Acousticness\": 0.133, \"Liveness\": 0.0931, \"Tempo\": 89.719, \"Duration (ms)\": 209583.0, \"Valence\": 0.79, \"Chord\": \"F\"}, {\"Index\": 1262, \"Highest Charting Position\": 71, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Future Nostalgia\", \"Streams\": 8091754, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3iYNJX4FTRGlfMQySjlGNr\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.875, \"Energy\": 0.813, \"Loudness\": -4.502, \"Speechiness\": 0.0579, \"Acousticness\": 0.00618, \"Liveness\": 0.321, \"Tempo\": 114.993, \"Duration (ms)\": 184882.0, \"Valence\": 0.859, \"Chord\": \"G\"}, {\"Index\": 1263, \"Highest Charting Position\": 92, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Good In Bed\", \"Streams\": 6802068, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3pyodt4pb554dMz8fCv7oi\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 64.0, \"Danceability\": 0.68, \"Energy\": 0.701, \"Loudness\": -5.001, \"Speechiness\": 0.0917, \"Acousticness\": 0.138, \"Liveness\": 0.168, \"Tempo\": 94.06, \"Duration (ms)\": 218754.0, \"Valence\": 0.649, \"Chord\": \"F\"}, {\"Index\": 1264, \"Highest Charting Position\": 27, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Scared To Live\", \"Streams\": 6566099, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"4BGZF4oLbTL0pWm7C18pbv\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 66.0, \"Danceability\": 0.504, \"Energy\": 0.498, \"Loudness\": -8.24, \"Speechiness\": 0.0499, \"Acousticness\": 0.131, \"Liveness\": 0.0929, \"Tempo\": 87.221, \"Duration (ms)\": 191307.0, \"Valence\": 0.196, \"Chord\": \"C\"}, {\"Index\": 1265, \"Highest Charting Position\": 21, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Alone Again\", \"Streams\": 6055294, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"6b5P51m8xx2XA6U7sdNZ5E\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 66.0, \"Danceability\": 0.218, \"Energy\": 0.652, \"Loudness\": -7.953, \"Speechiness\": 0.0641, \"Acousticness\": 0.033, \"Liveness\": 0.172, \"Tempo\": 65.375, \"Duration (ms)\": 250053.0, \"Valence\": 0.0599, \"Chord\": \"E\"}, {\"Index\": 1266, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Boys Will Be Boys\", \"Streams\": 6015914, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"4szI7zRh7kLApCSqiB6R7b\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 63.0, \"Danceability\": 0.768, \"Energy\": 0.486, \"Loudness\": -5.954, \"Speechiness\": 0.0353, \"Acousticness\": 0.408, \"Liveness\": 0.098, \"Tempo\": 125.021, \"Duration (ms)\": 166266.0, \"Valence\": 0.519, \"Chord\": \"D#/Eb\"}, {\"Index\": 1267, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Auto Blu\", \"Streams\": 5995116, \"Artist\": \"Shiva, Eiffel 65\", \"Artist Followers\": 561372.0, \"Song ID\": \"5swpvba5YLqVDy1nbzUdog\", \"Genre\": \"['italian hip hop', 'trap italiana']\", \"Release Date\": \"2020-03-26\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 56.0, \"Danceability\": 0.82, \"Energy\": 0.783, \"Loudness\": -6.146, \"Speechiness\": 0.0621, \"Acousticness\": 0.0158, \"Liveness\": 0.0938, \"Tempo\": 130.015, \"Duration (ms)\": 166087.0, \"Valence\": 0.653, \"Chord\": \"F\"}, {\"Index\": 1268, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Du bist mein\", \"Streams\": 5878493, \"Artist\": \"Zuna, Loredana, SRNO\", \"Artist Followers\": 900975.0, \"Song ID\": \"719aY5gAzJbx2PHjyalZQu\", \"Genre\": \"['albanian hip hop', 'german hip hop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 54.0, \"Danceability\": 0.761, \"Energy\": 0.556, \"Loudness\": -6.943, \"Speechiness\": 0.364, \"Acousticness\": 0.138, \"Liveness\": 0.0976, \"Tempo\": 187.81, \"Duration (ms)\": 160357.0, \"Valence\": 0.521, \"Chord\": \"C#/Db\"}, {\"Index\": 1269, \"Highest Charting Position\": 28, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Too Late\", \"Streams\": 5867746, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"2K9Ovn1o2bTGqbsABGC6m3\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.638, \"Energy\": 0.863, \"Loudness\": -5.221, \"Speechiness\": 0.132, \"Acousticness\": 0.052, \"Liveness\": 0.685, \"Tempo\": 120.077, \"Duration (ms)\": 239973.0, \"Valence\": 0.226, \"Chord\": \"E\"}, {\"Index\": 1270, \"Highest Charting Position\": 136, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Wildflower\", \"Streams\": 5791343, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"6qlcjGJPTZEwR8nf2nSe9C\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.644, \"Energy\": 0.768, \"Loudness\": -4.316, \"Speechiness\": 0.0455, \"Acousticness\": 0.174, \"Liveness\": 0.469, \"Tempo\": 108.992, \"Duration (ms)\": 220536.0, \"Valence\": 0.598, \"Chord\": \"F#/Gb\"}, {\"Index\": 1271, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Faith\", \"Streams\": 5730081, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"3orEOtd8CPL8GFlpRpKuoE\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.375, \"Energy\": 0.605, \"Loudness\": -7.268, \"Speechiness\": 0.0729, \"Acousticness\": 0.612, \"Liveness\": 0.147, \"Tempo\": 175.946, \"Duration (ms)\": 283227.0, \"Valence\": 0.128, \"Chord\": \"C\"}, {\"Index\": 1272, \"Highest Charting Position\": 35, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Snowchild\", \"Streams\": 5423997, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"3WlbeuhfRSqU7ylK2Ui5U7\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 66.0, \"Danceability\": 0.55, \"Energy\": 0.611, \"Loudness\": -7.475, \"Speechiness\": 0.137, \"Acousticness\": 0.162, \"Liveness\": 0.121, \"Tempo\": 148.062, \"Duration (ms)\": 247187.0, \"Valence\": 0.243, \"Chord\": \"C\"}, {\"Index\": 1273, \"Highest Charting Position\": 37, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Escape From LA\", \"Streams\": 5307288, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"1sOW4PuG5X3Ie3EXUhAopJ\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.404, \"Energy\": 0.524, \"Loudness\": -8.996, \"Speechiness\": 0.0593, \"Acousticness\": 0.0456, \"Liveness\": 0.199, \"Tempo\": 145.74, \"Duration (ms)\": 355960.0, \"Valence\": 0.168, \"Chord\": \"F\"}, {\"Index\": 1274, \"Highest Charting Position\": 161, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Allein sein\", \"Streams\": 5119993, \"Artist\": \"Ufo361\", \"Artist Followers\": 1700759.0, \"Song ID\": \"2TrhpvxwuF6hrboTdRXwnS\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 54.0, \"Danceability\": 0.774, \"Energy\": 0.588, \"Loudness\": -8.529, \"Speechiness\": 0.225, \"Acousticness\": 0.0386, \"Liveness\": 0.258, \"Tempo\": 75.978, \"Duration (ms)\": 147353.0, \"Valence\": 0.392, \"Chord\": \"C#/Db\"}, {\"Index\": 1275, \"Highest Charting Position\": 44, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Bichiyal\", \"Streams\": 4946613, \"Artist\": \"Bad Bunny, Yaviah\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4j4w4CXm6BSr0s25wAWrrX\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 75.0, \"Danceability\": 0.737, \"Energy\": 0.766, \"Loudness\": -4.242, \"Speechiness\": 0.0458, \"Acousticness\": 0.31, \"Liveness\": 0.114, \"Tempo\": 93.956, \"Duration (ms)\": 196500.0, \"Valence\": 0.662, \"Chord\": \"A#/Bb\"}, {\"Index\": 1276, \"Highest Charting Position\": 85, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Medusa\", \"Streams\": 4901559, \"Artist\": \"Jhay Cortez, Anuel AA, J Balvin\", \"Artist Followers\": 2435159.0, \"Song ID\": \"3qM0vBxIe4VUbK0Z0smuVP\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-05\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 70.0, \"Danceability\": 0.886, \"Energy\": 0.604, \"Loudness\": -7.293, \"Speechiness\": 0.208, \"Acousticness\": 0.194, \"Liveness\": 0.107, \"Tempo\": 98.023, \"Duration (ms)\": 305333.0, \"Valence\": 0.383, \"Chord\": \"C\"}, {\"Index\": 1277, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Break Up Song\", \"Streams\": 4593343, \"Artist\": \"Little Mix\", \"Artist Followers\": 9398941.0, \"Song ID\": \"5HArmECc1y0lCHKVKDKXa4\", \"Genre\": \"['dance pop', 'girl group', 'pop', 'post-teen pop', 'talent show', 'uk pop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.631, \"Energy\": 0.75, \"Loudness\": -5.416, \"Speechiness\": 0.0394, \"Acousticness\": 0.00388, \"Liveness\": 0.286, \"Tempo\": 90.019, \"Duration (ms)\": 200293.0, \"Valence\": 0.593, \"Chord\": \"F\"}, {\"Index\": 1278, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Teeth\", \"Streams\": 4571612, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"26wLOs3ZuHJa2Ihhx6QIE6\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 78.0, \"Danceability\": 0.749, \"Energy\": 0.461, \"Loudness\": -2.961, \"Speechiness\": 0.0416, \"Acousticness\": 0.0516, \"Liveness\": 0.0738, \"Tempo\": 139.02, \"Duration (ms)\": 204887.0, \"Valence\": 0.42, \"Chord\": \"A#/Bb\"}, {\"Index\": 1279, \"Highest Charting Position\": 51, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Repeat After Me (Interlude)\", \"Streams\": 10058303, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"40U8d12pC5UHqmHwXjHjjl\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 63.0, \"Danceability\": 0.555, \"Energy\": 0.619, \"Loudness\": -7.918, \"Speechiness\": 0.0314, \"Acousticness\": 0.0323, \"Liveness\": 0.0917, \"Tempo\": 95.032, \"Duration (ms)\": 195813.0, \"Valence\": 0.141, \"Chord\": \"C\"}, {\"Index\": 1280, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Until I Bleed Out\", \"Streams\": 9132077, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"2BcnxwxBuar5wjCaLqm5N3\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 63.0, \"Danceability\": 0.245, \"Energy\": 0.394, \"Loudness\": -9.887, \"Speechiness\": 0.0374, \"Acousticness\": 0.423, \"Liveness\": 0.093, \"Tempo\": 115.233, \"Duration (ms)\": 190173.0, \"Valence\": 0.148, \"Chord\": \"C\"}, {\"Index\": 1281, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Rosa\", \"Streams\": 7564893, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"464uJVLmr0fDJGXOnciaDe\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 64.0, \"Danceability\": 0.651, \"Energy\": 0.561, \"Loudness\": -5.715, \"Speechiness\": 0.25, \"Acousticness\": 0.25, \"Liveness\": 0.435, \"Tempo\": 175.992, \"Duration (ms)\": 189827.0, \"Valence\": 0.369, \"Chord\": \"A\"}, {\"Index\": 1282, \"Highest Charting Position\": 88, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Gris\", \"Streams\": 7514854, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"1syf62zw48zu4FrPwMtDHk\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 65.0, \"Danceability\": 0.849, \"Energy\": 0.709, \"Loudness\": -4.717, \"Speechiness\": 0.0794, \"Acousticness\": 0.229, \"Liveness\": 0.329, \"Tempo\": 93.06, \"Duration (ms)\": 176627.0, \"Valence\": 0.916, \"Chord\": \"F#/Gb\"}, {\"Index\": 1283, \"Highest Charting Position\": 103, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Negro\", \"Streams\": 6651425, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"2hsA9YWuF3C9Gosi4dpjJN\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.795, \"Energy\": 0.911, \"Loudness\": -2.228, \"Speechiness\": 0.0875, \"Acousticness\": 0.0157, \"Liveness\": 0.131, \"Tempo\": 164.081, \"Duration (ms)\": 182093.0, \"Valence\": 0.8, \"Chord\": \"C\"}, {\"Index\": 1284, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Verde\", \"Streams\": 5745393, \"Artist\": \"J Balvin, Sky Rompiendo\", \"Artist Followers\": 29067437.0, \"Song ID\": \"3HTbI3yUJQw3fP0Po8qLcD\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 63.0, \"Danceability\": 0.828, \"Energy\": 0.738, \"Loudness\": -4.295, \"Speechiness\": 0.0516, \"Acousticness\": 0.0381, \"Liveness\": 0.0917, \"Tempo\": 94.995, \"Duration (ms)\": 142547.0, \"Valence\": 0.818, \"Chord\": \"G#/Ab\"}, {\"Index\": 1285, \"Highest Charting Position\": 15, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Baby Pluto\", \"Streams\": 5600261, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7hav1MHURQf5SAoPk0egqh\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 69.0, \"Danceability\": 0.772, \"Energy\": 0.634, \"Loudness\": -6.101, \"Speechiness\": 0.212, \"Acousticness\": 0.135, \"Liveness\": 0.432, \"Tempo\": 160.052, \"Duration (ms)\": 210261.0, \"Valence\": 0.671, \"Chord\": \"A#/Bb\"}, {\"Index\": 1286, \"Highest Charting Position\": 31, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Lo Mein\", \"Streams\": 5231134, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"6CUP2khYzdphXebxVTfPE3\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.855, \"Energy\": 0.676, \"Loudness\": -5.736, \"Speechiness\": 0.325, \"Acousticness\": 0.0888, \"Liveness\": 0.144, \"Tempo\": 133.082, \"Duration (ms)\": 195299.0, \"Valence\": 0.509, \"Chord\": \"C#/Db\"}, {\"Index\": 1287, \"Highest Charting Position\": 113, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"No Judgement\", \"Streams\": 5082563, \"Artist\": \"Niall Horan\", \"Artist Followers\": 7564659.0, \"Song ID\": \"5IUOU5xkzGHsRFOYNu3GSK\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 65.0, \"Danceability\": 0.723, \"Energy\": 0.726, \"Loudness\": -3.835, \"Speechiness\": 0.0472, \"Acousticness\": 0.0564, \"Liveness\": 0.057, \"Tempo\": 100.051, \"Duration (ms)\": 176283.0, \"Valence\": 0.962, \"Chord\": \"C#/Db\"}, {\"Index\": 1288, \"Highest Charting Position\": 57, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Futsal Shuffle 2020 - Bonus Track\", \"Streams\": 5068849, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2fOlBMkWR7lXJfqp5VTbDG\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 63.0, \"Danceability\": 0.879, \"Energy\": 0.448, \"Loudness\": -8.57, \"Speechiness\": 0.222, \"Acousticness\": 0.0346, \"Liveness\": 0.224, \"Tempo\": 136.985, \"Duration (ms)\": 198913.0, \"Valence\": 0.278, \"Chord\": \"G\"}, {\"Index\": 1289, \"Highest Charting Position\": 163, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Arco\\u00edris\", \"Streams\": 5044774, \"Artist\": \"J Balvin, Mr Eazi\", \"Artist Followers\": 29067437.0, \"Song ID\": \"5zzbORcD0GwLY0wQHP1Xs1\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 62.0, \"Danceability\": 0.731, \"Energy\": 0.787, \"Loudness\": -5.26, \"Speechiness\": 0.0721, \"Acousticness\": 0.0853, \"Liveness\": 0.316, \"Tempo\": 92.971, \"Duration (ms)\": 186693.0, \"Valence\": 0.393, \"Chord\": \"E\"}, {\"Index\": 1290, \"Highest Charting Position\": 65, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"TOES (feat. Lil Baby & Moneybagg Yo)\", \"Streams\": 4878903, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"2FvD20Z8aoWIePi7PoN8sG\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 73.0, \"Danceability\": 0.816, \"Energy\": 0.582, \"Loudness\": -4.141, \"Speechiness\": 0.341, \"Acousticness\": 0.0794, \"Liveness\": 0.0916, \"Tempo\": 160.004, \"Duration (ms)\": 136366.0, \"Valence\": 0.542, \"Chord\": \"G#/Ab\"}, {\"Index\": 1291, \"Highest Charting Position\": 42, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Feel Me\", \"Streams\": 4765672, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"6XXYdF6pJR1K3wKvuxmu7n\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 63.0, \"Danceability\": 0.71, \"Energy\": 0.808, \"Loudness\": -6.703, \"Speechiness\": 0.0433, \"Acousticness\": 0.44, \"Liveness\": 0.0734, \"Tempo\": 99.989, \"Duration (ms)\": 226003.0, \"Valence\": 0.392, \"Chord\": \"D\"}, {\"Index\": 1292, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"H <3 T E L\", \"Streams\": 4701388, \"Artist\": \"Dardan, Monet192\", \"Artist Followers\": 861082.0, \"Song ID\": \"3S1NOXjDr2A4xXXsWo8kLr\", \"Genre\": \"['albanian hip hop', 'german hip hop']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 34.0, \"Danceability\": 0.726, \"Energy\": 0.646, \"Loudness\": -6.9, \"Speechiness\": 0.0977, \"Acousticness\": 0.0495, \"Liveness\": 0.112, \"Tempo\": 134.999, \"Duration (ms)\": 163253.0, \"Valence\": 0.58, \"Chord\": \"C#/Db\"}, {\"Index\": 1293, \"Highest Charting Position\": 63, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"25/8\", \"Streams\": 4684378, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4NqQaovM14WR2hNPMFxgjb\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 71.0, \"Danceability\": 0.761, \"Energy\": 0.732, \"Loudness\": -5.469, \"Speechiness\": 0.0549, \"Acousticness\": 0.092, \"Liveness\": 0.0716, \"Tempo\": 151.982, \"Duration (ms)\": 243276.0, \"Valence\": 0.542, \"Chord\": \"E\"}, {\"Index\": 1294, \"Highest Charting Position\": 81, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Se Me Olvid\\u00f3\", \"Streams\": 4591194, \"Artist\": \"Christian Nodal\", \"Artist Followers\": 8123757.0, \"Song ID\": \"7paFC3FEu1WtPVP4Do6VZN\", \"Genre\": \"['mariachi', 'nuevo regional mexicano', 'ranchera', 'regional mexican']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 71.0, \"Danceability\": 0.65, \"Energy\": 0.558, \"Loudness\": -3.082, \"Speechiness\": 0.0309, \"Acousticness\": 0.368, \"Liveness\": 0.303, \"Tempo\": 141.82, \"Duration (ms)\": 159533.0, \"Valence\": 0.725, \"Chord\": \"C\"}, {\"Index\": 1295, \"Highest Charting Position\": 130, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"B.S. (feat. H.E.R.)\", \"Streams\": 4557817, \"Artist\": \"Jhen\\u00e9 Aiko\", \"Artist Followers\": 4720858.0, \"Song ID\": \"63wx9vdskaXbYxyDx4oJCZ\", \"Genre\": \"['alternative r&b', 'dance pop', 'pop', 'pop rap', 'r&b', 'urban contemporary']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 72.0, \"Danceability\": 0.617, \"Energy\": 0.525, \"Loudness\": -10.426, \"Speechiness\": 0.12, \"Acousticness\": 0.554, \"Liveness\": 0.135, \"Tempo\": 135.781, \"Duration (ms)\": 212867.0, \"Valence\": 0.377, \"Chord\": \"G#/Ab\"}, {\"Index\": 1296, \"Highest Charting Position\": 45, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Soli\\u00e1\", \"Streams\": 4516243, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"7sOfmPd18RWp3FoCzpa7Kw\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 72.0, \"Danceability\": 0.71, \"Energy\": 0.81, \"Loudness\": -5.507, \"Speechiness\": 0.0854, \"Acousticness\": 0.117, \"Liveness\": 0.154, \"Tempo\": 92.041, \"Duration (ms)\": 159282.0, \"Valence\": 0.184, \"Chord\": \"D\"}, {\"Index\": 1297, \"Highest Charting Position\": 55, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Est\\u00e1 Cabr\\u00f3n Ser Yo\", \"Streams\": 4438261, \"Artist\": \"Bad Bunny, Anuel AA\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4saHEjXw7O1NXJOzBkUKKG\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.81, \"Energy\": 0.854, \"Loudness\": -3.999, \"Speechiness\": 0.254, \"Acousticness\": 0.0732, \"Liveness\": 0.123, \"Tempo\": 154.083, \"Duration (ms)\": 227939.0, \"Valence\": 0.879, \"Chord\": \"A#/Bb\"}, {\"Index\": 1298, \"Highest Charting Position\": 61, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Bean (Kobe) [feat. Chief Keef]\", \"Streams\": 9039518, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"0IpnZchq8ek2A6pGEP2Qb1\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 67.0, \"Danceability\": 0.733, \"Energy\": 0.567, \"Loudness\": -6.718, \"Speechiness\": 0.319, \"Acousticness\": 0.0129, \"Liveness\": 0.382, \"Tempo\": 75.491, \"Duration (ms)\": 238816.0, \"Valence\": 0.319, \"Chord\": \"C\"}, {\"Index\": 1299, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Yessirskiii\", \"Streams\": 8374259, \"Artist\": \"Lil Uzi Vert, 21 Savage\", \"Artist Followers\": 11821805.0, \"Song ID\": \"59JWp4PjZ9TRM8cmtaDYB1\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 70.0, \"Danceability\": 0.895, \"Energy\": 0.739, \"Loudness\": -6.633, \"Speechiness\": 0.283, \"Acousticness\": 0.0183, \"Liveness\": 0.102, \"Tempo\": 140.007, \"Duration (ms)\": 219340.0, \"Valence\": 0.763, \"Chord\": \"G#/Ab\"}, {\"Index\": 1300, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Cardigan\", \"Streams\": 6586204, \"Artist\": \"Don Toliver\", \"Artist Followers\": 1606884.0, \"Song ID\": \"0Li1OuXXfi7950ilZUFGkF\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 70.0, \"Danceability\": 0.747, \"Energy\": 0.497, \"Loudness\": -6.542, \"Speechiness\": 0.0401, \"Acousticness\": 0.248, \"Liveness\": 0.138, \"Tempo\": 142.046, \"Duration (ms)\": 158709.0, \"Valence\": 0.0663, \"Chord\": \"E\"}, {\"Index\": 1301, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Silly Watch\", \"Streams\": 6442451, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"5egD7A5x9AHdVO2fMo3Wbo\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 65.0, \"Danceability\": 0.903, \"Energy\": 0.535, \"Loudness\": -6.238, \"Speechiness\": 0.286, \"Acousticness\": 0.0298, \"Liveness\": 0.0851, \"Tempo\": 130.117, \"Duration (ms)\": 195692.0, \"Valence\": 0.157, \"Chord\": \"G#/Ab\"}, {\"Index\": 1302, \"Highest Charting Position\": 70, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Hablamos Ma\\u00f1ana\", \"Streams\": 6105711, \"Artist\": \"Bad Bunny, Duki, Pablo Chill-E\", \"Artist Followers\": 36177712.0, \"Song ID\": \"1V8XneTrX6kKeoxYbk4x6h\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.683, \"Energy\": 0.677, \"Loudness\": -4.496, \"Speechiness\": 0.0469, \"Acousticness\": 0.0869, \"Liveness\": 0.0998, \"Tempo\": 156.019, \"Duration (ms)\": 240253.0, \"Valence\": 0.514, \"Chord\": \"C#/Db\"}, {\"Index\": 1303, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Lotus\", \"Streams\": 6017103, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4SnlSaLJJ7reJMCHM5YUuX\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 58.0, \"Danceability\": 0.802, \"Energy\": 0.748, \"Loudness\": -5.708, \"Speechiness\": 0.207, \"Acousticness\": 0.24, \"Liveness\": 0.165, \"Tempo\": 150.063, \"Duration (ms)\": 193861.0, \"Valence\": 0.516, \"Chord\": \"G#/Ab\"}, {\"Index\": 1304, \"Highest Charting Position\": 126, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Lettre \\u00e0 une femme\", \"Streams\": 5895243, \"Artist\": \"Ninho\", \"Artist Followers\": 4764552.0, \"Song ID\": \"10rwyGbKAWZ8JZbL7uHl28\", \"Genre\": \"['french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2020-03-07\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 54.0, \"Danceability\": 0.487, \"Energy\": 0.398, \"Loudness\": -9.901, \"Speechiness\": 0.0697, \"Acousticness\": 0.835, \"Liveness\": 0.12, \"Tempo\": 149.367, \"Duration (ms)\": 157766.0, \"Valence\": 0.905, \"Chord\": \"C#/Db\"}, {\"Index\": 1305, \"Highest Charting Position\": 57, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Que Malo\", \"Streams\": 5544180, \"Artist\": \"Bad Bunny, \\u00d1engo Flow\", \"Artist Followers\": 36177712.0, \"Song ID\": \"53v2u51nq3CxiKUNphRzP1\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.802, \"Energy\": 0.787, \"Loudness\": -6.181, \"Speechiness\": 0.0599, \"Acousticness\": 0.0832, \"Liveness\": 0.153, \"Tempo\": 94.026, \"Duration (ms)\": 167975.0, \"Valence\": 0.446, \"Chord\": \"G\"}, {\"Index\": 1306, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Leaders (feat. NAV)\", \"Streams\": 5496780, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4D7NrSeqkTarBrJ80b2sBc\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 60.0, \"Danceability\": 0.95, \"Energy\": 0.654, \"Loudness\": -5.895, \"Speechiness\": 0.307, \"Acousticness\": 0.0744, \"Liveness\": 0.138, \"Tempo\": 132.936, \"Duration (ms)\": 194844.0, \"Valence\": 0.886, \"Chord\": \"C\"}, {\"Index\": 1307, \"Highest Charting Position\": 149, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Strawberry Peels (feat. Young Thug & Gunna)\", \"Streams\": 5468083, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4lAQfuREAHG8IC0PiiigBt\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 59.0, \"Danceability\": 0.862, \"Energy\": 0.65, \"Loudness\": -6.978, \"Speechiness\": 0.355, \"Acousticness\": 0.0207, \"Liveness\": 0.568, \"Tempo\": 131.194, \"Duration (ms)\": 115350.0, \"Valence\": 0.658, \"Chord\": \"A#/Bb\"}, {\"Index\": 1308, \"Highest Charting Position\": 60, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"La Zona\", \"Streams\": 5440382, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5kqNIqFjijuzvVLhuY9B8j\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.762, \"Energy\": 0.801, \"Loudness\": -3.661, \"Speechiness\": 0.0409, \"Acousticness\": 0.2, \"Liveness\": 0.254, \"Tempo\": 93.992, \"Duration (ms)\": 136893.0, \"Valence\": 0.81, \"Chord\": \"C#/Db\"}, {\"Index\": 1309, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Wassup (feat. Future)\", \"Streams\": 5415044, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"19Ec2gbNtQTE44IizcPjtD\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 57.0, \"Danceability\": 0.762, \"Energy\": 0.622, \"Loudness\": -6.293, \"Speechiness\": 0.223, \"Acousticness\": 0.352, \"Liveness\": 0.145, \"Tempo\": 130.019, \"Duration (ms)\": 193314.0, \"Valence\": 0.626, \"Chord\": \"F\"}, {\"Index\": 1310, \"Highest Charting Position\": 69, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Una Vez\", \"Streams\": 5411302, \"Artist\": \"Bad Bunny, Mora\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5J7teKIJGtqVypgYI6sqXj\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 77.0, \"Danceability\": 0.55, \"Energy\": 0.598, \"Loudness\": -5.402, \"Speechiness\": 0.0831, \"Acousticness\": 0.132, \"Liveness\": 0.0955, \"Tempo\": 83.836, \"Duration (ms)\": 232496.0, \"Valence\": 0.543, \"Chord\": \"B\"}, {\"Index\": 1311, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Moon Relate\", \"Streams\": 5324545, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4sWGHlZGM1XA7TyWdtBAbA\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 58.0, \"Danceability\": 0.867, \"Energy\": 0.768, \"Loudness\": -3.73, \"Speechiness\": 0.0791, \"Acousticness\": 0.18, \"Liveness\": 0.254, \"Tempo\": 102.021, \"Duration (ms)\": 181826.0, \"Valence\": 0.34, \"Chord\": \"G\"}, {\"Index\": 1312, \"Highest Charting Position\": 163, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Black And White\", \"Streams\": 5204120, \"Artist\": \"Niall Horan\", \"Artist Followers\": 7564659.0, \"Song ID\": \"7rpNuuoMbid56XkDsx2FjE\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 75.0, \"Danceability\": 0.443, \"Energy\": 0.582, \"Loudness\": -6.02, \"Speechiness\": 0.0482, \"Acousticness\": 0.0301, \"Liveness\": 0.127, \"Tempo\": 147.589, \"Duration (ms)\": 193090.0, \"Valence\": 0.239, \"Chord\": \"D\"}, {\"Index\": 1313, \"Highest Charting Position\": 81, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"The Other Side (from Trolls World Tour)\", \"Streams\": 5193927, \"Artist\": \"SZA, Justin Timberlake\", \"Artist Followers\": 5888533.0, \"Song ID\": \"463PQggkmk5tTw8ug0ahOX\", \"Genre\": \"['pop', 'pop rap', 'r&b']\", \"Release Date\": \"2020-02-26\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 68.0, \"Danceability\": 0.76, \"Energy\": 0.607, \"Loudness\": -6.274, \"Speechiness\": 0.0964, \"Acousticness\": 0.00277, \"Liveness\": 0.132, \"Tempo\": 105.979, \"Duration (ms)\": 188187.0, \"Valence\": 0.709, \"Chord\": \"G\"}, {\"Index\": 1314, \"Highest Charting Position\": 53, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Whine Up\", \"Streams\": 5130783, \"Artist\": \"Nicky Jam, Anuel AA\", \"Artist Followers\": 14831925.0, \"Song ID\": \"2pWOMNQJW3g2zmGjP0Vkb0\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-01\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.817, \"Energy\": 0.665, \"Loudness\": -6.224, \"Speechiness\": 0.0758, \"Acousticness\": 0.0549, \"Liveness\": 0.103, \"Tempo\": 104.957, \"Duration (ms)\": 215460.0, \"Valence\": 0.662, \"Chord\": \"A\"}, {\"Index\": 1315, \"Highest Charting Position\": 37, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Ayy Macarena\", \"Streams\": 5046905, \"Artist\": \"Tyga\", \"Artist Followers\": 6298789.0, \"Song ID\": \"6LcauUZjF1eXQrgqMUecHX\", \"Genre\": \"['dance pop', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2019-11-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.816, \"Energy\": 0.629, \"Loudness\": -5.568, \"Speechiness\": 0.226, \"Acousticness\": 0.133, \"Liveness\": 0.0692, \"Tempo\": 96.493, \"Duration (ms)\": 131607.0, \"Valence\": 0.714, \"Chord\": \"D\"}, {\"Index\": 1316, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Trap This Way (This Way)\", \"Streams\": 5043990, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7vTspUAmMKFkUpKL9HLZNL\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 59.0, \"Danceability\": 0.71, \"Energy\": 0.586, \"Loudness\": -5.331, \"Speechiness\": 0.381, \"Acousticness\": 0.248, \"Liveness\": 0.193, \"Tempo\": 175.987, \"Duration (ms)\": 185439.0, \"Valence\": 0.207, \"Chord\": \"D\"}, {\"Index\": 1317, \"Highest Charting Position\": 113, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Who (feat. BTS)\", \"Streams\": 5004752, \"Artist\": \"Lauv\", \"Artist Followers\": 4442273.0, \"Song ID\": \"2qG81jL9UIP54uS8gYyP4k\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 74.0, \"Danceability\": 0.632, \"Energy\": 0.345, \"Loudness\": -8.0, \"Speechiness\": 0.0349, \"Acousticness\": 0.551, \"Liveness\": 0.104, \"Tempo\": 141.641, \"Duration (ms)\": 180413.0, \"Valence\": 0.0818, \"Chord\": \"B\"}, {\"Index\": 1318, \"Highest Charting Position\": 51, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Homecoming\", \"Streams\": 4988839, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"6vxU64pcIuQ38O015Zy4qj\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 63.0, \"Danceability\": 0.929, \"Energy\": 0.563, \"Loudness\": -7.428, \"Speechiness\": 0.49, \"Acousticness\": 0.000592, \"Liveness\": 0.244, \"Tempo\": 129.957, \"Duration (ms)\": 213885.0, \"Valence\": 0.353, \"Chord\": \"A\"}, {\"Index\": 1319, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Got The Guap (feat. Young Thug)\", \"Streams\": 4946997, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"1HF6P40Z7nfExGaB1Gk99v\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 58.0, \"Danceability\": 0.837, \"Energy\": 0.601, \"Loudness\": -5.628, \"Speechiness\": 0.198, \"Acousticness\": 0.21, \"Liveness\": 0.0928, \"Tempo\": 142.977, \"Duration (ms)\": 176756.0, \"Valence\": 0.749, \"Chord\": \"G#/Ab\"}, {\"Index\": 1320, \"Highest Charting Position\": 53, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Prices\", \"Streams\": 4898167, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4YcWzLSnGqLjSCycuSMHnn\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 65.0, \"Danceability\": 0.786, \"Energy\": 0.683, \"Loudness\": -5.397, \"Speechiness\": 0.205, \"Acousticness\": 0.173, \"Liveness\": 0.706, \"Tempo\": 126.002, \"Duration (ms)\": 233333.0, \"Valence\": 0.57, \"Chord\": \"G\"}, {\"Index\": 1321, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"I Can Show You\", \"Streams\": 4831405, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"0AhJag7VI8uFf3mJFsTwvf\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 57.0, \"Danceability\": 0.817, \"Energy\": 0.656, \"Loudness\": -7.086, \"Speechiness\": 0.277, \"Acousticness\": 0.051, \"Liveness\": 0.115, \"Tempo\": 139.915, \"Duration (ms)\": 120076.0, \"Valence\": 0.314, \"Chord\": \"A#/Bb\"}, {\"Index\": 1322, \"Highest Charting Position\": 52, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"I'm Sorry\", \"Streams\": 4818039, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"1xcOYJxDa5pObgxY1r0I9c\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 60.0, \"Danceability\": 0.858, \"Energy\": 0.547, \"Loudness\": -5.822, \"Speechiness\": 0.29, \"Acousticness\": 0.213, \"Liveness\": 0.104, \"Tempo\": 128.02, \"Duration (ms)\": 211883.0, \"Valence\": 0.303, \"Chord\": \"C#/Db\"}, {\"Index\": 1323, \"Highest Charting Position\": 19, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Black Swan\", \"Streams\": 4802069, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3bkkMZEAhx7rTVz1C0itRQ\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 70.0, \"Danceability\": 0.719, \"Energy\": 0.758, \"Loudness\": -5.167, \"Speechiness\": 0.0851, \"Acousticness\": 0.137, \"Liveness\": 0.129, \"Tempo\": 147.023, \"Duration (ms)\": 198261.0, \"Valence\": 0.49, \"Chord\": \"D\"}, {\"Index\": 1324, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Bad Child\", \"Streams\": 4787180, \"Artist\": \"Tones And I\", \"Artist Followers\": 1251372.0, \"Song ID\": \"2hBeHlR2d7wFJVLcj2fivL\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 0.0, \"Danceability\": 0.756, \"Energy\": 0.553, \"Loudness\": -4.24, \"Speechiness\": 0.0343, \"Acousticness\": 0.404, \"Liveness\": 0.158, \"Tempo\": 117.992, \"Duration (ms)\": 221467.0, \"Valence\": 0.597, \"Chord\": \"F#/Gb\"}, {\"Index\": 1325, \"Highest Charting Position\": 61, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Adicto (with Anuel AA & Ozuna)\", \"Streams\": 4785720, \"Artist\": \"Tainy\", \"Artist Followers\": 509411.0, \"Song ID\": \"3jbT1Y5MoPwEIpZndDDwVq\", \"Genre\": \"['latin', 'latin hip hop', 'latin pop', 'pop reggaeton', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-08-22\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.734, \"Energy\": 0.836, \"Loudness\": -4.803, \"Speechiness\": 0.0735, \"Acousticness\": 0.017, \"Liveness\": 0.179, \"Tempo\": 80.002, \"Duration (ms)\": 270741.0, \"Valence\": 0.623, \"Chord\": \"A#/Bb\"}, {\"Index\": 1326, \"Highest Charting Position\": 66, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"<3\", \"Streams\": 4755477, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4MZSqgwlE71CWZ6qQ3gkKm\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.631, \"Energy\": 0.665, \"Loudness\": -7.589, \"Speechiness\": 0.229, \"Acousticness\": 0.602, \"Liveness\": 0.152, \"Tempo\": 80.353, \"Duration (ms)\": 157967.0, \"Valence\": 0.634, \"Chord\": \"A#/Bb\"}, {\"Index\": 1327, \"Highest Charting Position\": 198, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Bad Girls, Good Vibes\", \"Streams\": 4752181, \"Artist\": \"Ufo361\", \"Artist Followers\": 1700759.0, \"Song ID\": \"7IxGslFZA5QhgXbUsDmcjf\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 53.0, \"Danceability\": 0.826, \"Energy\": 0.368, \"Loudness\": -12.761, \"Speechiness\": 0.133, \"Acousticness\": 0.516, \"Liveness\": 0.0914, \"Tempo\": 127.977, \"Duration (ms)\": 107446.0, \"Valence\": 0.158, \"Chord\": \"G\"}, {\"Index\": 1328, \"Highest Charting Position\": 120, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Liberdade Provis\\u00f3ria - Ao Vivo\", \"Streams\": 4730891, \"Artist\": \"Henrique & Juliano\", \"Artist Followers\": 13312073.0, \"Song ID\": \"3Ghyp3X5Ua9ypHnBIgOObI\", \"Genre\": \"['sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 58.0, \"Danceability\": 0.668, \"Energy\": 0.684, \"Loudness\": -5.937, \"Speechiness\": 0.0527, \"Acousticness\": 0.627, \"Liveness\": 0.923, \"Tempo\": 108.138, \"Duration (ms)\": 187986.0, \"Valence\": 0.7, \"Chord\": \"C#/Db\"}, {\"Index\": 1329, \"Highest Charting Position\": 60, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"POP\", \"Streams\": 10484727, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"1jDbQz6tr52WgScCTXMnaN\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 58.0, \"Danceability\": 0.741, \"Energy\": 0.599, \"Loudness\": -6.672, \"Speechiness\": 0.419, \"Acousticness\": 0.00961, \"Liveness\": 0.785, \"Tempo\": 139.891, \"Duration (ms)\": 227474.0, \"Valence\": 0.276, \"Chord\": \"C#/Db\"}, {\"Index\": 1330, \"Highest Charting Position\": 61, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Celebration Station\", \"Streams\": 10396969, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"25B5fGr9K0VdZJiRFsnMO4\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 61.0, \"Danceability\": 0.748, \"Energy\": 0.771, \"Loudness\": -4.156, \"Speechiness\": 0.15, \"Acousticness\": 0.101, \"Liveness\": 0.135, \"Tempo\": 142.086, \"Duration (ms)\": 195058.0, \"Valence\": 0.792, \"Chord\": \"F#/Gb\"}, {\"Index\": 1331, \"Highest Charting Position\": 64, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Bigger Than Life\", \"Streams\": 9974143, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2oHDJHNondITqbl8xZ9vPn\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 62.0, \"Danceability\": 0.776, \"Energy\": 0.752, \"Loudness\": -4.711, \"Speechiness\": 0.193, \"Acousticness\": 0.325, \"Liveness\": 0.33, \"Tempo\": 140.013, \"Duration (ms)\": 192705.0, \"Valence\": 0.716, \"Chord\": \"G#/Ab\"}, {\"Index\": 1332, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Venetia\", \"Streams\": 9824605, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"3BYIzNZ3t9lRQCACXSMLrT\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 63.0, \"Danceability\": 0.775, \"Energy\": 0.757, \"Loudness\": -4.139, \"Speechiness\": 0.175, \"Acousticness\": 0.162, \"Liveness\": 0.148, \"Tempo\": 142.933, \"Duration (ms)\": 188800.0, \"Valence\": 0.562, \"Chord\": \"A\"}, {\"Index\": 1333, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"You Better Move\", \"Streams\": 9533898, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"6YAxCn4juTWn5hWl2hzHGw\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 60.0, \"Danceability\": 0.842, \"Energy\": 0.556, \"Loudness\": -6.793, \"Speechiness\": 0.442, \"Acousticness\": 0.159, \"Liveness\": 0.204, \"Tempo\": 118.836, \"Duration (ms)\": 196639.0, \"Valence\": 0.306, \"Chord\": \"G#/Ab\"}, {\"Index\": 1334, \"Highest Charting Position\": 93, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Chrome Heart Tags\", \"Streams\": 8219307, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"46mT9NR7N9Zf5MolcrBgE3\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 57.0, \"Danceability\": 0.702, \"Energy\": 0.768, \"Loudness\": -4.055, \"Speechiness\": 0.0669, \"Acousticness\": 0.541, \"Liveness\": 0.105, \"Tempo\": 70.056, \"Duration (ms)\": 212821.0, \"Valence\": 0.574, \"Chord\": \"C\"}, {\"Index\": 1335, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Bust Me\", \"Streams\": 7828045, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4wBcaYqLPm7EtDVoJQORU4\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 57.0, \"Danceability\": 0.734, \"Energy\": 0.703, \"Loudness\": -6.256, \"Speechiness\": 0.355, \"Acousticness\": 0.237, \"Liveness\": 0.413, \"Tempo\": 151.923, \"Duration (ms)\": 194452.0, \"Valence\": 0.608, \"Chord\": \"B\"}, {\"Index\": 1336, \"Highest Charting Position\": 46, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Ren\\u00e9\", \"Streams\": 7240117, \"Artist\": \"Residente\", \"Artist Followers\": 878491.0, \"Song ID\": \"6gm12xlADJwiBbHIKBXzGW\", \"Genre\": \"['venezuelan hip hop']\", \"Release Date\": \"2020-02-27\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 65.0, \"Danceability\": 0.486, \"Energy\": 0.388, \"Loudness\": -9.326, \"Speechiness\": 0.126, \"Acousticness\": 0.435, \"Liveness\": 0.196, \"Tempo\": 90.471, \"Duration (ms)\": 457592.0, \"Valence\": 0.467, \"Chord\": \"C\"}, {\"Index\": 1337, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Secure The Bag\", \"Streams\": 7053947, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7gHZGXSJzM29WA384suYY2\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 57.0, \"Danceability\": 0.803, \"Energy\": 0.719, \"Loudness\": -4.485, \"Speechiness\": 0.392, \"Acousticness\": 0.344, \"Liveness\": 0.425, \"Tempo\": 129.945, \"Duration (ms)\": 238425.0, \"Valence\": 0.549, \"Chord\": \"C\"}, {\"Index\": 1338, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Urgency (feat. Syd)\", \"Streams\": 6224412, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"5KlPy74NOEAt8jC3FYURnQ\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 53.0, \"Danceability\": 0.619, \"Energy\": 0.784, \"Loudness\": -6.11, \"Speechiness\": 0.123, \"Acousticness\": 0.0326, \"Liveness\": 0.315, \"Tempo\": 156.035, \"Duration (ms)\": 181161.0, \"Valence\": 0.471, \"Chord\": \"C#/Db\"}, {\"Index\": 1339, \"Highest Charting Position\": 34, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"ON (Feat. Sia)\", \"Streams\": 6219276, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3IB5qOeMayvpOdHxYCL5tZ\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 64.0, \"Danceability\": 0.591, \"Energy\": 0.848, \"Loudness\": -4.397, \"Speechiness\": 0.0828, \"Acousticness\": 0.137, \"Liveness\": 0.372, \"Tempo\": 105.922, \"Duration (ms)\": 246816.0, \"Valence\": 0.386, \"Chord\": \"A\"}, {\"Index\": 1340, \"Highest Charting Position\": 99, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"P FKN R\", \"Streams\": 6041127, \"Artist\": \"Bad Bunny, Kendo Kaponi, Arcangel\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0fgsKar6uBO08vzHXkTjWi\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 66.0, \"Danceability\": 0.82, \"Energy\": 0.635, \"Loudness\": -5.749, \"Speechiness\": 0.0772, \"Acousticness\": 0.409, \"Liveness\": 0.244, \"Tempo\": 101.024, \"Duration (ms)\": 258280.0, \"Valence\": 0.528, \"Chord\": \"F\"}, {\"Index\": 1341, \"Highest Charting Position\": 108, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Modern Loneliness\", \"Streams\": 6020508, \"Artist\": \"Lauv\", \"Artist Followers\": 4442273.0, \"Song ID\": \"1eyek0KJEh2v5HQ9uQSybb\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 68.0, \"Danceability\": 0.702, \"Energy\": 0.508, \"Loudness\": -7.105, \"Speechiness\": 0.035, \"Acousticness\": 0.144, \"Liveness\": 0.108, \"Tempo\": 82.008, \"Duration (ms)\": 252337.0, \"Valence\": 0.143, \"Chord\": \"G#/Ab\"}, {\"Index\": 1342, \"Highest Charting Position\": 65, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Heatin Up (feat. Gunna)\", \"Streams\": 6004839, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"7KSSdFCBHCfq4KPzz78ghk\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 66.0, \"Danceability\": 0.788, \"Energy\": 0.436, \"Loudness\": -9.435, \"Speechiness\": 0.364, \"Acousticness\": 0.0611, \"Liveness\": 0.0979, \"Tempo\": 129.847, \"Duration (ms)\": 177314.0, \"Valence\": 0.341, \"Chord\": \"C#/Db\"}, {\"Index\": 1343, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"SKYBOX\", \"Streams\": 5846484, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"7GwYENSg87oERcW0Wacd6m\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 59.0, \"Danceability\": 0.779, \"Energy\": 0.707, \"Loudness\": -6.527, \"Speechiness\": 0.16, \"Acousticness\": 0.0991, \"Liveness\": 0.0934, \"Tempo\": 140.894, \"Duration (ms)\": 178097.0, \"Valence\": 0.343, \"Chord\": \"C#/Db\"}, {\"Index\": 1344, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Young & Alive\", \"Streams\": 5578323, \"Artist\": \"Bazzi\", \"Artist Followers\": 4421378.0, \"Song ID\": \"5RsKelNxucrDxgMbZ3vd3W\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-05\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 71.0, \"Danceability\": 0.716, \"Energy\": 0.563, \"Loudness\": -5.486, \"Speechiness\": 0.0425, \"Acousticness\": 0.326, \"Liveness\": 0.119, \"Tempo\": 86.005, \"Duration (ms)\": 160465.0, \"Valence\": 0.495, \"Chord\": \"D#/Eb\"}, {\"Index\": 1345, \"Highest Charting Position\": 169, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"i'm so tired...\", \"Streams\": 5547770, \"Artist\": \"Lauv, Troye Sivan\", \"Artist Followers\": 4442273.0, \"Song ID\": \"4vjpLMyL3ZO6aphdYr8XYw\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-01-03--2020-01-10\", \"Popularity\": 77.0, \"Danceability\": 0.599, \"Energy\": 0.733, \"Loudness\": -7.058, \"Speechiness\": 0.203, \"Acousticness\": 0.176, \"Liveness\": 0.242, \"Tempo\": 102.211, \"Duration (ms)\": 162583.0, \"Valence\": 0.534, \"Chord\": \"B\"}, {\"Index\": 1346, \"Highest Charting Position\": 53, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Numbers (feat. Roddy Ricch, Gunna and London On Da Track)\", \"Streams\": 5487069, \"Artist\": \"A Boogie Wit da Hoodie\", \"Artist Followers\": 5865895.0, \"Song ID\": \"733c1CWmIGymoQXdp7Us88\", \"Genre\": \"['melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 68.0, \"Danceability\": 0.819, \"Energy\": 0.654, \"Loudness\": -6.665, \"Speechiness\": 0.136, \"Acousticness\": 0.517, \"Liveness\": 0.0996, \"Tempo\": 133.503, \"Duration (ms)\": 188563.0, \"Valence\": 0.455, \"Chord\": \"B\"}, {\"Index\": 1347, \"Highest Charting Position\": 105, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Girl\", \"Streams\": 5434180, \"Artist\": \"Myke Towers\", \"Artist Followers\": 6161098.0, \"Song ID\": \"43NqTeL8pgBxKHPMiJKUP5\", \"Genre\": \"['trap latino']\", \"Release Date\": \"2020-01-24\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 72.0, \"Danceability\": 0.733, \"Energy\": 0.708, \"Loudness\": -4.957, \"Speechiness\": 0.0937, \"Acousticness\": 0.0325, \"Liveness\": 0.324, \"Tempo\": 93.021, \"Duration (ms)\": 186427.0, \"Valence\": 0.694, \"Chord\": \"F#/Gb\"}, {\"Index\": 1348, \"Highest Charting Position\": 104, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Puesto Pa' Guerrial\", \"Streams\": 5359969, \"Artist\": \"Bad Bunny, Myke Towers\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5gCg2qMPzKkW4jS4dBKdDs\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 64.0, \"Danceability\": 0.867, \"Energy\": 0.686, \"Loudness\": -5.342, \"Speechiness\": 0.221, \"Acousticness\": 0.311, \"Liveness\": 0.1, \"Tempo\": 139.968, \"Duration (ms)\": 190207.0, \"Valence\": 0.658, \"Chord\": \"E\"}, {\"Index\": 1349, \"Highest Charting Position\": 114, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Definitivamente\", \"Streams\": 5325447, \"Artist\": \"Daddy Yankee, Sech\", \"Artist Followers\": 23936368.0, \"Song ID\": \"113PlnpZbHd3WIqeYjhZWv\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 66.0, \"Danceability\": 0.813, \"Energy\": 0.764, \"Loudness\": -3.39, \"Speechiness\": 0.105, \"Acousticness\": 0.586, \"Liveness\": 0.253, \"Tempo\": 100.047, \"Duration (ms)\": 217773.0, \"Valence\": 0.429, \"Chord\": \"G#/Ab\"}, {\"Index\": 1350, \"Highest Charting Position\": 41, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"South of the Border (feat. Camila Cabello & Cardi B)\", \"Streams\": 5315827, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"4vUmTMuQqjdnvlZmAH61Qk\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-07-12\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.857, \"Energy\": 0.621, \"Loudness\": -6.376, \"Speechiness\": 0.0825, \"Acousticness\": 0.148, \"Liveness\": 0.0865, \"Tempo\": 97.989, \"Duration (ms)\": 204467.0, \"Valence\": 0.668, \"Chord\": \"A\"}, {\"Index\": 1351, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"I Fall Apart\", \"Streams\": 5251918, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"75ZvA4QfFiZvzhj2xkaWAh\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2016-12-09\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 80.0, \"Danceability\": 0.556, \"Energy\": 0.538, \"Loudness\": -5.408, \"Speechiness\": 0.0382, \"Acousticness\": 0.0689, \"Liveness\": 0.196, \"Tempo\": 143.95, \"Duration (ms)\": 223347.0, \"Valence\": 0.291, \"Chord\": \"G#/Ab\"}, {\"Index\": 1352, \"Highest Charting Position\": 191, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"fuck, i'm lonely (with Anne-Marie)\", \"Streams\": 5226991, \"Artist\": \"Lauv\", \"Artist Followers\": 4442273.0, \"Song ID\": \"09PGubKAMryhOWv1LHpCYz\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 74.0, \"Danceability\": 0.806, \"Energy\": 0.558, \"Loudness\": -6.46, \"Speechiness\": 0.0683, \"Acousticness\": 0.482, \"Liveness\": 0.0618, \"Tempo\": 95.016, \"Duration (ms)\": 198973.0, \"Valence\": 0.678, \"Chord\": \"A\"}, {\"Index\": 1353, \"Highest Charting Position\": 78, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Aventura\", \"Streams\": 5206102, \"Artist\": \"Lunay, Ozuna, Anuel AA\", \"Artist Followers\": 4963516.0, \"Song ID\": \"37zdqI4r1gswIzczSBkRon\", \"Genre\": \"['latin', 'latin pop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-10-25\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.729, \"Energy\": 0.726, \"Loudness\": -3.208, \"Speechiness\": 0.0422, \"Acousticness\": 0.223, \"Liveness\": 0.101, \"Tempo\": 92.025, \"Duration (ms)\": 217130.0, \"Valence\": 0.876, \"Chord\": \"F\"}, {\"Index\": 1354, \"Highest Charting Position\": 12, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Rare\", \"Streams\": 5195842, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"7HMmFQsKsljwTw8bS7lu19\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 68.0, \"Danceability\": 0.838, \"Energy\": 0.545, \"Loudness\": -6.713, \"Speechiness\": 0.0706, \"Acousticness\": 0.208, \"Liveness\": 0.103, \"Tempo\": 114.998, \"Duration (ms)\": 220590.0, \"Valence\": 0.631, \"Chord\": \"F\"}, {\"Index\": 1355, \"Highest Charting Position\": 69, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"VIBEZ\", \"Streams\": 5121486, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"0fySG6A6qLE8IvDpayb5bM\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.768, \"Energy\": 0.652, \"Loudness\": -2.708, \"Speechiness\": 0.307, \"Acousticness\": 0.113, \"Liveness\": 0.107, \"Tempo\": 154.187, \"Duration (ms)\": 144935.0, \"Valence\": 0.777, \"Chord\": \"C#/Db\"}, {\"Index\": 1356, \"Highest Charting Position\": 69, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Mean It\", \"Streams\": 5110064, \"Artist\": \"Lauv, LANY\", \"Artist Followers\": 4442273.0, \"Song ID\": \"3uc8AGNL0KbvISIrjnfRvN\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.746, \"Energy\": 0.45, \"Loudness\": -8.543, \"Speechiness\": 0.0872, \"Acousticness\": 0.0407, \"Liveness\": 0.172, \"Tempo\": 95.998, \"Duration (ms)\": 232853.0, \"Valence\": 0.336, \"Chord\": \"G\"}, {\"Index\": 1357, \"Highest Charting Position\": 49, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"That Way\", \"Streams\": 12059592, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"5raTDhlbxFDnpn89bxArdH\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-01\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 67.0, \"Danceability\": 0.719, \"Energy\": 0.611, \"Loudness\": -5.01, \"Speechiness\": 0.0403, \"Acousticness\": 0.0582, \"Liveness\": 0.155, \"Tempo\": 129.962, \"Duration (ms)\": 212354.0, \"Valence\": 0.489, \"Chord\": \"G\"}, {\"Index\": 1358, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Live Off My Closet (feat. Future)\", \"Streams\": 7410327, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"6AyWdCtEn1DdxjnxPeojR2\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 59.0, \"Danceability\": 0.807, \"Energy\": 0.678, \"Loudness\": -3.244, \"Speechiness\": 0.177, \"Acousticness\": 0.0345, \"Liveness\": 0.0986, \"Tempo\": 147.004, \"Duration (ms)\": 173061.0, \"Valence\": 0.21, \"Chord\": \"F#/Gb\"}, {\"Index\": 1359, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Commercial (feat. Lil Uzi Vert)\", \"Streams\": 6540577, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"3tDqEKKUs6gf8zMvSuLyLA\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 67.0, \"Danceability\": 0.892, \"Energy\": 0.486, \"Loudness\": -8.637, \"Speechiness\": 0.384, \"Acousticness\": 0.048, \"Liveness\": 0.146, \"Tempo\": 120.998, \"Duration (ms)\": 214215.0, \"Valence\": 0.535, \"Chord\": \"B\"}, {\"Index\": 1360, \"Highest Charting Position\": 75, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Sum 2 Prove\", \"Streams\": 6497610, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"2u3EyuCqqV31woqGvO9LBz\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 71.0, \"Danceability\": 0.823, \"Energy\": 0.552, \"Loudness\": -7.57, \"Speechiness\": 0.324, \"Acousticness\": 0.0174, \"Liveness\": 0.122, \"Tempo\": 124.038, \"Duration (ms)\": 205760.0, \"Valence\": 0.418, \"Chord\": \"E\"}, {\"Index\": 1361, \"Highest Charting Position\": 47, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Filter\", \"Streams\": 5913946, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"0ono6UCNVZ1XqOm6j78Blu\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 79.0, \"Danceability\": 0.781, \"Energy\": 0.762, \"Loudness\": -5.188, \"Speechiness\": 0.0626, \"Acousticness\": 0.0222, \"Liveness\": 0.121, \"Tempo\": 110.042, \"Duration (ms)\": 180221.0, \"Valence\": 0.86, \"Chord\": \"A#/Bb\"}, {\"Index\": 1362, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Matrix\", \"Streams\": 5724739, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"7ygVaACDENw4PgLbN1awFE\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-02-24\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 55.0, \"Danceability\": 0.789, \"Energy\": 0.509, \"Loudness\": -8.766, \"Speechiness\": 0.291, \"Acousticness\": 0.768, \"Liveness\": 0.272, \"Tempo\": 114.957, \"Duration (ms)\": 183793.0, \"Valence\": 0.418, \"Chord\": \"A\"}, {\"Index\": 1363, \"Highest Charting Position\": 91, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Bellaquita - Remix\", \"Streams\": 5676621, \"Artist\": \"Dalex, Lenny Tav\\u00e1rez, Anitta, Natti Natasha, Farruko, Justin Quiles\", \"Artist Followers\": 3600989.0, \"Song ID\": \"1Xnn1TPyr5h0hpRAT4B4EA\", \"Genre\": \"['latin', 'r&b en espanol', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.795, \"Energy\": 0.715, \"Loudness\": -3.582, \"Speechiness\": 0.0838, \"Acousticness\": 0.141, \"Liveness\": 0.179, \"Tempo\": 165.941, \"Duration (ms)\": 304733.0, \"Valence\": 0.758, \"Chord\": \"C#/Db\"}, {\"Index\": 1364, \"Highest Charting Position\": 139, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Infeliz\", \"Streams\": 5490386, \"Artist\": \"Arcangel, Bad Bunny\", \"Artist Followers\": 6671084.0, \"Song ID\": \"4z6wo6PJG4Fve45OXK6D9m\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-12-20\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 72.0, \"Danceability\": 0.713, \"Energy\": 0.798, \"Loudness\": -3.147, \"Speechiness\": 0.219, \"Acousticness\": 0.366, \"Liveness\": 0.246, \"Tempo\": 176.073, \"Duration (ms)\": 221103.0, \"Valence\": 0.721, \"Chord\": \"C#/Db\"}, {\"Index\": 1365, \"Highest Charting Position\": 60, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Que Tire Pa Lante\", \"Streams\": 5436773, \"Artist\": \"Daddy Yankee\", \"Artist Followers\": 23936368.0, \"Song ID\": \"6RyaV7owmVU6fzEPE17sF1\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-10-18\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.658, \"Energy\": 0.901, \"Loudness\": -2.814, \"Speechiness\": 0.0357, \"Acousticness\": 0.0478, \"Liveness\": 0.12, \"Tempo\": 93.979, \"Duration (ms)\": 210520.0, \"Valence\": 0.708, \"Chord\": \"G\"}, {\"Index\": 1366, \"Highest Charting Position\": 32, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Futsal Shuffle 2020\", \"Streams\": 5386512, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2Ec33AVlkTTq8BHFgBTdQs\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-12\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.881, \"Energy\": 0.457, \"Loudness\": -8.191, \"Speechiness\": 0.156, \"Acousticness\": 0.0327, \"Liveness\": 0.231, \"Tempo\": 136.97, \"Duration (ms)\": 198913.0, \"Valence\": 0.296, \"Chord\": \"G\"}, {\"Index\": 1367, \"Highest Charting Position\": 123, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"GOODMORNINGTOKYO!\", \"Streams\": 5286044, \"Artist\": \"TOKYO\\u2019S REVENGE\", \"Artist Followers\": 313480.0, \"Song ID\": \"0Q2n5yzl2XRqYbV77tZNYp\", \"Genre\": \"['meme rap', 'sad rap', 'vapor trap', 'viral rap']\", \"Release Date\": \"2019-10-18\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 74.0, \"Danceability\": 0.907, \"Energy\": 0.539, \"Loudness\": -7.782, \"Speechiness\": 0.36, \"Acousticness\": 0.0408, \"Liveness\": 0.253, \"Tempo\": 124.918, \"Duration (ms)\": 150115.0, \"Valence\": 0.664, \"Chord\": \"E\"}, {\"Index\": 1368, \"Highest Charting Position\": 58, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Own It (feat. Ed Sheeran & Burna Boy)\", \"Streams\": 5273046, \"Artist\": \"Stormzy\", \"Artist Followers\": 2317758.0, \"Song ID\": \"4QPEwDdOMhY7rNS05mTyMR\", \"Genre\": \"['grime', 'uk hip hop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.817, \"Energy\": 0.781, \"Loudness\": -4.178, \"Speechiness\": 0.112, \"Acousticness\": 0.00838, \"Liveness\": 0.123, \"Tempo\": 104.0, \"Duration (ms)\": 216707.0, \"Valence\": 0.359, \"Chord\": \"G\"}, {\"Index\": 1369, \"Highest Charting Position\": 128, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Life Is Good (feat. Drake, DaBaby & Lil Baby) - Remix\", \"Streams\": 5260351, \"Artist\": \"Future\", \"Artist Followers\": 10491105.0, \"Song ID\": \"4iiWcajF1fEUpwcUewc464\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-02-15\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 61.0, \"Danceability\": 0.81, \"Energy\": 0.566, \"Loudness\": -8.33, \"Speechiness\": 0.433, \"Acousticness\": 0.107, \"Liveness\": 0.122, \"Tempo\": 142.069, \"Duration (ms)\": 315346.0, \"Valence\": 0.582, \"Chord\": \"F\"}, {\"Index\": 1370, \"Highest Charting Position\": 58, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"My Time\", \"Streams\": 5212053, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4vTgx6h4seHvkuFh84JXYP\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 74.0, \"Danceability\": 0.674, \"Energy\": 0.64, \"Loudness\": -5.139, \"Speechiness\": 0.0339, \"Acousticness\": 0.151, \"Liveness\": 0.0925, \"Tempo\": 99.908, \"Duration (ms)\": 234458.0, \"Valence\": 0.664, \"Chord\": \"C\"}, {\"Index\": 1371, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"100k Cash\", \"Streams\": 5192813, \"Artist\": \"Capital Bra, Samra\", \"Artist Followers\": 4093115.0, \"Song ID\": \"033if6Adj8fwBYsQzHOfQ8\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-02-27\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 52.0, \"Danceability\": 0.701, \"Energy\": 0.714, \"Loudness\": -5.906, \"Speechiness\": 0.524, \"Acousticness\": 0.289, \"Liveness\": 0.0883, \"Tempo\": 86.91, \"Duration (ms)\": 173353.0, \"Valence\": 0.604, \"Chord\": \"A#/Bb\"}, {\"Index\": 1372, \"Highest Charting Position\": 185, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Drown (feat. Clinton Kane)\", \"Streams\": 5186141, \"Artist\": \"Martin Garrix\", \"Artist Followers\": 14921269.0, \"Song ID\": \"4RVtBlHFKj51Ipvpfv5ER4\", \"Genre\": \"['dance pop', 'dutch edm', 'edm', 'pop', 'pop dance', 'progressive house', 'tropical house']\", \"Release Date\": \"2020-02-27\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 74.0, \"Danceability\": 0.573, \"Energy\": 0.739, \"Loudness\": -5.455, \"Speechiness\": 0.0581, \"Acousticness\": 0.212, \"Liveness\": 0.175, \"Tempo\": 120.077, \"Duration (ms)\": 174062.0, \"Valence\": 0.363, \"Chord\": \"A\"}, {\"Index\": 1373, \"Highest Charting Position\": 103, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"me & ur ghost\", \"Streams\": 5184069, \"Artist\": \"blackbear\", \"Artist Followers\": 4272745.0, \"Song ID\": \"38KsRHYE10bG0paU78gL9r\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 71.0, \"Danceability\": 0.742, \"Energy\": 0.679, \"Loudness\": -4.594, \"Speechiness\": 0.0259, \"Acousticness\": 0.0488, \"Liveness\": 0.0754, \"Tempo\": 100.041, \"Duration (ms)\": 201398.0, \"Valence\": 0.856, \"Chord\": \"G\"}, {\"Index\": 1374, \"Highest Charting Position\": 146, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"QUE PRETENDES\", \"Streams\": 5141047, \"Artist\": \"J Balvin, Bad Bunny\", \"Artist Followers\": 29067437.0, \"Song ID\": \"25ZAibhr3bdlMCLmubZDVt\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.639, \"Energy\": 0.791, \"Loudness\": -4.443, \"Speechiness\": 0.253, \"Acousticness\": 0.0275, \"Liveness\": 0.362, \"Tempo\": 92.603, \"Duration (ms)\": 222347.0, \"Valence\": 0.939, \"Chord\": \"A#/Bb\"}, {\"Index\": 1375, \"Highest Charting Position\": 140, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"You Need To Calm Down\", \"Streams\": 5115153, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6RRNNciQGZEXnqk8SQ9yv5\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.771, \"Energy\": 0.671, \"Loudness\": -5.617, \"Speechiness\": 0.0553, \"Acousticness\": 0.00929, \"Liveness\": 0.0637, \"Tempo\": 85.026, \"Duration (ms)\": 171360.0, \"Valence\": 0.714, \"Chord\": \"D\"}, {\"Index\": 1376, \"Highest Charting Position\": 90, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Quizas\", \"Streams\": 5112244, \"Artist\": \"Rich Music LTD, Sech, Dalex, Justin Quiles, Lenny Tav\\u00e1rez, Feid, Wisin, Zion\", \"Artist Followers\": 206225.0, \"Song ID\": \"5Id5B3dxJZhPcV9GzgYZZe\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-10-11\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.727, \"Energy\": 0.815, \"Loudness\": -2.454, \"Speechiness\": 0.153, \"Acousticness\": 0.0258, \"Liveness\": 0.231, \"Tempo\": 176.075, \"Duration (ms)\": 216067.0, \"Valence\": 0.677, \"Chord\": \"D#/Eb\"}, {\"Index\": 1377, \"Highest Charting Position\": 106, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Soltera - Remix\", \"Streams\": 5078459, \"Artist\": \"Lunay, Daddy Yankee, Bad Bunny\", \"Artist Followers\": 4963516.0, \"Song ID\": \"1c0hsvHLELX6y8qymnpLKL\", \"Genre\": \"['latin', 'latin pop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-05-10\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.795, \"Energy\": 0.783, \"Loudness\": -4.271, \"Speechiness\": 0.0432, \"Acousticness\": 0.361, \"Liveness\": 0.437, \"Tempo\": 92.01, \"Duration (ms)\": 266087.0, \"Valence\": 0.799, \"Chord\": \"F\"}, {\"Index\": 1378, \"Highest Charting Position\": 46, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Trampoline (with ZAYN)\", \"Streams\": 5075520, \"Artist\": \"SHAED\", \"Artist Followers\": 139434.0, \"Song ID\": \"1iQDltZqI7BXnHrFy4Qo1k\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-09-26\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 73.0, \"Danceability\": 0.619, \"Energy\": 0.459, \"Loudness\": -5.782, \"Speechiness\": 0.0334, \"Acousticness\": 0.56, \"Liveness\": 0.137, \"Tempo\": 126.803, \"Duration (ms)\": 184280.0, \"Valence\": 0.498, \"Chord\": \"G\"}, {\"Index\": 1379, \"Highest Charting Position\": 82, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Truth Hurts\", \"Streams\": 5024683, \"Artist\": \"Lizzo\", \"Artist Followers\": 3991674.0, \"Song ID\": \"3HWzoMvoF3TQfYg4UPszDq\", \"Genre\": \"['dance pop', 'escape room', 'minnesota hip hop', 'pop', 'pop rap', 'post-teen pop', 'trap queen']\", \"Release Date\": \"2019-04-19\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.715, \"Energy\": 0.624, \"Loudness\": -3.046, \"Speechiness\": 0.114, \"Acousticness\": 0.11, \"Liveness\": 0.123, \"Tempo\": 158.087, \"Duration (ms)\": 173325.0, \"Valence\": 0.412, \"Chord\": \"E\"}, {\"Index\": 1380, \"Highest Charting Position\": 91, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"bury a friend\", \"Streams\": 5020303, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"7p6ZK1vOxKELFwlDfwkJCp\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 1.0, \"Danceability\": 0.887, \"Energy\": 0.388, \"Loudness\": -14.505, \"Speechiness\": 0.349, \"Acousticness\": 0.739, \"Liveness\": 0.106, \"Tempo\": 120.035, \"Duration (ms)\": 193143.0, \"Valence\": 0.205, \"Chord\": \"G#/Ab\"}, {\"Index\": 1381, \"Highest Charting Position\": 54, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Louder than bombs\", \"Streams\": 10016907, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3op7HNwLli54MBjFGzIlZO\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.643, \"Energy\": 0.667, \"Loudness\": -6.993, \"Speechiness\": 0.152, \"Acousticness\": 0.0433, \"Liveness\": 0.0904, \"Tempo\": 145.999, \"Duration (ms)\": 217404.0, \"Valence\": 0.485, \"Chord\": \"C\"}, {\"Index\": 1382, \"Highest Charting Position\": 56, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"UGH!\", \"Streams\": 9991177, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"1aKuG1GG76xPLUkjBbQo3W\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.72, \"Energy\": 0.824, \"Loudness\": -5.086, \"Speechiness\": 0.128, \"Acousticness\": 0.0394, \"Liveness\": 0.0509, \"Tempo\": 165.998, \"Duration (ms)\": 225012.0, \"Valence\": 0.333, \"Chord\": \"A#/Bb\"}, {\"Index\": 1383, \"Highest Charting Position\": 67, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"00:00 (Zero O\\u2019Clock)\", \"Streams\": 9372219, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4AlihYDqxXshKhvh5tnMfP\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.566, \"Energy\": 0.548, \"Loudness\": -6.456, \"Speechiness\": 0.0579, \"Acousticness\": 0.0802, \"Liveness\": 0.11, \"Tempo\": 157.999, \"Duration (ms)\": 250296.0, \"Valence\": 0.196, \"Chord\": \"C#/Db\"}, {\"Index\": 1384, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Friends\", \"Streams\": 8822365, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"7w05lsU2VLSeiT8Nukrv5M\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.55, \"Energy\": 0.747, \"Loudness\": -5.211, \"Speechiness\": 0.0407, \"Acousticness\": 0.0668, \"Liveness\": 0.0536, \"Tempo\": 79.98, \"Duration (ms)\": 199339.0, \"Valence\": 0.648, \"Chord\": \"C#/Db\"}, {\"Index\": 1385, \"Highest Charting Position\": 75, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"We are Bulletproof : the Eternal\", \"Streams\": 8516710, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"44WLOqH7QayQOQdeUHeKUK\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.526, \"Energy\": 0.575, \"Loudness\": -5.215, \"Speechiness\": 0.0309, \"Acousticness\": 0.225, \"Liveness\": 0.108, \"Tempo\": 84.047, \"Duration (ms)\": 261543.0, \"Valence\": 0.19, \"Chord\": \"A\"}, {\"Index\": 1386, \"Highest Charting Position\": 79, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Inner Child\", \"Streams\": 8312399, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4BKOjYosPhw334moS3wlbO\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 71.0, \"Danceability\": 0.589, \"Energy\": 0.696, \"Loudness\": -7.981, \"Speechiness\": 0.0725, \"Acousticness\": 0.017, \"Liveness\": 0.0808, \"Tempo\": 134.953, \"Duration (ms)\": 233266.0, \"Valence\": 0.332, \"Chord\": \"B\"}, {\"Index\": 1387, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Moon\", \"Streams\": 7850129, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"1xfXXujIlLZAx5wpu46Nyk\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.703, \"Energy\": 0.646, \"Loudness\": -6.658, \"Speechiness\": 0.0596, \"Acousticness\": 0.0104, \"Liveness\": 0.191, \"Tempo\": 141.87, \"Duration (ms)\": 208590.0, \"Valence\": 0.64, \"Chord\": \"F#/Gb\"}, {\"Index\": 1388, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Outro : Ego\", \"Streams\": 6857808, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3r9FFjLrAIQjoR8pSHVPC9\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 69.0, \"Danceability\": 0.808, \"Energy\": 0.903, \"Loudness\": -3.106, \"Speechiness\": 0.0958, \"Acousticness\": 0.0121, \"Liveness\": 0.0993, \"Tempo\": 116.988, \"Duration (ms)\": 196199.0, \"Valence\": 0.473, \"Chord\": \"C\"}, {\"Index\": 1389, \"Highest Charting Position\": 109, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Interlude : Shadow\", \"Streams\": 6655856, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"2Nib4r0saYQf2pUV4RFDhl\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 68.0, \"Danceability\": 0.385, \"Energy\": 0.798, \"Loudness\": -6.439, \"Speechiness\": 0.483, \"Acousticness\": 0.115, \"Liveness\": 0.181, \"Tempo\": 149.756, \"Duration (ms)\": 259821.0, \"Valence\": 0.141, \"Chord\": \"A\"}, {\"Index\": 1390, \"Highest Charting Position\": 120, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Respect\", \"Streams\": 6373954, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"37TSJmYKLxXmx8OehFpqMN\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 67.0, \"Danceability\": 0.661, \"Energy\": 0.84, \"Loudness\": -4.805, \"Speechiness\": 0.116, \"Acousticness\": 0.00485, \"Liveness\": 0.287, \"Tempo\": 91.457, \"Duration (ms)\": 237540.0, \"Valence\": 0.524, \"Chord\": \"C\"}, {\"Index\": 1391, \"Highest Charting Position\": 154, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Tudo Ok\", \"Streams\": 5510844, \"Artist\": \"Thiaguinho MT, Mila, JS o M\\u00e3o de Ouro\", \"Artist Followers\": 28017.0, \"Song ID\": \"4HUZBG98TYbxSR9V1V2DWS\", \"Genre\": \"['brega funk', 'funk carioca']\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 57.0, \"Danceability\": 0.814, \"Energy\": 0.755, \"Loudness\": -6.164, \"Speechiness\": 0.0942, \"Acousticness\": 0.239, \"Liveness\": 0.306, \"Tempo\": 79.976, \"Duration (ms)\": 178500.0, \"Valence\": 0.963, \"Chord\": \"B\"}, {\"Index\": 1392, \"Highest Charting Position\": 128, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Perreo en La Luna\", \"Streams\": 5135469, \"Artist\": \"Rich Music LTD, Sech, Dalex, Justin Quiles, Lenny Tav\\u00e1rez, Feid\", \"Artist Followers\": 206225.0, \"Song ID\": \"0RDgqtvOHLwcI6yz9bjsZV\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-10-11\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.711, \"Energy\": 0.757, \"Loudness\": -4.188, \"Speechiness\": 0.29, \"Acousticness\": 0.268, \"Liveness\": 0.367, \"Tempo\": 174.013, \"Duration (ms)\": 218587.0, \"Valence\": 0.724, \"Chord\": \"C#/Db\"}, {\"Index\": 1393, \"Highest Charting Position\": 129, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Lose Yourself - From \\\"8 Mile\\\" Soundtrack\", \"Streams\": 5118004, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5Z01UMMf7V1o0MzF86s6WJ\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2005-12-06\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 75.0, \"Danceability\": 0.692, \"Energy\": 0.744, \"Loudness\": -4.565, \"Speechiness\": 0.257, \"Acousticness\": 0.00868, \"Liveness\": 0.359, \"Tempo\": 171.374, \"Duration (ms)\": 326467.0, \"Valence\": 0.0612, \"Chord\": \"D\"}, {\"Index\": 1394, \"Highest Charting Position\": 118, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"all the good girls go to hell\", \"Streams\": 5074485, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"6IRdLKIyS4p7XNiP8r6rsx\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-03-29\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.726, \"Energy\": 0.444, \"Loudness\": -8.922, \"Speechiness\": 0.372, \"Acousticness\": 0.283, \"Liveness\": 0.177, \"Tempo\": 185.044, \"Duration (ms)\": 168840.0, \"Valence\": 0.569, \"Chord\": \"G#/Ab\"}, {\"Index\": 1395, \"Highest Charting Position\": 155, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"SENTAD\\u00c3O\", \"Streams\": 5013019, \"Artist\": \"PEDRO SAMPAIO, Felipe Original, JS o M\\u00e3o de Ouro\", \"Artist Followers\": 1050520.0, \"Song ID\": \"4lKuzrdZrJuCAedbIslF3A\", \"Genre\": \"['funk carioca']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2019-12-27--2020-01-03\", \"Popularity\": 64.0, \"Danceability\": 0.68, \"Energy\": 0.869, \"Loudness\": -1.94, \"Speechiness\": 0.0589, \"Acousticness\": 0.178, \"Liveness\": 0.223, \"Tempo\": 173.997, \"Duration (ms)\": 143448.0, \"Valence\": 0.924, \"Chord\": \"F#/Gb\"}, {\"Index\": 1396, \"Highest Charting Position\": 182, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Lottery (Renegade)\", \"Streams\": 4994448, \"Artist\": \"K CAMP\", \"Artist Followers\": 1347589.0, \"Song ID\": \"4dZTZbmJBCCofAExHwefda\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'pop r&b', 'pop rap', 'r&b', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 61.0, \"Danceability\": 0.915, \"Energy\": 0.556, \"Loudness\": -8.601, \"Speechiness\": 0.216, \"Acousticness\": 0.0145, \"Liveness\": 0.0733, \"Tempo\": 148.964, \"Duration (ms)\": 170947.0, \"Valence\": 0.67, \"Chord\": \"C#/Db\"}, {\"Index\": 1397, \"Highest Charting Position\": 104, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Si Te Vas\", \"Streams\": 4954292, \"Artist\": \"Sech, Ozuna\", \"Artist Followers\": 8766508.0, \"Song ID\": \"6Y4PDQv4XjYjHLeLmvyOt0\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-09-26\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.73, \"Energy\": 0.644, \"Loudness\": -4.124, \"Speechiness\": 0.132, \"Acousticness\": 0.0933, \"Liveness\": 0.143, \"Tempo\": 174.101, \"Duration (ms)\": 204907.0, \"Valence\": 0.554, \"Chord\": \"C\"}, {\"Index\": 1398, \"Highest Charting Position\": 121, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Que Calor (with J Balvin & El Alfa)\", \"Streams\": 4950254, \"Artist\": \"Major Lazer, Diplo\", \"Artist Followers\": 6223652.0, \"Song ID\": \"3iQGDAAKMrlJarnaYNgnSE\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'moombahton', 'pop', 'pop dance', 'pop rap']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 29.0, \"Danceability\": 0.873, \"Energy\": 0.656, \"Loudness\": -6.043, \"Speechiness\": 0.068, \"Acousticness\": 0.00477, \"Liveness\": 0.0726, \"Tempo\": 125.982, \"Duration (ms)\": 206811.0, \"Valence\": 0.546, \"Chord\": \"G#/Ab\"}, {\"Index\": 1399, \"Highest Charting Position\": 186, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Rich Rich\", \"Streams\": 4938864, \"Artist\": \"Ufo361\", \"Artist Followers\": 1700759.0, \"Song ID\": \"2QfmSvSMwTXcvlIkU0w1Yk\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 50.0, \"Danceability\": 0.548, \"Energy\": 0.648, \"Loudness\": -4.796, \"Speechiness\": 0.292, \"Acousticness\": 0.0842, \"Liveness\": 0.123, \"Tempo\": 141.937, \"Duration (ms)\": 204319.0, \"Valence\": 0.232, \"Chord\": \"E\"}, {\"Index\": 1400, \"Highest Charting Position\": 86, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Indeciso\", \"Streams\": 4897374, \"Artist\": \"Reik, J Balvin, Lalo Ebratt\", \"Artist Followers\": 1251372.0, \"Song ID\": \"0FnPT2g07W4aXuHjniC1of\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.738, \"Energy\": 0.748, \"Loudness\": -4.902, \"Speechiness\": 0.0453, \"Acousticness\": 0.182, \"Liveness\": 0.109, \"Tempo\": 94.949, \"Duration (ms)\": 217253.0, \"Valence\": 0.896, \"Chord\": \"C\"}, {\"Index\": 1401, \"Highest Charting Position\": 148, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"i love you\", \"Streams\": 4863910, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"0np7TYPZSum9xTxe9QTr21\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-03--2020-01-10\", \"Popularity\": 2.0, \"Danceability\": 0.42, \"Energy\": 0.131, \"Loudness\": -18.435, \"Speechiness\": 0.0382, \"Acousticness\": 0.953, \"Liveness\": 0.109, \"Tempo\": 137.421, \"Duration (ms)\": 291796.0, \"Valence\": 0.12, \"Chord\": \"C\"}, {\"Index\": 1402, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Mejor\", \"Streams\": 4851895, \"Artist\": \"Dalex, Sech\", \"Artist Followers\": 3600989.0, \"Song ID\": \"6C1jKbkCUgFws7M0M4oGCB\", \"Genre\": \"['latin', 'r&b en espanol', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 63.0, \"Danceability\": 0.524, \"Energy\": 0.577, \"Loudness\": -4.501, \"Speechiness\": 0.18, \"Acousticness\": 0.185, \"Liveness\": 0.103, \"Tempo\": 175.396, \"Duration (ms)\": 201361.0, \"Valence\": 0.19, \"Chord\": \"D\"}, {\"Index\": 1403, \"Highest Charting Position\": 57, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Give No Fxk\", \"Streams\": 9652399, \"Artist\": \"Migos, Travis Scott, Young Thug\", \"Artist Followers\": 11692972.0, \"Song ID\": \"6ZelF5APDN5r6XnFqcnvWR\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 59.0, \"Danceability\": 0.904, \"Energy\": 0.627, \"Loudness\": -5.608, \"Speechiness\": 0.222, \"Acousticness\": 0.0303, \"Liveness\": 0.0923, \"Tempo\": 145.976, \"Duration (ms)\": 224243.0, \"Valence\": 0.236, \"Chord\": \"C#/Db\"}, {\"Index\": 1404, \"Highest Charting Position\": 61, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Come Around Me\", \"Streams\": 9533583, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2o9LAypwGH4ctV0i9boo6d\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 66.0, \"Danceability\": 0.648, \"Energy\": 0.681, \"Loudness\": -8.389, \"Speechiness\": 0.0378, \"Acousticness\": 0.263, \"Liveness\": 0.0971, \"Tempo\": 157.941, \"Duration (ms)\": 200773.0, \"Valence\": 0.767, \"Chord\": \"D\"}, {\"Index\": 1405, \"Highest Charting Position\": 64, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Habitual\", \"Streams\": 9120086, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"40qyPyljksBEqlNw5sW37T\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 62.0, \"Danceability\": 0.764, \"Energy\": 0.443, \"Loudness\": -6.625, \"Speechiness\": 0.0439, \"Acousticness\": 0.52, \"Liveness\": 0.0749, \"Tempo\": 138.999, \"Duration (ms)\": 168200.0, \"Valence\": 0.63, \"Chord\": \"E\"}, {\"Index\": 1406, \"Highest Charting Position\": 65, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"All Around Me\", \"Streams\": 9010535, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5Py8zRKGkZvgHniVVtvNCN\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 63.0, \"Danceability\": 0.566, \"Energy\": 0.438, \"Loudness\": -7.564, \"Speechiness\": 0.0367, \"Acousticness\": 0.809, \"Liveness\": 0.212, \"Tempo\": 117.127, \"Duration (ms)\": 136907.0, \"Valence\": 0.692, \"Chord\": \"C\"}, {\"Index\": 1407, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Get Me (feat. Kehlani)\", \"Streams\": 8362828, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5VwwpU7KsLhgfbMEecedhJ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 61.0, \"Danceability\": 0.832, \"Energy\": 0.508, \"Loudness\": -6.913, \"Speechiness\": 0.149, \"Acousticness\": 0.0492, \"Liveness\": 0.107, \"Tempo\": 109.352, \"Duration (ms)\": 185427.0, \"Valence\": 0.75, \"Chord\": \"F#/Gb\"}, {\"Index\": 1408, \"Highest Charting Position\": 79, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Second Emotion (feat. Travis Scott)\", \"Streams\": 8109572, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"1PnAx788sAvcI3ZxTlEyX8\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 61.0, \"Danceability\": 0.796, \"Energy\": 0.777, \"Loudness\": -6.112, \"Speechiness\": 0.0567, \"Acousticness\": 0.0276, \"Liveness\": 0.095, \"Tempo\": 141.97, \"Duration (ms)\": 202720.0, \"Valence\": 0.96, \"Chord\": \"B\"}, {\"Index\": 1409, \"Highest Charting Position\": 85, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Running Over (feat. Lil Dicky)\", \"Streams\": 7493188, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"75nKBP8jQu681pTNCtrEnn\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.774, \"Energy\": 0.603, \"Loudness\": -7.319, \"Speechiness\": 0.0591, \"Acousticness\": 0.438, \"Liveness\": 0.0869, \"Tempo\": 149.982, \"Duration (ms)\": 179627.0, \"Valence\": 0.977, \"Chord\": \"B\"}, {\"Index\": 1410, \"Highest Charting Position\": 86, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Available\", \"Streams\": 7473249, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"1b6tPXXCV2fSNtR3SKWUQA\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.702, \"Energy\": 0.608, \"Loudness\": -6.843, \"Speechiness\": 0.0359, \"Acousticness\": 0.0736, \"Liveness\": 0.129, \"Tempo\": 75.012, \"Duration (ms)\": 195333.0, \"Valence\": 0.597, \"Chord\": \"D#/Eb\"}, {\"Index\": 1411, \"Highest Charting Position\": 96, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Breathe Deeper\", \"Streams\": 7142364, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"3LbZIhU0smEU5SUnxod4j4\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 66.0, \"Danceability\": 0.664, \"Energy\": 0.848, \"Loudness\": -4.51, \"Speechiness\": 0.0322, \"Acousticness\": 0.0245, \"Liveness\": 0.172, \"Tempo\": 104.998, \"Duration (ms)\": 372867.0, \"Valence\": 0.502, \"Chord\": \"B\"}, {\"Index\": 1412, \"Highest Charting Position\": 103, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Changes\", \"Streams\": 6865229, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"521Os1SMlxmsoevsqyjNmJ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 62.0, \"Danceability\": 0.485, \"Energy\": 0.412, \"Loudness\": -7.766, \"Speechiness\": 0.042, \"Acousticness\": 0.738, \"Liveness\": 0.12, \"Tempo\": 64.062, \"Duration (ms)\": 135493.0, \"Valence\": 0.612, \"Chord\": \"A\"}, {\"Index\": 1413, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Confirmation\", \"Streams\": 6520106, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"60brXKLTC15vK0av5gIldm\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.438, \"Energy\": 0.315, \"Loudness\": -8.186, \"Speechiness\": 0.0375, \"Acousticness\": 0.608, \"Liveness\": 0.151, \"Tempo\": 190.064, \"Duration (ms)\": 170587.0, \"Valence\": 0.449, \"Chord\": \"G#/Ab\"}, {\"Index\": 1414, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Mios mit Bars\", \"Streams\": 6341141, \"Artist\": \"Luciano\", \"Artist Followers\": 942380.0, \"Song ID\": \"7Ek9e3eIuktIFjpDRQfmHE\", \"Genre\": \"['german drill', 'german hip hop']\", \"Release Date\": \"2020-02-13\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 57.0, \"Danceability\": 0.677, \"Energy\": 0.633, \"Loudness\": -7.353, \"Speechiness\": 0.0467, \"Acousticness\": 0.111, \"Liveness\": 0.217, \"Tempo\": 145.012, \"Duration (ms)\": 232147.0, \"Valence\": 0.404, \"Chord\": \"A\"}, {\"Index\": 1415, \"Highest Charting Position\": 135, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"E.T.A.\", \"Streams\": 6008945, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6PzOPrXx8tJEqace76yrv2\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.465, \"Energy\": 0.494, \"Loudness\": -7.595, \"Speechiness\": 0.066, \"Acousticness\": 0.49, \"Liveness\": 0.127, \"Tempo\": 127.298, \"Duration (ms)\": 176733.0, \"Valence\": 0.457, \"Chord\": \"E\"}, {\"Index\": 1416, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Borderline\", \"Streams\": 5921044, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"5hM5arv9KDbCHS0k9uqwjr\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 77.0, \"Danceability\": 0.621, \"Energy\": 0.873, \"Loudness\": -3.067, \"Speechiness\": 0.0369, \"Acousticness\": 0.0406, \"Liveness\": 0.0824, \"Tempo\": 97.96, \"Duration (ms)\": 237800.0, \"Valence\": 0.873, \"Chord\": \"F\"}, {\"Index\": 1417, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Take It Out On Me\", \"Streams\": 5858768, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"39nTNk5MfyiiRupTwn1iyC\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 54.0, \"Danceability\": 0.772, \"Energy\": 0.616, \"Loudness\": -4.673, \"Speechiness\": 0.102, \"Acousticness\": 0.00337, \"Liveness\": 0.104, \"Tempo\": 129.967, \"Duration (ms)\": 178013.0, \"Valence\": 0.279, \"Chord\": \"G\"}, {\"Index\": 1418, \"Highest Charting Position\": 67, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"No Shame\", \"Streams\": 5835260, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"5EbidH3lGB30WuDsoR4km6\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 62.0, \"Danceability\": 0.576, \"Energy\": 0.807, \"Loudness\": -3.019, \"Speechiness\": 0.0374, \"Acousticness\": 0.0185, \"Liveness\": 0.0963, \"Tempo\": 90.932, \"Duration (ms)\": 192737.0, \"Valence\": 0.479, \"Chord\": \"G\"}, {\"Index\": 1419, \"Highest Charting Position\": 160, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Might Not Give Up (feat. Young Thug)\", \"Streams\": 5503902, \"Artist\": \"A Boogie Wit da Hoodie\", \"Artist Followers\": 5865895.0, \"Song ID\": \"4l2rsMfr20dj6nf6i6F3Y8\", \"Genre\": \"['melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 57.0, \"Danceability\": 0.687, \"Energy\": 0.592, \"Loudness\": -6.378, \"Speechiness\": 0.224, \"Acousticness\": 0.203, \"Liveness\": 0.279, \"Tempo\": 178.83, \"Duration (ms)\": 225266.0, \"Valence\": 0.246, \"Chord\": \"D\"}, {\"Index\": 1420, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"That's What Love Is\", \"Streams\": 5440037, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2hLu8L8SNfCN4yKyPdX0h3\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 59.0, \"Danceability\": 0.639, \"Energy\": 0.437, \"Loudness\": -6.959, \"Speechiness\": 0.0355, \"Acousticness\": 0.692, \"Liveness\": 0.12, \"Tempo\": 147.575, \"Duration (ms)\": 165120.0, \"Valence\": 0.751, \"Chord\": \"A\"}, {\"Index\": 1421, \"Highest Charting Position\": 80, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Forever Yours - Avicii Tribute\", \"Streams\": 5421905, \"Artist\": \"Kygo, Sandro Cavazza\", \"Artist Followers\": 1251372.0, \"Song ID\": \"418ohXmKnlngIosIn6gG0H\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-10\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 15.0, \"Danceability\": 0.53, \"Energy\": 0.612, \"Loudness\": -8.794, \"Speechiness\": 0.0518, \"Acousticness\": 0.253, \"Liveness\": 0.246, \"Tempo\": 119.255, \"Duration (ms)\": 193847.0, \"Valence\": 0.433, \"Chord\": \"A#/Bb\"}, {\"Index\": 1422, \"Highest Charting Position\": 68, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Baby\", \"Streams\": 5376451, \"Artist\": \"Joker Bra, VIZE\", \"Artist Followers\": 191521.0, \"Song ID\": \"1V7JaMp11LKGwKiVmSetf0\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-01-30\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 63.0, \"Danceability\": 0.771, \"Energy\": 0.921, \"Loudness\": -4.228, \"Speechiness\": 0.109, \"Acousticness\": 0.166, \"Liveness\": 0.119, \"Tempo\": 128.021, \"Duration (ms)\": 148125.0, \"Valence\": 0.56, \"Chord\": \"C#/Db\"}, {\"Index\": 1423, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"One More Year\", \"Streams\": 5279739, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"5ozqshq2dtU7SYCpCBu0NE\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 56.0, \"Danceability\": 0.602, \"Energy\": 0.88, \"Loudness\": -5.414, \"Speechiness\": 0.0354, \"Acousticness\": 0.057, \"Liveness\": 0.284, \"Tempo\": 114.009, \"Duration (ms)\": 324013.0, \"Valence\": 0.493, \"Chord\": \"C#/Db\"}, {\"Index\": 1424, \"Highest Charting Position\": 14, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Good News\", \"Streams\": 5210780, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"1DWZUa5Mzf2BwzpHtgbHPY\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 75.0, \"Danceability\": 0.794, \"Energy\": 0.32, \"Loudness\": -12.92, \"Speechiness\": 0.173, \"Acousticness\": 0.853, \"Liveness\": 0.112, \"Tempo\": 174.088, \"Duration (ms)\": 342040.0, \"Valence\": 0.241, \"Chord\": \"C#/Db\"}, {\"Index\": 1425, \"Highest Charting Position\": 141, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"wish you were gay\", \"Streams\": 5187997, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"3Fj47GNK2kUF0uaEDgXLaD\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-03-29\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.853, \"Energy\": 0.351, \"Loudness\": -10.198, \"Speechiness\": 0.241, \"Acousticness\": 0.39, \"Liveness\": 0.752, \"Tempo\": 118.028, \"Duration (ms)\": 221543.0, \"Valence\": 0.282, \"Chord\": \"G\"}, {\"Index\": 1426, \"Highest Charting Position\": 61, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Only The Young - Featured in Miss Americana\", \"Streams\": 5111068, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2slqvGLwzZZYsT4K4Y1GBC\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 63.0, \"Danceability\": 0.56, \"Energy\": 0.78, \"Loudness\": -4.895, \"Speechiness\": 0.0517, \"Acousticness\": 0.00244, \"Liveness\": 0.0714, \"Tempo\": 93.516, \"Duration (ms)\": 157507.0, \"Valence\": 0.602, \"Chord\": \"F\"}, {\"Index\": 1427, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Lost In Yesterday\", \"Streams\": 5096624, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"5JWPUEov2wlX7c0jhYZpeB\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 69.0, \"Danceability\": 0.569, \"Energy\": 0.84, \"Loudness\": -4.123, \"Speechiness\": 0.118, \"Acousticness\": 0.0295, \"Liveness\": 0.0995, \"Tempo\": 183.059, \"Duration (ms)\": 249587.0, \"Valence\": 0.749, \"Chord\": \"C#/Db\"}, {\"Index\": 1428, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"At Least For Now\", \"Streams\": 5033764, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6VLkgf5YmLixsabdqiCVGU\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 54.0, \"Danceability\": 0.375, \"Energy\": 0.304, \"Loudness\": -9.897, \"Speechiness\": 0.0325, \"Acousticness\": 0.683, \"Liveness\": 0.196, \"Tempo\": 83.832, \"Duration (ms)\": 149653.0, \"Valence\": 0.295, \"Chord\": \"A\"}, {\"Index\": 1429, \"Highest Charting Position\": 167, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"you should see me in a crown\", \"Streams\": 4988054, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6WbvBhwCaUuYHcHGEuVgqo\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 0.0, \"Danceability\": 0.683, \"Energy\": 0.534, \"Loudness\": -10.348, \"Speechiness\": 0.189, \"Acousticness\": 0.519, \"Liveness\": 0.148, \"Tempo\": 150.469, \"Duration (ms)\": 180567.0, \"Valence\": 0.284, \"Chord\": \"E\"}, {\"Index\": 1430, \"Highest Charting Position\": 186, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Too Good At Goodbyes\", \"Streams\": 4984764, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"3VlbOrM6nYPprVvzBZllE5\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2017-11-03\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 72.0, \"Danceability\": 0.681, \"Energy\": 0.372, \"Loudness\": -8.237, \"Speechiness\": 0.0432, \"Acousticness\": 0.64, \"Liveness\": 0.169, \"Tempo\": 91.873, \"Duration (ms)\": 201000.0, \"Valence\": 0.476, \"Chord\": \"F\"}, {\"Index\": 1431, \"Highest Charting Position\": 7, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Intentions\", \"Streams\": 28509534, \"Artist\": \"Justin Bieber, Quavo\", \"Artist Followers\": 48544923.0, \"Song ID\": \"4umIPjkehX1r7uhmGvXiSV\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-07--2020-02-14\", \"Popularity\": 77.0, \"Danceability\": 0.806, \"Energy\": 0.546, \"Loudness\": -6.637, \"Speechiness\": 0.0575, \"Acousticness\": 0.3, \"Liveness\": 0.102, \"Tempo\": 147.986, \"Duration (ms)\": 212867.0, \"Valence\": 0.874, \"Chord\": \"A\"}, {\"Index\": 1432, \"Highest Charting Position\": 105, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Yikes\", \"Streams\": 6561188, \"Artist\": \"Nicki Minaj\", \"Artist Followers\": 22170982.0, \"Song ID\": \"75dLEqanQTupF3dtP9exT5\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'pop rap', 'post-teen pop', 'queens hip hop']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-02-07--2020-02-14\", \"Popularity\": 70.0, \"Danceability\": 0.911, \"Energy\": 0.637, \"Loudness\": -8.381, \"Speechiness\": 0.447, \"Acousticness\": 0.0409, \"Liveness\": 0.238, \"Tempo\": 149.996, \"Duration (ms)\": 156882.0, \"Valence\": 0.66, \"Chord\": \"G#/Ab\"}, {\"Index\": 1433, \"Highest Charting Position\": 66, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Yellow Hearts\", \"Streams\": 6554824, \"Artist\": \"Ant Saunders\", \"Artist Followers\": 82522.0, \"Song ID\": \"2W4yABdLc4Jnds67Poi5Nl\", \"Genre\": \"['chill r&b', 'pop']\", \"Release Date\": \"2019-06-18\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.866, \"Energy\": 0.438, \"Loudness\": -8.943, \"Speechiness\": 0.0719, \"Acousticness\": 0.177, \"Liveness\": 0.0743, \"Tempo\": 129.039, \"Duration (ms)\": 223258.0, \"Valence\": 0.695, \"Chord\": \"G\"}, {\"Index\": 1434, \"Highest Charting Position\": 120, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Birthday\", \"Streams\": 6207326, \"Artist\": \"Anne-Marie\", \"Artist Followers\": 8153871.0, \"Song ID\": \"5hff5RQeE84pznOt8WEWeO\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-02-07--2020-02-14\", \"Popularity\": 65.0, \"Danceability\": 0.609, \"Energy\": 0.785, \"Loudness\": -3.32, \"Speechiness\": 0.0891, \"Acousticness\": 0.0502, \"Liveness\": 0.171, \"Tempo\": 151.995, \"Duration (ms)\": 181467.0, \"Valence\": 0.756, \"Chord\": \"B\"}, {\"Index\": 1435, \"Highest Charting Position\": 16, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"HIGHEST IN THE ROOM (feat. ROSAL\\u00cdA & Lil Baby) - REMIX\", \"Streams\": 6107499, \"Artist\": \"Travis Scott\", \"Artist Followers\": 437907.0, \"Song ID\": \"7h0d2h0fUmzbs7zeFigJPn\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.559, \"Energy\": 0.491, \"Loudness\": -6.406, \"Speechiness\": 0.0346, \"Acousticness\": 0.0567, \"Liveness\": 0.0992, \"Tempo\": 153.131, \"Duration (ms)\": 244874.0, \"Valence\": 0.114, \"Chord\": \"D\"}, {\"Index\": 1436, \"Highest Charting Position\": 65, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Good as Hell (feat. Ariana Grande) - Remix\", \"Streams\": 6066001, \"Artist\": \"Lizzo\", \"Artist Followers\": 3991674.0, \"Song ID\": \"07Oz5StQ7GRoygNLaXs2pd\", \"Genre\": \"['dance pop', 'escape room', 'minnesota hip hop', 'pop', 'pop rap', 'post-teen pop', 'trap queen']\", \"Release Date\": \"2016\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.668, \"Energy\": 0.892, \"Loudness\": -3.001, \"Speechiness\": 0.0645, \"Acousticness\": 0.298, \"Liveness\": 0.735, \"Tempo\": 95.927, \"Duration (ms)\": 159011.0, \"Valence\": 0.478, \"Chord\": \"F\"}, {\"Index\": 1437, \"Highest Charting Position\": 70, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"I Do It (ft. Big Sean, Lil Baby)\", \"Streams\": 5561205, \"Artist\": \"Lil Wayne\", \"Artist Followers\": 10710088.0, \"Song ID\": \"1bRO28yzxgO3y3UmNR29TZ\", \"Genre\": \"['hip hop', 'new orleans rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 60.0, \"Danceability\": 0.804, \"Energy\": 0.528, \"Loudness\": -3.231, \"Speechiness\": 0.378, \"Acousticness\": 0.125, \"Liveness\": 0.41, \"Tempo\": 138.005, \"Duration (ms)\": 184440.0, \"Valence\": 0.321, \"Chord\": \"C#/Db\"}, {\"Index\": 1438, \"Highest Charting Position\": 45, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Get Me\", \"Streams\": 5236560, \"Artist\": \"Justin Bieber, Kehlani\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5VwwpU7KsLhgfbMEecedhJ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 61.0, \"Danceability\": 0.832, \"Energy\": 0.508, \"Loudness\": -6.913, \"Speechiness\": 0.149, \"Acousticness\": 0.0492, \"Liveness\": 0.107, \"Tempo\": 109.352, \"Duration (ms)\": 185427.0, \"Valence\": 0.75, \"Chord\": \"F#/Gb\"}, {\"Index\": 1439, \"Highest Charting Position\": 95, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Yo x Ti, Tu x Mi\", \"Streams\": 5202210, \"Artist\": \"ROSAL\\u00cdA, Ozuna\", \"Artist Followers\": 4769627.0, \"Song ID\": \"7BlBVFwvbWvcwNcUarQmjk\", \"Genre\": \"['r&b en espanol']\", \"Release Date\": \"2019-08-15\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.78, \"Energy\": 0.759, \"Loudness\": -3.292, \"Speechiness\": 0.225, \"Acousticness\": 0.462, \"Liveness\": 0.143, \"Tempo\": 91.952, \"Duration (ms)\": 201040.0, \"Valence\": 0.579, \"Chord\": \"C#/Db\"}, {\"Index\": 1440, \"Highest Charting Position\": 161, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"DJ No Pare (feat. Zion, Dalex, Lenny Tav\\u00e1rez) - Remix\", \"Streams\": 5148516, \"Artist\": \"Justin Quiles, Natti Natasha, Farruko\", \"Artist Followers\": 2897862.0, \"Song ID\": \"1ndyl3wJCFs872XZ3ztPk6\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.743, \"Energy\": 0.709, \"Loudness\": -3.922, \"Speechiness\": 0.0879, \"Acousticness\": 0.0451, \"Liveness\": 0.0809, \"Tempo\": 170.001, \"Duration (ms)\": 258600.0, \"Valence\": 0.831, \"Chord\": \"D#/Eb\"}, {\"Index\": 1441, \"Highest Charting Position\": 160, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"EARFQUAKE\", \"Streams\": 5079657, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6782693.0, \"Song ID\": \"5hVghJ4KaYES3BFUATCYn0\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 79.0, \"Danceability\": 0.554, \"Energy\": 0.498, \"Loudness\": -8.866, \"Speechiness\": 0.0685, \"Acousticness\": 0.23, \"Liveness\": 0.795, \"Tempo\": 79.635, \"Duration (ms)\": 190067.0, \"Valence\": 0.413, \"Chord\": \"A\"}, {\"Index\": 1442, \"Highest Charting Position\": 157, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Pa' Olvidarme De Ella\", \"Streams\": 5066711, \"Artist\": \"Piso 21, Christian Nodal\", \"Artist Followers\": 7226268.0, \"Song ID\": \"1cVlW9WQiGlFdWUXFdFZGh\", \"Genre\": \"['colombian pop', 'latin', 'latin pop', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.728, \"Energy\": 0.542, \"Loudness\": -5.195, \"Speechiness\": 0.0514, \"Acousticness\": 0.259, \"Liveness\": 0.136, \"Tempo\": 90.016, \"Duration (ms)\": 227234.0, \"Valence\": 0.637, \"Chord\": \"C\"}, {\"Index\": 1443, \"Highest Charting Position\": 89, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Loco Contigo (feat. J. Balvin & Tyga)\", \"Streams\": 5013732, \"Artist\": \"DJ Snake, J Balvin\", \"Artist Followers\": 7408249.0, \"Song ID\": \"6osaMSJh9NguagEDQcZaKx\", \"Genre\": \"['dance pop', 'edm', 'electronic trap', 'pop', 'pop dance']\", \"Release Date\": \"2019-07-25\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.694, \"Energy\": 0.758, \"Loudness\": -2.986, \"Speechiness\": 0.218, \"Acousticness\": 0.278, \"Liveness\": 0.102, \"Tempo\": 192.091, \"Duration (ms)\": 185195.0, \"Valence\": 0.371, \"Chord\": \"B\"}, {\"Index\": 1444, \"Highest Charting Position\": 54, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Psycho\", \"Streams\": 4991751, \"Artist\": \"Red Velvet\", \"Artist Followers\": 5688315.0, \"Song ID\": \"3CYH422oy1cZNoo0GTG1TK\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2019-12-23\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.664, \"Energy\": 0.666, \"Loudness\": -2.203, \"Speechiness\": 0.0446, \"Acousticness\": 0.193, \"Liveness\": 0.0854, \"Tempo\": 139.987, \"Duration (ms)\": 210560.0, \"Valence\": 0.405, \"Chord\": \"G#/Ab\"}, {\"Index\": 1445, \"Highest Charting Position\": 113, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Suge\", \"Streams\": 4986299, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"2gwkD6igEhQbDQegRCcdoB\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-03-01\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.876, \"Energy\": 0.662, \"Loudness\": -6.482, \"Speechiness\": 0.426, \"Acousticness\": 0.0608, \"Liveness\": 0.127, \"Tempo\": 75.445, \"Duration (ms)\": 163320.0, \"Valence\": 0.844, \"Chord\": \"D\"}, {\"Index\": 1446, \"Highest Charting Position\": 101, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Con Altura\", \"Streams\": 4961249, \"Artist\": \"ROSAL\\u00cdA, J Balvin, El Guincho\", \"Artist Followers\": 4769627.0, \"Song ID\": \"2qG5sZ7Si6sdK74qLxedYM\", \"Genre\": \"['r&b en espanol']\", \"Release Date\": \"2019-03-28\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.882, \"Energy\": 0.689, \"Loudness\": -4.027, \"Speechiness\": 0.124, \"Acousticness\": 0.39, \"Liveness\": 0.0501, \"Tempo\": 97.963, \"Duration (ms)\": 161627.0, \"Valence\": 0.746, \"Chord\": \"F#/Gb\"}, {\"Index\": 1447, \"Highest Charting Position\": 140, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Only Human\", \"Streams\": 4953866, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"0DiDStADDVh3SvAsoJAFMk\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-06-07\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.795, \"Energy\": 0.496, \"Loudness\": -5.883, \"Speechiness\": 0.0722, \"Acousticness\": 0.108, \"Liveness\": 0.0645, \"Tempo\": 94.01, \"Duration (ms)\": 183000.0, \"Valence\": 0.874, \"Chord\": \"C\"}, {\"Index\": 1448, \"Highest Charting Position\": 51, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Eleven\", \"Streams\": 4947780, \"Artist\": \"Khalid\", \"Artist Followers\": 14190858.0, \"Song ID\": \"18O00Y7yrkJ0pRXm1n21Og\", \"Genre\": \"['pop']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 68.0, \"Danceability\": 0.679, \"Energy\": 0.408, \"Loudness\": -9.754, \"Speechiness\": 0.0882, \"Acousticness\": 0.133, \"Liveness\": 0.23, \"Tempo\": 129.079, \"Duration (ms)\": 206080.0, \"Valence\": 0.151, \"Chord\": \"E\"}, {\"Index\": 1449, \"Highest Charting Position\": 135, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Talk (feat. Disclosure)\", \"Streams\": 4940984, \"Artist\": \"Khalid\", \"Artist Followers\": 14190858.0, \"Song ID\": \"6TqXcAFInzjp0bODyvrWEq\", \"Genre\": \"['pop']\", \"Release Date\": \"2019-04-05\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.9, \"Energy\": 0.4, \"Loudness\": -8.575, \"Speechiness\": 0.127, \"Acousticness\": 0.0516, \"Liveness\": 0.0599, \"Tempo\": 135.984, \"Duration (ms)\": 197573.0, \"Valence\": 0.346, \"Chord\": \"C\"}, {\"Index\": 1450, \"Highest Charting Position\": 117, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Hot (Remix) [feat. Gunna and Travis Scott]\", \"Streams\": 4905155, \"Artist\": \"Travis Scott, Young Thug\", \"Artist Followers\": 3337982.0, \"Song ID\": \"56AMYGJzxBO6p8v0wEe9de\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-11-01\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.845, \"Energy\": 0.631, \"Loudness\": -8.206, \"Speechiness\": 0.216, \"Acousticness\": 0.188, \"Liveness\": 0.0806, \"Tempo\": 111.983, \"Duration (ms)\": 279907.0, \"Valence\": 0.545, \"Chord\": \"G\"}, {\"Index\": 1451, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Weiss\", \"Streams\": 4872077, \"Artist\": \"Samra\", \"Artist Followers\": 1045091.0, \"Song ID\": \"38YP1STiBe3AZevFFJILf4\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-02-07--2020-02-14\", \"Popularity\": 56.0, \"Danceability\": 0.6, \"Energy\": 0.525, \"Loudness\": -6.585, \"Speechiness\": 0.423, \"Acousticness\": 0.393, \"Liveness\": 0.111, \"Tempo\": 96.989, \"Duration (ms)\": 162702.0, \"Valence\": 0.436, \"Chord\": \"D\"}, {\"Index\": 1452, \"Highest Charting Position\": 105, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Con Calma\", \"Streams\": 4861378, \"Artist\": \"Daddy Yankee, Snow\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3GIhMWNecxw8GyCFwviF6v\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 3.0, \"Danceability\": 0.737, \"Energy\": 0.86, \"Loudness\": -2.652, \"Speechiness\": 0.0594, \"Acousticness\": 0.11, \"Liveness\": 0.0574, \"Tempo\": 93.989, \"Duration (ms)\": 193227.0, \"Valence\": 0.656, \"Chord\": \"G#/Ab\"}, {\"Index\": 1453, \"Highest Charting Position\": 148, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"MIDDLE CHILD\", \"Streams\": 4836113, \"Artist\": \"J. Cole\", \"Artist Followers\": 14103694.0, \"Song ID\": \"2JvzF1RMd7lE3KmFlsyZD8\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2019-01-23\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.837, \"Energy\": 0.364, \"Loudness\": -11.713, \"Speechiness\": 0.276, \"Acousticness\": 0.149, \"Liveness\": 0.271, \"Tempo\": 123.984, \"Duration (ms)\": 213594.0, \"Valence\": 0.463, \"Chord\": \"G#/Ab\"}, {\"Index\": 1454, \"Highest Charting Position\": 136, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Otro Trago - Remix\", \"Streams\": 4803294, \"Artist\": \"Sech, Ozuna, Anuel AA, Darell, Nicky Jam\", \"Artist Followers\": 8766508.0, \"Song ID\": \"4bTZeO72FwMa6wKOiqoynL\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-07-26\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.725, \"Energy\": 0.79, \"Loudness\": -2.331, \"Speechiness\": 0.197, \"Acousticness\": 0.0711, \"Liveness\": 0.0602, \"Tempo\": 175.988, \"Duration (ms)\": 287773.0, \"Valence\": 0.763, \"Chord\": \"C\"}, {\"Index\": 1455, \"Highest Charting Position\": 113, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"FML\", \"Streams\": 6350496, \"Artist\": \"Arizona Zervas\", \"Artist Followers\": 621200.0, \"Song ID\": \"6lruHh1jF7ezgbLv72xYmf\", \"Genre\": \"['pop rap', 'rhode island rap']\", \"Release Date\": \"2018-06-03\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 74.0, \"Danceability\": 0.822, \"Energy\": 0.575, \"Loudness\": -5.95, \"Speechiness\": 0.0934, \"Acousticness\": 0.113, \"Liveness\": 0.106, \"Tempo\": 100.087, \"Duration (ms)\": 223000.0, \"Valence\": 0.616, \"Chord\": \"F\"}, {\"Index\": 1456, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"King Of My City\", \"Streams\": 5922748, \"Artist\": \"A Boogie Wit da Hoodie\", \"Artist Followers\": 1251372.0, \"Song ID\": \"4JEz0Iz8PnzHe5B0CkYSjP\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 0.0, \"Danceability\": 0.679, \"Energy\": 0.679, \"Loudness\": -6.747, \"Speechiness\": 0.167, \"Acousticness\": 0.443, \"Liveness\": 0.153, \"Tempo\": 119.921, \"Duration (ms)\": 148676.0, \"Valence\": 0.245, \"Chord\": \"E\"}, {\"Index\": 1457, \"Highest Charting Position\": 22, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Those Kinda Nights (feat. Ed Sheeran)\", \"Streams\": 5823422, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"0VSzREd1OjEWJ9tXoFHRQH\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 66.0, \"Danceability\": 0.794, \"Energy\": 0.637, \"Loudness\": -6.29, \"Speechiness\": 0.339, \"Acousticness\": 0.028, \"Liveness\": 0.0919, \"Tempo\": 103.868, \"Duration (ms)\": 177693.0, \"Valence\": 0.393, \"Chord\": \"E\"}, {\"Index\": 1458, \"Highest Charting Position\": 136, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Mon Ami\", \"Streams\": 5774770, \"Artist\": \"Samra\", \"Artist Followers\": 1045091.0, \"Song ID\": \"1R4xkZXQUQ8QJtAdwHkSgC\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-01-29\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 53.0, \"Danceability\": 0.801, \"Energy\": 0.731, \"Loudness\": -3.723, \"Speechiness\": 0.383, \"Acousticness\": 0.188, \"Liveness\": 0.111, \"Tempo\": 105.666, \"Duration (ms)\": 138409.0, \"Valence\": 0.537, \"Chord\": \"G#/Ab\"}, {\"Index\": 1459, \"Highest Charting Position\": 120, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Break My Stride\", \"Streams\": 5312936, \"Artist\": \"Matthew Wilder\", \"Artist Followers\": 30386.0, \"Song ID\": \"1mCsF9Tw4AkIZOjvZbZZdT\", \"Genre\": \"['new wave pop']\", \"Release Date\": \"1983-03-19\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 73.0, \"Danceability\": 0.917, \"Energy\": 0.588, \"Loudness\": -11.047, \"Speechiness\": 0.0607, \"Acousticness\": 0.195, \"Liveness\": 0.0914, \"Tempo\": 110.077, \"Duration (ms)\": 184480.0, \"Valence\": 0.828, \"Chord\": \"A#/Bb\"}, {\"Index\": 1460, \"Highest Charting Position\": 76, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Kein Wort\", \"Streams\": 5208651, \"Artist\": \"Juju, Loredana, Miksu / Macloud\", \"Artist Followers\": 486474.0, \"Song ID\": \"1hoLUVBx0ixX3kn0EX0P5n\", \"Genre\": \"['frauenrap', 'german hip hop', 'german pop']\", \"Release Date\": \"2020-01-16\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.746, \"Energy\": 0.592, \"Loudness\": -6.861, \"Speechiness\": 0.0914, \"Acousticness\": 0.462, \"Liveness\": 0.187, \"Tempo\": 160.065, \"Duration (ms)\": 162094.0, \"Valence\": 0.629, \"Chord\": \"F#/Gb\"}, {\"Index\": 1461, \"Highest Charting Position\": 86, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Graveyard\", \"Streams\": 5044853, \"Artist\": \"Halsey\", \"Artist Followers\": 15663384.0, \"Song ID\": \"2ufmtcIFdFpuUYBPXK5f67\", \"Genre\": \"['dance pop', 'electropop', 'etherpop', 'indie poptimism', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.667, \"Energy\": 0.583, \"Loudness\": -5.127, \"Speechiness\": 0.0747, \"Acousticness\": 0.231, \"Liveness\": 0.181, \"Tempo\": 92.043, \"Duration (ms)\": 181806.0, \"Valence\": 0.187, \"Chord\": \"B\"}, {\"Index\": 1462, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Wake Up Call (feat. Trippie Redd)\", \"Streams\": 5029979, \"Artist\": \"KSI\", \"Artist Followers\": 2010879.0, \"Song ID\": \"5MYzajZVxBaPT2JUSRa99L\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2020-01-27\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 56.0, \"Danceability\": 0.642, \"Energy\": 0.669, \"Loudness\": -5.774, \"Speechiness\": 0.0486, \"Acousticness\": 0.318, \"Liveness\": 0.119, \"Tempo\": 156.084, \"Duration (ms)\": 175067.0, \"Valence\": 0.227, \"Chord\": \"F#/Gb\"}, {\"Index\": 1463, \"Highest Charting Position\": 131, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Turn Me On (feat. Vula)\", \"Streams\": 4925843, \"Artist\": \"Riton, Oliver Heldens\", \"Artist Followers\": 83743.0, \"Song ID\": \"0qaWEvPkts34WF68r8Dzx9\", \"Genre\": \"['dance pop', 'house', 'pop dance', 'tropical house', 'uk dance']\", \"Release Date\": \"2019-09-13\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.737, \"Energy\": 0.828, \"Loudness\": -4.711, \"Speechiness\": 0.0396, \"Acousticness\": 0.0149, \"Liveness\": 0.0862, \"Tempo\": 124.051, \"Duration (ms)\": 208474.0, \"Valence\": 0.517, \"Chord\": \"B\"}, {\"Index\": 1464, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Hips Don't Lie (feat. Wyclef Jean)\", \"Streams\": 4918636, \"Artist\": \"Shakira\", \"Artist Followers\": 22136717.0, \"Song ID\": \"3ZFTkvIE7kyPt6Nu3PEa7V\", \"Genre\": \"['colombian pop', 'dance pop', 'latin', 'latin pop', 'pop']\", \"Release Date\": \"2005-11-28\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 83.0, \"Danceability\": 0.778, \"Energy\": 0.824, \"Loudness\": -5.892, \"Speechiness\": 0.0707, \"Acousticness\": 0.284, \"Liveness\": 0.405, \"Tempo\": 100.024, \"Duration (ms)\": 218093.0, \"Valence\": 0.758, \"Chord\": \"A#/Bb\"}, {\"Index\": 1465, \"Highest Charting Position\": 106, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Liar\", \"Streams\": 4896939, \"Artist\": \"Camila Cabello\", \"Artist Followers\": 22698747.0, \"Song ID\": \"7LzouaWGFCy4tkXDOOnEyM\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-09-04\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 69.0, \"Danceability\": 0.74, \"Energy\": 0.498, \"Loudness\": -6.684, \"Speechiness\": 0.0456, \"Acousticness\": 0.0169, \"Liveness\": 0.319, \"Tempo\": 98.016, \"Duration (ms)\": 207039.0, \"Valence\": 0.652, \"Chord\": \"B\"}, {\"Index\": 1466, \"Highest Charting Position\": 191, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Going Bad (feat. Drake)\", \"Streams\": 4889500, \"Artist\": \"Meek Mill\", \"Artist Followers\": 5241145.0, \"Song ID\": \"2IRZnDFmlqMuOrYOLnZZyc\", \"Genre\": \"['hip hop', 'philly rap', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2018-11-30\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.889, \"Energy\": 0.496, \"Loudness\": -6.365, \"Speechiness\": 0.0905, \"Acousticness\": 0.259, \"Liveness\": 0.252, \"Tempo\": 86.003, \"Duration (ms)\": 180522.0, \"Valence\": 0.544, \"Chord\": \"E\"}, {\"Index\": 1467, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"ME! (feat. Brendon Urie of Panic! At The Disco)\", \"Streams\": 4884909, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2Rk4JlNc2TPmZe2af99d45\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 77.0, \"Danceability\": 0.61, \"Energy\": 0.83, \"Loudness\": -4.105, \"Speechiness\": 0.0571, \"Acousticness\": 0.033, \"Liveness\": 0.118, \"Tempo\": 182.162, \"Duration (ms)\": 193000.0, \"Valence\": 0.728, \"Chord\": \"C\"}, {\"Index\": 1468, \"Highest Charting Position\": 134, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Panini\", \"Streams\": 4867723, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5488666.0, \"Song ID\": \"1000nHvUdawXuUHgBod4Wv\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2019-09-13\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.703, \"Energy\": 0.594, \"Loudness\": -6.146, \"Speechiness\": 0.0752, \"Acousticness\": 0.342, \"Liveness\": 0.123, \"Tempo\": 153.848, \"Duration (ms)\": 114893.0, \"Valence\": 0.475, \"Chord\": \"F\"}, {\"Index\": 1469, \"Highest Charting Position\": 191, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"idontwannabeyouanymore\", \"Streams\": 4824483, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"41zXlQxzTi6cGAjpOXyLYH\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2017-12-22\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 78.0, \"Danceability\": 0.483, \"Energy\": 0.412, \"Loudness\": -8.461, \"Speechiness\": 0.0402, \"Acousticness\": 0.737, \"Liveness\": 0.116, \"Tempo\": 170.163, \"Duration (ms)\": 203569.0, \"Valence\": 0.247, \"Chord\": \"G\"}, {\"Index\": 1470, \"Highest Charting Position\": 158, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"The London (feat. J. Cole & Travis Scott)\", \"Streams\": 4791732, \"Artist\": \"J. Cole, Young Thug\", \"Artist Followers\": 6383275.0, \"Song ID\": \"7DcvwMAiqKJQD1rrdfxSDx\", \"Genre\": \"['atl hip hop', 'atl trap', 'gangster rap', 'hip hop', 'melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2019-05-23\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.796, \"Energy\": 0.586, \"Loudness\": -6.946, \"Speechiness\": 0.147, \"Acousticness\": 0.0247, \"Liveness\": 0.132, \"Tempo\": 97.981, \"Duration (ms)\": 200107.0, \"Valence\": 0.179, \"Chord\": \"E\"}, {\"Index\": 1471, \"Highest Charting Position\": 123, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"223's (feat. 9lokknine)\", \"Streams\": 4781697, \"Artist\": \"YNW Melly\", \"Artist Followers\": 6332535.0, \"Song ID\": \"4sjiIpEv617LDXaidKioOI\", \"Genre\": \"['melodic rap', 'trap']\", \"Release Date\": \"2019-08-09\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.932, \"Energy\": 0.547, \"Loudness\": -7.787, \"Speechiness\": 0.333, \"Acousticness\": 0.0388, \"Liveness\": 0.0924, \"Tempo\": 94.998, \"Duration (ms)\": 176640.0, \"Valence\": 0.695, \"Chord\": \"C\"}, {\"Index\": 1472, \"Highest Charting Position\": 26, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Darkness\", \"Streams\": 7618955, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5SiZJoLXp3WOl3J4C8IK0d\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 65.0, \"Danceability\": 0.671, \"Energy\": 0.623, \"Loudness\": -7.161, \"Speechiness\": 0.308, \"Acousticness\": 0.00998, \"Liveness\": 0.643, \"Tempo\": 75.055, \"Duration (ms)\": 337147.0, \"Valence\": 0.195, \"Chord\": \"D\"}, {\"Index\": 1473, \"Highest Charting Position\": 30, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"You Gon\\u2019 Learn (feat. Royce Da 5'9\\\" & White Gold)\", \"Streams\": 7157402, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"0GQ5bFTVFFKpwNPc7KwQnB\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 66.0, \"Danceability\": 0.68, \"Energy\": 0.82, \"Loudness\": -4.197, \"Speechiness\": 0.151, \"Acousticness\": 0.0614, \"Liveness\": 0.597, \"Tempo\": 140.033, \"Duration (ms)\": 234653.0, \"Valence\": 0.243, \"Chord\": \"E\"}, {\"Index\": 1474, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Blue World\", \"Streams\": 7060589, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"2hwOoMtWPtTSSn6WHV7Vp5\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 75.0, \"Danceability\": 0.742, \"Energy\": 0.553, \"Loudness\": -8.98, \"Speechiness\": 0.419, \"Acousticness\": 0.389, \"Liveness\": 0.0694, \"Tempo\": 84.931, \"Duration (ms)\": 209440.0, \"Valence\": 0.508, \"Chord\": \"G#/Ab\"}, {\"Index\": 1475, \"Highest Charting Position\": 99, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Liberdade Provis\\u00f3ria\", \"Streams\": 6442626, \"Artist\": \"Henrique & Juliano\", \"Artist Followers\": 13312073.0, \"Song ID\": \"1vG3YuKRYqPwTmNmYgqkpg\", \"Genre\": \"['sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.668, \"Energy\": 0.684, \"Loudness\": -5.937, \"Speechiness\": 0.0527, \"Acousticness\": 0.627, \"Liveness\": 0.923, \"Tempo\": 108.138, \"Duration (ms)\": 187986.0, \"Valence\": 0.7, \"Chord\": \"C#/Db\"}, {\"Index\": 1476, \"Highest Charting Position\": 32, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Unaccommodating (feat. Young M.A)\", \"Streams\": 6374807, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"0q2vG0UVuy6ajjcpkQHdZM\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 65.0, \"Danceability\": 0.852, \"Energy\": 0.752, \"Loudness\": -5.793, \"Speechiness\": 0.0597, \"Acousticness\": 0.0169, \"Liveness\": 0.394, \"Tempo\": 89.95, \"Duration (ms)\": 216600.0, \"Valence\": 0.389, \"Chord\": \"C#/Db\"}, {\"Index\": 1477, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Donuts\", \"Streams\": 6113037, \"Artist\": \"Gzuz\", \"Artist Followers\": 1140383.0, \"Song ID\": \"5XVPNr0CAoUn1jD033Ucoo\", \"Genre\": \"['deep german hip hop', 'german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-02-13\", \"Weeks Charted\": \"2020-01-24--2020-01-31\", \"Popularity\": 62.0, \"Danceability\": 0.784, \"Energy\": 0.703, \"Loudness\": -7.491, \"Speechiness\": 0.236, \"Acousticness\": 0.0973, \"Liveness\": 0.0754, \"Tempo\": 141.035, \"Duration (ms)\": 162938.0, \"Valence\": 0.556, \"Chord\": \"B\"}, {\"Index\": 1478, \"Highest Charting Position\": 44, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Leaving Heaven (feat. Skylar Grey)\", \"Streams\": 5466161, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5CpsIb7SMFHjmAG8RvIWfq\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.661, \"Energy\": 0.748, \"Loudness\": -4.809, \"Speechiness\": 0.206, \"Acousticness\": 0.175, \"Liveness\": 0.254, \"Tempo\": 171.983, \"Duration (ms)\": 265947.0, \"Valence\": 0.509, \"Chord\": \"D\"}, {\"Index\": 1479, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Zu Ende\", \"Streams\": 5297101, \"Artist\": \"Samra, ELIF\", \"Artist Followers\": 1045091.0, \"Song ID\": \"0Vl4eICpXMjtiK0RhdaWov\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-01-23\", \"Weeks Charted\": \"2020-01-24--2020-01-31\", \"Popularity\": 57.0, \"Danceability\": 0.707, \"Energy\": 0.747, \"Loudness\": -5.212, \"Speechiness\": 0.279, \"Acousticness\": 0.307, \"Liveness\": 0.183, \"Tempo\": 80.025, \"Duration (ms)\": 197861.0, \"Valence\": 0.491, \"Chord\": \"G#/Ab\"}, {\"Index\": 1480, \"Highest Charting Position\": 171, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"B.I.T.C.H.\", \"Streams\": 5215211, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"06scTb0zbkxYNgpAB3J9fN\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-01-24\", \"Weeks Charted\": \"2020-01-24--2020-01-31\", \"Popularity\": 59.0, \"Danceability\": 0.742, \"Energy\": 0.731, \"Loudness\": -4.362, \"Speechiness\": 0.306, \"Acousticness\": 0.0851, \"Liveness\": 0.131, \"Tempo\": 174.019, \"Duration (ms)\": 183143.0, \"Valence\": 0.547, \"Chord\": \"B\"}, {\"Index\": 1481, \"Highest Charting Position\": 56, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Look At Her Now\", \"Streams\": 5066377, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 1251372.0, \"Song ID\": \"2XUPkAie1nz9SYIhbdIVWb\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.753, \"Energy\": 0.564, \"Loudness\": -7.908, \"Speechiness\": 0.251, \"Acousticness\": 0.114, \"Liveness\": 0.359, \"Tempo\": 77.341, \"Duration (ms)\": 162596.0, \"Valence\": 0.55, \"Chord\": \"A#/Bb\"}, {\"Index\": 1482, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Bi Sonraki Hayat\\u0131mda Gel\", \"Streams\": 5037967, \"Artist\": \"Murda, Ezhel\", \"Artist Followers\": 862965.0, \"Song ID\": \"5SYkeNpjhJPFUMOP5TK8iw\", \"Genre\": \"['basshall', 'turkish trap']\", \"Release Date\": \"2020-08-28\", \"Weeks Charted\": \"2020-01-24--2020-01-31\", \"Popularity\": 57.0, \"Danceability\": 0.933, \"Energy\": 0.448, \"Loudness\": -4.491, \"Speechiness\": 0.136, \"Acousticness\": 0.0253, \"Liveness\": 0.104, \"Tempo\": 103.981, \"Duration (ms)\": 167350.0, \"Valence\": 0.737, \"Chord\": \"G#/Ab\"}, {\"Index\": 1483, \"Highest Charting Position\": 126, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Legends\", \"Streams\": 4922369, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"1Knctxx9vGZxpZfF66BIEa\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2018-06-22\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.594, \"Energy\": 0.798, \"Loudness\": -5.244, \"Speechiness\": 0.0844, \"Acousticness\": 0.115, \"Liveness\": 0.143, \"Tempo\": 142.049, \"Duration (ms)\": 191840.0, \"Valence\": 0.381, \"Chord\": \"E\"}, {\"Index\": 1484, \"Highest Charting Position\": 157, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"11 PM\", \"Streams\": 4891989, \"Artist\": \"Maluma\", \"Artist Followers\": 26784251.0, \"Song ID\": \"7KbF6AdprOXEEHlsq11Z6d\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.777, \"Energy\": 0.712, \"Loudness\": -4.84, \"Speechiness\": 0.277, \"Acousticness\": 0.217, \"Liveness\": 0.091, \"Tempo\": 95.692, \"Duration (ms)\": 175733.0, \"Valence\": 0.68, \"Chord\": \"A#/Bb\"}, {\"Index\": 1485, \"Highest Charting Position\": 182, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Post Malone (feat. RANI)\", \"Streams\": 4855270, \"Artist\": \"Sam Feldt\", \"Artist Followers\": 639516.0, \"Song ID\": \"0qc4QlcCxVTGyShurEv1UU\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'pop', 'pop dance', 'pop edm', 'tropical house']\", \"Release Date\": \"2019-05-24\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.59, \"Energy\": 0.642, \"Loudness\": -3.87, \"Speechiness\": 0.122, \"Acousticness\": 0.0771, \"Liveness\": 0.105, \"Tempo\": 107.356, \"Duration (ms)\": 174444.0, \"Valence\": 0.651, \"Chord\": \"G\"}, {\"Index\": 1486, \"Highest Charting Position\": 52, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"In Too Deep\", \"Streams\": 4824037, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"7Dj2wqPYXfSRFwa6qyOztr\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.72, \"Energy\": 0.767, \"Loudness\": -5.839, \"Speechiness\": 0.214, \"Acousticness\": 0.0387, \"Liveness\": 0.202, \"Tempo\": 88.966, \"Duration (ms)\": 194707.0, \"Valence\": 0.595, \"Chord\": \"A#/Bb\"}, {\"Index\": 1487, \"Highest Charting Position\": 57, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Premonition - Intro\", \"Streams\": 10830400, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"7ccTcabbJlCJiIqtrSSwBk\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.847, \"Energy\": 0.637, \"Loudness\": -5.193, \"Speechiness\": 0.367, \"Acousticness\": 0.0258, \"Liveness\": 0.382, \"Tempo\": 165.979, \"Duration (ms)\": 173893.0, \"Valence\": 0.511, \"Chord\": \"C#/Db\"}, {\"Index\": 1488, \"Highest Charting Position\": 62, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"I Can See\", \"Streams\": 10086930, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"3R8CyhJfVjvgIROd5RSGhQ\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.699, \"Energy\": 0.503, \"Loudness\": -9.922, \"Speechiness\": 0.0882, \"Acousticness\": 0.391, \"Liveness\": 0.0996, \"Tempo\": 114.86, \"Duration (ms)\": 220853.0, \"Valence\": 0.0546, \"Chord\": \"F\"}, {\"Index\": 1489, \"Highest Charting Position\": 69, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Hand Me Downs\", \"Streams\": 9521654, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"2Yv2mHzr5AQavVdwQjEokV\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.677, \"Energy\": 0.33, \"Loudness\": -11.198, \"Speechiness\": 0.149, \"Acousticness\": 0.474, \"Liveness\": 0.064, \"Tempo\": 68.985, \"Duration (ms)\": 298440.0, \"Valence\": 0.336, \"Chord\": \"D\"}, {\"Index\": 1490, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"No Regrets (feat. Don Toliver)\", \"Streams\": 9493884, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"1lO9CZo6eDrOy0S7khgryG\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 63.0, \"Danceability\": 0.756, \"Energy\": 0.747, \"Loudness\": -5.407, \"Speechiness\": 0.046, \"Acousticness\": 0.0048, \"Liveness\": 0.588, \"Tempo\": 134.935, \"Duration (ms)\": 200947.0, \"Valence\": 0.0687, \"Chord\": \"A\"}, {\"Index\": 1491, \"Highest Charting Position\": 71, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Complicated\", \"Streams\": 9443725, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"3WfSNAoj2D8C9noPSGZZFM\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.831, \"Energy\": 0.36, \"Loudness\": -8.073, \"Speechiness\": 0.052, \"Acousticness\": 0.136, \"Liveness\": 0.0703, \"Tempo\": 75.014, \"Duration (ms)\": 232212.0, \"Valence\": 0.601, \"Chord\": \"C\"}, {\"Index\": 1492, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Lock It Up (feat. Anderson .Paak)\", \"Streams\": 9328951, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"1qwMkkRiD5jqLeUUjfgblh\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.848, \"Energy\": 0.745, \"Loudness\": -3.052, \"Speechiness\": 0.221, \"Acousticness\": 0.0949, \"Liveness\": 0.0796, \"Tempo\": 137.024, \"Duration (ms)\": 170227.0, \"Valence\": 0.516, \"Chord\": \"F#/Gb\"}, {\"Index\": 1493, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Marsh\", \"Streams\": 9260007, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"34d7sGX6WUqq8f04e7CSNF\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.871, \"Energy\": 0.493, \"Loudness\": -6.356, \"Speechiness\": 0.205, \"Acousticness\": 0.0134, \"Liveness\": 0.385, \"Tempo\": 144.989, \"Duration (ms)\": 200573.0, \"Valence\": 0.0495, \"Chord\": \"C#/Db\"}, {\"Index\": 1494, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Stepdad\", \"Streams\": 9159901, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"3QVHSV8YKYq4L8tI5rnFgj\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 61.0, \"Danceability\": 0.779, \"Energy\": 0.805, \"Loudness\": -3.121, \"Speechiness\": 0.178, \"Acousticness\": 0.018, \"Liveness\": 0.321, \"Tempo\": 145.68, \"Duration (ms)\": 213413.0, \"Valence\": 0.557, \"Chord\": \"C#/Db\"}, {\"Index\": 1495, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Yah Yah (feat. Royce Da 5'9\\\", Black Thought, Q-Tip & Denaun)\", \"Streams\": 8695060, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5mZXWEH2eh8zMZGCxT5aW0\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.458, \"Energy\": 0.966, \"Loudness\": -2.107, \"Speechiness\": 0.384, \"Acousticness\": 0.14, \"Liveness\": 0.11, \"Tempo\": 183.586, \"Duration (ms)\": 286960.0, \"Valence\": 0.356, \"Chord\": \"C#/Db\"}, {\"Index\": 1496, \"Highest Charting Position\": 90, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Never Love Again\", \"Streams\": 8335790, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"40YbWniIEmqy6s58fYXLUh\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.747, \"Energy\": 0.899, \"Loudness\": -5.125, \"Speechiness\": 0.246, \"Acousticness\": 0.1, \"Liveness\": 0.486, \"Tempo\": 92.029, \"Duration (ms)\": 177547.0, \"Valence\": 0.581, \"Chord\": \"F\"}, {\"Index\": 1497, \"Highest Charting Position\": 91, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Woods\", \"Streams\": 8329349, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"3Qa944OTMZkg8DHjET8JQv\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.779, \"Energy\": 0.362, \"Loudness\": -10.847, \"Speechiness\": 0.0474, \"Acousticness\": 0.135, \"Liveness\": 0.111, \"Tempo\": 85.011, \"Duration (ms)\": 286387.0, \"Valence\": 0.46, \"Chord\": \"C\"}, {\"Index\": 1498, \"Highest Charting Position\": 94, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Farewell\", \"Streams\": 8277608, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"74gykWHknHDrg4eMdcmdRq\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 61.0, \"Danceability\": 0.89, \"Energy\": 0.664, \"Loudness\": -6.625, \"Speechiness\": 0.106, \"Acousticness\": 0.00487, \"Liveness\": 0.257, \"Tempo\": 93.007, \"Duration (ms)\": 247733.0, \"Valence\": 0.467, \"Chord\": \"E\"}, {\"Index\": 1499, \"Highest Charting Position\": 98, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Everybody\", \"Streams\": 8172098, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"1OuN92HcVG6NVpWbeESNB3\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.875, \"Energy\": 0.599, \"Loudness\": -9.077, \"Speechiness\": 0.138, \"Acousticness\": 0.0333, \"Liveness\": 0.113, \"Tempo\": 152.061, \"Duration (ms)\": 256507.0, \"Valence\": 0.112, \"Chord\": \"A\"}, {\"Index\": 1500, \"Highest Charting Position\": 100, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Alfred - Interlude\", \"Streams\": 8030151, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"4EmunTy7kNBYQivOa8F6b8\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 57.0, \"Danceability\": 0.429, \"Energy\": 0.231, \"Loudness\": -20.43, \"Speechiness\": 0.402, \"Acousticness\": 0.878, \"Liveness\": 0.279, \"Tempo\": 74.545, \"Duration (ms)\": 30133.0, \"Valence\": 0.914, \"Chord\": \"F\"}, {\"Index\": 1501, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Little Engine\", \"Streams\": 7913461, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"4qNWEOMyexn7b8Icyk29t9\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.769, \"Energy\": 0.811, \"Loudness\": -4.162, \"Speechiness\": 0.228, \"Acousticness\": 0.0234, \"Liveness\": 0.0451, \"Tempo\": 155.081, \"Duration (ms)\": 177293.0, \"Valence\": 0.76, \"Chord\": \"A#/Bb\"}, {\"Index\": 1502, \"Highest Charting Position\": 113, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"I Will (feat. KXNG Crooked, Royce Da 5'9\\\" & Joell Ortiz)\", \"Streams\": 7115414, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"3CJbxqRQ0JNCqboWDNUUeX\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.635, \"Energy\": 0.543, \"Loudness\": -5.941, \"Speechiness\": 0.067, \"Acousticness\": 0.0454, \"Liveness\": 0.272, \"Tempo\": 98.743, \"Duration (ms)\": 303000.0, \"Valence\": 0.036, \"Chord\": \"G#/Ab\"}, {\"Index\": 1503, \"Highest Charting Position\": 115, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Still Learning\", \"Streams\": 7050815, \"Artist\": \"Halsey\", \"Artist Followers\": 15663384.0, \"Song ID\": \"2Mfv5HaqnI18Q9JRv9hqnn\", \"Genre\": \"['dance pop', 'electropop', 'etherpop', 'indie poptimism', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 59.0, \"Danceability\": 0.708, \"Energy\": 0.661, \"Loudness\": -6.543, \"Speechiness\": 0.0546, \"Acousticness\": 0.0396, \"Liveness\": 0.113, \"Tempo\": 102.046, \"Duration (ms)\": 211784.0, \"Valence\": 0.317, \"Chord\": \"C\"}, {\"Index\": 1504, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Surf\", \"Streams\": 6960699, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"1kwnxJNVl7cwcU98RvMBaR\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 67.0, \"Danceability\": 0.828, \"Energy\": 0.182, \"Loudness\": -13.066, \"Speechiness\": 0.166, \"Acousticness\": 0.754, \"Liveness\": 0.15, \"Tempo\": 147.279, \"Duration (ms)\": 330507.0, \"Valence\": 0.231, \"Chord\": \"C#/Db\"}, {\"Index\": 1505, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"That's On Me\", \"Streams\": 6462701, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"0udOCZp7yk0Ml92C0k8H8D\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.583, \"Energy\": 0.499, \"Loudness\": -10.086, \"Speechiness\": 0.0261, \"Acousticness\": 0.591, \"Liveness\": 0.33, \"Tempo\": 155.199, \"Duration (ms)\": 217868.0, \"Valence\": 0.342, \"Chord\": \"A#/Bb\"}, {\"Index\": 1506, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Once A Day\", \"Streams\": 6159873, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"26G5nmIx7Yvq79bIIluyZV\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 61.0, \"Danceability\": 0.762, \"Energy\": 0.054, \"Loudness\": -16.735, \"Speechiness\": 0.0503, \"Acousticness\": 0.947, \"Liveness\": 0.124, \"Tempo\": 96.838, \"Duration (ms)\": 160267.0, \"Valence\": 0.339, \"Chord\": \"D\"}, {\"Index\": 1507, \"Highest Charting Position\": 155, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Big Drip\", \"Streams\": 6010373, \"Artist\": \"Ufo361, Future\", \"Artist Followers\": 1700759.0, \"Song ID\": \"7HZoWhGQaKg97OsqG7HLOS\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 48.0, \"Danceability\": 0.791, \"Energy\": 0.535, \"Loudness\": -6.753, \"Speechiness\": 0.311, \"Acousticness\": 0.0448, \"Liveness\": 0.129, \"Tempo\": 158.922, \"Duration (ms)\": 173785.0, \"Valence\": 0.443, \"Chord\": \"C\"}, {\"Index\": 1508, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Hands\", \"Streams\": 5934464, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"6CrnvqCxBKVWahSiQwOesM\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 58.0, \"Danceability\": 0.739, \"Energy\": 0.627, \"Loudness\": -8.608, \"Speechiness\": 0.171, \"Acousticness\": 0.0459, \"Liveness\": 0.159, \"Tempo\": 74.962, \"Duration (ms)\": 199981.0, \"Valence\": 0.542, \"Chord\": \"C\"}, {\"Index\": 1509, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Dans l'espace (feat. Heuss l'Enfoir\\u00e9)\", \"Streams\": 5678754, \"Artist\": \"Gambi\", \"Artist Followers\": 951798.0, \"Song ID\": \"2KAkkba3PaYFegfmYpUITv\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 59.0, \"Danceability\": 0.916, \"Energy\": 0.57, \"Loudness\": -6.278, \"Speechiness\": 0.18, \"Acousticness\": 0.0286, \"Liveness\": 0.0851, \"Tempo\": 110.05, \"Duration (ms)\": 169702.0, \"Valence\": 0.7, \"Chord\": \"C#/Db\"}, {\"Index\": 1510, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Blanche\", \"Streams\": 5656775, \"Artist\": \"Maes, Booba\", \"Artist Followers\": 1603670.0, \"Song ID\": \"5GyyPRvEwdI4wJSUbzxHQv\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2020-01-16\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 65.0, \"Danceability\": 0.776, \"Energy\": 0.713, \"Loudness\": -6.121, \"Speechiness\": 0.143, \"Acousticness\": 0.525, \"Liveness\": 0.306, \"Tempo\": 127.987, \"Duration (ms)\": 193453.0, \"Valence\": 0.551, \"Chord\": \"E\"}, {\"Index\": 1511, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Vulnerable\", \"Streams\": 7531094, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"11OwAR3GlBj9E35Cznf7Lj\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 55.0, \"Danceability\": 0.695, \"Energy\": 0.573, \"Loudness\": -8.882, \"Speechiness\": 0.167, \"Acousticness\": 0.132, \"Liveness\": 0.156, \"Tempo\": 100.031, \"Duration (ms)\": 192172.0, \"Valence\": 0.38, \"Chord\": \"A#/Bb\"}, {\"Index\": 1512, \"Highest Charting Position\": 90, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Dance Again\", \"Streams\": 7394604, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"5sK3o66yupTNIK6gWgzGjf\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 56.0, \"Danceability\": 0.784, \"Energy\": 0.552, \"Loudness\": -7.261, \"Speechiness\": 0.0871, \"Acousticness\": 0.0447, \"Liveness\": 0.192, \"Tempo\": 111.984, \"Duration (ms)\": 170498.0, \"Valence\": 0.465, \"Chord\": \"C#/Db\"}, {\"Index\": 1513, \"Highest Charting Position\": 107, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Ring\", \"Streams\": 6693229, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"11Ey4yJVeWEsA73KjACkVY\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 55.0, \"Danceability\": 0.873, \"Energy\": 0.51, \"Loudness\": -5.35, \"Speechiness\": 0.0661, \"Acousticness\": 0.565, \"Liveness\": 0.0738, \"Tempo\": 110.953, \"Duration (ms)\": 148776.0, \"Valence\": 0.871, \"Chord\": \"D#/Eb\"}, {\"Index\": 1514, \"Highest Charting Position\": 111, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Crowded Room (feat. 6LACK)\", \"Streams\": 6483001, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"2C0hTkdEoikhKzDCJl32QZ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 55.0, \"Danceability\": 0.724, \"Energy\": 0.415, \"Loudness\": -8.408, \"Speechiness\": 0.0518, \"Acousticness\": 0.764, \"Liveness\": 0.103, \"Tempo\": 89.999, \"Duration (ms)\": 186459.0, \"Valence\": 0.328, \"Chord\": \"G\"}, {\"Index\": 1515, \"Highest Charting Position\": 119, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"People You Know\", \"Streams\": 6255954, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"63mdJr3NMY3wReOkNE6c6W\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 54.0, \"Danceability\": 0.695, \"Energy\": 0.62, \"Loudness\": -8.082, \"Speechiness\": 0.0521, \"Acousticness\": 0.0881, \"Liveness\": 0.111, \"Tempo\": 150.032, \"Duration (ms)\": 194900.0, \"Valence\": 0.62, \"Chord\": \"G#/Ab\"}, {\"Index\": 1516, \"Highest Charting Position\": 83, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Up All Night\", \"Streams\": 5834918, \"Artist\": \"Khalid\", \"Artist Followers\": 14190858.0, \"Song ID\": \"1mpD5Q8IM32I4bF6eCpU74\", \"Genre\": \"['pop']\", \"Release Date\": \"2019-11-14\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 69.0, \"Danceability\": 0.665, \"Energy\": 0.712, \"Loudness\": -7.536, \"Speechiness\": 0.0527, \"Acousticness\": 0.00103, \"Liveness\": 0.102, \"Tempo\": 93.992, \"Duration (ms)\": 157220.0, \"Valence\": 0.669, \"Chord\": \"C#/Db\"}, {\"Index\": 1517, \"Highest Charting Position\": 111, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Nice To Meet Ya\", \"Streams\": 5730427, \"Artist\": \"Niall Horan\", \"Artist Followers\": 7564659.0, \"Song ID\": \"3cphb8kdsjElYR7r5icK3H\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.591, \"Energy\": 0.841, \"Loudness\": -4.351, \"Speechiness\": 0.0304, \"Acousticness\": 0.0119, \"Liveness\": 0.395, \"Tempo\": 109.034, \"Duration (ms)\": 158805.0, \"Valence\": 0.392, \"Chord\": \"E\"}, {\"Index\": 1518, \"Highest Charting Position\": 102, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Into the Unknown\", \"Streams\": 5705999, \"Artist\": \"Idina Menzel, AURORA\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3Z0oQ8r78OUaHvGPiDBR3W\", \"Genre\": \"[]\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.323, \"Energy\": 0.405, \"Loudness\": -8.533, \"Speechiness\": 0.0413, \"Acousticness\": 0.849, \"Liveness\": 0.138, \"Tempo\": 145.104, \"Duration (ms)\": 194848.0, \"Valence\": 0.274, \"Chord\": \"A#/Bb\"}, {\"Index\": 1519, \"Highest Charting Position\": 161, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Let Me Get Me\", \"Streams\": 5356671, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"0uFForNKQPvgSCnxlZIhQy\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 51.0, \"Danceability\": 0.826, \"Energy\": 0.571, \"Loudness\": -9.263, \"Speechiness\": 0.0426, \"Acousticness\": 0.249, \"Liveness\": 0.215, \"Tempo\": 121.06, \"Duration (ms)\": 189145.0, \"Valence\": 0.475, \"Chord\": \"D\"}, {\"Index\": 1520, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"A Sweeter Place (feat. Kid Cudi)\", \"Streams\": 5291134, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4bb94wZVF1cX66vQjNeJTX\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 52.0, \"Danceability\": 0.583, \"Energy\": 0.777, \"Loudness\": -6.991, \"Speechiness\": 0.185, \"Acousticness\": 0.109, \"Liveness\": 0.108, \"Tempo\": 190.054, \"Duration (ms)\": 263306.0, \"Valence\": 0.31, \"Chord\": \"A#/Bb\"}, {\"Index\": 1521, \"Highest Charting Position\": 131, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Stuck In A Dream (feat. Gunna)\", \"Streams\": 5258047, \"Artist\": \"Lil Mosey\", \"Artist Followers\": 3818503.0, \"Song ID\": \"7iHHxY2NLlJRAmlAmC4ahQ\", \"Genre\": \"['melodic rap', 'rap', 'rap conscient', 'trap', 'vapor trap']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.748, \"Energy\": 0.648, \"Loudness\": -6.445, \"Speechiness\": 0.0816, \"Acousticness\": 0.484, \"Liveness\": 0.126, \"Tempo\": 139.952, \"Duration (ms)\": 123560.0, \"Valence\": 0.726, \"Chord\": \"A#/Bb\"}, {\"Index\": 1522, \"Highest Charting Position\": 138, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Take What You Want (feat. Ozzy Osbourne & Travis Scott)\", \"Streams\": 5199618, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"7CZyCXKG6d5ALeq41sLzbw\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.499, \"Energy\": 0.8, \"Loudness\": -2.665, \"Speechiness\": 0.0502, \"Acousticness\": 0.0906, \"Liveness\": 0.147, \"Tempo\": 139.919, \"Duration (ms)\": 229573.0, \"Valence\": 0.272, \"Chord\": \"C#/Db\"}, {\"Index\": 1523, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Tip Toe (feat. A Boogie Wit da Hoodie)\", \"Streams\": 5150724, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6608815.0, \"Song ID\": \"6ztvsy3C6hPjVg9j4x1XKJ\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 63.0, \"Danceability\": 0.757, \"Energy\": 0.673, \"Loudness\": -8.513, \"Speechiness\": 0.141, \"Acousticness\": 0.095, \"Liveness\": 0.338, \"Tempo\": 92.958, \"Duration (ms)\": 185806.0, \"Valence\": 0.574, \"Chord\": \"C#/Db\"}, {\"Index\": 1524, \"Highest Charting Position\": 182, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Start Wit Me (feat. Gunna)\", \"Streams\": 5085706, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6608815.0, \"Song ID\": \"7A20WnLkjtZU2d7hIB6Ziu\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 68.0, \"Danceability\": 0.886, \"Energy\": 0.479, \"Loudness\": -8.054, \"Speechiness\": 0.334, \"Acousticness\": 0.077, \"Liveness\": 0.135, \"Tempo\": 130.029, \"Duration (ms)\": 158692.0, \"Valence\": 0.408, \"Chord\": \"E\"}, {\"Index\": 1525, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Diamonds (with Normani)\", \"Streams\": 4981484, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"0PQsrLxPbOBBwwmXCnGvcF\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 58.0, \"Danceability\": 0.785, \"Energy\": 0.753, \"Loudness\": -3.841, \"Speechiness\": 0.0873, \"Acousticness\": 0.188, \"Liveness\": 0.265, \"Tempo\": 94.012, \"Duration (ms)\": 199301.0, \"Valence\": 0.488, \"Chord\": \"C#/Db\"}, {\"Index\": 1526, \"Highest Charting Position\": 140, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Don't Call Me Up\", \"Streams\": 4931458, \"Artist\": \"Mabel\", \"Artist Followers\": 1374784.0, \"Song ID\": \"5WHTFyqSii0lmT9R21abT8\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2019-01-18\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.674, \"Energy\": 0.881, \"Loudness\": -2.853, \"Speechiness\": 0.147, \"Acousticness\": 0.296, \"Liveness\": 0.0793, \"Tempo\": 98.994, \"Duration (ms)\": 178480.0, \"Valence\": 0.234, \"Chord\": \"A\"}, {\"Index\": 1527, \"Highest Charting Position\": 177, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Death\", \"Streams\": 4929396, \"Artist\": \"Trippie Redd, DaBaby\", \"Artist Followers\": 6434201.0, \"Song ID\": \"3Kd6Wp3lG5HXMB2dlvuy7y\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 65.0, \"Danceability\": 0.802, \"Energy\": 0.82, \"Loudness\": -5.969, \"Speechiness\": 0.146, \"Acousticness\": 0.0579, \"Liveness\": 0.149, \"Tempo\": 164.005, \"Duration (ms)\": 172196.0, \"Valence\": 0.613, \"Chord\": \"A#/Bb\"}, {\"Index\": 1528, \"Highest Charting Position\": 133, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Calma - Remix\", \"Streams\": 4879713, \"Artist\": \"Pedro Cap\\u00f3, Farruko\", \"Artist Followers\": 1353049.0, \"Song ID\": \"5iwz1NiezX7WWjnCgY5TH4\", \"Genre\": \"['latin', 'latin pop', 'puerto rican pop']\", \"Release Date\": \"2018-10-05\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.826, \"Energy\": 0.773, \"Loudness\": -4.218, \"Speechiness\": 0.0524, \"Acousticness\": 0.323, \"Liveness\": 0.143, \"Tempo\": 126.899, \"Duration (ms)\": 238200.0, \"Valence\": 0.761, \"Chord\": \"B\"}, {\"Index\": 1529, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Cut You Off\", \"Streams\": 4874380, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4OtHGdb0KqEbaWb6edUnR9\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 51.0, \"Danceability\": 0.855, \"Energy\": 0.294, \"Loudness\": -8.676, \"Speechiness\": 0.286, \"Acousticness\": 0.3, \"Liveness\": 0.091, \"Tempo\": 139.745, \"Duration (ms)\": 182017.0, \"Valence\": 0.842, \"Chord\": \"F\"}, {\"Index\": 1530, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Kinda Crazy\", \"Streams\": 4866777, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"59iGOjPSOcPLGl3vqEStUp\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 49.0, \"Danceability\": 0.691, \"Energy\": 0.446, \"Loudness\": -10.304, \"Speechiness\": 0.0472, \"Acousticness\": 0.484, \"Liveness\": 0.183, \"Tempo\": 93.03, \"Duration (ms)\": 212436.0, \"Valence\": 0.534, \"Chord\": \"B\"}, {\"Index\": 1531, \"Highest Charting Position\": 179, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"2002\", \"Streams\": 4831644, \"Artist\": \"Anne-Marie\", \"Artist Followers\": 8153871.0, \"Song ID\": \"2BgEsaKNfHUdlh97KmvFyo\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2018-04-27\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.697, \"Energy\": 0.683, \"Loudness\": -2.881, \"Speechiness\": 0.117, \"Acousticness\": 0.0372, \"Liveness\": 0.137, \"Tempo\": 96.133, \"Duration (ms)\": 186987.0, \"Valence\": 0.603, \"Chord\": \"C#/Db\"}, {\"Index\": 1532, \"Highest Charting Position\": 153, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Taki Taki (feat. Selena Gomez, Ozuna & Cardi B)\", \"Streams\": 4816702, \"Artist\": \"DJ Snake\", \"Artist Followers\": 7408249.0, \"Song ID\": \"0KoiMHhqKLoL4xM54rcWYY\", \"Genre\": \"['dance pop', 'edm', 'electronic trap', 'pop', 'pop dance']\", \"Release Date\": \"2019-07-25\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.842, \"Energy\": 0.801, \"Loudness\": -4.167, \"Speechiness\": 0.228, \"Acousticness\": 0.157, \"Liveness\": 0.0642, \"Tempo\": 95.881, \"Duration (ms)\": 212500.0, \"Valence\": 0.617, \"Chord\": \"G#/Ab\"}, {\"Index\": 1533, \"Highest Charting Position\": 107, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Family\", \"Streams\": 6145132, \"Artist\": \"The Chainsmokers, Kygo\", \"Artist Followers\": 18195884.0, \"Song ID\": \"3TKpJrY9q49Mj1JOsM9zGL\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.584, \"Energy\": 0.607, \"Loudness\": -6.605, \"Speechiness\": 0.0356, \"Acousticness\": 0.426, \"Liveness\": 0.101, \"Tempo\": 117.817, \"Duration (ms)\": 194827.0, \"Valence\": 0.374, \"Chord\": \"B\"}, {\"Index\": 1534, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"GANG GANG\", \"Streams\": 5898484, \"Artist\": \"JACKBOYS, Sheck Wes\", \"Artist Followers\": 437907.0, \"Song ID\": \"6uJONCdr2rC65BNmCnTBWK\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 69.0, \"Danceability\": 0.859, \"Energy\": 0.6, \"Loudness\": -4.63, \"Speechiness\": 0.301, \"Acousticness\": 0.071, \"Liveness\": 0.353, \"Tempo\": 123.017, \"Duration (ms)\": 244761.0, \"Valence\": 0.568, \"Chord\": \"G\"}, {\"Index\": 1535, \"Highest Charting Position\": 39, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Had Enough (feat. Quavo & Offset)\", \"Streams\": 5748010, \"Artist\": \"Don Toliver\", \"Artist Followers\": 437907.0, \"Song ID\": \"7LGWmZaoS7jZJ5tEi9EcDi\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.75, \"Energy\": 0.789, \"Loudness\": -4.578, \"Speechiness\": 0.108, \"Acousticness\": 0.253, \"Liveness\": 0.129, \"Tempo\": 147.957, \"Duration (ms)\": 157133.0, \"Valence\": 0.673, \"Chord\": \"D\"}, {\"Index\": 1536, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"WHAT TO DO? (feat. Don Toliver)\", \"Streams\": 5586351, \"Artist\": \"JACKBOYS, Travis Scott\", \"Artist Followers\": 437907.0, \"Song ID\": \"4AO1XhrgJczQ9bNVxdfKQe\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.643, \"Energy\": 0.594, \"Loudness\": -5.191, \"Speechiness\": 0.0312, \"Acousticness\": 0.0695, \"Liveness\": 0.115, \"Tempo\": 118.037, \"Duration (ms)\": 250142.0, \"Valence\": 0.195, \"Chord\": \"A\"}, {\"Index\": 1537, \"Highest Charting Position\": 125, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Writing on the Wall (feat. Post Malone, Cardi B & Rvssian)\", \"Streams\": 5229616, \"Artist\": \"French Montana\", \"Artist Followers\": 4039037.0, \"Song ID\": \"7x9nXsowok1JszkVztI5NI\", \"Genre\": \"['gangster rap', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 59.0, \"Danceability\": 0.773, \"Energy\": 0.836, \"Loudness\": -2.326, \"Speechiness\": 0.153, \"Acousticness\": 0.283, \"Liveness\": 0.0828, \"Tempo\": 112.01, \"Duration (ms)\": 201271.0, \"Valence\": 0.497, \"Chord\": \"A\"}, {\"Index\": 1538, \"Highest Charting Position\": 169, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"VALENTINO\", \"Streams\": 4935492, \"Artist\": \"24kGoldn\", \"Artist Followers\": 1276406.0, \"Song ID\": \"6piAUJJQFD8oHDUr0b7l7q\", \"Genre\": \"['cali rap']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.746, \"Energy\": 0.717, \"Loudness\": -4.841, \"Speechiness\": 0.179, \"Acousticness\": 0.199, \"Liveness\": 0.132, \"Tempo\": 150.964, \"Duration (ms)\": 179133.0, \"Valence\": 0.523, \"Chord\": \"A\"}, {\"Index\": 1539, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"fuck, i'm lonely (with Anne-Marie) - from \\u201c13 Reasons Why: Season 3\\u201d\", \"Streams\": 4856458, \"Artist\": \"Lauv\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-01-03--2020-01-10\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 1540, \"Highest Charting Position\": 150, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Roller\", \"Streams\": 4732292, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"6hw1Sy9wZ8UCxYGdpKrU6M\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2019-10-25\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.941, \"Energy\": 0.758, \"Loudness\": -6.47, \"Speechiness\": 0.17, \"Acousticness\": 0.0256, \"Liveness\": 0.193, \"Tempo\": 128.017, \"Duration (ms)\": 157093.0, \"Valence\": 0.683, \"Chord\": \"A#/Bb\"}, {\"Index\": 1541, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Never Really Over\", \"Streams\": 4679948, \"Artist\": \"Katy Perry\", \"Artist Followers\": 18936929.0, \"Song ID\": \"5PYQUBXc7NYeI1obMKSJK0\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-05-31\", \"Weeks Charted\": \"2020-01-03--2020-01-10\", \"Popularity\": 74.0, \"Danceability\": 0.77, \"Energy\": 0.882, \"Loudness\": -4.792, \"Speechiness\": 0.0602, \"Acousticness\": 0.194, \"Liveness\": 0.316, \"Tempo\": 99.991, \"Duration (ms)\": 223523.0, \"Valence\": 0.385, \"Chord\": \"G#/Ab\"}, {\"Index\": 1542, \"Highest Charting Position\": 145, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"One Kiss (with Dua Lipa)\", \"Streams\": 4594157, \"Artist\": \"Calvin Harris\", \"Artist Followers\": 21946934.0, \"Song ID\": \"7ef4DlsgrMEH11cDZd32M6\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'house', 'pop', 'progressive house', 'uk dance']\", \"Release Date\": \"2018-04-06\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.791, \"Energy\": 0.862, \"Loudness\": -3.24, \"Speechiness\": 0.11, \"Acousticness\": 0.037, \"Liveness\": 0.0814, \"Tempo\": 123.994, \"Duration (ms)\": 214847.0, \"Valence\": 0.592, \"Chord\": \"A\"}, {\"Index\": 1543, \"Highest Charting Position\": 192, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Fantas\\u00eda\", \"Streams\": 4543012, \"Artist\": \"Ozuna\", \"Artist Followers\": 29238936.0, \"Song ID\": \"40rXWke6SnXiGkSmaT8ZUr\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-29\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 59.0, \"Danceability\": 0.695, \"Energy\": 0.719, \"Loudness\": -5.938, \"Speechiness\": 0.0903, \"Acousticness\": 0.227, \"Liveness\": 0.0884, \"Tempo\": 180.074, \"Duration (ms)\": 175187.0, \"Valence\": 0.781, \"Chord\": \"D\"}, {\"Index\": 1544, \"Highest Charting Position\": 59, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Trampoline\", \"Streams\": 8896030, \"Artist\": \"SHAED, ZAYN\", \"Artist Followers\": 139434.0, \"Song ID\": \"1iQDltZqI7BXnHrFy4Qo1k\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-09-26\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.619, \"Energy\": 0.459, \"Loudness\": -5.782, \"Speechiness\": 0.0334, \"Acousticness\": 0.56, \"Liveness\": 0.137, \"Tempo\": 126.803, \"Duration (ms)\": 184280.0, \"Valence\": 0.498, \"Chord\": \"G\"}, {\"Index\": 1545, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"GATTI\", \"Streams\": 7685470, \"Artist\": \"JACKBOYS, Pop Smoke, Travis Scott\", \"Artist Followers\": 437907.0, \"Song ID\": \"40mjsnRjCpycdUw3xhS20g\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.594, \"Energy\": 0.676, \"Loudness\": -5.808, \"Speechiness\": 0.344, \"Acousticness\": 0.135, \"Liveness\": 0.163, \"Tempo\": 143.477, \"Duration (ms)\": 181145.0, \"Valence\": 0.472, \"Chord\": \"D\"}, {\"Index\": 1546, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Candy\", \"Streams\": 5632102, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"1VJwtWR6z7SpZRwipI12be\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2018-03-30\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.689, \"Energy\": 0.516, \"Loudness\": -5.857, \"Speechiness\": 0.0444, \"Acousticness\": 0.513, \"Liveness\": 0.163, \"Tempo\": 124.876, \"Duration (ms)\": 190920.0, \"Valence\": 0.209, \"Chord\": \"G#/Ab\"}, {\"Index\": 1547, \"Highest Charting Position\": 143, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"JACKBOYS\", \"Streams\": 5363493, \"Artist\": \"JACKBOYS\", \"Artist Followers\": 437907.0, \"Song ID\": \"62zKJrpbLxz6InR3tGyr7o\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 56.0, \"Danceability\": 0.413, \"Energy\": 0.13, \"Loudness\": -25.166, \"Speechiness\": 0.0336, \"Acousticness\": 0.9, \"Liveness\": 0.111, \"Tempo\": 123.342, \"Duration (ms)\": 46837.0, \"Valence\": 0.0676, \"Chord\": \"C\"}, {\"Index\": 1548, \"Highest Charting Position\": 156, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Combatchy (feat. MC Rebecca)\", \"Streams\": 5149797, \"Artist\": \"Anitta, Lexa, Lu\\u00edsa Sonza\", \"Artist Followers\": 10741972.0, \"Song ID\": \"2bPtwnrpFNEe8N7Q85kLHw\", \"Genre\": \"['funk carioca', 'funk pop', 'pagode baiano', 'pop nacional']\", \"Release Date\": \"2019-11-20\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 64.0, \"Danceability\": 0.826, \"Energy\": 0.73, \"Loudness\": -3.032, \"Speechiness\": 0.0809, \"Acousticness\": 0.383, \"Liveness\": 0.0197, \"Tempo\": 150.134, \"Duration (ms)\": 157600.0, \"Valence\": 0.605, \"Chord\": \"C#/Db\"}, {\"Index\": 1549, \"Highest Charting Position\": 178, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Old Town Road\", \"Streams\": 4852004, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5488666.0, \"Song ID\": \"2YpeDb67231RjR0MgVLzsG\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.878, \"Energy\": 0.619, \"Loudness\": -5.56, \"Speechiness\": 0.102, \"Acousticness\": 0.0533, \"Liveness\": 0.113, \"Tempo\": 136.041, \"Duration (ms)\": 157067.0, \"Valence\": 0.639, \"Chord\": \"F#/Gb\"}, {\"Index\": 1550, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Let Me Know (I Wonder Why Freestyle)\", \"Streams\": 4701532, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"3wwo0bJvDSorOpNfzEkfXx\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2019-12-07\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.635, \"Energy\": 0.537, \"Loudness\": -7.895, \"Speechiness\": 0.0832, \"Acousticness\": 0.172, \"Liveness\": 0.418, \"Tempo\": 125.028, \"Duration (ms)\": 215381.0, \"Valence\": 0.383, \"Chord\": \"G\"}, {\"Index\": 1551, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Ne reviens pas\", \"Streams\": 4676857, \"Artist\": \"Gradur, Heuss L'enfoir\\u00e9\", \"Artist Followers\": 1390813.0, \"Song ID\": \"4TnFANpjVwVKWzkxNzIyFH\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2019-11-29\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 62.0, \"Danceability\": 0.932, \"Energy\": 0.778, \"Loudness\": -3.384, \"Speechiness\": 0.0638, \"Acousticness\": 0.212, \"Liveness\": 0.168, \"Tempo\": 124.996, \"Duration (ms)\": 188613.0, \"Valence\": 0.933, \"Chord\": \"A#/Bb\"}, {\"Index\": 1552, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"New Rules\", \"Streams\": 4630675, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"2ekn2ttSfGqwhhate0LSR0\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2017-06-02\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.762, \"Energy\": 0.7, \"Loudness\": -6.021, \"Speechiness\": 0.0694, \"Acousticness\": 0.00261, \"Liveness\": 0.153, \"Tempo\": 116.073, \"Duration (ms)\": 209320.0, \"Valence\": 0.608, \"Chord\": \"A\"}, {\"Index\": 1553, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Cheirosa - Ao Vivo\", \"Streams\": 4623030, \"Artist\": \"Jorge & Mateus\", \"Artist Followers\": 15019109.0, \"Song ID\": \"2PWjKmjyTZeDpmOUa3a5da\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2019-10-11\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.528, \"Energy\": 0.87, \"Loudness\": -3.123, \"Speechiness\": 0.0851, \"Acousticness\": 0.24, \"Liveness\": 0.333, \"Tempo\": 152.37, \"Duration (ms)\": 181930.0, \"Valence\": 0.714, \"Chord\": \"B\"}, {\"Index\": 1554, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Havana (feat. Young Thug)\", \"Streams\": 4620876, \"Artist\": \"Camila Cabello\", \"Artist Followers\": 22698747.0, \"Song ID\": \"1rfofaqEpACxVEHIZBJe6W\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-01-12\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.765, \"Energy\": 0.523, \"Loudness\": -4.333, \"Speechiness\": 0.03, \"Acousticness\": 0.184, \"Liveness\": 0.132, \"Tempo\": 104.988, \"Duration (ms)\": 217307.0, \"Valence\": 0.394, \"Chord\": \"D\"}, {\"Index\": 1555, \"Highest Charting Position\": 198, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Surtada - Remix Brega Funk\", \"Streams\": 4607385, \"Artist\": \"Dad\\u00e1 Bolad\\u00e3o, Tati Zaqui, OIK\", \"Artist Followers\": 208630.0, \"Song ID\": \"5F8ffc8KWKNawllr5WsW0r\", \"Genre\": \"['brega funk', 'funk carioca']\", \"Release Date\": \"2019-09-25\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 60.0, \"Danceability\": 0.832, \"Energy\": 0.55, \"Loudness\": -7.026, \"Speechiness\": 0.0587, \"Acousticness\": 0.249, \"Liveness\": 0.182, \"Tempo\": 154.064, \"Duration (ms)\": 152784.0, \"Valence\": 0.881, \"Chord\": \"F\"}, {\"Index\": 1556, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lover (Remix) [feat. Shawn Mendes]\", \"Streams\": 4595450, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3i9UVldZOE0aD0JnyfAZZ0\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-11-13\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.448, \"Energy\": 0.603, \"Loudness\": -7.176, \"Speechiness\": 0.064, \"Acousticness\": 0.433, \"Liveness\": 0.0862, \"Tempo\": 205.272, \"Duration (ms)\": 221307.0, \"Valence\": 0.422, \"Chord\": \"G\"}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 22,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "alt.Chart(df).mark_bar().encode(\n",
    "    x = \"Artist\",\n",
    "    y = \"count()\"\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "002e8729",
   "metadata": {},
   "source": [
    "There are so many artists, this chart is pretty difficult to interpret.  Let's restrict ourselves to the top artists.\n",
    "\n",
    "Here are the top 19 artists.  (Why 19 rather than 20?  No great reason, but this particular chart looks better with 19.)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 23,
   "id": "db61c1a3",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "Taylor Swift          52\n",
       "Lil Uzi Vert          32\n",
       "Justin Bieber         32\n",
       "Juice WRLD            30\n",
       "Pop Smoke             29\n",
       "BTS                   29\n",
       "Bad Bunny             28\n",
       "Eminem                22\n",
       "The Weeknd            21\n",
       "Ariana Grande         20\n",
       "Drake                 19\n",
       "Billie Eilish         18\n",
       "Selena Gomez          17\n",
       "J. Cole               16\n",
       "Doja Cat              16\n",
       "Dua Lipa              15\n",
       "Lady Gaga             14\n",
       "Tyler, The Creator    14\n",
       "DaBaby                14\n",
       "Name: Artist, dtype: int64"
      ]
     },
     "execution_count": 23,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "top_artists = df.Artist.value_counts()[:19]\n",
    "top_artists"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "0cf60508",
   "metadata": {},
   "source": [
    "Let's make our Altair chart using the sub-DataFrame with just these 19 top artists.  We make this using a new pandas method, `isin`."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 24,
   "id": "0e669b76",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>Index</th>\n",
       "      <th>Highest Charting Position</th>\n",
       "      <th>Number of Times Charted</th>\n",
       "      <th>Week of Highest Charting</th>\n",
       "      <th>Song Name</th>\n",
       "      <th>Streams</th>\n",
       "      <th>Artist</th>\n",
       "      <th>Artist Followers</th>\n",
       "      <th>Song ID</th>\n",
       "      <th>Genre</th>\n",
       "      <th>...</th>\n",
       "      <th>Danceability</th>\n",
       "      <th>Energy</th>\n",
       "      <th>Loudness</th>\n",
       "      <th>Speechiness</th>\n",
       "      <th>Acousticness</th>\n",
       "      <th>Liveness</th>\n",
       "      <th>Tempo</th>\n",
       "      <th>Duration (ms)</th>\n",
       "      <th>Valence</th>\n",
       "      <th>Chord</th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>6</th>\n",
       "      <td>7</td>\n",
       "      <td>3</td>\n",
       "      <td>16</td>\n",
       "      <td>2021-05-14--2021-05-21</td>\n",
       "      <td>Kiss Me More (feat. SZA)</td>\n",
       "      <td>29356736</td>\n",
       "      <td>Doja Cat</td>\n",
       "      <td>8640063.0</td>\n",
       "      <td>748mdHapucXQri7IAO8yFK</td>\n",
       "      <td>['dance pop', 'pop']</td>\n",
       "      <td>...</td>\n",
       "      <td>0.762</td>\n",
       "      <td>0.701</td>\n",
       "      <td>-3.541</td>\n",
       "      <td>0.0286</td>\n",
       "      <td>0.23500</td>\n",
       "      <td>0.1230</td>\n",
       "      <td>110.968</td>\n",
       "      <td>208867.0</td>\n",
       "      <td>0.742</td>\n",
       "      <td>G#/Ab</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>8</th>\n",
       "      <td>9</td>\n",
       "      <td>3</td>\n",
       "      <td>8</td>\n",
       "      <td>2021-06-18--2021-06-25</td>\n",
       "      <td>Yonaguni</td>\n",
       "      <td>25030128</td>\n",
       "      <td>Bad Bunny</td>\n",
       "      <td>36142273.0</td>\n",
       "      <td>2JPLbjOn0wPCngEot2STUS</td>\n",
       "      <td>['latin', 'reggaeton', 'trap latino']</td>\n",
       "      <td>...</td>\n",
       "      <td>0.644</td>\n",
       "      <td>0.648</td>\n",
       "      <td>-4.601</td>\n",
       "      <td>0.1180</td>\n",
       "      <td>0.27600</td>\n",
       "      <td>0.1350</td>\n",
       "      <td>179.951</td>\n",
       "      <td>206710.0</td>\n",
       "      <td>0.440</td>\n",
       "      <td>C#/Db</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>10</th>\n",
       "      <td>11</td>\n",
       "      <td>4</td>\n",
       "      <td>43</td>\n",
       "      <td>2021-05-07--2021-05-14</td>\n",
       "      <td>Levitating (feat. DaBaby)</td>\n",
       "      <td>23518010</td>\n",
       "      <td>Dua Lipa</td>\n",
       "      <td>27142474.0</td>\n",
       "      <td>463CkQjx2Zk1yXoBuierM9</td>\n",
       "      <td>['dance pop', 'pop', 'uk pop']</td>\n",
       "      <td>...</td>\n",
       "      <td>0.702</td>\n",
       "      <td>0.825</td>\n",
       "      <td>-3.787</td>\n",
       "      <td>0.0601</td>\n",
       "      <td>0.00883</td>\n",
       "      <td>0.0674</td>\n",
       "      <td>102.977</td>\n",
       "      <td>203064.0</td>\n",
       "      <td>0.915</td>\n",
       "      <td>F#/Gb</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>12</th>\n",
       "      <td>13</td>\n",
       "      <td>5</td>\n",
       "      <td>3</td>\n",
       "      <td>2021-07-09--2021-07-16</td>\n",
       "      <td>Permission to Dance</td>\n",
       "      <td>22062812</td>\n",
       "      <td>BTS</td>\n",
       "      <td>37106176.0</td>\n",
       "      <td>0LThjFY2iTtNdd4wviwVV2</td>\n",
       "      <td>['k-pop', 'k-pop boy group']</td>\n",
       "      <td>...</td>\n",
       "      <td>0.702</td>\n",
       "      <td>0.741</td>\n",
       "      <td>-5.330</td>\n",
       "      <td>0.0427</td>\n",
       "      <td>0.00544</td>\n",
       "      <td>0.3370</td>\n",
       "      <td>124.925</td>\n",
       "      <td>187585.0</td>\n",
       "      <td>0.646</td>\n",
       "      <td>A</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>13</th>\n",
       "      <td>14</td>\n",
       "      <td>1</td>\n",
       "      <td>19</td>\n",
       "      <td>2021-04-02--2021-04-09</td>\n",
       "      <td>Peaches (feat. Daniel Caesar &amp; Giveon)</td>\n",
       "      <td>20294457</td>\n",
       "      <td>Justin Bieber</td>\n",
       "      <td>48504126.0</td>\n",
       "      <td>4iJyoBOLtHqaGxP12qzhQI</td>\n",
       "      <td>['canadian pop', 'pop', 'post-teen pop']</td>\n",
       "      <td>...</td>\n",
       "      <td>0.677</td>\n",
       "      <td>0.696</td>\n",
       "      <td>-6.181</td>\n",
       "      <td>0.1190</td>\n",
       "      <td>0.32100</td>\n",
       "      <td>0.4200</td>\n",
       "      <td>90.030</td>\n",
       "      <td>198082.0</td>\n",
       "      <td>0.464</td>\n",
       "      <td>C</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "<p>5 rows × 23 columns</p>\n",
       "</div>"
      ],
      "text/plain": [
       "    Index  Highest Charting Position  Number of Times Charted  \\\n",
       "6       7                          3                       16   \n",
       "8       9                          3                        8   \n",
       "10     11                          4                       43   \n",
       "12     13                          5                        3   \n",
       "13     14                          1                       19   \n",
       "\n",
       "   Week of Highest Charting                               Song Name   Streams  \\\n",
       "6    2021-05-14--2021-05-21                Kiss Me More (feat. SZA)  29356736   \n",
       "8    2021-06-18--2021-06-25                                Yonaguni  25030128   \n",
       "10   2021-05-07--2021-05-14               Levitating (feat. DaBaby)  23518010   \n",
       "12   2021-07-09--2021-07-16                     Permission to Dance  22062812   \n",
       "13   2021-04-02--2021-04-09  Peaches (feat. Daniel Caesar & Giveon)  20294457   \n",
       "\n",
       "           Artist  Artist Followers                 Song ID  \\\n",
       "6        Doja Cat         8640063.0  748mdHapucXQri7IAO8yFK   \n",
       "8       Bad Bunny        36142273.0  2JPLbjOn0wPCngEot2STUS   \n",
       "10       Dua Lipa        27142474.0  463CkQjx2Zk1yXoBuierM9   \n",
       "12            BTS        37106176.0  0LThjFY2iTtNdd4wviwVV2   \n",
       "13  Justin Bieber        48504126.0  4iJyoBOLtHqaGxP12qzhQI   \n",
       "\n",
       "                                       Genre  ... Danceability Energy  \\\n",
       "6                       ['dance pop', 'pop']  ...        0.762  0.701   \n",
       "8      ['latin', 'reggaeton', 'trap latino']  ...        0.644  0.648   \n",
       "10            ['dance pop', 'pop', 'uk pop']  ...        0.702  0.825   \n",
       "12              ['k-pop', 'k-pop boy group']  ...        0.702  0.741   \n",
       "13  ['canadian pop', 'pop', 'post-teen pop']  ...        0.677  0.696   \n",
       "\n",
       "    Loudness  Speechiness  Acousticness  Liveness    Tempo  Duration (ms)  \\\n",
       "6     -3.541       0.0286       0.23500    0.1230  110.968       208867.0   \n",
       "8     -4.601       0.1180       0.27600    0.1350  179.951       206710.0   \n",
       "10    -3.787       0.0601       0.00883    0.0674  102.977       203064.0   \n",
       "12    -5.330       0.0427       0.00544    0.3370  124.925       187585.0   \n",
       "13    -6.181       0.1190       0.32100    0.4200   90.030       198082.0   \n",
       "\n",
       "    Valence  Chord  \n",
       "6     0.742  G#/Ab  \n",
       "8     0.440  C#/Db  \n",
       "10    0.915  F#/Gb  \n",
       "12    0.646      A  \n",
       "13    0.464      C  \n",
       "\n",
       "[5 rows x 23 columns]"
      ]
     },
     "execution_count": 24,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "df_top = df[df.Artist.isin(top_artists.index)]\n",
    "df_top.head()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 25,
   "id": "0bbeffa9",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-cb1ab9998faa4033a1a5f73405bfe4d8\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-cb1ab9998faa4033a1a5f73405bfe4d8\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-cb1ab9998faa4033a1a5f73405bfe4d8\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-160a2b6fb60af0f1ff2f7ad1143b7368\"}, \"mark\": \"bar\", \"encoding\": {\"x\": {\"type\": \"nominal\", \"field\": \"Artist\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"count\"}}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-160a2b6fb60af0f1ff2f7ad1143b7368\": [{\"Index\": 7, \"Highest Charting Position\": 3, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Kiss Me More (feat. SZA)\", \"Streams\": 29356736, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"748mdHapucXQri7IAO8yFK\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 94.0, \"Danceability\": 0.762, \"Energy\": 0.701, \"Loudness\": -3.541, \"Speechiness\": 0.0286, \"Acousticness\": 0.235, \"Liveness\": 0.123, \"Tempo\": 110.968, \"Duration (ms)\": 208867.0, \"Valence\": 0.742, \"Chord\": \"G#/Ab\"}, {\"Index\": 9, \"Highest Charting Position\": 3, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Yonaguni\", \"Streams\": 25030128, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36142273.0, \"Song ID\": \"2JPLbjOn0wPCngEot2STUS\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 96.0, \"Danceability\": 0.644, \"Energy\": 0.648, \"Loudness\": -4.601, \"Speechiness\": 0.118, \"Acousticness\": 0.276, \"Liveness\": 0.135, \"Tempo\": 179.951, \"Duration (ms)\": 206710.0, \"Valence\": 0.44, \"Chord\": \"C#/Db\"}, {\"Index\": 11, \"Highest Charting Position\": 4, \"Number of Times Charted\": 43, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Levitating (feat. DaBaby)\", \"Streams\": 23518010, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"463CkQjx2Zk1yXoBuierM9\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-10-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 89.0, \"Danceability\": 0.702, \"Energy\": 0.825, \"Loudness\": -3.787, \"Speechiness\": 0.0601, \"Acousticness\": 0.00883, \"Liveness\": 0.0674, \"Tempo\": 102.977, \"Duration (ms)\": 203064.0, \"Valence\": 0.915, \"Chord\": \"F#/Gb\"}, {\"Index\": 13, \"Highest Charting Position\": 5, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Permission to Dance\", \"Streams\": 22062812, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"0LThjFY2iTtNdd4wviwVV2\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 95.0, \"Danceability\": 0.702, \"Energy\": 0.741, \"Loudness\": -5.33, \"Speechiness\": 0.0427, \"Acousticness\": 0.00544, \"Liveness\": 0.337, \"Tempo\": 124.925, \"Duration (ms)\": 187585.0, \"Valence\": 0.646, \"Chord\": \"A\"}, {\"Index\": 14, \"Highest Charting Position\": 1, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Peaches (feat. Daniel Caesar & Giveon)\", \"Streams\": 20294457, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48504126.0, \"Song ID\": \"4iJyoBOLtHqaGxP12qzhQI\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 94.0, \"Danceability\": 0.677, \"Energy\": 0.696, \"Loudness\": -6.181, \"Speechiness\": 0.119, \"Acousticness\": 0.321, \"Liveness\": 0.42, \"Tempo\": 90.03, \"Duration (ms)\": 198082.0, \"Valence\": 0.464, \"Chord\": \"C\"}, {\"Index\": 15, \"Highest Charting Position\": 2, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Butter\", \"Streams\": 19985713, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"2bgTY4UwhfBYhGT4HUYStN\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 95.0, \"Danceability\": 0.759, \"Energy\": 0.459, \"Loudness\": -5.187, \"Speechiness\": 0.0948, \"Acousticness\": 0.00323, \"Liveness\": 0.0906, \"Tempo\": 109.997, \"Duration (ms)\": 164442.0, \"Valence\": 0.695, \"Chord\": \"G#/Ab\"}, {\"Index\": 18, \"Highest Charting Position\": 5, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Save Your Tears (with Ariana Grande) (Remix)\", \"Streams\": 18053141, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"37BZB0z9T8Xu7U3e65qxFy\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 94.0, \"Danceability\": 0.65, \"Energy\": 0.825, \"Loudness\": -4.645, \"Speechiness\": 0.0325, \"Acousticness\": 0.0215, \"Liveness\": 0.0936, \"Tempo\": 118.091, \"Duration (ms)\": 191014.0, \"Valence\": 0.593, \"Chord\": \"C\"}, {\"Index\": 20, \"Highest Charting Position\": 20, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Need To Know\", \"Streams\": 16908917, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"3Vi5XqYrmQgOYBajMWSvCi\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 90.0, \"Danceability\": 0.664, \"Energy\": 0.609, \"Loudness\": -6.509, \"Speechiness\": 0.0707, \"Acousticness\": 0.304, \"Liveness\": 0.0926, \"Tempo\": 130.041, \"Duration (ms)\": 210560.0, \"Valence\": 0.194, \"Chord\": \"C#/Db\"}, {\"Index\": 22, \"Highest Charting Position\": 22, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Ain't Shit\", \"Streams\": 16126897, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"5lAnYvAIkSDNXqfo7DyFUm\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 90.0, \"Danceability\": 0.855, \"Energy\": 0.488, \"Loudness\": -4.601, \"Speechiness\": 0.208, \"Acousticness\": 0.506, \"Liveness\": 0.347, \"Tempo\": 124.097, \"Duration (ms)\": 174253.0, \"Valence\": 0.619, \"Chord\": \"D#/Eb\"}, {\"Index\": 25, \"Highest Charting Position\": 1, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Blinding Lights\", \"Streams\": 15011809, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"0VjIjW4GlUZAMYd2vXMi3b\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 92.0, \"Danceability\": 0.514, \"Energy\": 0.73, \"Loudness\": -5.934, \"Speechiness\": 0.0598, \"Acousticness\": 0.00146, \"Liveness\": 0.0897, \"Tempo\": 171.005, \"Duration (ms)\": 200040.0, \"Valence\": 0.334, \"Chord\": \"C#/Db\"}, {\"Index\": 44, \"Highest Charting Position\": 2, \"Number of Times Charted\": 49, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Dynamite\", \"Streams\": 11196819, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"4saklk6nie3yiGePpBwUoc\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 89.0, \"Danceability\": 0.746, \"Energy\": 0.765, \"Loudness\": -4.41, \"Speechiness\": 0.0993, \"Acousticness\": 0.0112, \"Liveness\": 0.0936, \"Tempo\": 114.044, \"Duration (ms)\": 199054.0, \"Valence\": 0.737, \"Chord\": \"F#/Gb\"}, {\"Index\": 53, \"Highest Charting Position\": 19, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"NDA\", \"Streams\": 9635619, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47014200.0, \"Song ID\": \"38GBNKZUhfBkk3oNlWzRYd\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-07-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 84.0, \"Danceability\": 0.765, \"Energy\": 0.373, \"Loudness\": -9.921, \"Speechiness\": 0.0713, \"Acousticness\": 0.341, \"Liveness\": 0.112, \"Tempo\": 85.016, \"Duration (ms)\": 195777.0, \"Valence\": 0.554, \"Chord\": \"G#/Ab\"}, {\"Index\": 64, \"Highest Charting Position\": 2, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Save Your Tears\", \"Streams\": 8843110, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"37BZB0z9T8Xu7U3e65qxFy\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 94.0, \"Danceability\": 0.65, \"Energy\": 0.825, \"Loudness\": -4.645, \"Speechiness\": 0.0325, \"Acousticness\": 0.0215, \"Liveness\": 0.0936, \"Tempo\": 118.091, \"Duration (ms)\": 191014.0, \"Valence\": 0.593, \"Chord\": \"C\"}, {\"Index\": 66, \"Highest Charting Position\": 2, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Don't Start Now\", \"Streams\": 8821971, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 1250353.0, \"Song ID\": \"7njGslFmqBmOSSOpTyZCs9\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.793, \"Energy\": 0.793, \"Loudness\": -4.521, \"Speechiness\": 0.083, \"Acousticness\": 0.0123, \"Liveness\": 0.0951, \"Tempo\": 123.95, \"Duration (ms)\": 183290.0, \"Valence\": 0.679, \"Chord\": \"B\"}, {\"Index\": 82, \"Highest Charting Position\": 6, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Wants and Needs (feat. Lil Baby)\", \"Streams\": 7637626, \"Artist\": \"Drake\", \"Artist Followers\": 56308172.0, \"Song ID\": \"65OVbaJR5O1RmwOQx0875b\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 87.0, \"Danceability\": 0.578, \"Energy\": 0.449, \"Loudness\": -6.349, \"Speechiness\": 0.286, \"Acousticness\": 0.0618, \"Liveness\": 0.119, \"Tempo\": 136.006, \"Duration (ms)\": 192956.0, \"Valence\": 0.1, \"Chord\": \"C#/Db\"}, {\"Index\": 84, \"Highest Charting Position\": 76, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Love Again\", \"Streams\": 7465445, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 1250353.0, \"Song ID\": \"2sN1pMv6d2t5GlvN6IBMlK\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2020-03-27--2020-04-03\", \"Popularity\": 0.0, \"Danceability\": 0.659, \"Energy\": 0.667, \"Loudness\": -4.668, \"Speechiness\": 0.0339, \"Acousticness\": 0.00173, \"Liveness\": 0.1, \"Tempo\": 115.982, \"Duration (ms)\": 258004.0, \"Valence\": 0.468, \"Chord\": \"B\"}, {\"Index\": 92, \"Highest Charting Position\": 1, \"Number of Times Charted\": 40, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"positions\", \"Streams\": 7244853, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67158068.0, \"Song ID\": \"35mvY5S1H3J2QZyna3TFe0\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 86.0, \"Danceability\": 0.737, \"Energy\": 0.802, \"Loudness\": -4.771, \"Speechiness\": 0.0878, \"Acousticness\": 0.468, \"Liveness\": 0.0931, \"Tempo\": 144.015, \"Duration (ms)\": 172325.0, \"Valence\": 0.682, \"Chord\": \"C\"}, {\"Index\": 97, \"Highest Charting Position\": 97, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Woman\", \"Streams\": 6858466, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"6Uj1ctrBOjOas8xZXGqKk4\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-06-25--2021-07-02\", \"Popularity\": 86.0, \"Danceability\": 0.824, \"Energy\": 0.764, \"Loudness\": -4.175, \"Speechiness\": 0.0854, \"Acousticness\": 0.0888, \"Liveness\": 0.117, \"Tempo\": 107.998, \"Duration (ms)\": 172627.0, \"Valence\": 0.881, \"Chord\": \"F\"}, {\"Index\": 101, \"Highest Charting Position\": 52, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Levitating\", \"Streams\": 6799831, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"463CkQjx2Zk1yXoBuierM9\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-10-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 89.0, \"Danceability\": 0.702, \"Energy\": 0.825, \"Loudness\": -3.787, \"Speechiness\": 0.0601, \"Acousticness\": 0.00883, \"Liveness\": 0.0674, \"Tempo\": 102.977, \"Duration (ms)\": 203064.0, \"Valence\": 0.915, \"Chord\": \"F#/Gb\"}, {\"Index\": 111, \"Highest Charting Position\": 46, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"lovely (with Khalid)\", \"Streams\": 6569547, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47014200.0, \"Song ID\": \"0u2P5u6lvoDfwTYjAADbn4\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2018-04-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.351, \"Energy\": 0.296, \"Loudness\": -10.109, \"Speechiness\": 0.0333, \"Acousticness\": 0.934, \"Liveness\": 0.095, \"Tempo\": 115.284, \"Duration (ms)\": 200186.0, \"Valence\": 0.12, \"Chord\": \"E\"}, {\"Index\": 114, \"Highest Charting Position\": 9, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Streets\", \"Streams\": 6502302, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"60ynsPSSKe6O3sfwRnIBRf\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 86.0, \"Danceability\": 0.749, \"Energy\": 0.463, \"Loudness\": -8.433, \"Speechiness\": 0.0842, \"Acousticness\": 0.21, \"Liveness\": 0.338, \"Tempo\": 90.035, \"Duration (ms)\": 226987.0, \"Valence\": 0.189, \"Chord\": \"B\"}, {\"Index\": 119, \"Highest Charting Position\": 5, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Hold On\", \"Streams\": 6300416, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 1250353.0, \"Song ID\": \"49xx65gvlD7xXjDTavFqaJ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 0.0, \"Danceability\": 0.658, \"Energy\": 0.634, \"Loudness\": -5.797, \"Speechiness\": 0.0413, \"Acousticness\": 0.0106, \"Liveness\": 0.132, \"Tempo\": 139.98, \"Duration (ms)\": 170813.0, \"Valence\": 0.29, \"Chord\": \"C#/Db\"}, {\"Index\": 123, \"Highest Charting Position\": 1, \"Number of Times Charted\": 67, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"ROCKSTAR (feat. Roddy Ricch)\", \"Streams\": 6180056, \"Artist\": \"DaBaby\", \"Artist Followers\": 7593046.0, \"Song ID\": \"7ytR5pFWmSjzHJIeQkgog4\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 86.0, \"Danceability\": 0.746, \"Energy\": 0.69, \"Loudness\": -7.956, \"Speechiness\": 0.164, \"Acousticness\": 0.247, \"Liveness\": 0.101, \"Tempo\": 89.977, \"Duration (ms)\": 181733.0, \"Valence\": 0.497, \"Chord\": \"B\"}, {\"Index\": 158, \"Highest Charting Position\": 6, \"Number of Times Charted\": 47, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"What You Know Bout Love\", \"Streams\": 5570735, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"1tkg4EHVoqnhR6iFEXb60y\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-07-03--2020-07-10\", \"Popularity\": 85.0, \"Danceability\": 0.709, \"Energy\": 0.548, \"Loudness\": -8.493, \"Speechiness\": 0.353, \"Acousticness\": 0.65, \"Liveness\": 0.133, \"Tempo\": 83.995, \"Duration (ms)\": 160000.0, \"Valence\": 0.543, \"Chord\": \"A#/Bb\"}, {\"Index\": 160, \"Highest Charting Position\": 121, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Red Light Green Light\", \"Streams\": 5493760, \"Artist\": \"DaBaby\", \"Artist Followers\": 7593046.0, \"Song ID\": \"1YDebgap5OFwXEBG18NJvy\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.933, \"Energy\": 0.656, \"Loudness\": -5.85, \"Speechiness\": 0.322, \"Acousticness\": 0.129, \"Liveness\": 0.161, \"Tempo\": 119.987, \"Duration (ms)\": 159083.0, \"Valence\": 0.934, \"Chord\": \"D\"}, {\"Index\": 161, \"Highest Charting Position\": 120, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Ball If I Want To\", \"Streams\": 5478055, \"Artist\": \"DaBaby\", \"Artist Followers\": 7593046.0, \"Song ID\": \"0cu0rhnlCnJ7JIeHRiLpj3\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\", \"Popularity\": 84.0, \"Danceability\": 0.902, \"Energy\": 0.669, \"Loudness\": -5.049, \"Speechiness\": 0.457, \"Acousticness\": 0.161, \"Liveness\": 0.0728, \"Tempo\": 139.949, \"Duration (ms)\": 112547.0, \"Valence\": 0.628, \"Chord\": \"C#/Db\"}, {\"Index\": 162, \"Highest Charting Position\": 31, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lucid Dreams\", \"Streams\": 5477563, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"285pBltuF7vW8TeWk8hdRR\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2018-12-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.511, \"Energy\": 0.566, \"Loudness\": -7.23, \"Speechiness\": 0.2, \"Acousticness\": 0.349, \"Liveness\": 0.34, \"Tempo\": 83.903, \"Duration (ms)\": 239836.0, \"Valence\": 0.218, \"Chord\": \"F#/Gb\"}, {\"Index\": 164, \"Highest Charting Position\": 5, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"34+35\", \"Streams\": 5453159, \"Artist\": \"Ariana Grande\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 165, \"Highest Charting Position\": 13, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"bad guy\", \"Streams\": 5436286, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"1hewNsVmijBqjKvFRQfk4m\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.701, \"Energy\": 0.425, \"Loudness\": -10.965, \"Speechiness\": 0.375, \"Acousticness\": 0.328, \"Liveness\": 0.1, \"Tempo\": 135.128, \"Duration (ms)\": 194088.0, \"Valence\": 0.562, \"Chord\": \"G\"}, {\"Index\": 167, \"Highest Charting Position\": 7, \"Number of Times Charted\": 56, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"For The Night (feat. Lil Baby & DaBaby)\", \"Streams\": 5431375, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"0PvFJmanyNQMseIFrU708S\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 84.0, \"Danceability\": 0.823, \"Energy\": 0.586, \"Loudness\": -6.606, \"Speechiness\": 0.2, \"Acousticness\": 0.114, \"Liveness\": 0.193, \"Tempo\": 125.971, \"Duration (ms)\": 190476.0, \"Valence\": 0.347, \"Chord\": \"F#/Gb\"}, {\"Index\": 175, \"Highest Charting Position\": 65, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Bout A Million (feat. 42 Dugg & 21 Savage)\", \"Streams\": 5315734, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"4LaGu95Ui2s4vprSQYWUAZ\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 81.0, \"Danceability\": 0.716, \"Energy\": 0.67, \"Loudness\": -6.995, \"Speechiness\": 0.101, \"Acousticness\": 0.526, \"Liveness\": 0.13, \"Tempo\": 145.043, \"Duration (ms)\": 203586.0, \"Valence\": 0.411, \"Chord\": \"C\"}, {\"Index\": 176, \"Highest Charting Position\": 72, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Demeanor (feat. Dua Lipa)\", \"Streams\": 5245618, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"3DMs7bahbQTnoxCjgP7qoK\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 81.0, \"Danceability\": 0.675, \"Energy\": 0.608, \"Loudness\": -6.934, \"Speechiness\": 0.103, \"Acousticness\": 0.336, \"Liveness\": 0.11, \"Tempo\": 99.865, \"Duration (ms)\": 184800.0, \"Valence\": 0.728, \"Chord\": \"D#/Eb\"}, {\"Index\": 187, \"Highest Charting Position\": 40, \"Number of Times Charted\": 65, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Dior\", \"Streams\": 5092354, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"79s5XnCN4TJKTVMSmOx8Ep\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2019-07-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-06-18--2021-06-25\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 83.0, \"Danceability\": 0.548, \"Energy\": 0.805, \"Loudness\": -5.732, \"Speechiness\": 0.351, \"Acousticness\": 0.212, \"Liveness\": 0.408, \"Tempo\": 142.094, \"Duration (ms)\": 216387.0, \"Valence\": 0.648, \"Chord\": \"G\"}, {\"Index\": 189, \"Highest Charting Position\": 52, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"The Hills\", \"Streams\": 5068864, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"7fBv7CLKzipRk6EC6TWHOB\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2015-08-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 84.0, \"Danceability\": 0.585, \"Energy\": 0.564, \"Loudness\": -7.063, \"Speechiness\": 0.0515, \"Acousticness\": 0.0671, \"Liveness\": 0.135, \"Tempo\": 113.003, \"Duration (ms)\": 242253.0, \"Valence\": 0.137, \"Chord\": \"C\"}, {\"Index\": 192, \"Highest Charting Position\": 64, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"De Museo\", \"Streams\": 5016125, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36142273.0, \"Song ID\": \"267NGliXM8YLVZiKAD9Otm\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 83.0, \"Danceability\": 0.592, \"Energy\": 0.494, \"Loudness\": -10.618, \"Speechiness\": 0.0747, \"Acousticness\": 0.237, \"Liveness\": 0.13, \"Tempo\": 132.037, \"Duration (ms)\": 209771.0, \"Valence\": 0.231, \"Chord\": \"E\"}, {\"Index\": 193, \"Highest Charting Position\": 41, \"Number of Times Charted\": 81, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"7 rings\", \"Streams\": 5002227, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67158068.0, \"Song ID\": \"6ocbgoVGwYJhOv1GgI9NsF\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-02-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.778, \"Energy\": 0.317, \"Loudness\": -10.732, \"Speechiness\": 0.334, \"Acousticness\": 0.592, \"Liveness\": 0.0881, \"Tempo\": 140.048, \"Duration (ms)\": 178627.0, \"Valence\": 0.327, \"Chord\": \"C#/Db\"}, {\"Index\": 200, \"Highest Charting Position\": 172, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"The Real Slim Shady\", \"Streams\": 4948965, \"Artist\": \"Eminem\", \"Artist Followers\": 46785561.0, \"Song ID\": \"3yfqSUWxFvZELEM4PmlwIR\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2000-05-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 84.0, \"Danceability\": 0.949, \"Energy\": 0.661, \"Loudness\": -4.244, \"Speechiness\": 0.0572, \"Acousticness\": 0.0302, \"Liveness\": 0.0454, \"Tempo\": 104.504, \"Duration (ms)\": 284200.0, \"Valence\": 0.76, \"Chord\": \"F\"}, {\"Index\": 201, \"Highest Charting Position\": 66, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Tell The Vision (feat. Kanye West & Pusha T)\", \"Streams\": 8859168, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"1Eu51GaXEehPMrDMh5QghA\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 57.0, \"Danceability\": 0.662, \"Energy\": 0.686, \"Loudness\": -8.302, \"Speechiness\": 0.332, \"Acousticness\": 0.251, \"Liveness\": 0.349, \"Tempo\": 143.971, \"Duration (ms)\": 215000.0, \"Valence\": 0.678, \"Chord\": \"G\"}, {\"Index\": 202, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Woo Baby (feat. Chris Brown)\", \"Streams\": 7371935, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"6bsqes8Zg9gUULzuCkMUs0\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 56.0, \"Danceability\": 0.563, \"Energy\": 0.672, \"Loudness\": -7.226, \"Speechiness\": 0.0765, \"Acousticness\": 0.359, \"Liveness\": 0.0972, \"Tempo\": 99.772, \"Duration (ms)\": 156000.0, \"Valence\": 0.284, \"Chord\": \"A\"}, {\"Index\": 204, \"Highest Charting Position\": 127, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"More Time\", \"Streams\": 6238351, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"7wAnRqccDr2tzcSKLR4jKl\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 55.0, \"Danceability\": 0.628, \"Energy\": 0.581, \"Loudness\": -8.377, \"Speechiness\": 0.188, \"Acousticness\": 0.46, \"Liveness\": 0.152, \"Tempo\": 145.396, \"Duration (ms)\": 120828.0, \"Valence\": 0.259, \"Chord\": \"D\"}, {\"Index\": 205, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Coupe\", \"Streams\": 6161664, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"7LB3ilSpX1mSMKKztNTnu2\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 54.0, \"Danceability\": 0.912, \"Energy\": 0.589, \"Loudness\": -7.476, \"Speechiness\": 0.2, \"Acousticness\": 0.0332, \"Liveness\": 0.0795, \"Tempo\": 135.921, \"Duration (ms)\": 123549.0, \"Valence\": 0.486, \"Chord\": \"G#/Ab\"}, {\"Index\": 207, \"Highest Charting Position\": 150, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Manslaughter (feat. Rick Ross & The-Dream)\", \"Streams\": 5822266, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"4byRwLo7EmkCNBU6S8G6u0\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 55.0, \"Danceability\": 0.441, \"Energy\": 0.623, \"Loudness\": -7.331, \"Speechiness\": 0.0414, \"Acousticness\": 0.135, \"Liveness\": 0.14, \"Tempo\": 78.082, \"Duration (ms)\": 249231.0, \"Valence\": 0.285, \"Chord\": \"C#/Db\"}, {\"Index\": 208, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Genius (feat. Lil Tjay & Swae Lee)\", \"Streams\": 5702636, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"2mmRtchzDVpCj9LSyexgjS\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 53.0, \"Danceability\": 0.723, \"Energy\": 0.667, \"Loudness\": -7.524, \"Speechiness\": 0.351, \"Acousticness\": 0.256, \"Liveness\": 0.261, \"Tempo\": 143.044, \"Duration (ms)\": 208112.0, \"Valence\": 0.396, \"Chord\": \"D\"}, {\"Index\": 209, \"Highest Charting Position\": 22, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"WUSYANAME (feat. Youngboy Never Broke Again & Ty Dolla $ign)\", \"Streams\": 5696113, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"5B0kgjHULYJhAQkK5XsMoC\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.493, \"Energy\": 0.653, \"Loudness\": -5.666, \"Speechiness\": 0.0466, \"Acousticness\": 0.269, \"Liveness\": 0.511, \"Tempo\": 142.347, \"Duration (ms)\": 121573.0, \"Valence\": 0.852, \"Chord\": \"C\"}, {\"Index\": 212, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Brush Em (feat. Rah Swish)\", \"Streams\": 5335271, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"58aW6yZGFl7rVM7SLfLnLL\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 54.0, \"Danceability\": 0.654, \"Energy\": 0.724, \"Loudness\": -6.59, \"Speechiness\": 0.355, \"Acousticness\": 0.106, \"Liveness\": 0.655, \"Tempo\": 71.696, \"Duration (ms)\": 150449.0, \"Valence\": 0.717, \"Chord\": \"D#/Eb\"}, {\"Index\": 216, \"Highest Charting Position\": 15, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Lost Cause\", \"Streams\": 5203319, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"36fhyo5QlxBW7DrDHIOn1G\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 0.0, \"Danceability\": 0.671, \"Energy\": 0.336, \"Loudness\": -8.494, \"Speechiness\": 0.241, \"Acousticness\": 0.705, \"Liveness\": 0.0577, \"Tempo\": 75.051, \"Duration (ms)\": 212496.0, \"Valence\": 0.518, \"Chord\": \"A#/Bb\"}, {\"Index\": 222, \"Highest Charting Position\": 22, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"We're Good\", \"Streams\": 6318660, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"1diS6nkxMQc3wwC4G1j0bh\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 83.0, \"Danceability\": 0.722, \"Energy\": 0.588, \"Loudness\": -5.932, \"Speechiness\": 0.0544, \"Acousticness\": 0.0319, \"Liveness\": 0.183, \"Tempo\": 134.01, \"Duration (ms)\": 165507.0, \"Valence\": 0.59, \"Chord\": \"F#/Gb\"}, {\"Index\": 223, \"Highest Charting Position\": 4, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Life Goes On\", \"Streams\": 6142975, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"249gnXrbfmV8NG6jTEMSwD\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 84.0, \"Danceability\": 0.566, \"Energy\": 0.716, \"Loudness\": -5.733, \"Speechiness\": 0.0424, \"Acousticness\": 0.00691, \"Liveness\": 0.37, \"Tempo\": 81.068, \"Duration (ms)\": 207481.0, \"Valence\": 0.45, \"Chord\": \"C#/Db\"}, {\"Index\": 225, \"Highest Charting Position\": 17, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Baila Conmigo (with Rauw Alejandro)\", \"Streams\": 5588217, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28909504.0, \"Song ID\": \"079Ey5uxL04AKPQgVQwx5h\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 84.0, \"Danceability\": 0.823, \"Energy\": 0.544, \"Loudness\": -7.132, \"Speechiness\": 0.0715, \"Acousticness\": 0.0215, \"Liveness\": 0.0966, \"Tempo\": 149.903, \"Duration (ms)\": 186088.0, \"Valence\": 0.664, \"Chord\": \"F\"}, {\"Index\": 239, \"Highest Charting Position\": 55, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"I Don't Do Drugs (feat. Ariana Grande)\", \"Streams\": 5912293, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0FFsgUoFibYISzMxuGS61W\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 80.0, \"Danceability\": 0.683, \"Energy\": 0.615, \"Loudness\": -5.737, \"Speechiness\": 0.0966, \"Acousticness\": 0.222, \"Liveness\": 0.154, \"Tempo\": 77.014, \"Duration (ms)\": 188893.0, \"Valence\": 0.45, \"Chord\": \"F\"}, {\"Index\": 241, \"Highest Charting Position\": 40, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"JUGGERNAUT (feat. Lil Uzi Vert & Pharrell Williams)\", \"Streams\": 5392334, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"7z4xW9WY86uH3gd1V9pfCM\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 80.0, \"Danceability\": 0.827, \"Energy\": 0.571, \"Loudness\": -7.949, \"Speechiness\": 0.366, \"Acousticness\": 0.0195, \"Liveness\": 0.166, \"Tempo\": 142.034, \"Duration (ms)\": 146419.0, \"Valence\": 0.62, \"Chord\": \"B\"}, {\"Index\": 246, \"Highest Charting Position\": 4, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Your Power\", \"Streams\": 5135380, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47014200.0, \"Song ID\": \"042Sl6Mn83JHyLEqdK7uI0\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-07-30\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 81.0, \"Danceability\": 0.632, \"Energy\": 0.284, \"Loudness\": -14.025, \"Speechiness\": 0.0801, \"Acousticness\": 0.932, \"Liveness\": 0.233, \"Tempo\": 129.642, \"Duration (ms)\": 245897.0, \"Valence\": 0.208, \"Chord\": \"A\"}, {\"Index\": 256, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"LUMBERJACK\", \"Streams\": 11756283, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"0BiK5BbYNFLb88CCOxBFJe\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 76.0, \"Danceability\": 0.386, \"Energy\": 0.762, \"Loudness\": -6.341, \"Speechiness\": 0.564, \"Acousticness\": 0.122, \"Liveness\": 0.527, \"Tempo\": 170.691, \"Duration (ms)\": 138312.0, \"Valence\": 0.433, \"Chord\": \"A\"}, {\"Index\": 257, \"Highest Charting Position\": 47, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"LEMONHEAD (feat. 42 Dugg)\", \"Streams\": 11380679, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"5fbHRCsGpFIOLRtlhCRFDR\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 78.0, \"Danceability\": 0.62, \"Energy\": 0.586, \"Loudness\": -6.612, \"Speechiness\": 0.212, \"Acousticness\": 0.155, \"Liveness\": 0.535, \"Tempo\": 137.131, \"Duration (ms)\": 130980.0, \"Valence\": 0.487, \"Chord\": \"C#/Db\"}, {\"Index\": 258, \"Highest Charting Position\": 59, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"HOT WIND BLOWS (feat. Lil Wayne)\", \"Streams\": 9889197, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"3JJL91ilRV6fXhKqu0FGXs\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 77.0, \"Danceability\": 0.371, \"Energy\": 0.75, \"Loudness\": -5.382, \"Speechiness\": 0.402, \"Acousticness\": 0.601, \"Liveness\": 0.482, \"Tempo\": 173.456, \"Duration (ms)\": 155293.0, \"Valence\": 0.729, \"Chord\": \"G\"}, {\"Index\": 259, \"Highest Charting Position\": 63, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"CORSO\", \"Streams\": 9503981, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"46oHvXwpEZOFX518we1nJD\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 77.0, \"Danceability\": 0.703, \"Energy\": 0.845, \"Loudness\": -4.851, \"Speechiness\": 0.337, \"Acousticness\": 0.169, \"Liveness\": 0.122, \"Tempo\": 97.672, \"Duration (ms)\": 146482.0, \"Valence\": 0.745, \"Chord\": \"A#/Bb\"}, {\"Index\": 260, \"Highest Charting Position\": 69, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"SWEET / I THOUGHT YOU WANTED TO DANCE (feat. Brent Faiyaz & Fana Hues)\", \"Streams\": 9142721, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"3EG9FJ0ToLfgnc1IG2Z1wz\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 79.0, \"Danceability\": 0.468, \"Energy\": 0.652, \"Loudness\": -4.912, \"Speechiness\": 0.0722, \"Acousticness\": 0.333, \"Liveness\": 0.55, \"Tempo\": 140.223, \"Duration (ms)\": 588139.0, \"Valence\": 0.39, \"Chord\": \"C\"}, {\"Index\": 261, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"SIR BAUDELAIRE (feat. DJ Drama)\", \"Streams\": 8884283, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"4ydmav4vl7hebadtfZtMrg\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 75.0, \"Danceability\": 0.467, \"Energy\": 0.635, \"Loudness\": -6.115, \"Speechiness\": 0.154, \"Acousticness\": 0.314, \"Liveness\": 0.844, \"Tempo\": 127.596, \"Duration (ms)\": 88625.0, \"Valence\": 0.51, \"Chord\": \"G\"}, {\"Index\": 262, \"Highest Charting Position\": 82, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"MASSA\", \"Streams\": 8218423, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"2goHCrsDJaflEwQ930ef0o\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 74.0, \"Danceability\": 0.685, \"Energy\": 0.855, \"Loudness\": -6.724, \"Speechiness\": 0.438, \"Acousticness\": 0.329, \"Liveness\": 0.301, \"Tempo\": 157.181, \"Duration (ms)\": 223719.0, \"Valence\": 0.46, \"Chord\": \"C#/Db\"}, {\"Index\": 263, \"Highest Charting Position\": 85, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"RUNITUP (feat. Teezo Touchdown)\", \"Streams\": 7917707, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"13HsOwrwTA5HgLuoaDHncP\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 75.0, \"Danceability\": 0.665, \"Energy\": 0.469, \"Loudness\": -7.778, \"Speechiness\": 0.13, \"Acousticness\": 0.565, \"Liveness\": 0.219, \"Tempo\": 115.852, \"Duration (ms)\": 229565.0, \"Valence\": 0.142, \"Chord\": \"A#/Bb\"}, {\"Index\": 264, \"Highest Charting Position\": 108, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"MANIFESTO (feat. Domo Genesis)\", \"Streams\": 6988886, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"6qouBO0wJtYc3k7DfKRUBx\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.454, \"Energy\": 0.866, \"Loudness\": -5.348, \"Speechiness\": 0.391, \"Acousticness\": 0.121, \"Liveness\": 0.167, \"Tempo\": 92.463, \"Duration (ms)\": 175123.0, \"Valence\": 0.518, \"Chord\": \"D\"}, {\"Index\": 265, \"Highest Charting Position\": 121, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Get Into It (Yuh)\", \"Streams\": 6503281, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0W6I02J9xcqK8MtSeosEXb\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 80.0, \"Danceability\": 0.912, \"Energy\": 0.655, \"Loudness\": -6.029, \"Speechiness\": 0.162, \"Acousticness\": 0.315, \"Liveness\": 0.0894, \"Tempo\": 91.942, \"Duration (ms)\": 138293.0, \"Valence\": 0.793, \"Chord\": \"G#/Ab\"}, {\"Index\": 266, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"WILSHIRE\", \"Streams\": 6268542, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"1pbbsI2KGPOMu0HmuGccBu\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.555, \"Energy\": 0.712, \"Loudness\": -7.446, \"Speechiness\": 0.323, \"Acousticness\": 0.0451, \"Liveness\": 0.182, \"Tempo\": 78.958, \"Duration (ms)\": 515865.0, \"Valence\": 0.555, \"Chord\": \"C#/Db\"}, {\"Index\": 267, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"RISE! (feat. DAISY WORLD)\", \"Streams\": 6034281, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"4Hta7Oy5W9HD0UgT1P8PPV\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.766, \"Energy\": 0.814, \"Loudness\": -3.367, \"Speechiness\": 0.0733, \"Acousticness\": 0.044, \"Liveness\": 0.195, \"Tempo\": 108.07, \"Duration (ms)\": 203588.0, \"Valence\": 0.481, \"Chord\": \"D\"}, {\"Index\": 268, \"Highest Charting Position\": 165, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Naked\", \"Streams\": 5527865, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0CsR9Y9SnC6ZWmekmVqSHz\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 75.0, \"Danceability\": 0.733, \"Energy\": 0.862, \"Loudness\": -5.736, \"Speechiness\": 0.197, \"Acousticness\": 0.374, \"Liveness\": 0.131, \"Tempo\": 111.076, \"Duration (ms)\": 223560.0, \"Valence\": 0.536, \"Chord\": \"G\"}, {\"Index\": 270, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Payday (feat. Young Thug)\", \"Streams\": 5393789, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"2HolBGR6tpiWI80MXoV1dJ\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.619, \"Energy\": 0.707, \"Loudness\": -5.791, \"Speechiness\": 0.0499, \"Acousticness\": 0.0366, \"Liveness\": 0.13, \"Tempo\": 168.995, \"Duration (ms)\": 212947.0, \"Valence\": 0.558, \"Chord\": \"C#/Db\"}, {\"Index\": 271, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Been Like This\", \"Streams\": 5362817, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"7y3xU9vEC1s8DSuuoSYKih\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 74.0, \"Danceability\": 0.678, \"Energy\": 0.531, \"Loudness\": -5.029, \"Speechiness\": 0.0374, \"Acousticness\": 0.126, \"Liveness\": 0.377, \"Tempo\": 99.008, \"Duration (ms)\": 177373.0, \"Valence\": 0.176, \"Chord\": \"A#/Bb\"}, {\"Index\": 279, \"Highest Charting Position\": 11, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"p r i d e . i s . t h e . d e v i l (with Lil Baby)\", \"Streams\": 5430260, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5W8jRrZ6tWrTrqnKRtIQBf\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.861, \"Energy\": 0.656, \"Loudness\": -7.867, \"Speechiness\": 0.425, \"Acousticness\": 0.104, \"Liveness\": 0.0986, \"Tempo\": 88.967, \"Duration (ms)\": 218210.0, \"Valence\": 0.331, \"Chord\": \"E\"}, {\"Index\": 280, \"Highest Charting Position\": 6, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"m y . l i f e (with 21 Savage & Morray)\", \"Streams\": 5246577, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"1D3z6HTiQsNmZxjl7F7eoG\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.597, \"Energy\": 0.587, \"Loudness\": -7.026, \"Speechiness\": 0.137, \"Acousticness\": 0.0622, \"Liveness\": 0.214, \"Tempo\": 140.021, \"Duration (ms)\": 218802.0, \"Valence\": 0.0753, \"Chord\": \"G\"}, {\"Index\": 286, \"Highest Charting Position\": 6, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Anyone\", \"Streams\": 5079587, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 1250353.0, \"Song ID\": \"2RwMwWo43LapkA4raptxaB\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-01-31--2020-02-07\", \"Popularity\": 0.0, \"Danceability\": 0.686, \"Energy\": 0.538, \"Loudness\": -8.026, \"Speechiness\": 0.0345, \"Acousticness\": 0.181, \"Liveness\": 0.113, \"Tempo\": 115.884, \"Duration (ms)\": 190779.0, \"Valence\": 0.584, \"Chord\": \"D\"}, {\"Index\": 290, \"Highest Charting Position\": 7, \"Number of Times Charted\": 65, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Break My Heart\", \"Streams\": 4971176, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"017PF4Q3l4DBUiWoXk4OWT\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 80.0, \"Danceability\": 0.73, \"Energy\": 0.729, \"Loudness\": -3.434, \"Speechiness\": 0.0884, \"Acousticness\": 0.167, \"Liveness\": 0.349, \"Tempo\": 113.011, \"Duration (ms)\": 221820.0, \"Valence\": 0.467, \"Chord\": \"E\"}, {\"Index\": 291, \"Highest Charting Position\": 2, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Laugh Now Cry Later (feat. Lil Durk)\", \"Streams\": 4916860, \"Artist\": \"Drake\", \"Artist Followers\": 56308172.0, \"Song ID\": \"2SAqBLGA283SUiwJ3xOUVI\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 83.0, \"Danceability\": 0.761, \"Energy\": 0.518, \"Loudness\": -8.871, \"Speechiness\": 0.134, \"Acousticness\": 0.244, \"Liveness\": 0.107, \"Tempo\": 133.976, \"Duration (ms)\": 261493.0, \"Valence\": 0.522, \"Chord\": \"C\"}, {\"Index\": 295, \"Highest Charting Position\": 119, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"No Role Modelz\", \"Streams\": 4904401, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"62vpWI1CHwFy7tMIcSStl8\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2014-12-09\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 84.0, \"Danceability\": 0.692, \"Energy\": 0.521, \"Loudness\": -8.465, \"Speechiness\": 0.33, \"Acousticness\": 0.301, \"Liveness\": 0.0565, \"Tempo\": 100.45, \"Duration (ms)\": 292987.0, \"Valence\": 0.463, \"Chord\": \"A#/Bb\"}, {\"Index\": 309, \"Highest Charting Position\": 2, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Therefore I Am\", \"Streams\": 5265630, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"0aACcc1jEv2C6VSmmJbllJ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 0.0, \"Danceability\": 0.889, \"Energy\": 0.34, \"Loudness\": -7.773, \"Speechiness\": 0.0697, \"Acousticness\": 0.218, \"Liveness\": 0.055, \"Tempo\": 94.009, \"Duration (ms)\": 174321.0, \"Valence\": 0.716, \"Chord\": \"B\"}, {\"Index\": 310, \"Highest Charting Position\": 12, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"TE MUDASTE\", \"Streams\": 5242347, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36142273.0, \"Song ID\": \"5RubKOuDoPn5Kj5TLVxSxY\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 82.0, \"Danceability\": 0.811, \"Energy\": 0.637, \"Loudness\": -4.835, \"Speechiness\": 0.0591, \"Acousticness\": 0.234, \"Liveness\": 0.118, \"Tempo\": 92.025, \"Duration (ms)\": 130014.0, \"Valence\": 0.471, \"Chord\": \"A#/Bb\"}, {\"Index\": 315, \"Highest Charting Position\": 1, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Rain On Me (with Ariana Grande)\", \"Streams\": 5041656, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18572085.0, \"Song ID\": \"24ySl2hOPGCDcxBxFIqWBu\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 79.0, \"Danceability\": 0.672, \"Energy\": 0.855, \"Loudness\": -3.764, \"Speechiness\": 0.0397, \"Acousticness\": 0.021, \"Liveness\": 0.323, \"Tempo\": 123.056, \"Duration (ms)\": 182200.0, \"Valence\": 0.646, \"Chord\": \"A\"}, {\"Index\": 320, \"Highest Charting Position\": 10, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"a m a r i\", \"Streams\": 5645966, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"2cnKST6T9qUo2i907lm8zX\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 79.0, \"Danceability\": 0.725, \"Energy\": 0.713, \"Loudness\": -6.173, \"Speechiness\": 0.187, \"Acousticness\": 0.127, \"Liveness\": 0.617, \"Tempo\": 65.988, \"Duration (ms)\": 148421.0, \"Valence\": 0.207, \"Chord\": \"E\"}, {\"Index\": 328, \"Highest Charting Position\": 170, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Killer (feat. Jack Harlow & Cordae) - Remix\", \"Streams\": 5404939, \"Artist\": \"Eminem\", \"Artist Followers\": 46785561.0, \"Song ID\": \"7zl7kehxesNEo2pYkKXTSe\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-05-28--2021-06-04\", \"Popularity\": 76.0, \"Danceability\": 0.924, \"Energy\": 0.73, \"Loudness\": -6.125, \"Speechiness\": 0.274, \"Acousticness\": 0.0525, \"Liveness\": 0.113, \"Tempo\": 99.01, \"Duration (ms)\": 236666.0, \"Valence\": 0.848, \"Chord\": \"B\"}, {\"Index\": 330, \"Highest Charting Position\": 108, \"Number of Times Charted\": 51, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"All Girls Are The Same\", \"Streams\": 5372180, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"4VXIryQMWpIdGgYR4TrjT1\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2018-12-10\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-08--2020-05-15\\n2020-04-24--2020-05-01\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.671, \"Energy\": 0.529, \"Loudness\": -7.226, \"Speechiness\": 0.307, \"Acousticness\": 0.0769, \"Liveness\": 0.0856, \"Tempo\": 161.989, \"Duration (ms)\": 165820.0, \"Valence\": 0.203, \"Chord\": \"C\"}, {\"Index\": 331, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"734\", \"Streams\": 5368759, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"6vB8bdQCCTDDIH8fhRfuXA\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-05-28--2021-06-04\", \"Popularity\": 75.0, \"Danceability\": 0.663, \"Energy\": 0.545, \"Loudness\": -3.93, \"Speechiness\": 0.036, \"Acousticness\": 0.123, \"Liveness\": 0.106, \"Tempo\": 78.452, \"Duration (ms)\": 196147.0, \"Valence\": 0.344, \"Chord\": \"D\"}, {\"Index\": 332, \"Highest Charting Position\": 85, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Boy With Luv (feat. Halsey)\", \"Streams\": 5266625, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"5KawlOMHjWeUjQtnuRs22c\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2019-04-12\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2020-11-20--2020-11-27\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-01-17--2020-01-24\", \"Popularity\": 82.0, \"Danceability\": 0.645, \"Energy\": 0.862, \"Loudness\": -4.757, \"Speechiness\": 0.0965, \"Acousticness\": 0.0923, \"Liveness\": 0.192, \"Tempo\": 119.991, \"Duration (ms)\": 229773.0, \"Valence\": 0.798, \"Chord\": \"B\"}, {\"Index\": 334, \"Highest Charting Position\": 4, \"Number of Times Charted\": 70, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Godzilla (feat. Juice WRLD)\", \"Streams\": 5143522, \"Artist\": \"Eminem\", \"Artist Followers\": 46785561.0, \"Song ID\": \"7FIWs0pqAYbP91WWM0vlTQ\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 83.0, \"Danceability\": 0.808, \"Energy\": 0.745, \"Loudness\": -5.26, \"Speechiness\": 0.342, \"Acousticness\": 0.145, \"Liveness\": 0.292, \"Tempo\": 165.995, \"Duration (ms)\": 210800.0, \"Valence\": 0.829, \"Chord\": \"A#/Bb\"}, {\"Index\": 337, \"Highest Charting Position\": 4, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Holy (feat. Chance The Rapper)\", \"Streams\": 5063015, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48504126.0, \"Song ID\": \"5u1n1kITHCxxp8twBcZxWy\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 81.0, \"Danceability\": 0.673, \"Energy\": 0.704, \"Loudness\": -8.056, \"Speechiness\": 0.36, \"Acousticness\": 0.196, \"Liveness\": 0.0898, \"Tempo\": 86.919, \"Duration (ms)\": 212093.0, \"Valence\": 0.372, \"Chord\": \"F#/Gb\"}, {\"Index\": 339, \"Highest Charting Position\": 15, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"i n t e r l u d e\", \"Streams\": 7880155, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"08LwMWf5Tcfsd752EPzFV0\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 76.0, \"Danceability\": 0.77, \"Energy\": 0.574, \"Loudness\": -5.525, \"Speechiness\": 0.106, \"Acousticness\": 0.0617, \"Liveness\": 0.104, \"Tempo\": 98.962, \"Duration (ms)\": 133022.0, \"Valence\": 0.104, \"Chord\": \"C#/Db\"}, {\"Index\": 340, \"Highest Charting Position\": 95, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Butter (Instrumental)\", \"Streams\": 7450126, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"2Ol2sv6gePRdJrZC1hDVNY\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 70.0, \"Danceability\": 0.429, \"Energy\": 0.387, \"Loudness\": -7.486, \"Speechiness\": 0.0753, \"Acousticness\": 0.000178, \"Liveness\": 0.142, \"Tempo\": 109.893, \"Duration (ms)\": 162147.0, \"Valence\": 0.41, \"Chord\": \"C#/Db\"}, {\"Index\": 341, \"Highest Charting Position\": 25, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Film out\", \"Streams\": 7198095, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"3UHPGOkUcE4hE7sqBF4Snt\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-04-01\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 81.0, \"Danceability\": 0.499, \"Energy\": 0.709, \"Loudness\": -6.404, \"Speechiness\": 0.134, \"Acousticness\": 0.296, \"Liveness\": 0.331, \"Tempo\": 164.032, \"Duration (ms)\": 214621.0, \"Valence\": 0.314, \"Chord\": \"A#/Bb\"}, {\"Index\": 345, \"Highest Charting Position\": 18, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"9 5 . s o u t h\", \"Streams\": 6333126, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5R691ipUYRDYW6ehapjoj6\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 75.0, \"Danceability\": 0.713, \"Energy\": 0.793, \"Loudness\": -5.277, \"Speechiness\": 0.397, \"Acousticness\": 0.271, \"Liveness\": 0.727, \"Tempo\": 71.724, \"Duration (ms)\": 196946.0, \"Valence\": 0.203, \"Chord\": \"D\"}, {\"Index\": 350, \"Highest Charting Position\": 27, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"l e t . g o . m y . h a n d (with Bas & 6LACK)\", \"Streams\": 5393643, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"0GAyuCo975IHGxxiLKDufB\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 73.0, \"Danceability\": 0.583, \"Energy\": 0.625, \"Loudness\": -8.011, \"Speechiness\": 0.277, \"Acousticness\": 0.506, \"Liveness\": 0.196, \"Tempo\": 89.812, \"Duration (ms)\": 266291.0, \"Valence\": 0.516, \"Chord\": \"C#/Db\"}, {\"Index\": 351, \"Highest Charting Position\": 2, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"What\\u2019s Next\", \"Streams\": 5335112, \"Artist\": \"Drake\", \"Artist Followers\": 56308172.0, \"Song ID\": \"3aQem4jVGdhtg116TmJnHz\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 81.0, \"Danceability\": 0.781, \"Energy\": 0.594, \"Loudness\": -6.959, \"Speechiness\": 0.0485, \"Acousticness\": 0.0136, \"Liveness\": 0.162, \"Tempo\": 129.895, \"Duration (ms)\": 178154.0, \"Valence\": 0.0628, \"Chord\": \"C\"}, {\"Index\": 359, \"Highest Charting Position\": 25, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"a p p l y i n g . p r e s s u r e\", \"Streams\": 15967986, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"1d7q712nXjG98HiwHk7HFS\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 71.0, \"Danceability\": 0.699, \"Energy\": 0.759, \"Loudness\": -5.302, \"Speechiness\": 0.311, \"Acousticness\": 0.0814, \"Liveness\": 0.312, \"Tempo\": 83.092, \"Duration (ms)\": 177337.0, \"Valence\": 0.404, \"Chord\": \"C#/Db\"}, {\"Index\": 360, \"Highest Charting Position\": 30, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"1 0 0 . m i l \\u2018 (with Bas)\", \"Streams\": 15171655, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"4n6NDfYake476trCjJRNl0\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 72.0, \"Danceability\": 0.711, \"Energy\": 0.647, \"Loudness\": -5.667, \"Speechiness\": 0.0822, \"Acousticness\": 0.334, \"Liveness\": 0.312, \"Tempo\": 125.092, \"Duration (ms)\": 163302.0, \"Valence\": 0.227, \"Chord\": \"D\"}, {\"Index\": 361, \"Highest Charting Position\": 32, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"p u n c h i n \\u2018 . t h e . c l o c k\", \"Streams\": 14051831, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"57ZUX6TNyKLBydAdVVd02x\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 70.0, \"Danceability\": 0.769, \"Energy\": 0.74, \"Loudness\": -6.579, \"Speechiness\": 0.378, \"Acousticness\": 0.197, \"Liveness\": 0.171, \"Tempo\": 94.104, \"Duration (ms)\": 112579.0, \"Valence\": 0.692, \"Chord\": \"B\"}, {\"Index\": 362, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"t h e . c l i m b . b a c k\", \"Streams\": 12648655, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5lLNBIyjp72btcnrjBG751\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.618, \"Energy\": 0.632, \"Loudness\": -6.973, \"Speechiness\": 0.346, \"Acousticness\": 0.0526, \"Liveness\": 0.353, \"Tempo\": 81.446, \"Duration (ms)\": 306257.0, \"Valence\": 0.319, \"Chord\": \"B\"}, {\"Index\": 363, \"Highest Charting Position\": 48, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"h u n g e r . o n . h i l l s i d e (with Bas)\", \"Streams\": 11647489, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5BwQjRasNcdRPuVWKcHto2\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 71.0, \"Danceability\": 0.563, \"Energy\": 0.703, \"Loudness\": -5.756, \"Speechiness\": 0.0702, \"Acousticness\": 0.126, \"Liveness\": 0.213, \"Tempo\": 94.983, \"Duration (ms)\": 238972.0, \"Valence\": 0.294, \"Chord\": \"D\"}, {\"Index\": 364, \"Highest Charting Position\": 55, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"c l o s e\", \"Streams\": 10712648, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"1D3z6HTiQsNmZxjl7F7eoG\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.597, \"Energy\": 0.587, \"Loudness\": -7.026, \"Speechiness\": 0.137, \"Acousticness\": 0.0622, \"Liveness\": 0.214, \"Tempo\": 140.021, \"Duration (ms)\": 218802.0, \"Valence\": 0.0753, \"Chord\": \"G\"}, {\"Index\": 373, \"Highest Charting Position\": 5, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Lonely (with benny blanco)\", \"Streams\": 5191697, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48504126.0, \"Song ID\": \"4y4spB9m0Q6026KfkAvy9Q\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 80.0, \"Danceability\": 0.631, \"Energy\": 0.239, \"Loudness\": -7.071, \"Speechiness\": 0.0398, \"Acousticness\": 0.864, \"Liveness\": 0.116, \"Tempo\": 79.859, \"Duration (ms)\": 149297.0, \"Valence\": 0.0927, \"Chord\": \"B\"}, {\"Index\": 378, \"Highest Charting Position\": 10, \"Number of Times Charted\": 69, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"everything i wanted\", \"Streams\": 5448680, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"1OC8hMoqAuWmTWJ4heJNlO\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.704, \"Energy\": 0.225, \"Loudness\": -14.454, \"Speechiness\": 0.0994, \"Acousticness\": 0.901, \"Liveness\": 0.106, \"Tempo\": 120.006, \"Duration (ms)\": 245426.0, \"Valence\": 0.243, \"Chord\": \"F#/Gb\"}, {\"Index\": 385, \"Highest Charting Position\": 7, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Wishing Well\", \"Streams\": 5125706, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"2U5WueTLIK5WJLD7mvDODv\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 83.0, \"Danceability\": 0.65, \"Energy\": 0.613, \"Loudness\": -6.13, \"Speechiness\": 0.128, \"Acousticness\": 0.00336, \"Liveness\": 0.267, \"Tempo\": 149.972, \"Duration (ms)\": 194621.0, \"Valence\": 0.0804, \"Chord\": \"A\"}, {\"Index\": 389, \"Highest Charting Position\": 4, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Come & Go (with Marshmello)\", \"Streams\": 5037124, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"2Y0wPrPQBrGhoLn14xRYCG\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 83.0, \"Danceability\": 0.625, \"Energy\": 0.814, \"Loudness\": -5.181, \"Speechiness\": 0.0657, \"Acousticness\": 0.0172, \"Liveness\": 0.158, \"Tempo\": 144.991, \"Duration (ms)\": 205485.0, \"Valence\": 0.535, \"Chord\": \"C\"}, {\"Index\": 390, \"Highest Charting Position\": 71, \"Number of Times Charted\": 72, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Robbery\", \"Streams\": 5024884, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"6Hj9jySrnFppAI0sEMCZpJ\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2019-03-08\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.685, \"Energy\": 0.692, \"Loudness\": -5.122, \"Speechiness\": 0.0457, \"Acousticness\": 0.328, \"Liveness\": 0.153, \"Tempo\": 159.966, \"Duration (ms)\": 240051.0, \"Valence\": 0.578, \"Chord\": \"D\"}, {\"Index\": 399, \"Highest Charting Position\": 20, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Mr. Perfectly Fine (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5480722, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2CYVETnhM9aytqrazYYwrK\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 74.0, \"Danceability\": 0.66, \"Energy\": 0.817, \"Loudness\": -6.269, \"Speechiness\": 0.0521, \"Acousticness\": 0.162, \"Liveness\": 0.0667, \"Tempo\": 135.942, \"Duration (ms)\": 277592.0, \"Valence\": 0.714, \"Chord\": \"B\"}, {\"Index\": 400, \"Highest Charting Position\": 42, \"Number of Times Charted\": 60, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"when the party's over\", \"Streams\": 5467596, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"5KWwUzVxubgSPmLIUAQhYt\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.484, \"Energy\": 0.103, \"Loudness\": -14.075, \"Speechiness\": 0.0627, \"Acousticness\": 0.979, \"Liveness\": 0.0895, \"Tempo\": 124.011, \"Duration (ms)\": 199931.0, \"Valence\": 0.194, \"Chord\": \"C#/Db\"}, {\"Index\": 406, \"Highest Charting Position\": 9, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"As I Am (feat. Khalid)\", \"Streams\": 5896065, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6F2r4HgpJnvKDmkN6JEN6J\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 72.0, \"Danceability\": 0.595, \"Energy\": 0.543, \"Loudness\": -8.149, \"Speechiness\": 0.038, \"Acousticness\": 0.127, \"Liveness\": 0.0975, \"Tempo\": 99.928, \"Duration (ms)\": 174406.0, \"Valence\": 0.109, \"Chord\": \"B\"}, {\"Index\": 413, \"Highest Charting Position\": 6, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"In Your Eyes\", \"Streams\": 5054319, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"7szuecWAPwGoV1e5vGu8tl\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 81.0, \"Danceability\": 0.667, \"Energy\": 0.719, \"Loudness\": -5.371, \"Speechiness\": 0.0346, \"Acousticness\": 0.00285, \"Liveness\": 0.0736, \"Tempo\": 100.021, \"Duration (ms)\": 237520.0, \"Valence\": 0.717, \"Chord\": \"G\"}, {\"Index\": 422, \"Highest Charting Position\": 8, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Love Story (Taylor\\u2019s Version)\", \"Streams\": 6202933, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6YvqWjhGD8mB5QXcbcUKtx\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 73.0, \"Danceability\": 0.627, \"Energy\": 0.792, \"Loudness\": -4.311, \"Speechiness\": 0.031, \"Acousticness\": 0.13, \"Liveness\": 0.0845, \"Tempo\": 119.054, \"Duration (ms)\": 235767.0, \"Valence\": 0.415, \"Chord\": \"D\"}, {\"Index\": 425, \"Highest Charting Position\": 3, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"willow\", \"Streams\": 5016865, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0lx2cLdOt3piJbcaXIV74f\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 79.0, \"Danceability\": 0.392, \"Energy\": 0.574, \"Loudness\": -9.195, \"Speechiness\": 0.17, \"Acousticness\": 0.833, \"Liveness\": 0.145, \"Tempo\": 81.112, \"Duration (ms)\": 214707.0, \"Valence\": 0.529, \"Chord\": \"G\"}, {\"Index\": 429, \"Highest Charting Position\": 52, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"You Belong With Me (Taylor\\u2019s Version)\", \"Streams\": 9872084, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1qrpoAMXodY6895hGKoUpA\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 73.0, \"Danceability\": 0.632, \"Energy\": 0.773, \"Loudness\": -4.856, \"Speechiness\": 0.0346, \"Acousticness\": 0.0623, \"Liveness\": 0.0885, \"Tempo\": 130.033, \"Duration (ms)\": 231124.0, \"Valence\": 0.474, \"Chord\": \"F#/Gb\"}, {\"Index\": 430, \"Highest Charting Position\": 54, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Fearless (Taylor\\u2019s Version)\", \"Streams\": 9676024, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"77sMIMlNaSURUAXq5coCxE\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 69.0, \"Danceability\": 0.569, \"Energy\": 0.741, \"Loudness\": -4.963, \"Speechiness\": 0.0282, \"Acousticness\": 0.0122, \"Liveness\": 0.333, \"Tempo\": 100.118, \"Duration (ms)\": 241592.0, \"Valence\": 0.43, \"Chord\": \"F\"}, {\"Index\": 432, \"Highest Charting Position\": 80, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Fifteen (Taylor\\u2019s Version)\", \"Streams\": 7852063, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2nqio0SfWg6gh2eCtfuMa5\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 66.0, \"Danceability\": 0.559, \"Energy\": 0.646, \"Loudness\": -4.61, \"Speechiness\": 0.0272, \"Acousticness\": 0.116, \"Liveness\": 0.32, \"Tempo\": 95.466, \"Duration (ms)\": 294419.0, \"Valence\": 0.289, \"Chord\": \"G\"}, {\"Index\": 433, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"The Way I Loved You (Taylor\\u2019s Version)\", \"Streams\": 7736262, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"22bPsP2jCgbLUvh82U0Z3M\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 72.0, \"Danceability\": 0.402, \"Energy\": 0.732, \"Loudness\": -4.665, \"Speechiness\": 0.0484, \"Acousticness\": 0.0033, \"Liveness\": 0.108, \"Tempo\": 161.032, \"Duration (ms)\": 243137.0, \"Valence\": 0.472, \"Chord\": \"F\"}, {\"Index\": 434, \"Highest Charting Position\": 51, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"You All Over Me (feat. Maren Morris) (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 7712896, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5pcjystBtalYeqaiXCcgEY\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 65.0, \"Danceability\": 0.589, \"Energy\": 0.496, \"Loudness\": -7.606, \"Speechiness\": 0.0377, \"Acousticness\": 0.818, \"Liveness\": 0.101, \"Tempo\": 142.731, \"Duration (ms)\": 220839.0, \"Valence\": 0.44, \"Chord\": \"D\"}, {\"Index\": 435, \"Highest Charting Position\": 93, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Hey Stephen (Taylor\\u2019s Version)\", \"Streams\": 7385864, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"550erGcdD9n6PnwxrvYqZT\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 66.0, \"Danceability\": 0.788, \"Energy\": 0.571, \"Loudness\": -6.135, \"Speechiness\": 0.0296, \"Acousticness\": 0.106, \"Liveness\": 0.0934, \"Tempo\": 115.99, \"Duration (ms)\": 254255.0, \"Valence\": 0.797, \"Chord\": \"F#/Gb\"}, {\"Index\": 436, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"White Horse (Taylor\\u2019s Version)\", \"Streams\": 7039222, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5YL553x8sHderRBDlm3NM3\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 65.0, \"Danceability\": 0.423, \"Energy\": 0.517, \"Loudness\": -7.377, \"Speechiness\": 0.0486, \"Acousticness\": 0.369, \"Liveness\": 0.177, \"Tempo\": 185.262, \"Duration (ms)\": 234516.0, \"Valence\": 0.366, \"Chord\": \"C\"}, {\"Index\": 437, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Forever & Always (Taylor\\u2019s Version)\", \"Streams\": 6566059, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1msEuwSBneBKpVCZQcFTsU\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 66.0, \"Danceability\": 0.598, \"Energy\": 0.821, \"Loudness\": -4.433, \"Speechiness\": 0.0447, \"Acousticness\": 0.0231, \"Liveness\": 0.143, \"Tempo\": 128.03, \"Duration (ms)\": 225328.0, \"Valence\": 0.673, \"Chord\": \"A#/Bb\"}, {\"Index\": 438, \"Highest Charting Position\": 119, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Breathe (feat. Colbie Caillat) (Taylor\\u2019s Version)\", \"Streams\": 6508683, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7HC7R2D8WjXVcUHJyEGjRs\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 64.0, \"Danceability\": 0.506, \"Energy\": 0.626, \"Loudness\": -6.066, \"Speechiness\": 0.0287, \"Acousticness\": 0.156, \"Liveness\": 0.228, \"Tempo\": 148.035, \"Duration (ms)\": 263377.0, \"Valence\": 0.321, \"Chord\": \"C#/Db\"}, {\"Index\": 440, \"Highest Charting Position\": 146, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"That\\u2019s When (feat. Keith Urban) (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5889939, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7eResoqEJJAVTkQYSqvO3P\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 67.0, \"Danceability\": 0.588, \"Energy\": 0.608, \"Loudness\": -7.062, \"Speechiness\": 0.0365, \"Acousticness\": 0.225, \"Liveness\": 0.092, \"Tempo\": 90.201, \"Duration (ms)\": 189496.0, \"Valence\": 0.508, \"Chord\": \"F\"}, {\"Index\": 441, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Tell Me Why (Taylor\\u2019s Version)\", \"Streams\": 5885151, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0k0vFacOHNuArLWMiH60p7\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 63.0, \"Danceability\": 0.578, \"Energy\": 0.909, \"Loudness\": -3.669, \"Speechiness\": 0.0628, \"Acousticness\": 0.0222, \"Liveness\": 0.333, \"Tempo\": 100.023, \"Duration (ms)\": 200576.0, \"Valence\": 0.541, \"Chord\": \"G\"}, {\"Index\": 442, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"You\\u2019re Not Sorry (Taylor\\u2019s Version)\", \"Streams\": 5860405, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6iiAfo4wTA2CVC3Uwx9uh8\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 64.0, \"Danceability\": 0.506, \"Energy\": 0.444, \"Loudness\": -4.99, \"Speechiness\": 0.0285, \"Acousticness\": 0.0538, \"Liveness\": 0.123, \"Tempo\": 133.873, \"Duration (ms)\": 261843.0, \"Valence\": 0.241, \"Chord\": \"F#/Gb\"}, {\"Index\": 445, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Don\\u2019t You (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5197564, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"4uuEGH5SVuzkkSFjo2DEiY\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 65.0, \"Danceability\": 0.563, \"Energy\": 0.473, \"Loudness\": -11.548, \"Speechiness\": 0.0503, \"Acousticness\": 0.514, \"Liveness\": 0.109, \"Tempo\": 101.934, \"Duration (ms)\": 208609.0, \"Valence\": 0.405, \"Chord\": \"D#/Eb\"}, {\"Index\": 446, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"We Were Happy (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5189423, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"34V9RiEPe8MNdU32qJsJa1\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 64.0, \"Danceability\": 0.609, \"Energy\": 0.373, \"Loudness\": -8.819, \"Speechiness\": 0.0263, \"Acousticness\": 0.849, \"Liveness\": 0.0779, \"Tempo\": 106.007, \"Duration (ms)\": 244237.0, \"Valence\": 0.13, \"Chord\": \"C\"}, {\"Index\": 451, \"Highest Charting Position\": 88, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Hello (feat. A Boogie Wit da Hoodie)\", \"Streams\": 5323062, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"2r6OAV3WsYtXuXjvJ1lIDi\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-20\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 82.0, \"Danceability\": 0.905, \"Energy\": 0.647, \"Loudness\": -5.065, \"Speechiness\": 0.107, \"Acousticness\": 0.0187, \"Liveness\": 0.282, \"Tempo\": 130.97, \"Duration (ms)\": 190534.0, \"Valence\": 0.367, \"Chord\": \"A#/Bb\"}, {\"Index\": 454, \"Highest Charting Position\": 28, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Unstable (feat. The Kid LAROI)\", \"Streams\": 5137645, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"137mSruegm1u6x9NvwiagR\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 74.0, \"Danceability\": 0.495, \"Energy\": 0.333, \"Loudness\": -10.109, \"Speechiness\": 0.0288, \"Acousticness\": 0.737, \"Liveness\": 0.112, \"Tempo\": 99.757, \"Duration (ms)\": 158324.0, \"Valence\": 0.37, \"Chord\": \"E\"}, {\"Index\": 455, \"Highest Charting Position\": 2, \"Number of Times Charted\": 48, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Stuck with U (with Justin Bieber)\", \"Streams\": 5094660, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"4HBZA5flZLE435QTztThqH\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 84.0, \"Danceability\": 0.597, \"Energy\": 0.45, \"Loudness\": -6.658, \"Speechiness\": 0.0418, \"Acousticness\": 0.223, \"Liveness\": 0.382, \"Tempo\": 178.765, \"Duration (ms)\": 228482.0, \"Valence\": 0.537, \"Chord\": \"G#/Ab\"}, {\"Index\": 460, \"Highest Charting Position\": 50, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Ghost\", \"Streams\": 5013450, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6I3mqTwhRpn34SLVafSH7G\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 71.0, \"Danceability\": 0.601, \"Energy\": 0.741, \"Loudness\": -5.569, \"Speechiness\": 0.0478, \"Acousticness\": 0.185, \"Liveness\": 0.415, \"Tempo\": 153.96, \"Duration (ms)\": 153190.0, \"Valence\": 0.441, \"Chord\": \"D\"}, {\"Index\": 461, \"Highest Charting Position\": 37, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Off My Face\", \"Streams\": 5004111, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"3T03rPwlL8NVk1yIaxeD8U\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 75.0, \"Danceability\": 0.509, \"Energy\": 0.228, \"Loudness\": -8.68, \"Speechiness\": 0.0332, \"Acousticness\": 0.92, \"Liveness\": 0.104, \"Tempo\": 90.674, \"Duration (ms)\": 156468.0, \"Valence\": 0.586, \"Chord\": \"E\"}, {\"Index\": 467, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Deserve You\", \"Streams\": 5837372, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5NU40QTlXrDUJzDBdv79bg\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 69.0, \"Danceability\": 0.677, \"Energy\": 0.633, \"Loudness\": -7.831, \"Speechiness\": 0.0771, \"Acousticness\": 0.0314, \"Liveness\": 0.112, \"Tempo\": 89.934, \"Duration (ms)\": 187239.0, \"Valence\": 0.409, \"Chord\": \"G\"}, {\"Index\": 468, \"Highest Charting Position\": 44, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"2 Much\", \"Streams\": 5794583, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"0oaY19dUwZimIgzn3ZZLZO\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 70.0, \"Danceability\": 0.583, \"Energy\": 0.444, \"Loudness\": -8.601, \"Speechiness\": 0.0456, \"Acousticness\": 0.593, \"Liveness\": 0.353, \"Tempo\": 119.59, \"Duration (ms)\": 152796.0, \"Valence\": 0.167, \"Chord\": \"A\"}, {\"Index\": 471, \"Highest Charting Position\": 61, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Loved By You (feat. Burna Boy)\", \"Streams\": 5419040, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2tB9OFgAHjAds3cqquLlvp\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 69.0, \"Danceability\": 0.79, \"Energy\": 0.724, \"Loudness\": -6.972, \"Speechiness\": 0.0852, \"Acousticness\": 0.0696, \"Liveness\": 0.113, \"Tempo\": 101.04, \"Duration (ms)\": 159250.0, \"Valence\": 0.642, \"Chord\": \"C#/Db\"}, {\"Index\": 473, \"Highest Charting Position\": 17, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Lemon Pepper Freestyle (feat. Rick Ross)\", \"Streams\": 5365747, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"4FRW5Nza1Ym91BGV4nFWXI\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 76.0, \"Danceability\": 0.77, \"Energy\": 0.637, \"Loudness\": -5.53, \"Speechiness\": 0.345, \"Acousticness\": 0.103, \"Liveness\": 0.171, \"Tempo\": 94.966, \"Duration (ms)\": 383037.0, \"Valence\": 0.431, \"Chord\": \"C#/Db\"}, {\"Index\": 476, \"Highest Charting Position\": 57, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Die For You (feat. Dominic Fike)\", \"Streams\": 5323412, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"7aely3H8kMj9o0gt6vXHE1\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 67.0, \"Danceability\": 0.728, \"Energy\": 0.629, \"Loudness\": -6.629, \"Speechiness\": 0.0318, \"Acousticness\": 0.00196, \"Liveness\": 0.0847, \"Tempo\": 135.031, \"Duration (ms)\": 198426.0, \"Valence\": 0.71, \"Chord\": \"C#/Db\"}, {\"Index\": 480, \"Highest Charting Position\": 60, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Love You Different (feat. BEAM)\", \"Streams\": 10024729, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"27UcQ6dAvQrgH9C880rCM3\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-19--2021-03-26\", \"Popularity\": 66.0, \"Danceability\": 0.759, \"Energy\": 0.584, \"Loudness\": -6.655, \"Speechiness\": 0.06, \"Acousticness\": 0.0652, \"Liveness\": 0.16, \"Tempo\": 127.138, \"Duration (ms)\": 186696.0, \"Valence\": 0.374, \"Chord\": \"G#/Ab\"}, {\"Index\": 481, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Somebody\", \"Streams\": 8912458, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"3rLIv187BhjyweFe89SgLn\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2010-01-01\", \"Weeks Charted\": \"2021-03-19--2021-03-26\", \"Popularity\": 67.0, \"Danceability\": 0.714, \"Energy\": 0.833, \"Loudness\": -5.239, \"Speechiness\": 0.0259, \"Acousticness\": 0.00249, \"Liveness\": 0.298, \"Tempo\": 129.964, \"Duration (ms)\": 220920.0, \"Valence\": 0.663, \"Chord\": \"F\"}, {\"Index\": 490, \"Highest Charting Position\": 109, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"D\\u00e1melo To\\u2019 (feat. Myke Towers)\", \"Streams\": 6426522, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"36CiGk9oRdwTnBDMgKEfjl\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 64.0, \"Danceability\": 0.787, \"Energy\": 0.641, \"Loudness\": -7.376, \"Speechiness\": 0.315, \"Acousticness\": 0.101, \"Liveness\": 0.07, \"Tempo\": 182.003, \"Duration (ms)\": 184134.0, \"Valence\": 0.437, \"Chord\": \"G#/Ab\"}, {\"Index\": 497, \"Highest Charting Position\": 6, \"Number of Times Charted\": 60, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Say So\", \"Streams\": 5103528, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"3Dv1eDb0MEgF93GpLXlucZ\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-02-26--2021-03-05\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.787, \"Energy\": 0.673, \"Loudness\": -4.583, \"Speechiness\": 0.159, \"Acousticness\": 0.264, \"Liveness\": 0.0904, \"Tempo\": 110.962, \"Duration (ms)\": 237893.0, \"Valence\": 0.779, \"Chord\": \"B\"}, {\"Index\": 501, \"Highest Charting Position\": 12, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Mood Swings (feat. Lil Tjay)\", \"Streams\": 5068349, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"5rZlwNFl01HqLWBQGryKSm\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 82.0, \"Danceability\": 0.48, \"Energy\": 0.602, \"Loudness\": -6.335, \"Speechiness\": 0.368, \"Acousticness\": 0.487, \"Liveness\": 0.0848, \"Tempo\": 179.798, \"Duration (ms)\": 213333.0, \"Valence\": 0.269, \"Chord\": \"A#/Bb\"}, {\"Index\": 507, \"Highest Charting Position\": 64, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"AP - Music from the film Boogie\", \"Streams\": 5462333, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"17vGPZ5EsdvtgAOCD4FLWI\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\", \"Popularity\": 75.0, \"Danceability\": 0.751, \"Energy\": 0.744, \"Loudness\": -6.859, \"Speechiness\": 0.177, \"Acousticness\": 0.152, \"Liveness\": 0.252, \"Tempo\": 148.014, \"Duration (ms)\": 171892.0, \"Valence\": 0.634, \"Chord\": \"C#/Db\"}, {\"Index\": 508, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Life's A Mess II (with Clever & Post Malone)\", \"Streams\": 5393459, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4O3RwH1TFG1EjPezLIYehI\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 72.0, \"Danceability\": 0.53, \"Energy\": 0.37, \"Loudness\": -9.989, \"Speechiness\": 0.0279, \"Acousticness\": 0.806, \"Liveness\": 0.112, \"Tempo\": 140.061, \"Duration (ms)\": 206734.0, \"Valence\": 0.701, \"Chord\": \"F#/Gb\"}, {\"Index\": 519, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"test drive\", \"Streams\": 6591829, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3eZYOQO4UzKrUDYDghtnFw\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-02-19\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 71.0, \"Danceability\": 0.698, \"Energy\": 0.708, \"Loudness\": -4.943, \"Speechiness\": 0.0454, \"Acousticness\": 0.0251, \"Liveness\": 0.124, \"Tempo\": 115.036, \"Duration (ms)\": 122174.0, \"Valence\": 0.322, \"Chord\": \"A\"}, {\"Index\": 527, \"Highest Charting Position\": 33, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"BOOKER T\", \"Streams\": 4995965, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"26w9NTiE9NGjW1ZvIOd1So\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 77.0, \"Danceability\": 0.883, \"Energy\": 0.6, \"Loudness\": -7.188, \"Speechiness\": 0.37, \"Acousticness\": 0.114, \"Liveness\": 0.0931, \"Tempo\": 113.903, \"Duration (ms)\": 156430.0, \"Valence\": 0.691, \"Chord\": \"G\"}, {\"Index\": 528, \"Highest Charting Position\": 5, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Intentions (feat. Quavo)\", \"Streams\": 4994138, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"4umIPjkehX1r7uhmGvXiSV\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 77.0, \"Danceability\": 0.806, \"Energy\": 0.546, \"Loudness\": -6.637, \"Speechiness\": 0.0575, \"Acousticness\": 0.3, \"Liveness\": 0.102, \"Tempo\": 147.986, \"Duration (ms)\": 212867.0, \"Valence\": 0.874, \"Chord\": \"A\"}, {\"Index\": 531, \"Highest Charting Position\": 20, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"34+35 Remix (feat. Doja Cat, Megan Thee Stallion) - Remix\", \"Streams\": 6162453, \"Artist\": \"Ariana Grande\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 541, \"Highest Charting Position\": 14, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"motive (with Doja Cat)\", \"Streams\": 4986037, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"5GkQIP5mWPi4KZLLXeuFTT\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 80.0, \"Danceability\": 0.789, \"Energy\": 0.742, \"Loudness\": -5.664, \"Speechiness\": 0.0652, \"Acousticness\": 0.0681, \"Liveness\": 0.166, \"Tempo\": 116.965, \"Duration (ms)\": 167990.0, \"Valence\": 0.661, \"Chord\": \"A#/Bb\"}, {\"Index\": 550, \"Highest Charting Position\": 2, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Toosie Slide\", \"Streams\": 4966878, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"127QTOFJsJQp5LbJbu3A1y\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 78.0, \"Danceability\": 0.834, \"Energy\": 0.454, \"Loudness\": -9.75, \"Speechiness\": 0.201, \"Acousticness\": 0.321, \"Liveness\": 0.114, \"Tempo\": 81.618, \"Duration (ms)\": 247059.0, \"Valence\": 0.837, \"Chord\": \"C#/Db\"}, {\"Index\": 551, \"Highest Charting Position\": 167, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Earned It (Fifty Shades Of Grey)\", \"Streams\": 4929647, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"4frLb7nWtsz2ymBE6k2GRP\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2015-08-28\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 69.0, \"Danceability\": 0.659, \"Energy\": 0.291, \"Loudness\": -8.275, \"Speechiness\": 0.0348, \"Acousticness\": 0.405, \"Liveness\": 0.0771, \"Tempo\": 119.829, \"Duration (ms)\": 277680.0, \"Valence\": 0.406, \"Chord\": \"D\"}, {\"Index\": 555, \"Highest Charting Position\": 27, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Bad Boy (with Young Thug)\", \"Streams\": 6011642, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"43CIWpJaJHRcI4mUSjqgc2\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 76.0, \"Danceability\": 0.697, \"Energy\": 0.674, \"Loudness\": -6.326, \"Speechiness\": 0.0533, \"Acousticness\": 0.00215, \"Liveness\": 0.138, \"Tempo\": 81.535, \"Duration (ms)\": 157355.0, \"Valence\": 0.198, \"Chord\": \"C#/Db\"}, {\"Index\": 556, \"Highest Charting Position\": 19, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Lo Vas A Olvidar (with ROSAL\\u00cdA)\", \"Streams\": 5963380, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"0psS4i5YooJrXfDnGvWRLi\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 68.0, \"Danceability\": 0.343, \"Energy\": 0.243, \"Loudness\": -14.66, \"Speechiness\": 0.0777, \"Acousticness\": 0.721, \"Liveness\": 0.0668, \"Tempo\": 135.154, \"Duration (ms)\": 203464.0, \"Valence\": 0.032, \"Chord\": \"E\"}, {\"Index\": 558, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Can't Feel My Face\", \"Streams\": 5479407, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"22VdIZQfgXJea34mQxlt81\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2015-08-28\", \"Weeks Charted\": \"2021-02-05--2021-02-12\", \"Popularity\": 80.0, \"Danceability\": 0.705, \"Energy\": 0.769, \"Loudness\": -5.526, \"Speechiness\": 0.0425, \"Acousticness\": 0.113, \"Liveness\": 0.105, \"Tempo\": 107.949, \"Duration (ms)\": 213520.0, \"Valence\": 0.583, \"Chord\": \"A\"}, {\"Index\": 560, \"Highest Charting Position\": 168, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Call Out My Name\", \"Streams\": 5233359, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"09mEdoA6zrmBPgTEN5qXmN\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2018-03-30\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\", \"Popularity\": 80.0, \"Danceability\": 0.461, \"Energy\": 0.593, \"Loudness\": -4.954, \"Speechiness\": 0.0356, \"Acousticness\": 0.17, \"Liveness\": 0.307, \"Tempo\": 134.17, \"Duration (ms)\": 228373.0, \"Valence\": 0.175, \"Chord\": \"C#/Db\"}, {\"Index\": 566, \"Highest Charting Position\": 18, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Heartless\", \"Streams\": 4995578, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"6bnF93Rx87YqUBLSgjiMU8\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.537, \"Energy\": 0.746, \"Loudness\": -5.507, \"Speechiness\": 0.15, \"Acousticness\": 0.0236, \"Liveness\": 0.156, \"Tempo\": 170.062, \"Duration (ms)\": 198267.0, \"Valence\": 0.252, \"Chord\": \"A#/Bb\"}, {\"Index\": 567, \"Highest Charting Position\": 20, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"pov\", \"Streams\": 4906738, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3UoULw70kMsiVXxW0L3A33\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 79.0, \"Danceability\": 0.487, \"Energy\": 0.534, \"Loudness\": -5.664, \"Speechiness\": 0.0555, \"Acousticness\": 0.36, \"Liveness\": 0.1, \"Tempo\": 131.798, \"Duration (ms)\": 201882.0, \"Valence\": 0.173, \"Chord\": \"C\"}, {\"Index\": 581, \"Highest Charting Position\": 66, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"De Una Vez\", \"Streams\": 5186567, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"1v3lhrZEsOcazqR2QIyyRu\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 70.0, \"Danceability\": 0.659, \"Energy\": 0.479, \"Loudness\": -6.79, \"Speechiness\": 0.2, \"Acousticness\": 0.152, \"Liveness\": 0.268, \"Tempo\": 163.882, \"Duration (ms)\": 155956.0, \"Valence\": 0.0395, \"Chord\": \"B\"}, {\"Index\": 586, \"Highest Charting Position\": 10, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"champagne problems\", \"Streams\": 4848954, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0sY6ZUTh4yoctD8VIXz339\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 75.0, \"Danceability\": 0.462, \"Energy\": 0.24, \"Loudness\": -12.077, \"Speechiness\": 0.0377, \"Acousticness\": 0.92, \"Liveness\": 0.113, \"Tempo\": 171.319, \"Duration (ms)\": 244000.0, \"Valence\": 0.32, \"Chord\": \"C\"}, {\"Index\": 599, \"Highest Charting Position\": 21, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"HACIENDO QUE ME AMAS\", \"Streams\": 4935633, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"26QApq0cuO9brJigr0C0W4\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 78.0, \"Danceability\": 0.584, \"Energy\": 0.411, \"Loudness\": -7.147, \"Speechiness\": 0.0838, \"Acousticness\": 0.869, \"Liveness\": 0.0955, \"Tempo\": 169.934, \"Duration (ms)\": 217769.0, \"Valence\": 0.412, \"Chord\": \"A#/Bb\"}, {\"Index\": 601, \"Highest Charting Position\": 17, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"The Woo (feat. 50 Cent & Roddy Ricch)\", \"Streams\": 4892682, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"1H7KnK26kc1YyellpbINEn\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 79.0, \"Danceability\": 0.49, \"Energy\": 0.618, \"Loudness\": -5.655, \"Speechiness\": 0.104, \"Acousticness\": 0.0221, \"Liveness\": 0.259, \"Tempo\": 99.7, \"Duration (ms)\": 201600.0, \"Valence\": 0.286, \"Chord\": \"C#/Db\"}, {\"Index\": 609, \"Highest Charting Position\": 15, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"no body, no crime (feat. HAIM)\", \"Streams\": 4986214, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3RaT22zZsxVYxxKR7TAaYF\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 68.0, \"Danceability\": 0.546, \"Energy\": 0.613, \"Loudness\": -7.589, \"Speechiness\": 0.0264, \"Acousticness\": 0.418, \"Liveness\": 0.103, \"Tempo\": 79.015, \"Duration (ms)\": 215627.0, \"Valence\": 0.535, \"Chord\": \"G\"}, {\"Index\": 622, \"Highest Charting Position\": 3, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Tell Me\", \"Streams\": 16657592, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"0lizgQ7Qw35od7CYaoMBZb\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2014-11-24\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 61.0, \"Danceability\": 0.525, \"Energy\": 0.621, \"Loudness\": -7.364, \"Speechiness\": 0.116, \"Acousticness\": 0.0489, \"Liveness\": 0.294, \"Tempo\": 191.9, \"Duration (ms)\": 204093.0, \"Valence\": 0.591, \"Chord\": \"G\"}, {\"Index\": 631, \"Highest Charting Position\": 15, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Mistletoe\", \"Streams\": 10609206, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"7xapw9Oy21WpfEcib2ErSA\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2011-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 59.0, \"Danceability\": 0.657, \"Energy\": 0.56, \"Loudness\": -9.049, \"Speechiness\": 0.0467, \"Acousticness\": 0.498, \"Liveness\": 0.0794, \"Tempo\": 161.993, \"Duration (ms)\": 182947.0, \"Valence\": 0.854, \"Chord\": \"F#/Gb\"}, {\"Index\": 664, \"Highest Charting Position\": 107, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Gnat\", \"Streams\": 8614955, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"6cS9PmLky2NhLOhpIsUlow\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 70.0, \"Danceability\": 0.835, \"Energy\": 0.869, \"Loudness\": -4.582, \"Speechiness\": 0.27, \"Acousticness\": 0.248, \"Liveness\": 0.462, \"Tempo\": 140.945, \"Duration (ms)\": 224656.0, \"Valence\": 0.82, \"Chord\": \"A#/Bb\"}, {\"Index\": 668, \"Highest Charting Position\": 22, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"\\u2018tis the damn season\", \"Streams\": 8115520, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7dW84mWkdWE5a6lFWxJCBG\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.575, \"Energy\": 0.434, \"Loudness\": -8.193, \"Speechiness\": 0.0312, \"Acousticness\": 0.735, \"Liveness\": 0.105, \"Tempo\": 145.916, \"Duration (ms)\": 229840.0, \"Valence\": 0.348, \"Chord\": \"F\"}, {\"Index\": 672, \"Highest Charting Position\": 19, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"gold rush\", \"Streams\": 7901968, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5BK0uqwY9DNfZ630STAEaq\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 70.0, \"Danceability\": 0.512, \"Energy\": 0.462, \"Loudness\": -10.491, \"Speechiness\": 0.0408, \"Acousticness\": 0.83, \"Liveness\": 0.121, \"Tempo\": 112.05, \"Duration (ms)\": 185320.0, \"Valence\": 0.353, \"Chord\": \"A\"}, {\"Index\": 689, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas Tree Farm\", \"Streams\": 6657404, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2mvabkN1i2gLnGAPUVdwek\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 52.0, \"Danceability\": 0.598, \"Energy\": 0.68, \"Loudness\": -4.505, \"Speechiness\": 0.0331, \"Acousticness\": 0.06, \"Liveness\": 0.324, \"Tempo\": 134.002, \"Duration (ms)\": 228027.0, \"Valence\": 0.437, \"Chord\": \"G\"}, {\"Index\": 692, \"Highest Charting Position\": 24, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"tolerate it\", \"Streams\": 6635109, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0PurA4JVJ8YQgSVopY8fn6\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 67.0, \"Danceability\": 0.316, \"Energy\": 0.361, \"Loudness\": -10.381, \"Speechiness\": 0.0488, \"Acousticness\": 0.878, \"Liveness\": 0.0797, \"Tempo\": 74.952, \"Duration (ms)\": 245440.0, \"Valence\": 0.221, \"Chord\": \"A\"}, {\"Index\": 695, \"Highest Charting Position\": 28, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"happiness\", \"Streams\": 16213589, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"73YUReisjb3A9ActdLLjJQ\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 65.0, \"Danceability\": 0.559, \"Energy\": 0.334, \"Loudness\": -10.733, \"Speechiness\": 0.0376, \"Acousticness\": 0.87, \"Liveness\": 0.114, \"Tempo\": 122.079, \"Duration (ms)\": 315147.0, \"Valence\": 0.211, \"Chord\": \"B\"}, {\"Index\": 696, \"Highest Charting Position\": 34, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"ivy\", \"Streams\": 14519547, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"19CSr8rwW05VJL2F91KFNK\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.515, \"Energy\": 0.545, \"Loudness\": -9.277, \"Speechiness\": 0.0353, \"Acousticness\": 0.855, \"Liveness\": 0.0921, \"Tempo\": 88.856, \"Duration (ms)\": 260440.0, \"Valence\": 0.535, \"Chord\": \"D\"}, {\"Index\": 697, \"Highest Charting Position\": 38, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"dorothea\", \"Streams\": 14392788, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"670fUmXf4KQekzbEgaXyPA\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.605, \"Energy\": 0.488, \"Loudness\": -8.322, \"Speechiness\": 0.0264, \"Acousticness\": 0.696, \"Liveness\": 0.129, \"Tempo\": 119.966, \"Duration (ms)\": 225880.0, \"Valence\": 0.354, \"Chord\": \"E\"}, {\"Index\": 698, \"Highest Charting Position\": 39, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"coney island (feat. The National)\", \"Streams\": 14385703, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3k7ne7VmH43ZPWxPdvPUgR\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.537, \"Energy\": 0.537, \"Loudness\": -11.266, \"Speechiness\": 0.0617, \"Acousticness\": 0.819, \"Liveness\": 0.142, \"Tempo\": 107.895, \"Duration (ms)\": 275320.0, \"Valence\": 0.292, \"Chord\": \"G#/Ab\"}, {\"Index\": 699, \"Highest Charting Position\": 43, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"evermore (feat. Bon Iver)\", \"Streams\": 13810722, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3O5osWf1rSoKMwe6E9ZaXP\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.39, \"Energy\": 0.27, \"Loudness\": -10.673, \"Speechiness\": 0.0308, \"Acousticness\": 0.937, \"Liveness\": 0.111, \"Tempo\": 125.177, \"Duration (ms)\": 304107.0, \"Valence\": 0.32, \"Chord\": \"C#/Db\"}, {\"Index\": 700, \"Highest Charting Position\": 45, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"long story short\", \"Streams\": 13583538, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2o2sgVJIgFXk8GQjWTgI6U\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.546, \"Energy\": 0.73, \"Loudness\": -7.704, \"Speechiness\": 0.0417, \"Acousticness\": 0.66, \"Liveness\": 0.0972, \"Tempo\": 157.895, \"Duration (ms)\": 215920.0, \"Valence\": 0.573, \"Chord\": \"C\"}, {\"Index\": 701, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"cowboy like me\", \"Streams\": 12782098, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1XjHRolIXL2M1EEOUsGGR4\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.604, \"Energy\": 0.517, \"Loudness\": -9.014, \"Speechiness\": 0.0347, \"Acousticness\": 0.768, \"Liveness\": 0.123, \"Tempo\": 127.967, \"Duration (ms)\": 275040.0, \"Valence\": 0.511, \"Chord\": \"C\"}, {\"Index\": 702, \"Highest Charting Position\": 57, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"marjorie\", \"Streams\": 12234761, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"12ntTeqEeTg7GAVpe8Mhpl\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.535, \"Energy\": 0.561, \"Loudness\": -11.609, \"Speechiness\": 0.0484, \"Acousticness\": 0.876, \"Liveness\": 0.115, \"Tempo\": 96.103, \"Duration (ms)\": 257773.0, \"Valence\": 0.287, \"Chord\": \"F\"}, {\"Index\": 703, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"closure\", \"Streams\": 11245393, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"35rdVq36LMHQX0Suw9a6tK\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 62.0, \"Danceability\": 0.689, \"Energy\": 0.704, \"Loudness\": -10.813, \"Speechiness\": 0.245, \"Acousticness\": 0.835, \"Liveness\": 0.134, \"Tempo\": 151.884, \"Duration (ms)\": 180653.0, \"Valence\": 0.92, \"Chord\": \"A\"}, {\"Index\": 711, \"Highest Charting Position\": 17, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"YO VISTO AS\\u00cd\", \"Streams\": 6388079, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5fROvzNghPid8mbKNDYvpJ\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 73.0, \"Danceability\": 0.688, \"Energy\": 0.881, \"Loudness\": -4.889, \"Speechiness\": 0.0474, \"Acousticness\": 0.0947, \"Liveness\": 0.0804, \"Tempo\": 123.013, \"Duration (ms)\": 191526.0, \"Valence\": 0.677, \"Chord\": \"G\"}, {\"Index\": 714, \"Highest Charting Position\": 1, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"cardigan\", \"Streams\": 5845457, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"4R2kfaDFhslZEMJqAFNpdd\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-12-11--2020-12-18\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 79.0, \"Danceability\": 0.613, \"Energy\": 0.581, \"Loudness\": -8.588, \"Speechiness\": 0.0424, \"Acousticness\": 0.537, \"Liveness\": 0.25, \"Tempo\": 130.033, \"Duration (ms)\": 239560.0, \"Valence\": 0.551, \"Chord\": \"C\"}, {\"Index\": 715, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Real Shit (with benny blanco)\", \"Streams\": 9325928, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"3uVPLtkmDu8pDkYEAVqbgS\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-12-02\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 70.0, \"Danceability\": 0.703, \"Energy\": 0.703, \"Loudness\": -4.672, \"Speechiness\": 0.133, \"Acousticness\": 0.605, \"Liveness\": 0.12, \"Tempo\": 76.017, \"Duration (ms)\": 183783.0, \"Valence\": 0.697, \"Chord\": \"C#/Db\"}, {\"Index\": 717, \"Highest Charting Position\": 138, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Blinding Lights (with ROSAL\\u00cdA) - Remix\", \"Streams\": 6653913, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"7MXgrcOQAJ5VwSNUL0lDd3\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 64.0, \"Danceability\": 0.49, \"Energy\": 0.694, \"Loudness\": -5.793, \"Speechiness\": 0.0618, \"Acousticness\": 0.0133, \"Liveness\": 0.0946, \"Tempo\": 170.903, \"Duration (ms)\": 216123.0, \"Valence\": 0.249, \"Chord\": \"F\"}, {\"Index\": 719, \"Highest Charting Position\": 29, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"TE DESEO LO MEJOR\", \"Streams\": 6204228, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"23XjN1s3DZC8Q9ZwuorYY4\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.763, \"Energy\": 0.597, \"Loudness\": -5.054, \"Speechiness\": 0.0416, \"Acousticness\": 0.158, \"Liveness\": 0.111, \"Tempo\": 126.054, \"Duration (ms)\": 139576.0, \"Valence\": 0.194, \"Chord\": \"C#/Db\"}, {\"Index\": 722, \"Highest Charting Position\": 18, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Blue & Grey\", \"Streams\": 5698275, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"0n2moJpAEWHwaPYYjkzMDl\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 77.0, \"Danceability\": 0.547, \"Energy\": 0.605, \"Loudness\": -6.755, \"Speechiness\": 0.0415, \"Acousticness\": 0.42, \"Liveness\": 0.125, \"Tempo\": 121.953, \"Duration (ms)\": 254950.0, \"Valence\": 0.364, \"Chord\": \"G#/Ab\"}, {\"Index\": 725, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"LA DROGA\", \"Streams\": 5375449, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"67ACYA3UI6QMNtHX6b34wX\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.643, \"Energy\": 0.727, \"Loudness\": -5.506, \"Speechiness\": 0.0389, \"Acousticness\": 0.0439, \"Liveness\": 0.123, \"Tempo\": 90.019, \"Duration (ms)\": 162299.0, \"Valence\": 0.295, \"Chord\": \"C#/Db\"}, {\"Index\": 729, \"Highest Charting Position\": 41, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"HOY COBR\\u00c9\", \"Streams\": 12914431, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0tjZv2hChdHZCW1zFXpy1J\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.86, \"Energy\": 0.725, \"Loudness\": -6.7, \"Speechiness\": 0.249, \"Acousticness\": 0.0464, \"Liveness\": 0.0994, \"Tempo\": 145.001, \"Duration (ms)\": 162151.0, \"Valence\": 0.375, \"Chord\": \"B\"}, {\"Index\": 730, \"Highest Charting Position\": 44, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"MALDITA POBREZA\", \"Streams\": 12660806, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0Lsis3LB0XAK6XlTHXaJk2\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 67.0, \"Danceability\": 0.762, \"Energy\": 0.861, \"Loudness\": -4.075, \"Speechiness\": 0.0652, \"Acousticness\": 0.139, \"Liveness\": 0.0956, \"Tempo\": 133.037, \"Duration (ms)\": 213609.0, \"Valence\": 0.588, \"Chord\": \"E\"}, {\"Index\": 731, \"Highest Charting Position\": 48, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"EL MUNDO ES M\\u00cdO\", \"Streams\": 12507010, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"36DHxTW2xdr9GG15T9oK9L\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 67.0, \"Danceability\": 0.716, \"Energy\": 0.522, \"Loudness\": -6.834, \"Speechiness\": 0.0582, \"Acousticness\": 0.166, \"Liveness\": 0.113, \"Tempo\": 76.993, \"Duration (ms)\": 165199.0, \"Valence\": 0.224, \"Chord\": \"F\"}, {\"Index\": 732, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"ANTES QUE SE ACABE\", \"Streams\": 11298839, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"7kjEqI6eZ7YlFrGhxixnlN\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 76.0, \"Danceability\": 0.693, \"Energy\": 0.549, \"Loudness\": -6.098, \"Speechiness\": 0.0577, \"Acousticness\": 0.505, \"Liveness\": 0.324, \"Tempo\": 139.988, \"Duration (ms)\": 221187.0, \"Valence\": 0.473, \"Chord\": \"D\"}, {\"Index\": 734, \"Highest Charting Position\": 63, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"120\", \"Streams\": 10957181, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3KJ3opyV29269SXkPrc19l\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 72.0, \"Danceability\": 0.636, \"Energy\": 0.656, \"Loudness\": -5.542, \"Speechiness\": 0.0676, \"Acousticness\": 0.451, \"Liveness\": 0.287, \"Tempo\": 171.918, \"Duration (ms)\": 151506.0, \"Valence\": 0.439, \"Chord\": \"D\"}, {\"Index\": 735, \"Highest Charting Position\": 66, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"TRELLAS\", \"Streams\": 10733416, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"09WAnxdBuebQopKhJT3oZS\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 66.0, \"Danceability\": 0.43, \"Energy\": 0.412, \"Loudness\": -5.372, \"Speechiness\": 0.0281, \"Acousticness\": 0.2, \"Liveness\": 0.324, \"Tempo\": 90.872, \"Duration (ms)\": 157673.0, \"Valence\": 0.0508, \"Chord\": \"D\"}, {\"Index\": 737, \"Highest Charting Position\": 16, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Fly To My Room\", \"Streams\": 8413330, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3QH8rQGNFX8VLbCgZ7uPTS\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 76.0, \"Danceability\": 0.764, \"Energy\": 0.526, \"Loudness\": -7.355, \"Speechiness\": 0.212, \"Acousticness\": 0.0484, \"Liveness\": 0.0718, \"Tempo\": 114.91, \"Duration (ms)\": 222243.0, \"Valence\": 0.588, \"Chord\": \"B\"}, {\"Index\": 738, \"Highest Charting Position\": 24, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Telepathy\", \"Streams\": 7703744, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"2FVpOsjT1iquZ3SpCjZ9Ne\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 77.0, \"Danceability\": 0.787, \"Energy\": 0.669, \"Loudness\": -4.333, \"Speechiness\": 0.0428, \"Acousticness\": 0.00782, \"Liveness\": 0.123, \"Tempo\": 104.994, \"Duration (ms)\": 202313.0, \"Valence\": 0.57, \"Chord\": \"F\"}, {\"Index\": 739, \"Highest Charting Position\": 26, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Dis-ease\", \"Streams\": 7165808, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"54DmTIv86D3sYdiawjULQ0\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 75.0, \"Danceability\": 0.731, \"Energy\": 0.845, \"Loudness\": -5.352, \"Speechiness\": 0.132, \"Acousticness\": 0.0132, \"Liveness\": 0.0782, \"Tempo\": 101.085, \"Duration (ms)\": 239722.0, \"Valence\": 0.484, \"Chord\": \"G#/Ab\"}, {\"Index\": 740, \"Highest Charting Position\": 27, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Stay\", \"Streams\": 7010227, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3ndCsZfq8OVwwkz9mmZvUz\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 76.0, \"Danceability\": 0.582, \"Energy\": 0.693, \"Loudness\": -5.048, \"Speechiness\": 0.0465, \"Acousticness\": 0.114, \"Liveness\": 0.13, \"Tempo\": 125.904, \"Duration (ms)\": 204800.0, \"Valence\": 0.341, \"Chord\": \"F#/Gb\"}, {\"Index\": 745, \"Highest Charting Position\": 78, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Skit\", \"Streams\": 8392247, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4GVwjLRT7oSsKby7Vy8EHr\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 60.0, \"Danceability\": 0.703, \"Energy\": 0.321, \"Loudness\": -13.135, \"Speechiness\": 0.884, \"Acousticness\": 0.864, \"Liveness\": 0.908, \"Tempo\": 114.822, \"Duration (ms)\": 179548.0, \"Valence\": 0.544, \"Chord\": \"E\"}, {\"Index\": 755, \"Highest Charting Position\": 7, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Smile (with The Weeknd)\", \"Streams\": 5164187, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"6wQlQrTY5mVS8EGaFZVwVF\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 75.0, \"Danceability\": 0.694, \"Energy\": 0.685, \"Loudness\": -6.535, \"Speechiness\": 0.133, \"Acousticness\": 0.224, \"Liveness\": 0.124, \"Tempo\": 158.831, \"Duration (ms)\": 196180.0, \"Valence\": 0.306, \"Chord\": \"F#/Gb\"}, {\"Index\": 772, \"Highest Charting Position\": 20, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"off the table (with The Weeknd)\", \"Streams\": 5308945, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"7E1jVNoWuemqUryI4FxsVD\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 67.0, \"Danceability\": 0.411, \"Energy\": 0.522, \"Loudness\": -7.295, \"Speechiness\": 0.0981, \"Acousticness\": 0.519, \"Liveness\": 0.398, \"Tempo\": 88.332, \"Duration (ms)\": 239949.0, \"Valence\": 0.382, \"Chord\": \"C\"}, {\"Index\": 779, \"Highest Charting Position\": 25, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"just like magic\", \"Streams\": 4980571, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"7Dx9Z6Aon1qPS2N0rHSWTe\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 69.0, \"Danceability\": 0.719, \"Energy\": 0.607, \"Loudness\": -5.156, \"Speechiness\": 0.165, \"Acousticness\": 0.08, \"Liveness\": 0.125, \"Tempo\": 128.006, \"Duration (ms)\": 149900.0, \"Valence\": 0.464, \"Chord\": \"G#/Ab\"}, {\"Index\": 788, \"Highest Charting Position\": 5, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"my future\", \"Streams\": 4721082, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"3YUMWmx8EJq0DurfuIwoGh\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-07-30\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 80.0, \"Danceability\": 0.456, \"Energy\": 0.285, \"Loudness\": -10.755, \"Speechiness\": 0.0979, \"Acousticness\": 0.814, \"Liveness\": 0.307, \"Tempo\": 104.89, \"Duration (ms)\": 210005.0, \"Valence\": 0.0809, \"Chord\": \"G#/Ab\"}, {\"Index\": 790, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"safety net (feat. Ty Dolla $ign)\", \"Streams\": 5798744, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"14gkWVFMwdxBMyqBw1wmIg\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 70.0, \"Danceability\": 0.552, \"Energy\": 0.599, \"Loudness\": -5.75, \"Speechiness\": 0.0404, \"Acousticness\": 0.0703, \"Liveness\": 0.0986, \"Tempo\": 161.884, \"Duration (ms)\": 208457.0, \"Valence\": 0.0916, \"Chord\": \"C#/Db\"}, {\"Index\": 791, \"Highest Charting Position\": 31, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"shut up\", \"Streams\": 5282490, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3ko9jEHNt4O5fjKN65ULJp\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 63.0, \"Danceability\": 0.499, \"Energy\": 0.462, \"Loudness\": -5.308, \"Speechiness\": 0.0312, \"Acousticness\": 0.801, \"Liveness\": 0.0946, \"Tempo\": 127.698, \"Duration (ms)\": 157710.0, \"Valence\": 0.599, \"Chord\": \"C\"}, {\"Index\": 792, \"Highest Charting Position\": 42, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"nasty\", \"Streams\": 5249342, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"0sci7ppTZFm4mjcH3nu8yO\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 69.0, \"Danceability\": 0.772, \"Energy\": 0.506, \"Loudness\": -6.558, \"Speechiness\": 0.139, \"Acousticness\": 0.0814, \"Liveness\": 0.182, \"Tempo\": 127.894, \"Duration (ms)\": 200733.0, \"Valence\": 0.456, \"Chord\": \"F#/Gb\"}, {\"Index\": 798, \"Highest Charting Position\": 41, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Got It On Me\", \"Streams\": 4924030, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"25zlnOAzbVoOzIeXSvQFf1\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 78.0, \"Danceability\": 0.688, \"Energy\": 0.647, \"Loudness\": -7.258, \"Speechiness\": 0.19, \"Acousticness\": 0.00815, \"Liveness\": 0.095, \"Tempo\": 88.834, \"Duration (ms)\": 164580.0, \"Valence\": 0.195, \"Chord\": \"D\"}, {\"Index\": 799, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"my hair\", \"Streams\": 4896521, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"6u7gmPOz7pzzaeR9xSBpsR\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 66.0, \"Danceability\": 0.686, \"Energy\": 0.526, \"Loudness\": -6.842, \"Speechiness\": 0.0374, \"Acousticness\": 0.0815, \"Liveness\": 0.144, \"Tempo\": 92.013, \"Duration (ms)\": 158436.0, \"Valence\": 0.372, \"Chord\": \"C\"}, {\"Index\": 800, \"Highest Charting Position\": 59, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"obvious\", \"Streams\": 4865084, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"0q85C1JiECyYIQthz1posA\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 65.0, \"Danceability\": 0.624, \"Energy\": 0.672, \"Loudness\": -5.334, \"Speechiness\": 0.106, \"Acousticness\": 0.0967, \"Liveness\": 0.155, \"Tempo\": 159.852, \"Duration (ms)\": 146959.0, \"Valence\": 0.26, \"Chord\": \"C\"}, {\"Index\": 805, \"Highest Charting Position\": 51, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"six thirty\", \"Streams\": 10941573, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"2IKJtXeR5UsaUjZB46fTOK\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 63.0, \"Danceability\": 0.739, \"Energy\": 0.516, \"Loudness\": -7.154, \"Speechiness\": 0.0539, \"Acousticness\": 0.67, \"Liveness\": 0.151, \"Tempo\": 120.109, \"Duration (ms)\": 183874.0, \"Valence\": 0.434, \"Chord\": \"C\"}, {\"Index\": 806, \"Highest Charting Position\": 65, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"love language\", \"Streams\": 9399230, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"6NYtLvyThMT0oALFdJFdzq\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 62.0, \"Danceability\": 0.688, \"Energy\": 0.573, \"Loudness\": -5.03, \"Speechiness\": 0.208, \"Acousticness\": 0.0686, \"Liveness\": 0.0749, \"Tempo\": 110.034, \"Duration (ms)\": 179861.0, \"Valence\": 0.553, \"Chord\": \"A#/Bb\"}, {\"Index\": 807, \"Highest Charting Position\": 66, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"west side\", \"Streams\": 9397167, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"1whfVLMKWqAX3uk97VXsNN\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 62.0, \"Danceability\": 0.688, \"Energy\": 0.455, \"Loudness\": -8.632, \"Speechiness\": 0.199, \"Acousticness\": 0.186, \"Liveness\": 0.0794, \"Tempo\": 87.865, \"Duration (ms)\": 132279.0, \"Valence\": 0.557, \"Chord\": \"B\"}, {\"Index\": 819, \"Highest Charting Position\": 88, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"thank u, next\", \"Streams\": 5079328, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3e9HZxeyfWwjeyPAMmWSSQ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-02-08\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.717, \"Energy\": 0.653, \"Loudness\": -5.634, \"Speechiness\": 0.0658, \"Acousticness\": 0.229, \"Liveness\": 0.101, \"Tempo\": 106.966, \"Duration (ms)\": 207320.0, \"Valence\": 0.412, \"Chord\": \"C#/Db\"}, {\"Index\": 838, \"Highest Charting Position\": 18, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Yo Perreo Sola\", \"Streams\": 4680447, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0SqqAgdovOE24BzxIClpjw\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 78.0, \"Danceability\": 0.86, \"Energy\": 0.758, \"Loudness\": -5.16, \"Speechiness\": 0.0695, \"Acousticness\": 0.021, \"Liveness\": 0.344, \"Tempo\": 97.014, \"Duration (ms)\": 172127.0, \"Valence\": 0.453, \"Chord\": \"B\"}, {\"Index\": 890, \"Highest Charting Position\": 4, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"exile (feat. Bon Iver)\", \"Streams\": 4924533, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"4pvb0WLRcMtbPGmtejJJ6y\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 77.0, \"Danceability\": 0.298, \"Energy\": 0.38, \"Loudness\": -8.426, \"Speechiness\": 0.0287, \"Acousticness\": 0.778, \"Liveness\": 0.11, \"Tempo\": 75.602, \"Duration (ms)\": 285634.0, \"Valence\": 0.152, \"Chord\": \"F#/Gb\"}, {\"Index\": 891, \"Highest Charting Position\": 10, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Righteous\", \"Streams\": 4819362, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5dOxHHMOFAbG3VH23t0xNm\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 78.0, \"Danceability\": 0.706, \"Energy\": 0.625, \"Loudness\": -7.426, \"Speechiness\": 0.0314, \"Acousticness\": 0.0417, \"Liveness\": 0.129, \"Tempo\": 142.948, \"Duration (ms)\": 242181.0, \"Valence\": 0.225, \"Chord\": \"C\"}, {\"Index\": 892, \"Highest Charting Position\": 9, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Conversations\", \"Streams\": 4805366, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4K06PO78fW4mnBVenxGNob\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 75.0, \"Danceability\": 0.747, \"Energy\": 0.622, \"Loudness\": -5.825, \"Speechiness\": 0.0838, \"Acousticness\": 0.176, \"Liveness\": 0.151, \"Tempo\": 159.93, \"Duration (ms)\": 181661.0, \"Valence\": 0.57, \"Chord\": \"B\"}, {\"Index\": 894, \"Highest Charting Position\": 23, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Chicago Freestyle (feat. Giveon)\", \"Streams\": 4799038, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"4wVOKKEHUJxHCFFNUWDn0B\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 80.0, \"Danceability\": 0.735, \"Energy\": 0.449, \"Loudness\": -7.507, \"Speechiness\": 0.347, \"Acousticness\": 0.629, \"Liveness\": 0.113, \"Tempo\": 122.947, \"Duration (ms)\": 220488.0, \"Valence\": 0.0397, \"Chord\": \"A#/Bb\"}, {\"Index\": 896, \"Highest Charting Position\": 12, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Physical\", \"Streams\": 4599807, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3AzjcOeAmA57TIOr9zF1ZW\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 77.0, \"Danceability\": 0.647, \"Energy\": 0.844, \"Loudness\": -3.756, \"Speechiness\": 0.0457, \"Acousticness\": 0.0137, \"Liveness\": 0.102, \"Tempo\": 146.967, \"Duration (ms)\": 193829.0, \"Valence\": 0.746, \"Chord\": \"C\"}, {\"Index\": 909, \"Highest Charting Position\": 21, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Boss Bitch\", \"Streams\": 4620838, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"78qd8dvwea0Gosb6Fe6j3k\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-01-23\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 81.0, \"Danceability\": 0.707, \"Energy\": 0.955, \"Loudness\": -4.593, \"Speechiness\": 0.222, \"Acousticness\": 0.127, \"Liveness\": 0.202, \"Tempo\": 125.989, \"Duration (ms)\": 134240.0, \"Valence\": 0.575, \"Chord\": \"A#/Bb\"}, {\"Index\": 922, \"Highest Charting Position\": 5, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"the 1\", \"Streams\": 4587573, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0Jlcvv8IykzHaSmj49uNW8\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 75.0, \"Danceability\": 0.777, \"Energy\": 0.357, \"Loudness\": -6.942, \"Speechiness\": 0.0522, \"Acousticness\": 0.757, \"Liveness\": 0.108, \"Tempo\": 139.883, \"Duration (ms)\": 210252.0, \"Valence\": 0.172, \"Chord\": \"C\"}, {\"Index\": 932, \"Highest Charting Position\": 5, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Sour Candy (with BLACKPINK)\", \"Streams\": 4556900, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"6R6ZoHTypt5lt68MWbzZXv\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-28\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 70.0, \"Danceability\": 0.752, \"Energy\": 0.87, \"Loudness\": -3.812, \"Speechiness\": 0.0623, \"Acousticness\": 0.0604, \"Liveness\": 0.489, \"Tempo\": 120.006, \"Duration (ms)\": 157707.0, \"Valence\": 0.784, \"Chord\": \"A\"}, {\"Index\": 934, \"Highest Charting Position\": 31, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Bandit (with YoungBoy Never Broke Again)\", \"Streams\": 4514763, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"6Gg1gjgKi2AK4e0qzsR7sd\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.474, \"Energy\": 0.631, \"Loudness\": -5.884, \"Speechiness\": 0.343, \"Acousticness\": 0.0687, \"Liveness\": 0.132, \"Tempo\": 180.051, \"Duration (ms)\": 189323.0, \"Valence\": 0.425, \"Chord\": \"F\"}, {\"Index\": 938, \"Highest Charting Position\": 22, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"ON\", \"Streams\": 5391018, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"2QyuXBcV1LJ2rq01KhreMF\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 77.0, \"Danceability\": 0.583, \"Energy\": 0.817, \"Loudness\": -5.146, \"Speechiness\": 0.0987, \"Acousticness\": 0.118, \"Liveness\": 0.338, \"Tempo\": 105.936, \"Duration (ms)\": 246381.0, \"Valence\": 0.438, \"Chord\": \"A\"}, {\"Index\": 940, \"Highest Charting Position\": 8, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Life's A Mess (feat. Halsey)\", \"Streams\": 4883202, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5wWAwzGp2OaaoIkwcz6wZs\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 74.0, \"Danceability\": 0.63, \"Energy\": 0.446, \"Loudness\": -8.9, \"Speechiness\": 0.0351, \"Acousticness\": 0.337, \"Liveness\": 0.166, \"Tempo\": 143.078, \"Duration (ms)\": 202193.0, \"Valence\": 0.177, \"Chord\": \"C#/Db\"}, {\"Index\": 943, \"Highest Charting Position\": 11, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"august\", \"Streams\": 4586236, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3hUxzQpSfdDqwM3ZTFQY0K\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 76.0, \"Danceability\": 0.532, \"Energy\": 0.623, \"Loudness\": -9.208, \"Speechiness\": 0.0331, \"Acousticness\": 0.538, \"Liveness\": 0.0925, \"Tempo\": 89.937, \"Duration (ms)\": 261923.0, \"Valence\": 0.403, \"Chord\": \"F\"}, {\"Index\": 946, \"Highest Charting Position\": 72, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Stay Gold\", \"Streams\": 4405338, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3Ys2PYl1wyPKQIwyqhP9cQ\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-07-14\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-07-10--2020-07-17\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 73.0, \"Danceability\": 0.723, \"Energy\": 0.634, \"Loudness\": -5.415, \"Speechiness\": 0.0542, \"Acousticness\": 0.0892, \"Liveness\": 0.0787, \"Tempo\": 129.017, \"Duration (ms)\": 243267.0, \"Valence\": 0.582, \"Chord\": \"C#/Db\"}, {\"Index\": 949, \"Highest Charting Position\": 8, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"the last great american dynasty\", \"Streams\": 4389670, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2Eeur20xVqfUoM3Q7EFPFt\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.686, \"Energy\": 0.662, \"Loudness\": -8.505, \"Speechiness\": 0.0413, \"Acousticness\": 0.467, \"Liveness\": 0.109, \"Tempo\": 147.922, \"Duration (ms)\": 230999.0, \"Valence\": 0.706, \"Chord\": \"G\"}, {\"Index\": 950, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Levitating (feat. Madonna and Missy Elliott) [The Blessed Madonna Remix]\", \"Streams\": 5254969, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"0pk1hxhJLBSZZ5RKBhcwOa\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-08-13\", \"Weeks Charted\": \"2020-08-14--2020-08-21\", \"Popularity\": 62.0, \"Danceability\": 0.808, \"Energy\": 0.655, \"Loudness\": -7.34, \"Speechiness\": 0.139, \"Acousticness\": 0.0373, \"Liveness\": 0.208, \"Tempo\": 116.029, \"Duration (ms)\": 250280.0, \"Valence\": 0.56, \"Chord\": \"B\"}, {\"Index\": 951, \"Highest Charting Position\": 10, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"my tears ricochet\", \"Streams\": 5111416, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1MgV7FIyNxIG7WzMRJV5HC\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.456, \"Energy\": 0.263, \"Loudness\": -10.63, \"Speechiness\": 0.0332, \"Acousticness\": 0.806, \"Liveness\": 0.0749, \"Tempo\": 129.86, \"Duration (ms)\": 255894.0, \"Valence\": 0.111, \"Chord\": \"C\"}, {\"Index\": 956, \"Highest Charting Position\": 55, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Hallucinate\", \"Streams\": 4472669, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"1nYeVF5vIBxMxfPoL0SIWg\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 72.0, \"Danceability\": 0.627, \"Energy\": 0.69, \"Loudness\": -5.396, \"Speechiness\": 0.139, \"Acousticness\": 0.033, \"Liveness\": 0.0742, \"Tempo\": 122.053, \"Duration (ms)\": 208505.0, \"Valence\": 0.627, \"Chord\": \"A#/Bb\"}, {\"Index\": 961, \"Highest Charting Position\": 17, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"invisible string\", \"Streams\": 4424118, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6VsvKPJ4xjVNKpI8VVZ3SV\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.653, \"Energy\": 0.452, \"Loudness\": -11.143, \"Speechiness\": 0.055, \"Acousticness\": 0.838, \"Liveness\": 0.108, \"Tempo\": 83.433, \"Duration (ms)\": 252881.0, \"Valence\": 0.45, \"Chord\": \"E\"}, {\"Index\": 966, \"Highest Charting Position\": 13, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"mirrorball\", \"Streams\": 5564072, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0ZNU020wNYvgW84iljPkPP\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.553, \"Energy\": 0.413, \"Loudness\": -10.037, \"Speechiness\": 0.0334, \"Acousticness\": 0.687, \"Liveness\": 0.0594, \"Tempo\": 110.107, \"Duration (ms)\": 208978.0, \"Valence\": 0.379, \"Chord\": \"D\"}, {\"Index\": 967, \"Highest Charting Position\": 15, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"seven\", \"Streams\": 5459423, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6KJqZcs9XDgVck7Lg9QOTC\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 69.0, \"Danceability\": 0.596, \"Energy\": 0.488, \"Loudness\": -10.769, \"Speechiness\": 0.0274, \"Acousticness\": 0.9, \"Liveness\": 0.091, \"Tempo\": 94.926, \"Duration (ms)\": 208907.0, \"Valence\": 0.415, \"Chord\": \"E\"}, {\"Index\": 968, \"Highest Charting Position\": 18, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"this is me trying\", \"Streams\": 5128412, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7kt9e9LFSpN1zQtYEl19o1\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.515, \"Energy\": 0.476, \"Loudness\": -9.843, \"Speechiness\": 0.0328, \"Acousticness\": 0.314, \"Liveness\": 0.171, \"Tempo\": 135.886, \"Duration (ms)\": 195097.0, \"Valence\": 0.412, \"Chord\": \"A\"}, {\"Index\": 969, \"Highest Charting Position\": 24, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"betty\", \"Streams\": 5112180, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5kI4eCXXzyuIUXjQra0Cxi\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.593, \"Energy\": 0.377, \"Loudness\": -8.761, \"Speechiness\": 0.0253, \"Acousticness\": 0.6, \"Liveness\": 0.0976, \"Tempo\": 95.939, \"Duration (ms)\": 294521.0, \"Valence\": 0.502, \"Chord\": \"C\"}, {\"Index\": 970, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"BLIND (feat. Young Thug)\", \"Streams\": 5074613, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"2T5NBwKRySiCR78vVk08vr\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-08-04\", \"Weeks Charted\": \"2020-08-07--2020-08-14\", \"Popularity\": 69.0, \"Danceability\": 0.709, \"Energy\": 0.679, \"Loudness\": -6.503, \"Speechiness\": 0.346, \"Acousticness\": 0.0115, \"Liveness\": 0.0971, \"Tempo\": 162.973, \"Duration (ms)\": 153467.0, \"Valence\": 0.754, \"Chord\": \"B\"}, {\"Index\": 971, \"Highest Charting Position\": 20, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"illicit affairs\", \"Streams\": 5053658, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2NmsngXHeC1GQ9wWrzhOMf\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.559, \"Energy\": 0.31, \"Loudness\": -10.445, \"Speechiness\": 0.0338, \"Acousticness\": 0.881, \"Liveness\": 0.106, \"Tempo\": 119.845, \"Duration (ms)\": 190898.0, \"Valence\": 0.46, \"Chord\": \"A#/Bb\"}, {\"Index\": 972, \"Highest Charting Position\": 170, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Freak\", \"Streams\": 4736059, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"3aA6xB0tOilDDX17fIJ0Bl\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2020-08-07--2020-08-14\", \"Popularity\": 75.0, \"Danceability\": 0.688, \"Energy\": 0.716, \"Loudness\": -5.702, \"Speechiness\": 0.0385, \"Acousticness\": 0.0969, \"Liveness\": 0.0989, \"Tempo\": 116.912, \"Duration (ms)\": 284480.0, \"Valence\": 0.373, \"Chord\": \"G\"}, {\"Index\": 977, \"Highest Charting Position\": 29, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"mad woman\", \"Streams\": 6796343, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2QDyYdZyhlP2fp79KZX8Bi\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 67.0, \"Danceability\": 0.592, \"Energy\": 0.699, \"Loudness\": -8.995, \"Speechiness\": 0.0471, \"Acousticness\": 0.655, \"Liveness\": 0.114, \"Tempo\": 141.916, \"Duration (ms)\": 237258.0, \"Valence\": 0.506, \"Chord\": \"D#/Eb\"}, {\"Index\": 978, \"Highest Charting Position\": 33, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"epiphany\", \"Streams\": 6085522, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"08fa9LFcFBTcilB3iq2e2A\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 66.0, \"Danceability\": 0.354, \"Energy\": 0.267, \"Loudness\": -13.69, \"Speechiness\": 0.0281, \"Acousticness\": 0.731, \"Liveness\": 0.0858, \"Tempo\": 94.219, \"Duration (ms)\": 289749.0, \"Valence\": 0.113, \"Chord\": \"C#/Db\"}, {\"Index\": 979, \"Highest Charting Position\": 41, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"peace\", \"Streams\": 5943851, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7MbT4I8qGntX4fMdqMQgke\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 67.0, \"Danceability\": 0.647, \"Energy\": 0.272, \"Loudness\": -12.906, \"Speechiness\": 0.0916, \"Acousticness\": 0.918, \"Liveness\": 0.0918, \"Tempo\": 150.044, \"Duration (ms)\": 234000.0, \"Valence\": 0.339, \"Chord\": \"F\"}, {\"Index\": 984, \"Highest Charting Position\": 47, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"hoax\", \"Streams\": 5375944, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6MWoRt97mnSTXZhu3ggi9C\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 66.0, \"Danceability\": 0.662, \"Energy\": 0.181, \"Loudness\": -15.065, \"Speechiness\": 0.0415, \"Acousticness\": 0.966, \"Liveness\": 0.133, \"Tempo\": 118.819, \"Duration (ms)\": 220043.0, \"Valence\": 0.429, \"Chord\": \"G#/Ab\"}, {\"Index\": 985, \"Highest Charting Position\": 25, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Blood On My Jeans\", \"Streams\": 4978899, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"0fCwrjKfWxF3xQhZrYUw4T\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 73.0, \"Danceability\": 0.868, \"Energy\": 0.55, \"Loudness\": -6.417, \"Speechiness\": 0.226, \"Acousticness\": 0.183, \"Liveness\": 0.109, \"Tempo\": 117.943, \"Duration (ms)\": 154767.0, \"Valence\": 0.464, \"Chord\": \"F#/Gb\"}, {\"Index\": 992, \"Highest Charting Position\": 101, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"ocean eyes\", \"Streams\": 4476954, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6pFTDHGJtKOxrQ85xRZ8Ue\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 1.0, \"Danceability\": 0.358, \"Energy\": 0.372, \"Loudness\": -7.664, \"Speechiness\": 0.0464, \"Acousticness\": 0.81, \"Liveness\": 0.0877, \"Tempo\": 144.833, \"Duration (ms)\": 200387.0, \"Valence\": 0.16, \"Chord\": \"E\"}, {\"Index\": 993, \"Highest Charting Position\": 82, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Lion King On Ice\", \"Streams\": 8293983, \"Artist\": \"J. Cole\", \"Artist Followers\": 14103694.0, \"Song ID\": \"1ZvBVbsaNqHEP6ymXaPGlj\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2020-07-22\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 64.0, \"Danceability\": 0.732, \"Energy\": 0.663, \"Loudness\": -7.616, \"Speechiness\": 0.192, \"Acousticness\": 0.0819, \"Liveness\": 0.115, \"Tempo\": 139.964, \"Duration (ms)\": 210587.0, \"Valence\": 0.227, \"Chord\": \"F#/Gb\"}, {\"Index\": 996, \"Highest Charting Position\": 37, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Stay High\", \"Streams\": 5047752, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"21CkzgKCBCq5V4XKjiGSIj\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 75.0, \"Danceability\": 0.745, \"Energy\": 0.5, \"Loudness\": -6.184, \"Speechiness\": 0.135, \"Acousticness\": 0.439, \"Liveness\": 0.0943, \"Tempo\": 76.968, \"Duration (ms)\": 168685.0, \"Valence\": 0.433, \"Chord\": \"G#/Ab\"}, {\"Index\": 999, \"Highest Charting Position\": 35, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Tell Me U Luv Me (with Trippie Redd)\", \"Streams\": 4798078, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5JAYDuLRkODlVt6dgoalKk\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 72.0, \"Danceability\": 0.66, \"Energy\": 0.76, \"Loudness\": -5.726, \"Speechiness\": 0.0787, \"Acousticness\": 0.291, \"Liveness\": 0.632, \"Tempo\": 127.984, \"Duration (ms)\": 180129.0, \"Valence\": 0.394, \"Chord\": \"D\"}, {\"Index\": 1000, \"Highest Charting Position\": 27, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Bad Energy\", \"Streams\": 4761155, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"7d94IqWX2UmSKMGUYSGFJG\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 72.0, \"Danceability\": 0.654, \"Energy\": 0.452, \"Loudness\": -6.36, \"Speechiness\": 0.0439, \"Acousticness\": 0.17, \"Liveness\": 0.114, \"Tempo\": 138.034, \"Duration (ms)\": 186749.0, \"Valence\": 0.532, \"Chord\": \"G\"}, {\"Index\": 1001, \"Highest Charting Position\": 24, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Titanic\", \"Streams\": 4687464, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"1YM6c2sxbf2Jacl9IFgn4I\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 71.0, \"Danceability\": 0.567, \"Energy\": 0.545, \"Loudness\": -6.668, \"Speechiness\": 0.0448, \"Acousticness\": 0.168, \"Liveness\": 0.112, \"Tempo\": 174.146, \"Duration (ms)\": 176650.0, \"Valence\": 0.234, \"Chord\": \"C#/Db\"}, {\"Index\": 1007, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Up Up And Away\", \"Streams\": 6229316, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"7pbg3ABlAZv2NiIdKbBBFm\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 72.0, \"Danceability\": 0.661, \"Energy\": 0.665, \"Loudness\": -6.356, \"Speechiness\": 0.053, \"Acousticness\": 0.538, \"Liveness\": 0.0981, \"Tempo\": 75.059, \"Duration (ms)\": 147548.0, \"Valence\": 0.486, \"Chord\": \"E\"}, {\"Index\": 1008, \"Highest Charting Position\": 46, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Man Of The Year\", \"Streams\": 6223001, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"7AvprzMsRJpybaalckaT8c\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 73.0, \"Danceability\": 0.621, \"Energy\": 0.695, \"Loudness\": -5.124, \"Speechiness\": 0.0911, \"Acousticness\": 0.00584, \"Liveness\": 0.086, \"Tempo\": 173.966, \"Duration (ms)\": 136408.0, \"Valence\": 0.298, \"Chord\": \"E\"}, {\"Index\": 1009, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Fighting Demons\", \"Streams\": 5946573, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"0440JCJyIAmINA8KcYgFb5\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 70.0, \"Danceability\": 0.707, \"Energy\": 0.67, \"Loudness\": -6.328, \"Speechiness\": 0.257, \"Acousticness\": 0.0813, \"Liveness\": 0.098, \"Tempo\": 163.099, \"Duration (ms)\": 200629.0, \"Valence\": 0.235, \"Chord\": \"G\"}, {\"Index\": 1010, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Can't Die\", \"Streams\": 5777859, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4PPLJAEYBSOcnzr9TZoqf9\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 71.0, \"Danceability\": 0.652, \"Energy\": 0.671, \"Loudness\": -5.89, \"Speechiness\": 0.0756, \"Acousticness\": 0.0222, \"Liveness\": 0.107, \"Tempo\": 84.008, \"Duration (ms)\": 182922.0, \"Valence\": 0.274, \"Chord\": \"D\"}, {\"Index\": 1011, \"Highest Charting Position\": 44, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Screw Juice\", \"Streams\": 5394197, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4F6YLjakjqWFTgC5qfEwPQ\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 69.0, \"Danceability\": 0.595, \"Energy\": 0.528, \"Loudness\": -7.371, \"Speechiness\": 0.0935, \"Acousticness\": 0.082, \"Liveness\": 0.142, \"Tempo\": 150.075, \"Duration (ms)\": 179464.0, \"Valence\": 0.515, \"Chord\": \"F\"}, {\"Index\": 1013, \"Highest Charting Position\": 45, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"I Want It\", \"Streams\": 5137482, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"2SVx3uds6jTWALFxevIWMA\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 69.0, \"Danceability\": 0.288, \"Energy\": 0.638, \"Loudness\": -6.935, \"Speechiness\": 0.0779, \"Acousticness\": 0.133, \"Liveness\": 0.14, \"Tempo\": 66.424, \"Duration (ms)\": 173114.0, \"Valence\": 0.147, \"Chord\": \"E\"}, {\"Index\": 1017, \"Highest Charting Position\": 5, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"La Dif\\u00edcil\", \"Streams\": 4727554, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"6NfrH0ANGmgBXyxgV2PeXt\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 78.0, \"Danceability\": 0.685, \"Energy\": 0.848, \"Loudness\": -4.561, \"Speechiness\": 0.0858, \"Acousticness\": 0.0861, \"Liveness\": 0.0783, \"Tempo\": 179.87, \"Duration (ms)\": 163084.0, \"Valence\": 0.761, \"Chord\": \"G#/Ab\"}, {\"Index\": 1024, \"Highest Charting Position\": 2, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Yummy\", \"Streams\": 4599349, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"41L3O37CECZt3N7ziG2z7l\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-03\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 72.0, \"Danceability\": 0.687, \"Energy\": 0.514, \"Loudness\": -6.612, \"Speechiness\": 0.0897, \"Acousticness\": 0.366, \"Liveness\": 0.116, \"Tempo\": 145.921, \"Duration (ms)\": 210427.0, \"Valence\": 0.494, \"Chord\": \"A\"}, {\"Index\": 1026, \"Highest Charting Position\": 69, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Like That (feat. Gucci Mane)\", \"Streams\": 4565377, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"4EivmOT13NMpNSfTKn9p4s\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 77.0, \"Danceability\": 0.879, \"Energy\": 0.498, \"Loudness\": -6.027, \"Speechiness\": 0.18, \"Acousticness\": 0.239, \"Liveness\": 0.0967, \"Tempo\": 106.044, \"Duration (ms)\": 163173.0, \"Valence\": 0.405, \"Chord\": \"E\"}, {\"Index\": 1028, \"Highest Charting Position\": 23, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"BOP\", \"Streams\": 4496450, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"6Ozh9Ok6h4Oi1wUSLtBseN\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.769, \"Energy\": 0.787, \"Loudness\": -3.909, \"Speechiness\": 0.367, \"Acousticness\": 0.189, \"Liveness\": 0.129, \"Tempo\": 126.77, \"Duration (ms)\": 159715.0, \"Valence\": 0.836, \"Chord\": \"B\"}, {\"Index\": 1030, \"Highest Charting Position\": 78, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Anxiety - Intro\", \"Streams\": 8449557, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"02XcRGWPkvomFvzTamEKHg\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 60.0, \"Danceability\": 0.307, \"Energy\": 0.528, \"Loudness\": -11.337, \"Speechiness\": 0.108, \"Acousticness\": 0.972, \"Liveness\": 0.222, \"Tempo\": 174.795, \"Duration (ms)\": 70395.0, \"Valence\": 0.58, \"Chord\": \"B\"}, {\"Index\": 1031, \"Highest Charting Position\": 112, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Juice WRLD Speaks From Heaven - Outro\", \"Streams\": 6682917, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"1OjiYjgPZyxS0AiXiSnuYI\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 59.0, \"Danceability\": 0.392, \"Energy\": 0.373, \"Loudness\": -14.097, \"Speechiness\": 0.0968, \"Acousticness\": 0.991, \"Liveness\": 0.545, \"Tempo\": 121.678, \"Duration (ms)\": 30583.0, \"Valence\": 0.519, \"Chord\": \"C\"}, {\"Index\": 1032, \"Highest Charting Position\": 113, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"The Man, The Myth, The Legend - Interlude\", \"Streams\": 6640728, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4sjdZEEQvR1sXrRNSuBfbA\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 58.0, \"Danceability\": 0.667, \"Energy\": 0.447, \"Loudness\": -14.625, \"Speechiness\": 0.761, \"Acousticness\": 0.916, \"Liveness\": 0.612, \"Tempo\": 83.534, \"Duration (ms)\": 136545.0, \"Valence\": 0.829, \"Chord\": \"D\"}, {\"Index\": 1035, \"Highest Charting Position\": 53, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Gangstas\", \"Streams\": 5104422, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"1hg3RlqFZXJb5YgRoK9qmF\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 71.0, \"Danceability\": 0.548, \"Energy\": 0.506, \"Loudness\": -7.434, \"Speechiness\": 0.102, \"Acousticness\": 0.203, \"Liveness\": 0.0788, \"Tempo\": 119.987, \"Duration (ms)\": 160000.0, \"Valence\": 0.557, \"Chord\": \"E\"}, {\"Index\": 1040, \"Highest Charting Position\": 64, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Make It Rain (feat. Rowdy Rebel)\", \"Streams\": 4594248, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"71d7LaAgPcNcUopu3OzmP7\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 62.0, \"Danceability\": 0.5, \"Energy\": 0.767, \"Loudness\": -4.105, \"Speechiness\": 0.403, \"Acousticness\": 0.162, \"Liveness\": 0.385, \"Tempo\": 159.477, \"Duration (ms)\": 202443.0, \"Valence\": 0.58, \"Chord\": \"C#/Db\"}, {\"Index\": 1042, \"Highest Charting Position\": 79, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Something Special\", \"Streams\": 4535580, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"5kkaSMcf4BFlhRRICCKZb6\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 72.0, \"Danceability\": 0.739, \"Energy\": 0.616, \"Loudness\": -6.963, \"Speechiness\": 0.0338, \"Acousticness\": 0.252, \"Liveness\": 0.101, \"Tempo\": 91.071, \"Duration (ms)\": 158466.0, \"Valence\": 0.654, \"Chord\": \"G\"}, {\"Index\": 1043, \"Highest Charting Position\": 58, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Aim For The Moon (feat. Quavo)\", \"Streams\": 9011502, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"6O7fPYTsb2mY0PiFt2ymDB\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 67.0, \"Danceability\": 0.713, \"Energy\": 0.605, \"Loudness\": -7.487, \"Speechiness\": 0.107, \"Acousticness\": 0.497, \"Liveness\": 0.115, \"Tempo\": 142.025, \"Duration (ms)\": 175756.0, \"Valence\": 0.432, \"Chord\": \"B\"}, {\"Index\": 1044, \"Highest Charting Position\": 63, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"44 BullDog\", \"Streams\": 8443771, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"7sjFIZ1g5QLJLGja3k592K\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 66.0, \"Danceability\": 0.8, \"Energy\": 0.564, \"Loudness\": -5.817, \"Speechiness\": 0.4, \"Acousticness\": 0.0287, \"Liveness\": 0.112, \"Tempo\": 139.989, \"Duration (ms)\": 150857.0, \"Valence\": 0.318, \"Chord\": \"G#/Ab\"}, {\"Index\": 1045, \"Highest Charting Position\": 88, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Creature (feat. Swae Lee)\", \"Streams\": 7308690, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"3eV2WT9YhfzkxbufnBF8wK\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 66.0, \"Danceability\": 0.794, \"Energy\": 0.717, \"Loudness\": -5.73, \"Speechiness\": 0.251, \"Acousticness\": 0.0511, \"Liveness\": 0.195, \"Tempo\": 141.881, \"Duration (ms)\": 202816.0, \"Valence\": 0.372, \"Chord\": \"G\"}, {\"Index\": 1046, \"Highest Charting Position\": 95, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Yea Yea\", \"Streams\": 7112419, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"0bjgQ24UZGwKikldIyEOgf\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 63.0, \"Danceability\": 0.717, \"Energy\": 0.474, \"Loudness\": -8.383, \"Speechiness\": 0.403, \"Acousticness\": 0.0509, \"Liveness\": 0.139, \"Tempo\": 123.906, \"Duration (ms)\": 185804.0, \"Valence\": 0.448, \"Chord\": \"F\"}, {\"Index\": 1047, \"Highest Charting Position\": 100, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Enjoy Yourself (feat. Karol G)\", \"Streams\": 6620040, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"3NWrHCwvyII4fTx05PN3IO\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 70.0, \"Danceability\": 0.764, \"Energy\": 0.676, \"Loudness\": -6.761, \"Speechiness\": 0.0927, \"Acousticness\": 0.389, \"Liveness\": 0.215, \"Tempo\": 97.02, \"Duration (ms)\": 197938.0, \"Valence\": 0.461, \"Chord\": \"B\"}, {\"Index\": 1048, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Bad Bitch From Tokyo (Intro)\", \"Streams\": 6144736, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"4OGIeHtYhRTJ8iW21UUyZW\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 59.0, \"Danceability\": 0.645, \"Energy\": 0.64, \"Loudness\": -6.871, \"Speechiness\": 0.179, \"Acousticness\": 0.395, \"Liveness\": 0.286, \"Tempo\": 140.248, \"Duration (ms)\": 48000.0, \"Valence\": 0.674, \"Chord\": \"A#/Bb\"}, {\"Index\": 1049, \"Highest Charting Position\": 117, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Snitching (feat. Quavo & Future)\", \"Streams\": 6102253, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"2FhEj9lvEIaJihjFprRrGt\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 59.0, \"Danceability\": 0.944, \"Energy\": 0.579, \"Loudness\": -4.961, \"Speechiness\": 0.191, \"Acousticness\": 0.0381, \"Liveness\": 0.253, \"Tempo\": 135.033, \"Duration (ms)\": 259346.0, \"Valence\": 0.769, \"Chord\": \"G#/Ab\"}, {\"Index\": 1050, \"Highest Charting Position\": 121, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"West Coast Shit (feat. Tyga & Quavo)\", \"Streams\": 5931242, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"1JDhNQ0oOT7XpclZn3aQ8F\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 61.0, \"Danceability\": 0.831, \"Energy\": 0.762, \"Loudness\": -5.656, \"Speechiness\": 0.207, \"Acousticness\": 0.0885, \"Liveness\": 0.107, \"Tempo\": 99.999, \"Duration (ms)\": 192000.0, \"Valence\": 0.495, \"Chord\": \"B\"}, {\"Index\": 1053, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Tunnel Vision (Outro)\", \"Streams\": 4907751, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"2SxR5RitJdsG6wINvJLBSD\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 60.0, \"Danceability\": 0.718, \"Energy\": 0.66, \"Loudness\": -7.39, \"Speechiness\": 0.325, \"Acousticness\": 0.363, \"Liveness\": 0.159, \"Tempo\": 142.879, \"Duration (ms)\": 132587.0, \"Valence\": 0.659, \"Chord\": \"D\"}, {\"Index\": 1054, \"Highest Charting Position\": 7, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Si Veo a Tu Mam\\u00e1\", \"Streams\": 4638728, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"41wtwzCZkXwpnakmwJ239F\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 80.0, \"Danceability\": 0.9, \"Energy\": 0.603, \"Loudness\": -5.313, \"Speechiness\": 0.0646, \"Acousticness\": 0.402, \"Liveness\": 0.134, \"Tempo\": 129.928, \"Duration (ms)\": 170972.0, \"Valence\": 0.824, \"Chord\": \"D\"}, {\"Index\": 1067, \"Highest Charting Position\": 32, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Myron\", \"Streams\": 4593309, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"56uXDJRCuoS7abX3SkzHKQ\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 76.0, \"Danceability\": 0.771, \"Energy\": 0.654, \"Loudness\": -6.976, \"Speechiness\": 0.298, \"Acousticness\": 0.055, \"Liveness\": 0.214, \"Tempo\": 155.047, \"Duration (ms)\": 224955.0, \"Valence\": 0.573, \"Chord\": \"G#/Ab\"}, {\"Index\": 1074, \"Highest Charting Position\": 88, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Money In The Grave (Drake ft. Rick Ross)\", \"Streams\": 4403348, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5ry2OE6R2zPQFDO85XkgRb\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2019-06-15\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.831, \"Energy\": 0.502, \"Loudness\": -4.045, \"Speechiness\": 0.046, \"Acousticness\": 0.101, \"Liveness\": 0.122, \"Tempo\": 100.541, \"Duration (ms)\": 205427.0, \"Valence\": 0.101, \"Chord\": \"A#/Bb\"}, {\"Index\": 1075, \"Highest Charting Position\": 25, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Say So (feat. Nicki Minaj)\", \"Streams\": 4385148, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"11VApNQCWLJdzxWrlmwzUa\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 69.0, \"Danceability\": 0.856, \"Energy\": 0.641, \"Loudness\": -4.64, \"Speechiness\": 0.204, \"Acousticness\": 0.119, \"Liveness\": 0.427, \"Tempo\": 111.004, \"Duration (ms)\": 206221.0, \"Valence\": 0.745, \"Chord\": \"B\"}, {\"Index\": 1082, \"Highest Charting Position\": 14, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Lose You To Love Me\", \"Streams\": 4322088, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4l0Mvzj72xxOpRrp6h8nHi\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.488, \"Energy\": 0.343, \"Loudness\": -8.985, \"Speechiness\": 0.0436, \"Acousticness\": 0.556, \"Liveness\": 0.21, \"Tempo\": 102.819, \"Duration (ms)\": 206459.0, \"Valence\": 0.0978, \"Chord\": \"E\"}, {\"Index\": 1090, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Snow On Tha Bluff\", \"Streams\": 5060764, \"Artist\": \"J. Cole\", \"Artist Followers\": 14103694.0, \"Song ID\": \"1oOEkBNp4zWnkD7nWjJdog\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2020-06-16\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 66.0, \"Danceability\": 0.586, \"Energy\": 0.512, \"Loudness\": -8.819, \"Speechiness\": 0.0668, \"Acousticness\": 0.723, \"Liveness\": 0.119, \"Tempo\": 75.857, \"Duration (ms)\": 235480.0, \"Valence\": 0.235, \"Chord\": \"G#/Ab\"}, {\"Index\": 1093, \"Highest Charting Position\": 13, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Stupid Love\", \"Streams\": 4609858, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 1251372.0, \"Song ID\": \"1zPwSOUc5MPtPg8EgXAGKU\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-08\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 0.0, \"Danceability\": 0.68, \"Energy\": 0.825, \"Loudness\": -4.296, \"Speechiness\": 0.0702, \"Acousticness\": 0.00173, \"Liveness\": 0.27, \"Tempo\": 117.987, \"Duration (ms)\": 193533.0, \"Valence\": 0.784, \"Chord\": \"G#/Ab\"}, {\"Index\": 1100, \"Highest Charting Position\": 76, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"ROCKSTAR (feat. Roddy Ricch) - BLM REMIX\", \"Streams\": 7353153, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"4Aykm3xrOFSHrAnv80KUhh\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 62.0, \"Danceability\": 0.747, \"Energy\": 0.689, \"Loudness\": -7.246, \"Speechiness\": 0.242, \"Acousticness\": 0.197, \"Liveness\": 0.0884, \"Tempo\": 89.901, \"Duration (ms)\": 204547.0, \"Valence\": 0.75, \"Chord\": \"B\"}, {\"Index\": 1104, \"Highest Charting Position\": 21, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"P2\", \"Streams\": 4769996, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"3kW4z2pIj5VY5fLjBrMRL5\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 73.0, \"Danceability\": 0.775, \"Energy\": 0.72, \"Loudness\": -5.353, \"Speechiness\": 0.193, \"Acousticness\": 0.0236, \"Liveness\": 0.114, \"Tempo\": 155.086, \"Duration (ms)\": 234627.0, \"Valence\": 0.49, \"Chord\": \"B\"}, {\"Index\": 1108, \"Highest Charting Position\": 48, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"BYE ME FUI\", \"Streams\": 4567732, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0FktnzDqjClqU6iqOZVEs2\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 72.0, \"Danceability\": 0.712, \"Energy\": 0.599, \"Loudness\": -6.342, \"Speechiness\": 0.112, \"Acousticness\": 0.412, \"Liveness\": 0.103, \"Tempo\": 179.788, \"Duration (ms)\": 178000.0, \"Valence\": 0.588, \"Chord\": \"F\"}, {\"Index\": 1109, \"Highest Charting Position\": 15, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Vete\", \"Streams\": 4486408, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5DxXgozhkPLgrbKFY91w0c\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-21\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.886, \"Energy\": 0.672, \"Loudness\": -4.394, \"Speechiness\": 0.188, \"Acousticness\": 0.0363, \"Liveness\": 0.101, \"Tempo\": 91.976, \"Duration (ms)\": 192024.0, \"Valence\": 0.526, \"Chord\": \"C#/Db\"}, {\"Index\": 1125, \"Highest Charting Position\": 137, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"XO Tour Llif3\", \"Streams\": 4314080, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7GX5flRQZVHRAGd6B4TmDO\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2017-08-25\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-08--2020-05-15\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 82.0, \"Danceability\": 0.732, \"Energy\": 0.75, \"Loudness\": -6.366, \"Speechiness\": 0.231, \"Acousticness\": 0.00264, \"Liveness\": 0.109, \"Tempo\": 155.096, \"Duration (ms)\": 182707.0, \"Valence\": 0.401, \"Chord\": \"B\"}, {\"Index\": 1129, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Alice\", \"Streams\": 10342277, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"41A89rj3GoMG6ktN37L7PG\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 64.0, \"Danceability\": 0.723, \"Energy\": 0.88, \"Loudness\": -4.287, \"Speechiness\": 0.038, \"Acousticness\": 0.00334, \"Liveness\": 0.0632, \"Tempo\": 123.036, \"Duration (ms)\": 177600.0, \"Valence\": 0.323, \"Chord\": \"B\"}, {\"Index\": 1130, \"Highest Charting Position\": 58, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Free Woman\", \"Streams\": 9266945, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"4L6ihclQPu1hqP9r3WNJjQ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 63.0, \"Danceability\": 0.731, \"Energy\": 0.927, \"Loudness\": -3.634, \"Speechiness\": 0.0781, \"Acousticness\": 0.0228, \"Liveness\": 0.187, \"Tempo\": 119.006, \"Duration (ms)\": 191467.0, \"Valence\": 0.478, \"Chord\": \"C\"}, {\"Index\": 1131, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Fun Tonight\", \"Streams\": 7907329, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"6hyQVqfHFvsJDjcmj4qrHf\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.645, \"Energy\": 0.923, \"Loudness\": -4.262, \"Speechiness\": 0.0725, \"Acousticness\": 0.364, \"Liveness\": 0.14, \"Tempo\": 117.945, \"Duration (ms)\": 173427.0, \"Valence\": 0.323, \"Chord\": \"B\"}, {\"Index\": 1132, \"Highest Charting Position\": 75, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Sine From Above (with Elton John)\", \"Streams\": 7734309, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"0zzsyWc45eUcSjw4FNHxeN\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 60.0, \"Danceability\": 0.642, \"Energy\": 0.792, \"Loudness\": -5.746, \"Speechiness\": 0.0488, \"Acousticness\": 0.158, \"Liveness\": 0.68, \"Tempo\": 122.965, \"Duration (ms)\": 244880.0, \"Valence\": 0.0903, \"Chord\": \"C\"}, {\"Index\": 1133, \"Highest Charting Position\": 77, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Enigma\", \"Streams\": 7695566, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"7JDbfYUHjDzQPFSDh5lzGs\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 59.0, \"Danceability\": 0.669, \"Energy\": 0.804, \"Loudness\": -4.035, \"Speechiness\": 0.036, \"Acousticness\": 0.0306, \"Liveness\": 0.694, \"Tempo\": 116.001, \"Duration (ms)\": 179760.0, \"Valence\": 0.184, \"Chord\": \"C\"}, {\"Index\": 1134, \"Highest Charting Position\": 79, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Replay\", \"Streams\": 7479618, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"7sKbyYeJnITO1Eh9xd0lKd\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 63.0, \"Danceability\": 0.658, \"Energy\": 0.878, \"Loudness\": -3.875, \"Speechiness\": 0.123, \"Acousticness\": 0.00792, \"Liveness\": 0.944, \"Tempo\": 122.015, \"Duration (ms)\": 186653.0, \"Valence\": 0.683, \"Chord\": \"C#/Db\"}, {\"Index\": 1135, \"Highest Charting Position\": 80, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Plastic Doll\", \"Streams\": 7451452, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"3CidPLqWXqgesJlwYVJZdy\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.743, \"Energy\": 0.853, \"Loudness\": -4.842, \"Speechiness\": 0.04, \"Acousticness\": 0.0019, \"Liveness\": 0.0872, \"Tempo\": 121.028, \"Duration (ms)\": 221667.0, \"Valence\": 0.422, \"Chord\": \"C\"}, {\"Index\": 1136, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Chromatica II\", \"Streams\": 7136521, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"0oQc0F6KUE7QY7k5TU6bic\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.184, \"Energy\": 0.297, \"Loudness\": -14.534, \"Speechiness\": 0.0359, \"Acousticness\": 0.473, \"Liveness\": 0.527, \"Tempo\": 75.824, \"Duration (ms)\": 41867.0, \"Valence\": 0.113, \"Chord\": \"D\"}, {\"Index\": 1137, \"Highest Charting Position\": 91, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Babylon\", \"Streams\": 6996402, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"5DttNeiizFqWUON9hZBqTY\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 61.0, \"Danceability\": 0.698, \"Energy\": 0.799, \"Loudness\": -4.372, \"Speechiness\": 0.0342, \"Acousticness\": 0.0129, \"Liveness\": 0.215, \"Tempo\": 115.957, \"Duration (ms)\": 161733.0, \"Valence\": 0.351, \"Chord\": \"D\"}, {\"Index\": 1138, \"Highest Charting Position\": 93, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Chromatica I\", \"Streams\": 6630385, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"0oQc0F6KUE7QY7k5TU6bic\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.184, \"Energy\": 0.297, \"Loudness\": -14.534, \"Speechiness\": 0.0359, \"Acousticness\": 0.473, \"Liveness\": 0.527, \"Tempo\": 75.824, \"Duration (ms)\": 41867.0, \"Valence\": 0.113, \"Chord\": \"D\"}, {\"Index\": 1139, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"1000 Doves\", \"Streams\": 6069544, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"62hTXlVQacy3pjBW4ntRPl\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.668, \"Energy\": 0.826, \"Loudness\": -4.466, \"Speechiness\": 0.0383, \"Acousticness\": 0.0236, \"Liveness\": 0.474, \"Tempo\": 122.973, \"Duration (ms)\": 215480.0, \"Valence\": 0.388, \"Chord\": \"A\"}, {\"Index\": 1151, \"Highest Charting Position\": 90, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"In Your Eyes (with Doja Cat) - Remix\", \"Streams\": 6511008, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"0UnTaVkntyh3vqvLEvbpQx\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-05-21\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 67.0, \"Danceability\": 0.679, \"Energy\": 0.731, \"Loudness\": -5.522, \"Speechiness\": 0.0319, \"Acousticness\": 0.00518, \"Liveness\": 0.0614, \"Tempo\": 99.984, \"Duration (ms)\": 237912.0, \"Valence\": 0.727, \"Chord\": \"G\"}, {\"Index\": 1164, \"Highest Charting Position\": 7, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"After Hours\", \"Streams\": 4559855, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"2p8IUWQDrpjuFltbdgLOag\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 75.0, \"Danceability\": 0.664, \"Energy\": 0.572, \"Loudness\": -6.099, \"Speechiness\": 0.0305, \"Acousticness\": 0.0811, \"Liveness\": 0.121, \"Tempo\": 108.959, \"Duration (ms)\": 361027.0, \"Valence\": 0.143, \"Chord\": \"F\"}, {\"Index\": 1172, \"Highest Charting Position\": 12, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Pain 1993 (with Playboi Carti)\", \"Streams\": 6085143, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"6Kj17Afjo1OKJYpf5VzCeo\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 67.0, \"Danceability\": 0.825, \"Energy\": 0.373, \"Loudness\": -5.532, \"Speechiness\": 0.108, \"Acousticness\": 0.163, \"Liveness\": 0.368, \"Tempo\": 77.271, \"Duration (ms)\": 149078.0, \"Valence\": 0.12, \"Chord\": \"F\"}, {\"Index\": 1178, \"Highest Charting Position\": 82, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"BENDICIONES\", \"Streams\": 4639997, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2CoMYp2uIKsT09nreEZnZn\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 67.0, \"Danceability\": 0.828, \"Energy\": 0.581, \"Loudness\": -9.909, \"Speechiness\": 0.0725, \"Acousticness\": 0.0378, \"Liveness\": 0.103, \"Tempo\": 143.995, \"Duration (ms)\": 155060.0, \"Valence\": 0.843, \"Chord\": \"B\"}, {\"Index\": 1182, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"SI ELLA SALE\", \"Streams\": 7055918, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"1zaDh3qaGSeSmulNyWlUxm\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 63.0, \"Danceability\": 0.869, \"Energy\": 0.727, \"Loudness\": -7.397, \"Speechiness\": 0.123, \"Acousticness\": 0.0589, \"Liveness\": 0.107, \"Tempo\": 147.967, \"Duration (ms)\": 143240.0, \"Valence\": 0.92, \"Chord\": \"G\"}, {\"Index\": 1183, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"RONCA FREESTYLE\", \"Streams\": 5784075, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3XZeOzJ9tqnu58YP6cqApI\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 64.0, \"Danceability\": 0.856, \"Energy\": 0.656, \"Loudness\": -6.483, \"Speechiness\": 0.131, \"Acousticness\": 0.165, \"Liveness\": 0.0998, \"Tempo\": 90.041, \"Duration (ms)\": 150060.0, \"Valence\": 0.586, \"Chord\": \"F\"}, {\"Index\": 1188, \"Highest Charting Position\": 52, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"A Tu Merced\", \"Streams\": 4909499, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4r9jkMEnArtWGH2rL2FZl0\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 82.0, \"Danceability\": 0.86, \"Energy\": 0.791, \"Loudness\": -4.784, \"Speechiness\": 0.0568, \"Acousticness\": 0.169, \"Liveness\": 0.106, \"Tempo\": 92.023, \"Duration (ms)\": 175918.0, \"Valence\": 0.887, \"Chord\": \"C\"}, {\"Index\": 1189, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Demons (feat. Fivio Foreign & Sosa Geek)\", \"Streams\": 4766829, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"05aZ9sAU1YXndHv0FMi9iW\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 63.0, \"Danceability\": 0.543, \"Energy\": 0.766, \"Loudness\": -3.387, \"Speechiness\": 0.343, \"Acousticness\": 0.423, \"Liveness\": 0.155, \"Tempo\": 106.869, \"Duration (ms)\": 204805.0, \"Valence\": 0.729, \"Chord\": \"C\"}, {\"Index\": 1196, \"Highest Charting Position\": 4, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"No Time To Die\", \"Streams\": 4293009, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"73SpzrcaHk0RQPFP73vqVR\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2020-02-13\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 75.0, \"Danceability\": 0.38, \"Energy\": 0.219, \"Loudness\": -13.273, \"Speechiness\": 0.0358, \"Acousticness\": 0.917, \"Liveness\": 0.0827, \"Tempo\": 73.537, \"Duration (ms)\": 242265.0, \"Valence\": 0.0517, \"Chord\": \"E\"}, {\"Index\": 1198, \"Highest Charting Position\": 51, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Time Flies\", \"Streams\": 9904749, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5H4mXWKcicuLKDn4Jy0sK7\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 71.0, \"Danceability\": 0.864, \"Energy\": 0.477, \"Loudness\": -5.786, \"Speechiness\": 0.224, \"Acousticness\": 0.201, \"Liveness\": 0.182, \"Tempo\": 86.46, \"Duration (ms)\": 192932.0, \"Valence\": 0.5, \"Chord\": \"A#/Bb\"}, {\"Index\": 1199, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Desires (with Future)\", \"Streams\": 9628215, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"7eYAHC0RbBF9eaqWzT34Aq\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.812, \"Energy\": 0.506, \"Loudness\": -7.706, \"Speechiness\": 0.116, \"Acousticness\": 0.281, \"Liveness\": 0.325, \"Tempo\": 145.074, \"Duration (ms)\": 237946.0, \"Valence\": 0.554, \"Chord\": \"F\"}, {\"Index\": 1200, \"Highest Charting Position\": 55, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Not You Too (feat. Chris Brown)\", \"Streams\": 9284383, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"3Q4gttWQ6hxqWOa3tHoTNi\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.458, \"Energy\": 0.452, \"Loudness\": -9.299, \"Speechiness\": 0.047, \"Acousticness\": 0.342, \"Liveness\": 0.0703, \"Tempo\": 86.318, \"Duration (ms)\": 269680.0, \"Valence\": 0.316, \"Chord\": \"A\"}, {\"Index\": 1201, \"Highest Charting Position\": 67, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Landed\", \"Streams\": 8355036, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"3KixNgUEaDtrKJVzdqjU5q\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 60.0, \"Danceability\": 0.881, \"Energy\": 0.636, \"Loudness\": -4.629, \"Speechiness\": 0.287, \"Acousticness\": 0.00606, \"Liveness\": 0.111, \"Tempo\": 163.949, \"Duration (ms)\": 152195.0, \"Valence\": 0.715, \"Chord\": \"G\"}, {\"Index\": 1202, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"When To Say When\", \"Streams\": 8304928, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5TCBWmEBrin7etRa4Lswr1\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 60.0, \"Danceability\": 0.41, \"Energy\": 0.82, \"Loudness\": -6.808, \"Speechiness\": 0.533, \"Acousticness\": 0.252, \"Liveness\": 0.538, \"Tempo\": 170.718, \"Duration (ms)\": 223124.0, \"Valence\": 0.526, \"Chord\": \"C#/Db\"}, {\"Index\": 1203, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Deep Pockets\", \"Streams\": 8285754, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"3IvMYBE7A3c7to1aEcfFJk\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 58.0, \"Danceability\": 0.473, \"Energy\": 0.824, \"Loudness\": -3.68, \"Speechiness\": 0.163, \"Acousticness\": 0.482, \"Liveness\": 0.605, \"Tempo\": 77.888, \"Duration (ms)\": 222929.0, \"Valence\": 0.374, \"Chord\": \"G\"}, {\"Index\": 1204, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"War\", \"Streams\": 7821869, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"1I55Ea0zVoSKs6MqW7DQ3i\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.749, \"Energy\": 0.792, \"Loudness\": -4.151, \"Speechiness\": 0.0826, \"Acousticness\": 0.292, \"Liveness\": 0.109, \"Tempo\": 144.064, \"Duration (ms)\": 180000.0, \"Valence\": 0.239, \"Chord\": \"A#/Bb\"}, {\"Index\": 1205, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"From Florida With Love\", \"Streams\": 7216610, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"0YkUwXxnTkeJBvt5upeEtP\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.787, \"Energy\": 0.477, \"Loudness\": -7.837, \"Speechiness\": 0.199, \"Acousticness\": 0.768, \"Liveness\": 0.104, \"Tempo\": 80.506, \"Duration (ms)\": 234783.0, \"Valence\": 0.476, \"Chord\": \"F#/Gb\"}, {\"Index\": 1206, \"Highest Charting Position\": 89, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Losses\", \"Streams\": 6894756, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"6fLVTVaHWaEfVKfEgbkf4D\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 57.0, \"Danceability\": 0.551, \"Energy\": 0.57, \"Loudness\": -7.385, \"Speechiness\": 0.351, \"Acousticness\": 0.28, \"Liveness\": 0.424, \"Tempo\": 85.687, \"Duration (ms)\": 271184.0, \"Valence\": 0.505, \"Chord\": \"C#/Db\"}, {\"Index\": 1208, \"Highest Charting Position\": 40, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Boyfriend\", \"Streams\": 5236730, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4QnC1bIaMSfDQvF4XDhV5M\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 62.0, \"Danceability\": 0.811, \"Energy\": 0.512, \"Loudness\": -6.381, \"Speechiness\": 0.17, \"Acousticness\": 0.218, \"Liveness\": 0.0768, \"Tempo\": 92.046, \"Duration (ms)\": 161188.0, \"Valence\": 0.346, \"Chord\": \"D\"}, {\"Index\": 1211, \"Highest Charting Position\": 32, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"FIND MY WAY\", \"Streams\": 4753495, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"1gVCEnryJhkdQcuC0Kbvor\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 66.0, \"Danceability\": 0.836, \"Energy\": 0.624, \"Loudness\": -6.75, \"Speechiness\": 0.184, \"Acousticness\": 0.187, \"Liveness\": 0.138, \"Tempo\": 103.0, \"Duration (ms)\": 139890.0, \"Valence\": 0.7, \"Chord\": \"E\"}, {\"Index\": 1213, \"Highest Charting Position\": 130, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"God's Plan\", \"Streams\": 4565400, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"6DCZcSspjsKoFjzjrWoCdn\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2018-06-29\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.754, \"Energy\": 0.449, \"Loudness\": -9.211, \"Speechiness\": 0.109, \"Acousticness\": 0.0332, \"Liveness\": 0.552, \"Tempo\": 77.169, \"Duration (ms)\": 198973.0, \"Valence\": 0.357, \"Chord\": \"G\"}, {\"Index\": 1222, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Sasuke\", \"Streams\": 4701551, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"0ROE31C8Wu4neZoR9stM9e\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 56.0, \"Danceability\": 0.859, \"Energy\": 0.477, \"Loudness\": -6.116, \"Speechiness\": 0.428, \"Acousticness\": 0.00414, \"Liveness\": 0.0819, \"Tempo\": 145.979, \"Duration (ms)\": 251336.0, \"Valence\": 0.153, \"Chord\": \"C#/Db\"}, {\"Index\": 1230, \"Highest Charting Position\": 78, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"PICK UP (feat. Quavo)\", \"Streams\": 7065060, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"5gNOINI5dXZVom2b36LMOd\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 65.0, \"Danceability\": 0.915, \"Energy\": 0.612, \"Loudness\": -4.535, \"Speechiness\": 0.407, \"Acousticness\": 0.0944, \"Liveness\": 0.115, \"Tempo\": 129.93, \"Duration (ms)\": 118547.0, \"Valence\": 0.758, \"Chord\": \"C#/Db\"}, {\"Index\": 1231, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"JUMP (feat. YoungBoy Never Broke Again)\", \"Streams\": 6033348, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"0oT9ElXYSxvnOOagP9efDq\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 62.0, \"Danceability\": 0.896, \"Energy\": 0.72, \"Loudness\": -6.262, \"Speechiness\": 0.355, \"Acousticness\": 0.169, \"Liveness\": 0.252, \"Tempo\": 140.1, \"Duration (ms)\": 212093.0, \"Valence\": 0.966, \"Chord\": \"C\"}, {\"Index\": 1232, \"Highest Charting Position\": 156, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"LIGHTSKIN SH*T (feat. Future & jetsonmade)\", \"Streams\": 4861875, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"16oi4OiKmkO51l60F5R9kR\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 56.0, \"Danceability\": 0.932, \"Energy\": 0.578, \"Loudness\": -4.478, \"Speechiness\": 0.366, \"Acousticness\": 0.115, \"Liveness\": 0.115, \"Tempo\": 129.991, \"Duration (ms)\": 111173.0, \"Valence\": 0.623, \"Chord\": \"A\"}, {\"Index\": 1233, \"Highest Charting Position\": 16, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"That Way - Bonus Track\", \"Streams\": 4825741, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2ajzBr7vwHTEBeqDzcsNRC\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.712, \"Energy\": 0.598, \"Loudness\": -5.368, \"Speechiness\": 0.0388, \"Acousticness\": 0.0546, \"Liveness\": 0.154, \"Tempo\": 130.007, \"Duration (ms)\": 212354.0, \"Valence\": 0.504, \"Chord\": \"G\"}, {\"Index\": 1237, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"BLAME IT ON BABY\", \"Streams\": 4616034, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"0jWm0VyD8p3MrSInczpows\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 57.0, \"Danceability\": 0.875, \"Energy\": 0.687, \"Loudness\": -5.734, \"Speechiness\": 0.387, \"Acousticness\": 0.236, \"Liveness\": 0.141, \"Tempo\": 109.791, \"Duration (ms)\": 125907.0, \"Valence\": 0.864, \"Chord\": \"A\"}, {\"Index\": 1252, \"Highest Charting Position\": 15, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Forever (feat. Post Malone & Clever)\", \"Streams\": 6517807, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2ZlCGeK30BLRNSPC832pNZ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 68.0, \"Danceability\": 0.825, \"Energy\": 0.483, \"Loudness\": -5.746, \"Speechiness\": 0.08, \"Acousticness\": 0.538, \"Liveness\": 0.204, \"Tempo\": 139.98, \"Duration (ms)\": 219933.0, \"Valence\": 0.892, \"Chord\": \"G#/Ab\"}, {\"Index\": 1255, \"Highest Charting Position\": 29, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Pero Ya No\", \"Streams\": 4666658, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"75pQqzwgCjUOSSy5CpmAjy\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 72.0, \"Danceability\": 0.882, \"Energy\": 0.612, \"Loudness\": -6.103, \"Speechiness\": 0.118, \"Acousticness\": 0.0475, \"Liveness\": 0.182, \"Tempo\": 147.982, \"Duration (ms)\": 160638.0, \"Valence\": 0.742, \"Chord\": \"E\"}, {\"Index\": 1256, \"Highest Charting Position\": 24, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Hardest To Love\", \"Streams\": 4553544, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"6kWxIqQDsKFYCJGbU4AjCX\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.467, \"Energy\": 0.608, \"Loudness\": -7.847, \"Speechiness\": 0.0707, \"Acousticness\": 0.0909, \"Liveness\": 0.125, \"Tempo\": 80.957, \"Duration (ms)\": 211400.0, \"Valence\": 0.108, \"Chord\": \"A#/Bb\"}, {\"Index\": 1259, \"Highest Charting Position\": 69, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Pretty Please\", \"Streams\": 4305034, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"6DXZiYUbrYgrVIhfX3U9Z2\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 67.0, \"Danceability\": 0.906, \"Energy\": 0.474, \"Loudness\": -6.124, \"Speechiness\": 0.194, \"Acousticness\": 0.0311, \"Liveness\": 0.286, \"Tempo\": 106.976, \"Duration (ms)\": 194607.0, \"Valence\": 0.656, \"Chord\": \"C#/Db\"}, {\"Index\": 1261, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Cool\", \"Streams\": 8136247, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"4Ulqu89XempybuL8ApUeqL\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.469, \"Energy\": 0.785, \"Loudness\": -4.015, \"Speechiness\": 0.0664, \"Acousticness\": 0.133, \"Liveness\": 0.0931, \"Tempo\": 89.719, \"Duration (ms)\": 209583.0, \"Valence\": 0.79, \"Chord\": \"F\"}, {\"Index\": 1262, \"Highest Charting Position\": 71, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Future Nostalgia\", \"Streams\": 8091754, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3iYNJX4FTRGlfMQySjlGNr\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.875, \"Energy\": 0.813, \"Loudness\": -4.502, \"Speechiness\": 0.0579, \"Acousticness\": 0.00618, \"Liveness\": 0.321, \"Tempo\": 114.993, \"Duration (ms)\": 184882.0, \"Valence\": 0.859, \"Chord\": \"G\"}, {\"Index\": 1263, \"Highest Charting Position\": 92, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Good In Bed\", \"Streams\": 6802068, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3pyodt4pb554dMz8fCv7oi\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 64.0, \"Danceability\": 0.68, \"Energy\": 0.701, \"Loudness\": -5.001, \"Speechiness\": 0.0917, \"Acousticness\": 0.138, \"Liveness\": 0.168, \"Tempo\": 94.06, \"Duration (ms)\": 218754.0, \"Valence\": 0.649, \"Chord\": \"F\"}, {\"Index\": 1264, \"Highest Charting Position\": 27, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Scared To Live\", \"Streams\": 6566099, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"4BGZF4oLbTL0pWm7C18pbv\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 66.0, \"Danceability\": 0.504, \"Energy\": 0.498, \"Loudness\": -8.24, \"Speechiness\": 0.0499, \"Acousticness\": 0.131, \"Liveness\": 0.0929, \"Tempo\": 87.221, \"Duration (ms)\": 191307.0, \"Valence\": 0.196, \"Chord\": \"C\"}, {\"Index\": 1265, \"Highest Charting Position\": 21, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Alone Again\", \"Streams\": 6055294, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"6b5P51m8xx2XA6U7sdNZ5E\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 66.0, \"Danceability\": 0.218, \"Energy\": 0.652, \"Loudness\": -7.953, \"Speechiness\": 0.0641, \"Acousticness\": 0.033, \"Liveness\": 0.172, \"Tempo\": 65.375, \"Duration (ms)\": 250053.0, \"Valence\": 0.0599, \"Chord\": \"E\"}, {\"Index\": 1266, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Boys Will Be Boys\", \"Streams\": 6015914, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"4szI7zRh7kLApCSqiB6R7b\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 63.0, \"Danceability\": 0.768, \"Energy\": 0.486, \"Loudness\": -5.954, \"Speechiness\": 0.0353, \"Acousticness\": 0.408, \"Liveness\": 0.098, \"Tempo\": 125.021, \"Duration (ms)\": 166266.0, \"Valence\": 0.519, \"Chord\": \"D#/Eb\"}, {\"Index\": 1269, \"Highest Charting Position\": 28, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Too Late\", \"Streams\": 5867746, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"2K9Ovn1o2bTGqbsABGC6m3\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.638, \"Energy\": 0.863, \"Loudness\": -5.221, \"Speechiness\": 0.132, \"Acousticness\": 0.052, \"Liveness\": 0.685, \"Tempo\": 120.077, \"Duration (ms)\": 239973.0, \"Valence\": 0.226, \"Chord\": \"E\"}, {\"Index\": 1271, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Faith\", \"Streams\": 5730081, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"3orEOtd8CPL8GFlpRpKuoE\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.375, \"Energy\": 0.605, \"Loudness\": -7.268, \"Speechiness\": 0.0729, \"Acousticness\": 0.612, \"Liveness\": 0.147, \"Tempo\": 175.946, \"Duration (ms)\": 283227.0, \"Valence\": 0.128, \"Chord\": \"C\"}, {\"Index\": 1272, \"Highest Charting Position\": 35, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Snowchild\", \"Streams\": 5423997, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"3WlbeuhfRSqU7ylK2Ui5U7\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 66.0, \"Danceability\": 0.55, \"Energy\": 0.611, \"Loudness\": -7.475, \"Speechiness\": 0.137, \"Acousticness\": 0.162, \"Liveness\": 0.121, \"Tempo\": 148.062, \"Duration (ms)\": 247187.0, \"Valence\": 0.243, \"Chord\": \"C\"}, {\"Index\": 1273, \"Highest Charting Position\": 37, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Escape From LA\", \"Streams\": 5307288, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"1sOW4PuG5X3Ie3EXUhAopJ\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.404, \"Energy\": 0.524, \"Loudness\": -8.996, \"Speechiness\": 0.0593, \"Acousticness\": 0.0456, \"Liveness\": 0.199, \"Tempo\": 145.74, \"Duration (ms)\": 355960.0, \"Valence\": 0.168, \"Chord\": \"F\"}, {\"Index\": 1279, \"Highest Charting Position\": 51, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Repeat After Me (Interlude)\", \"Streams\": 10058303, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"40U8d12pC5UHqmHwXjHjjl\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 63.0, \"Danceability\": 0.555, \"Energy\": 0.619, \"Loudness\": -7.918, \"Speechiness\": 0.0314, \"Acousticness\": 0.0323, \"Liveness\": 0.0917, \"Tempo\": 95.032, \"Duration (ms)\": 195813.0, \"Valence\": 0.141, \"Chord\": \"C\"}, {\"Index\": 1280, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Until I Bleed Out\", \"Streams\": 9132077, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"2BcnxwxBuar5wjCaLqm5N3\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 63.0, \"Danceability\": 0.245, \"Energy\": 0.394, \"Loudness\": -9.887, \"Speechiness\": 0.0374, \"Acousticness\": 0.423, \"Liveness\": 0.093, \"Tempo\": 115.233, \"Duration (ms)\": 190173.0, \"Valence\": 0.148, \"Chord\": \"C\"}, {\"Index\": 1285, \"Highest Charting Position\": 15, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Baby Pluto\", \"Streams\": 5600261, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7hav1MHURQf5SAoPk0egqh\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 69.0, \"Danceability\": 0.772, \"Energy\": 0.634, \"Loudness\": -6.101, \"Speechiness\": 0.212, \"Acousticness\": 0.135, \"Liveness\": 0.432, \"Tempo\": 160.052, \"Duration (ms)\": 210261.0, \"Valence\": 0.671, \"Chord\": \"A#/Bb\"}, {\"Index\": 1286, \"Highest Charting Position\": 31, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Lo Mein\", \"Streams\": 5231134, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"6CUP2khYzdphXebxVTfPE3\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.855, \"Energy\": 0.676, \"Loudness\": -5.736, \"Speechiness\": 0.325, \"Acousticness\": 0.0888, \"Liveness\": 0.144, \"Tempo\": 133.082, \"Duration (ms)\": 195299.0, \"Valence\": 0.509, \"Chord\": \"C#/Db\"}, {\"Index\": 1288, \"Highest Charting Position\": 57, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Futsal Shuffle 2020 - Bonus Track\", \"Streams\": 5068849, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2fOlBMkWR7lXJfqp5VTbDG\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 63.0, \"Danceability\": 0.879, \"Energy\": 0.448, \"Loudness\": -8.57, \"Speechiness\": 0.222, \"Acousticness\": 0.0346, \"Liveness\": 0.224, \"Tempo\": 136.985, \"Duration (ms)\": 198913.0, \"Valence\": 0.278, \"Chord\": \"G\"}, {\"Index\": 1290, \"Highest Charting Position\": 65, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"TOES (feat. Lil Baby & Moneybagg Yo)\", \"Streams\": 4878903, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"2FvD20Z8aoWIePi7PoN8sG\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 73.0, \"Danceability\": 0.816, \"Energy\": 0.582, \"Loudness\": -4.141, \"Speechiness\": 0.341, \"Acousticness\": 0.0794, \"Liveness\": 0.0916, \"Tempo\": 160.004, \"Duration (ms)\": 136366.0, \"Valence\": 0.542, \"Chord\": \"G#/Ab\"}, {\"Index\": 1291, \"Highest Charting Position\": 42, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Feel Me\", \"Streams\": 4765672, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"6XXYdF6pJR1K3wKvuxmu7n\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 63.0, \"Danceability\": 0.71, \"Energy\": 0.808, \"Loudness\": -6.703, \"Speechiness\": 0.0433, \"Acousticness\": 0.44, \"Liveness\": 0.0734, \"Tempo\": 99.989, \"Duration (ms)\": 226003.0, \"Valence\": 0.392, \"Chord\": \"D\"}, {\"Index\": 1293, \"Highest Charting Position\": 63, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"25/8\", \"Streams\": 4684378, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4NqQaovM14WR2hNPMFxgjb\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 71.0, \"Danceability\": 0.761, \"Energy\": 0.732, \"Loudness\": -5.469, \"Speechiness\": 0.0549, \"Acousticness\": 0.092, \"Liveness\": 0.0716, \"Tempo\": 151.982, \"Duration (ms)\": 243276.0, \"Valence\": 0.542, \"Chord\": \"E\"}, {\"Index\": 1296, \"Highest Charting Position\": 45, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Soli\\u00e1\", \"Streams\": 4516243, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"7sOfmPd18RWp3FoCzpa7Kw\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 72.0, \"Danceability\": 0.71, \"Energy\": 0.81, \"Loudness\": -5.507, \"Speechiness\": 0.0854, \"Acousticness\": 0.117, \"Liveness\": 0.154, \"Tempo\": 92.041, \"Duration (ms)\": 159282.0, \"Valence\": 0.184, \"Chord\": \"D\"}, {\"Index\": 1298, \"Highest Charting Position\": 61, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Bean (Kobe) [feat. Chief Keef]\", \"Streams\": 9039518, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"0IpnZchq8ek2A6pGEP2Qb1\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 67.0, \"Danceability\": 0.733, \"Energy\": 0.567, \"Loudness\": -6.718, \"Speechiness\": 0.319, \"Acousticness\": 0.0129, \"Liveness\": 0.382, \"Tempo\": 75.491, \"Duration (ms)\": 238816.0, \"Valence\": 0.319, \"Chord\": \"C\"}, {\"Index\": 1301, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Silly Watch\", \"Streams\": 6442451, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"5egD7A5x9AHdVO2fMo3Wbo\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 65.0, \"Danceability\": 0.903, \"Energy\": 0.535, \"Loudness\": -6.238, \"Speechiness\": 0.286, \"Acousticness\": 0.0298, \"Liveness\": 0.0851, \"Tempo\": 130.117, \"Duration (ms)\": 195692.0, \"Valence\": 0.157, \"Chord\": \"G#/Ab\"}, {\"Index\": 1303, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Lotus\", \"Streams\": 6017103, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4SnlSaLJJ7reJMCHM5YUuX\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 58.0, \"Danceability\": 0.802, \"Energy\": 0.748, \"Loudness\": -5.708, \"Speechiness\": 0.207, \"Acousticness\": 0.24, \"Liveness\": 0.165, \"Tempo\": 150.063, \"Duration (ms)\": 193861.0, \"Valence\": 0.516, \"Chord\": \"G#/Ab\"}, {\"Index\": 1306, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Leaders (feat. NAV)\", \"Streams\": 5496780, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4D7NrSeqkTarBrJ80b2sBc\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 60.0, \"Danceability\": 0.95, \"Energy\": 0.654, \"Loudness\": -5.895, \"Speechiness\": 0.307, \"Acousticness\": 0.0744, \"Liveness\": 0.138, \"Tempo\": 132.936, \"Duration (ms)\": 194844.0, \"Valence\": 0.886, \"Chord\": \"C\"}, {\"Index\": 1307, \"Highest Charting Position\": 149, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Strawberry Peels (feat. Young Thug & Gunna)\", \"Streams\": 5468083, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4lAQfuREAHG8IC0PiiigBt\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 59.0, \"Danceability\": 0.862, \"Energy\": 0.65, \"Loudness\": -6.978, \"Speechiness\": 0.355, \"Acousticness\": 0.0207, \"Liveness\": 0.568, \"Tempo\": 131.194, \"Duration (ms)\": 115350.0, \"Valence\": 0.658, \"Chord\": \"A#/Bb\"}, {\"Index\": 1308, \"Highest Charting Position\": 60, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"La Zona\", \"Streams\": 5440382, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5kqNIqFjijuzvVLhuY9B8j\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.762, \"Energy\": 0.801, \"Loudness\": -3.661, \"Speechiness\": 0.0409, \"Acousticness\": 0.2, \"Liveness\": 0.254, \"Tempo\": 93.992, \"Duration (ms)\": 136893.0, \"Valence\": 0.81, \"Chord\": \"C#/Db\"}, {\"Index\": 1309, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Wassup (feat. Future)\", \"Streams\": 5415044, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"19Ec2gbNtQTE44IizcPjtD\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 57.0, \"Danceability\": 0.762, \"Energy\": 0.622, \"Loudness\": -6.293, \"Speechiness\": 0.223, \"Acousticness\": 0.352, \"Liveness\": 0.145, \"Tempo\": 130.019, \"Duration (ms)\": 193314.0, \"Valence\": 0.626, \"Chord\": \"F\"}, {\"Index\": 1311, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Moon Relate\", \"Streams\": 5324545, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4sWGHlZGM1XA7TyWdtBAbA\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 58.0, \"Danceability\": 0.867, \"Energy\": 0.768, \"Loudness\": -3.73, \"Speechiness\": 0.0791, \"Acousticness\": 0.18, \"Liveness\": 0.254, \"Tempo\": 102.021, \"Duration (ms)\": 181826.0, \"Valence\": 0.34, \"Chord\": \"G\"}, {\"Index\": 1316, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Trap This Way (This Way)\", \"Streams\": 5043990, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7vTspUAmMKFkUpKL9HLZNL\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 59.0, \"Danceability\": 0.71, \"Energy\": 0.586, \"Loudness\": -5.331, \"Speechiness\": 0.381, \"Acousticness\": 0.248, \"Liveness\": 0.193, \"Tempo\": 175.987, \"Duration (ms)\": 185439.0, \"Valence\": 0.207, \"Chord\": \"D\"}, {\"Index\": 1318, \"Highest Charting Position\": 51, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Homecoming\", \"Streams\": 4988839, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"6vxU64pcIuQ38O015Zy4qj\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 63.0, \"Danceability\": 0.929, \"Energy\": 0.563, \"Loudness\": -7.428, \"Speechiness\": 0.49, \"Acousticness\": 0.000592, \"Liveness\": 0.244, \"Tempo\": 129.957, \"Duration (ms)\": 213885.0, \"Valence\": 0.353, \"Chord\": \"A\"}, {\"Index\": 1319, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Got The Guap (feat. Young Thug)\", \"Streams\": 4946997, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"1HF6P40Z7nfExGaB1Gk99v\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 58.0, \"Danceability\": 0.837, \"Energy\": 0.601, \"Loudness\": -5.628, \"Speechiness\": 0.198, \"Acousticness\": 0.21, \"Liveness\": 0.0928, \"Tempo\": 142.977, \"Duration (ms)\": 176756.0, \"Valence\": 0.749, \"Chord\": \"G#/Ab\"}, {\"Index\": 1320, \"Highest Charting Position\": 53, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Prices\", \"Streams\": 4898167, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4YcWzLSnGqLjSCycuSMHnn\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 65.0, \"Danceability\": 0.786, \"Energy\": 0.683, \"Loudness\": -5.397, \"Speechiness\": 0.205, \"Acousticness\": 0.173, \"Liveness\": 0.706, \"Tempo\": 126.002, \"Duration (ms)\": 233333.0, \"Valence\": 0.57, \"Chord\": \"G\"}, {\"Index\": 1321, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"I Can Show You\", \"Streams\": 4831405, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"0AhJag7VI8uFf3mJFsTwvf\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 57.0, \"Danceability\": 0.817, \"Energy\": 0.656, \"Loudness\": -7.086, \"Speechiness\": 0.277, \"Acousticness\": 0.051, \"Liveness\": 0.115, \"Tempo\": 139.915, \"Duration (ms)\": 120076.0, \"Valence\": 0.314, \"Chord\": \"A#/Bb\"}, {\"Index\": 1322, \"Highest Charting Position\": 52, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"I'm Sorry\", \"Streams\": 4818039, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"1xcOYJxDa5pObgxY1r0I9c\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 60.0, \"Danceability\": 0.858, \"Energy\": 0.547, \"Loudness\": -5.822, \"Speechiness\": 0.29, \"Acousticness\": 0.213, \"Liveness\": 0.104, \"Tempo\": 128.02, \"Duration (ms)\": 211883.0, \"Valence\": 0.303, \"Chord\": \"C#/Db\"}, {\"Index\": 1323, \"Highest Charting Position\": 19, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Black Swan\", \"Streams\": 4802069, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3bkkMZEAhx7rTVz1C0itRQ\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 70.0, \"Danceability\": 0.719, \"Energy\": 0.758, \"Loudness\": -5.167, \"Speechiness\": 0.0851, \"Acousticness\": 0.137, \"Liveness\": 0.129, \"Tempo\": 147.023, \"Duration (ms)\": 198261.0, \"Valence\": 0.49, \"Chord\": \"D\"}, {\"Index\": 1326, \"Highest Charting Position\": 66, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"<3\", \"Streams\": 4755477, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4MZSqgwlE71CWZ6qQ3gkKm\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.631, \"Energy\": 0.665, \"Loudness\": -7.589, \"Speechiness\": 0.229, \"Acousticness\": 0.602, \"Liveness\": 0.152, \"Tempo\": 80.353, \"Duration (ms)\": 157967.0, \"Valence\": 0.634, \"Chord\": \"A#/Bb\"}, {\"Index\": 1329, \"Highest Charting Position\": 60, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"POP\", \"Streams\": 10484727, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"1jDbQz6tr52WgScCTXMnaN\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 58.0, \"Danceability\": 0.741, \"Energy\": 0.599, \"Loudness\": -6.672, \"Speechiness\": 0.419, \"Acousticness\": 0.00961, \"Liveness\": 0.785, \"Tempo\": 139.891, \"Duration (ms)\": 227474.0, \"Valence\": 0.276, \"Chord\": \"C#/Db\"}, {\"Index\": 1330, \"Highest Charting Position\": 61, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Celebration Station\", \"Streams\": 10396969, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"25B5fGr9K0VdZJiRFsnMO4\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 61.0, \"Danceability\": 0.748, \"Energy\": 0.771, \"Loudness\": -4.156, \"Speechiness\": 0.15, \"Acousticness\": 0.101, \"Liveness\": 0.135, \"Tempo\": 142.086, \"Duration (ms)\": 195058.0, \"Valence\": 0.792, \"Chord\": \"F#/Gb\"}, {\"Index\": 1331, \"Highest Charting Position\": 64, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Bigger Than Life\", \"Streams\": 9974143, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2oHDJHNondITqbl8xZ9vPn\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 62.0, \"Danceability\": 0.776, \"Energy\": 0.752, \"Loudness\": -4.711, \"Speechiness\": 0.193, \"Acousticness\": 0.325, \"Liveness\": 0.33, \"Tempo\": 140.013, \"Duration (ms)\": 192705.0, \"Valence\": 0.716, \"Chord\": \"G#/Ab\"}, {\"Index\": 1332, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Venetia\", \"Streams\": 9824605, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"3BYIzNZ3t9lRQCACXSMLrT\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 63.0, \"Danceability\": 0.775, \"Energy\": 0.757, \"Loudness\": -4.139, \"Speechiness\": 0.175, \"Acousticness\": 0.162, \"Liveness\": 0.148, \"Tempo\": 142.933, \"Duration (ms)\": 188800.0, \"Valence\": 0.562, \"Chord\": \"A\"}, {\"Index\": 1333, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"You Better Move\", \"Streams\": 9533898, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"6YAxCn4juTWn5hWl2hzHGw\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 60.0, \"Danceability\": 0.842, \"Energy\": 0.556, \"Loudness\": -6.793, \"Speechiness\": 0.442, \"Acousticness\": 0.159, \"Liveness\": 0.204, \"Tempo\": 118.836, \"Duration (ms)\": 196639.0, \"Valence\": 0.306, \"Chord\": \"G#/Ab\"}, {\"Index\": 1334, \"Highest Charting Position\": 93, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Chrome Heart Tags\", \"Streams\": 8219307, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"46mT9NR7N9Zf5MolcrBgE3\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 57.0, \"Danceability\": 0.702, \"Energy\": 0.768, \"Loudness\": -4.055, \"Speechiness\": 0.0669, \"Acousticness\": 0.541, \"Liveness\": 0.105, \"Tempo\": 70.056, \"Duration (ms)\": 212821.0, \"Valence\": 0.574, \"Chord\": \"C\"}, {\"Index\": 1335, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Bust Me\", \"Streams\": 7828045, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4wBcaYqLPm7EtDVoJQORU4\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 57.0, \"Danceability\": 0.734, \"Energy\": 0.703, \"Loudness\": -6.256, \"Speechiness\": 0.355, \"Acousticness\": 0.237, \"Liveness\": 0.413, \"Tempo\": 151.923, \"Duration (ms)\": 194452.0, \"Valence\": 0.608, \"Chord\": \"B\"}, {\"Index\": 1337, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Secure The Bag\", \"Streams\": 7053947, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7gHZGXSJzM29WA384suYY2\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 57.0, \"Danceability\": 0.803, \"Energy\": 0.719, \"Loudness\": -4.485, \"Speechiness\": 0.392, \"Acousticness\": 0.344, \"Liveness\": 0.425, \"Tempo\": 129.945, \"Duration (ms)\": 238425.0, \"Valence\": 0.549, \"Chord\": \"C\"}, {\"Index\": 1338, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Urgency (feat. Syd)\", \"Streams\": 6224412, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"5KlPy74NOEAt8jC3FYURnQ\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 53.0, \"Danceability\": 0.619, \"Energy\": 0.784, \"Loudness\": -6.11, \"Speechiness\": 0.123, \"Acousticness\": 0.0326, \"Liveness\": 0.315, \"Tempo\": 156.035, \"Duration (ms)\": 181161.0, \"Valence\": 0.471, \"Chord\": \"C#/Db\"}, {\"Index\": 1339, \"Highest Charting Position\": 34, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"ON (Feat. Sia)\", \"Streams\": 6219276, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3IB5qOeMayvpOdHxYCL5tZ\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 64.0, \"Danceability\": 0.591, \"Energy\": 0.848, \"Loudness\": -4.397, \"Speechiness\": 0.0828, \"Acousticness\": 0.137, \"Liveness\": 0.372, \"Tempo\": 105.922, \"Duration (ms)\": 246816.0, \"Valence\": 0.386, \"Chord\": \"A\"}, {\"Index\": 1354, \"Highest Charting Position\": 12, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Rare\", \"Streams\": 5195842, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"7HMmFQsKsljwTw8bS7lu19\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 68.0, \"Danceability\": 0.838, \"Energy\": 0.545, \"Loudness\": -6.713, \"Speechiness\": 0.0706, \"Acousticness\": 0.208, \"Liveness\": 0.103, \"Tempo\": 114.998, \"Duration (ms)\": 220590.0, \"Valence\": 0.631, \"Chord\": \"F\"}, {\"Index\": 1355, \"Highest Charting Position\": 69, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"VIBEZ\", \"Streams\": 5121486, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"0fySG6A6qLE8IvDpayb5bM\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.768, \"Energy\": 0.652, \"Loudness\": -2.708, \"Speechiness\": 0.307, \"Acousticness\": 0.113, \"Liveness\": 0.107, \"Tempo\": 154.187, \"Duration (ms)\": 144935.0, \"Valence\": 0.777, \"Chord\": \"C#/Db\"}, {\"Index\": 1357, \"Highest Charting Position\": 49, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"That Way\", \"Streams\": 12059592, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"5raTDhlbxFDnpn89bxArdH\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-01\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 67.0, \"Danceability\": 0.719, \"Energy\": 0.611, \"Loudness\": -5.01, \"Speechiness\": 0.0403, \"Acousticness\": 0.0582, \"Liveness\": 0.155, \"Tempo\": 129.962, \"Duration (ms)\": 212354.0, \"Valence\": 0.489, \"Chord\": \"G\"}, {\"Index\": 1361, \"Highest Charting Position\": 47, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Filter\", \"Streams\": 5913946, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"0ono6UCNVZ1XqOm6j78Blu\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 79.0, \"Danceability\": 0.781, \"Energy\": 0.762, \"Loudness\": -5.188, \"Speechiness\": 0.0626, \"Acousticness\": 0.0222, \"Liveness\": 0.121, \"Tempo\": 110.042, \"Duration (ms)\": 180221.0, \"Valence\": 0.86, \"Chord\": \"A#/Bb\"}, {\"Index\": 1366, \"Highest Charting Position\": 32, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Futsal Shuffle 2020\", \"Streams\": 5386512, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2Ec33AVlkTTq8BHFgBTdQs\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-12\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.881, \"Energy\": 0.457, \"Loudness\": -8.191, \"Speechiness\": 0.156, \"Acousticness\": 0.0327, \"Liveness\": 0.231, \"Tempo\": 136.97, \"Duration (ms)\": 198913.0, \"Valence\": 0.296, \"Chord\": \"G\"}, {\"Index\": 1370, \"Highest Charting Position\": 58, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"My Time\", \"Streams\": 5212053, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4vTgx6h4seHvkuFh84JXYP\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 74.0, \"Danceability\": 0.674, \"Energy\": 0.64, \"Loudness\": -5.139, \"Speechiness\": 0.0339, \"Acousticness\": 0.151, \"Liveness\": 0.0925, \"Tempo\": 99.908, \"Duration (ms)\": 234458.0, \"Valence\": 0.664, \"Chord\": \"C\"}, {\"Index\": 1375, \"Highest Charting Position\": 140, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"You Need To Calm Down\", \"Streams\": 5115153, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6RRNNciQGZEXnqk8SQ9yv5\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.771, \"Energy\": 0.671, \"Loudness\": -5.617, \"Speechiness\": 0.0553, \"Acousticness\": 0.00929, \"Liveness\": 0.0637, \"Tempo\": 85.026, \"Duration (ms)\": 171360.0, \"Valence\": 0.714, \"Chord\": \"D\"}, {\"Index\": 1380, \"Highest Charting Position\": 91, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"bury a friend\", \"Streams\": 5020303, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"7p6ZK1vOxKELFwlDfwkJCp\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 1.0, \"Danceability\": 0.887, \"Energy\": 0.388, \"Loudness\": -14.505, \"Speechiness\": 0.349, \"Acousticness\": 0.739, \"Liveness\": 0.106, \"Tempo\": 120.035, \"Duration (ms)\": 193143.0, \"Valence\": 0.205, \"Chord\": \"G#/Ab\"}, {\"Index\": 1381, \"Highest Charting Position\": 54, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Louder than bombs\", \"Streams\": 10016907, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3op7HNwLli54MBjFGzIlZO\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.643, \"Energy\": 0.667, \"Loudness\": -6.993, \"Speechiness\": 0.152, \"Acousticness\": 0.0433, \"Liveness\": 0.0904, \"Tempo\": 145.999, \"Duration (ms)\": 217404.0, \"Valence\": 0.485, \"Chord\": \"C\"}, {\"Index\": 1382, \"Highest Charting Position\": 56, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"UGH!\", \"Streams\": 9991177, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"1aKuG1GG76xPLUkjBbQo3W\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.72, \"Energy\": 0.824, \"Loudness\": -5.086, \"Speechiness\": 0.128, \"Acousticness\": 0.0394, \"Liveness\": 0.0509, \"Tempo\": 165.998, \"Duration (ms)\": 225012.0, \"Valence\": 0.333, \"Chord\": \"A#/Bb\"}, {\"Index\": 1383, \"Highest Charting Position\": 67, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"00:00 (Zero O\\u2019Clock)\", \"Streams\": 9372219, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4AlihYDqxXshKhvh5tnMfP\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.566, \"Energy\": 0.548, \"Loudness\": -6.456, \"Speechiness\": 0.0579, \"Acousticness\": 0.0802, \"Liveness\": 0.11, \"Tempo\": 157.999, \"Duration (ms)\": 250296.0, \"Valence\": 0.196, \"Chord\": \"C#/Db\"}, {\"Index\": 1384, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Friends\", \"Streams\": 8822365, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"7w05lsU2VLSeiT8Nukrv5M\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.55, \"Energy\": 0.747, \"Loudness\": -5.211, \"Speechiness\": 0.0407, \"Acousticness\": 0.0668, \"Liveness\": 0.0536, \"Tempo\": 79.98, \"Duration (ms)\": 199339.0, \"Valence\": 0.648, \"Chord\": \"C#/Db\"}, {\"Index\": 1385, \"Highest Charting Position\": 75, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"We are Bulletproof : the Eternal\", \"Streams\": 8516710, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"44WLOqH7QayQOQdeUHeKUK\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.526, \"Energy\": 0.575, \"Loudness\": -5.215, \"Speechiness\": 0.0309, \"Acousticness\": 0.225, \"Liveness\": 0.108, \"Tempo\": 84.047, \"Duration (ms)\": 261543.0, \"Valence\": 0.19, \"Chord\": \"A\"}, {\"Index\": 1386, \"Highest Charting Position\": 79, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Inner Child\", \"Streams\": 8312399, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4BKOjYosPhw334moS3wlbO\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 71.0, \"Danceability\": 0.589, \"Energy\": 0.696, \"Loudness\": -7.981, \"Speechiness\": 0.0725, \"Acousticness\": 0.017, \"Liveness\": 0.0808, \"Tempo\": 134.953, \"Duration (ms)\": 233266.0, \"Valence\": 0.332, \"Chord\": \"B\"}, {\"Index\": 1387, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Moon\", \"Streams\": 7850129, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"1xfXXujIlLZAx5wpu46Nyk\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.703, \"Energy\": 0.646, \"Loudness\": -6.658, \"Speechiness\": 0.0596, \"Acousticness\": 0.0104, \"Liveness\": 0.191, \"Tempo\": 141.87, \"Duration (ms)\": 208590.0, \"Valence\": 0.64, \"Chord\": \"F#/Gb\"}, {\"Index\": 1388, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Outro : Ego\", \"Streams\": 6857808, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3r9FFjLrAIQjoR8pSHVPC9\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 69.0, \"Danceability\": 0.808, \"Energy\": 0.903, \"Loudness\": -3.106, \"Speechiness\": 0.0958, \"Acousticness\": 0.0121, \"Liveness\": 0.0993, \"Tempo\": 116.988, \"Duration (ms)\": 196199.0, \"Valence\": 0.473, \"Chord\": \"C\"}, {\"Index\": 1389, \"Highest Charting Position\": 109, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Interlude : Shadow\", \"Streams\": 6655856, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"2Nib4r0saYQf2pUV4RFDhl\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 68.0, \"Danceability\": 0.385, \"Energy\": 0.798, \"Loudness\": -6.439, \"Speechiness\": 0.483, \"Acousticness\": 0.115, \"Liveness\": 0.181, \"Tempo\": 149.756, \"Duration (ms)\": 259821.0, \"Valence\": 0.141, \"Chord\": \"A\"}, {\"Index\": 1390, \"Highest Charting Position\": 120, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Respect\", \"Streams\": 6373954, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"37TSJmYKLxXmx8OehFpqMN\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 67.0, \"Danceability\": 0.661, \"Energy\": 0.84, \"Loudness\": -4.805, \"Speechiness\": 0.116, \"Acousticness\": 0.00485, \"Liveness\": 0.287, \"Tempo\": 91.457, \"Duration (ms)\": 237540.0, \"Valence\": 0.524, \"Chord\": \"C\"}, {\"Index\": 1393, \"Highest Charting Position\": 129, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Lose Yourself - From \\\"8 Mile\\\" Soundtrack\", \"Streams\": 5118004, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5Z01UMMf7V1o0MzF86s6WJ\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2005-12-06\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 75.0, \"Danceability\": 0.692, \"Energy\": 0.744, \"Loudness\": -4.565, \"Speechiness\": 0.257, \"Acousticness\": 0.00868, \"Liveness\": 0.359, \"Tempo\": 171.374, \"Duration (ms)\": 326467.0, \"Valence\": 0.0612, \"Chord\": \"D\"}, {\"Index\": 1394, \"Highest Charting Position\": 118, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"all the good girls go to hell\", \"Streams\": 5074485, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"6IRdLKIyS4p7XNiP8r6rsx\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-03-29\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.726, \"Energy\": 0.444, \"Loudness\": -8.922, \"Speechiness\": 0.372, \"Acousticness\": 0.283, \"Liveness\": 0.177, \"Tempo\": 185.044, \"Duration (ms)\": 168840.0, \"Valence\": 0.569, \"Chord\": \"G#/Ab\"}, {\"Index\": 1401, \"Highest Charting Position\": 148, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"i love you\", \"Streams\": 4863910, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"0np7TYPZSum9xTxe9QTr21\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-03--2020-01-10\", \"Popularity\": 2.0, \"Danceability\": 0.42, \"Energy\": 0.131, \"Loudness\": -18.435, \"Speechiness\": 0.0382, \"Acousticness\": 0.953, \"Liveness\": 0.109, \"Tempo\": 137.421, \"Duration (ms)\": 291796.0, \"Valence\": 0.12, \"Chord\": \"C\"}, {\"Index\": 1404, \"Highest Charting Position\": 61, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Come Around Me\", \"Streams\": 9533583, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2o9LAypwGH4ctV0i9boo6d\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 66.0, \"Danceability\": 0.648, \"Energy\": 0.681, \"Loudness\": -8.389, \"Speechiness\": 0.0378, \"Acousticness\": 0.263, \"Liveness\": 0.0971, \"Tempo\": 157.941, \"Duration (ms)\": 200773.0, \"Valence\": 0.767, \"Chord\": \"D\"}, {\"Index\": 1405, \"Highest Charting Position\": 64, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Habitual\", \"Streams\": 9120086, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"40qyPyljksBEqlNw5sW37T\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 62.0, \"Danceability\": 0.764, \"Energy\": 0.443, \"Loudness\": -6.625, \"Speechiness\": 0.0439, \"Acousticness\": 0.52, \"Liveness\": 0.0749, \"Tempo\": 138.999, \"Duration (ms)\": 168200.0, \"Valence\": 0.63, \"Chord\": \"E\"}, {\"Index\": 1406, \"Highest Charting Position\": 65, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"All Around Me\", \"Streams\": 9010535, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5Py8zRKGkZvgHniVVtvNCN\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 63.0, \"Danceability\": 0.566, \"Energy\": 0.438, \"Loudness\": -7.564, \"Speechiness\": 0.0367, \"Acousticness\": 0.809, \"Liveness\": 0.212, \"Tempo\": 117.127, \"Duration (ms)\": 136907.0, \"Valence\": 0.692, \"Chord\": \"C\"}, {\"Index\": 1407, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Get Me (feat. Kehlani)\", \"Streams\": 8362828, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5VwwpU7KsLhgfbMEecedhJ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 61.0, \"Danceability\": 0.832, \"Energy\": 0.508, \"Loudness\": -6.913, \"Speechiness\": 0.149, \"Acousticness\": 0.0492, \"Liveness\": 0.107, \"Tempo\": 109.352, \"Duration (ms)\": 185427.0, \"Valence\": 0.75, \"Chord\": \"F#/Gb\"}, {\"Index\": 1408, \"Highest Charting Position\": 79, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Second Emotion (feat. Travis Scott)\", \"Streams\": 8109572, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"1PnAx788sAvcI3ZxTlEyX8\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 61.0, \"Danceability\": 0.796, \"Energy\": 0.777, \"Loudness\": -6.112, \"Speechiness\": 0.0567, \"Acousticness\": 0.0276, \"Liveness\": 0.095, \"Tempo\": 141.97, \"Duration (ms)\": 202720.0, \"Valence\": 0.96, \"Chord\": \"B\"}, {\"Index\": 1409, \"Highest Charting Position\": 85, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Running Over (feat. Lil Dicky)\", \"Streams\": 7493188, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"75nKBP8jQu681pTNCtrEnn\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.774, \"Energy\": 0.603, \"Loudness\": -7.319, \"Speechiness\": 0.0591, \"Acousticness\": 0.438, \"Liveness\": 0.0869, \"Tempo\": 149.982, \"Duration (ms)\": 179627.0, \"Valence\": 0.977, \"Chord\": \"B\"}, {\"Index\": 1410, \"Highest Charting Position\": 86, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Available\", \"Streams\": 7473249, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"1b6tPXXCV2fSNtR3SKWUQA\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.702, \"Energy\": 0.608, \"Loudness\": -6.843, \"Speechiness\": 0.0359, \"Acousticness\": 0.0736, \"Liveness\": 0.129, \"Tempo\": 75.012, \"Duration (ms)\": 195333.0, \"Valence\": 0.597, \"Chord\": \"D#/Eb\"}, {\"Index\": 1412, \"Highest Charting Position\": 103, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Changes\", \"Streams\": 6865229, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"521Os1SMlxmsoevsqyjNmJ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 62.0, \"Danceability\": 0.485, \"Energy\": 0.412, \"Loudness\": -7.766, \"Speechiness\": 0.042, \"Acousticness\": 0.738, \"Liveness\": 0.12, \"Tempo\": 64.062, \"Duration (ms)\": 135493.0, \"Valence\": 0.612, \"Chord\": \"A\"}, {\"Index\": 1413, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Confirmation\", \"Streams\": 6520106, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"60brXKLTC15vK0av5gIldm\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.438, \"Energy\": 0.315, \"Loudness\": -8.186, \"Speechiness\": 0.0375, \"Acousticness\": 0.608, \"Liveness\": 0.151, \"Tempo\": 190.064, \"Duration (ms)\": 170587.0, \"Valence\": 0.449, \"Chord\": \"G#/Ab\"}, {\"Index\": 1415, \"Highest Charting Position\": 135, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"E.T.A.\", \"Streams\": 6008945, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6PzOPrXx8tJEqace76yrv2\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.465, \"Energy\": 0.494, \"Loudness\": -7.595, \"Speechiness\": 0.066, \"Acousticness\": 0.49, \"Liveness\": 0.127, \"Tempo\": 127.298, \"Duration (ms)\": 176733.0, \"Valence\": 0.457, \"Chord\": \"E\"}, {\"Index\": 1417, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Take It Out On Me\", \"Streams\": 5858768, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"39nTNk5MfyiiRupTwn1iyC\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 54.0, \"Danceability\": 0.772, \"Energy\": 0.616, \"Loudness\": -4.673, \"Speechiness\": 0.102, \"Acousticness\": 0.00337, \"Liveness\": 0.104, \"Tempo\": 129.967, \"Duration (ms)\": 178013.0, \"Valence\": 0.279, \"Chord\": \"G\"}, {\"Index\": 1420, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"That's What Love Is\", \"Streams\": 5440037, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2hLu8L8SNfCN4yKyPdX0h3\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 59.0, \"Danceability\": 0.639, \"Energy\": 0.437, \"Loudness\": -6.959, \"Speechiness\": 0.0355, \"Acousticness\": 0.692, \"Liveness\": 0.12, \"Tempo\": 147.575, \"Duration (ms)\": 165120.0, \"Valence\": 0.751, \"Chord\": \"A\"}, {\"Index\": 1425, \"Highest Charting Position\": 141, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"wish you were gay\", \"Streams\": 5187997, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"3Fj47GNK2kUF0uaEDgXLaD\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-03-29\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.853, \"Energy\": 0.351, \"Loudness\": -10.198, \"Speechiness\": 0.241, \"Acousticness\": 0.39, \"Liveness\": 0.752, \"Tempo\": 118.028, \"Duration (ms)\": 221543.0, \"Valence\": 0.282, \"Chord\": \"G\"}, {\"Index\": 1426, \"Highest Charting Position\": 61, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Only The Young - Featured in Miss Americana\", \"Streams\": 5111068, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2slqvGLwzZZYsT4K4Y1GBC\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 63.0, \"Danceability\": 0.56, \"Energy\": 0.78, \"Loudness\": -4.895, \"Speechiness\": 0.0517, \"Acousticness\": 0.00244, \"Liveness\": 0.0714, \"Tempo\": 93.516, \"Duration (ms)\": 157507.0, \"Valence\": 0.602, \"Chord\": \"F\"}, {\"Index\": 1428, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"At Least For Now\", \"Streams\": 5033764, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6VLkgf5YmLixsabdqiCVGU\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 54.0, \"Danceability\": 0.375, \"Energy\": 0.304, \"Loudness\": -9.897, \"Speechiness\": 0.0325, \"Acousticness\": 0.683, \"Liveness\": 0.196, \"Tempo\": 83.832, \"Duration (ms)\": 149653.0, \"Valence\": 0.295, \"Chord\": \"A\"}, {\"Index\": 1429, \"Highest Charting Position\": 167, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"you should see me in a crown\", \"Streams\": 4988054, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6WbvBhwCaUuYHcHGEuVgqo\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 0.0, \"Danceability\": 0.683, \"Energy\": 0.534, \"Loudness\": -10.348, \"Speechiness\": 0.189, \"Acousticness\": 0.519, \"Liveness\": 0.148, \"Tempo\": 150.469, \"Duration (ms)\": 180567.0, \"Valence\": 0.284, \"Chord\": \"E\"}, {\"Index\": 1441, \"Highest Charting Position\": 160, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"EARFQUAKE\", \"Streams\": 5079657, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6782693.0, \"Song ID\": \"5hVghJ4KaYES3BFUATCYn0\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 79.0, \"Danceability\": 0.554, \"Energy\": 0.498, \"Loudness\": -8.866, \"Speechiness\": 0.0685, \"Acousticness\": 0.23, \"Liveness\": 0.795, \"Tempo\": 79.635, \"Duration (ms)\": 190067.0, \"Valence\": 0.413, \"Chord\": \"A\"}, {\"Index\": 1445, \"Highest Charting Position\": 113, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Suge\", \"Streams\": 4986299, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"2gwkD6igEhQbDQegRCcdoB\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-03-01\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.876, \"Energy\": 0.662, \"Loudness\": -6.482, \"Speechiness\": 0.426, \"Acousticness\": 0.0608, \"Liveness\": 0.127, \"Tempo\": 75.445, \"Duration (ms)\": 163320.0, \"Valence\": 0.844, \"Chord\": \"D\"}, {\"Index\": 1453, \"Highest Charting Position\": 148, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"MIDDLE CHILD\", \"Streams\": 4836113, \"Artist\": \"J. Cole\", \"Artist Followers\": 14103694.0, \"Song ID\": \"2JvzF1RMd7lE3KmFlsyZD8\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2019-01-23\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.837, \"Energy\": 0.364, \"Loudness\": -11.713, \"Speechiness\": 0.276, \"Acousticness\": 0.149, \"Liveness\": 0.271, \"Tempo\": 123.984, \"Duration (ms)\": 213594.0, \"Valence\": 0.463, \"Chord\": \"G#/Ab\"}, {\"Index\": 1457, \"Highest Charting Position\": 22, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Those Kinda Nights (feat. Ed Sheeran)\", \"Streams\": 5823422, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"0VSzREd1OjEWJ9tXoFHRQH\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 66.0, \"Danceability\": 0.794, \"Energy\": 0.637, \"Loudness\": -6.29, \"Speechiness\": 0.339, \"Acousticness\": 0.028, \"Liveness\": 0.0919, \"Tempo\": 103.868, \"Duration (ms)\": 177693.0, \"Valence\": 0.393, \"Chord\": \"E\"}, {\"Index\": 1467, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"ME! (feat. Brendon Urie of Panic! At The Disco)\", \"Streams\": 4884909, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2Rk4JlNc2TPmZe2af99d45\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 77.0, \"Danceability\": 0.61, \"Energy\": 0.83, \"Loudness\": -4.105, \"Speechiness\": 0.0571, \"Acousticness\": 0.033, \"Liveness\": 0.118, \"Tempo\": 182.162, \"Duration (ms)\": 193000.0, \"Valence\": 0.728, \"Chord\": \"C\"}, {\"Index\": 1469, \"Highest Charting Position\": 191, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"idontwannabeyouanymore\", \"Streams\": 4824483, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"41zXlQxzTi6cGAjpOXyLYH\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2017-12-22\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 78.0, \"Danceability\": 0.483, \"Energy\": 0.412, \"Loudness\": -8.461, \"Speechiness\": 0.0402, \"Acousticness\": 0.737, \"Liveness\": 0.116, \"Tempo\": 170.163, \"Duration (ms)\": 203569.0, \"Valence\": 0.247, \"Chord\": \"G\"}, {\"Index\": 1472, \"Highest Charting Position\": 26, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Darkness\", \"Streams\": 7618955, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5SiZJoLXp3WOl3J4C8IK0d\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 65.0, \"Danceability\": 0.671, \"Energy\": 0.623, \"Loudness\": -7.161, \"Speechiness\": 0.308, \"Acousticness\": 0.00998, \"Liveness\": 0.643, \"Tempo\": 75.055, \"Duration (ms)\": 337147.0, \"Valence\": 0.195, \"Chord\": \"D\"}, {\"Index\": 1473, \"Highest Charting Position\": 30, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"You Gon\\u2019 Learn (feat. Royce Da 5'9\\\" & White Gold)\", \"Streams\": 7157402, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"0GQ5bFTVFFKpwNPc7KwQnB\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 66.0, \"Danceability\": 0.68, \"Energy\": 0.82, \"Loudness\": -4.197, \"Speechiness\": 0.151, \"Acousticness\": 0.0614, \"Liveness\": 0.597, \"Tempo\": 140.033, \"Duration (ms)\": 234653.0, \"Valence\": 0.243, \"Chord\": \"E\"}, {\"Index\": 1476, \"Highest Charting Position\": 32, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Unaccommodating (feat. Young M.A)\", \"Streams\": 6374807, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"0q2vG0UVuy6ajjcpkQHdZM\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 65.0, \"Danceability\": 0.852, \"Energy\": 0.752, \"Loudness\": -5.793, \"Speechiness\": 0.0597, \"Acousticness\": 0.0169, \"Liveness\": 0.394, \"Tempo\": 89.95, \"Duration (ms)\": 216600.0, \"Valence\": 0.389, \"Chord\": \"C#/Db\"}, {\"Index\": 1478, \"Highest Charting Position\": 44, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Leaving Heaven (feat. Skylar Grey)\", \"Streams\": 5466161, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5CpsIb7SMFHjmAG8RvIWfq\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.661, \"Energy\": 0.748, \"Loudness\": -4.809, \"Speechiness\": 0.206, \"Acousticness\": 0.175, \"Liveness\": 0.254, \"Tempo\": 171.983, \"Duration (ms)\": 265947.0, \"Valence\": 0.509, \"Chord\": \"D\"}, {\"Index\": 1481, \"Highest Charting Position\": 56, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Look At Her Now\", \"Streams\": 5066377, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 1251372.0, \"Song ID\": \"2XUPkAie1nz9SYIhbdIVWb\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.753, \"Energy\": 0.564, \"Loudness\": -7.908, \"Speechiness\": 0.251, \"Acousticness\": 0.114, \"Liveness\": 0.359, \"Tempo\": 77.341, \"Duration (ms)\": 162596.0, \"Valence\": 0.55, \"Chord\": \"A#/Bb\"}, {\"Index\": 1483, \"Highest Charting Position\": 126, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Legends\", \"Streams\": 4922369, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"1Knctxx9vGZxpZfF66BIEa\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2018-06-22\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.594, \"Energy\": 0.798, \"Loudness\": -5.244, \"Speechiness\": 0.0844, \"Acousticness\": 0.115, \"Liveness\": 0.143, \"Tempo\": 142.049, \"Duration (ms)\": 191840.0, \"Valence\": 0.381, \"Chord\": \"E\"}, {\"Index\": 1486, \"Highest Charting Position\": 52, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"In Too Deep\", \"Streams\": 4824037, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"7Dj2wqPYXfSRFwa6qyOztr\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.72, \"Energy\": 0.767, \"Loudness\": -5.839, \"Speechiness\": 0.214, \"Acousticness\": 0.0387, \"Liveness\": 0.202, \"Tempo\": 88.966, \"Duration (ms)\": 194707.0, \"Valence\": 0.595, \"Chord\": \"A#/Bb\"}, {\"Index\": 1487, \"Highest Charting Position\": 57, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Premonition - Intro\", \"Streams\": 10830400, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"7ccTcabbJlCJiIqtrSSwBk\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.847, \"Energy\": 0.637, \"Loudness\": -5.193, \"Speechiness\": 0.367, \"Acousticness\": 0.0258, \"Liveness\": 0.382, \"Tempo\": 165.979, \"Duration (ms)\": 173893.0, \"Valence\": 0.511, \"Chord\": \"C#/Db\"}, {\"Index\": 1490, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"No Regrets (feat. Don Toliver)\", \"Streams\": 9493884, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"1lO9CZo6eDrOy0S7khgryG\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 63.0, \"Danceability\": 0.756, \"Energy\": 0.747, \"Loudness\": -5.407, \"Speechiness\": 0.046, \"Acousticness\": 0.0048, \"Liveness\": 0.588, \"Tempo\": 134.935, \"Duration (ms)\": 200947.0, \"Valence\": 0.0687, \"Chord\": \"A\"}, {\"Index\": 1492, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Lock It Up (feat. Anderson .Paak)\", \"Streams\": 9328951, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"1qwMkkRiD5jqLeUUjfgblh\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.848, \"Energy\": 0.745, \"Loudness\": -3.052, \"Speechiness\": 0.221, \"Acousticness\": 0.0949, \"Liveness\": 0.0796, \"Tempo\": 137.024, \"Duration (ms)\": 170227.0, \"Valence\": 0.516, \"Chord\": \"F#/Gb\"}, {\"Index\": 1493, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Marsh\", \"Streams\": 9260007, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"34d7sGX6WUqq8f04e7CSNF\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.871, \"Energy\": 0.493, \"Loudness\": -6.356, \"Speechiness\": 0.205, \"Acousticness\": 0.0134, \"Liveness\": 0.385, \"Tempo\": 144.989, \"Duration (ms)\": 200573.0, \"Valence\": 0.0495, \"Chord\": \"C#/Db\"}, {\"Index\": 1494, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Stepdad\", \"Streams\": 9159901, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"3QVHSV8YKYq4L8tI5rnFgj\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 61.0, \"Danceability\": 0.779, \"Energy\": 0.805, \"Loudness\": -3.121, \"Speechiness\": 0.178, \"Acousticness\": 0.018, \"Liveness\": 0.321, \"Tempo\": 145.68, \"Duration (ms)\": 213413.0, \"Valence\": 0.557, \"Chord\": \"C#/Db\"}, {\"Index\": 1495, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Yah Yah (feat. Royce Da 5'9\\\", Black Thought, Q-Tip & Denaun)\", \"Streams\": 8695060, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5mZXWEH2eh8zMZGCxT5aW0\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.458, \"Energy\": 0.966, \"Loudness\": -2.107, \"Speechiness\": 0.384, \"Acousticness\": 0.14, \"Liveness\": 0.11, \"Tempo\": 183.586, \"Duration (ms)\": 286960.0, \"Valence\": 0.356, \"Chord\": \"C#/Db\"}, {\"Index\": 1496, \"Highest Charting Position\": 90, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Never Love Again\", \"Streams\": 8335790, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"40YbWniIEmqy6s58fYXLUh\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.747, \"Energy\": 0.899, \"Loudness\": -5.125, \"Speechiness\": 0.246, \"Acousticness\": 0.1, \"Liveness\": 0.486, \"Tempo\": 92.029, \"Duration (ms)\": 177547.0, \"Valence\": 0.581, \"Chord\": \"F\"}, {\"Index\": 1498, \"Highest Charting Position\": 94, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Farewell\", \"Streams\": 8277608, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"74gykWHknHDrg4eMdcmdRq\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 61.0, \"Danceability\": 0.89, \"Energy\": 0.664, \"Loudness\": -6.625, \"Speechiness\": 0.106, \"Acousticness\": 0.00487, \"Liveness\": 0.257, \"Tempo\": 93.007, \"Duration (ms)\": 247733.0, \"Valence\": 0.467, \"Chord\": \"E\"}, {\"Index\": 1500, \"Highest Charting Position\": 100, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Alfred - Interlude\", \"Streams\": 8030151, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"4EmunTy7kNBYQivOa8F6b8\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 57.0, \"Danceability\": 0.429, \"Energy\": 0.231, \"Loudness\": -20.43, \"Speechiness\": 0.402, \"Acousticness\": 0.878, \"Liveness\": 0.279, \"Tempo\": 74.545, \"Duration (ms)\": 30133.0, \"Valence\": 0.914, \"Chord\": \"F\"}, {\"Index\": 1501, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Little Engine\", \"Streams\": 7913461, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"4qNWEOMyexn7b8Icyk29t9\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.769, \"Energy\": 0.811, \"Loudness\": -4.162, \"Speechiness\": 0.228, \"Acousticness\": 0.0234, \"Liveness\": 0.0451, \"Tempo\": 155.081, \"Duration (ms)\": 177293.0, \"Valence\": 0.76, \"Chord\": \"A#/Bb\"}, {\"Index\": 1502, \"Highest Charting Position\": 113, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"I Will (feat. KXNG Crooked, Royce Da 5'9\\\" & Joell Ortiz)\", \"Streams\": 7115414, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"3CJbxqRQ0JNCqboWDNUUeX\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.635, \"Energy\": 0.543, \"Loudness\": -5.941, \"Speechiness\": 0.067, \"Acousticness\": 0.0454, \"Liveness\": 0.272, \"Tempo\": 98.743, \"Duration (ms)\": 303000.0, \"Valence\": 0.036, \"Chord\": \"G#/Ab\"}, {\"Index\": 1511, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Vulnerable\", \"Streams\": 7531094, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"11OwAR3GlBj9E35Cznf7Lj\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 55.0, \"Danceability\": 0.695, \"Energy\": 0.573, \"Loudness\": -8.882, \"Speechiness\": 0.167, \"Acousticness\": 0.132, \"Liveness\": 0.156, \"Tempo\": 100.031, \"Duration (ms)\": 192172.0, \"Valence\": 0.38, \"Chord\": \"A#/Bb\"}, {\"Index\": 1512, \"Highest Charting Position\": 90, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Dance Again\", \"Streams\": 7394604, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"5sK3o66yupTNIK6gWgzGjf\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 56.0, \"Danceability\": 0.784, \"Energy\": 0.552, \"Loudness\": -7.261, \"Speechiness\": 0.0871, \"Acousticness\": 0.0447, \"Liveness\": 0.192, \"Tempo\": 111.984, \"Duration (ms)\": 170498.0, \"Valence\": 0.465, \"Chord\": \"C#/Db\"}, {\"Index\": 1513, \"Highest Charting Position\": 107, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Ring\", \"Streams\": 6693229, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"11Ey4yJVeWEsA73KjACkVY\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 55.0, \"Danceability\": 0.873, \"Energy\": 0.51, \"Loudness\": -5.35, \"Speechiness\": 0.0661, \"Acousticness\": 0.565, \"Liveness\": 0.0738, \"Tempo\": 110.953, \"Duration (ms)\": 148776.0, \"Valence\": 0.871, \"Chord\": \"D#/Eb\"}, {\"Index\": 1514, \"Highest Charting Position\": 111, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Crowded Room (feat. 6LACK)\", \"Streams\": 6483001, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"2C0hTkdEoikhKzDCJl32QZ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 55.0, \"Danceability\": 0.724, \"Energy\": 0.415, \"Loudness\": -8.408, \"Speechiness\": 0.0518, \"Acousticness\": 0.764, \"Liveness\": 0.103, \"Tempo\": 89.999, \"Duration (ms)\": 186459.0, \"Valence\": 0.328, \"Chord\": \"G\"}, {\"Index\": 1515, \"Highest Charting Position\": 119, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"People You Know\", \"Streams\": 6255954, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"63mdJr3NMY3wReOkNE6c6W\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 54.0, \"Danceability\": 0.695, \"Energy\": 0.62, \"Loudness\": -8.082, \"Speechiness\": 0.0521, \"Acousticness\": 0.0881, \"Liveness\": 0.111, \"Tempo\": 150.032, \"Duration (ms)\": 194900.0, \"Valence\": 0.62, \"Chord\": \"G#/Ab\"}, {\"Index\": 1519, \"Highest Charting Position\": 161, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Let Me Get Me\", \"Streams\": 5356671, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"0uFForNKQPvgSCnxlZIhQy\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 51.0, \"Danceability\": 0.826, \"Energy\": 0.571, \"Loudness\": -9.263, \"Speechiness\": 0.0426, \"Acousticness\": 0.249, \"Liveness\": 0.215, \"Tempo\": 121.06, \"Duration (ms)\": 189145.0, \"Valence\": 0.475, \"Chord\": \"D\"}, {\"Index\": 1520, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"A Sweeter Place (feat. Kid Cudi)\", \"Streams\": 5291134, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4bb94wZVF1cX66vQjNeJTX\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 52.0, \"Danceability\": 0.583, \"Energy\": 0.777, \"Loudness\": -6.991, \"Speechiness\": 0.185, \"Acousticness\": 0.109, \"Liveness\": 0.108, \"Tempo\": 190.054, \"Duration (ms)\": 263306.0, \"Valence\": 0.31, \"Chord\": \"A#/Bb\"}, {\"Index\": 1529, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Cut You Off\", \"Streams\": 4874380, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4OtHGdb0KqEbaWb6edUnR9\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 51.0, \"Danceability\": 0.855, \"Energy\": 0.294, \"Loudness\": -8.676, \"Speechiness\": 0.286, \"Acousticness\": 0.3, \"Liveness\": 0.091, \"Tempo\": 139.745, \"Duration (ms)\": 182017.0, \"Valence\": 0.842, \"Chord\": \"F\"}, {\"Index\": 1530, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Kinda Crazy\", \"Streams\": 4866777, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"59iGOjPSOcPLGl3vqEStUp\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 49.0, \"Danceability\": 0.691, \"Energy\": 0.446, \"Loudness\": -10.304, \"Speechiness\": 0.0472, \"Acousticness\": 0.484, \"Liveness\": 0.183, \"Tempo\": 93.03, \"Duration (ms)\": 212436.0, \"Valence\": 0.534, \"Chord\": \"B\"}, {\"Index\": 1546, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Candy\", \"Streams\": 5632102, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"1VJwtWR6z7SpZRwipI12be\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2018-03-30\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.689, \"Energy\": 0.516, \"Loudness\": -5.857, \"Speechiness\": 0.0444, \"Acousticness\": 0.513, \"Liveness\": 0.163, \"Tempo\": 124.876, \"Duration (ms)\": 190920.0, \"Valence\": 0.209, \"Chord\": \"G#/Ab\"}, {\"Index\": 1550, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Let Me Know (I Wonder Why Freestyle)\", \"Streams\": 4701532, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"3wwo0bJvDSorOpNfzEkfXx\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2019-12-07\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.635, \"Energy\": 0.537, \"Loudness\": -7.895, \"Speechiness\": 0.0832, \"Acousticness\": 0.172, \"Liveness\": 0.418, \"Tempo\": 125.028, \"Duration (ms)\": 215381.0, \"Valence\": 0.383, \"Chord\": \"G\"}, {\"Index\": 1552, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"New Rules\", \"Streams\": 4630675, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"2ekn2ttSfGqwhhate0LSR0\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2017-06-02\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.762, \"Energy\": 0.7, \"Loudness\": -6.021, \"Speechiness\": 0.0694, \"Acousticness\": 0.00261, \"Liveness\": 0.153, \"Tempo\": 116.073, \"Duration (ms)\": 209320.0, \"Valence\": 0.608, \"Chord\": \"A\"}, {\"Index\": 1556, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lover (Remix) [feat. Shawn Mendes]\", \"Streams\": 4595450, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3i9UVldZOE0aD0JnyfAZZ0\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-11-13\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.448, \"Energy\": 0.603, \"Loudness\": -7.176, \"Speechiness\": 0.064, \"Acousticness\": 0.433, \"Liveness\": 0.0862, \"Tempo\": 205.272, \"Duration (ms)\": 221307.0, \"Valence\": 0.422, \"Chord\": \"G\"}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 25,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "alt.Chart(df_top).mark_bar().encode(\n",
    "    x = \"Artist\",\n",
    "    y = \"count()\"\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "fc40da22",
   "metadata": {},
   "source": [
    "Let's add color to the chart, using the average number of Streams for each artist.  In this example, `mean` is a special function in Altair, just like `count`."
   ]
  },
  {
   "cell_type": "markdown",
   "id": "27815f9d",
   "metadata": {},
   "source": [
    "(spotify-bar)=\n",
    "#### Spotify bar chart"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 26,
   "id": "8d04e98e",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-8a4e7c82529d4d11adfc1c3e49a7428c\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-8a4e7c82529d4d11adfc1c3e49a7428c\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-8a4e7c82529d4d11adfc1c3e49a7428c\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-160a2b6fb60af0f1ff2f7ad1143b7368\"}, \"mark\": \"bar\", \"encoding\": {\"color\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"field\": \"Streams\"}, \"x\": {\"type\": \"nominal\", \"field\": \"Artist\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"count\"}}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-160a2b6fb60af0f1ff2f7ad1143b7368\": [{\"Index\": 7, \"Highest Charting Position\": 3, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Kiss Me More (feat. SZA)\", \"Streams\": 29356736, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"748mdHapucXQri7IAO8yFK\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 94.0, \"Danceability\": 0.762, \"Energy\": 0.701, \"Loudness\": -3.541, \"Speechiness\": 0.0286, \"Acousticness\": 0.235, \"Liveness\": 0.123, \"Tempo\": 110.968, \"Duration (ms)\": 208867.0, \"Valence\": 0.742, \"Chord\": \"G#/Ab\"}, {\"Index\": 9, \"Highest Charting Position\": 3, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Yonaguni\", \"Streams\": 25030128, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36142273.0, \"Song ID\": \"2JPLbjOn0wPCngEot2STUS\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 96.0, \"Danceability\": 0.644, \"Energy\": 0.648, \"Loudness\": -4.601, \"Speechiness\": 0.118, \"Acousticness\": 0.276, \"Liveness\": 0.135, \"Tempo\": 179.951, \"Duration (ms)\": 206710.0, \"Valence\": 0.44, \"Chord\": \"C#/Db\"}, {\"Index\": 11, \"Highest Charting Position\": 4, \"Number of Times Charted\": 43, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Levitating (feat. DaBaby)\", \"Streams\": 23518010, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"463CkQjx2Zk1yXoBuierM9\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-10-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 89.0, \"Danceability\": 0.702, \"Energy\": 0.825, \"Loudness\": -3.787, \"Speechiness\": 0.0601, \"Acousticness\": 0.00883, \"Liveness\": 0.0674, \"Tempo\": 102.977, \"Duration (ms)\": 203064.0, \"Valence\": 0.915, \"Chord\": \"F#/Gb\"}, {\"Index\": 13, \"Highest Charting Position\": 5, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Permission to Dance\", \"Streams\": 22062812, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"0LThjFY2iTtNdd4wviwVV2\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 95.0, \"Danceability\": 0.702, \"Energy\": 0.741, \"Loudness\": -5.33, \"Speechiness\": 0.0427, \"Acousticness\": 0.00544, \"Liveness\": 0.337, \"Tempo\": 124.925, \"Duration (ms)\": 187585.0, \"Valence\": 0.646, \"Chord\": \"A\"}, {\"Index\": 14, \"Highest Charting Position\": 1, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Peaches (feat. Daniel Caesar & Giveon)\", \"Streams\": 20294457, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48504126.0, \"Song ID\": \"4iJyoBOLtHqaGxP12qzhQI\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 94.0, \"Danceability\": 0.677, \"Energy\": 0.696, \"Loudness\": -6.181, \"Speechiness\": 0.119, \"Acousticness\": 0.321, \"Liveness\": 0.42, \"Tempo\": 90.03, \"Duration (ms)\": 198082.0, \"Valence\": 0.464, \"Chord\": \"C\"}, {\"Index\": 15, \"Highest Charting Position\": 2, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Butter\", \"Streams\": 19985713, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"2bgTY4UwhfBYhGT4HUYStN\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 95.0, \"Danceability\": 0.759, \"Energy\": 0.459, \"Loudness\": -5.187, \"Speechiness\": 0.0948, \"Acousticness\": 0.00323, \"Liveness\": 0.0906, \"Tempo\": 109.997, \"Duration (ms)\": 164442.0, \"Valence\": 0.695, \"Chord\": \"G#/Ab\"}, {\"Index\": 18, \"Highest Charting Position\": 5, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Save Your Tears (with Ariana Grande) (Remix)\", \"Streams\": 18053141, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"37BZB0z9T8Xu7U3e65qxFy\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 94.0, \"Danceability\": 0.65, \"Energy\": 0.825, \"Loudness\": -4.645, \"Speechiness\": 0.0325, \"Acousticness\": 0.0215, \"Liveness\": 0.0936, \"Tempo\": 118.091, \"Duration (ms)\": 191014.0, \"Valence\": 0.593, \"Chord\": \"C\"}, {\"Index\": 20, \"Highest Charting Position\": 20, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Need To Know\", \"Streams\": 16908917, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"3Vi5XqYrmQgOYBajMWSvCi\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 90.0, \"Danceability\": 0.664, \"Energy\": 0.609, \"Loudness\": -6.509, \"Speechiness\": 0.0707, \"Acousticness\": 0.304, \"Liveness\": 0.0926, \"Tempo\": 130.041, \"Duration (ms)\": 210560.0, \"Valence\": 0.194, \"Chord\": \"C#/Db\"}, {\"Index\": 22, \"Highest Charting Position\": 22, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Ain't Shit\", \"Streams\": 16126897, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"5lAnYvAIkSDNXqfo7DyFUm\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 90.0, \"Danceability\": 0.855, \"Energy\": 0.488, \"Loudness\": -4.601, \"Speechiness\": 0.208, \"Acousticness\": 0.506, \"Liveness\": 0.347, \"Tempo\": 124.097, \"Duration (ms)\": 174253.0, \"Valence\": 0.619, \"Chord\": \"D#/Eb\"}, {\"Index\": 25, \"Highest Charting Position\": 1, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Blinding Lights\", \"Streams\": 15011809, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"0VjIjW4GlUZAMYd2vXMi3b\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 92.0, \"Danceability\": 0.514, \"Energy\": 0.73, \"Loudness\": -5.934, \"Speechiness\": 0.0598, \"Acousticness\": 0.00146, \"Liveness\": 0.0897, \"Tempo\": 171.005, \"Duration (ms)\": 200040.0, \"Valence\": 0.334, \"Chord\": \"C#/Db\"}, {\"Index\": 44, \"Highest Charting Position\": 2, \"Number of Times Charted\": 49, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Dynamite\", \"Streams\": 11196819, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"4saklk6nie3yiGePpBwUoc\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 89.0, \"Danceability\": 0.746, \"Energy\": 0.765, \"Loudness\": -4.41, \"Speechiness\": 0.0993, \"Acousticness\": 0.0112, \"Liveness\": 0.0936, \"Tempo\": 114.044, \"Duration (ms)\": 199054.0, \"Valence\": 0.737, \"Chord\": \"F#/Gb\"}, {\"Index\": 53, \"Highest Charting Position\": 19, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"NDA\", \"Streams\": 9635619, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47014200.0, \"Song ID\": \"38GBNKZUhfBkk3oNlWzRYd\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-07-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 84.0, \"Danceability\": 0.765, \"Energy\": 0.373, \"Loudness\": -9.921, \"Speechiness\": 0.0713, \"Acousticness\": 0.341, \"Liveness\": 0.112, \"Tempo\": 85.016, \"Duration (ms)\": 195777.0, \"Valence\": 0.554, \"Chord\": \"G#/Ab\"}, {\"Index\": 64, \"Highest Charting Position\": 2, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Save Your Tears\", \"Streams\": 8843110, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"37BZB0z9T8Xu7U3e65qxFy\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 94.0, \"Danceability\": 0.65, \"Energy\": 0.825, \"Loudness\": -4.645, \"Speechiness\": 0.0325, \"Acousticness\": 0.0215, \"Liveness\": 0.0936, \"Tempo\": 118.091, \"Duration (ms)\": 191014.0, \"Valence\": 0.593, \"Chord\": \"C\"}, {\"Index\": 66, \"Highest Charting Position\": 2, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Don't Start Now\", \"Streams\": 8821971, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 1250353.0, \"Song ID\": \"7njGslFmqBmOSSOpTyZCs9\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.793, \"Energy\": 0.793, \"Loudness\": -4.521, \"Speechiness\": 0.083, \"Acousticness\": 0.0123, \"Liveness\": 0.0951, \"Tempo\": 123.95, \"Duration (ms)\": 183290.0, \"Valence\": 0.679, \"Chord\": \"B\"}, {\"Index\": 82, \"Highest Charting Position\": 6, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Wants and Needs (feat. Lil Baby)\", \"Streams\": 7637626, \"Artist\": \"Drake\", \"Artist Followers\": 56308172.0, \"Song ID\": \"65OVbaJR5O1RmwOQx0875b\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 87.0, \"Danceability\": 0.578, \"Energy\": 0.449, \"Loudness\": -6.349, \"Speechiness\": 0.286, \"Acousticness\": 0.0618, \"Liveness\": 0.119, \"Tempo\": 136.006, \"Duration (ms)\": 192956.0, \"Valence\": 0.1, \"Chord\": \"C#/Db\"}, {\"Index\": 84, \"Highest Charting Position\": 76, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Love Again\", \"Streams\": 7465445, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 1250353.0, \"Song ID\": \"2sN1pMv6d2t5GlvN6IBMlK\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2020-03-27--2020-04-03\", \"Popularity\": 0.0, \"Danceability\": 0.659, \"Energy\": 0.667, \"Loudness\": -4.668, \"Speechiness\": 0.0339, \"Acousticness\": 0.00173, \"Liveness\": 0.1, \"Tempo\": 115.982, \"Duration (ms)\": 258004.0, \"Valence\": 0.468, \"Chord\": \"B\"}, {\"Index\": 92, \"Highest Charting Position\": 1, \"Number of Times Charted\": 40, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"positions\", \"Streams\": 7244853, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67158068.0, \"Song ID\": \"35mvY5S1H3J2QZyna3TFe0\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 86.0, \"Danceability\": 0.737, \"Energy\": 0.802, \"Loudness\": -4.771, \"Speechiness\": 0.0878, \"Acousticness\": 0.468, \"Liveness\": 0.0931, \"Tempo\": 144.015, \"Duration (ms)\": 172325.0, \"Valence\": 0.682, \"Chord\": \"C\"}, {\"Index\": 97, \"Highest Charting Position\": 97, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Woman\", \"Streams\": 6858466, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"6Uj1ctrBOjOas8xZXGqKk4\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-06-25--2021-07-02\", \"Popularity\": 86.0, \"Danceability\": 0.824, \"Energy\": 0.764, \"Loudness\": -4.175, \"Speechiness\": 0.0854, \"Acousticness\": 0.0888, \"Liveness\": 0.117, \"Tempo\": 107.998, \"Duration (ms)\": 172627.0, \"Valence\": 0.881, \"Chord\": \"F\"}, {\"Index\": 101, \"Highest Charting Position\": 52, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Levitating\", \"Streams\": 6799831, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"463CkQjx2Zk1yXoBuierM9\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-10-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 89.0, \"Danceability\": 0.702, \"Energy\": 0.825, \"Loudness\": -3.787, \"Speechiness\": 0.0601, \"Acousticness\": 0.00883, \"Liveness\": 0.0674, \"Tempo\": 102.977, \"Duration (ms)\": 203064.0, \"Valence\": 0.915, \"Chord\": \"F#/Gb\"}, {\"Index\": 111, \"Highest Charting Position\": 46, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"lovely (with Khalid)\", \"Streams\": 6569547, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47014200.0, \"Song ID\": \"0u2P5u6lvoDfwTYjAADbn4\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2018-04-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.351, \"Energy\": 0.296, \"Loudness\": -10.109, \"Speechiness\": 0.0333, \"Acousticness\": 0.934, \"Liveness\": 0.095, \"Tempo\": 115.284, \"Duration (ms)\": 200186.0, \"Valence\": 0.12, \"Chord\": \"E\"}, {\"Index\": 114, \"Highest Charting Position\": 9, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Streets\", \"Streams\": 6502302, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"60ynsPSSKe6O3sfwRnIBRf\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 86.0, \"Danceability\": 0.749, \"Energy\": 0.463, \"Loudness\": -8.433, \"Speechiness\": 0.0842, \"Acousticness\": 0.21, \"Liveness\": 0.338, \"Tempo\": 90.035, \"Duration (ms)\": 226987.0, \"Valence\": 0.189, \"Chord\": \"B\"}, {\"Index\": 119, \"Highest Charting Position\": 5, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Hold On\", \"Streams\": 6300416, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 1250353.0, \"Song ID\": \"49xx65gvlD7xXjDTavFqaJ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 0.0, \"Danceability\": 0.658, \"Energy\": 0.634, \"Loudness\": -5.797, \"Speechiness\": 0.0413, \"Acousticness\": 0.0106, \"Liveness\": 0.132, \"Tempo\": 139.98, \"Duration (ms)\": 170813.0, \"Valence\": 0.29, \"Chord\": \"C#/Db\"}, {\"Index\": 123, \"Highest Charting Position\": 1, \"Number of Times Charted\": 67, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"ROCKSTAR (feat. Roddy Ricch)\", \"Streams\": 6180056, \"Artist\": \"DaBaby\", \"Artist Followers\": 7593046.0, \"Song ID\": \"7ytR5pFWmSjzHJIeQkgog4\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 86.0, \"Danceability\": 0.746, \"Energy\": 0.69, \"Loudness\": -7.956, \"Speechiness\": 0.164, \"Acousticness\": 0.247, \"Liveness\": 0.101, \"Tempo\": 89.977, \"Duration (ms)\": 181733.0, \"Valence\": 0.497, \"Chord\": \"B\"}, {\"Index\": 158, \"Highest Charting Position\": 6, \"Number of Times Charted\": 47, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"What You Know Bout Love\", \"Streams\": 5570735, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"1tkg4EHVoqnhR6iFEXb60y\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-07-03--2020-07-10\", \"Popularity\": 85.0, \"Danceability\": 0.709, \"Energy\": 0.548, \"Loudness\": -8.493, \"Speechiness\": 0.353, \"Acousticness\": 0.65, \"Liveness\": 0.133, \"Tempo\": 83.995, \"Duration (ms)\": 160000.0, \"Valence\": 0.543, \"Chord\": \"A#/Bb\"}, {\"Index\": 160, \"Highest Charting Position\": 121, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Red Light Green Light\", \"Streams\": 5493760, \"Artist\": \"DaBaby\", \"Artist Followers\": 7593046.0, \"Song ID\": \"1YDebgap5OFwXEBG18NJvy\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.933, \"Energy\": 0.656, \"Loudness\": -5.85, \"Speechiness\": 0.322, \"Acousticness\": 0.129, \"Liveness\": 0.161, \"Tempo\": 119.987, \"Duration (ms)\": 159083.0, \"Valence\": 0.934, \"Chord\": \"D\"}, {\"Index\": 161, \"Highest Charting Position\": 120, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Ball If I Want To\", \"Streams\": 5478055, \"Artist\": \"DaBaby\", \"Artist Followers\": 7593046.0, \"Song ID\": \"0cu0rhnlCnJ7JIeHRiLpj3\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\", \"Popularity\": 84.0, \"Danceability\": 0.902, \"Energy\": 0.669, \"Loudness\": -5.049, \"Speechiness\": 0.457, \"Acousticness\": 0.161, \"Liveness\": 0.0728, \"Tempo\": 139.949, \"Duration (ms)\": 112547.0, \"Valence\": 0.628, \"Chord\": \"C#/Db\"}, {\"Index\": 162, \"Highest Charting Position\": 31, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lucid Dreams\", \"Streams\": 5477563, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"285pBltuF7vW8TeWk8hdRR\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2018-12-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.511, \"Energy\": 0.566, \"Loudness\": -7.23, \"Speechiness\": 0.2, \"Acousticness\": 0.349, \"Liveness\": 0.34, \"Tempo\": 83.903, \"Duration (ms)\": 239836.0, \"Valence\": 0.218, \"Chord\": \"F#/Gb\"}, {\"Index\": 164, \"Highest Charting Position\": 5, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"34+35\", \"Streams\": 5453159, \"Artist\": \"Ariana Grande\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 165, \"Highest Charting Position\": 13, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"bad guy\", \"Streams\": 5436286, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"1hewNsVmijBqjKvFRQfk4m\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.701, \"Energy\": 0.425, \"Loudness\": -10.965, \"Speechiness\": 0.375, \"Acousticness\": 0.328, \"Liveness\": 0.1, \"Tempo\": 135.128, \"Duration (ms)\": 194088.0, \"Valence\": 0.562, \"Chord\": \"G\"}, {\"Index\": 167, \"Highest Charting Position\": 7, \"Number of Times Charted\": 56, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"For The Night (feat. Lil Baby & DaBaby)\", \"Streams\": 5431375, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"0PvFJmanyNQMseIFrU708S\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 84.0, \"Danceability\": 0.823, \"Energy\": 0.586, \"Loudness\": -6.606, \"Speechiness\": 0.2, \"Acousticness\": 0.114, \"Liveness\": 0.193, \"Tempo\": 125.971, \"Duration (ms)\": 190476.0, \"Valence\": 0.347, \"Chord\": \"F#/Gb\"}, {\"Index\": 175, \"Highest Charting Position\": 65, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Bout A Million (feat. 42 Dugg & 21 Savage)\", \"Streams\": 5315734, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"4LaGu95Ui2s4vprSQYWUAZ\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 81.0, \"Danceability\": 0.716, \"Energy\": 0.67, \"Loudness\": -6.995, \"Speechiness\": 0.101, \"Acousticness\": 0.526, \"Liveness\": 0.13, \"Tempo\": 145.043, \"Duration (ms)\": 203586.0, \"Valence\": 0.411, \"Chord\": \"C\"}, {\"Index\": 176, \"Highest Charting Position\": 72, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Demeanor (feat. Dua Lipa)\", \"Streams\": 5245618, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"3DMs7bahbQTnoxCjgP7qoK\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 81.0, \"Danceability\": 0.675, \"Energy\": 0.608, \"Loudness\": -6.934, \"Speechiness\": 0.103, \"Acousticness\": 0.336, \"Liveness\": 0.11, \"Tempo\": 99.865, \"Duration (ms)\": 184800.0, \"Valence\": 0.728, \"Chord\": \"D#/Eb\"}, {\"Index\": 187, \"Highest Charting Position\": 40, \"Number of Times Charted\": 65, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Dior\", \"Streams\": 5092354, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"79s5XnCN4TJKTVMSmOx8Ep\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2019-07-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-06-18--2021-06-25\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 83.0, \"Danceability\": 0.548, \"Energy\": 0.805, \"Loudness\": -5.732, \"Speechiness\": 0.351, \"Acousticness\": 0.212, \"Liveness\": 0.408, \"Tempo\": 142.094, \"Duration (ms)\": 216387.0, \"Valence\": 0.648, \"Chord\": \"G\"}, {\"Index\": 189, \"Highest Charting Position\": 52, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"The Hills\", \"Streams\": 5068864, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"7fBv7CLKzipRk6EC6TWHOB\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2015-08-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 84.0, \"Danceability\": 0.585, \"Energy\": 0.564, \"Loudness\": -7.063, \"Speechiness\": 0.0515, \"Acousticness\": 0.0671, \"Liveness\": 0.135, \"Tempo\": 113.003, \"Duration (ms)\": 242253.0, \"Valence\": 0.137, \"Chord\": \"C\"}, {\"Index\": 192, \"Highest Charting Position\": 64, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"De Museo\", \"Streams\": 5016125, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36142273.0, \"Song ID\": \"267NGliXM8YLVZiKAD9Otm\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 83.0, \"Danceability\": 0.592, \"Energy\": 0.494, \"Loudness\": -10.618, \"Speechiness\": 0.0747, \"Acousticness\": 0.237, \"Liveness\": 0.13, \"Tempo\": 132.037, \"Duration (ms)\": 209771.0, \"Valence\": 0.231, \"Chord\": \"E\"}, {\"Index\": 193, \"Highest Charting Position\": 41, \"Number of Times Charted\": 81, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"7 rings\", \"Streams\": 5002227, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67158068.0, \"Song ID\": \"6ocbgoVGwYJhOv1GgI9NsF\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-02-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.778, \"Energy\": 0.317, \"Loudness\": -10.732, \"Speechiness\": 0.334, \"Acousticness\": 0.592, \"Liveness\": 0.0881, \"Tempo\": 140.048, \"Duration (ms)\": 178627.0, \"Valence\": 0.327, \"Chord\": \"C#/Db\"}, {\"Index\": 200, \"Highest Charting Position\": 172, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"The Real Slim Shady\", \"Streams\": 4948965, \"Artist\": \"Eminem\", \"Artist Followers\": 46785561.0, \"Song ID\": \"3yfqSUWxFvZELEM4PmlwIR\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2000-05-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 84.0, \"Danceability\": 0.949, \"Energy\": 0.661, \"Loudness\": -4.244, \"Speechiness\": 0.0572, \"Acousticness\": 0.0302, \"Liveness\": 0.0454, \"Tempo\": 104.504, \"Duration (ms)\": 284200.0, \"Valence\": 0.76, \"Chord\": \"F\"}, {\"Index\": 201, \"Highest Charting Position\": 66, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Tell The Vision (feat. Kanye West & Pusha T)\", \"Streams\": 8859168, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"1Eu51GaXEehPMrDMh5QghA\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 57.0, \"Danceability\": 0.662, \"Energy\": 0.686, \"Loudness\": -8.302, \"Speechiness\": 0.332, \"Acousticness\": 0.251, \"Liveness\": 0.349, \"Tempo\": 143.971, \"Duration (ms)\": 215000.0, \"Valence\": 0.678, \"Chord\": \"G\"}, {\"Index\": 202, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Woo Baby (feat. Chris Brown)\", \"Streams\": 7371935, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"6bsqes8Zg9gUULzuCkMUs0\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 56.0, \"Danceability\": 0.563, \"Energy\": 0.672, \"Loudness\": -7.226, \"Speechiness\": 0.0765, \"Acousticness\": 0.359, \"Liveness\": 0.0972, \"Tempo\": 99.772, \"Duration (ms)\": 156000.0, \"Valence\": 0.284, \"Chord\": \"A\"}, {\"Index\": 204, \"Highest Charting Position\": 127, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"More Time\", \"Streams\": 6238351, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"7wAnRqccDr2tzcSKLR4jKl\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 55.0, \"Danceability\": 0.628, \"Energy\": 0.581, \"Loudness\": -8.377, \"Speechiness\": 0.188, \"Acousticness\": 0.46, \"Liveness\": 0.152, \"Tempo\": 145.396, \"Duration (ms)\": 120828.0, \"Valence\": 0.259, \"Chord\": \"D\"}, {\"Index\": 205, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Coupe\", \"Streams\": 6161664, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"7LB3ilSpX1mSMKKztNTnu2\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 54.0, \"Danceability\": 0.912, \"Energy\": 0.589, \"Loudness\": -7.476, \"Speechiness\": 0.2, \"Acousticness\": 0.0332, \"Liveness\": 0.0795, \"Tempo\": 135.921, \"Duration (ms)\": 123549.0, \"Valence\": 0.486, \"Chord\": \"G#/Ab\"}, {\"Index\": 207, \"Highest Charting Position\": 150, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Manslaughter (feat. Rick Ross & The-Dream)\", \"Streams\": 5822266, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"4byRwLo7EmkCNBU6S8G6u0\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 55.0, \"Danceability\": 0.441, \"Energy\": 0.623, \"Loudness\": -7.331, \"Speechiness\": 0.0414, \"Acousticness\": 0.135, \"Liveness\": 0.14, \"Tempo\": 78.082, \"Duration (ms)\": 249231.0, \"Valence\": 0.285, \"Chord\": \"C#/Db\"}, {\"Index\": 208, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Genius (feat. Lil Tjay & Swae Lee)\", \"Streams\": 5702636, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"2mmRtchzDVpCj9LSyexgjS\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 53.0, \"Danceability\": 0.723, \"Energy\": 0.667, \"Loudness\": -7.524, \"Speechiness\": 0.351, \"Acousticness\": 0.256, \"Liveness\": 0.261, \"Tempo\": 143.044, \"Duration (ms)\": 208112.0, \"Valence\": 0.396, \"Chord\": \"D\"}, {\"Index\": 209, \"Highest Charting Position\": 22, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"WUSYANAME (feat. Youngboy Never Broke Again & Ty Dolla $ign)\", \"Streams\": 5696113, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"5B0kgjHULYJhAQkK5XsMoC\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.493, \"Energy\": 0.653, \"Loudness\": -5.666, \"Speechiness\": 0.0466, \"Acousticness\": 0.269, \"Liveness\": 0.511, \"Tempo\": 142.347, \"Duration (ms)\": 121573.0, \"Valence\": 0.852, \"Chord\": \"C\"}, {\"Index\": 212, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Brush Em (feat. Rah Swish)\", \"Streams\": 5335271, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"58aW6yZGFl7rVM7SLfLnLL\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 54.0, \"Danceability\": 0.654, \"Energy\": 0.724, \"Loudness\": -6.59, \"Speechiness\": 0.355, \"Acousticness\": 0.106, \"Liveness\": 0.655, \"Tempo\": 71.696, \"Duration (ms)\": 150449.0, \"Valence\": 0.717, \"Chord\": \"D#/Eb\"}, {\"Index\": 216, \"Highest Charting Position\": 15, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Lost Cause\", \"Streams\": 5203319, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"36fhyo5QlxBW7DrDHIOn1G\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 0.0, \"Danceability\": 0.671, \"Energy\": 0.336, \"Loudness\": -8.494, \"Speechiness\": 0.241, \"Acousticness\": 0.705, \"Liveness\": 0.0577, \"Tempo\": 75.051, \"Duration (ms)\": 212496.0, \"Valence\": 0.518, \"Chord\": \"A#/Bb\"}, {\"Index\": 222, \"Highest Charting Position\": 22, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"We're Good\", \"Streams\": 6318660, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"1diS6nkxMQc3wwC4G1j0bh\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 83.0, \"Danceability\": 0.722, \"Energy\": 0.588, \"Loudness\": -5.932, \"Speechiness\": 0.0544, \"Acousticness\": 0.0319, \"Liveness\": 0.183, \"Tempo\": 134.01, \"Duration (ms)\": 165507.0, \"Valence\": 0.59, \"Chord\": \"F#/Gb\"}, {\"Index\": 223, \"Highest Charting Position\": 4, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Life Goes On\", \"Streams\": 6142975, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"249gnXrbfmV8NG6jTEMSwD\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 84.0, \"Danceability\": 0.566, \"Energy\": 0.716, \"Loudness\": -5.733, \"Speechiness\": 0.0424, \"Acousticness\": 0.00691, \"Liveness\": 0.37, \"Tempo\": 81.068, \"Duration (ms)\": 207481.0, \"Valence\": 0.45, \"Chord\": \"C#/Db\"}, {\"Index\": 225, \"Highest Charting Position\": 17, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Baila Conmigo (with Rauw Alejandro)\", \"Streams\": 5588217, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28909504.0, \"Song ID\": \"079Ey5uxL04AKPQgVQwx5h\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 84.0, \"Danceability\": 0.823, \"Energy\": 0.544, \"Loudness\": -7.132, \"Speechiness\": 0.0715, \"Acousticness\": 0.0215, \"Liveness\": 0.0966, \"Tempo\": 149.903, \"Duration (ms)\": 186088.0, \"Valence\": 0.664, \"Chord\": \"F\"}, {\"Index\": 239, \"Highest Charting Position\": 55, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"I Don't Do Drugs (feat. Ariana Grande)\", \"Streams\": 5912293, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0FFsgUoFibYISzMxuGS61W\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 80.0, \"Danceability\": 0.683, \"Energy\": 0.615, \"Loudness\": -5.737, \"Speechiness\": 0.0966, \"Acousticness\": 0.222, \"Liveness\": 0.154, \"Tempo\": 77.014, \"Duration (ms)\": 188893.0, \"Valence\": 0.45, \"Chord\": \"F\"}, {\"Index\": 241, \"Highest Charting Position\": 40, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"JUGGERNAUT (feat. Lil Uzi Vert & Pharrell Williams)\", \"Streams\": 5392334, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"7z4xW9WY86uH3gd1V9pfCM\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 80.0, \"Danceability\": 0.827, \"Energy\": 0.571, \"Loudness\": -7.949, \"Speechiness\": 0.366, \"Acousticness\": 0.0195, \"Liveness\": 0.166, \"Tempo\": 142.034, \"Duration (ms)\": 146419.0, \"Valence\": 0.62, \"Chord\": \"B\"}, {\"Index\": 246, \"Highest Charting Position\": 4, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Your Power\", \"Streams\": 5135380, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47014200.0, \"Song ID\": \"042Sl6Mn83JHyLEqdK7uI0\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-07-30\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 81.0, \"Danceability\": 0.632, \"Energy\": 0.284, \"Loudness\": -14.025, \"Speechiness\": 0.0801, \"Acousticness\": 0.932, \"Liveness\": 0.233, \"Tempo\": 129.642, \"Duration (ms)\": 245897.0, \"Valence\": 0.208, \"Chord\": \"A\"}, {\"Index\": 256, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"LUMBERJACK\", \"Streams\": 11756283, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"0BiK5BbYNFLb88CCOxBFJe\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 76.0, \"Danceability\": 0.386, \"Energy\": 0.762, \"Loudness\": -6.341, \"Speechiness\": 0.564, \"Acousticness\": 0.122, \"Liveness\": 0.527, \"Tempo\": 170.691, \"Duration (ms)\": 138312.0, \"Valence\": 0.433, \"Chord\": \"A\"}, {\"Index\": 257, \"Highest Charting Position\": 47, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"LEMONHEAD (feat. 42 Dugg)\", \"Streams\": 11380679, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"5fbHRCsGpFIOLRtlhCRFDR\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 78.0, \"Danceability\": 0.62, \"Energy\": 0.586, \"Loudness\": -6.612, \"Speechiness\": 0.212, \"Acousticness\": 0.155, \"Liveness\": 0.535, \"Tempo\": 137.131, \"Duration (ms)\": 130980.0, \"Valence\": 0.487, \"Chord\": \"C#/Db\"}, {\"Index\": 258, \"Highest Charting Position\": 59, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"HOT WIND BLOWS (feat. Lil Wayne)\", \"Streams\": 9889197, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"3JJL91ilRV6fXhKqu0FGXs\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 77.0, \"Danceability\": 0.371, \"Energy\": 0.75, \"Loudness\": -5.382, \"Speechiness\": 0.402, \"Acousticness\": 0.601, \"Liveness\": 0.482, \"Tempo\": 173.456, \"Duration (ms)\": 155293.0, \"Valence\": 0.729, \"Chord\": \"G\"}, {\"Index\": 259, \"Highest Charting Position\": 63, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"CORSO\", \"Streams\": 9503981, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"46oHvXwpEZOFX518we1nJD\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 77.0, \"Danceability\": 0.703, \"Energy\": 0.845, \"Loudness\": -4.851, \"Speechiness\": 0.337, \"Acousticness\": 0.169, \"Liveness\": 0.122, \"Tempo\": 97.672, \"Duration (ms)\": 146482.0, \"Valence\": 0.745, \"Chord\": \"A#/Bb\"}, {\"Index\": 260, \"Highest Charting Position\": 69, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"SWEET / I THOUGHT YOU WANTED TO DANCE (feat. Brent Faiyaz & Fana Hues)\", \"Streams\": 9142721, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"3EG9FJ0ToLfgnc1IG2Z1wz\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 79.0, \"Danceability\": 0.468, \"Energy\": 0.652, \"Loudness\": -4.912, \"Speechiness\": 0.0722, \"Acousticness\": 0.333, \"Liveness\": 0.55, \"Tempo\": 140.223, \"Duration (ms)\": 588139.0, \"Valence\": 0.39, \"Chord\": \"C\"}, {\"Index\": 261, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"SIR BAUDELAIRE (feat. DJ Drama)\", \"Streams\": 8884283, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"4ydmav4vl7hebadtfZtMrg\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 75.0, \"Danceability\": 0.467, \"Energy\": 0.635, \"Loudness\": -6.115, \"Speechiness\": 0.154, \"Acousticness\": 0.314, \"Liveness\": 0.844, \"Tempo\": 127.596, \"Duration (ms)\": 88625.0, \"Valence\": 0.51, \"Chord\": \"G\"}, {\"Index\": 262, \"Highest Charting Position\": 82, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"MASSA\", \"Streams\": 8218423, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"2goHCrsDJaflEwQ930ef0o\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 74.0, \"Danceability\": 0.685, \"Energy\": 0.855, \"Loudness\": -6.724, \"Speechiness\": 0.438, \"Acousticness\": 0.329, \"Liveness\": 0.301, \"Tempo\": 157.181, \"Duration (ms)\": 223719.0, \"Valence\": 0.46, \"Chord\": \"C#/Db\"}, {\"Index\": 263, \"Highest Charting Position\": 85, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"RUNITUP (feat. Teezo Touchdown)\", \"Streams\": 7917707, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"13HsOwrwTA5HgLuoaDHncP\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 75.0, \"Danceability\": 0.665, \"Energy\": 0.469, \"Loudness\": -7.778, \"Speechiness\": 0.13, \"Acousticness\": 0.565, \"Liveness\": 0.219, \"Tempo\": 115.852, \"Duration (ms)\": 229565.0, \"Valence\": 0.142, \"Chord\": \"A#/Bb\"}, {\"Index\": 264, \"Highest Charting Position\": 108, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"MANIFESTO (feat. Domo Genesis)\", \"Streams\": 6988886, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"6qouBO0wJtYc3k7DfKRUBx\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.454, \"Energy\": 0.866, \"Loudness\": -5.348, \"Speechiness\": 0.391, \"Acousticness\": 0.121, \"Liveness\": 0.167, \"Tempo\": 92.463, \"Duration (ms)\": 175123.0, \"Valence\": 0.518, \"Chord\": \"D\"}, {\"Index\": 265, \"Highest Charting Position\": 121, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Get Into It (Yuh)\", \"Streams\": 6503281, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0W6I02J9xcqK8MtSeosEXb\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 80.0, \"Danceability\": 0.912, \"Energy\": 0.655, \"Loudness\": -6.029, \"Speechiness\": 0.162, \"Acousticness\": 0.315, \"Liveness\": 0.0894, \"Tempo\": 91.942, \"Duration (ms)\": 138293.0, \"Valence\": 0.793, \"Chord\": \"G#/Ab\"}, {\"Index\": 266, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"WILSHIRE\", \"Streams\": 6268542, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"1pbbsI2KGPOMu0HmuGccBu\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.555, \"Energy\": 0.712, \"Loudness\": -7.446, \"Speechiness\": 0.323, \"Acousticness\": 0.0451, \"Liveness\": 0.182, \"Tempo\": 78.958, \"Duration (ms)\": 515865.0, \"Valence\": 0.555, \"Chord\": \"C#/Db\"}, {\"Index\": 267, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"RISE! (feat. DAISY WORLD)\", \"Streams\": 6034281, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"4Hta7Oy5W9HD0UgT1P8PPV\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.766, \"Energy\": 0.814, \"Loudness\": -3.367, \"Speechiness\": 0.0733, \"Acousticness\": 0.044, \"Liveness\": 0.195, \"Tempo\": 108.07, \"Duration (ms)\": 203588.0, \"Valence\": 0.481, \"Chord\": \"D\"}, {\"Index\": 268, \"Highest Charting Position\": 165, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Naked\", \"Streams\": 5527865, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0CsR9Y9SnC6ZWmekmVqSHz\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 75.0, \"Danceability\": 0.733, \"Energy\": 0.862, \"Loudness\": -5.736, \"Speechiness\": 0.197, \"Acousticness\": 0.374, \"Liveness\": 0.131, \"Tempo\": 111.076, \"Duration (ms)\": 223560.0, \"Valence\": 0.536, \"Chord\": \"G\"}, {\"Index\": 270, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Payday (feat. Young Thug)\", \"Streams\": 5393789, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"2HolBGR6tpiWI80MXoV1dJ\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.619, \"Energy\": 0.707, \"Loudness\": -5.791, \"Speechiness\": 0.0499, \"Acousticness\": 0.0366, \"Liveness\": 0.13, \"Tempo\": 168.995, \"Duration (ms)\": 212947.0, \"Valence\": 0.558, \"Chord\": \"C#/Db\"}, {\"Index\": 271, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Been Like This\", \"Streams\": 5362817, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"7y3xU9vEC1s8DSuuoSYKih\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 74.0, \"Danceability\": 0.678, \"Energy\": 0.531, \"Loudness\": -5.029, \"Speechiness\": 0.0374, \"Acousticness\": 0.126, \"Liveness\": 0.377, \"Tempo\": 99.008, \"Duration (ms)\": 177373.0, \"Valence\": 0.176, \"Chord\": \"A#/Bb\"}, {\"Index\": 279, \"Highest Charting Position\": 11, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"p r i d e . i s . t h e . d e v i l (with Lil Baby)\", \"Streams\": 5430260, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5W8jRrZ6tWrTrqnKRtIQBf\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.861, \"Energy\": 0.656, \"Loudness\": -7.867, \"Speechiness\": 0.425, \"Acousticness\": 0.104, \"Liveness\": 0.0986, \"Tempo\": 88.967, \"Duration (ms)\": 218210.0, \"Valence\": 0.331, \"Chord\": \"E\"}, {\"Index\": 280, \"Highest Charting Position\": 6, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"m y . l i f e (with 21 Savage & Morray)\", \"Streams\": 5246577, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"1D3z6HTiQsNmZxjl7F7eoG\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.597, \"Energy\": 0.587, \"Loudness\": -7.026, \"Speechiness\": 0.137, \"Acousticness\": 0.0622, \"Liveness\": 0.214, \"Tempo\": 140.021, \"Duration (ms)\": 218802.0, \"Valence\": 0.0753, \"Chord\": \"G\"}, {\"Index\": 286, \"Highest Charting Position\": 6, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Anyone\", \"Streams\": 5079587, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 1250353.0, \"Song ID\": \"2RwMwWo43LapkA4raptxaB\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-01-31--2020-02-07\", \"Popularity\": 0.0, \"Danceability\": 0.686, \"Energy\": 0.538, \"Loudness\": -8.026, \"Speechiness\": 0.0345, \"Acousticness\": 0.181, \"Liveness\": 0.113, \"Tempo\": 115.884, \"Duration (ms)\": 190779.0, \"Valence\": 0.584, \"Chord\": \"D\"}, {\"Index\": 290, \"Highest Charting Position\": 7, \"Number of Times Charted\": 65, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Break My Heart\", \"Streams\": 4971176, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"017PF4Q3l4DBUiWoXk4OWT\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 80.0, \"Danceability\": 0.73, \"Energy\": 0.729, \"Loudness\": -3.434, \"Speechiness\": 0.0884, \"Acousticness\": 0.167, \"Liveness\": 0.349, \"Tempo\": 113.011, \"Duration (ms)\": 221820.0, \"Valence\": 0.467, \"Chord\": \"E\"}, {\"Index\": 291, \"Highest Charting Position\": 2, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Laugh Now Cry Later (feat. Lil Durk)\", \"Streams\": 4916860, \"Artist\": \"Drake\", \"Artist Followers\": 56308172.0, \"Song ID\": \"2SAqBLGA283SUiwJ3xOUVI\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 83.0, \"Danceability\": 0.761, \"Energy\": 0.518, \"Loudness\": -8.871, \"Speechiness\": 0.134, \"Acousticness\": 0.244, \"Liveness\": 0.107, \"Tempo\": 133.976, \"Duration (ms)\": 261493.0, \"Valence\": 0.522, \"Chord\": \"C\"}, {\"Index\": 295, \"Highest Charting Position\": 119, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"No Role Modelz\", \"Streams\": 4904401, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"62vpWI1CHwFy7tMIcSStl8\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2014-12-09\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 84.0, \"Danceability\": 0.692, \"Energy\": 0.521, \"Loudness\": -8.465, \"Speechiness\": 0.33, \"Acousticness\": 0.301, \"Liveness\": 0.0565, \"Tempo\": 100.45, \"Duration (ms)\": 292987.0, \"Valence\": 0.463, \"Chord\": \"A#/Bb\"}, {\"Index\": 309, \"Highest Charting Position\": 2, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Therefore I Am\", \"Streams\": 5265630, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"0aACcc1jEv2C6VSmmJbllJ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 0.0, \"Danceability\": 0.889, \"Energy\": 0.34, \"Loudness\": -7.773, \"Speechiness\": 0.0697, \"Acousticness\": 0.218, \"Liveness\": 0.055, \"Tempo\": 94.009, \"Duration (ms)\": 174321.0, \"Valence\": 0.716, \"Chord\": \"B\"}, {\"Index\": 310, \"Highest Charting Position\": 12, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"TE MUDASTE\", \"Streams\": 5242347, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36142273.0, \"Song ID\": \"5RubKOuDoPn5Kj5TLVxSxY\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 82.0, \"Danceability\": 0.811, \"Energy\": 0.637, \"Loudness\": -4.835, \"Speechiness\": 0.0591, \"Acousticness\": 0.234, \"Liveness\": 0.118, \"Tempo\": 92.025, \"Duration (ms)\": 130014.0, \"Valence\": 0.471, \"Chord\": \"A#/Bb\"}, {\"Index\": 315, \"Highest Charting Position\": 1, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Rain On Me (with Ariana Grande)\", \"Streams\": 5041656, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18572085.0, \"Song ID\": \"24ySl2hOPGCDcxBxFIqWBu\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 79.0, \"Danceability\": 0.672, \"Energy\": 0.855, \"Loudness\": -3.764, \"Speechiness\": 0.0397, \"Acousticness\": 0.021, \"Liveness\": 0.323, \"Tempo\": 123.056, \"Duration (ms)\": 182200.0, \"Valence\": 0.646, \"Chord\": \"A\"}, {\"Index\": 320, \"Highest Charting Position\": 10, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"a m a r i\", \"Streams\": 5645966, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"2cnKST6T9qUo2i907lm8zX\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 79.0, \"Danceability\": 0.725, \"Energy\": 0.713, \"Loudness\": -6.173, \"Speechiness\": 0.187, \"Acousticness\": 0.127, \"Liveness\": 0.617, \"Tempo\": 65.988, \"Duration (ms)\": 148421.0, \"Valence\": 0.207, \"Chord\": \"E\"}, {\"Index\": 328, \"Highest Charting Position\": 170, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Killer (feat. Jack Harlow & Cordae) - Remix\", \"Streams\": 5404939, \"Artist\": \"Eminem\", \"Artist Followers\": 46785561.0, \"Song ID\": \"7zl7kehxesNEo2pYkKXTSe\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-05-28--2021-06-04\", \"Popularity\": 76.0, \"Danceability\": 0.924, \"Energy\": 0.73, \"Loudness\": -6.125, \"Speechiness\": 0.274, \"Acousticness\": 0.0525, \"Liveness\": 0.113, \"Tempo\": 99.01, \"Duration (ms)\": 236666.0, \"Valence\": 0.848, \"Chord\": \"B\"}, {\"Index\": 330, \"Highest Charting Position\": 108, \"Number of Times Charted\": 51, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"All Girls Are The Same\", \"Streams\": 5372180, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"4VXIryQMWpIdGgYR4TrjT1\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2018-12-10\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-08--2020-05-15\\n2020-04-24--2020-05-01\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.671, \"Energy\": 0.529, \"Loudness\": -7.226, \"Speechiness\": 0.307, \"Acousticness\": 0.0769, \"Liveness\": 0.0856, \"Tempo\": 161.989, \"Duration (ms)\": 165820.0, \"Valence\": 0.203, \"Chord\": \"C\"}, {\"Index\": 331, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"734\", \"Streams\": 5368759, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"6vB8bdQCCTDDIH8fhRfuXA\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-05-28--2021-06-04\", \"Popularity\": 75.0, \"Danceability\": 0.663, \"Energy\": 0.545, \"Loudness\": -3.93, \"Speechiness\": 0.036, \"Acousticness\": 0.123, \"Liveness\": 0.106, \"Tempo\": 78.452, \"Duration (ms)\": 196147.0, \"Valence\": 0.344, \"Chord\": \"D\"}, {\"Index\": 332, \"Highest Charting Position\": 85, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Boy With Luv (feat. Halsey)\", \"Streams\": 5266625, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"5KawlOMHjWeUjQtnuRs22c\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2019-04-12\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2020-11-20--2020-11-27\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-01-17--2020-01-24\", \"Popularity\": 82.0, \"Danceability\": 0.645, \"Energy\": 0.862, \"Loudness\": -4.757, \"Speechiness\": 0.0965, \"Acousticness\": 0.0923, \"Liveness\": 0.192, \"Tempo\": 119.991, \"Duration (ms)\": 229773.0, \"Valence\": 0.798, \"Chord\": \"B\"}, {\"Index\": 334, \"Highest Charting Position\": 4, \"Number of Times Charted\": 70, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Godzilla (feat. Juice WRLD)\", \"Streams\": 5143522, \"Artist\": \"Eminem\", \"Artist Followers\": 46785561.0, \"Song ID\": \"7FIWs0pqAYbP91WWM0vlTQ\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 83.0, \"Danceability\": 0.808, \"Energy\": 0.745, \"Loudness\": -5.26, \"Speechiness\": 0.342, \"Acousticness\": 0.145, \"Liveness\": 0.292, \"Tempo\": 165.995, \"Duration (ms)\": 210800.0, \"Valence\": 0.829, \"Chord\": \"A#/Bb\"}, {\"Index\": 337, \"Highest Charting Position\": 4, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Holy (feat. Chance The Rapper)\", \"Streams\": 5063015, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48504126.0, \"Song ID\": \"5u1n1kITHCxxp8twBcZxWy\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 81.0, \"Danceability\": 0.673, \"Energy\": 0.704, \"Loudness\": -8.056, \"Speechiness\": 0.36, \"Acousticness\": 0.196, \"Liveness\": 0.0898, \"Tempo\": 86.919, \"Duration (ms)\": 212093.0, \"Valence\": 0.372, \"Chord\": \"F#/Gb\"}, {\"Index\": 339, \"Highest Charting Position\": 15, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"i n t e r l u d e\", \"Streams\": 7880155, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"08LwMWf5Tcfsd752EPzFV0\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 76.0, \"Danceability\": 0.77, \"Energy\": 0.574, \"Loudness\": -5.525, \"Speechiness\": 0.106, \"Acousticness\": 0.0617, \"Liveness\": 0.104, \"Tempo\": 98.962, \"Duration (ms)\": 133022.0, \"Valence\": 0.104, \"Chord\": \"C#/Db\"}, {\"Index\": 340, \"Highest Charting Position\": 95, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Butter (Instrumental)\", \"Streams\": 7450126, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"2Ol2sv6gePRdJrZC1hDVNY\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 70.0, \"Danceability\": 0.429, \"Energy\": 0.387, \"Loudness\": -7.486, \"Speechiness\": 0.0753, \"Acousticness\": 0.000178, \"Liveness\": 0.142, \"Tempo\": 109.893, \"Duration (ms)\": 162147.0, \"Valence\": 0.41, \"Chord\": \"C#/Db\"}, {\"Index\": 341, \"Highest Charting Position\": 25, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Film out\", \"Streams\": 7198095, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"3UHPGOkUcE4hE7sqBF4Snt\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-04-01\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 81.0, \"Danceability\": 0.499, \"Energy\": 0.709, \"Loudness\": -6.404, \"Speechiness\": 0.134, \"Acousticness\": 0.296, \"Liveness\": 0.331, \"Tempo\": 164.032, \"Duration (ms)\": 214621.0, \"Valence\": 0.314, \"Chord\": \"A#/Bb\"}, {\"Index\": 345, \"Highest Charting Position\": 18, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"9 5 . s o u t h\", \"Streams\": 6333126, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5R691ipUYRDYW6ehapjoj6\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 75.0, \"Danceability\": 0.713, \"Energy\": 0.793, \"Loudness\": -5.277, \"Speechiness\": 0.397, \"Acousticness\": 0.271, \"Liveness\": 0.727, \"Tempo\": 71.724, \"Duration (ms)\": 196946.0, \"Valence\": 0.203, \"Chord\": \"D\"}, {\"Index\": 350, \"Highest Charting Position\": 27, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"l e t . g o . m y . h a n d (with Bas & 6LACK)\", \"Streams\": 5393643, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"0GAyuCo975IHGxxiLKDufB\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 73.0, \"Danceability\": 0.583, \"Energy\": 0.625, \"Loudness\": -8.011, \"Speechiness\": 0.277, \"Acousticness\": 0.506, \"Liveness\": 0.196, \"Tempo\": 89.812, \"Duration (ms)\": 266291.0, \"Valence\": 0.516, \"Chord\": \"C#/Db\"}, {\"Index\": 351, \"Highest Charting Position\": 2, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"What\\u2019s Next\", \"Streams\": 5335112, \"Artist\": \"Drake\", \"Artist Followers\": 56308172.0, \"Song ID\": \"3aQem4jVGdhtg116TmJnHz\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 81.0, \"Danceability\": 0.781, \"Energy\": 0.594, \"Loudness\": -6.959, \"Speechiness\": 0.0485, \"Acousticness\": 0.0136, \"Liveness\": 0.162, \"Tempo\": 129.895, \"Duration (ms)\": 178154.0, \"Valence\": 0.0628, \"Chord\": \"C\"}, {\"Index\": 359, \"Highest Charting Position\": 25, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"a p p l y i n g . p r e s s u r e\", \"Streams\": 15967986, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"1d7q712nXjG98HiwHk7HFS\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 71.0, \"Danceability\": 0.699, \"Energy\": 0.759, \"Loudness\": -5.302, \"Speechiness\": 0.311, \"Acousticness\": 0.0814, \"Liveness\": 0.312, \"Tempo\": 83.092, \"Duration (ms)\": 177337.0, \"Valence\": 0.404, \"Chord\": \"C#/Db\"}, {\"Index\": 360, \"Highest Charting Position\": 30, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"1 0 0 . m i l \\u2018 (with Bas)\", \"Streams\": 15171655, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"4n6NDfYake476trCjJRNl0\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 72.0, \"Danceability\": 0.711, \"Energy\": 0.647, \"Loudness\": -5.667, \"Speechiness\": 0.0822, \"Acousticness\": 0.334, \"Liveness\": 0.312, \"Tempo\": 125.092, \"Duration (ms)\": 163302.0, \"Valence\": 0.227, \"Chord\": \"D\"}, {\"Index\": 361, \"Highest Charting Position\": 32, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"p u n c h i n \\u2018 . t h e . c l o c k\", \"Streams\": 14051831, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"57ZUX6TNyKLBydAdVVd02x\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 70.0, \"Danceability\": 0.769, \"Energy\": 0.74, \"Loudness\": -6.579, \"Speechiness\": 0.378, \"Acousticness\": 0.197, \"Liveness\": 0.171, \"Tempo\": 94.104, \"Duration (ms)\": 112579.0, \"Valence\": 0.692, \"Chord\": \"B\"}, {\"Index\": 362, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"t h e . c l i m b . b a c k\", \"Streams\": 12648655, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5lLNBIyjp72btcnrjBG751\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.618, \"Energy\": 0.632, \"Loudness\": -6.973, \"Speechiness\": 0.346, \"Acousticness\": 0.0526, \"Liveness\": 0.353, \"Tempo\": 81.446, \"Duration (ms)\": 306257.0, \"Valence\": 0.319, \"Chord\": \"B\"}, {\"Index\": 363, \"Highest Charting Position\": 48, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"h u n g e r . o n . h i l l s i d e (with Bas)\", \"Streams\": 11647489, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5BwQjRasNcdRPuVWKcHto2\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 71.0, \"Danceability\": 0.563, \"Energy\": 0.703, \"Loudness\": -5.756, \"Speechiness\": 0.0702, \"Acousticness\": 0.126, \"Liveness\": 0.213, \"Tempo\": 94.983, \"Duration (ms)\": 238972.0, \"Valence\": 0.294, \"Chord\": \"D\"}, {\"Index\": 364, \"Highest Charting Position\": 55, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"c l o s e\", \"Streams\": 10712648, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"1D3z6HTiQsNmZxjl7F7eoG\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.597, \"Energy\": 0.587, \"Loudness\": -7.026, \"Speechiness\": 0.137, \"Acousticness\": 0.0622, \"Liveness\": 0.214, \"Tempo\": 140.021, \"Duration (ms)\": 218802.0, \"Valence\": 0.0753, \"Chord\": \"G\"}, {\"Index\": 373, \"Highest Charting Position\": 5, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Lonely (with benny blanco)\", \"Streams\": 5191697, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48504126.0, \"Song ID\": \"4y4spB9m0Q6026KfkAvy9Q\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 80.0, \"Danceability\": 0.631, \"Energy\": 0.239, \"Loudness\": -7.071, \"Speechiness\": 0.0398, \"Acousticness\": 0.864, \"Liveness\": 0.116, \"Tempo\": 79.859, \"Duration (ms)\": 149297.0, \"Valence\": 0.0927, \"Chord\": \"B\"}, {\"Index\": 378, \"Highest Charting Position\": 10, \"Number of Times Charted\": 69, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"everything i wanted\", \"Streams\": 5448680, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"1OC8hMoqAuWmTWJ4heJNlO\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.704, \"Energy\": 0.225, \"Loudness\": -14.454, \"Speechiness\": 0.0994, \"Acousticness\": 0.901, \"Liveness\": 0.106, \"Tempo\": 120.006, \"Duration (ms)\": 245426.0, \"Valence\": 0.243, \"Chord\": \"F#/Gb\"}, {\"Index\": 385, \"Highest Charting Position\": 7, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Wishing Well\", \"Streams\": 5125706, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"2U5WueTLIK5WJLD7mvDODv\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 83.0, \"Danceability\": 0.65, \"Energy\": 0.613, \"Loudness\": -6.13, \"Speechiness\": 0.128, \"Acousticness\": 0.00336, \"Liveness\": 0.267, \"Tempo\": 149.972, \"Duration (ms)\": 194621.0, \"Valence\": 0.0804, \"Chord\": \"A\"}, {\"Index\": 389, \"Highest Charting Position\": 4, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Come & Go (with Marshmello)\", \"Streams\": 5037124, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"2Y0wPrPQBrGhoLn14xRYCG\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 83.0, \"Danceability\": 0.625, \"Energy\": 0.814, \"Loudness\": -5.181, \"Speechiness\": 0.0657, \"Acousticness\": 0.0172, \"Liveness\": 0.158, \"Tempo\": 144.991, \"Duration (ms)\": 205485.0, \"Valence\": 0.535, \"Chord\": \"C\"}, {\"Index\": 390, \"Highest Charting Position\": 71, \"Number of Times Charted\": 72, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Robbery\", \"Streams\": 5024884, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"6Hj9jySrnFppAI0sEMCZpJ\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2019-03-08\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.685, \"Energy\": 0.692, \"Loudness\": -5.122, \"Speechiness\": 0.0457, \"Acousticness\": 0.328, \"Liveness\": 0.153, \"Tempo\": 159.966, \"Duration (ms)\": 240051.0, \"Valence\": 0.578, \"Chord\": \"D\"}, {\"Index\": 399, \"Highest Charting Position\": 20, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Mr. Perfectly Fine (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5480722, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2CYVETnhM9aytqrazYYwrK\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 74.0, \"Danceability\": 0.66, \"Energy\": 0.817, \"Loudness\": -6.269, \"Speechiness\": 0.0521, \"Acousticness\": 0.162, \"Liveness\": 0.0667, \"Tempo\": 135.942, \"Duration (ms)\": 277592.0, \"Valence\": 0.714, \"Chord\": \"B\"}, {\"Index\": 400, \"Highest Charting Position\": 42, \"Number of Times Charted\": 60, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"when the party's over\", \"Streams\": 5467596, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"5KWwUzVxubgSPmLIUAQhYt\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.484, \"Energy\": 0.103, \"Loudness\": -14.075, \"Speechiness\": 0.0627, \"Acousticness\": 0.979, \"Liveness\": 0.0895, \"Tempo\": 124.011, \"Duration (ms)\": 199931.0, \"Valence\": 0.194, \"Chord\": \"C#/Db\"}, {\"Index\": 406, \"Highest Charting Position\": 9, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"As I Am (feat. Khalid)\", \"Streams\": 5896065, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6F2r4HgpJnvKDmkN6JEN6J\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 72.0, \"Danceability\": 0.595, \"Energy\": 0.543, \"Loudness\": -8.149, \"Speechiness\": 0.038, \"Acousticness\": 0.127, \"Liveness\": 0.0975, \"Tempo\": 99.928, \"Duration (ms)\": 174406.0, \"Valence\": 0.109, \"Chord\": \"B\"}, {\"Index\": 413, \"Highest Charting Position\": 6, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"In Your Eyes\", \"Streams\": 5054319, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"7szuecWAPwGoV1e5vGu8tl\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 81.0, \"Danceability\": 0.667, \"Energy\": 0.719, \"Loudness\": -5.371, \"Speechiness\": 0.0346, \"Acousticness\": 0.00285, \"Liveness\": 0.0736, \"Tempo\": 100.021, \"Duration (ms)\": 237520.0, \"Valence\": 0.717, \"Chord\": \"G\"}, {\"Index\": 422, \"Highest Charting Position\": 8, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Love Story (Taylor\\u2019s Version)\", \"Streams\": 6202933, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6YvqWjhGD8mB5QXcbcUKtx\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 73.0, \"Danceability\": 0.627, \"Energy\": 0.792, \"Loudness\": -4.311, \"Speechiness\": 0.031, \"Acousticness\": 0.13, \"Liveness\": 0.0845, \"Tempo\": 119.054, \"Duration (ms)\": 235767.0, \"Valence\": 0.415, \"Chord\": \"D\"}, {\"Index\": 425, \"Highest Charting Position\": 3, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"willow\", \"Streams\": 5016865, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0lx2cLdOt3piJbcaXIV74f\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 79.0, \"Danceability\": 0.392, \"Energy\": 0.574, \"Loudness\": -9.195, \"Speechiness\": 0.17, \"Acousticness\": 0.833, \"Liveness\": 0.145, \"Tempo\": 81.112, \"Duration (ms)\": 214707.0, \"Valence\": 0.529, \"Chord\": \"G\"}, {\"Index\": 429, \"Highest Charting Position\": 52, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"You Belong With Me (Taylor\\u2019s Version)\", \"Streams\": 9872084, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1qrpoAMXodY6895hGKoUpA\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 73.0, \"Danceability\": 0.632, \"Energy\": 0.773, \"Loudness\": -4.856, \"Speechiness\": 0.0346, \"Acousticness\": 0.0623, \"Liveness\": 0.0885, \"Tempo\": 130.033, \"Duration (ms)\": 231124.0, \"Valence\": 0.474, \"Chord\": \"F#/Gb\"}, {\"Index\": 430, \"Highest Charting Position\": 54, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Fearless (Taylor\\u2019s Version)\", \"Streams\": 9676024, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"77sMIMlNaSURUAXq5coCxE\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 69.0, \"Danceability\": 0.569, \"Energy\": 0.741, \"Loudness\": -4.963, \"Speechiness\": 0.0282, \"Acousticness\": 0.0122, \"Liveness\": 0.333, \"Tempo\": 100.118, \"Duration (ms)\": 241592.0, \"Valence\": 0.43, \"Chord\": \"F\"}, {\"Index\": 432, \"Highest Charting Position\": 80, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Fifteen (Taylor\\u2019s Version)\", \"Streams\": 7852063, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2nqio0SfWg6gh2eCtfuMa5\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 66.0, \"Danceability\": 0.559, \"Energy\": 0.646, \"Loudness\": -4.61, \"Speechiness\": 0.0272, \"Acousticness\": 0.116, \"Liveness\": 0.32, \"Tempo\": 95.466, \"Duration (ms)\": 294419.0, \"Valence\": 0.289, \"Chord\": \"G\"}, {\"Index\": 433, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"The Way I Loved You (Taylor\\u2019s Version)\", \"Streams\": 7736262, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"22bPsP2jCgbLUvh82U0Z3M\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 72.0, \"Danceability\": 0.402, \"Energy\": 0.732, \"Loudness\": -4.665, \"Speechiness\": 0.0484, \"Acousticness\": 0.0033, \"Liveness\": 0.108, \"Tempo\": 161.032, \"Duration (ms)\": 243137.0, \"Valence\": 0.472, \"Chord\": \"F\"}, {\"Index\": 434, \"Highest Charting Position\": 51, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"You All Over Me (feat. Maren Morris) (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 7712896, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5pcjystBtalYeqaiXCcgEY\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 65.0, \"Danceability\": 0.589, \"Energy\": 0.496, \"Loudness\": -7.606, \"Speechiness\": 0.0377, \"Acousticness\": 0.818, \"Liveness\": 0.101, \"Tempo\": 142.731, \"Duration (ms)\": 220839.0, \"Valence\": 0.44, \"Chord\": \"D\"}, {\"Index\": 435, \"Highest Charting Position\": 93, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Hey Stephen (Taylor\\u2019s Version)\", \"Streams\": 7385864, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"550erGcdD9n6PnwxrvYqZT\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 66.0, \"Danceability\": 0.788, \"Energy\": 0.571, \"Loudness\": -6.135, \"Speechiness\": 0.0296, \"Acousticness\": 0.106, \"Liveness\": 0.0934, \"Tempo\": 115.99, \"Duration (ms)\": 254255.0, \"Valence\": 0.797, \"Chord\": \"F#/Gb\"}, {\"Index\": 436, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"White Horse (Taylor\\u2019s Version)\", \"Streams\": 7039222, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5YL553x8sHderRBDlm3NM3\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 65.0, \"Danceability\": 0.423, \"Energy\": 0.517, \"Loudness\": -7.377, \"Speechiness\": 0.0486, \"Acousticness\": 0.369, \"Liveness\": 0.177, \"Tempo\": 185.262, \"Duration (ms)\": 234516.0, \"Valence\": 0.366, \"Chord\": \"C\"}, {\"Index\": 437, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Forever & Always (Taylor\\u2019s Version)\", \"Streams\": 6566059, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1msEuwSBneBKpVCZQcFTsU\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 66.0, \"Danceability\": 0.598, \"Energy\": 0.821, \"Loudness\": -4.433, \"Speechiness\": 0.0447, \"Acousticness\": 0.0231, \"Liveness\": 0.143, \"Tempo\": 128.03, \"Duration (ms)\": 225328.0, \"Valence\": 0.673, \"Chord\": \"A#/Bb\"}, {\"Index\": 438, \"Highest Charting Position\": 119, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Breathe (feat. Colbie Caillat) (Taylor\\u2019s Version)\", \"Streams\": 6508683, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7HC7R2D8WjXVcUHJyEGjRs\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 64.0, \"Danceability\": 0.506, \"Energy\": 0.626, \"Loudness\": -6.066, \"Speechiness\": 0.0287, \"Acousticness\": 0.156, \"Liveness\": 0.228, \"Tempo\": 148.035, \"Duration (ms)\": 263377.0, \"Valence\": 0.321, \"Chord\": \"C#/Db\"}, {\"Index\": 440, \"Highest Charting Position\": 146, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"That\\u2019s When (feat. Keith Urban) (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5889939, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7eResoqEJJAVTkQYSqvO3P\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 67.0, \"Danceability\": 0.588, \"Energy\": 0.608, \"Loudness\": -7.062, \"Speechiness\": 0.0365, \"Acousticness\": 0.225, \"Liveness\": 0.092, \"Tempo\": 90.201, \"Duration (ms)\": 189496.0, \"Valence\": 0.508, \"Chord\": \"F\"}, {\"Index\": 441, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Tell Me Why (Taylor\\u2019s Version)\", \"Streams\": 5885151, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0k0vFacOHNuArLWMiH60p7\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 63.0, \"Danceability\": 0.578, \"Energy\": 0.909, \"Loudness\": -3.669, \"Speechiness\": 0.0628, \"Acousticness\": 0.0222, \"Liveness\": 0.333, \"Tempo\": 100.023, \"Duration (ms)\": 200576.0, \"Valence\": 0.541, \"Chord\": \"G\"}, {\"Index\": 442, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"You\\u2019re Not Sorry (Taylor\\u2019s Version)\", \"Streams\": 5860405, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6iiAfo4wTA2CVC3Uwx9uh8\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 64.0, \"Danceability\": 0.506, \"Energy\": 0.444, \"Loudness\": -4.99, \"Speechiness\": 0.0285, \"Acousticness\": 0.0538, \"Liveness\": 0.123, \"Tempo\": 133.873, \"Duration (ms)\": 261843.0, \"Valence\": 0.241, \"Chord\": \"F#/Gb\"}, {\"Index\": 445, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Don\\u2019t You (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5197564, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"4uuEGH5SVuzkkSFjo2DEiY\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 65.0, \"Danceability\": 0.563, \"Energy\": 0.473, \"Loudness\": -11.548, \"Speechiness\": 0.0503, \"Acousticness\": 0.514, \"Liveness\": 0.109, \"Tempo\": 101.934, \"Duration (ms)\": 208609.0, \"Valence\": 0.405, \"Chord\": \"D#/Eb\"}, {\"Index\": 446, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"We Were Happy (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5189423, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"34V9RiEPe8MNdU32qJsJa1\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 64.0, \"Danceability\": 0.609, \"Energy\": 0.373, \"Loudness\": -8.819, \"Speechiness\": 0.0263, \"Acousticness\": 0.849, \"Liveness\": 0.0779, \"Tempo\": 106.007, \"Duration (ms)\": 244237.0, \"Valence\": 0.13, \"Chord\": \"C\"}, {\"Index\": 451, \"Highest Charting Position\": 88, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Hello (feat. A Boogie Wit da Hoodie)\", \"Streams\": 5323062, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"2r6OAV3WsYtXuXjvJ1lIDi\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-20\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 82.0, \"Danceability\": 0.905, \"Energy\": 0.647, \"Loudness\": -5.065, \"Speechiness\": 0.107, \"Acousticness\": 0.0187, \"Liveness\": 0.282, \"Tempo\": 130.97, \"Duration (ms)\": 190534.0, \"Valence\": 0.367, \"Chord\": \"A#/Bb\"}, {\"Index\": 454, \"Highest Charting Position\": 28, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Unstable (feat. The Kid LAROI)\", \"Streams\": 5137645, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"137mSruegm1u6x9NvwiagR\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 74.0, \"Danceability\": 0.495, \"Energy\": 0.333, \"Loudness\": -10.109, \"Speechiness\": 0.0288, \"Acousticness\": 0.737, \"Liveness\": 0.112, \"Tempo\": 99.757, \"Duration (ms)\": 158324.0, \"Valence\": 0.37, \"Chord\": \"E\"}, {\"Index\": 455, \"Highest Charting Position\": 2, \"Number of Times Charted\": 48, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Stuck with U (with Justin Bieber)\", \"Streams\": 5094660, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"4HBZA5flZLE435QTztThqH\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 84.0, \"Danceability\": 0.597, \"Energy\": 0.45, \"Loudness\": -6.658, \"Speechiness\": 0.0418, \"Acousticness\": 0.223, \"Liveness\": 0.382, \"Tempo\": 178.765, \"Duration (ms)\": 228482.0, \"Valence\": 0.537, \"Chord\": \"G#/Ab\"}, {\"Index\": 460, \"Highest Charting Position\": 50, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Ghost\", \"Streams\": 5013450, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6I3mqTwhRpn34SLVafSH7G\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 71.0, \"Danceability\": 0.601, \"Energy\": 0.741, \"Loudness\": -5.569, \"Speechiness\": 0.0478, \"Acousticness\": 0.185, \"Liveness\": 0.415, \"Tempo\": 153.96, \"Duration (ms)\": 153190.0, \"Valence\": 0.441, \"Chord\": \"D\"}, {\"Index\": 461, \"Highest Charting Position\": 37, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Off My Face\", \"Streams\": 5004111, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"3T03rPwlL8NVk1yIaxeD8U\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 75.0, \"Danceability\": 0.509, \"Energy\": 0.228, \"Loudness\": -8.68, \"Speechiness\": 0.0332, \"Acousticness\": 0.92, \"Liveness\": 0.104, \"Tempo\": 90.674, \"Duration (ms)\": 156468.0, \"Valence\": 0.586, \"Chord\": \"E\"}, {\"Index\": 467, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Deserve You\", \"Streams\": 5837372, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5NU40QTlXrDUJzDBdv79bg\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 69.0, \"Danceability\": 0.677, \"Energy\": 0.633, \"Loudness\": -7.831, \"Speechiness\": 0.0771, \"Acousticness\": 0.0314, \"Liveness\": 0.112, \"Tempo\": 89.934, \"Duration (ms)\": 187239.0, \"Valence\": 0.409, \"Chord\": \"G\"}, {\"Index\": 468, \"Highest Charting Position\": 44, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"2 Much\", \"Streams\": 5794583, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"0oaY19dUwZimIgzn3ZZLZO\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 70.0, \"Danceability\": 0.583, \"Energy\": 0.444, \"Loudness\": -8.601, \"Speechiness\": 0.0456, \"Acousticness\": 0.593, \"Liveness\": 0.353, \"Tempo\": 119.59, \"Duration (ms)\": 152796.0, \"Valence\": 0.167, \"Chord\": \"A\"}, {\"Index\": 471, \"Highest Charting Position\": 61, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Loved By You (feat. Burna Boy)\", \"Streams\": 5419040, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2tB9OFgAHjAds3cqquLlvp\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 69.0, \"Danceability\": 0.79, \"Energy\": 0.724, \"Loudness\": -6.972, \"Speechiness\": 0.0852, \"Acousticness\": 0.0696, \"Liveness\": 0.113, \"Tempo\": 101.04, \"Duration (ms)\": 159250.0, \"Valence\": 0.642, \"Chord\": \"C#/Db\"}, {\"Index\": 473, \"Highest Charting Position\": 17, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Lemon Pepper Freestyle (feat. Rick Ross)\", \"Streams\": 5365747, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"4FRW5Nza1Ym91BGV4nFWXI\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 76.0, \"Danceability\": 0.77, \"Energy\": 0.637, \"Loudness\": -5.53, \"Speechiness\": 0.345, \"Acousticness\": 0.103, \"Liveness\": 0.171, \"Tempo\": 94.966, \"Duration (ms)\": 383037.0, \"Valence\": 0.431, \"Chord\": \"C#/Db\"}, {\"Index\": 476, \"Highest Charting Position\": 57, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Die For You (feat. Dominic Fike)\", \"Streams\": 5323412, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"7aely3H8kMj9o0gt6vXHE1\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 67.0, \"Danceability\": 0.728, \"Energy\": 0.629, \"Loudness\": -6.629, \"Speechiness\": 0.0318, \"Acousticness\": 0.00196, \"Liveness\": 0.0847, \"Tempo\": 135.031, \"Duration (ms)\": 198426.0, \"Valence\": 0.71, \"Chord\": \"C#/Db\"}, {\"Index\": 480, \"Highest Charting Position\": 60, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Love You Different (feat. BEAM)\", \"Streams\": 10024729, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"27UcQ6dAvQrgH9C880rCM3\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-19--2021-03-26\", \"Popularity\": 66.0, \"Danceability\": 0.759, \"Energy\": 0.584, \"Loudness\": -6.655, \"Speechiness\": 0.06, \"Acousticness\": 0.0652, \"Liveness\": 0.16, \"Tempo\": 127.138, \"Duration (ms)\": 186696.0, \"Valence\": 0.374, \"Chord\": \"G#/Ab\"}, {\"Index\": 481, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Somebody\", \"Streams\": 8912458, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"3rLIv187BhjyweFe89SgLn\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2010-01-01\", \"Weeks Charted\": \"2021-03-19--2021-03-26\", \"Popularity\": 67.0, \"Danceability\": 0.714, \"Energy\": 0.833, \"Loudness\": -5.239, \"Speechiness\": 0.0259, \"Acousticness\": 0.00249, \"Liveness\": 0.298, \"Tempo\": 129.964, \"Duration (ms)\": 220920.0, \"Valence\": 0.663, \"Chord\": \"F\"}, {\"Index\": 490, \"Highest Charting Position\": 109, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"D\\u00e1melo To\\u2019 (feat. Myke Towers)\", \"Streams\": 6426522, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"36CiGk9oRdwTnBDMgKEfjl\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 64.0, \"Danceability\": 0.787, \"Energy\": 0.641, \"Loudness\": -7.376, \"Speechiness\": 0.315, \"Acousticness\": 0.101, \"Liveness\": 0.07, \"Tempo\": 182.003, \"Duration (ms)\": 184134.0, \"Valence\": 0.437, \"Chord\": \"G#/Ab\"}, {\"Index\": 497, \"Highest Charting Position\": 6, \"Number of Times Charted\": 60, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Say So\", \"Streams\": 5103528, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"3Dv1eDb0MEgF93GpLXlucZ\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-02-26--2021-03-05\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.787, \"Energy\": 0.673, \"Loudness\": -4.583, \"Speechiness\": 0.159, \"Acousticness\": 0.264, \"Liveness\": 0.0904, \"Tempo\": 110.962, \"Duration (ms)\": 237893.0, \"Valence\": 0.779, \"Chord\": \"B\"}, {\"Index\": 501, \"Highest Charting Position\": 12, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Mood Swings (feat. Lil Tjay)\", \"Streams\": 5068349, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"5rZlwNFl01HqLWBQGryKSm\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 82.0, \"Danceability\": 0.48, \"Energy\": 0.602, \"Loudness\": -6.335, \"Speechiness\": 0.368, \"Acousticness\": 0.487, \"Liveness\": 0.0848, \"Tempo\": 179.798, \"Duration (ms)\": 213333.0, \"Valence\": 0.269, \"Chord\": \"A#/Bb\"}, {\"Index\": 507, \"Highest Charting Position\": 64, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"AP - Music from the film Boogie\", \"Streams\": 5462333, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"17vGPZ5EsdvtgAOCD4FLWI\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\", \"Popularity\": 75.0, \"Danceability\": 0.751, \"Energy\": 0.744, \"Loudness\": -6.859, \"Speechiness\": 0.177, \"Acousticness\": 0.152, \"Liveness\": 0.252, \"Tempo\": 148.014, \"Duration (ms)\": 171892.0, \"Valence\": 0.634, \"Chord\": \"C#/Db\"}, {\"Index\": 508, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Life's A Mess II (with Clever & Post Malone)\", \"Streams\": 5393459, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4O3RwH1TFG1EjPezLIYehI\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 72.0, \"Danceability\": 0.53, \"Energy\": 0.37, \"Loudness\": -9.989, \"Speechiness\": 0.0279, \"Acousticness\": 0.806, \"Liveness\": 0.112, \"Tempo\": 140.061, \"Duration (ms)\": 206734.0, \"Valence\": 0.701, \"Chord\": \"F#/Gb\"}, {\"Index\": 519, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"test drive\", \"Streams\": 6591829, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3eZYOQO4UzKrUDYDghtnFw\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-02-19\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 71.0, \"Danceability\": 0.698, \"Energy\": 0.708, \"Loudness\": -4.943, \"Speechiness\": 0.0454, \"Acousticness\": 0.0251, \"Liveness\": 0.124, \"Tempo\": 115.036, \"Duration (ms)\": 122174.0, \"Valence\": 0.322, \"Chord\": \"A\"}, {\"Index\": 527, \"Highest Charting Position\": 33, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"BOOKER T\", \"Streams\": 4995965, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"26w9NTiE9NGjW1ZvIOd1So\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 77.0, \"Danceability\": 0.883, \"Energy\": 0.6, \"Loudness\": -7.188, \"Speechiness\": 0.37, \"Acousticness\": 0.114, \"Liveness\": 0.0931, \"Tempo\": 113.903, \"Duration (ms)\": 156430.0, \"Valence\": 0.691, \"Chord\": \"G\"}, {\"Index\": 528, \"Highest Charting Position\": 5, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Intentions (feat. Quavo)\", \"Streams\": 4994138, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"4umIPjkehX1r7uhmGvXiSV\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 77.0, \"Danceability\": 0.806, \"Energy\": 0.546, \"Loudness\": -6.637, \"Speechiness\": 0.0575, \"Acousticness\": 0.3, \"Liveness\": 0.102, \"Tempo\": 147.986, \"Duration (ms)\": 212867.0, \"Valence\": 0.874, \"Chord\": \"A\"}, {\"Index\": 531, \"Highest Charting Position\": 20, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"34+35 Remix (feat. Doja Cat, Megan Thee Stallion) - Remix\", \"Streams\": 6162453, \"Artist\": \"Ariana Grande\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 541, \"Highest Charting Position\": 14, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"motive (with Doja Cat)\", \"Streams\": 4986037, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"5GkQIP5mWPi4KZLLXeuFTT\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 80.0, \"Danceability\": 0.789, \"Energy\": 0.742, \"Loudness\": -5.664, \"Speechiness\": 0.0652, \"Acousticness\": 0.0681, \"Liveness\": 0.166, \"Tempo\": 116.965, \"Duration (ms)\": 167990.0, \"Valence\": 0.661, \"Chord\": \"A#/Bb\"}, {\"Index\": 550, \"Highest Charting Position\": 2, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Toosie Slide\", \"Streams\": 4966878, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"127QTOFJsJQp5LbJbu3A1y\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 78.0, \"Danceability\": 0.834, \"Energy\": 0.454, \"Loudness\": -9.75, \"Speechiness\": 0.201, \"Acousticness\": 0.321, \"Liveness\": 0.114, \"Tempo\": 81.618, \"Duration (ms)\": 247059.0, \"Valence\": 0.837, \"Chord\": \"C#/Db\"}, {\"Index\": 551, \"Highest Charting Position\": 167, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Earned It (Fifty Shades Of Grey)\", \"Streams\": 4929647, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"4frLb7nWtsz2ymBE6k2GRP\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2015-08-28\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 69.0, \"Danceability\": 0.659, \"Energy\": 0.291, \"Loudness\": -8.275, \"Speechiness\": 0.0348, \"Acousticness\": 0.405, \"Liveness\": 0.0771, \"Tempo\": 119.829, \"Duration (ms)\": 277680.0, \"Valence\": 0.406, \"Chord\": \"D\"}, {\"Index\": 555, \"Highest Charting Position\": 27, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Bad Boy (with Young Thug)\", \"Streams\": 6011642, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"43CIWpJaJHRcI4mUSjqgc2\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 76.0, \"Danceability\": 0.697, \"Energy\": 0.674, \"Loudness\": -6.326, \"Speechiness\": 0.0533, \"Acousticness\": 0.00215, \"Liveness\": 0.138, \"Tempo\": 81.535, \"Duration (ms)\": 157355.0, \"Valence\": 0.198, \"Chord\": \"C#/Db\"}, {\"Index\": 556, \"Highest Charting Position\": 19, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Lo Vas A Olvidar (with ROSAL\\u00cdA)\", \"Streams\": 5963380, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"0psS4i5YooJrXfDnGvWRLi\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 68.0, \"Danceability\": 0.343, \"Energy\": 0.243, \"Loudness\": -14.66, \"Speechiness\": 0.0777, \"Acousticness\": 0.721, \"Liveness\": 0.0668, \"Tempo\": 135.154, \"Duration (ms)\": 203464.0, \"Valence\": 0.032, \"Chord\": \"E\"}, {\"Index\": 558, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Can't Feel My Face\", \"Streams\": 5479407, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"22VdIZQfgXJea34mQxlt81\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2015-08-28\", \"Weeks Charted\": \"2021-02-05--2021-02-12\", \"Popularity\": 80.0, \"Danceability\": 0.705, \"Energy\": 0.769, \"Loudness\": -5.526, \"Speechiness\": 0.0425, \"Acousticness\": 0.113, \"Liveness\": 0.105, \"Tempo\": 107.949, \"Duration (ms)\": 213520.0, \"Valence\": 0.583, \"Chord\": \"A\"}, {\"Index\": 560, \"Highest Charting Position\": 168, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Call Out My Name\", \"Streams\": 5233359, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"09mEdoA6zrmBPgTEN5qXmN\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2018-03-30\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\", \"Popularity\": 80.0, \"Danceability\": 0.461, \"Energy\": 0.593, \"Loudness\": -4.954, \"Speechiness\": 0.0356, \"Acousticness\": 0.17, \"Liveness\": 0.307, \"Tempo\": 134.17, \"Duration (ms)\": 228373.0, \"Valence\": 0.175, \"Chord\": \"C#/Db\"}, {\"Index\": 566, \"Highest Charting Position\": 18, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Heartless\", \"Streams\": 4995578, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"6bnF93Rx87YqUBLSgjiMU8\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.537, \"Energy\": 0.746, \"Loudness\": -5.507, \"Speechiness\": 0.15, \"Acousticness\": 0.0236, \"Liveness\": 0.156, \"Tempo\": 170.062, \"Duration (ms)\": 198267.0, \"Valence\": 0.252, \"Chord\": \"A#/Bb\"}, {\"Index\": 567, \"Highest Charting Position\": 20, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"pov\", \"Streams\": 4906738, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3UoULw70kMsiVXxW0L3A33\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 79.0, \"Danceability\": 0.487, \"Energy\": 0.534, \"Loudness\": -5.664, \"Speechiness\": 0.0555, \"Acousticness\": 0.36, \"Liveness\": 0.1, \"Tempo\": 131.798, \"Duration (ms)\": 201882.0, \"Valence\": 0.173, \"Chord\": \"C\"}, {\"Index\": 581, \"Highest Charting Position\": 66, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"De Una Vez\", \"Streams\": 5186567, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"1v3lhrZEsOcazqR2QIyyRu\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 70.0, \"Danceability\": 0.659, \"Energy\": 0.479, \"Loudness\": -6.79, \"Speechiness\": 0.2, \"Acousticness\": 0.152, \"Liveness\": 0.268, \"Tempo\": 163.882, \"Duration (ms)\": 155956.0, \"Valence\": 0.0395, \"Chord\": \"B\"}, {\"Index\": 586, \"Highest Charting Position\": 10, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"champagne problems\", \"Streams\": 4848954, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0sY6ZUTh4yoctD8VIXz339\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 75.0, \"Danceability\": 0.462, \"Energy\": 0.24, \"Loudness\": -12.077, \"Speechiness\": 0.0377, \"Acousticness\": 0.92, \"Liveness\": 0.113, \"Tempo\": 171.319, \"Duration (ms)\": 244000.0, \"Valence\": 0.32, \"Chord\": \"C\"}, {\"Index\": 599, \"Highest Charting Position\": 21, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"HACIENDO QUE ME AMAS\", \"Streams\": 4935633, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"26QApq0cuO9brJigr0C0W4\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 78.0, \"Danceability\": 0.584, \"Energy\": 0.411, \"Loudness\": -7.147, \"Speechiness\": 0.0838, \"Acousticness\": 0.869, \"Liveness\": 0.0955, \"Tempo\": 169.934, \"Duration (ms)\": 217769.0, \"Valence\": 0.412, \"Chord\": \"A#/Bb\"}, {\"Index\": 601, \"Highest Charting Position\": 17, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"The Woo (feat. 50 Cent & Roddy Ricch)\", \"Streams\": 4892682, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"1H7KnK26kc1YyellpbINEn\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 79.0, \"Danceability\": 0.49, \"Energy\": 0.618, \"Loudness\": -5.655, \"Speechiness\": 0.104, \"Acousticness\": 0.0221, \"Liveness\": 0.259, \"Tempo\": 99.7, \"Duration (ms)\": 201600.0, \"Valence\": 0.286, \"Chord\": \"C#/Db\"}, {\"Index\": 609, \"Highest Charting Position\": 15, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"no body, no crime (feat. HAIM)\", \"Streams\": 4986214, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3RaT22zZsxVYxxKR7TAaYF\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 68.0, \"Danceability\": 0.546, \"Energy\": 0.613, \"Loudness\": -7.589, \"Speechiness\": 0.0264, \"Acousticness\": 0.418, \"Liveness\": 0.103, \"Tempo\": 79.015, \"Duration (ms)\": 215627.0, \"Valence\": 0.535, \"Chord\": \"G\"}, {\"Index\": 622, \"Highest Charting Position\": 3, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Tell Me\", \"Streams\": 16657592, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"0lizgQ7Qw35od7CYaoMBZb\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2014-11-24\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 61.0, \"Danceability\": 0.525, \"Energy\": 0.621, \"Loudness\": -7.364, \"Speechiness\": 0.116, \"Acousticness\": 0.0489, \"Liveness\": 0.294, \"Tempo\": 191.9, \"Duration (ms)\": 204093.0, \"Valence\": 0.591, \"Chord\": \"G\"}, {\"Index\": 631, \"Highest Charting Position\": 15, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Mistletoe\", \"Streams\": 10609206, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"7xapw9Oy21WpfEcib2ErSA\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2011-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 59.0, \"Danceability\": 0.657, \"Energy\": 0.56, \"Loudness\": -9.049, \"Speechiness\": 0.0467, \"Acousticness\": 0.498, \"Liveness\": 0.0794, \"Tempo\": 161.993, \"Duration (ms)\": 182947.0, \"Valence\": 0.854, \"Chord\": \"F#/Gb\"}, {\"Index\": 664, \"Highest Charting Position\": 107, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Gnat\", \"Streams\": 8614955, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"6cS9PmLky2NhLOhpIsUlow\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 70.0, \"Danceability\": 0.835, \"Energy\": 0.869, \"Loudness\": -4.582, \"Speechiness\": 0.27, \"Acousticness\": 0.248, \"Liveness\": 0.462, \"Tempo\": 140.945, \"Duration (ms)\": 224656.0, \"Valence\": 0.82, \"Chord\": \"A#/Bb\"}, {\"Index\": 668, \"Highest Charting Position\": 22, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"\\u2018tis the damn season\", \"Streams\": 8115520, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7dW84mWkdWE5a6lFWxJCBG\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.575, \"Energy\": 0.434, \"Loudness\": -8.193, \"Speechiness\": 0.0312, \"Acousticness\": 0.735, \"Liveness\": 0.105, \"Tempo\": 145.916, \"Duration (ms)\": 229840.0, \"Valence\": 0.348, \"Chord\": \"F\"}, {\"Index\": 672, \"Highest Charting Position\": 19, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"gold rush\", \"Streams\": 7901968, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5BK0uqwY9DNfZ630STAEaq\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 70.0, \"Danceability\": 0.512, \"Energy\": 0.462, \"Loudness\": -10.491, \"Speechiness\": 0.0408, \"Acousticness\": 0.83, \"Liveness\": 0.121, \"Tempo\": 112.05, \"Duration (ms)\": 185320.0, \"Valence\": 0.353, \"Chord\": \"A\"}, {\"Index\": 689, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas Tree Farm\", \"Streams\": 6657404, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2mvabkN1i2gLnGAPUVdwek\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 52.0, \"Danceability\": 0.598, \"Energy\": 0.68, \"Loudness\": -4.505, \"Speechiness\": 0.0331, \"Acousticness\": 0.06, \"Liveness\": 0.324, \"Tempo\": 134.002, \"Duration (ms)\": 228027.0, \"Valence\": 0.437, \"Chord\": \"G\"}, {\"Index\": 692, \"Highest Charting Position\": 24, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"tolerate it\", \"Streams\": 6635109, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0PurA4JVJ8YQgSVopY8fn6\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 67.0, \"Danceability\": 0.316, \"Energy\": 0.361, \"Loudness\": -10.381, \"Speechiness\": 0.0488, \"Acousticness\": 0.878, \"Liveness\": 0.0797, \"Tempo\": 74.952, \"Duration (ms)\": 245440.0, \"Valence\": 0.221, \"Chord\": \"A\"}, {\"Index\": 695, \"Highest Charting Position\": 28, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"happiness\", \"Streams\": 16213589, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"73YUReisjb3A9ActdLLjJQ\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 65.0, \"Danceability\": 0.559, \"Energy\": 0.334, \"Loudness\": -10.733, \"Speechiness\": 0.0376, \"Acousticness\": 0.87, \"Liveness\": 0.114, \"Tempo\": 122.079, \"Duration (ms)\": 315147.0, \"Valence\": 0.211, \"Chord\": \"B\"}, {\"Index\": 696, \"Highest Charting Position\": 34, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"ivy\", \"Streams\": 14519547, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"19CSr8rwW05VJL2F91KFNK\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.515, \"Energy\": 0.545, \"Loudness\": -9.277, \"Speechiness\": 0.0353, \"Acousticness\": 0.855, \"Liveness\": 0.0921, \"Tempo\": 88.856, \"Duration (ms)\": 260440.0, \"Valence\": 0.535, \"Chord\": \"D\"}, {\"Index\": 697, \"Highest Charting Position\": 38, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"dorothea\", \"Streams\": 14392788, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"670fUmXf4KQekzbEgaXyPA\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.605, \"Energy\": 0.488, \"Loudness\": -8.322, \"Speechiness\": 0.0264, \"Acousticness\": 0.696, \"Liveness\": 0.129, \"Tempo\": 119.966, \"Duration (ms)\": 225880.0, \"Valence\": 0.354, \"Chord\": \"E\"}, {\"Index\": 698, \"Highest Charting Position\": 39, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"coney island (feat. The National)\", \"Streams\": 14385703, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3k7ne7VmH43ZPWxPdvPUgR\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.537, \"Energy\": 0.537, \"Loudness\": -11.266, \"Speechiness\": 0.0617, \"Acousticness\": 0.819, \"Liveness\": 0.142, \"Tempo\": 107.895, \"Duration (ms)\": 275320.0, \"Valence\": 0.292, \"Chord\": \"G#/Ab\"}, {\"Index\": 699, \"Highest Charting Position\": 43, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"evermore (feat. Bon Iver)\", \"Streams\": 13810722, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3O5osWf1rSoKMwe6E9ZaXP\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.39, \"Energy\": 0.27, \"Loudness\": -10.673, \"Speechiness\": 0.0308, \"Acousticness\": 0.937, \"Liveness\": 0.111, \"Tempo\": 125.177, \"Duration (ms)\": 304107.0, \"Valence\": 0.32, \"Chord\": \"C#/Db\"}, {\"Index\": 700, \"Highest Charting Position\": 45, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"long story short\", \"Streams\": 13583538, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2o2sgVJIgFXk8GQjWTgI6U\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.546, \"Energy\": 0.73, \"Loudness\": -7.704, \"Speechiness\": 0.0417, \"Acousticness\": 0.66, \"Liveness\": 0.0972, \"Tempo\": 157.895, \"Duration (ms)\": 215920.0, \"Valence\": 0.573, \"Chord\": \"C\"}, {\"Index\": 701, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"cowboy like me\", \"Streams\": 12782098, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1XjHRolIXL2M1EEOUsGGR4\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.604, \"Energy\": 0.517, \"Loudness\": -9.014, \"Speechiness\": 0.0347, \"Acousticness\": 0.768, \"Liveness\": 0.123, \"Tempo\": 127.967, \"Duration (ms)\": 275040.0, \"Valence\": 0.511, \"Chord\": \"C\"}, {\"Index\": 702, \"Highest Charting Position\": 57, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"marjorie\", \"Streams\": 12234761, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"12ntTeqEeTg7GAVpe8Mhpl\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.535, \"Energy\": 0.561, \"Loudness\": -11.609, \"Speechiness\": 0.0484, \"Acousticness\": 0.876, \"Liveness\": 0.115, \"Tempo\": 96.103, \"Duration (ms)\": 257773.0, \"Valence\": 0.287, \"Chord\": \"F\"}, {\"Index\": 703, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"closure\", \"Streams\": 11245393, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"35rdVq36LMHQX0Suw9a6tK\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 62.0, \"Danceability\": 0.689, \"Energy\": 0.704, \"Loudness\": -10.813, \"Speechiness\": 0.245, \"Acousticness\": 0.835, \"Liveness\": 0.134, \"Tempo\": 151.884, \"Duration (ms)\": 180653.0, \"Valence\": 0.92, \"Chord\": \"A\"}, {\"Index\": 711, \"Highest Charting Position\": 17, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"YO VISTO AS\\u00cd\", \"Streams\": 6388079, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5fROvzNghPid8mbKNDYvpJ\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 73.0, \"Danceability\": 0.688, \"Energy\": 0.881, \"Loudness\": -4.889, \"Speechiness\": 0.0474, \"Acousticness\": 0.0947, \"Liveness\": 0.0804, \"Tempo\": 123.013, \"Duration (ms)\": 191526.0, \"Valence\": 0.677, \"Chord\": \"G\"}, {\"Index\": 714, \"Highest Charting Position\": 1, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"cardigan\", \"Streams\": 5845457, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"4R2kfaDFhslZEMJqAFNpdd\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-12-11--2020-12-18\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 79.0, \"Danceability\": 0.613, \"Energy\": 0.581, \"Loudness\": -8.588, \"Speechiness\": 0.0424, \"Acousticness\": 0.537, \"Liveness\": 0.25, \"Tempo\": 130.033, \"Duration (ms)\": 239560.0, \"Valence\": 0.551, \"Chord\": \"C\"}, {\"Index\": 715, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Real Shit (with benny blanco)\", \"Streams\": 9325928, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"3uVPLtkmDu8pDkYEAVqbgS\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-12-02\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 70.0, \"Danceability\": 0.703, \"Energy\": 0.703, \"Loudness\": -4.672, \"Speechiness\": 0.133, \"Acousticness\": 0.605, \"Liveness\": 0.12, \"Tempo\": 76.017, \"Duration (ms)\": 183783.0, \"Valence\": 0.697, \"Chord\": \"C#/Db\"}, {\"Index\": 717, \"Highest Charting Position\": 138, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Blinding Lights (with ROSAL\\u00cdA) - Remix\", \"Streams\": 6653913, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"7MXgrcOQAJ5VwSNUL0lDd3\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 64.0, \"Danceability\": 0.49, \"Energy\": 0.694, \"Loudness\": -5.793, \"Speechiness\": 0.0618, \"Acousticness\": 0.0133, \"Liveness\": 0.0946, \"Tempo\": 170.903, \"Duration (ms)\": 216123.0, \"Valence\": 0.249, \"Chord\": \"F\"}, {\"Index\": 719, \"Highest Charting Position\": 29, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"TE DESEO LO MEJOR\", \"Streams\": 6204228, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"23XjN1s3DZC8Q9ZwuorYY4\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.763, \"Energy\": 0.597, \"Loudness\": -5.054, \"Speechiness\": 0.0416, \"Acousticness\": 0.158, \"Liveness\": 0.111, \"Tempo\": 126.054, \"Duration (ms)\": 139576.0, \"Valence\": 0.194, \"Chord\": \"C#/Db\"}, {\"Index\": 722, \"Highest Charting Position\": 18, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Blue & Grey\", \"Streams\": 5698275, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"0n2moJpAEWHwaPYYjkzMDl\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 77.0, \"Danceability\": 0.547, \"Energy\": 0.605, \"Loudness\": -6.755, \"Speechiness\": 0.0415, \"Acousticness\": 0.42, \"Liveness\": 0.125, \"Tempo\": 121.953, \"Duration (ms)\": 254950.0, \"Valence\": 0.364, \"Chord\": \"G#/Ab\"}, {\"Index\": 725, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"LA DROGA\", \"Streams\": 5375449, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"67ACYA3UI6QMNtHX6b34wX\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.643, \"Energy\": 0.727, \"Loudness\": -5.506, \"Speechiness\": 0.0389, \"Acousticness\": 0.0439, \"Liveness\": 0.123, \"Tempo\": 90.019, \"Duration (ms)\": 162299.0, \"Valence\": 0.295, \"Chord\": \"C#/Db\"}, {\"Index\": 729, \"Highest Charting Position\": 41, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"HOY COBR\\u00c9\", \"Streams\": 12914431, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0tjZv2hChdHZCW1zFXpy1J\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.86, \"Energy\": 0.725, \"Loudness\": -6.7, \"Speechiness\": 0.249, \"Acousticness\": 0.0464, \"Liveness\": 0.0994, \"Tempo\": 145.001, \"Duration (ms)\": 162151.0, \"Valence\": 0.375, \"Chord\": \"B\"}, {\"Index\": 730, \"Highest Charting Position\": 44, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"MALDITA POBREZA\", \"Streams\": 12660806, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0Lsis3LB0XAK6XlTHXaJk2\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 67.0, \"Danceability\": 0.762, \"Energy\": 0.861, \"Loudness\": -4.075, \"Speechiness\": 0.0652, \"Acousticness\": 0.139, \"Liveness\": 0.0956, \"Tempo\": 133.037, \"Duration (ms)\": 213609.0, \"Valence\": 0.588, \"Chord\": \"E\"}, {\"Index\": 731, \"Highest Charting Position\": 48, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"EL MUNDO ES M\\u00cdO\", \"Streams\": 12507010, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"36DHxTW2xdr9GG15T9oK9L\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 67.0, \"Danceability\": 0.716, \"Energy\": 0.522, \"Loudness\": -6.834, \"Speechiness\": 0.0582, \"Acousticness\": 0.166, \"Liveness\": 0.113, \"Tempo\": 76.993, \"Duration (ms)\": 165199.0, \"Valence\": 0.224, \"Chord\": \"F\"}, {\"Index\": 732, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"ANTES QUE SE ACABE\", \"Streams\": 11298839, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"7kjEqI6eZ7YlFrGhxixnlN\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 76.0, \"Danceability\": 0.693, \"Energy\": 0.549, \"Loudness\": -6.098, \"Speechiness\": 0.0577, \"Acousticness\": 0.505, \"Liveness\": 0.324, \"Tempo\": 139.988, \"Duration (ms)\": 221187.0, \"Valence\": 0.473, \"Chord\": \"D\"}, {\"Index\": 734, \"Highest Charting Position\": 63, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"120\", \"Streams\": 10957181, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3KJ3opyV29269SXkPrc19l\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 72.0, \"Danceability\": 0.636, \"Energy\": 0.656, \"Loudness\": -5.542, \"Speechiness\": 0.0676, \"Acousticness\": 0.451, \"Liveness\": 0.287, \"Tempo\": 171.918, \"Duration (ms)\": 151506.0, \"Valence\": 0.439, \"Chord\": \"D\"}, {\"Index\": 735, \"Highest Charting Position\": 66, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"TRELLAS\", \"Streams\": 10733416, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"09WAnxdBuebQopKhJT3oZS\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 66.0, \"Danceability\": 0.43, \"Energy\": 0.412, \"Loudness\": -5.372, \"Speechiness\": 0.0281, \"Acousticness\": 0.2, \"Liveness\": 0.324, \"Tempo\": 90.872, \"Duration (ms)\": 157673.0, \"Valence\": 0.0508, \"Chord\": \"D\"}, {\"Index\": 737, \"Highest Charting Position\": 16, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Fly To My Room\", \"Streams\": 8413330, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3QH8rQGNFX8VLbCgZ7uPTS\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 76.0, \"Danceability\": 0.764, \"Energy\": 0.526, \"Loudness\": -7.355, \"Speechiness\": 0.212, \"Acousticness\": 0.0484, \"Liveness\": 0.0718, \"Tempo\": 114.91, \"Duration (ms)\": 222243.0, \"Valence\": 0.588, \"Chord\": \"B\"}, {\"Index\": 738, \"Highest Charting Position\": 24, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Telepathy\", \"Streams\": 7703744, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"2FVpOsjT1iquZ3SpCjZ9Ne\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 77.0, \"Danceability\": 0.787, \"Energy\": 0.669, \"Loudness\": -4.333, \"Speechiness\": 0.0428, \"Acousticness\": 0.00782, \"Liveness\": 0.123, \"Tempo\": 104.994, \"Duration (ms)\": 202313.0, \"Valence\": 0.57, \"Chord\": \"F\"}, {\"Index\": 739, \"Highest Charting Position\": 26, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Dis-ease\", \"Streams\": 7165808, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"54DmTIv86D3sYdiawjULQ0\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 75.0, \"Danceability\": 0.731, \"Energy\": 0.845, \"Loudness\": -5.352, \"Speechiness\": 0.132, \"Acousticness\": 0.0132, \"Liveness\": 0.0782, \"Tempo\": 101.085, \"Duration (ms)\": 239722.0, \"Valence\": 0.484, \"Chord\": \"G#/Ab\"}, {\"Index\": 740, \"Highest Charting Position\": 27, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Stay\", \"Streams\": 7010227, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3ndCsZfq8OVwwkz9mmZvUz\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 76.0, \"Danceability\": 0.582, \"Energy\": 0.693, \"Loudness\": -5.048, \"Speechiness\": 0.0465, \"Acousticness\": 0.114, \"Liveness\": 0.13, \"Tempo\": 125.904, \"Duration (ms)\": 204800.0, \"Valence\": 0.341, \"Chord\": \"F#/Gb\"}, {\"Index\": 745, \"Highest Charting Position\": 78, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Skit\", \"Streams\": 8392247, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4GVwjLRT7oSsKby7Vy8EHr\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 60.0, \"Danceability\": 0.703, \"Energy\": 0.321, \"Loudness\": -13.135, \"Speechiness\": 0.884, \"Acousticness\": 0.864, \"Liveness\": 0.908, \"Tempo\": 114.822, \"Duration (ms)\": 179548.0, \"Valence\": 0.544, \"Chord\": \"E\"}, {\"Index\": 755, \"Highest Charting Position\": 7, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Smile (with The Weeknd)\", \"Streams\": 5164187, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"6wQlQrTY5mVS8EGaFZVwVF\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 75.0, \"Danceability\": 0.694, \"Energy\": 0.685, \"Loudness\": -6.535, \"Speechiness\": 0.133, \"Acousticness\": 0.224, \"Liveness\": 0.124, \"Tempo\": 158.831, \"Duration (ms)\": 196180.0, \"Valence\": 0.306, \"Chord\": \"F#/Gb\"}, {\"Index\": 772, \"Highest Charting Position\": 20, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"off the table (with The Weeknd)\", \"Streams\": 5308945, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"7E1jVNoWuemqUryI4FxsVD\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 67.0, \"Danceability\": 0.411, \"Energy\": 0.522, \"Loudness\": -7.295, \"Speechiness\": 0.0981, \"Acousticness\": 0.519, \"Liveness\": 0.398, \"Tempo\": 88.332, \"Duration (ms)\": 239949.0, \"Valence\": 0.382, \"Chord\": \"C\"}, {\"Index\": 779, \"Highest Charting Position\": 25, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"just like magic\", \"Streams\": 4980571, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"7Dx9Z6Aon1qPS2N0rHSWTe\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 69.0, \"Danceability\": 0.719, \"Energy\": 0.607, \"Loudness\": -5.156, \"Speechiness\": 0.165, \"Acousticness\": 0.08, \"Liveness\": 0.125, \"Tempo\": 128.006, \"Duration (ms)\": 149900.0, \"Valence\": 0.464, \"Chord\": \"G#/Ab\"}, {\"Index\": 788, \"Highest Charting Position\": 5, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"my future\", \"Streams\": 4721082, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"3YUMWmx8EJq0DurfuIwoGh\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-07-30\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 80.0, \"Danceability\": 0.456, \"Energy\": 0.285, \"Loudness\": -10.755, \"Speechiness\": 0.0979, \"Acousticness\": 0.814, \"Liveness\": 0.307, \"Tempo\": 104.89, \"Duration (ms)\": 210005.0, \"Valence\": 0.0809, \"Chord\": \"G#/Ab\"}, {\"Index\": 790, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"safety net (feat. Ty Dolla $ign)\", \"Streams\": 5798744, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"14gkWVFMwdxBMyqBw1wmIg\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 70.0, \"Danceability\": 0.552, \"Energy\": 0.599, \"Loudness\": -5.75, \"Speechiness\": 0.0404, \"Acousticness\": 0.0703, \"Liveness\": 0.0986, \"Tempo\": 161.884, \"Duration (ms)\": 208457.0, \"Valence\": 0.0916, \"Chord\": \"C#/Db\"}, {\"Index\": 791, \"Highest Charting Position\": 31, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"shut up\", \"Streams\": 5282490, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3ko9jEHNt4O5fjKN65ULJp\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 63.0, \"Danceability\": 0.499, \"Energy\": 0.462, \"Loudness\": -5.308, \"Speechiness\": 0.0312, \"Acousticness\": 0.801, \"Liveness\": 0.0946, \"Tempo\": 127.698, \"Duration (ms)\": 157710.0, \"Valence\": 0.599, \"Chord\": \"C\"}, {\"Index\": 792, \"Highest Charting Position\": 42, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"nasty\", \"Streams\": 5249342, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"0sci7ppTZFm4mjcH3nu8yO\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 69.0, \"Danceability\": 0.772, \"Energy\": 0.506, \"Loudness\": -6.558, \"Speechiness\": 0.139, \"Acousticness\": 0.0814, \"Liveness\": 0.182, \"Tempo\": 127.894, \"Duration (ms)\": 200733.0, \"Valence\": 0.456, \"Chord\": \"F#/Gb\"}, {\"Index\": 798, \"Highest Charting Position\": 41, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Got It On Me\", \"Streams\": 4924030, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"25zlnOAzbVoOzIeXSvQFf1\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 78.0, \"Danceability\": 0.688, \"Energy\": 0.647, \"Loudness\": -7.258, \"Speechiness\": 0.19, \"Acousticness\": 0.00815, \"Liveness\": 0.095, \"Tempo\": 88.834, \"Duration (ms)\": 164580.0, \"Valence\": 0.195, \"Chord\": \"D\"}, {\"Index\": 799, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"my hair\", \"Streams\": 4896521, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"6u7gmPOz7pzzaeR9xSBpsR\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 66.0, \"Danceability\": 0.686, \"Energy\": 0.526, \"Loudness\": -6.842, \"Speechiness\": 0.0374, \"Acousticness\": 0.0815, \"Liveness\": 0.144, \"Tempo\": 92.013, \"Duration (ms)\": 158436.0, \"Valence\": 0.372, \"Chord\": \"C\"}, {\"Index\": 800, \"Highest Charting Position\": 59, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"obvious\", \"Streams\": 4865084, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"0q85C1JiECyYIQthz1posA\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 65.0, \"Danceability\": 0.624, \"Energy\": 0.672, \"Loudness\": -5.334, \"Speechiness\": 0.106, \"Acousticness\": 0.0967, \"Liveness\": 0.155, \"Tempo\": 159.852, \"Duration (ms)\": 146959.0, \"Valence\": 0.26, \"Chord\": \"C\"}, {\"Index\": 805, \"Highest Charting Position\": 51, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"six thirty\", \"Streams\": 10941573, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"2IKJtXeR5UsaUjZB46fTOK\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 63.0, \"Danceability\": 0.739, \"Energy\": 0.516, \"Loudness\": -7.154, \"Speechiness\": 0.0539, \"Acousticness\": 0.67, \"Liveness\": 0.151, \"Tempo\": 120.109, \"Duration (ms)\": 183874.0, \"Valence\": 0.434, \"Chord\": \"C\"}, {\"Index\": 806, \"Highest Charting Position\": 65, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"love language\", \"Streams\": 9399230, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"6NYtLvyThMT0oALFdJFdzq\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 62.0, \"Danceability\": 0.688, \"Energy\": 0.573, \"Loudness\": -5.03, \"Speechiness\": 0.208, \"Acousticness\": 0.0686, \"Liveness\": 0.0749, \"Tempo\": 110.034, \"Duration (ms)\": 179861.0, \"Valence\": 0.553, \"Chord\": \"A#/Bb\"}, {\"Index\": 807, \"Highest Charting Position\": 66, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"west side\", \"Streams\": 9397167, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"1whfVLMKWqAX3uk97VXsNN\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 62.0, \"Danceability\": 0.688, \"Energy\": 0.455, \"Loudness\": -8.632, \"Speechiness\": 0.199, \"Acousticness\": 0.186, \"Liveness\": 0.0794, \"Tempo\": 87.865, \"Duration (ms)\": 132279.0, \"Valence\": 0.557, \"Chord\": \"B\"}, {\"Index\": 819, \"Highest Charting Position\": 88, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"thank u, next\", \"Streams\": 5079328, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3e9HZxeyfWwjeyPAMmWSSQ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-02-08\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.717, \"Energy\": 0.653, \"Loudness\": -5.634, \"Speechiness\": 0.0658, \"Acousticness\": 0.229, \"Liveness\": 0.101, \"Tempo\": 106.966, \"Duration (ms)\": 207320.0, \"Valence\": 0.412, \"Chord\": \"C#/Db\"}, {\"Index\": 838, \"Highest Charting Position\": 18, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Yo Perreo Sola\", \"Streams\": 4680447, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0SqqAgdovOE24BzxIClpjw\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 78.0, \"Danceability\": 0.86, \"Energy\": 0.758, \"Loudness\": -5.16, \"Speechiness\": 0.0695, \"Acousticness\": 0.021, \"Liveness\": 0.344, \"Tempo\": 97.014, \"Duration (ms)\": 172127.0, \"Valence\": 0.453, \"Chord\": \"B\"}, {\"Index\": 890, \"Highest Charting Position\": 4, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"exile (feat. Bon Iver)\", \"Streams\": 4924533, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"4pvb0WLRcMtbPGmtejJJ6y\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 77.0, \"Danceability\": 0.298, \"Energy\": 0.38, \"Loudness\": -8.426, \"Speechiness\": 0.0287, \"Acousticness\": 0.778, \"Liveness\": 0.11, \"Tempo\": 75.602, \"Duration (ms)\": 285634.0, \"Valence\": 0.152, \"Chord\": \"F#/Gb\"}, {\"Index\": 891, \"Highest Charting Position\": 10, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Righteous\", \"Streams\": 4819362, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5dOxHHMOFAbG3VH23t0xNm\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 78.0, \"Danceability\": 0.706, \"Energy\": 0.625, \"Loudness\": -7.426, \"Speechiness\": 0.0314, \"Acousticness\": 0.0417, \"Liveness\": 0.129, \"Tempo\": 142.948, \"Duration (ms)\": 242181.0, \"Valence\": 0.225, \"Chord\": \"C\"}, {\"Index\": 892, \"Highest Charting Position\": 9, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Conversations\", \"Streams\": 4805366, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4K06PO78fW4mnBVenxGNob\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 75.0, \"Danceability\": 0.747, \"Energy\": 0.622, \"Loudness\": -5.825, \"Speechiness\": 0.0838, \"Acousticness\": 0.176, \"Liveness\": 0.151, \"Tempo\": 159.93, \"Duration (ms)\": 181661.0, \"Valence\": 0.57, \"Chord\": \"B\"}, {\"Index\": 894, \"Highest Charting Position\": 23, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Chicago Freestyle (feat. Giveon)\", \"Streams\": 4799038, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"4wVOKKEHUJxHCFFNUWDn0B\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 80.0, \"Danceability\": 0.735, \"Energy\": 0.449, \"Loudness\": -7.507, \"Speechiness\": 0.347, \"Acousticness\": 0.629, \"Liveness\": 0.113, \"Tempo\": 122.947, \"Duration (ms)\": 220488.0, \"Valence\": 0.0397, \"Chord\": \"A#/Bb\"}, {\"Index\": 896, \"Highest Charting Position\": 12, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Physical\", \"Streams\": 4599807, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3AzjcOeAmA57TIOr9zF1ZW\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 77.0, \"Danceability\": 0.647, \"Energy\": 0.844, \"Loudness\": -3.756, \"Speechiness\": 0.0457, \"Acousticness\": 0.0137, \"Liveness\": 0.102, \"Tempo\": 146.967, \"Duration (ms)\": 193829.0, \"Valence\": 0.746, \"Chord\": \"C\"}, {\"Index\": 909, \"Highest Charting Position\": 21, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Boss Bitch\", \"Streams\": 4620838, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"78qd8dvwea0Gosb6Fe6j3k\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-01-23\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 81.0, \"Danceability\": 0.707, \"Energy\": 0.955, \"Loudness\": -4.593, \"Speechiness\": 0.222, \"Acousticness\": 0.127, \"Liveness\": 0.202, \"Tempo\": 125.989, \"Duration (ms)\": 134240.0, \"Valence\": 0.575, \"Chord\": \"A#/Bb\"}, {\"Index\": 922, \"Highest Charting Position\": 5, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"the 1\", \"Streams\": 4587573, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0Jlcvv8IykzHaSmj49uNW8\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 75.0, \"Danceability\": 0.777, \"Energy\": 0.357, \"Loudness\": -6.942, \"Speechiness\": 0.0522, \"Acousticness\": 0.757, \"Liveness\": 0.108, \"Tempo\": 139.883, \"Duration (ms)\": 210252.0, \"Valence\": 0.172, \"Chord\": \"C\"}, {\"Index\": 932, \"Highest Charting Position\": 5, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Sour Candy (with BLACKPINK)\", \"Streams\": 4556900, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"6R6ZoHTypt5lt68MWbzZXv\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-28\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 70.0, \"Danceability\": 0.752, \"Energy\": 0.87, \"Loudness\": -3.812, \"Speechiness\": 0.0623, \"Acousticness\": 0.0604, \"Liveness\": 0.489, \"Tempo\": 120.006, \"Duration (ms)\": 157707.0, \"Valence\": 0.784, \"Chord\": \"A\"}, {\"Index\": 934, \"Highest Charting Position\": 31, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Bandit (with YoungBoy Never Broke Again)\", \"Streams\": 4514763, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"6Gg1gjgKi2AK4e0qzsR7sd\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.474, \"Energy\": 0.631, \"Loudness\": -5.884, \"Speechiness\": 0.343, \"Acousticness\": 0.0687, \"Liveness\": 0.132, \"Tempo\": 180.051, \"Duration (ms)\": 189323.0, \"Valence\": 0.425, \"Chord\": \"F\"}, {\"Index\": 938, \"Highest Charting Position\": 22, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"ON\", \"Streams\": 5391018, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"2QyuXBcV1LJ2rq01KhreMF\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 77.0, \"Danceability\": 0.583, \"Energy\": 0.817, \"Loudness\": -5.146, \"Speechiness\": 0.0987, \"Acousticness\": 0.118, \"Liveness\": 0.338, \"Tempo\": 105.936, \"Duration (ms)\": 246381.0, \"Valence\": 0.438, \"Chord\": \"A\"}, {\"Index\": 940, \"Highest Charting Position\": 8, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Life's A Mess (feat. Halsey)\", \"Streams\": 4883202, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5wWAwzGp2OaaoIkwcz6wZs\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 74.0, \"Danceability\": 0.63, \"Energy\": 0.446, \"Loudness\": -8.9, \"Speechiness\": 0.0351, \"Acousticness\": 0.337, \"Liveness\": 0.166, \"Tempo\": 143.078, \"Duration (ms)\": 202193.0, \"Valence\": 0.177, \"Chord\": \"C#/Db\"}, {\"Index\": 943, \"Highest Charting Position\": 11, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"august\", \"Streams\": 4586236, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3hUxzQpSfdDqwM3ZTFQY0K\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 76.0, \"Danceability\": 0.532, \"Energy\": 0.623, \"Loudness\": -9.208, \"Speechiness\": 0.0331, \"Acousticness\": 0.538, \"Liveness\": 0.0925, \"Tempo\": 89.937, \"Duration (ms)\": 261923.0, \"Valence\": 0.403, \"Chord\": \"F\"}, {\"Index\": 946, \"Highest Charting Position\": 72, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Stay Gold\", \"Streams\": 4405338, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3Ys2PYl1wyPKQIwyqhP9cQ\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-07-14\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-07-10--2020-07-17\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 73.0, \"Danceability\": 0.723, \"Energy\": 0.634, \"Loudness\": -5.415, \"Speechiness\": 0.0542, \"Acousticness\": 0.0892, \"Liveness\": 0.0787, \"Tempo\": 129.017, \"Duration (ms)\": 243267.0, \"Valence\": 0.582, \"Chord\": \"C#/Db\"}, {\"Index\": 949, \"Highest Charting Position\": 8, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"the last great american dynasty\", \"Streams\": 4389670, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2Eeur20xVqfUoM3Q7EFPFt\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.686, \"Energy\": 0.662, \"Loudness\": -8.505, \"Speechiness\": 0.0413, \"Acousticness\": 0.467, \"Liveness\": 0.109, \"Tempo\": 147.922, \"Duration (ms)\": 230999.0, \"Valence\": 0.706, \"Chord\": \"G\"}, {\"Index\": 950, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Levitating (feat. Madonna and Missy Elliott) [The Blessed Madonna Remix]\", \"Streams\": 5254969, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"0pk1hxhJLBSZZ5RKBhcwOa\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-08-13\", \"Weeks Charted\": \"2020-08-14--2020-08-21\", \"Popularity\": 62.0, \"Danceability\": 0.808, \"Energy\": 0.655, \"Loudness\": -7.34, \"Speechiness\": 0.139, \"Acousticness\": 0.0373, \"Liveness\": 0.208, \"Tempo\": 116.029, \"Duration (ms)\": 250280.0, \"Valence\": 0.56, \"Chord\": \"B\"}, {\"Index\": 951, \"Highest Charting Position\": 10, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"my tears ricochet\", \"Streams\": 5111416, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1MgV7FIyNxIG7WzMRJV5HC\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.456, \"Energy\": 0.263, \"Loudness\": -10.63, \"Speechiness\": 0.0332, \"Acousticness\": 0.806, \"Liveness\": 0.0749, \"Tempo\": 129.86, \"Duration (ms)\": 255894.0, \"Valence\": 0.111, \"Chord\": \"C\"}, {\"Index\": 956, \"Highest Charting Position\": 55, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Hallucinate\", \"Streams\": 4472669, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"1nYeVF5vIBxMxfPoL0SIWg\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 72.0, \"Danceability\": 0.627, \"Energy\": 0.69, \"Loudness\": -5.396, \"Speechiness\": 0.139, \"Acousticness\": 0.033, \"Liveness\": 0.0742, \"Tempo\": 122.053, \"Duration (ms)\": 208505.0, \"Valence\": 0.627, \"Chord\": \"A#/Bb\"}, {\"Index\": 961, \"Highest Charting Position\": 17, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"invisible string\", \"Streams\": 4424118, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6VsvKPJ4xjVNKpI8VVZ3SV\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.653, \"Energy\": 0.452, \"Loudness\": -11.143, \"Speechiness\": 0.055, \"Acousticness\": 0.838, \"Liveness\": 0.108, \"Tempo\": 83.433, \"Duration (ms)\": 252881.0, \"Valence\": 0.45, \"Chord\": \"E\"}, {\"Index\": 966, \"Highest Charting Position\": 13, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"mirrorball\", \"Streams\": 5564072, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0ZNU020wNYvgW84iljPkPP\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.553, \"Energy\": 0.413, \"Loudness\": -10.037, \"Speechiness\": 0.0334, \"Acousticness\": 0.687, \"Liveness\": 0.0594, \"Tempo\": 110.107, \"Duration (ms)\": 208978.0, \"Valence\": 0.379, \"Chord\": \"D\"}, {\"Index\": 967, \"Highest Charting Position\": 15, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"seven\", \"Streams\": 5459423, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6KJqZcs9XDgVck7Lg9QOTC\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 69.0, \"Danceability\": 0.596, \"Energy\": 0.488, \"Loudness\": -10.769, \"Speechiness\": 0.0274, \"Acousticness\": 0.9, \"Liveness\": 0.091, \"Tempo\": 94.926, \"Duration (ms)\": 208907.0, \"Valence\": 0.415, \"Chord\": \"E\"}, {\"Index\": 968, \"Highest Charting Position\": 18, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"this is me trying\", \"Streams\": 5128412, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7kt9e9LFSpN1zQtYEl19o1\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.515, \"Energy\": 0.476, \"Loudness\": -9.843, \"Speechiness\": 0.0328, \"Acousticness\": 0.314, \"Liveness\": 0.171, \"Tempo\": 135.886, \"Duration (ms)\": 195097.0, \"Valence\": 0.412, \"Chord\": \"A\"}, {\"Index\": 969, \"Highest Charting Position\": 24, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"betty\", \"Streams\": 5112180, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5kI4eCXXzyuIUXjQra0Cxi\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.593, \"Energy\": 0.377, \"Loudness\": -8.761, \"Speechiness\": 0.0253, \"Acousticness\": 0.6, \"Liveness\": 0.0976, \"Tempo\": 95.939, \"Duration (ms)\": 294521.0, \"Valence\": 0.502, \"Chord\": \"C\"}, {\"Index\": 970, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"BLIND (feat. Young Thug)\", \"Streams\": 5074613, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"2T5NBwKRySiCR78vVk08vr\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-08-04\", \"Weeks Charted\": \"2020-08-07--2020-08-14\", \"Popularity\": 69.0, \"Danceability\": 0.709, \"Energy\": 0.679, \"Loudness\": -6.503, \"Speechiness\": 0.346, \"Acousticness\": 0.0115, \"Liveness\": 0.0971, \"Tempo\": 162.973, \"Duration (ms)\": 153467.0, \"Valence\": 0.754, \"Chord\": \"B\"}, {\"Index\": 971, \"Highest Charting Position\": 20, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"illicit affairs\", \"Streams\": 5053658, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2NmsngXHeC1GQ9wWrzhOMf\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.559, \"Energy\": 0.31, \"Loudness\": -10.445, \"Speechiness\": 0.0338, \"Acousticness\": 0.881, \"Liveness\": 0.106, \"Tempo\": 119.845, \"Duration (ms)\": 190898.0, \"Valence\": 0.46, \"Chord\": \"A#/Bb\"}, {\"Index\": 972, \"Highest Charting Position\": 170, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Freak\", \"Streams\": 4736059, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"3aA6xB0tOilDDX17fIJ0Bl\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2020-08-07--2020-08-14\", \"Popularity\": 75.0, \"Danceability\": 0.688, \"Energy\": 0.716, \"Loudness\": -5.702, \"Speechiness\": 0.0385, \"Acousticness\": 0.0969, \"Liveness\": 0.0989, \"Tempo\": 116.912, \"Duration (ms)\": 284480.0, \"Valence\": 0.373, \"Chord\": \"G\"}, {\"Index\": 977, \"Highest Charting Position\": 29, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"mad woman\", \"Streams\": 6796343, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2QDyYdZyhlP2fp79KZX8Bi\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 67.0, \"Danceability\": 0.592, \"Energy\": 0.699, \"Loudness\": -8.995, \"Speechiness\": 0.0471, \"Acousticness\": 0.655, \"Liveness\": 0.114, \"Tempo\": 141.916, \"Duration (ms)\": 237258.0, \"Valence\": 0.506, \"Chord\": \"D#/Eb\"}, {\"Index\": 978, \"Highest Charting Position\": 33, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"epiphany\", \"Streams\": 6085522, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"08fa9LFcFBTcilB3iq2e2A\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 66.0, \"Danceability\": 0.354, \"Energy\": 0.267, \"Loudness\": -13.69, \"Speechiness\": 0.0281, \"Acousticness\": 0.731, \"Liveness\": 0.0858, \"Tempo\": 94.219, \"Duration (ms)\": 289749.0, \"Valence\": 0.113, \"Chord\": \"C#/Db\"}, {\"Index\": 979, \"Highest Charting Position\": 41, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"peace\", \"Streams\": 5943851, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7MbT4I8qGntX4fMdqMQgke\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 67.0, \"Danceability\": 0.647, \"Energy\": 0.272, \"Loudness\": -12.906, \"Speechiness\": 0.0916, \"Acousticness\": 0.918, \"Liveness\": 0.0918, \"Tempo\": 150.044, \"Duration (ms)\": 234000.0, \"Valence\": 0.339, \"Chord\": \"F\"}, {\"Index\": 984, \"Highest Charting Position\": 47, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"hoax\", \"Streams\": 5375944, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6MWoRt97mnSTXZhu3ggi9C\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 66.0, \"Danceability\": 0.662, \"Energy\": 0.181, \"Loudness\": -15.065, \"Speechiness\": 0.0415, \"Acousticness\": 0.966, \"Liveness\": 0.133, \"Tempo\": 118.819, \"Duration (ms)\": 220043.0, \"Valence\": 0.429, \"Chord\": \"G#/Ab\"}, {\"Index\": 985, \"Highest Charting Position\": 25, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Blood On My Jeans\", \"Streams\": 4978899, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"0fCwrjKfWxF3xQhZrYUw4T\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 73.0, \"Danceability\": 0.868, \"Energy\": 0.55, \"Loudness\": -6.417, \"Speechiness\": 0.226, \"Acousticness\": 0.183, \"Liveness\": 0.109, \"Tempo\": 117.943, \"Duration (ms)\": 154767.0, \"Valence\": 0.464, \"Chord\": \"F#/Gb\"}, {\"Index\": 992, \"Highest Charting Position\": 101, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"ocean eyes\", \"Streams\": 4476954, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6pFTDHGJtKOxrQ85xRZ8Ue\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 1.0, \"Danceability\": 0.358, \"Energy\": 0.372, \"Loudness\": -7.664, \"Speechiness\": 0.0464, \"Acousticness\": 0.81, \"Liveness\": 0.0877, \"Tempo\": 144.833, \"Duration (ms)\": 200387.0, \"Valence\": 0.16, \"Chord\": \"E\"}, {\"Index\": 993, \"Highest Charting Position\": 82, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Lion King On Ice\", \"Streams\": 8293983, \"Artist\": \"J. Cole\", \"Artist Followers\": 14103694.0, \"Song ID\": \"1ZvBVbsaNqHEP6ymXaPGlj\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2020-07-22\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 64.0, \"Danceability\": 0.732, \"Energy\": 0.663, \"Loudness\": -7.616, \"Speechiness\": 0.192, \"Acousticness\": 0.0819, \"Liveness\": 0.115, \"Tempo\": 139.964, \"Duration (ms)\": 210587.0, \"Valence\": 0.227, \"Chord\": \"F#/Gb\"}, {\"Index\": 996, \"Highest Charting Position\": 37, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Stay High\", \"Streams\": 5047752, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"21CkzgKCBCq5V4XKjiGSIj\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 75.0, \"Danceability\": 0.745, \"Energy\": 0.5, \"Loudness\": -6.184, \"Speechiness\": 0.135, \"Acousticness\": 0.439, \"Liveness\": 0.0943, \"Tempo\": 76.968, \"Duration (ms)\": 168685.0, \"Valence\": 0.433, \"Chord\": \"G#/Ab\"}, {\"Index\": 999, \"Highest Charting Position\": 35, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Tell Me U Luv Me (with Trippie Redd)\", \"Streams\": 4798078, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5JAYDuLRkODlVt6dgoalKk\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 72.0, \"Danceability\": 0.66, \"Energy\": 0.76, \"Loudness\": -5.726, \"Speechiness\": 0.0787, \"Acousticness\": 0.291, \"Liveness\": 0.632, \"Tempo\": 127.984, \"Duration (ms)\": 180129.0, \"Valence\": 0.394, \"Chord\": \"D\"}, {\"Index\": 1000, \"Highest Charting Position\": 27, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Bad Energy\", \"Streams\": 4761155, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"7d94IqWX2UmSKMGUYSGFJG\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 72.0, \"Danceability\": 0.654, \"Energy\": 0.452, \"Loudness\": -6.36, \"Speechiness\": 0.0439, \"Acousticness\": 0.17, \"Liveness\": 0.114, \"Tempo\": 138.034, \"Duration (ms)\": 186749.0, \"Valence\": 0.532, \"Chord\": \"G\"}, {\"Index\": 1001, \"Highest Charting Position\": 24, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Titanic\", \"Streams\": 4687464, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"1YM6c2sxbf2Jacl9IFgn4I\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 71.0, \"Danceability\": 0.567, \"Energy\": 0.545, \"Loudness\": -6.668, \"Speechiness\": 0.0448, \"Acousticness\": 0.168, \"Liveness\": 0.112, \"Tempo\": 174.146, \"Duration (ms)\": 176650.0, \"Valence\": 0.234, \"Chord\": \"C#/Db\"}, {\"Index\": 1007, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Up Up And Away\", \"Streams\": 6229316, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"7pbg3ABlAZv2NiIdKbBBFm\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 72.0, \"Danceability\": 0.661, \"Energy\": 0.665, \"Loudness\": -6.356, \"Speechiness\": 0.053, \"Acousticness\": 0.538, \"Liveness\": 0.0981, \"Tempo\": 75.059, \"Duration (ms)\": 147548.0, \"Valence\": 0.486, \"Chord\": \"E\"}, {\"Index\": 1008, \"Highest Charting Position\": 46, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Man Of The Year\", \"Streams\": 6223001, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"7AvprzMsRJpybaalckaT8c\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 73.0, \"Danceability\": 0.621, \"Energy\": 0.695, \"Loudness\": -5.124, \"Speechiness\": 0.0911, \"Acousticness\": 0.00584, \"Liveness\": 0.086, \"Tempo\": 173.966, \"Duration (ms)\": 136408.0, \"Valence\": 0.298, \"Chord\": \"E\"}, {\"Index\": 1009, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Fighting Demons\", \"Streams\": 5946573, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"0440JCJyIAmINA8KcYgFb5\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 70.0, \"Danceability\": 0.707, \"Energy\": 0.67, \"Loudness\": -6.328, \"Speechiness\": 0.257, \"Acousticness\": 0.0813, \"Liveness\": 0.098, \"Tempo\": 163.099, \"Duration (ms)\": 200629.0, \"Valence\": 0.235, \"Chord\": \"G\"}, {\"Index\": 1010, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Can't Die\", \"Streams\": 5777859, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4PPLJAEYBSOcnzr9TZoqf9\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 71.0, \"Danceability\": 0.652, \"Energy\": 0.671, \"Loudness\": -5.89, \"Speechiness\": 0.0756, \"Acousticness\": 0.0222, \"Liveness\": 0.107, \"Tempo\": 84.008, \"Duration (ms)\": 182922.0, \"Valence\": 0.274, \"Chord\": \"D\"}, {\"Index\": 1011, \"Highest Charting Position\": 44, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Screw Juice\", \"Streams\": 5394197, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4F6YLjakjqWFTgC5qfEwPQ\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 69.0, \"Danceability\": 0.595, \"Energy\": 0.528, \"Loudness\": -7.371, \"Speechiness\": 0.0935, \"Acousticness\": 0.082, \"Liveness\": 0.142, \"Tempo\": 150.075, \"Duration (ms)\": 179464.0, \"Valence\": 0.515, \"Chord\": \"F\"}, {\"Index\": 1013, \"Highest Charting Position\": 45, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"I Want It\", \"Streams\": 5137482, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"2SVx3uds6jTWALFxevIWMA\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 69.0, \"Danceability\": 0.288, \"Energy\": 0.638, \"Loudness\": -6.935, \"Speechiness\": 0.0779, \"Acousticness\": 0.133, \"Liveness\": 0.14, \"Tempo\": 66.424, \"Duration (ms)\": 173114.0, \"Valence\": 0.147, \"Chord\": \"E\"}, {\"Index\": 1017, \"Highest Charting Position\": 5, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"La Dif\\u00edcil\", \"Streams\": 4727554, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"6NfrH0ANGmgBXyxgV2PeXt\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 78.0, \"Danceability\": 0.685, \"Energy\": 0.848, \"Loudness\": -4.561, \"Speechiness\": 0.0858, \"Acousticness\": 0.0861, \"Liveness\": 0.0783, \"Tempo\": 179.87, \"Duration (ms)\": 163084.0, \"Valence\": 0.761, \"Chord\": \"G#/Ab\"}, {\"Index\": 1024, \"Highest Charting Position\": 2, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Yummy\", \"Streams\": 4599349, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"41L3O37CECZt3N7ziG2z7l\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-03\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 72.0, \"Danceability\": 0.687, \"Energy\": 0.514, \"Loudness\": -6.612, \"Speechiness\": 0.0897, \"Acousticness\": 0.366, \"Liveness\": 0.116, \"Tempo\": 145.921, \"Duration (ms)\": 210427.0, \"Valence\": 0.494, \"Chord\": \"A\"}, {\"Index\": 1026, \"Highest Charting Position\": 69, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Like That (feat. Gucci Mane)\", \"Streams\": 4565377, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"4EivmOT13NMpNSfTKn9p4s\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 77.0, \"Danceability\": 0.879, \"Energy\": 0.498, \"Loudness\": -6.027, \"Speechiness\": 0.18, \"Acousticness\": 0.239, \"Liveness\": 0.0967, \"Tempo\": 106.044, \"Duration (ms)\": 163173.0, \"Valence\": 0.405, \"Chord\": \"E\"}, {\"Index\": 1028, \"Highest Charting Position\": 23, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"BOP\", \"Streams\": 4496450, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"6Ozh9Ok6h4Oi1wUSLtBseN\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.769, \"Energy\": 0.787, \"Loudness\": -3.909, \"Speechiness\": 0.367, \"Acousticness\": 0.189, \"Liveness\": 0.129, \"Tempo\": 126.77, \"Duration (ms)\": 159715.0, \"Valence\": 0.836, \"Chord\": \"B\"}, {\"Index\": 1030, \"Highest Charting Position\": 78, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Anxiety - Intro\", \"Streams\": 8449557, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"02XcRGWPkvomFvzTamEKHg\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 60.0, \"Danceability\": 0.307, \"Energy\": 0.528, \"Loudness\": -11.337, \"Speechiness\": 0.108, \"Acousticness\": 0.972, \"Liveness\": 0.222, \"Tempo\": 174.795, \"Duration (ms)\": 70395.0, \"Valence\": 0.58, \"Chord\": \"B\"}, {\"Index\": 1031, \"Highest Charting Position\": 112, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Juice WRLD Speaks From Heaven - Outro\", \"Streams\": 6682917, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"1OjiYjgPZyxS0AiXiSnuYI\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 59.0, \"Danceability\": 0.392, \"Energy\": 0.373, \"Loudness\": -14.097, \"Speechiness\": 0.0968, \"Acousticness\": 0.991, \"Liveness\": 0.545, \"Tempo\": 121.678, \"Duration (ms)\": 30583.0, \"Valence\": 0.519, \"Chord\": \"C\"}, {\"Index\": 1032, \"Highest Charting Position\": 113, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"The Man, The Myth, The Legend - Interlude\", \"Streams\": 6640728, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4sjdZEEQvR1sXrRNSuBfbA\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 58.0, \"Danceability\": 0.667, \"Energy\": 0.447, \"Loudness\": -14.625, \"Speechiness\": 0.761, \"Acousticness\": 0.916, \"Liveness\": 0.612, \"Tempo\": 83.534, \"Duration (ms)\": 136545.0, \"Valence\": 0.829, \"Chord\": \"D\"}, {\"Index\": 1035, \"Highest Charting Position\": 53, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Gangstas\", \"Streams\": 5104422, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"1hg3RlqFZXJb5YgRoK9qmF\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 71.0, \"Danceability\": 0.548, \"Energy\": 0.506, \"Loudness\": -7.434, \"Speechiness\": 0.102, \"Acousticness\": 0.203, \"Liveness\": 0.0788, \"Tempo\": 119.987, \"Duration (ms)\": 160000.0, \"Valence\": 0.557, \"Chord\": \"E\"}, {\"Index\": 1040, \"Highest Charting Position\": 64, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Make It Rain (feat. Rowdy Rebel)\", \"Streams\": 4594248, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"71d7LaAgPcNcUopu3OzmP7\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 62.0, \"Danceability\": 0.5, \"Energy\": 0.767, \"Loudness\": -4.105, \"Speechiness\": 0.403, \"Acousticness\": 0.162, \"Liveness\": 0.385, \"Tempo\": 159.477, \"Duration (ms)\": 202443.0, \"Valence\": 0.58, \"Chord\": \"C#/Db\"}, {\"Index\": 1042, \"Highest Charting Position\": 79, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Something Special\", \"Streams\": 4535580, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"5kkaSMcf4BFlhRRICCKZb6\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 72.0, \"Danceability\": 0.739, \"Energy\": 0.616, \"Loudness\": -6.963, \"Speechiness\": 0.0338, \"Acousticness\": 0.252, \"Liveness\": 0.101, \"Tempo\": 91.071, \"Duration (ms)\": 158466.0, \"Valence\": 0.654, \"Chord\": \"G\"}, {\"Index\": 1043, \"Highest Charting Position\": 58, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Aim For The Moon (feat. Quavo)\", \"Streams\": 9011502, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"6O7fPYTsb2mY0PiFt2ymDB\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 67.0, \"Danceability\": 0.713, \"Energy\": 0.605, \"Loudness\": -7.487, \"Speechiness\": 0.107, \"Acousticness\": 0.497, \"Liveness\": 0.115, \"Tempo\": 142.025, \"Duration (ms)\": 175756.0, \"Valence\": 0.432, \"Chord\": \"B\"}, {\"Index\": 1044, \"Highest Charting Position\": 63, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"44 BullDog\", \"Streams\": 8443771, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"7sjFIZ1g5QLJLGja3k592K\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 66.0, \"Danceability\": 0.8, \"Energy\": 0.564, \"Loudness\": -5.817, \"Speechiness\": 0.4, \"Acousticness\": 0.0287, \"Liveness\": 0.112, \"Tempo\": 139.989, \"Duration (ms)\": 150857.0, \"Valence\": 0.318, \"Chord\": \"G#/Ab\"}, {\"Index\": 1045, \"Highest Charting Position\": 88, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Creature (feat. Swae Lee)\", \"Streams\": 7308690, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"3eV2WT9YhfzkxbufnBF8wK\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 66.0, \"Danceability\": 0.794, \"Energy\": 0.717, \"Loudness\": -5.73, \"Speechiness\": 0.251, \"Acousticness\": 0.0511, \"Liveness\": 0.195, \"Tempo\": 141.881, \"Duration (ms)\": 202816.0, \"Valence\": 0.372, \"Chord\": \"G\"}, {\"Index\": 1046, \"Highest Charting Position\": 95, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Yea Yea\", \"Streams\": 7112419, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"0bjgQ24UZGwKikldIyEOgf\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 63.0, \"Danceability\": 0.717, \"Energy\": 0.474, \"Loudness\": -8.383, \"Speechiness\": 0.403, \"Acousticness\": 0.0509, \"Liveness\": 0.139, \"Tempo\": 123.906, \"Duration (ms)\": 185804.0, \"Valence\": 0.448, \"Chord\": \"F\"}, {\"Index\": 1047, \"Highest Charting Position\": 100, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Enjoy Yourself (feat. Karol G)\", \"Streams\": 6620040, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"3NWrHCwvyII4fTx05PN3IO\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 70.0, \"Danceability\": 0.764, \"Energy\": 0.676, \"Loudness\": -6.761, \"Speechiness\": 0.0927, \"Acousticness\": 0.389, \"Liveness\": 0.215, \"Tempo\": 97.02, \"Duration (ms)\": 197938.0, \"Valence\": 0.461, \"Chord\": \"B\"}, {\"Index\": 1048, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Bad Bitch From Tokyo (Intro)\", \"Streams\": 6144736, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"4OGIeHtYhRTJ8iW21UUyZW\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 59.0, \"Danceability\": 0.645, \"Energy\": 0.64, \"Loudness\": -6.871, \"Speechiness\": 0.179, \"Acousticness\": 0.395, \"Liveness\": 0.286, \"Tempo\": 140.248, \"Duration (ms)\": 48000.0, \"Valence\": 0.674, \"Chord\": \"A#/Bb\"}, {\"Index\": 1049, \"Highest Charting Position\": 117, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Snitching (feat. Quavo & Future)\", \"Streams\": 6102253, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"2FhEj9lvEIaJihjFprRrGt\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 59.0, \"Danceability\": 0.944, \"Energy\": 0.579, \"Loudness\": -4.961, \"Speechiness\": 0.191, \"Acousticness\": 0.0381, \"Liveness\": 0.253, \"Tempo\": 135.033, \"Duration (ms)\": 259346.0, \"Valence\": 0.769, \"Chord\": \"G#/Ab\"}, {\"Index\": 1050, \"Highest Charting Position\": 121, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"West Coast Shit (feat. Tyga & Quavo)\", \"Streams\": 5931242, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"1JDhNQ0oOT7XpclZn3aQ8F\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 61.0, \"Danceability\": 0.831, \"Energy\": 0.762, \"Loudness\": -5.656, \"Speechiness\": 0.207, \"Acousticness\": 0.0885, \"Liveness\": 0.107, \"Tempo\": 99.999, \"Duration (ms)\": 192000.0, \"Valence\": 0.495, \"Chord\": \"B\"}, {\"Index\": 1053, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Tunnel Vision (Outro)\", \"Streams\": 4907751, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"2SxR5RitJdsG6wINvJLBSD\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 60.0, \"Danceability\": 0.718, \"Energy\": 0.66, \"Loudness\": -7.39, \"Speechiness\": 0.325, \"Acousticness\": 0.363, \"Liveness\": 0.159, \"Tempo\": 142.879, \"Duration (ms)\": 132587.0, \"Valence\": 0.659, \"Chord\": \"D\"}, {\"Index\": 1054, \"Highest Charting Position\": 7, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Si Veo a Tu Mam\\u00e1\", \"Streams\": 4638728, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"41wtwzCZkXwpnakmwJ239F\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 80.0, \"Danceability\": 0.9, \"Energy\": 0.603, \"Loudness\": -5.313, \"Speechiness\": 0.0646, \"Acousticness\": 0.402, \"Liveness\": 0.134, \"Tempo\": 129.928, \"Duration (ms)\": 170972.0, \"Valence\": 0.824, \"Chord\": \"D\"}, {\"Index\": 1067, \"Highest Charting Position\": 32, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Myron\", \"Streams\": 4593309, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"56uXDJRCuoS7abX3SkzHKQ\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 76.0, \"Danceability\": 0.771, \"Energy\": 0.654, \"Loudness\": -6.976, \"Speechiness\": 0.298, \"Acousticness\": 0.055, \"Liveness\": 0.214, \"Tempo\": 155.047, \"Duration (ms)\": 224955.0, \"Valence\": 0.573, \"Chord\": \"G#/Ab\"}, {\"Index\": 1074, \"Highest Charting Position\": 88, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Money In The Grave (Drake ft. Rick Ross)\", \"Streams\": 4403348, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5ry2OE6R2zPQFDO85XkgRb\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2019-06-15\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.831, \"Energy\": 0.502, \"Loudness\": -4.045, \"Speechiness\": 0.046, \"Acousticness\": 0.101, \"Liveness\": 0.122, \"Tempo\": 100.541, \"Duration (ms)\": 205427.0, \"Valence\": 0.101, \"Chord\": \"A#/Bb\"}, {\"Index\": 1075, \"Highest Charting Position\": 25, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Say So (feat. Nicki Minaj)\", \"Streams\": 4385148, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"11VApNQCWLJdzxWrlmwzUa\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 69.0, \"Danceability\": 0.856, \"Energy\": 0.641, \"Loudness\": -4.64, \"Speechiness\": 0.204, \"Acousticness\": 0.119, \"Liveness\": 0.427, \"Tempo\": 111.004, \"Duration (ms)\": 206221.0, \"Valence\": 0.745, \"Chord\": \"B\"}, {\"Index\": 1082, \"Highest Charting Position\": 14, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Lose You To Love Me\", \"Streams\": 4322088, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4l0Mvzj72xxOpRrp6h8nHi\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.488, \"Energy\": 0.343, \"Loudness\": -8.985, \"Speechiness\": 0.0436, \"Acousticness\": 0.556, \"Liveness\": 0.21, \"Tempo\": 102.819, \"Duration (ms)\": 206459.0, \"Valence\": 0.0978, \"Chord\": \"E\"}, {\"Index\": 1090, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Snow On Tha Bluff\", \"Streams\": 5060764, \"Artist\": \"J. Cole\", \"Artist Followers\": 14103694.0, \"Song ID\": \"1oOEkBNp4zWnkD7nWjJdog\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2020-06-16\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 66.0, \"Danceability\": 0.586, \"Energy\": 0.512, \"Loudness\": -8.819, \"Speechiness\": 0.0668, \"Acousticness\": 0.723, \"Liveness\": 0.119, \"Tempo\": 75.857, \"Duration (ms)\": 235480.0, \"Valence\": 0.235, \"Chord\": \"G#/Ab\"}, {\"Index\": 1093, \"Highest Charting Position\": 13, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Stupid Love\", \"Streams\": 4609858, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 1251372.0, \"Song ID\": \"1zPwSOUc5MPtPg8EgXAGKU\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-08\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 0.0, \"Danceability\": 0.68, \"Energy\": 0.825, \"Loudness\": -4.296, \"Speechiness\": 0.0702, \"Acousticness\": 0.00173, \"Liveness\": 0.27, \"Tempo\": 117.987, \"Duration (ms)\": 193533.0, \"Valence\": 0.784, \"Chord\": \"G#/Ab\"}, {\"Index\": 1100, \"Highest Charting Position\": 76, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"ROCKSTAR (feat. Roddy Ricch) - BLM REMIX\", \"Streams\": 7353153, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"4Aykm3xrOFSHrAnv80KUhh\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 62.0, \"Danceability\": 0.747, \"Energy\": 0.689, \"Loudness\": -7.246, \"Speechiness\": 0.242, \"Acousticness\": 0.197, \"Liveness\": 0.0884, \"Tempo\": 89.901, \"Duration (ms)\": 204547.0, \"Valence\": 0.75, \"Chord\": \"B\"}, {\"Index\": 1104, \"Highest Charting Position\": 21, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"P2\", \"Streams\": 4769996, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"3kW4z2pIj5VY5fLjBrMRL5\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 73.0, \"Danceability\": 0.775, \"Energy\": 0.72, \"Loudness\": -5.353, \"Speechiness\": 0.193, \"Acousticness\": 0.0236, \"Liveness\": 0.114, \"Tempo\": 155.086, \"Duration (ms)\": 234627.0, \"Valence\": 0.49, \"Chord\": \"B\"}, {\"Index\": 1108, \"Highest Charting Position\": 48, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"BYE ME FUI\", \"Streams\": 4567732, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0FktnzDqjClqU6iqOZVEs2\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 72.0, \"Danceability\": 0.712, \"Energy\": 0.599, \"Loudness\": -6.342, \"Speechiness\": 0.112, \"Acousticness\": 0.412, \"Liveness\": 0.103, \"Tempo\": 179.788, \"Duration (ms)\": 178000.0, \"Valence\": 0.588, \"Chord\": \"F\"}, {\"Index\": 1109, \"Highest Charting Position\": 15, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Vete\", \"Streams\": 4486408, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5DxXgozhkPLgrbKFY91w0c\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-21\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.886, \"Energy\": 0.672, \"Loudness\": -4.394, \"Speechiness\": 0.188, \"Acousticness\": 0.0363, \"Liveness\": 0.101, \"Tempo\": 91.976, \"Duration (ms)\": 192024.0, \"Valence\": 0.526, \"Chord\": \"C#/Db\"}, {\"Index\": 1125, \"Highest Charting Position\": 137, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"XO Tour Llif3\", \"Streams\": 4314080, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7GX5flRQZVHRAGd6B4TmDO\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2017-08-25\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-08--2020-05-15\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 82.0, \"Danceability\": 0.732, \"Energy\": 0.75, \"Loudness\": -6.366, \"Speechiness\": 0.231, \"Acousticness\": 0.00264, \"Liveness\": 0.109, \"Tempo\": 155.096, \"Duration (ms)\": 182707.0, \"Valence\": 0.401, \"Chord\": \"B\"}, {\"Index\": 1129, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Alice\", \"Streams\": 10342277, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"41A89rj3GoMG6ktN37L7PG\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 64.0, \"Danceability\": 0.723, \"Energy\": 0.88, \"Loudness\": -4.287, \"Speechiness\": 0.038, \"Acousticness\": 0.00334, \"Liveness\": 0.0632, \"Tempo\": 123.036, \"Duration (ms)\": 177600.0, \"Valence\": 0.323, \"Chord\": \"B\"}, {\"Index\": 1130, \"Highest Charting Position\": 58, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Free Woman\", \"Streams\": 9266945, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"4L6ihclQPu1hqP9r3WNJjQ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 63.0, \"Danceability\": 0.731, \"Energy\": 0.927, \"Loudness\": -3.634, \"Speechiness\": 0.0781, \"Acousticness\": 0.0228, \"Liveness\": 0.187, \"Tempo\": 119.006, \"Duration (ms)\": 191467.0, \"Valence\": 0.478, \"Chord\": \"C\"}, {\"Index\": 1131, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Fun Tonight\", \"Streams\": 7907329, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"6hyQVqfHFvsJDjcmj4qrHf\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.645, \"Energy\": 0.923, \"Loudness\": -4.262, \"Speechiness\": 0.0725, \"Acousticness\": 0.364, \"Liveness\": 0.14, \"Tempo\": 117.945, \"Duration (ms)\": 173427.0, \"Valence\": 0.323, \"Chord\": \"B\"}, {\"Index\": 1132, \"Highest Charting Position\": 75, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Sine From Above (with Elton John)\", \"Streams\": 7734309, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"0zzsyWc45eUcSjw4FNHxeN\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 60.0, \"Danceability\": 0.642, \"Energy\": 0.792, \"Loudness\": -5.746, \"Speechiness\": 0.0488, \"Acousticness\": 0.158, \"Liveness\": 0.68, \"Tempo\": 122.965, \"Duration (ms)\": 244880.0, \"Valence\": 0.0903, \"Chord\": \"C\"}, {\"Index\": 1133, \"Highest Charting Position\": 77, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Enigma\", \"Streams\": 7695566, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"7JDbfYUHjDzQPFSDh5lzGs\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 59.0, \"Danceability\": 0.669, \"Energy\": 0.804, \"Loudness\": -4.035, \"Speechiness\": 0.036, \"Acousticness\": 0.0306, \"Liveness\": 0.694, \"Tempo\": 116.001, \"Duration (ms)\": 179760.0, \"Valence\": 0.184, \"Chord\": \"C\"}, {\"Index\": 1134, \"Highest Charting Position\": 79, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Replay\", \"Streams\": 7479618, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"7sKbyYeJnITO1Eh9xd0lKd\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 63.0, \"Danceability\": 0.658, \"Energy\": 0.878, \"Loudness\": -3.875, \"Speechiness\": 0.123, \"Acousticness\": 0.00792, \"Liveness\": 0.944, \"Tempo\": 122.015, \"Duration (ms)\": 186653.0, \"Valence\": 0.683, \"Chord\": \"C#/Db\"}, {\"Index\": 1135, \"Highest Charting Position\": 80, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Plastic Doll\", \"Streams\": 7451452, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"3CidPLqWXqgesJlwYVJZdy\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.743, \"Energy\": 0.853, \"Loudness\": -4.842, \"Speechiness\": 0.04, \"Acousticness\": 0.0019, \"Liveness\": 0.0872, \"Tempo\": 121.028, \"Duration (ms)\": 221667.0, \"Valence\": 0.422, \"Chord\": \"C\"}, {\"Index\": 1136, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Chromatica II\", \"Streams\": 7136521, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"0oQc0F6KUE7QY7k5TU6bic\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.184, \"Energy\": 0.297, \"Loudness\": -14.534, \"Speechiness\": 0.0359, \"Acousticness\": 0.473, \"Liveness\": 0.527, \"Tempo\": 75.824, \"Duration (ms)\": 41867.0, \"Valence\": 0.113, \"Chord\": \"D\"}, {\"Index\": 1137, \"Highest Charting Position\": 91, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Babylon\", \"Streams\": 6996402, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"5DttNeiizFqWUON9hZBqTY\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 61.0, \"Danceability\": 0.698, \"Energy\": 0.799, \"Loudness\": -4.372, \"Speechiness\": 0.0342, \"Acousticness\": 0.0129, \"Liveness\": 0.215, \"Tempo\": 115.957, \"Duration (ms)\": 161733.0, \"Valence\": 0.351, \"Chord\": \"D\"}, {\"Index\": 1138, \"Highest Charting Position\": 93, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Chromatica I\", \"Streams\": 6630385, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"0oQc0F6KUE7QY7k5TU6bic\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.184, \"Energy\": 0.297, \"Loudness\": -14.534, \"Speechiness\": 0.0359, \"Acousticness\": 0.473, \"Liveness\": 0.527, \"Tempo\": 75.824, \"Duration (ms)\": 41867.0, \"Valence\": 0.113, \"Chord\": \"D\"}, {\"Index\": 1139, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"1000 Doves\", \"Streams\": 6069544, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"62hTXlVQacy3pjBW4ntRPl\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.668, \"Energy\": 0.826, \"Loudness\": -4.466, \"Speechiness\": 0.0383, \"Acousticness\": 0.0236, \"Liveness\": 0.474, \"Tempo\": 122.973, \"Duration (ms)\": 215480.0, \"Valence\": 0.388, \"Chord\": \"A\"}, {\"Index\": 1151, \"Highest Charting Position\": 90, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"In Your Eyes (with Doja Cat) - Remix\", \"Streams\": 6511008, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"0UnTaVkntyh3vqvLEvbpQx\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-05-21\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 67.0, \"Danceability\": 0.679, \"Energy\": 0.731, \"Loudness\": -5.522, \"Speechiness\": 0.0319, \"Acousticness\": 0.00518, \"Liveness\": 0.0614, \"Tempo\": 99.984, \"Duration (ms)\": 237912.0, \"Valence\": 0.727, \"Chord\": \"G\"}, {\"Index\": 1164, \"Highest Charting Position\": 7, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"After Hours\", \"Streams\": 4559855, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"2p8IUWQDrpjuFltbdgLOag\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 75.0, \"Danceability\": 0.664, \"Energy\": 0.572, \"Loudness\": -6.099, \"Speechiness\": 0.0305, \"Acousticness\": 0.0811, \"Liveness\": 0.121, \"Tempo\": 108.959, \"Duration (ms)\": 361027.0, \"Valence\": 0.143, \"Chord\": \"F\"}, {\"Index\": 1172, \"Highest Charting Position\": 12, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Pain 1993 (with Playboi Carti)\", \"Streams\": 6085143, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"6Kj17Afjo1OKJYpf5VzCeo\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 67.0, \"Danceability\": 0.825, \"Energy\": 0.373, \"Loudness\": -5.532, \"Speechiness\": 0.108, \"Acousticness\": 0.163, \"Liveness\": 0.368, \"Tempo\": 77.271, \"Duration (ms)\": 149078.0, \"Valence\": 0.12, \"Chord\": \"F\"}, {\"Index\": 1178, \"Highest Charting Position\": 82, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"BENDICIONES\", \"Streams\": 4639997, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2CoMYp2uIKsT09nreEZnZn\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 67.0, \"Danceability\": 0.828, \"Energy\": 0.581, \"Loudness\": -9.909, \"Speechiness\": 0.0725, \"Acousticness\": 0.0378, \"Liveness\": 0.103, \"Tempo\": 143.995, \"Duration (ms)\": 155060.0, \"Valence\": 0.843, \"Chord\": \"B\"}, {\"Index\": 1182, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"SI ELLA SALE\", \"Streams\": 7055918, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"1zaDh3qaGSeSmulNyWlUxm\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 63.0, \"Danceability\": 0.869, \"Energy\": 0.727, \"Loudness\": -7.397, \"Speechiness\": 0.123, \"Acousticness\": 0.0589, \"Liveness\": 0.107, \"Tempo\": 147.967, \"Duration (ms)\": 143240.0, \"Valence\": 0.92, \"Chord\": \"G\"}, {\"Index\": 1183, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"RONCA FREESTYLE\", \"Streams\": 5784075, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3XZeOzJ9tqnu58YP6cqApI\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 64.0, \"Danceability\": 0.856, \"Energy\": 0.656, \"Loudness\": -6.483, \"Speechiness\": 0.131, \"Acousticness\": 0.165, \"Liveness\": 0.0998, \"Tempo\": 90.041, \"Duration (ms)\": 150060.0, \"Valence\": 0.586, \"Chord\": \"F\"}, {\"Index\": 1188, \"Highest Charting Position\": 52, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"A Tu Merced\", \"Streams\": 4909499, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4r9jkMEnArtWGH2rL2FZl0\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 82.0, \"Danceability\": 0.86, \"Energy\": 0.791, \"Loudness\": -4.784, \"Speechiness\": 0.0568, \"Acousticness\": 0.169, \"Liveness\": 0.106, \"Tempo\": 92.023, \"Duration (ms)\": 175918.0, \"Valence\": 0.887, \"Chord\": \"C\"}, {\"Index\": 1189, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Demons (feat. Fivio Foreign & Sosa Geek)\", \"Streams\": 4766829, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"05aZ9sAU1YXndHv0FMi9iW\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 63.0, \"Danceability\": 0.543, \"Energy\": 0.766, \"Loudness\": -3.387, \"Speechiness\": 0.343, \"Acousticness\": 0.423, \"Liveness\": 0.155, \"Tempo\": 106.869, \"Duration (ms)\": 204805.0, \"Valence\": 0.729, \"Chord\": \"C\"}, {\"Index\": 1196, \"Highest Charting Position\": 4, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"No Time To Die\", \"Streams\": 4293009, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"73SpzrcaHk0RQPFP73vqVR\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2020-02-13\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 75.0, \"Danceability\": 0.38, \"Energy\": 0.219, \"Loudness\": -13.273, \"Speechiness\": 0.0358, \"Acousticness\": 0.917, \"Liveness\": 0.0827, \"Tempo\": 73.537, \"Duration (ms)\": 242265.0, \"Valence\": 0.0517, \"Chord\": \"E\"}, {\"Index\": 1198, \"Highest Charting Position\": 51, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Time Flies\", \"Streams\": 9904749, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5H4mXWKcicuLKDn4Jy0sK7\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 71.0, \"Danceability\": 0.864, \"Energy\": 0.477, \"Loudness\": -5.786, \"Speechiness\": 0.224, \"Acousticness\": 0.201, \"Liveness\": 0.182, \"Tempo\": 86.46, \"Duration (ms)\": 192932.0, \"Valence\": 0.5, \"Chord\": \"A#/Bb\"}, {\"Index\": 1199, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Desires (with Future)\", \"Streams\": 9628215, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"7eYAHC0RbBF9eaqWzT34Aq\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.812, \"Energy\": 0.506, \"Loudness\": -7.706, \"Speechiness\": 0.116, \"Acousticness\": 0.281, \"Liveness\": 0.325, \"Tempo\": 145.074, \"Duration (ms)\": 237946.0, \"Valence\": 0.554, \"Chord\": \"F\"}, {\"Index\": 1200, \"Highest Charting Position\": 55, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Not You Too (feat. Chris Brown)\", \"Streams\": 9284383, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"3Q4gttWQ6hxqWOa3tHoTNi\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.458, \"Energy\": 0.452, \"Loudness\": -9.299, \"Speechiness\": 0.047, \"Acousticness\": 0.342, \"Liveness\": 0.0703, \"Tempo\": 86.318, \"Duration (ms)\": 269680.0, \"Valence\": 0.316, \"Chord\": \"A\"}, {\"Index\": 1201, \"Highest Charting Position\": 67, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Landed\", \"Streams\": 8355036, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"3KixNgUEaDtrKJVzdqjU5q\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 60.0, \"Danceability\": 0.881, \"Energy\": 0.636, \"Loudness\": -4.629, \"Speechiness\": 0.287, \"Acousticness\": 0.00606, \"Liveness\": 0.111, \"Tempo\": 163.949, \"Duration (ms)\": 152195.0, \"Valence\": 0.715, \"Chord\": \"G\"}, {\"Index\": 1202, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"When To Say When\", \"Streams\": 8304928, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5TCBWmEBrin7etRa4Lswr1\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 60.0, \"Danceability\": 0.41, \"Energy\": 0.82, \"Loudness\": -6.808, \"Speechiness\": 0.533, \"Acousticness\": 0.252, \"Liveness\": 0.538, \"Tempo\": 170.718, \"Duration (ms)\": 223124.0, \"Valence\": 0.526, \"Chord\": \"C#/Db\"}, {\"Index\": 1203, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Deep Pockets\", \"Streams\": 8285754, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"3IvMYBE7A3c7to1aEcfFJk\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 58.0, \"Danceability\": 0.473, \"Energy\": 0.824, \"Loudness\": -3.68, \"Speechiness\": 0.163, \"Acousticness\": 0.482, \"Liveness\": 0.605, \"Tempo\": 77.888, \"Duration (ms)\": 222929.0, \"Valence\": 0.374, \"Chord\": \"G\"}, {\"Index\": 1204, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"War\", \"Streams\": 7821869, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"1I55Ea0zVoSKs6MqW7DQ3i\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.749, \"Energy\": 0.792, \"Loudness\": -4.151, \"Speechiness\": 0.0826, \"Acousticness\": 0.292, \"Liveness\": 0.109, \"Tempo\": 144.064, \"Duration (ms)\": 180000.0, \"Valence\": 0.239, \"Chord\": \"A#/Bb\"}, {\"Index\": 1205, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"From Florida With Love\", \"Streams\": 7216610, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"0YkUwXxnTkeJBvt5upeEtP\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.787, \"Energy\": 0.477, \"Loudness\": -7.837, \"Speechiness\": 0.199, \"Acousticness\": 0.768, \"Liveness\": 0.104, \"Tempo\": 80.506, \"Duration (ms)\": 234783.0, \"Valence\": 0.476, \"Chord\": \"F#/Gb\"}, {\"Index\": 1206, \"Highest Charting Position\": 89, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Losses\", \"Streams\": 6894756, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"6fLVTVaHWaEfVKfEgbkf4D\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 57.0, \"Danceability\": 0.551, \"Energy\": 0.57, \"Loudness\": -7.385, \"Speechiness\": 0.351, \"Acousticness\": 0.28, \"Liveness\": 0.424, \"Tempo\": 85.687, \"Duration (ms)\": 271184.0, \"Valence\": 0.505, \"Chord\": \"C#/Db\"}, {\"Index\": 1208, \"Highest Charting Position\": 40, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Boyfriend\", \"Streams\": 5236730, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4QnC1bIaMSfDQvF4XDhV5M\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 62.0, \"Danceability\": 0.811, \"Energy\": 0.512, \"Loudness\": -6.381, \"Speechiness\": 0.17, \"Acousticness\": 0.218, \"Liveness\": 0.0768, \"Tempo\": 92.046, \"Duration (ms)\": 161188.0, \"Valence\": 0.346, \"Chord\": \"D\"}, {\"Index\": 1211, \"Highest Charting Position\": 32, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"FIND MY WAY\", \"Streams\": 4753495, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"1gVCEnryJhkdQcuC0Kbvor\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 66.0, \"Danceability\": 0.836, \"Energy\": 0.624, \"Loudness\": -6.75, \"Speechiness\": 0.184, \"Acousticness\": 0.187, \"Liveness\": 0.138, \"Tempo\": 103.0, \"Duration (ms)\": 139890.0, \"Valence\": 0.7, \"Chord\": \"E\"}, {\"Index\": 1213, \"Highest Charting Position\": 130, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"God's Plan\", \"Streams\": 4565400, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"6DCZcSspjsKoFjzjrWoCdn\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2018-06-29\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.754, \"Energy\": 0.449, \"Loudness\": -9.211, \"Speechiness\": 0.109, \"Acousticness\": 0.0332, \"Liveness\": 0.552, \"Tempo\": 77.169, \"Duration (ms)\": 198973.0, \"Valence\": 0.357, \"Chord\": \"G\"}, {\"Index\": 1222, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Sasuke\", \"Streams\": 4701551, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"0ROE31C8Wu4neZoR9stM9e\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 56.0, \"Danceability\": 0.859, \"Energy\": 0.477, \"Loudness\": -6.116, \"Speechiness\": 0.428, \"Acousticness\": 0.00414, \"Liveness\": 0.0819, \"Tempo\": 145.979, \"Duration (ms)\": 251336.0, \"Valence\": 0.153, \"Chord\": \"C#/Db\"}, {\"Index\": 1230, \"Highest Charting Position\": 78, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"PICK UP (feat. Quavo)\", \"Streams\": 7065060, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"5gNOINI5dXZVom2b36LMOd\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 65.0, \"Danceability\": 0.915, \"Energy\": 0.612, \"Loudness\": -4.535, \"Speechiness\": 0.407, \"Acousticness\": 0.0944, \"Liveness\": 0.115, \"Tempo\": 129.93, \"Duration (ms)\": 118547.0, \"Valence\": 0.758, \"Chord\": \"C#/Db\"}, {\"Index\": 1231, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"JUMP (feat. YoungBoy Never Broke Again)\", \"Streams\": 6033348, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"0oT9ElXYSxvnOOagP9efDq\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 62.0, \"Danceability\": 0.896, \"Energy\": 0.72, \"Loudness\": -6.262, \"Speechiness\": 0.355, \"Acousticness\": 0.169, \"Liveness\": 0.252, \"Tempo\": 140.1, \"Duration (ms)\": 212093.0, \"Valence\": 0.966, \"Chord\": \"C\"}, {\"Index\": 1232, \"Highest Charting Position\": 156, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"LIGHTSKIN SH*T (feat. Future & jetsonmade)\", \"Streams\": 4861875, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"16oi4OiKmkO51l60F5R9kR\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 56.0, \"Danceability\": 0.932, \"Energy\": 0.578, \"Loudness\": -4.478, \"Speechiness\": 0.366, \"Acousticness\": 0.115, \"Liveness\": 0.115, \"Tempo\": 129.991, \"Duration (ms)\": 111173.0, \"Valence\": 0.623, \"Chord\": \"A\"}, {\"Index\": 1233, \"Highest Charting Position\": 16, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"That Way - Bonus Track\", \"Streams\": 4825741, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2ajzBr7vwHTEBeqDzcsNRC\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.712, \"Energy\": 0.598, \"Loudness\": -5.368, \"Speechiness\": 0.0388, \"Acousticness\": 0.0546, \"Liveness\": 0.154, \"Tempo\": 130.007, \"Duration (ms)\": 212354.0, \"Valence\": 0.504, \"Chord\": \"G\"}, {\"Index\": 1237, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"BLAME IT ON BABY\", \"Streams\": 4616034, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"0jWm0VyD8p3MrSInczpows\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 57.0, \"Danceability\": 0.875, \"Energy\": 0.687, \"Loudness\": -5.734, \"Speechiness\": 0.387, \"Acousticness\": 0.236, \"Liveness\": 0.141, \"Tempo\": 109.791, \"Duration (ms)\": 125907.0, \"Valence\": 0.864, \"Chord\": \"A\"}, {\"Index\": 1252, \"Highest Charting Position\": 15, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Forever (feat. Post Malone & Clever)\", \"Streams\": 6517807, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2ZlCGeK30BLRNSPC832pNZ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 68.0, \"Danceability\": 0.825, \"Energy\": 0.483, \"Loudness\": -5.746, \"Speechiness\": 0.08, \"Acousticness\": 0.538, \"Liveness\": 0.204, \"Tempo\": 139.98, \"Duration (ms)\": 219933.0, \"Valence\": 0.892, \"Chord\": \"G#/Ab\"}, {\"Index\": 1255, \"Highest Charting Position\": 29, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Pero Ya No\", \"Streams\": 4666658, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"75pQqzwgCjUOSSy5CpmAjy\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 72.0, \"Danceability\": 0.882, \"Energy\": 0.612, \"Loudness\": -6.103, \"Speechiness\": 0.118, \"Acousticness\": 0.0475, \"Liveness\": 0.182, \"Tempo\": 147.982, \"Duration (ms)\": 160638.0, \"Valence\": 0.742, \"Chord\": \"E\"}, {\"Index\": 1256, \"Highest Charting Position\": 24, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Hardest To Love\", \"Streams\": 4553544, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"6kWxIqQDsKFYCJGbU4AjCX\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.467, \"Energy\": 0.608, \"Loudness\": -7.847, \"Speechiness\": 0.0707, \"Acousticness\": 0.0909, \"Liveness\": 0.125, \"Tempo\": 80.957, \"Duration (ms)\": 211400.0, \"Valence\": 0.108, \"Chord\": \"A#/Bb\"}, {\"Index\": 1259, \"Highest Charting Position\": 69, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Pretty Please\", \"Streams\": 4305034, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"6DXZiYUbrYgrVIhfX3U9Z2\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 67.0, \"Danceability\": 0.906, \"Energy\": 0.474, \"Loudness\": -6.124, \"Speechiness\": 0.194, \"Acousticness\": 0.0311, \"Liveness\": 0.286, \"Tempo\": 106.976, \"Duration (ms)\": 194607.0, \"Valence\": 0.656, \"Chord\": \"C#/Db\"}, {\"Index\": 1261, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Cool\", \"Streams\": 8136247, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"4Ulqu89XempybuL8ApUeqL\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.469, \"Energy\": 0.785, \"Loudness\": -4.015, \"Speechiness\": 0.0664, \"Acousticness\": 0.133, \"Liveness\": 0.0931, \"Tempo\": 89.719, \"Duration (ms)\": 209583.0, \"Valence\": 0.79, \"Chord\": \"F\"}, {\"Index\": 1262, \"Highest Charting Position\": 71, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Future Nostalgia\", \"Streams\": 8091754, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3iYNJX4FTRGlfMQySjlGNr\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.875, \"Energy\": 0.813, \"Loudness\": -4.502, \"Speechiness\": 0.0579, \"Acousticness\": 0.00618, \"Liveness\": 0.321, \"Tempo\": 114.993, \"Duration (ms)\": 184882.0, \"Valence\": 0.859, \"Chord\": \"G\"}, {\"Index\": 1263, \"Highest Charting Position\": 92, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Good In Bed\", \"Streams\": 6802068, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3pyodt4pb554dMz8fCv7oi\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 64.0, \"Danceability\": 0.68, \"Energy\": 0.701, \"Loudness\": -5.001, \"Speechiness\": 0.0917, \"Acousticness\": 0.138, \"Liveness\": 0.168, \"Tempo\": 94.06, \"Duration (ms)\": 218754.0, \"Valence\": 0.649, \"Chord\": \"F\"}, {\"Index\": 1264, \"Highest Charting Position\": 27, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Scared To Live\", \"Streams\": 6566099, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"4BGZF4oLbTL0pWm7C18pbv\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 66.0, \"Danceability\": 0.504, \"Energy\": 0.498, \"Loudness\": -8.24, \"Speechiness\": 0.0499, \"Acousticness\": 0.131, \"Liveness\": 0.0929, \"Tempo\": 87.221, \"Duration (ms)\": 191307.0, \"Valence\": 0.196, \"Chord\": \"C\"}, {\"Index\": 1265, \"Highest Charting Position\": 21, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Alone Again\", \"Streams\": 6055294, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"6b5P51m8xx2XA6U7sdNZ5E\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 66.0, \"Danceability\": 0.218, \"Energy\": 0.652, \"Loudness\": -7.953, \"Speechiness\": 0.0641, \"Acousticness\": 0.033, \"Liveness\": 0.172, \"Tempo\": 65.375, \"Duration (ms)\": 250053.0, \"Valence\": 0.0599, \"Chord\": \"E\"}, {\"Index\": 1266, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Boys Will Be Boys\", \"Streams\": 6015914, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"4szI7zRh7kLApCSqiB6R7b\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 63.0, \"Danceability\": 0.768, \"Energy\": 0.486, \"Loudness\": -5.954, \"Speechiness\": 0.0353, \"Acousticness\": 0.408, \"Liveness\": 0.098, \"Tempo\": 125.021, \"Duration (ms)\": 166266.0, \"Valence\": 0.519, \"Chord\": \"D#/Eb\"}, {\"Index\": 1269, \"Highest Charting Position\": 28, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Too Late\", \"Streams\": 5867746, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"2K9Ovn1o2bTGqbsABGC6m3\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.638, \"Energy\": 0.863, \"Loudness\": -5.221, \"Speechiness\": 0.132, \"Acousticness\": 0.052, \"Liveness\": 0.685, \"Tempo\": 120.077, \"Duration (ms)\": 239973.0, \"Valence\": 0.226, \"Chord\": \"E\"}, {\"Index\": 1271, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Faith\", \"Streams\": 5730081, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"3orEOtd8CPL8GFlpRpKuoE\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.375, \"Energy\": 0.605, \"Loudness\": -7.268, \"Speechiness\": 0.0729, \"Acousticness\": 0.612, \"Liveness\": 0.147, \"Tempo\": 175.946, \"Duration (ms)\": 283227.0, \"Valence\": 0.128, \"Chord\": \"C\"}, {\"Index\": 1272, \"Highest Charting Position\": 35, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Snowchild\", \"Streams\": 5423997, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"3WlbeuhfRSqU7ylK2Ui5U7\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 66.0, \"Danceability\": 0.55, \"Energy\": 0.611, \"Loudness\": -7.475, \"Speechiness\": 0.137, \"Acousticness\": 0.162, \"Liveness\": 0.121, \"Tempo\": 148.062, \"Duration (ms)\": 247187.0, \"Valence\": 0.243, \"Chord\": \"C\"}, {\"Index\": 1273, \"Highest Charting Position\": 37, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Escape From LA\", \"Streams\": 5307288, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"1sOW4PuG5X3Ie3EXUhAopJ\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.404, \"Energy\": 0.524, \"Loudness\": -8.996, \"Speechiness\": 0.0593, \"Acousticness\": 0.0456, \"Liveness\": 0.199, \"Tempo\": 145.74, \"Duration (ms)\": 355960.0, \"Valence\": 0.168, \"Chord\": \"F\"}, {\"Index\": 1279, \"Highest Charting Position\": 51, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Repeat After Me (Interlude)\", \"Streams\": 10058303, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"40U8d12pC5UHqmHwXjHjjl\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 63.0, \"Danceability\": 0.555, \"Energy\": 0.619, \"Loudness\": -7.918, \"Speechiness\": 0.0314, \"Acousticness\": 0.0323, \"Liveness\": 0.0917, \"Tempo\": 95.032, \"Duration (ms)\": 195813.0, \"Valence\": 0.141, \"Chord\": \"C\"}, {\"Index\": 1280, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Until I Bleed Out\", \"Streams\": 9132077, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"2BcnxwxBuar5wjCaLqm5N3\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 63.0, \"Danceability\": 0.245, \"Energy\": 0.394, \"Loudness\": -9.887, \"Speechiness\": 0.0374, \"Acousticness\": 0.423, \"Liveness\": 0.093, \"Tempo\": 115.233, \"Duration (ms)\": 190173.0, \"Valence\": 0.148, \"Chord\": \"C\"}, {\"Index\": 1285, \"Highest Charting Position\": 15, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Baby Pluto\", \"Streams\": 5600261, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7hav1MHURQf5SAoPk0egqh\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 69.0, \"Danceability\": 0.772, \"Energy\": 0.634, \"Loudness\": -6.101, \"Speechiness\": 0.212, \"Acousticness\": 0.135, \"Liveness\": 0.432, \"Tempo\": 160.052, \"Duration (ms)\": 210261.0, \"Valence\": 0.671, \"Chord\": \"A#/Bb\"}, {\"Index\": 1286, \"Highest Charting Position\": 31, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Lo Mein\", \"Streams\": 5231134, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"6CUP2khYzdphXebxVTfPE3\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.855, \"Energy\": 0.676, \"Loudness\": -5.736, \"Speechiness\": 0.325, \"Acousticness\": 0.0888, \"Liveness\": 0.144, \"Tempo\": 133.082, \"Duration (ms)\": 195299.0, \"Valence\": 0.509, \"Chord\": \"C#/Db\"}, {\"Index\": 1288, \"Highest Charting Position\": 57, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Futsal Shuffle 2020 - Bonus Track\", \"Streams\": 5068849, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2fOlBMkWR7lXJfqp5VTbDG\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 63.0, \"Danceability\": 0.879, \"Energy\": 0.448, \"Loudness\": -8.57, \"Speechiness\": 0.222, \"Acousticness\": 0.0346, \"Liveness\": 0.224, \"Tempo\": 136.985, \"Duration (ms)\": 198913.0, \"Valence\": 0.278, \"Chord\": \"G\"}, {\"Index\": 1290, \"Highest Charting Position\": 65, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"TOES (feat. Lil Baby & Moneybagg Yo)\", \"Streams\": 4878903, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"2FvD20Z8aoWIePi7PoN8sG\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 73.0, \"Danceability\": 0.816, \"Energy\": 0.582, \"Loudness\": -4.141, \"Speechiness\": 0.341, \"Acousticness\": 0.0794, \"Liveness\": 0.0916, \"Tempo\": 160.004, \"Duration (ms)\": 136366.0, \"Valence\": 0.542, \"Chord\": \"G#/Ab\"}, {\"Index\": 1291, \"Highest Charting Position\": 42, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Feel Me\", \"Streams\": 4765672, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"6XXYdF6pJR1K3wKvuxmu7n\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 63.0, \"Danceability\": 0.71, \"Energy\": 0.808, \"Loudness\": -6.703, \"Speechiness\": 0.0433, \"Acousticness\": 0.44, \"Liveness\": 0.0734, \"Tempo\": 99.989, \"Duration (ms)\": 226003.0, \"Valence\": 0.392, \"Chord\": \"D\"}, {\"Index\": 1293, \"Highest Charting Position\": 63, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"25/8\", \"Streams\": 4684378, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4NqQaovM14WR2hNPMFxgjb\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 71.0, \"Danceability\": 0.761, \"Energy\": 0.732, \"Loudness\": -5.469, \"Speechiness\": 0.0549, \"Acousticness\": 0.092, \"Liveness\": 0.0716, \"Tempo\": 151.982, \"Duration (ms)\": 243276.0, \"Valence\": 0.542, \"Chord\": \"E\"}, {\"Index\": 1296, \"Highest Charting Position\": 45, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Soli\\u00e1\", \"Streams\": 4516243, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"7sOfmPd18RWp3FoCzpa7Kw\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 72.0, \"Danceability\": 0.71, \"Energy\": 0.81, \"Loudness\": -5.507, \"Speechiness\": 0.0854, \"Acousticness\": 0.117, \"Liveness\": 0.154, \"Tempo\": 92.041, \"Duration (ms)\": 159282.0, \"Valence\": 0.184, \"Chord\": \"D\"}, {\"Index\": 1298, \"Highest Charting Position\": 61, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Bean (Kobe) [feat. Chief Keef]\", \"Streams\": 9039518, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"0IpnZchq8ek2A6pGEP2Qb1\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 67.0, \"Danceability\": 0.733, \"Energy\": 0.567, \"Loudness\": -6.718, \"Speechiness\": 0.319, \"Acousticness\": 0.0129, \"Liveness\": 0.382, \"Tempo\": 75.491, \"Duration (ms)\": 238816.0, \"Valence\": 0.319, \"Chord\": \"C\"}, {\"Index\": 1301, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Silly Watch\", \"Streams\": 6442451, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"5egD7A5x9AHdVO2fMo3Wbo\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 65.0, \"Danceability\": 0.903, \"Energy\": 0.535, \"Loudness\": -6.238, \"Speechiness\": 0.286, \"Acousticness\": 0.0298, \"Liveness\": 0.0851, \"Tempo\": 130.117, \"Duration (ms)\": 195692.0, \"Valence\": 0.157, \"Chord\": \"G#/Ab\"}, {\"Index\": 1303, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Lotus\", \"Streams\": 6017103, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4SnlSaLJJ7reJMCHM5YUuX\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 58.0, \"Danceability\": 0.802, \"Energy\": 0.748, \"Loudness\": -5.708, \"Speechiness\": 0.207, \"Acousticness\": 0.24, \"Liveness\": 0.165, \"Tempo\": 150.063, \"Duration (ms)\": 193861.0, \"Valence\": 0.516, \"Chord\": \"G#/Ab\"}, {\"Index\": 1306, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Leaders (feat. NAV)\", \"Streams\": 5496780, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4D7NrSeqkTarBrJ80b2sBc\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 60.0, \"Danceability\": 0.95, \"Energy\": 0.654, \"Loudness\": -5.895, \"Speechiness\": 0.307, \"Acousticness\": 0.0744, \"Liveness\": 0.138, \"Tempo\": 132.936, \"Duration (ms)\": 194844.0, \"Valence\": 0.886, \"Chord\": \"C\"}, {\"Index\": 1307, \"Highest Charting Position\": 149, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Strawberry Peels (feat. Young Thug & Gunna)\", \"Streams\": 5468083, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4lAQfuREAHG8IC0PiiigBt\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 59.0, \"Danceability\": 0.862, \"Energy\": 0.65, \"Loudness\": -6.978, \"Speechiness\": 0.355, \"Acousticness\": 0.0207, \"Liveness\": 0.568, \"Tempo\": 131.194, \"Duration (ms)\": 115350.0, \"Valence\": 0.658, \"Chord\": \"A#/Bb\"}, {\"Index\": 1308, \"Highest Charting Position\": 60, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"La Zona\", \"Streams\": 5440382, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5kqNIqFjijuzvVLhuY9B8j\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.762, \"Energy\": 0.801, \"Loudness\": -3.661, \"Speechiness\": 0.0409, \"Acousticness\": 0.2, \"Liveness\": 0.254, \"Tempo\": 93.992, \"Duration (ms)\": 136893.0, \"Valence\": 0.81, \"Chord\": \"C#/Db\"}, {\"Index\": 1309, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Wassup (feat. Future)\", \"Streams\": 5415044, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"19Ec2gbNtQTE44IizcPjtD\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 57.0, \"Danceability\": 0.762, \"Energy\": 0.622, \"Loudness\": -6.293, \"Speechiness\": 0.223, \"Acousticness\": 0.352, \"Liveness\": 0.145, \"Tempo\": 130.019, \"Duration (ms)\": 193314.0, \"Valence\": 0.626, \"Chord\": \"F\"}, {\"Index\": 1311, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Moon Relate\", \"Streams\": 5324545, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4sWGHlZGM1XA7TyWdtBAbA\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 58.0, \"Danceability\": 0.867, \"Energy\": 0.768, \"Loudness\": -3.73, \"Speechiness\": 0.0791, \"Acousticness\": 0.18, \"Liveness\": 0.254, \"Tempo\": 102.021, \"Duration (ms)\": 181826.0, \"Valence\": 0.34, \"Chord\": \"G\"}, {\"Index\": 1316, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Trap This Way (This Way)\", \"Streams\": 5043990, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7vTspUAmMKFkUpKL9HLZNL\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 59.0, \"Danceability\": 0.71, \"Energy\": 0.586, \"Loudness\": -5.331, \"Speechiness\": 0.381, \"Acousticness\": 0.248, \"Liveness\": 0.193, \"Tempo\": 175.987, \"Duration (ms)\": 185439.0, \"Valence\": 0.207, \"Chord\": \"D\"}, {\"Index\": 1318, \"Highest Charting Position\": 51, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Homecoming\", \"Streams\": 4988839, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"6vxU64pcIuQ38O015Zy4qj\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 63.0, \"Danceability\": 0.929, \"Energy\": 0.563, \"Loudness\": -7.428, \"Speechiness\": 0.49, \"Acousticness\": 0.000592, \"Liveness\": 0.244, \"Tempo\": 129.957, \"Duration (ms)\": 213885.0, \"Valence\": 0.353, \"Chord\": \"A\"}, {\"Index\": 1319, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Got The Guap (feat. Young Thug)\", \"Streams\": 4946997, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"1HF6P40Z7nfExGaB1Gk99v\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 58.0, \"Danceability\": 0.837, \"Energy\": 0.601, \"Loudness\": -5.628, \"Speechiness\": 0.198, \"Acousticness\": 0.21, \"Liveness\": 0.0928, \"Tempo\": 142.977, \"Duration (ms)\": 176756.0, \"Valence\": 0.749, \"Chord\": \"G#/Ab\"}, {\"Index\": 1320, \"Highest Charting Position\": 53, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Prices\", \"Streams\": 4898167, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4YcWzLSnGqLjSCycuSMHnn\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 65.0, \"Danceability\": 0.786, \"Energy\": 0.683, \"Loudness\": -5.397, \"Speechiness\": 0.205, \"Acousticness\": 0.173, \"Liveness\": 0.706, \"Tempo\": 126.002, \"Duration (ms)\": 233333.0, \"Valence\": 0.57, \"Chord\": \"G\"}, {\"Index\": 1321, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"I Can Show You\", \"Streams\": 4831405, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"0AhJag7VI8uFf3mJFsTwvf\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 57.0, \"Danceability\": 0.817, \"Energy\": 0.656, \"Loudness\": -7.086, \"Speechiness\": 0.277, \"Acousticness\": 0.051, \"Liveness\": 0.115, \"Tempo\": 139.915, \"Duration (ms)\": 120076.0, \"Valence\": 0.314, \"Chord\": \"A#/Bb\"}, {\"Index\": 1322, \"Highest Charting Position\": 52, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"I'm Sorry\", \"Streams\": 4818039, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"1xcOYJxDa5pObgxY1r0I9c\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 60.0, \"Danceability\": 0.858, \"Energy\": 0.547, \"Loudness\": -5.822, \"Speechiness\": 0.29, \"Acousticness\": 0.213, \"Liveness\": 0.104, \"Tempo\": 128.02, \"Duration (ms)\": 211883.0, \"Valence\": 0.303, \"Chord\": \"C#/Db\"}, {\"Index\": 1323, \"Highest Charting Position\": 19, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Black Swan\", \"Streams\": 4802069, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3bkkMZEAhx7rTVz1C0itRQ\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 70.0, \"Danceability\": 0.719, \"Energy\": 0.758, \"Loudness\": -5.167, \"Speechiness\": 0.0851, \"Acousticness\": 0.137, \"Liveness\": 0.129, \"Tempo\": 147.023, \"Duration (ms)\": 198261.0, \"Valence\": 0.49, \"Chord\": \"D\"}, {\"Index\": 1326, \"Highest Charting Position\": 66, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"<3\", \"Streams\": 4755477, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4MZSqgwlE71CWZ6qQ3gkKm\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.631, \"Energy\": 0.665, \"Loudness\": -7.589, \"Speechiness\": 0.229, \"Acousticness\": 0.602, \"Liveness\": 0.152, \"Tempo\": 80.353, \"Duration (ms)\": 157967.0, \"Valence\": 0.634, \"Chord\": \"A#/Bb\"}, {\"Index\": 1329, \"Highest Charting Position\": 60, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"POP\", \"Streams\": 10484727, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"1jDbQz6tr52WgScCTXMnaN\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 58.0, \"Danceability\": 0.741, \"Energy\": 0.599, \"Loudness\": -6.672, \"Speechiness\": 0.419, \"Acousticness\": 0.00961, \"Liveness\": 0.785, \"Tempo\": 139.891, \"Duration (ms)\": 227474.0, \"Valence\": 0.276, \"Chord\": \"C#/Db\"}, {\"Index\": 1330, \"Highest Charting Position\": 61, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Celebration Station\", \"Streams\": 10396969, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"25B5fGr9K0VdZJiRFsnMO4\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 61.0, \"Danceability\": 0.748, \"Energy\": 0.771, \"Loudness\": -4.156, \"Speechiness\": 0.15, \"Acousticness\": 0.101, \"Liveness\": 0.135, \"Tempo\": 142.086, \"Duration (ms)\": 195058.0, \"Valence\": 0.792, \"Chord\": \"F#/Gb\"}, {\"Index\": 1331, \"Highest Charting Position\": 64, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Bigger Than Life\", \"Streams\": 9974143, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2oHDJHNondITqbl8xZ9vPn\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 62.0, \"Danceability\": 0.776, \"Energy\": 0.752, \"Loudness\": -4.711, \"Speechiness\": 0.193, \"Acousticness\": 0.325, \"Liveness\": 0.33, \"Tempo\": 140.013, \"Duration (ms)\": 192705.0, \"Valence\": 0.716, \"Chord\": \"G#/Ab\"}, {\"Index\": 1332, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Venetia\", \"Streams\": 9824605, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"3BYIzNZ3t9lRQCACXSMLrT\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 63.0, \"Danceability\": 0.775, \"Energy\": 0.757, \"Loudness\": -4.139, \"Speechiness\": 0.175, \"Acousticness\": 0.162, \"Liveness\": 0.148, \"Tempo\": 142.933, \"Duration (ms)\": 188800.0, \"Valence\": 0.562, \"Chord\": \"A\"}, {\"Index\": 1333, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"You Better Move\", \"Streams\": 9533898, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"6YAxCn4juTWn5hWl2hzHGw\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 60.0, \"Danceability\": 0.842, \"Energy\": 0.556, \"Loudness\": -6.793, \"Speechiness\": 0.442, \"Acousticness\": 0.159, \"Liveness\": 0.204, \"Tempo\": 118.836, \"Duration (ms)\": 196639.0, \"Valence\": 0.306, \"Chord\": \"G#/Ab\"}, {\"Index\": 1334, \"Highest Charting Position\": 93, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Chrome Heart Tags\", \"Streams\": 8219307, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"46mT9NR7N9Zf5MolcrBgE3\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 57.0, \"Danceability\": 0.702, \"Energy\": 0.768, \"Loudness\": -4.055, \"Speechiness\": 0.0669, \"Acousticness\": 0.541, \"Liveness\": 0.105, \"Tempo\": 70.056, \"Duration (ms)\": 212821.0, \"Valence\": 0.574, \"Chord\": \"C\"}, {\"Index\": 1335, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Bust Me\", \"Streams\": 7828045, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4wBcaYqLPm7EtDVoJQORU4\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 57.0, \"Danceability\": 0.734, \"Energy\": 0.703, \"Loudness\": -6.256, \"Speechiness\": 0.355, \"Acousticness\": 0.237, \"Liveness\": 0.413, \"Tempo\": 151.923, \"Duration (ms)\": 194452.0, \"Valence\": 0.608, \"Chord\": \"B\"}, {\"Index\": 1337, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Secure The Bag\", \"Streams\": 7053947, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7gHZGXSJzM29WA384suYY2\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 57.0, \"Danceability\": 0.803, \"Energy\": 0.719, \"Loudness\": -4.485, \"Speechiness\": 0.392, \"Acousticness\": 0.344, \"Liveness\": 0.425, \"Tempo\": 129.945, \"Duration (ms)\": 238425.0, \"Valence\": 0.549, \"Chord\": \"C\"}, {\"Index\": 1338, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Urgency (feat. Syd)\", \"Streams\": 6224412, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"5KlPy74NOEAt8jC3FYURnQ\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 53.0, \"Danceability\": 0.619, \"Energy\": 0.784, \"Loudness\": -6.11, \"Speechiness\": 0.123, \"Acousticness\": 0.0326, \"Liveness\": 0.315, \"Tempo\": 156.035, \"Duration (ms)\": 181161.0, \"Valence\": 0.471, \"Chord\": \"C#/Db\"}, {\"Index\": 1339, \"Highest Charting Position\": 34, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"ON (Feat. Sia)\", \"Streams\": 6219276, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3IB5qOeMayvpOdHxYCL5tZ\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 64.0, \"Danceability\": 0.591, \"Energy\": 0.848, \"Loudness\": -4.397, \"Speechiness\": 0.0828, \"Acousticness\": 0.137, \"Liveness\": 0.372, \"Tempo\": 105.922, \"Duration (ms)\": 246816.0, \"Valence\": 0.386, \"Chord\": \"A\"}, {\"Index\": 1354, \"Highest Charting Position\": 12, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Rare\", \"Streams\": 5195842, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"7HMmFQsKsljwTw8bS7lu19\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 68.0, \"Danceability\": 0.838, \"Energy\": 0.545, \"Loudness\": -6.713, \"Speechiness\": 0.0706, \"Acousticness\": 0.208, \"Liveness\": 0.103, \"Tempo\": 114.998, \"Duration (ms)\": 220590.0, \"Valence\": 0.631, \"Chord\": \"F\"}, {\"Index\": 1355, \"Highest Charting Position\": 69, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"VIBEZ\", \"Streams\": 5121486, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"0fySG6A6qLE8IvDpayb5bM\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.768, \"Energy\": 0.652, \"Loudness\": -2.708, \"Speechiness\": 0.307, \"Acousticness\": 0.113, \"Liveness\": 0.107, \"Tempo\": 154.187, \"Duration (ms)\": 144935.0, \"Valence\": 0.777, \"Chord\": \"C#/Db\"}, {\"Index\": 1357, \"Highest Charting Position\": 49, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"That Way\", \"Streams\": 12059592, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"5raTDhlbxFDnpn89bxArdH\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-01\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 67.0, \"Danceability\": 0.719, \"Energy\": 0.611, \"Loudness\": -5.01, \"Speechiness\": 0.0403, \"Acousticness\": 0.0582, \"Liveness\": 0.155, \"Tempo\": 129.962, \"Duration (ms)\": 212354.0, \"Valence\": 0.489, \"Chord\": \"G\"}, {\"Index\": 1361, \"Highest Charting Position\": 47, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Filter\", \"Streams\": 5913946, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"0ono6UCNVZ1XqOm6j78Blu\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 79.0, \"Danceability\": 0.781, \"Energy\": 0.762, \"Loudness\": -5.188, \"Speechiness\": 0.0626, \"Acousticness\": 0.0222, \"Liveness\": 0.121, \"Tempo\": 110.042, \"Duration (ms)\": 180221.0, \"Valence\": 0.86, \"Chord\": \"A#/Bb\"}, {\"Index\": 1366, \"Highest Charting Position\": 32, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Futsal Shuffle 2020\", \"Streams\": 5386512, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2Ec33AVlkTTq8BHFgBTdQs\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-12\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.881, \"Energy\": 0.457, \"Loudness\": -8.191, \"Speechiness\": 0.156, \"Acousticness\": 0.0327, \"Liveness\": 0.231, \"Tempo\": 136.97, \"Duration (ms)\": 198913.0, \"Valence\": 0.296, \"Chord\": \"G\"}, {\"Index\": 1370, \"Highest Charting Position\": 58, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"My Time\", \"Streams\": 5212053, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4vTgx6h4seHvkuFh84JXYP\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 74.0, \"Danceability\": 0.674, \"Energy\": 0.64, \"Loudness\": -5.139, \"Speechiness\": 0.0339, \"Acousticness\": 0.151, \"Liveness\": 0.0925, \"Tempo\": 99.908, \"Duration (ms)\": 234458.0, \"Valence\": 0.664, \"Chord\": \"C\"}, {\"Index\": 1375, \"Highest Charting Position\": 140, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"You Need To Calm Down\", \"Streams\": 5115153, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6RRNNciQGZEXnqk8SQ9yv5\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.771, \"Energy\": 0.671, \"Loudness\": -5.617, \"Speechiness\": 0.0553, \"Acousticness\": 0.00929, \"Liveness\": 0.0637, \"Tempo\": 85.026, \"Duration (ms)\": 171360.0, \"Valence\": 0.714, \"Chord\": \"D\"}, {\"Index\": 1380, \"Highest Charting Position\": 91, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"bury a friend\", \"Streams\": 5020303, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"7p6ZK1vOxKELFwlDfwkJCp\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 1.0, \"Danceability\": 0.887, \"Energy\": 0.388, \"Loudness\": -14.505, \"Speechiness\": 0.349, \"Acousticness\": 0.739, \"Liveness\": 0.106, \"Tempo\": 120.035, \"Duration (ms)\": 193143.0, \"Valence\": 0.205, \"Chord\": \"G#/Ab\"}, {\"Index\": 1381, \"Highest Charting Position\": 54, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Louder than bombs\", \"Streams\": 10016907, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3op7HNwLli54MBjFGzIlZO\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.643, \"Energy\": 0.667, \"Loudness\": -6.993, \"Speechiness\": 0.152, \"Acousticness\": 0.0433, \"Liveness\": 0.0904, \"Tempo\": 145.999, \"Duration (ms)\": 217404.0, \"Valence\": 0.485, \"Chord\": \"C\"}, {\"Index\": 1382, \"Highest Charting Position\": 56, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"UGH!\", \"Streams\": 9991177, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"1aKuG1GG76xPLUkjBbQo3W\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.72, \"Energy\": 0.824, \"Loudness\": -5.086, \"Speechiness\": 0.128, \"Acousticness\": 0.0394, \"Liveness\": 0.0509, \"Tempo\": 165.998, \"Duration (ms)\": 225012.0, \"Valence\": 0.333, \"Chord\": \"A#/Bb\"}, {\"Index\": 1383, \"Highest Charting Position\": 67, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"00:00 (Zero O\\u2019Clock)\", \"Streams\": 9372219, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4AlihYDqxXshKhvh5tnMfP\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.566, \"Energy\": 0.548, \"Loudness\": -6.456, \"Speechiness\": 0.0579, \"Acousticness\": 0.0802, \"Liveness\": 0.11, \"Tempo\": 157.999, \"Duration (ms)\": 250296.0, \"Valence\": 0.196, \"Chord\": \"C#/Db\"}, {\"Index\": 1384, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Friends\", \"Streams\": 8822365, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"7w05lsU2VLSeiT8Nukrv5M\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.55, \"Energy\": 0.747, \"Loudness\": -5.211, \"Speechiness\": 0.0407, \"Acousticness\": 0.0668, \"Liveness\": 0.0536, \"Tempo\": 79.98, \"Duration (ms)\": 199339.0, \"Valence\": 0.648, \"Chord\": \"C#/Db\"}, {\"Index\": 1385, \"Highest Charting Position\": 75, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"We are Bulletproof : the Eternal\", \"Streams\": 8516710, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"44WLOqH7QayQOQdeUHeKUK\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.526, \"Energy\": 0.575, \"Loudness\": -5.215, \"Speechiness\": 0.0309, \"Acousticness\": 0.225, \"Liveness\": 0.108, \"Tempo\": 84.047, \"Duration (ms)\": 261543.0, \"Valence\": 0.19, \"Chord\": \"A\"}, {\"Index\": 1386, \"Highest Charting Position\": 79, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Inner Child\", \"Streams\": 8312399, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4BKOjYosPhw334moS3wlbO\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 71.0, \"Danceability\": 0.589, \"Energy\": 0.696, \"Loudness\": -7.981, \"Speechiness\": 0.0725, \"Acousticness\": 0.017, \"Liveness\": 0.0808, \"Tempo\": 134.953, \"Duration (ms)\": 233266.0, \"Valence\": 0.332, \"Chord\": \"B\"}, {\"Index\": 1387, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Moon\", \"Streams\": 7850129, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"1xfXXujIlLZAx5wpu46Nyk\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.703, \"Energy\": 0.646, \"Loudness\": -6.658, \"Speechiness\": 0.0596, \"Acousticness\": 0.0104, \"Liveness\": 0.191, \"Tempo\": 141.87, \"Duration (ms)\": 208590.0, \"Valence\": 0.64, \"Chord\": \"F#/Gb\"}, {\"Index\": 1388, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Outro : Ego\", \"Streams\": 6857808, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3r9FFjLrAIQjoR8pSHVPC9\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 69.0, \"Danceability\": 0.808, \"Energy\": 0.903, \"Loudness\": -3.106, \"Speechiness\": 0.0958, \"Acousticness\": 0.0121, \"Liveness\": 0.0993, \"Tempo\": 116.988, \"Duration (ms)\": 196199.0, \"Valence\": 0.473, \"Chord\": \"C\"}, {\"Index\": 1389, \"Highest Charting Position\": 109, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Interlude : Shadow\", \"Streams\": 6655856, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"2Nib4r0saYQf2pUV4RFDhl\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 68.0, \"Danceability\": 0.385, \"Energy\": 0.798, \"Loudness\": -6.439, \"Speechiness\": 0.483, \"Acousticness\": 0.115, \"Liveness\": 0.181, \"Tempo\": 149.756, \"Duration (ms)\": 259821.0, \"Valence\": 0.141, \"Chord\": \"A\"}, {\"Index\": 1390, \"Highest Charting Position\": 120, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Respect\", \"Streams\": 6373954, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"37TSJmYKLxXmx8OehFpqMN\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 67.0, \"Danceability\": 0.661, \"Energy\": 0.84, \"Loudness\": -4.805, \"Speechiness\": 0.116, \"Acousticness\": 0.00485, \"Liveness\": 0.287, \"Tempo\": 91.457, \"Duration (ms)\": 237540.0, \"Valence\": 0.524, \"Chord\": \"C\"}, {\"Index\": 1393, \"Highest Charting Position\": 129, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Lose Yourself - From \\\"8 Mile\\\" Soundtrack\", \"Streams\": 5118004, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5Z01UMMf7V1o0MzF86s6WJ\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2005-12-06\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 75.0, \"Danceability\": 0.692, \"Energy\": 0.744, \"Loudness\": -4.565, \"Speechiness\": 0.257, \"Acousticness\": 0.00868, \"Liveness\": 0.359, \"Tempo\": 171.374, \"Duration (ms)\": 326467.0, \"Valence\": 0.0612, \"Chord\": \"D\"}, {\"Index\": 1394, \"Highest Charting Position\": 118, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"all the good girls go to hell\", \"Streams\": 5074485, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"6IRdLKIyS4p7XNiP8r6rsx\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-03-29\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.726, \"Energy\": 0.444, \"Loudness\": -8.922, \"Speechiness\": 0.372, \"Acousticness\": 0.283, \"Liveness\": 0.177, \"Tempo\": 185.044, \"Duration (ms)\": 168840.0, \"Valence\": 0.569, \"Chord\": \"G#/Ab\"}, {\"Index\": 1401, \"Highest Charting Position\": 148, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"i love you\", \"Streams\": 4863910, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"0np7TYPZSum9xTxe9QTr21\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-03--2020-01-10\", \"Popularity\": 2.0, \"Danceability\": 0.42, \"Energy\": 0.131, \"Loudness\": -18.435, \"Speechiness\": 0.0382, \"Acousticness\": 0.953, \"Liveness\": 0.109, \"Tempo\": 137.421, \"Duration (ms)\": 291796.0, \"Valence\": 0.12, \"Chord\": \"C\"}, {\"Index\": 1404, \"Highest Charting Position\": 61, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Come Around Me\", \"Streams\": 9533583, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2o9LAypwGH4ctV0i9boo6d\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 66.0, \"Danceability\": 0.648, \"Energy\": 0.681, \"Loudness\": -8.389, \"Speechiness\": 0.0378, \"Acousticness\": 0.263, \"Liveness\": 0.0971, \"Tempo\": 157.941, \"Duration (ms)\": 200773.0, \"Valence\": 0.767, \"Chord\": \"D\"}, {\"Index\": 1405, \"Highest Charting Position\": 64, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Habitual\", \"Streams\": 9120086, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"40qyPyljksBEqlNw5sW37T\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 62.0, \"Danceability\": 0.764, \"Energy\": 0.443, \"Loudness\": -6.625, \"Speechiness\": 0.0439, \"Acousticness\": 0.52, \"Liveness\": 0.0749, \"Tempo\": 138.999, \"Duration (ms)\": 168200.0, \"Valence\": 0.63, \"Chord\": \"E\"}, {\"Index\": 1406, \"Highest Charting Position\": 65, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"All Around Me\", \"Streams\": 9010535, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5Py8zRKGkZvgHniVVtvNCN\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 63.0, \"Danceability\": 0.566, \"Energy\": 0.438, \"Loudness\": -7.564, \"Speechiness\": 0.0367, \"Acousticness\": 0.809, \"Liveness\": 0.212, \"Tempo\": 117.127, \"Duration (ms)\": 136907.0, \"Valence\": 0.692, \"Chord\": \"C\"}, {\"Index\": 1407, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Get Me (feat. Kehlani)\", \"Streams\": 8362828, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5VwwpU7KsLhgfbMEecedhJ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 61.0, \"Danceability\": 0.832, \"Energy\": 0.508, \"Loudness\": -6.913, \"Speechiness\": 0.149, \"Acousticness\": 0.0492, \"Liveness\": 0.107, \"Tempo\": 109.352, \"Duration (ms)\": 185427.0, \"Valence\": 0.75, \"Chord\": \"F#/Gb\"}, {\"Index\": 1408, \"Highest Charting Position\": 79, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Second Emotion (feat. Travis Scott)\", \"Streams\": 8109572, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"1PnAx788sAvcI3ZxTlEyX8\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 61.0, \"Danceability\": 0.796, \"Energy\": 0.777, \"Loudness\": -6.112, \"Speechiness\": 0.0567, \"Acousticness\": 0.0276, \"Liveness\": 0.095, \"Tempo\": 141.97, \"Duration (ms)\": 202720.0, \"Valence\": 0.96, \"Chord\": \"B\"}, {\"Index\": 1409, \"Highest Charting Position\": 85, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Running Over (feat. Lil Dicky)\", \"Streams\": 7493188, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"75nKBP8jQu681pTNCtrEnn\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.774, \"Energy\": 0.603, \"Loudness\": -7.319, \"Speechiness\": 0.0591, \"Acousticness\": 0.438, \"Liveness\": 0.0869, \"Tempo\": 149.982, \"Duration (ms)\": 179627.0, \"Valence\": 0.977, \"Chord\": \"B\"}, {\"Index\": 1410, \"Highest Charting Position\": 86, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Available\", \"Streams\": 7473249, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"1b6tPXXCV2fSNtR3SKWUQA\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.702, \"Energy\": 0.608, \"Loudness\": -6.843, \"Speechiness\": 0.0359, \"Acousticness\": 0.0736, \"Liveness\": 0.129, \"Tempo\": 75.012, \"Duration (ms)\": 195333.0, \"Valence\": 0.597, \"Chord\": \"D#/Eb\"}, {\"Index\": 1412, \"Highest Charting Position\": 103, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Changes\", \"Streams\": 6865229, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"521Os1SMlxmsoevsqyjNmJ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 62.0, \"Danceability\": 0.485, \"Energy\": 0.412, \"Loudness\": -7.766, \"Speechiness\": 0.042, \"Acousticness\": 0.738, \"Liveness\": 0.12, \"Tempo\": 64.062, \"Duration (ms)\": 135493.0, \"Valence\": 0.612, \"Chord\": \"A\"}, {\"Index\": 1413, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Confirmation\", \"Streams\": 6520106, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"60brXKLTC15vK0av5gIldm\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.438, \"Energy\": 0.315, \"Loudness\": -8.186, \"Speechiness\": 0.0375, \"Acousticness\": 0.608, \"Liveness\": 0.151, \"Tempo\": 190.064, \"Duration (ms)\": 170587.0, \"Valence\": 0.449, \"Chord\": \"G#/Ab\"}, {\"Index\": 1415, \"Highest Charting Position\": 135, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"E.T.A.\", \"Streams\": 6008945, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6PzOPrXx8tJEqace76yrv2\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.465, \"Energy\": 0.494, \"Loudness\": -7.595, \"Speechiness\": 0.066, \"Acousticness\": 0.49, \"Liveness\": 0.127, \"Tempo\": 127.298, \"Duration (ms)\": 176733.0, \"Valence\": 0.457, \"Chord\": \"E\"}, {\"Index\": 1417, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Take It Out On Me\", \"Streams\": 5858768, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"39nTNk5MfyiiRupTwn1iyC\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 54.0, \"Danceability\": 0.772, \"Energy\": 0.616, \"Loudness\": -4.673, \"Speechiness\": 0.102, \"Acousticness\": 0.00337, \"Liveness\": 0.104, \"Tempo\": 129.967, \"Duration (ms)\": 178013.0, \"Valence\": 0.279, \"Chord\": \"G\"}, {\"Index\": 1420, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"That's What Love Is\", \"Streams\": 5440037, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2hLu8L8SNfCN4yKyPdX0h3\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 59.0, \"Danceability\": 0.639, \"Energy\": 0.437, \"Loudness\": -6.959, \"Speechiness\": 0.0355, \"Acousticness\": 0.692, \"Liveness\": 0.12, \"Tempo\": 147.575, \"Duration (ms)\": 165120.0, \"Valence\": 0.751, \"Chord\": \"A\"}, {\"Index\": 1425, \"Highest Charting Position\": 141, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"wish you were gay\", \"Streams\": 5187997, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"3Fj47GNK2kUF0uaEDgXLaD\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-03-29\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.853, \"Energy\": 0.351, \"Loudness\": -10.198, \"Speechiness\": 0.241, \"Acousticness\": 0.39, \"Liveness\": 0.752, \"Tempo\": 118.028, \"Duration (ms)\": 221543.0, \"Valence\": 0.282, \"Chord\": \"G\"}, {\"Index\": 1426, \"Highest Charting Position\": 61, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Only The Young - Featured in Miss Americana\", \"Streams\": 5111068, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2slqvGLwzZZYsT4K4Y1GBC\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 63.0, \"Danceability\": 0.56, \"Energy\": 0.78, \"Loudness\": -4.895, \"Speechiness\": 0.0517, \"Acousticness\": 0.00244, \"Liveness\": 0.0714, \"Tempo\": 93.516, \"Duration (ms)\": 157507.0, \"Valence\": 0.602, \"Chord\": \"F\"}, {\"Index\": 1428, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"At Least For Now\", \"Streams\": 5033764, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6VLkgf5YmLixsabdqiCVGU\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 54.0, \"Danceability\": 0.375, \"Energy\": 0.304, \"Loudness\": -9.897, \"Speechiness\": 0.0325, \"Acousticness\": 0.683, \"Liveness\": 0.196, \"Tempo\": 83.832, \"Duration (ms)\": 149653.0, \"Valence\": 0.295, \"Chord\": \"A\"}, {\"Index\": 1429, \"Highest Charting Position\": 167, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"you should see me in a crown\", \"Streams\": 4988054, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6WbvBhwCaUuYHcHGEuVgqo\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 0.0, \"Danceability\": 0.683, \"Energy\": 0.534, \"Loudness\": -10.348, \"Speechiness\": 0.189, \"Acousticness\": 0.519, \"Liveness\": 0.148, \"Tempo\": 150.469, \"Duration (ms)\": 180567.0, \"Valence\": 0.284, \"Chord\": \"E\"}, {\"Index\": 1441, \"Highest Charting Position\": 160, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"EARFQUAKE\", \"Streams\": 5079657, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6782693.0, \"Song ID\": \"5hVghJ4KaYES3BFUATCYn0\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 79.0, \"Danceability\": 0.554, \"Energy\": 0.498, \"Loudness\": -8.866, \"Speechiness\": 0.0685, \"Acousticness\": 0.23, \"Liveness\": 0.795, \"Tempo\": 79.635, \"Duration (ms)\": 190067.0, \"Valence\": 0.413, \"Chord\": \"A\"}, {\"Index\": 1445, \"Highest Charting Position\": 113, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Suge\", \"Streams\": 4986299, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"2gwkD6igEhQbDQegRCcdoB\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-03-01\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.876, \"Energy\": 0.662, \"Loudness\": -6.482, \"Speechiness\": 0.426, \"Acousticness\": 0.0608, \"Liveness\": 0.127, \"Tempo\": 75.445, \"Duration (ms)\": 163320.0, \"Valence\": 0.844, \"Chord\": \"D\"}, {\"Index\": 1453, \"Highest Charting Position\": 148, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"MIDDLE CHILD\", \"Streams\": 4836113, \"Artist\": \"J. Cole\", \"Artist Followers\": 14103694.0, \"Song ID\": \"2JvzF1RMd7lE3KmFlsyZD8\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2019-01-23\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.837, \"Energy\": 0.364, \"Loudness\": -11.713, \"Speechiness\": 0.276, \"Acousticness\": 0.149, \"Liveness\": 0.271, \"Tempo\": 123.984, \"Duration (ms)\": 213594.0, \"Valence\": 0.463, \"Chord\": \"G#/Ab\"}, {\"Index\": 1457, \"Highest Charting Position\": 22, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Those Kinda Nights (feat. Ed Sheeran)\", \"Streams\": 5823422, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"0VSzREd1OjEWJ9tXoFHRQH\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 66.0, \"Danceability\": 0.794, \"Energy\": 0.637, \"Loudness\": -6.29, \"Speechiness\": 0.339, \"Acousticness\": 0.028, \"Liveness\": 0.0919, \"Tempo\": 103.868, \"Duration (ms)\": 177693.0, \"Valence\": 0.393, \"Chord\": \"E\"}, {\"Index\": 1467, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"ME! (feat. Brendon Urie of Panic! At The Disco)\", \"Streams\": 4884909, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2Rk4JlNc2TPmZe2af99d45\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 77.0, \"Danceability\": 0.61, \"Energy\": 0.83, \"Loudness\": -4.105, \"Speechiness\": 0.0571, \"Acousticness\": 0.033, \"Liveness\": 0.118, \"Tempo\": 182.162, \"Duration (ms)\": 193000.0, \"Valence\": 0.728, \"Chord\": \"C\"}, {\"Index\": 1469, \"Highest Charting Position\": 191, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"idontwannabeyouanymore\", \"Streams\": 4824483, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"41zXlQxzTi6cGAjpOXyLYH\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2017-12-22\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 78.0, \"Danceability\": 0.483, \"Energy\": 0.412, \"Loudness\": -8.461, \"Speechiness\": 0.0402, \"Acousticness\": 0.737, \"Liveness\": 0.116, \"Tempo\": 170.163, \"Duration (ms)\": 203569.0, \"Valence\": 0.247, \"Chord\": \"G\"}, {\"Index\": 1472, \"Highest Charting Position\": 26, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Darkness\", \"Streams\": 7618955, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5SiZJoLXp3WOl3J4C8IK0d\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 65.0, \"Danceability\": 0.671, \"Energy\": 0.623, \"Loudness\": -7.161, \"Speechiness\": 0.308, \"Acousticness\": 0.00998, \"Liveness\": 0.643, \"Tempo\": 75.055, \"Duration (ms)\": 337147.0, \"Valence\": 0.195, \"Chord\": \"D\"}, {\"Index\": 1473, \"Highest Charting Position\": 30, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"You Gon\\u2019 Learn (feat. Royce Da 5'9\\\" & White Gold)\", \"Streams\": 7157402, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"0GQ5bFTVFFKpwNPc7KwQnB\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 66.0, \"Danceability\": 0.68, \"Energy\": 0.82, \"Loudness\": -4.197, \"Speechiness\": 0.151, \"Acousticness\": 0.0614, \"Liveness\": 0.597, \"Tempo\": 140.033, \"Duration (ms)\": 234653.0, \"Valence\": 0.243, \"Chord\": \"E\"}, {\"Index\": 1476, \"Highest Charting Position\": 32, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Unaccommodating (feat. Young M.A)\", \"Streams\": 6374807, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"0q2vG0UVuy6ajjcpkQHdZM\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 65.0, \"Danceability\": 0.852, \"Energy\": 0.752, \"Loudness\": -5.793, \"Speechiness\": 0.0597, \"Acousticness\": 0.0169, \"Liveness\": 0.394, \"Tempo\": 89.95, \"Duration (ms)\": 216600.0, \"Valence\": 0.389, \"Chord\": \"C#/Db\"}, {\"Index\": 1478, \"Highest Charting Position\": 44, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Leaving Heaven (feat. Skylar Grey)\", \"Streams\": 5466161, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5CpsIb7SMFHjmAG8RvIWfq\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.661, \"Energy\": 0.748, \"Loudness\": -4.809, \"Speechiness\": 0.206, \"Acousticness\": 0.175, \"Liveness\": 0.254, \"Tempo\": 171.983, \"Duration (ms)\": 265947.0, \"Valence\": 0.509, \"Chord\": \"D\"}, {\"Index\": 1481, \"Highest Charting Position\": 56, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Look At Her Now\", \"Streams\": 5066377, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 1251372.0, \"Song ID\": \"2XUPkAie1nz9SYIhbdIVWb\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.753, \"Energy\": 0.564, \"Loudness\": -7.908, \"Speechiness\": 0.251, \"Acousticness\": 0.114, \"Liveness\": 0.359, \"Tempo\": 77.341, \"Duration (ms)\": 162596.0, \"Valence\": 0.55, \"Chord\": \"A#/Bb\"}, {\"Index\": 1483, \"Highest Charting Position\": 126, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Legends\", \"Streams\": 4922369, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"1Knctxx9vGZxpZfF66BIEa\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2018-06-22\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.594, \"Energy\": 0.798, \"Loudness\": -5.244, \"Speechiness\": 0.0844, \"Acousticness\": 0.115, \"Liveness\": 0.143, \"Tempo\": 142.049, \"Duration (ms)\": 191840.0, \"Valence\": 0.381, \"Chord\": \"E\"}, {\"Index\": 1486, \"Highest Charting Position\": 52, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"In Too Deep\", \"Streams\": 4824037, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"7Dj2wqPYXfSRFwa6qyOztr\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.72, \"Energy\": 0.767, \"Loudness\": -5.839, \"Speechiness\": 0.214, \"Acousticness\": 0.0387, \"Liveness\": 0.202, \"Tempo\": 88.966, \"Duration (ms)\": 194707.0, \"Valence\": 0.595, \"Chord\": \"A#/Bb\"}, {\"Index\": 1487, \"Highest Charting Position\": 57, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Premonition - Intro\", \"Streams\": 10830400, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"7ccTcabbJlCJiIqtrSSwBk\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.847, \"Energy\": 0.637, \"Loudness\": -5.193, \"Speechiness\": 0.367, \"Acousticness\": 0.0258, \"Liveness\": 0.382, \"Tempo\": 165.979, \"Duration (ms)\": 173893.0, \"Valence\": 0.511, \"Chord\": \"C#/Db\"}, {\"Index\": 1490, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"No Regrets (feat. Don Toliver)\", \"Streams\": 9493884, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"1lO9CZo6eDrOy0S7khgryG\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 63.0, \"Danceability\": 0.756, \"Energy\": 0.747, \"Loudness\": -5.407, \"Speechiness\": 0.046, \"Acousticness\": 0.0048, \"Liveness\": 0.588, \"Tempo\": 134.935, \"Duration (ms)\": 200947.0, \"Valence\": 0.0687, \"Chord\": \"A\"}, {\"Index\": 1492, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Lock It Up (feat. Anderson .Paak)\", \"Streams\": 9328951, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"1qwMkkRiD5jqLeUUjfgblh\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.848, \"Energy\": 0.745, \"Loudness\": -3.052, \"Speechiness\": 0.221, \"Acousticness\": 0.0949, \"Liveness\": 0.0796, \"Tempo\": 137.024, \"Duration (ms)\": 170227.0, \"Valence\": 0.516, \"Chord\": \"F#/Gb\"}, {\"Index\": 1493, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Marsh\", \"Streams\": 9260007, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"34d7sGX6WUqq8f04e7CSNF\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.871, \"Energy\": 0.493, \"Loudness\": -6.356, \"Speechiness\": 0.205, \"Acousticness\": 0.0134, \"Liveness\": 0.385, \"Tempo\": 144.989, \"Duration (ms)\": 200573.0, \"Valence\": 0.0495, \"Chord\": \"C#/Db\"}, {\"Index\": 1494, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Stepdad\", \"Streams\": 9159901, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"3QVHSV8YKYq4L8tI5rnFgj\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 61.0, \"Danceability\": 0.779, \"Energy\": 0.805, \"Loudness\": -3.121, \"Speechiness\": 0.178, \"Acousticness\": 0.018, \"Liveness\": 0.321, \"Tempo\": 145.68, \"Duration (ms)\": 213413.0, \"Valence\": 0.557, \"Chord\": \"C#/Db\"}, {\"Index\": 1495, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Yah Yah (feat. Royce Da 5'9\\\", Black Thought, Q-Tip & Denaun)\", \"Streams\": 8695060, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5mZXWEH2eh8zMZGCxT5aW0\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.458, \"Energy\": 0.966, \"Loudness\": -2.107, \"Speechiness\": 0.384, \"Acousticness\": 0.14, \"Liveness\": 0.11, \"Tempo\": 183.586, \"Duration (ms)\": 286960.0, \"Valence\": 0.356, \"Chord\": \"C#/Db\"}, {\"Index\": 1496, \"Highest Charting Position\": 90, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Never Love Again\", \"Streams\": 8335790, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"40YbWniIEmqy6s58fYXLUh\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.747, \"Energy\": 0.899, \"Loudness\": -5.125, \"Speechiness\": 0.246, \"Acousticness\": 0.1, \"Liveness\": 0.486, \"Tempo\": 92.029, \"Duration (ms)\": 177547.0, \"Valence\": 0.581, \"Chord\": \"F\"}, {\"Index\": 1498, \"Highest Charting Position\": 94, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Farewell\", \"Streams\": 8277608, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"74gykWHknHDrg4eMdcmdRq\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 61.0, \"Danceability\": 0.89, \"Energy\": 0.664, \"Loudness\": -6.625, \"Speechiness\": 0.106, \"Acousticness\": 0.00487, \"Liveness\": 0.257, \"Tempo\": 93.007, \"Duration (ms)\": 247733.0, \"Valence\": 0.467, \"Chord\": \"E\"}, {\"Index\": 1500, \"Highest Charting Position\": 100, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Alfred - Interlude\", \"Streams\": 8030151, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"4EmunTy7kNBYQivOa8F6b8\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 57.0, \"Danceability\": 0.429, \"Energy\": 0.231, \"Loudness\": -20.43, \"Speechiness\": 0.402, \"Acousticness\": 0.878, \"Liveness\": 0.279, \"Tempo\": 74.545, \"Duration (ms)\": 30133.0, \"Valence\": 0.914, \"Chord\": \"F\"}, {\"Index\": 1501, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Little Engine\", \"Streams\": 7913461, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"4qNWEOMyexn7b8Icyk29t9\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.769, \"Energy\": 0.811, \"Loudness\": -4.162, \"Speechiness\": 0.228, \"Acousticness\": 0.0234, \"Liveness\": 0.0451, \"Tempo\": 155.081, \"Duration (ms)\": 177293.0, \"Valence\": 0.76, \"Chord\": \"A#/Bb\"}, {\"Index\": 1502, \"Highest Charting Position\": 113, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"I Will (feat. KXNG Crooked, Royce Da 5'9\\\" & Joell Ortiz)\", \"Streams\": 7115414, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"3CJbxqRQ0JNCqboWDNUUeX\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.635, \"Energy\": 0.543, \"Loudness\": -5.941, \"Speechiness\": 0.067, \"Acousticness\": 0.0454, \"Liveness\": 0.272, \"Tempo\": 98.743, \"Duration (ms)\": 303000.0, \"Valence\": 0.036, \"Chord\": \"G#/Ab\"}, {\"Index\": 1511, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Vulnerable\", \"Streams\": 7531094, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"11OwAR3GlBj9E35Cznf7Lj\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 55.0, \"Danceability\": 0.695, \"Energy\": 0.573, \"Loudness\": -8.882, \"Speechiness\": 0.167, \"Acousticness\": 0.132, \"Liveness\": 0.156, \"Tempo\": 100.031, \"Duration (ms)\": 192172.0, \"Valence\": 0.38, \"Chord\": \"A#/Bb\"}, {\"Index\": 1512, \"Highest Charting Position\": 90, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Dance Again\", \"Streams\": 7394604, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"5sK3o66yupTNIK6gWgzGjf\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 56.0, \"Danceability\": 0.784, \"Energy\": 0.552, \"Loudness\": -7.261, \"Speechiness\": 0.0871, \"Acousticness\": 0.0447, \"Liveness\": 0.192, \"Tempo\": 111.984, \"Duration (ms)\": 170498.0, \"Valence\": 0.465, \"Chord\": \"C#/Db\"}, {\"Index\": 1513, \"Highest Charting Position\": 107, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Ring\", \"Streams\": 6693229, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"11Ey4yJVeWEsA73KjACkVY\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 55.0, \"Danceability\": 0.873, \"Energy\": 0.51, \"Loudness\": -5.35, \"Speechiness\": 0.0661, \"Acousticness\": 0.565, \"Liveness\": 0.0738, \"Tempo\": 110.953, \"Duration (ms)\": 148776.0, \"Valence\": 0.871, \"Chord\": \"D#/Eb\"}, {\"Index\": 1514, \"Highest Charting Position\": 111, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Crowded Room (feat. 6LACK)\", \"Streams\": 6483001, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"2C0hTkdEoikhKzDCJl32QZ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 55.0, \"Danceability\": 0.724, \"Energy\": 0.415, \"Loudness\": -8.408, \"Speechiness\": 0.0518, \"Acousticness\": 0.764, \"Liveness\": 0.103, \"Tempo\": 89.999, \"Duration (ms)\": 186459.0, \"Valence\": 0.328, \"Chord\": \"G\"}, {\"Index\": 1515, \"Highest Charting Position\": 119, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"People You Know\", \"Streams\": 6255954, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"63mdJr3NMY3wReOkNE6c6W\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 54.0, \"Danceability\": 0.695, \"Energy\": 0.62, \"Loudness\": -8.082, \"Speechiness\": 0.0521, \"Acousticness\": 0.0881, \"Liveness\": 0.111, \"Tempo\": 150.032, \"Duration (ms)\": 194900.0, \"Valence\": 0.62, \"Chord\": \"G#/Ab\"}, {\"Index\": 1519, \"Highest Charting Position\": 161, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Let Me Get Me\", \"Streams\": 5356671, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"0uFForNKQPvgSCnxlZIhQy\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 51.0, \"Danceability\": 0.826, \"Energy\": 0.571, \"Loudness\": -9.263, \"Speechiness\": 0.0426, \"Acousticness\": 0.249, \"Liveness\": 0.215, \"Tempo\": 121.06, \"Duration (ms)\": 189145.0, \"Valence\": 0.475, \"Chord\": \"D\"}, {\"Index\": 1520, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"A Sweeter Place (feat. Kid Cudi)\", \"Streams\": 5291134, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4bb94wZVF1cX66vQjNeJTX\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 52.0, \"Danceability\": 0.583, \"Energy\": 0.777, \"Loudness\": -6.991, \"Speechiness\": 0.185, \"Acousticness\": 0.109, \"Liveness\": 0.108, \"Tempo\": 190.054, \"Duration (ms)\": 263306.0, \"Valence\": 0.31, \"Chord\": \"A#/Bb\"}, {\"Index\": 1529, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Cut You Off\", \"Streams\": 4874380, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4OtHGdb0KqEbaWb6edUnR9\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 51.0, \"Danceability\": 0.855, \"Energy\": 0.294, \"Loudness\": -8.676, \"Speechiness\": 0.286, \"Acousticness\": 0.3, \"Liveness\": 0.091, \"Tempo\": 139.745, \"Duration (ms)\": 182017.0, \"Valence\": 0.842, \"Chord\": \"F\"}, {\"Index\": 1530, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Kinda Crazy\", \"Streams\": 4866777, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"59iGOjPSOcPLGl3vqEStUp\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 49.0, \"Danceability\": 0.691, \"Energy\": 0.446, \"Loudness\": -10.304, \"Speechiness\": 0.0472, \"Acousticness\": 0.484, \"Liveness\": 0.183, \"Tempo\": 93.03, \"Duration (ms)\": 212436.0, \"Valence\": 0.534, \"Chord\": \"B\"}, {\"Index\": 1546, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Candy\", \"Streams\": 5632102, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"1VJwtWR6z7SpZRwipI12be\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2018-03-30\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.689, \"Energy\": 0.516, \"Loudness\": -5.857, \"Speechiness\": 0.0444, \"Acousticness\": 0.513, \"Liveness\": 0.163, \"Tempo\": 124.876, \"Duration (ms)\": 190920.0, \"Valence\": 0.209, \"Chord\": \"G#/Ab\"}, {\"Index\": 1550, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Let Me Know (I Wonder Why Freestyle)\", \"Streams\": 4701532, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"3wwo0bJvDSorOpNfzEkfXx\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2019-12-07\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.635, \"Energy\": 0.537, \"Loudness\": -7.895, \"Speechiness\": 0.0832, \"Acousticness\": 0.172, \"Liveness\": 0.418, \"Tempo\": 125.028, \"Duration (ms)\": 215381.0, \"Valence\": 0.383, \"Chord\": \"G\"}, {\"Index\": 1552, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"New Rules\", \"Streams\": 4630675, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"2ekn2ttSfGqwhhate0LSR0\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2017-06-02\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.762, \"Energy\": 0.7, \"Loudness\": -6.021, \"Speechiness\": 0.0694, \"Acousticness\": 0.00261, \"Liveness\": 0.153, \"Tempo\": 116.073, \"Duration (ms)\": 209320.0, \"Valence\": 0.608, \"Chord\": \"A\"}, {\"Index\": 1556, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lover (Remix) [feat. Shawn Mendes]\", \"Streams\": 4595450, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3i9UVldZOE0aD0JnyfAZZ0\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-11-13\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.448, \"Energy\": 0.603, \"Loudness\": -7.176, \"Speechiness\": 0.064, \"Acousticness\": 0.433, \"Liveness\": 0.0862, \"Tempo\": 205.272, \"Duration (ms)\": 221307.0, \"Valence\": 0.422, \"Chord\": \"G\"}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 26,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "alt.Chart(df_top).mark_bar().encode(\n",
    "    x = \"Artist\",\n",
    "    y = \"count()\",\n",
    "    color = \"mean(Streams)\"\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "086f00ab",
   "metadata": {},
   "source": [
    "```{admonition} Exercise\n",
    ":class: tip\n",
    "Copy the above histogram code, and replace `mean` with `sum`.  Suddenly the colors are less interesting.  Why do you think that is?\n",
    "```"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "2bde678d",
   "metadata": {},
   "source": [
    "(Spotify-interactive)=\n",
    "### Interactive example\n",
    "We end with an example just for inspiration.  One of the distinguishing features of Altair is its support for interactivity.  If you click and drag on the below chart, the points in the region you select will gain color."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 27,
   "id": "fb796595",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-b3d95a849dbe4761aac9c10e24e0b8a9\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-b3d95a849dbe4761aac9c10e24e0b8a9\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-b3d95a849dbe4761aac9c10e24e0b8a9\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-67c9fb159873386c9c7303ca2ad81ad2\"}, \"mark\": \"circle\", \"encoding\": {\"color\": {\"condition\": {\"type\": \"quantitative\", \"field\": \"Acousticness\", \"scale\": {\"reverse\": true, \"scheme\": \"turbo\"}, \"selection\": \"selector001\"}, \"value\": \"lightgrey\"}, \"x\": {\"type\": \"quantitative\", \"field\": \"Energy\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"Loudness\"}}, \"height\": 450, \"selection\": {\"selector001\": {\"type\": \"interval\", \"empty\": \"none\"}}, \"title\": \"Spotify dataset from Kaggle\", \"width\": 720, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-67c9fb159873386c9c7303ca2ad81ad2\": [{\"Index\": 1, \"Highest Charting Position\": 1, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Beggin'\", \"Streams\": 48633449, \"Artist\": \"M\\u00e5neskin\", \"Artist Followers\": 3377762.0, \"Song ID\": \"3Wrjm47oTz2sjIgck11l5e\", \"Genre\": \"['indie rock italiano', 'italian pop']\", \"Release Date\": \"2017-12-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 100.0, \"Danceability\": 0.714, \"Energy\": 0.8, \"Loudness\": -4.808, \"Speechiness\": 0.0504, \"Acousticness\": 0.127, \"Liveness\": 0.359, \"Tempo\": 134.002, \"Duration (ms)\": 211560.0, \"Valence\": 0.589, \"Chord\": \"B\"}, {\"Index\": 2, \"Highest Charting Position\": 2, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"STAY (with Justin Bieber)\", \"Streams\": 47248719, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2230022.0, \"Song ID\": \"5HCyWlXZPP0y6Gqq8TgA20\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 99.0, \"Danceability\": 0.591, \"Energy\": 0.764, \"Loudness\": -5.484, \"Speechiness\": 0.0483, \"Acousticness\": 0.0383, \"Liveness\": 0.103, \"Tempo\": 169.928, \"Duration (ms)\": 141806.0, \"Valence\": 0.478, \"Chord\": \"C#/Db\"}, {\"Index\": 3, \"Highest Charting Position\": 1, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"good 4 u\", \"Streams\": 40162559, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"4ZtFanR9U6ndgddUvNcjcG\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 99.0, \"Danceability\": 0.563, \"Energy\": 0.664, \"Loudness\": -5.044, \"Speechiness\": 0.154, \"Acousticness\": 0.335, \"Liveness\": 0.0849, \"Tempo\": 166.928, \"Duration (ms)\": 178147.0, \"Valence\": 0.688, \"Chord\": \"A\"}, {\"Index\": 4, \"Highest Charting Position\": 3, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Bad Habits\", \"Streams\": 37799456, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83293380.0, \"Song ID\": \"6PQ88X9TkUIAUIZJHW2upE\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 98.0, \"Danceability\": 0.808, \"Energy\": 0.897, \"Loudness\": -3.712, \"Speechiness\": 0.0348, \"Acousticness\": 0.0469, \"Liveness\": 0.364, \"Tempo\": 126.026, \"Duration (ms)\": 231041.0, \"Valence\": 0.591, \"Chord\": \"B\"}, {\"Index\": 5, \"Highest Charting Position\": 5, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"INDUSTRY BABY (feat. Jack Harlow)\", \"Streams\": 33948454, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5473565.0, \"Song ID\": \"27NovPIUIRrOZoCHxABJwK\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2021-07-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 96.0, \"Danceability\": 0.736, \"Energy\": 0.704, \"Loudness\": -7.409, \"Speechiness\": 0.0615, \"Acousticness\": 0.0203, \"Liveness\": 0.0501, \"Tempo\": 149.995, \"Duration (ms)\": 212000.0, \"Valence\": 0.894, \"Chord\": \"D#/Eb\"}, {\"Index\": 6, \"Highest Charting Position\": 1, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"MONTERO (Call Me By Your Name)\", \"Streams\": 30071134, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5473565.0, \"Song ID\": \"67BtfxlNbhBmCDR2L2l8qd\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2021-03-31\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 97.0, \"Danceability\": 0.61, \"Energy\": 0.508, \"Loudness\": -6.682, \"Speechiness\": 0.152, \"Acousticness\": 0.297, \"Liveness\": 0.384, \"Tempo\": 178.818, \"Duration (ms)\": 137876.0, \"Valence\": 0.758, \"Chord\": \"G#/Ab\"}, {\"Index\": 7, \"Highest Charting Position\": 3, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Kiss Me More (feat. SZA)\", \"Streams\": 29356736, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"748mdHapucXQri7IAO8yFK\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 94.0, \"Danceability\": 0.762, \"Energy\": 0.701, \"Loudness\": -3.541, \"Speechiness\": 0.0286, \"Acousticness\": 0.235, \"Liveness\": 0.123, \"Tempo\": 110.968, \"Duration (ms)\": 208867.0, \"Valence\": 0.742, \"Chord\": \"G#/Ab\"}, {\"Index\": 8, \"Highest Charting Position\": 2, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Todo De Ti\", \"Streams\": 26951613, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6080597.0, \"Song ID\": \"4fSIb4hdOQ151TILNsSEaF\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2021-05-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 95.0, \"Danceability\": 0.78, \"Energy\": 0.718, \"Loudness\": -3.605, \"Speechiness\": 0.0506, \"Acousticness\": 0.31, \"Liveness\": 0.0932, \"Tempo\": 127.949, \"Duration (ms)\": 199604.0, \"Valence\": 0.342, \"Chord\": \"D#/Eb\"}, {\"Index\": 9, \"Highest Charting Position\": 3, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Yonaguni\", \"Streams\": 25030128, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36142273.0, \"Song ID\": \"2JPLbjOn0wPCngEot2STUS\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 96.0, \"Danceability\": 0.644, \"Energy\": 0.648, \"Loudness\": -4.601, \"Speechiness\": 0.118, \"Acousticness\": 0.276, \"Liveness\": 0.135, \"Tempo\": 179.951, \"Duration (ms)\": 206710.0, \"Valence\": 0.44, \"Chord\": \"C#/Db\"}, {\"Index\": 10, \"Highest Charting Position\": 8, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"I WANNA BE YOUR SLAVE\", \"Streams\": 24551591, \"Artist\": \"M\\u00e5neskin\", \"Artist Followers\": 3377762.0, \"Song ID\": \"4pt5fDVTg5GhEvEtlz9dKk\", \"Genre\": \"['indie rock italiano', 'italian pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 95.0, \"Danceability\": 0.75, \"Energy\": 0.608, \"Loudness\": -4.008, \"Speechiness\": 0.0387, \"Acousticness\": 0.00165, \"Liveness\": 0.178, \"Tempo\": 132.507, \"Duration (ms)\": 173347.0, \"Valence\": 0.958, \"Chord\": \"C#/Db\"}, {\"Index\": 11, \"Highest Charting Position\": 4, \"Number of Times Charted\": 43, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Levitating (feat. DaBaby)\", \"Streams\": 23518010, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"463CkQjx2Zk1yXoBuierM9\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-10-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 89.0, \"Danceability\": 0.702, \"Energy\": 0.825, \"Loudness\": -3.787, \"Speechiness\": 0.0601, \"Acousticness\": 0.00883, \"Liveness\": 0.0674, \"Tempo\": 102.977, \"Duration (ms)\": 203064.0, \"Valence\": 0.915, \"Chord\": \"F#/Gb\"}, {\"Index\": 12, \"Highest Charting Position\": 9, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Qu\\u00e9 M\\u00e1s Pues?\", \"Streams\": 22405111, \"Artist\": \"J Balvin, Maria Becerra\", \"Artist Followers\": 29051363.0, \"Song ID\": \"6hf0RpxTbOprT5nnwzkk8e\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\", \"Popularity\": 95.0, \"Danceability\": 0.891, \"Energy\": 0.819, \"Loudness\": -3.964, \"Speechiness\": 0.106, \"Acousticness\": 0.0261, \"Liveness\": 0.173, \"Tempo\": 101.968, \"Duration (ms)\": 217773.0, \"Valence\": 0.768, \"Chord\": \"G#/Ab\"}, {\"Index\": 13, \"Highest Charting Position\": 5, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Permission to Dance\", \"Streams\": 22062812, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"0LThjFY2iTtNdd4wviwVV2\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 95.0, \"Danceability\": 0.702, \"Energy\": 0.741, \"Loudness\": -5.33, \"Speechiness\": 0.0427, \"Acousticness\": 0.00544, \"Liveness\": 0.337, \"Tempo\": 124.925, \"Duration (ms)\": 187585.0, \"Valence\": 0.646, \"Chord\": \"A\"}, {\"Index\": 14, \"Highest Charting Position\": 1, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Peaches (feat. Daniel Caesar & Giveon)\", \"Streams\": 20294457, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48504126.0, \"Song ID\": \"4iJyoBOLtHqaGxP12qzhQI\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 94.0, \"Danceability\": 0.677, \"Energy\": 0.696, \"Loudness\": -6.181, \"Speechiness\": 0.119, \"Acousticness\": 0.321, \"Liveness\": 0.42, \"Tempo\": 90.03, \"Duration (ms)\": 198082.0, \"Valence\": 0.464, \"Chord\": \"C\"}, {\"Index\": 15, \"Highest Charting Position\": 2, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Butter\", \"Streams\": 19985713, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"2bgTY4UwhfBYhGT4HUYStN\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 95.0, \"Danceability\": 0.759, \"Energy\": 0.459, \"Loudness\": -5.187, \"Speechiness\": 0.0948, \"Acousticness\": 0.00323, \"Liveness\": 0.0906, \"Tempo\": 109.997, \"Duration (ms)\": 164442.0, \"Valence\": 0.695, \"Chord\": \"G#/Ab\"}, {\"Index\": 16, \"Highest Charting Position\": 7, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"traitor\", \"Streams\": 19480679, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"5CZ40GBx1sQ9agT82CLQCT\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 94.0, \"Danceability\": 0.38, \"Energy\": 0.339, \"Loudness\": -7.885, \"Speechiness\": 0.0338, \"Acousticness\": 0.691, \"Liveness\": 0.12, \"Tempo\": 100.607, \"Duration (ms)\": 229227.0, \"Valence\": 0.0849, \"Chord\": \"D#/Eb\"}, {\"Index\": 17, \"Highest Charting Position\": 3, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"deja vu\", \"Streams\": 18571755, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"6HU7h9RYOaPRFeh0R3UeAr\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 93.0, \"Danceability\": 0.442, \"Energy\": 0.612, \"Loudness\": -7.222, \"Speechiness\": 0.112, \"Acousticness\": 0.584, \"Liveness\": 0.37, \"Tempo\": 180.917, \"Duration (ms)\": 215507.0, \"Valence\": 0.178, \"Chord\": \"D\"}, {\"Index\": 18, \"Highest Charting Position\": 5, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Save Your Tears (with Ariana Grande) (Remix)\", \"Streams\": 18053141, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"37BZB0z9T8Xu7U3e65qxFy\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 94.0, \"Danceability\": 0.65, \"Energy\": 0.825, \"Loudness\": -4.645, \"Speechiness\": 0.0325, \"Acousticness\": 0.0215, \"Liveness\": 0.0936, \"Tempo\": 118.091, \"Duration (ms)\": 191014.0, \"Valence\": 0.593, \"Chord\": \"C\"}, {\"Index\": 19, \"Highest Charting Position\": 14, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"AM Remix\", \"Streams\": 17617965, \"Artist\": \"Nio Garcia, J Balvin, Bad Bunny\", \"Artist Followers\": 2123734.0, \"Song ID\": \"05bfbizlM5AX6Mf1RRyMho\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-24\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 93.0, \"Danceability\": 0.743, \"Energy\": 0.655, \"Loudness\": -5.015, \"Speechiness\": 0.159, \"Acousticness\": 0.114, \"Liveness\": 0.0764, \"Tempo\": 172.031, \"Duration (ms)\": 261335.0, \"Valence\": 0.785, \"Chord\": \"F#/Gb\"}, {\"Index\": 20, \"Highest Charting Position\": 20, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Need To Know\", \"Streams\": 16908917, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"3Vi5XqYrmQgOYBajMWSvCi\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 90.0, \"Danceability\": 0.664, \"Energy\": 0.609, \"Loudness\": -6.509, \"Speechiness\": 0.0707, \"Acousticness\": 0.304, \"Liveness\": 0.0926, \"Tempo\": 130.041, \"Duration (ms)\": 210560.0, \"Valence\": 0.194, \"Chord\": \"C#/Db\"}, {\"Index\": 21, \"Highest Charting Position\": 19, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Volando - Remix\", \"Streams\": 16606925, \"Artist\": \"Mora, Bad Bunny, Sech\", \"Artist Followers\": 151486.0, \"Song ID\": \"0G2zPzWqVjR68iNPmx2TBe\", \"Genre\": \"['reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 91.0, \"Danceability\": 0.659, \"Energy\": 0.688, \"Loudness\": -4.649, \"Speechiness\": 0.0673, \"Acousticness\": 0.207, \"Liveness\": 0.113, \"Tempo\": 153.979, \"Duration (ms)\": 273474.0, \"Valence\": 0.632, \"Chord\": \"F#/Gb\"}, {\"Index\": 22, \"Highest Charting Position\": 22, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Ain't Shit\", \"Streams\": 16126897, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"5lAnYvAIkSDNXqfo7DyFUm\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 90.0, \"Danceability\": 0.855, \"Energy\": 0.488, \"Loudness\": -4.601, \"Speechiness\": 0.208, \"Acousticness\": 0.506, \"Liveness\": 0.347, \"Tempo\": 124.097, \"Duration (ms)\": 174253.0, \"Valence\": 0.619, \"Chord\": \"D#/Eb\"}, {\"Index\": 23, \"Highest Charting Position\": 1, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"drivers license\", \"Streams\": 15684978, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"5wANPM4fQCJwkGd4rN57mH\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 92.0, \"Danceability\": 0.561, \"Energy\": 0.431, \"Loudness\": -8.81, \"Speechiness\": 0.0578, \"Acousticness\": 0.768, \"Liveness\": 0.106, \"Tempo\": 143.875, \"Duration (ms)\": 242013.0, \"Valence\": 0.137, \"Chord\": \"A#/Bb\"}, {\"Index\": 24, \"Highest Charting Position\": 24, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Heat Waves\", \"Streams\": 15089184, \"Artist\": \"Glass Animals\", \"Artist Followers\": 1890510.0, \"Song ID\": \"3USxtqRwSYz57Ewm6wWRMp\", \"Genre\": \"['gauze pop', 'indietronica', 'shiver pop']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 85.0, \"Danceability\": 0.761, \"Energy\": 0.525, \"Loudness\": -6.9, \"Speechiness\": 0.0944, \"Acousticness\": 0.44, \"Liveness\": 0.0921, \"Tempo\": 80.87, \"Duration (ms)\": 238805.0, \"Valence\": 0.531, \"Chord\": \"B\"}, {\"Index\": 25, \"Highest Charting Position\": 1, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Blinding Lights\", \"Streams\": 15011809, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"0VjIjW4GlUZAMYd2vXMi3b\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 92.0, \"Danceability\": 0.514, \"Energy\": 0.73, \"Loudness\": -5.934, \"Speechiness\": 0.0598, \"Acousticness\": 0.00146, \"Liveness\": 0.0897, \"Tempo\": 171.005, \"Duration (ms)\": 200040.0, \"Valence\": 0.334, \"Chord\": \"C#/Db\"}, {\"Index\": 26, \"Highest Charting Position\": 12, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"happier\", \"Streams\": 14849078, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"2tGvwE8GcFKwNdAXMnlbfl\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 92.0, \"Danceability\": 0.395, \"Energy\": 0.443, \"Loudness\": -9.72, \"Speechiness\": 0.133, \"Acousticness\": 0.765, \"Liveness\": 0.0839, \"Tempo\": 168.924, \"Duration (ms)\": 175933.0, \"Valence\": 0.338, \"Chord\": \"F#/Gb\"}, {\"Index\": 27, \"Highest Charting Position\": 27, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Pepas\", \"Streams\": 14809458, \"Artist\": \"Farruko\", \"Artist Followers\": 10502148.0, \"Song ID\": \"5fwSHlTEWpluwOM0Sxnh5k\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-24\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 92.0, \"Danceability\": 0.762, \"Energy\": 0.766, \"Loudness\": -3.955, \"Speechiness\": 0.0343, \"Acousticness\": 0.00776, \"Liveness\": 0.128, \"Tempo\": 130.001, \"Duration (ms)\": 287120.0, \"Valence\": 0.442, \"Chord\": \"G\"}, {\"Index\": 28, \"Highest Charting Position\": 18, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Motley Crew\", \"Streams\": 14329162, \"Artist\": \"Post Malone\", \"Artist Followers\": 33651775.0, \"Song ID\": \"40uMIn2zJLAQhNXghRjBed\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 90.0, \"Danceability\": 0.797, \"Energy\": 0.631, \"Loudness\": -3.818, \"Speechiness\": 0.0786, \"Acousticness\": 0.0904, \"Liveness\": 0.0998, \"Tempo\": 129.915, \"Duration (ms)\": 184213.0, \"Valence\": 0.288, \"Chord\": \"D#/Eb\"}, {\"Index\": 29, \"Highest Charting Position\": 15, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Friday (feat. Mufasa & Hypeman) - Dopamine Re-Edit\", \"Streams\": 14273637, \"Artist\": \"Riton, Nightcrawlers\", \"Artist Followers\": 83689.0, \"Song ID\": \"4cG7HUWYHBV6R6tHn1gxrl\", \"Genre\": \"['dance pop', 'house', 'pop dance', 'tropical house', 'uk dance']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 92.0, \"Danceability\": 0.824, \"Energy\": 0.862, \"Loudness\": -3.424, \"Speechiness\": 0.126, \"Acousticness\": 0.0076, \"Liveness\": 0.303, \"Tempo\": 122.98, \"Duration (ms)\": 169153.0, \"Valence\": 0.801, \"Chord\": \"D\"}, {\"Index\": 30, \"Highest Charting Position\": 3, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Astronaut In The Ocean\", \"Streams\": 14174752, \"Artist\": \"Masked Wolf\", \"Artist Followers\": 365975.0, \"Song ID\": \"3Ofmpyhv5UAQ70mENzB277\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2021-01-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 89.0, \"Danceability\": 0.778, \"Energy\": 0.695, \"Loudness\": -6.865, \"Speechiness\": 0.0913, \"Acousticness\": 0.175, \"Liveness\": 0.15, \"Tempo\": 149.996, \"Duration (ms)\": 132780.0, \"Valence\": 0.472, \"Chord\": \"E\"}, {\"Index\": 31, \"Highest Charting Position\": 5, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Leave The Door Open\", \"Streams\": 13963568, \"Artist\": \"Bruno Mars, Anderson .Paak, Silk Sonic\", \"Artist Followers\": 32574754.0, \"Song ID\": \"7MAibcTli4IisCtbHKrGMh\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 92.0, \"Danceability\": 0.586, \"Energy\": 0.616, \"Loudness\": -7.964, \"Speechiness\": 0.0324, \"Acousticness\": 0.182, \"Liveness\": 0.0927, \"Tempo\": 148.088, \"Duration (ms)\": 242096.0, \"Valence\": 0.719, \"Chord\": \"F\"}, {\"Index\": 32, \"Highest Charting Position\": 32, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Don't Go Yet\", \"Streams\": 13205250, \"Artist\": \"Camila Cabello\", \"Artist Followers\": 22683756.0, \"Song ID\": \"1058fW9H3fZA6QjYCdOBad\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-07-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 88.0, \"Danceability\": 0.666, \"Energy\": 0.796, \"Loudness\": -6.967, \"Speechiness\": 0.103, \"Acousticness\": 0.0492, \"Liveness\": 0.0442, \"Tempo\": 110.108, \"Duration (ms)\": 164842.0, \"Valence\": 0.61, \"Chord\": \"A#/Bb\"}, {\"Index\": 33, \"Highest Charting Position\": 11, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"favorite crime\", \"Streams\": 12818935, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"5JCoSi02qi3jJeHdZXMmR8\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 91.0, \"Danceability\": 0.369, \"Energy\": 0.272, \"Loudness\": -10.497, \"Speechiness\": 0.0364, \"Acousticness\": 0.866, \"Liveness\": 0.147, \"Tempo\": 172.929, \"Duration (ms)\": 152667.0, \"Valence\": 0.218, \"Chord\": \"A\"}, {\"Index\": 34, \"Highest Charting Position\": 10, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Pareja Del A\\u00f1o\", \"Streams\": 12572307, \"Artist\": \"Sebastian Yatra, Myke Towers\", \"Artist Followers\": 16216789.0, \"Song ID\": \"2rCbl9naJYhaxjLsfx88uM\", \"Genre\": \"['colombian pop', 'latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 91.0, \"Danceability\": 0.715, \"Energy\": 0.622, \"Loudness\": -5.102, \"Speechiness\": 0.046, \"Acousticness\": 0.163, \"Liveness\": 0.0948, \"Tempo\": 80.015, \"Duration (ms)\": 195053.0, \"Valence\": 0.808, \"Chord\": \"E\"}, {\"Index\": 35, \"Highest Charting Position\": 4, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Watermelon Sugar\", \"Streams\": 11996689, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16112621.0, \"Song ID\": \"6UelLqGlWMcVH1E5c4H7lY\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 90.0, \"Danceability\": 0.548, \"Energy\": 0.816, \"Loudness\": -4.209, \"Speechiness\": 0.0465, \"Acousticness\": 0.122, \"Liveness\": 0.335, \"Tempo\": 95.39, \"Duration (ms)\": 174000.0, \"Valence\": 0.557, \"Chord\": \"C\"}, {\"Index\": 36, \"Highest Charting Position\": 36, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"NOT SOBER (feat. Polo G & Stunna Gambino)\", \"Streams\": 11869336, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 37, \"Highest Charting Position\": 3, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"RAPSTAR\", \"Streams\": 11683383, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"43PGPuHIlVOc04jrZVh9L6\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 89.0, \"Danceability\": 0.789, \"Energy\": 0.536, \"Loudness\": -6.862, \"Speechiness\": 0.242, \"Acousticness\": 0.41, \"Liveness\": 0.129, \"Tempo\": 81.039, \"Duration (ms)\": 165926.0, \"Valence\": 0.437, \"Chord\": \"F#/Gb\"}, {\"Index\": 38, \"Highest Charting Position\": 15, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"You Right\", \"Streams\": 11629418, \"Artist\": \"Doja Cat, The Weeknd\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0k4d5YPDr1r7FX77VdqWez\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 89.0, \"Danceability\": 0.828, \"Energy\": 0.621, \"Loudness\": -6.414, \"Speechiness\": 0.0565, \"Acousticness\": 0.0164, \"Liveness\": 0.0845, \"Tempo\": 128.986, \"Duration (ms)\": 186173.0, \"Valence\": 0.436, \"Chord\": \"G#/Ab\"}, {\"Index\": 39, \"Highest Charting Position\": 39, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"911 - Remix\", \"Streams\": 11553846, \"Artist\": \"Sech, Jhay Cortez\", \"Artist Followers\": 8758283.0, \"Song ID\": \"27RSJHEA99Y0Vsow7nA37A\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 89.0, \"Danceability\": 0.816, \"Energy\": 0.71, \"Loudness\": -3.728, \"Speechiness\": 0.0398, \"Acousticness\": 0.165, \"Liveness\": 0.292, \"Tempo\": 93.02, \"Duration (ms)\": 208631.0, \"Valence\": 0.784, \"Chord\": \"G\"}, {\"Index\": 40, \"Highest Charting Position\": 1, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"D\\u00c1KITI\", \"Streams\": 11524288, \"Artist\": \"Bad Bunny, Jhay Cortez\", \"Artist Followers\": 36142273.0, \"Song ID\": \"4MzXwWMhyBbmu6hOcLVD49\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 86.0, \"Danceability\": 0.731, \"Energy\": 0.573, \"Loudness\": -10.059, \"Speechiness\": 0.0544, \"Acousticness\": 0.401, \"Liveness\": 0.113, \"Tempo\": 109.928, \"Duration (ms)\": 205090.0, \"Valence\": 0.145, \"Chord\": \"E\"}, {\"Index\": 41, \"Highest Charting Position\": 41, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Mi\\u00e9nteme\", \"Streams\": 11477024, \"Artist\": \"TINI, Maria Becerra\", \"Artist Followers\": 2936204.0, \"Song ID\": \"0cOa970mzTWAxKtltpkpLc\", \"Genre\": \"['latin pop', 'pop argentino']\", \"Release Date\": \"2021-04-29\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 90.0, \"Danceability\": 0.85, \"Energy\": 0.541, \"Loudness\": -4.522, \"Speechiness\": 0.0674, \"Acousticness\": 0.161, \"Liveness\": 0.286, \"Tempo\": 92.003, \"Duration (ms)\": 165275.0, \"Valence\": 0.916, \"Chord\": \"D\"}, {\"Index\": 42, \"Highest Charting Position\": 17, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"jealousy, jealousy\", \"Streams\": 11287301, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"0MMyJUC3WNnFS1lit5pTjk\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 90.0, \"Danceability\": 0.695, \"Energy\": 0.575, \"Loudness\": -6.334, \"Speechiness\": 0.116, \"Acousticness\": 0.198, \"Liveness\": 0.0614, \"Tempo\": 163.929, \"Duration (ms)\": 173160.0, \"Valence\": 0.699, \"Chord\": \"A#/Bb\"}, {\"Index\": 43, \"Highest Charting Position\": 33, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Poblado - Remix\", \"Streams\": 11283626, \"Artist\": \"J Balvin, KAROL G, Nicky Jam, Crissin, Totoy El Frio, Natan & Shander\", \"Artist Followers\": 29051363.0, \"Song ID\": \"1WedZeiezCmCEOzLwhx0hV\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 89.0, \"Danceability\": 0.813, \"Energy\": 0.809, \"Loudness\": -5.382, \"Speechiness\": 0.0846, \"Acousticness\": 0.102, \"Liveness\": 0.377, \"Tempo\": 93.005, \"Duration (ms)\": 393280.0, \"Valence\": 0.646, \"Chord\": \"D#/Eb\"}, {\"Index\": 44, \"Highest Charting Position\": 2, \"Number of Times Charted\": 49, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Dynamite\", \"Streams\": 11196819, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"4saklk6nie3yiGePpBwUoc\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 89.0, \"Danceability\": 0.746, \"Energy\": 0.765, \"Loudness\": -4.41, \"Speechiness\": 0.0993, \"Acousticness\": 0.0112, \"Liveness\": 0.0936, \"Tempo\": 114.044, \"Duration (ms)\": 199054.0, \"Valence\": 0.737, \"Chord\": \"F#/Gb\"}, {\"Index\": 45, \"Highest Charting Position\": 9, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"The Business\", \"Streams\": 10739770, \"Artist\": \"Ti\\u00ebsto\", \"Artist Followers\": 5785065.0, \"Song ID\": \"6f3Slt0GbA2bPZlz0aIFXN\", \"Genre\": \"['big room', 'brostep', 'dance pop', 'dutch edm', 'edm', 'electro house', 'house', 'pop dance', 'slap house', 'trance', 'tropical house']\", \"Release Date\": \"2020-09-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 90.0, \"Danceability\": 0.798, \"Energy\": 0.62, \"Loudness\": -7.079, \"Speechiness\": 0.232, \"Acousticness\": 0.414, \"Liveness\": 0.112, \"Tempo\": 120.031, \"Duration (ms)\": 164000.0, \"Valence\": 0.235, \"Chord\": \"G#/Ab\"}, {\"Index\": 46, \"Highest Charting Position\": 46, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Heartbreak Anthem (with David Guetta & Little Mix)\", \"Streams\": 10315460, \"Artist\": \"Galantis\", \"Artist Followers\": 3120157.0, \"Song ID\": \"5K6Ssv4Z3zRvxt0P6EKUAP\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2021-05-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 89.0, \"Danceability\": 0.595, \"Energy\": 0.784, \"Loudness\": -4.878, \"Speechiness\": 0.102, \"Acousticness\": 0.216, \"Liveness\": 0.0608, \"Tempo\": 124.111, \"Duration (ms)\": 183726.0, \"Valence\": 0.479, \"Chord\": \"C#/Db\"}, {\"Index\": 47, \"Highest Charting Position\": 1, \"Number of Times Charted\": 51, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Mood (feat. iann dior)\", \"Streams\": 10222056, \"Artist\": \"24kGoldn\", \"Artist Followers\": 1274433.0, \"Song ID\": \"4jPy3l0RUwlUI9T5XHBW2m\", \"Genre\": \"['cali rap']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 89.0, \"Danceability\": 0.701, \"Energy\": 0.716, \"Loudness\": -3.671, \"Speechiness\": 0.0361, \"Acousticness\": 0.174, \"Liveness\": 0.324, \"Tempo\": 91.007, \"Duration (ms)\": 140533.0, \"Valence\": 0.732, \"Chord\": \"G\"}, {\"Index\": 48, \"Highest Charting Position\": 48, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Entre Nosotros\", \"Streams\": 10215216, \"Artist\": \"Tiago PZK, LIT killah\", \"Artist Followers\": 375865.0, \"Song ID\": \"6w8yBI2vthyN9UnwO4UBWb\", \"Genre\": \"['trap argentino']\", \"Release Date\": \"2021-07-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 89.0, \"Danceability\": 0.729, \"Energy\": 0.513, \"Loudness\": -6.345, \"Speechiness\": 0.0455, \"Acousticness\": 0.494, \"Liveness\": 0.137, \"Tempo\": 170.064, \"Duration (ms)\": 192353.0, \"Valence\": 0.789, \"Chord\": \"F\"}, {\"Index\": 49, \"Highest Charting Position\": 29, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Fiel - Remix\", \"Streams\": 10032746, \"Artist\": \"Wisin, Jhay Cortez, Anuel AA, Los Legendarios, Myke Towers\", \"Artist Followers\": 6929075.0, \"Song ID\": \"43qcs9NpJhDxtG91zxFkj7\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 89.0, \"Danceability\": 0.839, \"Energy\": 0.711, \"Loudness\": -4.733, \"Speechiness\": 0.0473, \"Acousticness\": 0.398, \"Liveness\": 0.118, \"Tempo\": 97.99, \"Duration (ms)\": 349547.0, \"Valence\": 0.573, \"Chord\": \"F#/Gb\"}, {\"Index\": 50, \"Highest Charting Position\": 20, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Build a Bitch\", \"Streams\": 9841998, \"Artist\": \"Bella Poarch\", \"Artist Followers\": 389076.0, \"Song ID\": \"7BoobGhD4x5K96Me0hqC8Q\", \"Genre\": \"[]\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 89.0, \"Danceability\": 0.855, \"Energy\": 0.463, \"Loudness\": -7.454, \"Speechiness\": 0.0367, \"Acousticness\": 0.217, \"Liveness\": 0.347, \"Tempo\": 102.931, \"Duration (ms)\": 122773.0, \"Valence\": 0.866, \"Chord\": \"D#/Eb\"}, {\"Index\": 51, \"Highest Charting Position\": 19, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Nicky Jam: Bzrp Music Sessions, Vol. 41\", \"Streams\": 9799701, \"Artist\": \"Bizarrap, Nicky Jam\", \"Artist Followers\": 3126961.0, \"Song ID\": \"03LfOYi0icz4souspZVVhq\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2021-06-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 88.0, \"Danceability\": 0.627, \"Energy\": 0.849, \"Loudness\": -3.167, \"Speechiness\": 0.153, \"Acousticness\": 0.0913, \"Liveness\": 0.145, \"Tempo\": 89.907, \"Duration (ms)\": 158087.0, \"Valence\": 0.818, \"Chord\": \"C#/Db\"}, {\"Index\": 52, \"Highest Charting Position\": 52, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Tiroteo - Remix\", \"Streams\": 9781153, \"Artist\": \"Marc Segu\\u00ed, Rauw Alejandro, Pol Granch\", \"Artist Followers\": 45362.0, \"Song ID\": \"4OwhwvKESFtuu06dTgct7i\", \"Genre\": \"[]\", \"Release Date\": \"2021-04-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 88.0, \"Danceability\": 0.75, \"Energy\": 0.522, \"Loudness\": -7.018, \"Speechiness\": 0.0293, \"Acousticness\": 0.282, \"Liveness\": 0.0743, \"Tempo\": 110.427, \"Duration (ms)\": 321556.0, \"Valence\": 0.601, \"Chord\": \"A\"}, {\"Index\": 53, \"Highest Charting Position\": 19, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"NDA\", \"Streams\": 9635619, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47014200.0, \"Song ID\": \"38GBNKZUhfBkk3oNlWzRYd\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-07-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 84.0, \"Danceability\": 0.765, \"Energy\": 0.373, \"Loudness\": -9.921, \"Speechiness\": 0.0713, \"Acousticness\": 0.341, \"Liveness\": 0.112, \"Tempo\": 85.016, \"Duration (ms)\": 195777.0, \"Valence\": 0.554, \"Chord\": \"G#/Ab\"}, {\"Index\": 54, \"Highest Charting Position\": 40, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Rasputin\", \"Streams\": 9600707, \"Artist\": \"Majestic, Boney M.\", \"Artist Followers\": 32178.0, \"Song ID\": \"6FO4K7MrMoYkc5BlpX5LNV\", \"Genre\": \"['house', 'pop dance', 'uk dance']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 49.0, \"Danceability\": 0.83, \"Energy\": 0.839, \"Loudness\": -6.985, \"Speechiness\": 0.0699, \"Acousticness\": 0.00201, \"Liveness\": 0.0353, \"Tempo\": 128.012, \"Duration (ms)\": 345543.0, \"Valence\": 0.59, \"Chord\": \"F#/Gb\"}, {\"Index\": 55, \"Highest Charting Position\": 52, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Leave Before You Love Me (with Jonas Brothers)\", \"Streams\": 9428494, \"Artist\": \"Marshmello\", \"Artist Followers\": 31541310.0, \"Song ID\": \"4qu63nuBpdn0qHUHuObEj1\", \"Genre\": \"['brostep', 'edm', 'pop', 'pop dance', 'progressive electro house']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\", \"Popularity\": 89.0, \"Danceability\": 0.721, \"Energy\": 0.738, \"Loudness\": -4.77, \"Speechiness\": 0.0403, \"Acousticness\": 0.00226, \"Liveness\": 0.118, \"Tempo\": 119.976, \"Duration (ms)\": 154983.0, \"Valence\": 0.637, \"Chord\": \"G\"}, {\"Index\": 56, \"Highest Charting Position\": 56, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Freaks\", \"Streams\": 9319465, \"Artist\": \"Surf Curse\", \"Artist Followers\": 495226.0, \"Song ID\": \"7EkWXAI1wn8Ii883ecd9xr\", \"Genre\": \"['dreamo', 'indie surf', 'surf punk', 'vegas indie']\", \"Release Date\": \"2021-05-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 89.0, \"Danceability\": 0.345, \"Energy\": 0.941, \"Loudness\": -9.918, \"Speechiness\": 0.0466, \"Acousticness\": 3.84e-05, \"Liveness\": 0.0511, \"Tempo\": 179.626, \"Duration (ms)\": 147062.0, \"Valence\": 0.407, \"Chord\": \"A\"}, {\"Index\": 57, \"Highest Charting Position\": 57, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Meu Peda\\u00e7o de Pecado\", \"Streams\": 9206366, \"Artist\": \"Jo\\u00e3o Gomes\", \"Artist Followers\": 409173.0, \"Song ID\": \"2kJRlOyrxsy7Ot3c5TZ8Q6\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 83.0, \"Danceability\": 0.668, \"Energy\": 0.887, \"Loudness\": -4.404, \"Speechiness\": 0.0564, \"Acousticness\": 0.369, \"Liveness\": 0.257, \"Tempo\": 151.92, \"Duration (ms)\": 157176.0, \"Valence\": 0.907, \"Chord\": \"B\"}, {\"Index\": 58, \"Highest Charting Position\": 31, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"2/Catorce\", \"Streams\": 9086979, \"Artist\": \"Rauw Alejandro, Mr. Naisgai\", \"Artist Followers\": 6080597.0, \"Song ID\": \"71R8HJxQk5qMiRstrlXN9t\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2021-02-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 87.0, \"Danceability\": 0.54, \"Energy\": 0.455, \"Loudness\": -5.988, \"Speechiness\": 0.224, \"Acousticness\": 0.675, \"Liveness\": 0.12, \"Tempo\": 83.876, \"Duration (ms)\": 212032.0, \"Valence\": 0.432, \"Chord\": \"D#/Eb\"}, {\"Index\": 59, \"Highest Charting Position\": 34, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Beautiful Mistakes (feat. Megan Thee Stallion)\", \"Streams\": 9048966, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32262679.0, \"Song ID\": \"5zFglKYiknIxks8geR8rcL\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 88.0, \"Danceability\": 0.713, \"Energy\": 0.676, \"Loudness\": -5.483, \"Speechiness\": 0.027, \"Acousticness\": 0.0377, \"Liveness\": 0.154, \"Tempo\": 99.048, \"Duration (ms)\": 227395.0, \"Valence\": 0.721, \"Chord\": \"A#/Bb\"}, {\"Index\": 60, \"Highest Charting Position\": 31, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Run\", \"Streams\": 9017356, \"Artist\": \"OneRepublic\", \"Artist Followers\": 12169108.0, \"Song ID\": \"2UbVnbE5FH6008mAm6Mmgw\", \"Genre\": \"['dance pop', 'piano rock', 'pop', 'pop rock']\", \"Release Date\": \"2021-05-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2020-09-25--2020-10-02\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 88.0, \"Danceability\": 0.682, \"Energy\": 0.72, \"Loudness\": -8.173, \"Speechiness\": 0.0381, \"Acousticness\": 0.326, \"Liveness\": 0.148, \"Tempo\": 117.003, \"Duration (ms)\": 169011.0, \"Valence\": 0.673, \"Chord\": \"B\"}, {\"Index\": 61, \"Highest Charting Position\": 46, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Thot Shit\", \"Streams\": 8977336, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4787261.0, \"Song ID\": \"5zNW5ARjYhJQJz1AChP33n\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 88.0, \"Danceability\": 0.95, \"Energy\": 0.693, \"Loudness\": -3.424, \"Speechiness\": 0.0898, \"Acousticness\": 0.0133, \"Liveness\": 0.173, \"Tempo\": 130.02, \"Duration (ms)\": 184635.0, \"Valence\": 0.891, \"Chord\": \"A\"}, {\"Index\": 62, \"Highest Charting Position\": 26, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Your Love (9PM)\", \"Streams\": 8935418, \"Artist\": \"ATB, Topic, A7S\", \"Artist Followers\": 291777.0, \"Song ID\": \"5YaskwnGDZFDRipaqzbwQx\", \"Genre\": \"['german dance', 'german techno', 'german trance', 'trance']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 88.0, \"Danceability\": 0.669, \"Energy\": 0.784, \"Loudness\": -5.603, \"Speechiness\": 0.112, \"Acousticness\": 0.194, \"Liveness\": 0.115, \"Tempo\": 125.993, \"Duration (ms)\": 150053.0, \"Valence\": 0.517, \"Chord\": \"G\"}, {\"Index\": 63, \"Highest Charting Position\": 9, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"brutal\", \"Streams\": 8881356, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"6SRsiMl7w1USE4mFqrOhHC\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 89.0, \"Danceability\": 0.672, \"Energy\": 0.526, \"Loudness\": -6.446, \"Speechiness\": 0.0599, \"Acousticness\": 0.0311, \"Liveness\": 0.28, \"Tempo\": 123.999, \"Duration (ms)\": 143747.0, \"Valence\": 0.28, \"Chord\": \"E\"}, {\"Index\": 64, \"Highest Charting Position\": 2, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Save Your Tears\", \"Streams\": 8843110, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"37BZB0z9T8Xu7U3e65qxFy\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 94.0, \"Danceability\": 0.65, \"Energy\": 0.825, \"Loudness\": -4.645, \"Speechiness\": 0.0325, \"Acousticness\": 0.0215, \"Liveness\": 0.0936, \"Tempo\": 118.091, \"Duration (ms)\": 191014.0, \"Valence\": 0.593, \"Chord\": \"C\"}, {\"Index\": 65, \"Highest Charting Position\": 8, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Heartbreak Anniversary\", \"Streams\": 8832945, \"Artist\": \"Giveon\", \"Artist Followers\": 1398563.0, \"Song ID\": \"3FAJ6O0NOHQV8Mc5Ri6ENp\", \"Genre\": \"['pop', 'r&b']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 87.0, \"Danceability\": 0.449, \"Energy\": 0.465, \"Loudness\": -8.964, \"Speechiness\": 0.0791, \"Acousticness\": 0.524, \"Liveness\": 0.303, \"Tempo\": 89.087, \"Duration (ms)\": 198371.0, \"Valence\": 0.543, \"Chord\": \"C\"}, {\"Index\": 66, \"Highest Charting Position\": 2, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Don't Start Now\", \"Streams\": 8821971, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 1250353.0, \"Song ID\": \"7njGslFmqBmOSSOpTyZCs9\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.793, \"Energy\": 0.793, \"Loudness\": -4.521, \"Speechiness\": 0.083, \"Acousticness\": 0.0123, \"Liveness\": 0.0951, \"Tempo\": 123.95, \"Duration (ms)\": 183290.0, \"Valence\": 0.679, \"Chord\": \"B\"}, {\"Index\": 67, \"Highest Charting Position\": 33, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Dinero\", \"Streams\": 8564775, \"Artist\": \"Trinidad Cardona\", \"Artist Followers\": 116817.0, \"Song ID\": \"3ggtU1ZOKO8ZNiqPNyXGcm\", \"Genre\": \"[]\", \"Release Date\": \"2018-02-02\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 87.0, \"Danceability\": 0.708, \"Energy\": 0.782, \"Loudness\": -4.687, \"Speechiness\": 0.0674, \"Acousticness\": 0.00772, \"Liveness\": 0.107, \"Tempo\": 119.997, \"Duration (ms)\": 160880.0, \"Valence\": 0.484, \"Chord\": \"D\"}, {\"Index\": 68, \"Highest Charting Position\": 35, \"Number of Times Charted\": 48, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Sweater Weather\", \"Streams\": 8564017, \"Artist\": \"The Neighbourhood\", \"Artist Followers\": 6662605.0, \"Song ID\": \"2QjOHCTQ1Jl3zawyYOpxh6\", \"Genre\": \"['modern alternative rock', 'modern rock', 'pop']\", \"Release Date\": \"2013-04-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 87.0, \"Danceability\": 0.612, \"Energy\": 0.807, \"Loudness\": -2.81, \"Speechiness\": 0.0336, \"Acousticness\": 0.0495, \"Liveness\": 0.101, \"Tempo\": 124.053, \"Duration (ms)\": 240400.0, \"Valence\": 0.398, \"Chord\": \"A#/Bb\"}, {\"Index\": 69, \"Highest Charting Position\": 69, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Sobrio\", \"Streams\": 8514480, \"Artist\": \"Maluma\", \"Artist Followers\": 26769304.0, \"Song ID\": \"4HzqWEdAbzcVFDv0pvxV4w\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-07-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 87.0, \"Danceability\": 0.762, \"Energy\": 0.77, \"Loudness\": -2.758, \"Speechiness\": 0.223, \"Acousticness\": 0.138, \"Liveness\": 0.15, \"Tempo\": 177.998, \"Duration (ms)\": 201181.0, \"Valence\": 0.631, \"Chord\": \"F\"}, {\"Index\": 70, \"Highest Charting Position\": 12, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Someone You Loved\", \"Streams\": 8490162, \"Artist\": \"Lewis Capaldi\", \"Artist Followers\": 8384096.0, \"Song ID\": \"7qEHsqek33rTcFNT9PFqLf\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.501, \"Energy\": 0.405, \"Loudness\": -5.679, \"Speechiness\": 0.0319, \"Acousticness\": 0.751, \"Liveness\": 0.105, \"Tempo\": 109.891, \"Duration (ms)\": 182161.0, \"Valence\": 0.446, \"Chord\": \"C#/Db\"}, {\"Index\": 71, \"Highest Charting Position\": 71, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Over The Top (feat. Drake)\", \"Streams\": 8269753, \"Artist\": \"Smiley\", \"Artist Followers\": 26131.0, \"Song ID\": \"3yaYgjEFkRw3PVjW9mV1TO\", \"Genre\": \"['canadian hip hop', 'toronto rap']\", \"Release Date\": \"2021-07-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 83.0, \"Danceability\": 0.833, \"Energy\": 0.498, \"Loudness\": -5.196, \"Speechiness\": 0.117, \"Acousticness\": 0.0493, \"Liveness\": 0.119, \"Tempo\": 139.928, \"Duration (ms)\": 153406.0, \"Valence\": 0.259, \"Chord\": \"A#/Bb\"}, {\"Index\": 72, \"Highest Charting Position\": 72, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"2055\", \"Streams\": 8133401, \"Artist\": \"Sleepy Hallow\", \"Artist Followers\": 408696.0, \"Song ID\": \"4XvcHTUfIlWfyJTRG0aqlo\", \"Genre\": \"['brooklyn drill', 'nyc rap']\", \"Release Date\": \"2021-06-02\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 85.0, \"Danceability\": 0.829, \"Energy\": 0.512, \"Loudness\": -5.865, \"Speechiness\": 0.187, \"Acousticness\": 0.492, \"Liveness\": 0.12, \"Tempo\": 80.511, \"Duration (ms)\": 123987.0, \"Valence\": 0.638, \"Chord\": \"F#/Gb\"}, {\"Index\": 73, \"Highest Charting Position\": 33, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"EL MAKINON\", \"Streams\": 8102107, \"Artist\": \"KAROL G, Mariah Angeliq\", \"Artist Followers\": 17775316.0, \"Song ID\": \"2FSGUA0gFgGeQdprjtGM2M\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 87.0, \"Danceability\": 0.635, \"Energy\": 0.706, \"Loudness\": -3.224, \"Speechiness\": 0.125, \"Acousticness\": 0.256, \"Liveness\": 0.108, \"Tempo\": 88.863, \"Duration (ms)\": 209160.0, \"Valence\": 0.443, \"Chord\": \"F\"}, {\"Index\": 74, \"Highest Charting Position\": 74, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Loco\", \"Streams\": 8093413, \"Artist\": \"Justin Quiles, Chimbala, Zion & Lennox\", \"Artist Followers\": 2895789.0, \"Song ID\": \"6PDlkWmrq2ZKiUuFt2aQsH\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 87.0, \"Danceability\": 0.77, \"Energy\": 0.899, \"Loudness\": -2.981, \"Speechiness\": 0.0494, \"Acousticness\": 0.222, \"Liveness\": 0.0894, \"Tempo\": 128.05, \"Duration (ms)\": 231604.0, \"Valence\": 0.851, \"Chord\": \"G#/Ab\"}, {\"Index\": 75, \"Highest Charting Position\": 75, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Love Tonight - Edit\", \"Streams\": 8006336, \"Artist\": \"Shouse\", \"Artist Followers\": 27116.0, \"Song ID\": \"6OufwUcCqo81guU2jAlDVP\", \"Genre\": \"['aussietronica']\", \"Release Date\": \"2017-12-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 87.0, \"Danceability\": 0.727, \"Energy\": 0.681, \"Loudness\": -7.114, \"Speechiness\": 0.0265, \"Acousticness\": 0.00214, \"Liveness\": 0.0861, \"Tempo\": 123.028, \"Duration (ms)\": 241970.0, \"Valence\": 0.448, \"Chord\": \"F\"}, {\"Index\": 76, \"Highest Charting Position\": 12, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"ZITTI E BUONI\", \"Streams\": 7975148, \"Artist\": \"M\\u00e5neskin\", \"Artist Followers\": 3377762.0, \"Song ID\": \"776AftMmFFAWUIEAb3lHhw\", \"Genre\": \"['indie rock italiano', 'italian pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-03-05--2021-03-12\", \"Popularity\": 86.0, \"Danceability\": 0.625, \"Energy\": 0.939, \"Loudness\": -3.115, \"Speechiness\": 0.0669, \"Acousticness\": 0.00138, \"Liveness\": 0.424, \"Tempo\": 102.999, \"Duration (ms)\": 194787.0, \"Valence\": 0.644, \"Chord\": \"E\"}, {\"Index\": 77, \"Highest Charting Position\": 2, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"telepat\\u00eda\", \"Streams\": 7912399, \"Artist\": \"Kali Uchis\", \"Artist Followers\": 1999954.0, \"Song ID\": \"6tDDoYIxWvMLTdKpjFkc1B\", \"Genre\": \"['colombian pop', 'pop']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 88.0, \"Danceability\": 0.653, \"Energy\": 0.524, \"Loudness\": -9.016, \"Speechiness\": 0.0502, \"Acousticness\": 0.112, \"Liveness\": 0.203, \"Tempo\": 83.97, \"Duration (ms)\": 160191.0, \"Valence\": 0.553, \"Chord\": \"B\"}, {\"Index\": 78, \"Highest Charting Position\": 9, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Botella Tras Botella\", \"Streams\": 7735223, \"Artist\": \"Gera MX, Christian Nodal\", \"Artist Followers\": 2043294.0, \"Song ID\": \"2MnLkFqY9Rpg9s3Zv6ZJdK\", \"Genre\": \"['mexican hip hop', 'rap conciencia']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 87.0, \"Danceability\": 0.727, \"Energy\": 0.546, \"Loudness\": -4.572, \"Speechiness\": 0.0437, \"Acousticness\": 0.656, \"Liveness\": 0.122, \"Tempo\": 106.891, \"Duration (ms)\": 197333.0, \"Valence\": 0.69, \"Chord\": \"C\"}, {\"Index\": 79, \"Highest Charting Position\": 7, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Fiel\", \"Streams\": 7717211, \"Artist\": \"Los Legendarios, Wisin, Jhay Cortez\", \"Artist Followers\": 31488.0, \"Song ID\": \"7Bk0uXKk1uPT0XuQbpFzvs\", \"Genre\": \"['reggaeton', 'trap latino']\", \"Release Date\": \"2021-02-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 88.0, \"Danceability\": 0.849, \"Energy\": 0.701, \"Loudness\": -4.407, \"Speechiness\": 0.06, \"Acousticness\": 0.407, \"Liveness\": 0.112, \"Tempo\": 98.005, \"Duration (ms)\": 261667.0, \"Valence\": 0.505, \"Chord\": \"F#/Gb\"}, {\"Index\": 80, \"Highest Charting Position\": 1, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Dance Monkey\", \"Streams\": 7687058, \"Artist\": \"Tones And I\", \"Artist Followers\": 2819593.0, \"Song ID\": \"2XU0oxnq2qxCpomAAuJY8K\", \"Genre\": \"['australian pop', 'pop']\", \"Release Date\": \"2019-10-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.824, \"Energy\": 0.588, \"Loudness\": -6.4, \"Speechiness\": 0.0924, \"Acousticness\": 0.692, \"Liveness\": 0.149, \"Tempo\": 98.027, \"Duration (ms)\": 209438.0, \"Valence\": 0.513, \"Chord\": \"F#/Gb\"}, {\"Index\": 81, \"Highest Charting Position\": 7, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"WITHOUT YOU\", \"Streams\": 7642130, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2230022.0, \"Song ID\": \"27OeeYzk6klgBh83TSvGMA\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 87.0, \"Danceability\": 0.662, \"Energy\": 0.413, \"Loudness\": -7.357, \"Speechiness\": 0.0299, \"Acousticness\": 0.213, \"Liveness\": 0.134, \"Tempo\": 93.005, \"Duration (ms)\": 161385.0, \"Valence\": 0.467, \"Chord\": \"C\"}, {\"Index\": 82, \"Highest Charting Position\": 6, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Wants and Needs (feat. Lil Baby)\", \"Streams\": 7637626, \"Artist\": \"Drake\", \"Artist Followers\": 56308172.0, \"Song ID\": \"65OVbaJR5O1RmwOQx0875b\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 87.0, \"Danceability\": 0.578, \"Energy\": 0.449, \"Loudness\": -6.349, \"Speechiness\": 0.286, \"Acousticness\": 0.0618, \"Liveness\": 0.119, \"Tempo\": 136.006, \"Duration (ms)\": 192956.0, \"Valence\": 0.1, \"Chord\": \"C#/Db\"}, {\"Index\": 83, \"Highest Charting Position\": 83, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Bezos I\", \"Streams\": 7516291, \"Artist\": \"Bo Burnham\", \"Artist Followers\": 1042079.0, \"Song ID\": \"0Kdj7nwaYQmvhxnqZaIQuW\", \"Genre\": \"['comic']\", \"Release Date\": \"2021-06-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 84.0, \"Danceability\": 0.694, \"Energy\": 0.948, \"Loudness\": -5.307, \"Speechiness\": 0.0361, \"Acousticness\": 0.00936, \"Liveness\": 0.139, \"Tempo\": 115.044, \"Duration (ms)\": 58149.0, \"Valence\": 0.705, \"Chord\": \"D\"}, {\"Index\": 84, \"Highest Charting Position\": 76, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Love Again\", \"Streams\": 7465445, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 1250353.0, \"Song ID\": \"2sN1pMv6d2t5GlvN6IBMlK\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2020-03-27--2020-04-03\", \"Popularity\": 0.0, \"Danceability\": 0.659, \"Energy\": 0.667, \"Loudness\": -4.668, \"Speechiness\": 0.0339, \"Acousticness\": 0.00173, \"Liveness\": 0.1, \"Tempo\": 115.982, \"Duration (ms)\": 258004.0, \"Valence\": 0.468, \"Chord\": \"B\"}, {\"Index\": 85, \"Highest Charting Position\": 32, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Goosebumps - Remix\", \"Streams\": 7452633, \"Artist\": \"Travis Scott, HVME\", \"Artist Followers\": 17719446.0, \"Song ID\": \"5uEYRdEIh9Bo4fpjDd4Na9\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 87.0, \"Danceability\": 0.841, \"Energy\": 0.593, \"Loudness\": -7.846, \"Speechiness\": 0.0379, \"Acousticness\": 0.418, \"Liveness\": 0.124, \"Tempo\": 124.917, \"Duration (ms)\": 162803.0, \"Valence\": 0.808, \"Chord\": \"C#/Db\"}, {\"Index\": 86, \"Highest Charting Position\": 11, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Head & Heart (feat. MNEK)\", \"Streams\": 7434252, \"Artist\": \"Joel Corry\", \"Artist Followers\": 207547.0, \"Song ID\": \"6cx06DFPPHchuUAcTxznu9\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance', 'tropical house', 'uk dance']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 87.0, \"Danceability\": 0.734, \"Energy\": 0.874, \"Loudness\": -3.158, \"Speechiness\": 0.0662, \"Acousticness\": 0.168, \"Liveness\": 0.0489, \"Tempo\": 122.953, \"Duration (ms)\": 166028.0, \"Valence\": 0.905, \"Chord\": \"G#/Ab\"}, {\"Index\": 87, \"Highest Charting Position\": 42, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"BED\", \"Streams\": 7383369, \"Artist\": \"Joel Corry, RAYE, David Guetta\", \"Artist Followers\": 207547.0, \"Song ID\": \"0siYMEsGrzzzlWLXK5zJfS\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance', 'tropical house', 'uk dance']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 87.0, \"Danceability\": 0.671, \"Energy\": 0.782, \"Loudness\": -4.593, \"Speechiness\": 0.0341, \"Acousticness\": 0.0142, \"Liveness\": 0.333, \"Tempo\": 123.989, \"Duration (ms)\": 178088.0, \"Valence\": 0.618, \"Chord\": \"F#/Gb\"}, {\"Index\": 88, \"Highest Charting Position\": 78, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Iko Iko (My Bestie)\", \"Streams\": 7381585, \"Artist\": \"Justin Wellington, Small Jam\", \"Artist Followers\": 18228.0, \"Song ID\": \"7MC4XR9M9amdmKQr2iDF7i\", \"Genre\": \"['melanesian pop', 'pacific islands pop', 'png pop']\", \"Release Date\": \"2019-06-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 87.0, \"Danceability\": 0.862, \"Energy\": 0.753, \"Loudness\": -5.356, \"Speechiness\": 0.0625, \"Acousticness\": 0.131, \"Liveness\": 0.077, \"Tempo\": 105.039, \"Duration (ms)\": 182857.0, \"Valence\": 0.827, \"Chord\": \"F\"}, {\"Index\": 89, \"Highest Charting Position\": 89, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Better Believe\", \"Streams\": 7365053, \"Artist\": \"Belly, The Weeknd, Young Thug\", \"Artist Followers\": 203972.0, \"Song ID\": \"3zs87EV3EZSh2UpiXxT52Y\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'pop rap', 'rap', 'southern hip hop', 'trap', 'trap soul', 'underground hip hop']\", \"Release Date\": \"2021-07-22\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 80.0, \"Danceability\": 0.797, \"Energy\": 0.573, \"Loudness\": -7.85, \"Speechiness\": 0.319, \"Acousticness\": 0.159, \"Liveness\": 0.144, \"Tempo\": 124.995, \"Duration (ms)\": 206629.0, \"Valence\": 0.445, \"Chord\": \"C\"}, {\"Index\": 90, \"Highest Charting Position\": 23, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Arcade\", \"Streams\": 7353795, \"Artist\": \"Duncan Laurence\", \"Artist Followers\": 287361.0, \"Song ID\": \"1Xi84slp6FryDSCbzq4UCD\", \"Genre\": \"['dutch pop']\", \"Release Date\": \"2019-03-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 84.0, \"Danceability\": 0.45, \"Energy\": 0.329, \"Loudness\": -12.603, \"Speechiness\": 0.0441, \"Acousticness\": 0.818, \"Liveness\": 0.135, \"Tempo\": 71.884, \"Duration (ms)\": 183624.0, \"Valence\": 0.266, \"Chord\": \"A\"}, {\"Index\": 91, \"Highest Charting Position\": 55, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"512\", \"Streams\": 7336542, \"Artist\": \"Mora, Jhay Cortez\", \"Artist Followers\": 151486.0, \"Song ID\": \"5jzEwSyyymBlf1fa1o39T2\", \"Genre\": \"['reggaeton', 'trap latino']\", \"Release Date\": \"2021-02-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 87.0, \"Danceability\": 0.818, \"Energy\": 0.673, \"Loudness\": -7.542, \"Speechiness\": 0.148, \"Acousticness\": 0.348, \"Liveness\": 0.172, \"Tempo\": 87.961, \"Duration (ms)\": 193636.0, \"Valence\": 0.695, \"Chord\": \"E\"}, {\"Index\": 92, \"Highest Charting Position\": 1, \"Number of Times Charted\": 40, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"positions\", \"Streams\": 7244853, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67158068.0, \"Song ID\": \"35mvY5S1H3J2QZyna3TFe0\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 86.0, \"Danceability\": 0.737, \"Energy\": 0.802, \"Loudness\": -4.771, \"Speechiness\": 0.0878, \"Acousticness\": 0.468, \"Liveness\": 0.0931, \"Tempo\": 144.015, \"Duration (ms)\": 172325.0, \"Valence\": 0.682, \"Chord\": \"C\"}, {\"Index\": 93, \"Highest Charting Position\": 6, \"Number of Times Charted\": 84, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Circles\", \"Streams\": 7156162, \"Artist\": \"Post Malone\", \"Artist Followers\": 33651775.0, \"Song ID\": \"21jGcNKet2qwijlDFuPiPb\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 87.0, \"Danceability\": 0.695, \"Energy\": 0.762, \"Loudness\": -3.497, \"Speechiness\": 0.0395, \"Acousticness\": 0.192, \"Liveness\": 0.0863, \"Tempo\": 120.042, \"Duration (ms)\": 215280.0, \"Valence\": 0.553, \"Chord\": \"C\"}, {\"Index\": 94, \"Highest Charting Position\": 94, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Blaues Licht\", \"Streams\": 7084292, \"Artist\": \"RAF Camora, Bonez MC\", \"Artist Followers\": 1329531.0, \"Song ID\": \"08EPQiLMyGB8GJX2EiVoCM\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 78.0, \"Danceability\": 0.819, \"Energy\": 0.835, \"Loudness\": -4.899, \"Speechiness\": 0.102, \"Acousticness\": 0.398, \"Liveness\": 0.252, \"Tempo\": 144.955, \"Duration (ms)\": 144264.0, \"Valence\": 0.703, \"Chord\": \"G#/Ab\"}, {\"Index\": 95, \"Highest Charting Position\": 75, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Ram Pam Pam\", \"Streams\": 7064003, \"Artist\": \"Natti Natasha, Becky G\", \"Artist Followers\": 6341942.0, \"Song ID\": \"4DHDIdeayp8xvlyg22wREO\", \"Genre\": \"['latin', 'latin pop', 'rap latina', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-04-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 86.0, \"Danceability\": 0.908, \"Energy\": 0.813, \"Loudness\": -2.749, \"Speechiness\": 0.0777, \"Acousticness\": 0.305, \"Liveness\": 0.278, \"Tempo\": 97.018, \"Duration (ms)\": 200785.0, \"Valence\": 0.924, \"Chord\": \"F\"}, {\"Index\": 96, \"Highest Charting Position\": 96, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"In Da Getto\", \"Streams\": 6984262, \"Artist\": \"J Balvin, Skrillex\", \"Artist Followers\": 1250353.0, \"Song ID\": \"5lGtPshEJlsJgmqKLi41LY\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 2.0, \"Danceability\": 0.915, \"Energy\": 0.72, \"Loudness\": -3.126, \"Speechiness\": 0.0459, \"Acousticness\": 0.025, \"Liveness\": 0.0942, \"Tempo\": 126.986, \"Duration (ms)\": 131067.0, \"Valence\": 0.631, \"Chord\": \"G#/Ab\"}, {\"Index\": 97, \"Highest Charting Position\": 97, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Woman\", \"Streams\": 6858466, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"6Uj1ctrBOjOas8xZXGqKk4\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-06-25--2021-07-02\", \"Popularity\": 86.0, \"Danceability\": 0.824, \"Energy\": 0.764, \"Loudness\": -4.175, \"Speechiness\": 0.0854, \"Acousticness\": 0.0888, \"Liveness\": 0.117, \"Tempo\": 107.998, \"Duration (ms)\": 172627.0, \"Valence\": 0.881, \"Chord\": \"F\"}, {\"Index\": 98, \"Highest Charting Position\": 60, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"t r a n s p a r e n t s o u l feat. Travis Barker\", \"Streams\": 6853994, \"Artist\": \"WILLOW\", \"Artist Followers\": 1521837.0, \"Song ID\": \"1QL7nSDZCwZMnbisV4KOXt\", \"Genre\": \"['afrofuturism', 'dance pop', 'electropop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2021-04-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 85.0, \"Danceability\": 0.39, \"Energy\": 0.83, \"Loudness\": -5.201, \"Speechiness\": 0.0563, \"Acousticness\": 0.0021, \"Liveness\": 0.156, \"Tempo\": 90.021, \"Duration (ms)\": 168030.0, \"Valence\": 0.191, \"Chord\": \"B\"}, {\"Index\": 99, \"Highest Charting Position\": 99, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Clash (feat. Stormzy)\", \"Streams\": 6825463, \"Artist\": \"Dave\", \"Artist Followers\": 1427540.0, \"Song ID\": \"2oUwMN5VfdGX10XeQJLBBi\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2021-07-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-09--2021-07-16\", \"Popularity\": 79.0, \"Danceability\": 0.871, \"Energy\": 0.519, \"Loudness\": -6.549, \"Speechiness\": 0.258, \"Acousticness\": 0.313, \"Liveness\": 0.0869, \"Tempo\": 140.013, \"Duration (ms)\": 251733.0, \"Valence\": 0.532, \"Chord\": \"D\"}, {\"Index\": 100, \"Highest Charting Position\": 22, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Before You Go\", \"Streams\": 6813800, \"Artist\": \"Lewis Capaldi\", \"Artist Followers\": 8384096.0, \"Song ID\": \"2gMXnyrvIjhVBUZwvLZDMP\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.459, \"Energy\": 0.575, \"Loudness\": -4.858, \"Speechiness\": 0.0573, \"Acousticness\": 0.604, \"Liveness\": 0.0885, \"Tempo\": 111.881, \"Duration (ms)\": 215107.0, \"Valence\": 0.183, \"Chord\": \"D#/Eb\"}, {\"Index\": 101, \"Highest Charting Position\": 52, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Levitating\", \"Streams\": 6799831, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"463CkQjx2Zk1yXoBuierM9\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-10-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 89.0, \"Danceability\": 0.702, \"Energy\": 0.825, \"Loudness\": -3.787, \"Speechiness\": 0.0601, \"Acousticness\": 0.00883, \"Liveness\": 0.0674, \"Tempo\": 102.977, \"Duration (ms)\": 203064.0, \"Valence\": 0.915, \"Chord\": \"F#/Gb\"}, {\"Index\": 102, \"Highest Charting Position\": 85, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Reckless\", \"Streams\": 6711375, \"Artist\": \"Madison Beer\", \"Artist Followers\": 3363988.0, \"Song ID\": \"5ajjAnNRh8bxFvaVHzpPjh\", \"Genre\": \"['alt z', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 86.0, \"Danceability\": 0.386, \"Energy\": 0.426, \"Loudness\": -6.642, \"Speechiness\": 0.0363, \"Acousticness\": 0.807, \"Liveness\": 0.14, \"Tempo\": 180.104, \"Duration (ms)\": 203385.0, \"Valence\": 0.261, \"Chord\": \"D#/Eb\"}, {\"Index\": 103, \"Highest Charting Position\": 103, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"No Me Conocen (Remix) [con DUKI, Rei & Tiago PZK]\", \"Streams\": 6709106, \"Artist\": \"BANDIDO\", \"Artist Followers\": 16074.0, \"Song ID\": \"7COGuXyTr12KvdaYXMqheC\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 85.0, \"Danceability\": 0.769, \"Energy\": 0.812, \"Loudness\": -2.088, \"Speechiness\": 0.0825, \"Acousticness\": 0.281, \"Liveness\": 0.0781, \"Tempo\": 180.003, \"Duration (ms)\": 280274.0, \"Valence\": 0.926, \"Chord\": \"C#/Db\"}, {\"Index\": 104, \"Highest Charting Position\": 88, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Believer\", \"Streams\": 6699895, \"Artist\": \"Imagine Dragons\", \"Artist Followers\": 35285425.0, \"Song ID\": \"0pqnGHJpmpxLKifKRmU6WP\", \"Genre\": \"['modern rock', 'pop', 'rock']\", \"Release Date\": \"2017-06-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.776, \"Energy\": 0.78, \"Loudness\": -4.374, \"Speechiness\": 0.128, \"Acousticness\": 0.0622, \"Liveness\": 0.081, \"Tempo\": 124.949, \"Duration (ms)\": 204347.0, \"Valence\": 0.666, \"Chord\": \"A#/Bb\"}, {\"Index\": 105, \"Highest Charting Position\": 2, \"Number of Times Charted\": 48, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Lemonade (feat. Gunna, Don Toliver & NAV)\", \"Streams\": 6697067, \"Artist\": \"Internet Money\", \"Artist Followers\": 411579.0, \"Song ID\": \"02kDW379Yfd5PzW5A6vuGt\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 82.0, \"Danceability\": 0.799, \"Energy\": 0.66, \"Loudness\": -6.153, \"Speechiness\": 0.079, \"Acousticness\": 0.256, \"Liveness\": 0.111, \"Tempo\": 140.04, \"Duration (ms)\": 195429.0, \"Valence\": 0.471, \"Chord\": \"C#/Db\"}, {\"Index\": 106, \"Highest Charting Position\": 45, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Talking to the Moon\", \"Streams\": 6660319, \"Artist\": \"Bruno Mars\", \"Artist Followers\": 32574754.0, \"Song ID\": \"161DnLWsx1i3u1JT05lzqU\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2010-10-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 83.0, \"Danceability\": 0.523, \"Energy\": 0.606, \"Loudness\": -4.754, \"Speechiness\": 0.0301, \"Acousticness\": 0.512, \"Liveness\": 0.106, \"Tempo\": 145.837, \"Duration (ms)\": 217867.0, \"Valence\": 0.065, \"Chord\": \"C#/Db\"}, {\"Index\": 107, \"Highest Charting Position\": 3, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Roses - Imanbek Remix\", \"Streams\": 6653690, \"Artist\": \"SAINt JHN\", \"Artist Followers\": 742692.0, \"Song ID\": \"0zLCBJZSiELJf02ucPP9wb\", \"Genre\": \"['melodic rap', 'pop rap', 'rap', 'slap house', 'trap']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.769, \"Energy\": 0.719, \"Loudness\": -5.472, \"Speechiness\": 0.0474, \"Acousticness\": 0.0143, \"Liveness\": 0.359, \"Tempo\": 121.955, \"Duration (ms)\": 176867.0, \"Valence\": 0.863, \"Chord\": \"G#/Ab\"}, {\"Index\": 108, \"Highest Charting Position\": 59, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Sal y Perrea\", \"Streams\": 6635076, \"Artist\": \"Sech\", \"Artist Followers\": 8758283.0, \"Song ID\": \"5u7twkeask1VIyDeNTElSU\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-04-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 86.0, \"Danceability\": 0.786, \"Energy\": 0.899, \"Loudness\": -0.515, \"Speechiness\": 0.127, \"Acousticness\": 0.192, \"Liveness\": 0.299, \"Tempo\": 90.025, \"Duration (ms)\": 216510.0, \"Valence\": 0.813, \"Chord\": \"A#/Bb\"}, {\"Index\": 109, \"Highest Charting Position\": 109, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Fulanito\", \"Streams\": 6614072, \"Artist\": \"Becky G, El Alfa\", \"Artist Followers\": 10356559.0, \"Song ID\": \"59L8x0xy8njj75vzVCPMqg\", \"Genre\": \"['dance pop', 'latin', 'latin pop', 'latin viral pop', 'pop', 'rap latina', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-06-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 86.0, \"Danceability\": 0.93, \"Energy\": 0.837, \"Loudness\": -4.632, \"Speechiness\": 0.187, \"Acousticness\": 0.256, \"Liveness\": 0.239, \"Tempo\": 111.898, \"Duration (ms)\": 158532.0, \"Valence\": 0.821, \"Chord\": \"G\"}, {\"Index\": 110, \"Highest Charting Position\": 110, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Par\\u00eds\", \"Streams\": 6584896, \"Artist\": \"Ingratax\", \"Artist Followers\": 56699.0, \"Song ID\": \"4bF2y8rR7GUjrd5LNEvej3\", \"Genre\": \"[]\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 86.0, \"Danceability\": 0.57, \"Energy\": 0.455, \"Loudness\": -5.748, \"Speechiness\": 0.0996, \"Acousticness\": 0.441, \"Liveness\": 0.0654, \"Tempo\": 167.933, \"Duration (ms)\": 151429.0, \"Valence\": 0.399, \"Chord\": \"C#/Db\"}, {\"Index\": 111, \"Highest Charting Position\": 46, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"lovely (with Khalid)\", \"Streams\": 6569547, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47014200.0, \"Song ID\": \"0u2P5u6lvoDfwTYjAADbn4\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2018-04-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.351, \"Energy\": 0.296, \"Loudness\": -10.109, \"Speechiness\": 0.0333, \"Acousticness\": 0.934, \"Liveness\": 0.095, \"Tempo\": 115.284, \"Duration (ms)\": 200186.0, \"Valence\": 0.12, \"Chord\": \"E\"}, {\"Index\": 112, \"Highest Charting Position\": 24, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Sunflower - Spider-Man: Into the Spider-Verse\", \"Streams\": 6546948, \"Artist\": \"Post Malone, Swae Lee\", \"Artist Followers\": 1250353.0, \"Song ID\": \"3KkXRkHbMCARz0aVfEt68P\", \"Genre\": \"[]\", \"Release Date\": \"2018-12-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.76, \"Energy\": 0.479, \"Loudness\": -5.574, \"Speechiness\": 0.0466, \"Acousticness\": 0.556, \"Liveness\": 0.0703, \"Tempo\": 89.911, \"Duration (ms)\": 158040.0, \"Valence\": 0.913, \"Chord\": \"D\"}, {\"Index\": 113, \"Highest Charting Position\": 113, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"double take\", \"Streams\": 6539852, \"Artist\": \"dhruv\", \"Artist Followers\": 73211.0, \"Song ID\": \"2CVChktEKBsM6v4IfdFU5k\", \"Genre\": \"['chill r&b', 'nyc pop']\", \"Release Date\": \"2019-05-24\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 86.0, \"Danceability\": 0.663, \"Energy\": 0.434, \"Loudness\": -11.177, \"Speechiness\": 0.0648, \"Acousticness\": 0.828, \"Liveness\": 0.249, \"Tempo\": 109.075, \"Duration (ms)\": 171743.0, \"Valence\": 0.225, \"Chord\": \"G#/Ab\"}, {\"Index\": 114, \"Highest Charting Position\": 9, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Streets\", \"Streams\": 6502302, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"60ynsPSSKe6O3sfwRnIBRf\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 86.0, \"Danceability\": 0.749, \"Energy\": 0.463, \"Loudness\": -8.433, \"Speechiness\": 0.0842, \"Acousticness\": 0.21, \"Liveness\": 0.338, \"Tempo\": 90.035, \"Duration (ms)\": 226987.0, \"Valence\": 0.189, \"Chord\": \"B\"}, {\"Index\": 115, \"Highest Charting Position\": 80, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"By Your Side (feat. Tom Grennan)\", \"Streams\": 6488622, \"Artist\": \"Calvin Harris\", \"Artist Followers\": 21942793.0, \"Song ID\": \"0vR2rIVORmgeKiGIgNT0fV\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'house', 'pop', 'progressive house', 'uk dance']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 85.0, \"Danceability\": 0.733, \"Energy\": 0.96, \"Loudness\": -3.597, \"Speechiness\": 0.0295, \"Acousticness\": 0.0514, \"Liveness\": 0.287, \"Tempo\": 124.01, \"Duration (ms)\": 189672.0, \"Valence\": 0.811, \"Chord\": \"G\"}, {\"Index\": 116, \"Highest Charting Position\": 116, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"MORENA\", \"Streams\": 6469500, \"Artist\": \"Luan Santana\", \"Artist Followers\": 5420471.0, \"Song ID\": \"4PQdrXMDHDPl1RczrrlADd\", \"Genre\": \"['sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2021-06-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 85.0, \"Danceability\": 0.526, \"Energy\": 0.731, \"Loudness\": -4.662, \"Speechiness\": 0.0887, \"Acousticness\": 0.18, \"Liveness\": 0.0891, \"Tempo\": 86.959, \"Duration (ms)\": 193221.0, \"Valence\": 0.476, \"Chord\": \"B\"}, {\"Index\": 117, \"Highest Charting Position\": 80, \"Number of Times Charted\": 80, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Shape of You\", \"Streams\": 6452492, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83293380.0, \"Song ID\": \"7qiZfU4dY1lWllzX7mPBI3\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2017-03-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.825, \"Energy\": 0.652, \"Loudness\": -3.183, \"Speechiness\": 0.0802, \"Acousticness\": 0.581, \"Liveness\": 0.0931, \"Tempo\": 95.977, \"Duration (ms)\": 233713.0, \"Valence\": 0.931, \"Chord\": \"C#/Db\"}, {\"Index\": 118, \"Highest Charting Position\": 9, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Se\\u00f1orita\", \"Streams\": 6317487, \"Artist\": \"Shawn Mendes, Camila Cabello\", \"Artist Followers\": 33879560.0, \"Song ID\": \"0TK2YIli7K1leLovkQiNik\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.759, \"Energy\": 0.54, \"Loudness\": -6.039, \"Speechiness\": 0.0287, \"Acousticness\": 0.037, \"Liveness\": 0.0945, \"Tempo\": 116.947, \"Duration (ms)\": 190960.0, \"Valence\": 0.75, \"Chord\": \"A\"}, {\"Index\": 119, \"Highest Charting Position\": 5, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Hold On\", \"Streams\": 6300416, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 1250353.0, \"Song ID\": \"49xx65gvlD7xXjDTavFqaJ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 0.0, \"Danceability\": 0.658, \"Energy\": 0.634, \"Loudness\": -5.797, \"Speechiness\": 0.0413, \"Acousticness\": 0.0106, \"Liveness\": 0.132, \"Tempo\": 139.98, \"Duration (ms)\": 170813.0, \"Valence\": 0.29, \"Chord\": \"C#/Db\"}, {\"Index\": 120, \"Highest Charting Position\": 99, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Perfect\", \"Streams\": 6278765, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83293380.0, \"Song ID\": \"0tgVpDi06FyKpA1z0VMD4v\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2017-03-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 86.0, \"Danceability\": 0.599, \"Energy\": 0.448, \"Loudness\": -6.312, \"Speechiness\": 0.0232, \"Acousticness\": 0.163, \"Liveness\": 0.106, \"Tempo\": 95.05, \"Duration (ms)\": 263400.0, \"Valence\": 0.168, \"Chord\": \"G#/Ab\"}, {\"Index\": 121, \"Highest Charting Position\": 80, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"2:50 Remix\", \"Streams\": 6244011, \"Artist\": \"MYA, TINI, Duki\", \"Artist Followers\": 282045.0, \"Song ID\": \"74znaWw1hmQBusGPSOuTFy\", \"Genre\": \"['latin pop']\", \"Release Date\": \"2021-06-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 85.0, \"Danceability\": 0.818, \"Energy\": 0.812, \"Loudness\": -4.425, \"Speechiness\": 0.0475, \"Acousticness\": 0.112, \"Liveness\": 0.234, \"Tempo\": 139.966, \"Duration (ms)\": 231708.0, \"Valence\": 0.844, \"Chord\": \"A\"}, {\"Index\": 122, \"Highest Charting Position\": 2, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"LA NOCHE DE ANOCHE\", \"Streams\": 6242863, \"Artist\": \"Bad Bunny, ROSAL\\u00cdA\", \"Artist Followers\": 36142273.0, \"Song ID\": \"2XIc1pqjXV3Cr2BQUGNBck\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 86.0, \"Danceability\": 0.856, \"Energy\": 0.618, \"Loudness\": -4.892, \"Speechiness\": 0.286, \"Acousticness\": 0.0303, \"Liveness\": 0.0866, \"Tempo\": 81.993, \"Duration (ms)\": 203201.0, \"Valence\": 0.391, \"Chord\": \"G\"}, {\"Index\": 123, \"Highest Charting Position\": 1, \"Number of Times Charted\": 67, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"ROCKSTAR (feat. Roddy Ricch)\", \"Streams\": 6180056, \"Artist\": \"DaBaby\", \"Artist Followers\": 7593046.0, \"Song ID\": \"7ytR5pFWmSjzHJIeQkgog4\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 86.0, \"Danceability\": 0.746, \"Energy\": 0.69, \"Loudness\": -7.956, \"Speechiness\": 0.164, \"Acousticness\": 0.247, \"Liveness\": 0.101, \"Tempo\": 89.977, \"Duration (ms)\": 181733.0, \"Valence\": 0.497, \"Chord\": \"B\"}, {\"Index\": 124, \"Highest Charting Position\": 12, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Heather\", \"Streams\": 6164795, \"Artist\": \"Conan Gray\", \"Artist Followers\": 3794081.0, \"Song ID\": \"4xqrdfXkTW4T0RauPLv3WA\", \"Genre\": \"['alt z', 'bedroom pop', 'electropop', 'indie pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 86.0, \"Danceability\": 0.357, \"Energy\": 0.425, \"Loudness\": -7.301, \"Speechiness\": 0.0333, \"Acousticness\": 0.584, \"Liveness\": 0.322, \"Tempo\": 102.078, \"Duration (ms)\": 198040.0, \"Valence\": 0.27, \"Chord\": \"F\"}, {\"Index\": 125, \"Highest Charting Position\": 13, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"you broke me first\", \"Streams\": 6152121, \"Artist\": \"Tate McRae\", \"Artist Followers\": 1647262.0, \"Song ID\": \"45bE4HXI0AwGZXfZtMp8JR\", \"Genre\": \"['alt z', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 86.0, \"Danceability\": 0.667, \"Energy\": 0.373, \"Loudness\": -9.389, \"Speechiness\": 0.05, \"Acousticness\": 0.785, \"Liveness\": 0.0906, \"Tempo\": 124.148, \"Duration (ms)\": 169266.0, \"Valence\": 0.0823, \"Chord\": \"E\"}, {\"Index\": 126, \"Highest Charting Position\": 126, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"The Nights\", \"Streams\": 6136340, \"Artist\": \"Avicii\", \"Artist Followers\": 20270895.0, \"Song ID\": \"0ct6r3EGTcMLPtrXHDvVjc\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance']\", \"Release Date\": \"2014-01-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 85.0, \"Danceability\": 0.527, \"Energy\": 0.835, \"Loudness\": -5.298, \"Speechiness\": 0.0433, \"Acousticness\": 0.0166, \"Liveness\": 0.249, \"Tempo\": 125.983, \"Duration (ms)\": 176658.0, \"Valence\": 0.654, \"Chord\": \"F#/Gb\"}, {\"Index\": 127, \"Highest Charting Position\": 122, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Riptide\", \"Streams\": 6089242, \"Artist\": \"Vance Joy\", \"Artist Followers\": 2421254.0, \"Song ID\": \"3JvrhDOgAt6p7K8mDyZwRd\", \"Genre\": \"['folk-pop', 'modern rock', 'pop', 'pop rock']\", \"Release Date\": \"2014-09-09\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 78.0, \"Danceability\": 0.484, \"Energy\": 0.731, \"Loudness\": -6.694, \"Speechiness\": 0.0379, \"Acousticness\": 0.431, \"Liveness\": 0.151, \"Tempo\": 101.654, \"Duration (ms)\": 204280.0, \"Valence\": 0.51, \"Chord\": \"C#/Db\"}, {\"Index\": 128, \"Highest Charting Position\": 128, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Smells Like Teen Spirit\", \"Streams\": 6065267, \"Artist\": \"Nirvana\", \"Artist Followers\": 13261089.0, \"Song ID\": \"5ghIJDpPoe3CfHMGu71E6T\", \"Genre\": \"['grunge', 'permanent wave', 'rock']\", \"Release Date\": \"1991-09-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\", \"Popularity\": 77.0, \"Danceability\": 0.502, \"Energy\": 0.912, \"Loudness\": -4.556, \"Speechiness\": 0.0564, \"Acousticness\": 2.55e-05, \"Liveness\": 0.106, \"Tempo\": 116.761, \"Duration (ms)\": 301920.0, \"Valence\": 0.72, \"Chord\": \"C#/Db\"}, {\"Index\": 129, \"Highest Charting Position\": 11, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"enough for you\", \"Streams\": 6040918, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"2TOzTqQXNmR2zDJXihjZ2e\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 86.0, \"Danceability\": 0.638, \"Energy\": 0.259, \"Loudness\": -10.706, \"Speechiness\": 0.0898, \"Acousticness\": 0.753, \"Liveness\": 0.219, \"Tempo\": 88.485, \"Duration (ms)\": 202827.0, \"Valence\": 0.269, \"Chord\": \"G\"}, {\"Index\": 130, \"Highest Charting Position\": 99, \"Number of Times Charted\": 42, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Daddy Issues\", \"Streams\": 6014443, \"Artist\": \"The Neighbourhood\", \"Artist Followers\": 6662605.0, \"Song ID\": \"5E30LdtzQTGqRvNd7l6kG5\", \"Genre\": \"['modern alternative rock', 'modern rock', 'pop']\", \"Release Date\": \"2015-10-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 85.0, \"Danceability\": 0.588, \"Energy\": 0.521, \"Loudness\": -9.461, \"Speechiness\": 0.0329, \"Acousticness\": 0.0678, \"Liveness\": 0.123, \"Tempo\": 85.012, \"Duration (ms)\": 260173.0, \"Valence\": 0.337, \"Chord\": \"A#/Bb\"}, {\"Index\": 131, \"Highest Charting Position\": 131, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Aquelas Coisas\", \"Streams\": 6012839, \"Artist\": \"Jo\\u00e3o Gomes\", \"Artist Followers\": 409173.0, \"Song ID\": \"0FqVtQxRD3HsPltldG5v5M\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 84.0, \"Danceability\": 0.682, \"Energy\": 0.873, \"Loudness\": -4.163, \"Speechiness\": 0.0449, \"Acousticness\": 0.402, \"Liveness\": 0.0946, \"Tempo\": 150.006, \"Duration (ms)\": 147072.0, \"Valence\": 0.964, \"Chord\": \"F#/Gb\"}, {\"Index\": 132, \"Highest Charting Position\": 19, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Miss The Rage (feat. Playboi Carti)\", \"Streams\": 5952490, \"Artist\": \"Trippie Redd\", \"Artist Followers\": 6430522.0, \"Song ID\": \"2BITQ360Knh6qNAOqR7Dyq\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2021-05-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 85.0, \"Danceability\": 0.584, \"Energy\": 0.859, \"Loudness\": -5.616, \"Speechiness\": 0.121, \"Acousticness\": 0.0144, \"Liveness\": 0.847, \"Tempo\": 77.005, \"Duration (ms)\": 236883.0, \"Valence\": 0.369, \"Chord\": \"G#/Ab\"}, {\"Index\": 133, \"Highest Charting Position\": 4, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Memories\", \"Streams\": 5928329, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32262679.0, \"Song ID\": \"4cktbXiXOapiLBMprHFErI\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.775, \"Energy\": 0.327, \"Loudness\": -7.241, \"Speechiness\": 0.0557, \"Acousticness\": 0.841, \"Liveness\": 0.0821, \"Tempo\": 91.05, \"Duration (ms)\": 189486.0, \"Valence\": 0.595, \"Chord\": \"B\"}, {\"Index\": 134, \"Highest Charting Position\": 76, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Another Love\", \"Streams\": 5914661, \"Artist\": \"Tom Odell\", \"Artist Followers\": 1838616.0, \"Song ID\": \"7otCGmgp9h4CsR2LhwB6gt\", \"Genre\": \"['pop']\", \"Release Date\": \"2013-09-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 67.0, \"Danceability\": 0.445, \"Energy\": 0.537, \"Loudness\": -8.532, \"Speechiness\": 0.04, \"Acousticness\": 0.695, \"Liveness\": 0.0941, \"Tempo\": 122.764, \"Duration (ms)\": 244360.0, \"Valence\": 0.131, \"Chord\": \"E\"}, {\"Index\": 135, \"Highest Charting Position\": 135, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Here's Your Perfect\", \"Streams\": 5912784, \"Artist\": \"Jamie Miller\", \"Artist Followers\": 64288.0, \"Song ID\": \"2aTKrdenCq5qBOoJPFdn4P\", \"Genre\": \"['pop soul']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 85.0, \"Danceability\": 0.558, \"Energy\": 0.454, \"Loudness\": -5.335, \"Speechiness\": 0.0551, \"Acousticness\": 0.499, \"Liveness\": 0.146, \"Tempo\": 113.12, \"Duration (ms)\": 158594.0, \"Valence\": 0.424, \"Chord\": \"F#/Gb\"}, {\"Index\": 136, \"Highest Charting Position\": 108, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Take Me To Church\", \"Streams\": 5907750, \"Artist\": \"Hozier\", \"Artist Followers\": 4781906.0, \"Song ID\": \"1CS7Sd1u5tWkstBhpssyjP\", \"Genre\": \"['irish singer-songwriter', 'modern rock', 'pop']\", \"Release Date\": \"2014-09-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 74.0, \"Danceability\": 0.566, \"Energy\": 0.664, \"Loudness\": -5.303, \"Speechiness\": 0.0464, \"Acousticness\": 0.634, \"Liveness\": 0.116, \"Tempo\": 128.945, \"Duration (ms)\": 241693.0, \"Valence\": 0.437, \"Chord\": \"E\"}, {\"Index\": 137, \"Highest Charting Position\": 110, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Little Bit of Love\", \"Streams\": 5848466, \"Artist\": \"Tom Grennan\", \"Artist Followers\": 261225.0, \"Song ID\": \"2sX7lJXsOYGP1Us6CqM9t1\", \"Genre\": \"['modern rock', 'uk pop']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 80.0, \"Danceability\": 0.689, \"Energy\": 0.706, \"Loudness\": -4.48, \"Speechiness\": 0.0312, \"Acousticness\": 0.0833, \"Liveness\": 0.105, \"Tempo\": 106.52, \"Duration (ms)\": 226268.0, \"Valence\": 0.623, \"Chord\": \"C#/Db\"}, {\"Index\": 138, \"Highest Charting Position\": 138, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Ficha Limpa\", \"Streams\": 5847975, \"Artist\": \"Gusttavo Lima\", \"Artist Followers\": 12969190.0, \"Song ID\": \"5SwyN9hzmWjBsINlif8li8\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2021-06-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 85.0, \"Danceability\": 0.774, \"Energy\": 0.732, \"Loudness\": -4.227, \"Speechiness\": 0.0308, \"Acousticness\": 0.108, \"Liveness\": 0.243, \"Tempo\": 135.005, \"Duration (ms)\": 192725.0, \"Valence\": 0.734, \"Chord\": \"A\"}, {\"Index\": 139, \"Highest Charting Position\": 14, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Up\", \"Streams\": 5845156, \"Artist\": \"Cardi B\", \"Artist Followers\": 17353707.0, \"Song ID\": \"1XXimziG1uhM0eDNCZCrUl\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'rap']\", \"Release Date\": \"2021-02-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 83.0, \"Danceability\": 0.868, \"Energy\": 0.795, \"Loudness\": -6.044, \"Speechiness\": 0.269, \"Acousticness\": 0.0012, \"Liveness\": 0.0461, \"Tempo\": 166.0, \"Duration (ms)\": 156945.0, \"Valence\": 0.819, \"Chord\": \"B\"}, {\"Index\": 140, \"Highest Charting Position\": 2, \"Number of Times Charted\": 52, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Haw\\u00e1i\", \"Streams\": 5769714, \"Artist\": \"Maluma\", \"Artist Followers\": 26769304.0, \"Song ID\": \"0GzuHFG4Ql6DoyxFRnIk3F\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-11-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 77.0, \"Danceability\": 0.766, \"Energy\": 0.788, \"Loudness\": -3.128, \"Speechiness\": 0.312, \"Acousticness\": 0.105, \"Liveness\": 0.142, \"Tempo\": 179.984, \"Duration (ms)\": 200482.0, \"Valence\": 0.609, \"Chord\": \"F#/Gb\"}, {\"Index\": 141, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"New Normal\", \"Streams\": 5768653, \"Artist\": \"Khalid\", \"Artist Followers\": 14187747.0, \"Song ID\": \"2CIYemjFXdmCWpJnfbtrD6\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-07-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 79.0, \"Danceability\": 0.39, \"Energy\": 0.534, \"Loudness\": -9.575, \"Speechiness\": 0.0709, \"Acousticness\": 0.0807, \"Liveness\": 0.184, \"Tempo\": 92.047, \"Duration (ms)\": 198765.0, \"Valence\": 0.244, \"Chord\": \"C\"}, {\"Index\": 142, \"Highest Charting Position\": 81, \"Number of Times Charted\": 81, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Bohemian Rhapsody - Remastered 2011\", \"Streams\": 5756583, \"Artist\": \"Queen\", \"Artist Followers\": 35888760.0, \"Song ID\": \"7tFiyTwD0nx5a1eklYtX2J\", \"Genre\": \"['classic rock', 'glam rock', 'rock']\", \"Release Date\": \"1975-11-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.392, \"Energy\": 0.402, \"Loudness\": -9.961, \"Speechiness\": 0.0536, \"Acousticness\": 0.288, \"Liveness\": 0.243, \"Tempo\": 143.883, \"Duration (ms)\": 354320.0, \"Valence\": 0.228, \"Chord\": \"C\"}, {\"Index\": 143, \"Highest Charting Position\": 5, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Bandido\", \"Streams\": 5734402, \"Artist\": \"Myke Towers, Juhn\", \"Artist Followers\": 6150675.0, \"Song ID\": \"1xK1Gg9SxG8fy2Ya373oqb\", \"Genre\": \"['trap latino']\", \"Release Date\": \"2020-12-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\", \"Popularity\": 85.0, \"Danceability\": 0.713, \"Energy\": 0.617, \"Loudness\": -4.637, \"Speechiness\": 0.0887, \"Acousticness\": 0.122, \"Liveness\": 0.0962, \"Tempo\": 168.021, \"Duration (ms)\": 232853.0, \"Valence\": 0.682, \"Chord\": \"G#/Ab\"}, {\"Index\": 144, \"Highest Charting Position\": 25, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Paradise (feat. Dermot Kennedy)\", \"Streams\": 5693848, \"Artist\": \"MEDUZA\", \"Artist Followers\": 441674.0, \"Song ID\": \"6ft4hAq6yde8jPZY2i5zLr\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop house', 'tropical house']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 85.0, \"Danceability\": 0.632, \"Energy\": 0.595, \"Loudness\": -7.644, \"Speechiness\": 0.0401, \"Acousticness\": 0.0689, \"Liveness\": 0.209, \"Tempo\": 124.114, \"Duration (ms)\": 167903.0, \"Valence\": 0.435, \"Chord\": \"G#/Ab\"}, {\"Index\": 145, \"Highest Charting Position\": 13, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"goosebumps\", \"Streams\": 5691540, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17719446.0, \"Song ID\": \"5uEYRdEIh9Bo4fpjDd4Na9\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 87.0, \"Danceability\": 0.841, \"Energy\": 0.593, \"Loudness\": -7.846, \"Speechiness\": 0.0379, \"Acousticness\": 0.418, \"Liveness\": 0.124, \"Tempo\": 124.917, \"Duration (ms)\": 162803.0, \"Valence\": 0.808, \"Chord\": \"C#/Db\"}, {\"Index\": 146, \"Highest Charting Position\": 90, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Wasted Love (feat. Lagique)\", \"Streams\": 5690260, \"Artist\": \"Ofenbach\", \"Artist Followers\": 432581.0, \"Song ID\": \"2pPO9YecZimmuVQfIzfV6U\", \"Genre\": \"['edm', 'new french touch', 'pop dance', 'tropical house']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 85.0, \"Danceability\": 0.734, \"Energy\": 0.855, \"Loudness\": -4.578, \"Speechiness\": 0.135, \"Acousticness\": 0.0821, \"Liveness\": 0.0901, \"Tempo\": 121.955, \"Duration (ms)\": 139563.0, \"Valence\": 0.54, \"Chord\": \"F#/Gb\"}, {\"Index\": 147, \"Highest Charting Position\": 100, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"KESI - Remix\", \"Streams\": 5682062, \"Artist\": \"Camilo, Shawn Mendes\", \"Artist Followers\": 10561047.0, \"Song ID\": \"0IqCoZ168iRc9LqfrYgpZy\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2021-07-14\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 83.0, \"Danceability\": 0.871, \"Energy\": 0.815, \"Loudness\": -4.439, \"Speechiness\": 0.0477, \"Acousticness\": 0.127, \"Liveness\": 0.094, \"Tempo\": 122.959, \"Duration (ms)\": 176575.0, \"Valence\": 0.823, \"Chord\": \"E\"}, {\"Index\": 148, \"Highest Charting Position\": 59, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Shallow\", \"Streams\": 5672480, \"Artist\": \"Lady Gaga, Bradley Cooper\", \"Artist Followers\": 18572085.0, \"Song ID\": \"2VxeLyX666F8uXCJ0dZF8B\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-10-05\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.572, \"Energy\": 0.385, \"Loudness\": -6.362, \"Speechiness\": 0.0308, \"Acousticness\": 0.371, \"Liveness\": 0.231, \"Tempo\": 95.799, \"Duration (ms)\": 215733.0, \"Valence\": 0.323, \"Chord\": \"G\"}, {\"Index\": 149, \"Highest Charting Position\": 110, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Tell Em\", \"Streams\": 5668576, \"Artist\": \"Cochise, $NOT\", \"Artist Followers\": 159647.0, \"Song ID\": \"7nc7mlSdWYeFom84zZ8Wr8\", \"Genre\": \"['plugg', 'vapor trap', 'viral rap']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\", \"Popularity\": 85.0, \"Danceability\": 0.672, \"Energy\": 0.717, \"Loudness\": -7.476, \"Speechiness\": 0.226, \"Acousticness\": 0.103, \"Liveness\": 0.398, \"Tempo\": 157.905, \"Duration (ms)\": 180380.0, \"Valence\": 0.473, \"Chord\": \"F\"}, {\"Index\": 150, \"Highest Charting Position\": 103, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"N\\u00e3o, N\\u00e3o Vou\", \"Streams\": 5652272, \"Artist\": \"Mari Fernandez\", \"Artist Followers\": 15889.0, \"Song ID\": \"0xBQvhJAm6f7J142ympKOn\", \"Genre\": \"[]\", \"Release Date\": \"2021-04-29\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.631, \"Energy\": 0.861, \"Loudness\": -1.891, \"Speechiness\": 0.0424, \"Acousticness\": 0.427, \"Liveness\": 0.215, \"Tempo\": 149.95, \"Duration (ms)\": 173038.0, \"Valence\": 0.822, \"Chord\": \"B\"}, {\"Index\": 151, \"Highest Charting Position\": 147, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Counting Stars\", \"Streams\": 5647568, \"Artist\": \"OneRepublic\", \"Artist Followers\": 12169108.0, \"Song ID\": \"6sy3LkhNFjJWlaeSMNwQ62\", \"Genre\": \"['dance pop', 'piano rock', 'pop', 'pop rock']\", \"Release Date\": \"2014-01-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 74.0, \"Danceability\": 0.664, \"Energy\": 0.705, \"Loudness\": -4.972, \"Speechiness\": 0.0382, \"Acousticness\": 0.0654, \"Liveness\": 0.115, \"Tempo\": 122.017, \"Duration (ms)\": 257840.0, \"Valence\": 0.477, \"Chord\": \"C#/Db\"}, {\"Index\": 152, \"Highest Charting Position\": 121, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Yellow\", \"Streams\": 5628703, \"Artist\": \"Coldplay\", \"Artist Followers\": 31151294.0, \"Song ID\": \"3AJwUDP919kvQ9QcozQPxg\", \"Genre\": \"['permanent wave', 'pop']\", \"Release Date\": \"2000-07-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 85.0, \"Danceability\": 0.429, \"Energy\": 0.661, \"Loudness\": -7.227, \"Speechiness\": 0.0281, \"Acousticness\": 0.00239, \"Liveness\": 0.234, \"Tempo\": 173.372, \"Duration (ms)\": 266773.0, \"Valence\": 0.285, \"Chord\": \"B\"}, {\"Index\": 153, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Como Si No Importara\", \"Streams\": 5627257, \"Artist\": \"Emilia, Duki\", \"Artist Followers\": 205590.0, \"Song ID\": \"1GYJpuLq41vEVKXiHGEY9j\", \"Genre\": \"[]\", \"Release Date\": \"2021-07-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 83.0, \"Danceability\": 0.843, \"Energy\": 0.534, \"Loudness\": -6.658, \"Speechiness\": 0.142, \"Acousticness\": 0.467, \"Liveness\": 0.0984, \"Tempo\": 94.984, \"Duration (ms)\": 173053.0, \"Valence\": 0.528, \"Chord\": \"C#/Db\"}, {\"Index\": 154, \"Highest Charting Position\": 154, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Se For Amor\", \"Streams\": 5618268, \"Artist\": \"Jo\\u00e3o Gomes, Vitor Fernandes\", \"Artist Followers\": 409173.0, \"Song ID\": \"5F2xRvRFkxDvqdFtUNAEyw\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 81.0, \"Danceability\": 0.667, \"Energy\": 0.899, \"Loudness\": -4.402, \"Speechiness\": 0.0322, \"Acousticness\": 0.423, \"Liveness\": 0.332, \"Tempo\": 147.962, \"Duration (ms)\": 239928.0, \"Valence\": 0.835, \"Chord\": \"B\"}, {\"Index\": 155, \"Highest Charting Position\": 142, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Wake Me Up\", \"Streams\": 5607285, \"Artist\": \"Avicii\", \"Artist Followers\": 20270895.0, \"Song ID\": \"0nrRP2bk19rLc0orkWPQk2\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance']\", \"Release Date\": \"2013-01-01\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-01--2021-01-08\\n2020-08-07--2020-08-14\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.532, \"Energy\": 0.783, \"Loudness\": -5.697, \"Speechiness\": 0.0523, \"Acousticness\": 0.0038, \"Liveness\": 0.161, \"Tempo\": 124.08, \"Duration (ms)\": 247427.0, \"Valence\": 0.643, \"Chord\": \"D\"}, {\"Index\": 156, \"Highest Charting Position\": 128, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Baby Me Atende\", \"Streams\": 5594505, \"Artist\": \"Matheus Fernandes, Dilsinho\", \"Artist Followers\": 77034.0, \"Song ID\": \"5R9KPXQVeyqsHZoPLMgfNy\", \"Genre\": \"['forro', 'sertanejo pop']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 83.0, \"Danceability\": 0.65, \"Energy\": 0.792, \"Loudness\": -3.825, \"Speechiness\": 0.0393, \"Acousticness\": 0.607, \"Liveness\": 0.92, \"Tempo\": 154.027, \"Duration (ms)\": 225672.0, \"Valence\": 0.872, \"Chord\": \"F#/Gb\"}, {\"Index\": 157, \"Highest Charting Position\": 68, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Ramenez la coupe \\u00e0 la maison\", \"Streams\": 5576844, \"Artist\": \"Vegedream\", \"Artist Followers\": 1250353.0, \"Song ID\": \"0dqVP9CnGjaYNjya3gYbYy\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 0.0, \"Danceability\": 0.808, \"Energy\": 0.66, \"Loudness\": -6.237, \"Speechiness\": 0.0395, \"Acousticness\": 0.0358, \"Liveness\": 0.138, \"Tempo\": 107.994, \"Duration (ms)\": 235556.0, \"Valence\": 0.804, \"Chord\": \"C\"}, {\"Index\": 158, \"Highest Charting Position\": 6, \"Number of Times Charted\": 47, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"What You Know Bout Love\", \"Streams\": 5570735, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"1tkg4EHVoqnhR6iFEXb60y\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-07-03--2020-07-10\", \"Popularity\": 85.0, \"Danceability\": 0.709, \"Energy\": 0.548, \"Loudness\": -8.493, \"Speechiness\": 0.353, \"Acousticness\": 0.65, \"Liveness\": 0.133, \"Tempo\": 83.995, \"Duration (ms)\": 160000.0, \"Valence\": 0.543, \"Chord\": \"A#/Bb\"}, {\"Index\": 159, \"Highest Charting Position\": 19, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Runaway\", \"Streams\": 5566150, \"Artist\": \"AURORA\", \"Artist Followers\": 1687399.0, \"Song ID\": \"0TCmhnbMpw5zwPsTvlXTJi\", \"Genre\": \"['art pop', 'norwegian pop']\", \"Release Date\": \"2014\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 77.0, \"Danceability\": 0.521, \"Energy\": 0.277, \"Loudness\": -10.34, \"Speechiness\": 0.0356, \"Acousticness\": 0.634, \"Liveness\": 0.103, \"Tempo\": 115.01, \"Duration (ms)\": 248827.0, \"Valence\": 0.13, \"Chord\": \"B\"}, {\"Index\": 160, \"Highest Charting Position\": 121, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Red Light Green Light\", \"Streams\": 5493760, \"Artist\": \"DaBaby\", \"Artist Followers\": 7593046.0, \"Song ID\": \"1YDebgap5OFwXEBG18NJvy\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.933, \"Energy\": 0.656, \"Loudness\": -5.85, \"Speechiness\": 0.322, \"Acousticness\": 0.129, \"Liveness\": 0.161, \"Tempo\": 119.987, \"Duration (ms)\": 159083.0, \"Valence\": 0.934, \"Chord\": \"D\"}, {\"Index\": 161, \"Highest Charting Position\": 120, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Ball If I Want To\", \"Streams\": 5478055, \"Artist\": \"DaBaby\", \"Artist Followers\": 7593046.0, \"Song ID\": \"0cu0rhnlCnJ7JIeHRiLpj3\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\", \"Popularity\": 84.0, \"Danceability\": 0.902, \"Energy\": 0.669, \"Loudness\": -5.049, \"Speechiness\": 0.457, \"Acousticness\": 0.161, \"Liveness\": 0.0728, \"Tempo\": 139.949, \"Duration (ms)\": 112547.0, \"Valence\": 0.628, \"Chord\": \"C#/Db\"}, {\"Index\": 162, \"Highest Charting Position\": 31, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lucid Dreams\", \"Streams\": 5477563, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"285pBltuF7vW8TeWk8hdRR\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2018-12-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.511, \"Energy\": 0.566, \"Loudness\": -7.23, \"Speechiness\": 0.2, \"Acousticness\": 0.349, \"Liveness\": 0.34, \"Tempo\": 83.903, \"Duration (ms)\": 239836.0, \"Valence\": 0.218, \"Chord\": \"F#/Gb\"}, {\"Index\": 163, \"Highest Charting Position\": 4, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Calling My Phone\", \"Streams\": 5467753, \"Artist\": \"Lil Tjay, 6LACK\", \"Artist Followers\": 3553442.0, \"Song ID\": \"3J8EOeKLTLXORtWPpOU5bE\", \"Genre\": \"['brooklyn drill', 'melodic rap', 'nyc rap']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 85.0, \"Danceability\": 0.907, \"Energy\": 0.393, \"Loudness\": -7.636, \"Speechiness\": 0.0539, \"Acousticness\": 0.451, \"Liveness\": 0.135, \"Tempo\": 104.949, \"Duration (ms)\": 205458.0, \"Valence\": 0.202, \"Chord\": \"E\"}, {\"Index\": 164, \"Highest Charting Position\": 5, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"34+35\", \"Streams\": 5453159, \"Artist\": \"Ariana Grande\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 165, \"Highest Charting Position\": 13, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"bad guy\", \"Streams\": 5436286, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"1hewNsVmijBqjKvFRQfk4m\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.701, \"Energy\": 0.425, \"Loudness\": -10.965, \"Speechiness\": 0.375, \"Acousticness\": 0.328, \"Liveness\": 0.1, \"Tempo\": 135.128, \"Duration (ms)\": 194088.0, \"Valence\": 0.562, \"Chord\": \"G\"}, {\"Index\": 166, \"Highest Charting Position\": 59, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Cover Me In Sunshine\", \"Streams\": 5434073, \"Artist\": \"P!nk, Willow Sage Hart\", \"Artist Followers\": 11477164.0, \"Song ID\": \"6Tio0ZoDeSQnI7EBAqWer2\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-02-12\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 83.0, \"Danceability\": 0.476, \"Energy\": 0.594, \"Loudness\": -6.879, \"Speechiness\": 0.135, \"Acousticness\": 0.0599, \"Liveness\": 0.0785, \"Tempo\": 159.702, \"Duration (ms)\": 141050.0, \"Valence\": 0.314, \"Chord\": \"F\"}, {\"Index\": 167, \"Highest Charting Position\": 7, \"Number of Times Charted\": 56, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"For The Night (feat. Lil Baby & DaBaby)\", \"Streams\": 5431375, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"0PvFJmanyNQMseIFrU708S\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 84.0, \"Danceability\": 0.823, \"Energy\": 0.586, \"Loudness\": -6.606, \"Speechiness\": 0.2, \"Acousticness\": 0.114, \"Liveness\": 0.193, \"Tempo\": 125.971, \"Duration (ms)\": 190476.0, \"Valence\": 0.347, \"Chord\": \"F#/Gb\"}, {\"Index\": 168, \"Highest Charting Position\": 13, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"1 step forward, 3 steps back\", \"Streams\": 5420003, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"4wcBRRpIfesgcyUtis7PEg\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 85.0, \"Danceability\": 0.473, \"Energy\": 0.203, \"Loudness\": -12.627, \"Speechiness\": 0.102, \"Acousticness\": 0.941, \"Liveness\": 0.126, \"Tempo\": 168.884, \"Duration (ms)\": 163587.0, \"Valence\": 0.419, \"Chord\": \"D\"}, {\"Index\": 169, \"Highest Charting Position\": 1, \"Number of Times Charted\": 51, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"WAP (feat. Megan Thee Stallion)\", \"Streams\": 5386268, \"Artist\": \"Cardi B\", \"Artist Followers\": 17353707.0, \"Song ID\": \"4Oun2ylbjFKMPTiaSbbCih\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'rap']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 84.0, \"Danceability\": 0.935, \"Energy\": 0.454, \"Loudness\": -7.509, \"Speechiness\": 0.375, \"Acousticness\": 0.0194, \"Liveness\": 0.0824, \"Tempo\": 133.073, \"Duration (ms)\": 187541.0, \"Valence\": 0.357, \"Chord\": \"C#/Db\"}, {\"Index\": 170, \"Highest Charting Position\": 155, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Mr. Brightside\", \"Streams\": 5382191, \"Artist\": \"The Killers\", \"Artist Followers\": 6118063.0, \"Song ID\": \"7oK9VyNzrYvRFo7nQEYkWN\", \"Genre\": \"['dance rock', 'modern rock', 'permanent wave', 'rock']\", \"Release Date\": \"2004-06-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-12--2021-03-19\\n2021-02-26--2021-03-05\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 75.0, \"Danceability\": 0.356, \"Energy\": 0.924, \"Loudness\": -3.74, \"Speechiness\": 0.0808, \"Acousticness\": 0.00101, \"Liveness\": 0.0953, \"Tempo\": 148.017, \"Duration (ms)\": 222587.0, \"Valence\": 0.232, \"Chord\": \"C#/Db\"}, {\"Index\": 171, \"Highest Charting Position\": 144, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Every Breath You Take\", \"Streams\": 5379704, \"Artist\": \"The Police\", \"Artist Followers\": 4339245.0, \"Song ID\": \"1JSTJqkT5qHq8MDJnJbRE1\", \"Genre\": \"['album rock', 'art rock', 'classic rock', 'mellow gold', 'new wave', 'permanent wave', 'rock', 'soft rock']\", \"Release Date\": \"1983-06-17\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-01-01--2021-01-08\\n2020-06-19--2020-06-26\\n2020-06-05--2020-06-12\", \"Popularity\": 83.0, \"Danceability\": 0.82, \"Energy\": 0.452, \"Loudness\": -9.796, \"Speechiness\": 0.0348, \"Acousticness\": 0.543, \"Liveness\": 0.0714, \"Tempo\": 117.401, \"Duration (ms)\": 253920.0, \"Valence\": 0.74, \"Chord\": \"C#/Db\"}, {\"Index\": 172, \"Highest Charting Position\": 20, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Dreams - 2004 Remaster\", \"Streams\": 5378971, \"Artist\": \"Fleetwood Mac\", \"Artist Followers\": 6930669.0, \"Song ID\": \"0ofHAoxe9vBkTCp2UQIavz\", \"Genre\": \"['album rock', 'classic rock', 'mellow gold', 'rock', 'soft rock', 'yacht rock']\", \"Release Date\": \"1977-02-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 84.0, \"Danceability\": 0.828, \"Energy\": 0.492, \"Loudness\": -9.744, \"Speechiness\": 0.0276, \"Acousticness\": 0.0644, \"Liveness\": 0.128, \"Tempo\": 120.151, \"Duration (ms)\": 257800.0, \"Valence\": 0.789, \"Chord\": \"C\"}, {\"Index\": 173, \"Highest Charting Position\": 94, \"Number of Times Charted\": 82, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Say You Won't Let Go\", \"Streams\": 5375426, \"Artist\": \"James Arthur\", \"Artist Followers\": 8441598.0, \"Song ID\": \"5uCax9HTNlzGybIStD3vDh\", \"Genre\": \"['pop', 'post-teen pop', 'talent show', 'uk pop']\", \"Release Date\": \"2016-10-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.358, \"Energy\": 0.557, \"Loudness\": -7.398, \"Speechiness\": 0.059, \"Acousticness\": 0.695, \"Liveness\": 0.0902, \"Tempo\": 85.043, \"Duration (ms)\": 211467.0, \"Valence\": 0.494, \"Chord\": \"A#/Bb\"}, {\"Index\": 174, \"Highest Charting Position\": 110, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Wild Side (feat. Cardi B)\", \"Streams\": 5366242, \"Artist\": \"Normani\", \"Artist Followers\": 1304510.0, \"Song ID\": \"2vXgyN14LX2zl7JEASw242\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop', 'r&b', 'urban contemporary']\", \"Release Date\": \"2021-07-22\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 75.0, \"Danceability\": 0.74, \"Energy\": 0.576, \"Loudness\": -6.744, \"Speechiness\": 0.146, \"Acousticness\": 0.0249, \"Liveness\": 0.104, \"Tempo\": 110.095, \"Duration (ms)\": 209476.0, \"Valence\": 0.315, \"Chord\": \"F#/Gb\"}, {\"Index\": 175, \"Highest Charting Position\": 65, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Bout A Million (feat. 42 Dugg & 21 Savage)\", \"Streams\": 5315734, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"4LaGu95Ui2s4vprSQYWUAZ\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 81.0, \"Danceability\": 0.716, \"Energy\": 0.67, \"Loudness\": -6.995, \"Speechiness\": 0.101, \"Acousticness\": 0.526, \"Liveness\": 0.13, \"Tempo\": 145.043, \"Duration (ms)\": 203586.0, \"Valence\": 0.411, \"Chord\": \"C\"}, {\"Index\": 176, \"Highest Charting Position\": 72, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Demeanor (feat. Dua Lipa)\", \"Streams\": 5245618, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"3DMs7bahbQTnoxCjgP7qoK\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\", \"Popularity\": 81.0, \"Danceability\": 0.675, \"Energy\": 0.608, \"Loudness\": -6.934, \"Speechiness\": 0.103, \"Acousticness\": 0.336, \"Liveness\": 0.11, \"Tempo\": 99.865, \"Duration (ms)\": 184800.0, \"Valence\": 0.728, \"Chord\": \"D#/Eb\"}, {\"Index\": 177, \"Highest Charting Position\": 4, \"Number of Times Charted\": 76, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"death bed (coffee for your head)\", \"Streams\": 5238547, \"Artist\": \"Powfu, beabadoobee\", \"Artist Followers\": 924083.0, \"Song ID\": \"7eJMfftS33KTjuF7lTsMCx\", \"Genre\": \"['sad rap']\", \"Release Date\": \"2020-02-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 85.0, \"Danceability\": 0.726, \"Energy\": 0.431, \"Loudness\": -8.765, \"Speechiness\": 0.135, \"Acousticness\": 0.731, \"Liveness\": 0.696, \"Tempo\": 144.026, \"Duration (ms)\": 173333.0, \"Valence\": 0.348, \"Chord\": \"G#/Ab\"}, {\"Index\": 178, \"Highest Charting Position\": 100, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Our Song\", \"Streams\": 5235335, \"Artist\": \"Anne-Marie, Niall Horan\", \"Artist Followers\": 8148393.0, \"Song ID\": \"5zqObw7wjBgL9TDiAymxPn\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 83.0, \"Danceability\": 0.595, \"Energy\": 0.759, \"Loudness\": -4.245, \"Speechiness\": 0.0423, \"Acousticness\": 0.141, \"Liveness\": 0.172, \"Tempo\": 80.953, \"Duration (ms)\": 163733.0, \"Valence\": 0.515, \"Chord\": \"B\"}, {\"Index\": 179, \"Highest Charting Position\": 138, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Another One Bites The Dust - Remastered 2011\", \"Streams\": 5204983, \"Artist\": \"Queen\", \"Artist Followers\": 35888760.0, \"Song ID\": \"57JVGBtBLCfHw2muk5416J\", \"Genre\": \"['classic rock', 'glam rock', 'rock']\", \"Release Date\": \"1980-06-27\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.933, \"Energy\": 0.528, \"Loudness\": -6.472, \"Speechiness\": 0.162, \"Acousticness\": 0.112, \"Liveness\": 0.163, \"Tempo\": 109.975, \"Duration (ms)\": 214653.0, \"Valence\": 0.756, \"Chord\": \"F\"}, {\"Index\": 180, \"Highest Charting Position\": 149, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"One Dance\", \"Streams\": 5178490, \"Artist\": \"Drake, WizKid, Kyla\", \"Artist Followers\": 56308172.0, \"Song ID\": \"1zi7xx7UVEFkmKfv06H8x0\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2016-05-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\", \"Popularity\": 84.0, \"Danceability\": 0.792, \"Energy\": 0.625, \"Loudness\": -5.609, \"Speechiness\": 0.0536, \"Acousticness\": 0.00776, \"Liveness\": 0.329, \"Tempo\": 103.967, \"Duration (ms)\": 173987.0, \"Valence\": 0.37, \"Chord\": \"C#/Db\"}, {\"Index\": 181, \"Highest Charting Position\": 15, \"Number of Times Charted\": 83, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Adore You\", \"Streams\": 5166847, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16112621.0, \"Song ID\": \"3jjujdWJ72nww5eGnfs2E7\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.676, \"Energy\": 0.771, \"Loudness\": -3.675, \"Speechiness\": 0.0483, \"Acousticness\": 0.0237, \"Liveness\": 0.102, \"Tempo\": 99.048, \"Duration (ms)\": 207133.0, \"Valence\": 0.569, \"Chord\": \"G#/Ab\"}, {\"Index\": 182, \"Highest Charting Position\": 181, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"As the World Caves In\", \"Streams\": 5145493, \"Artist\": \"Sarah Cothran\", \"Artist Followers\": 180723.0, \"Song ID\": \"2xXNLutYAOELYVObYb1C1S\", \"Genre\": \"[]\", \"Release Date\": \"2021-06-10\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-04--2021-06-11\", \"Popularity\": 71.0, \"Danceability\": 0.422, \"Energy\": 0.25, \"Loudness\": -6.836, \"Speechiness\": 0.0351, \"Acousticness\": 0.441, \"Liveness\": 0.35, \"Tempo\": 124.026, \"Duration (ms)\": 161613.0, \"Valence\": 0.246, \"Chord\": \"C\"}, {\"Index\": 183, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Fancy Like\", \"Streams\": 5145432, \"Artist\": \"Walker Hayes\", \"Artist Followers\": 304995.0, \"Song ID\": \"3ZozFqJJlDBNIm4xqxn2ZD\", \"Genre\": \"['contemporary country', 'country', 'country road', 'modern country rock']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 83.0, \"Danceability\": 0.649, \"Energy\": 0.76, \"Loudness\": -6.487, \"Speechiness\": 0.0574, \"Acousticness\": 0.114, \"Liveness\": 0.317, \"Tempo\": 80.018, \"Duration (ms)\": 161853.0, \"Valence\": 0.843, \"Chord\": \"C#/Db\"}, {\"Index\": 184, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"C\\u00farame\", \"Streams\": 5104206, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6080597.0, \"Song ID\": \"3PwRuzdphgedcWVUOVYJ7I\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 85.0, \"Danceability\": 0.765, \"Energy\": 0.625, \"Loudness\": -3.599, \"Speechiness\": 0.0548, \"Acousticness\": 0.584, \"Liveness\": 0.112, \"Tempo\": 102.101, \"Duration (ms)\": 164706.0, \"Valence\": 0.262, \"Chord\": \"A\"}, {\"Index\": 185, \"Highest Charting Position\": 110, \"Number of Times Charted\": 78, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"All of Me\", \"Streams\": 5103014, \"Artist\": \"John Legend\", \"Artist Followers\": 5799137.0, \"Song ID\": \"3U4isOIWM3VvDubwSI3y7a\", \"Genre\": \"['neo soul', 'pop', 'pop soul', 'r&b', 'urban contemporary']\", \"Release Date\": \"2013-08-30\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.422, \"Energy\": 0.264, \"Loudness\": -7.064, \"Speechiness\": 0.0322, \"Acousticness\": 0.922, \"Liveness\": 0.132, \"Tempo\": 119.93, \"Duration (ms)\": 269560.0, \"Valence\": 0.331, \"Chord\": \"G#/Ab\"}, {\"Index\": 186, \"Highest Charting Position\": 80, \"Number of Times Charted\": 41, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Martin & Gina\", \"Streams\": 5098609, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"1VLtjHwRWOVJiE5Py7JxoQ\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 85.0, \"Danceability\": 0.832, \"Energy\": 0.534, \"Loudness\": -7.813, \"Speechiness\": 0.253, \"Acousticness\": 0.345, \"Liveness\": 0.165, \"Tempo\": 93.924, \"Duration (ms)\": 132833.0, \"Valence\": 0.116, \"Chord\": \"C#/Db\"}, {\"Index\": 187, \"Highest Charting Position\": 40, \"Number of Times Charted\": 65, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Dior\", \"Streams\": 5092354, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"79s5XnCN4TJKTVMSmOx8Ep\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2019-07-26\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-06-18--2021-06-25\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 83.0, \"Danceability\": 0.548, \"Energy\": 0.805, \"Loudness\": -5.732, \"Speechiness\": 0.351, \"Acousticness\": 0.212, \"Liveness\": 0.408, \"Tempo\": 142.094, \"Duration (ms)\": 216387.0, \"Valence\": 0.648, \"Chord\": \"G\"}, {\"Index\": 188, \"Highest Charting Position\": 45, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Best Friend (feat. Doja Cat)\", \"Streams\": 5090062, \"Artist\": \"Saweetie\", \"Artist Followers\": 1254432.0, \"Song ID\": \"2etHQJxIbV0soyPhelVs9Y\", \"Genre\": \"['cali rap', 'dance pop', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2021-01-07\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 83.0, \"Danceability\": 0.84, \"Energy\": 0.766, \"Loudness\": -4.12, \"Speechiness\": 0.136, \"Acousticness\": 0.00302, \"Liveness\": 0.0684, \"Tempo\": 94.018, \"Duration (ms)\": 155884.0, \"Valence\": 0.402, \"Chord\": \"E\"}, {\"Index\": 189, \"Highest Charting Position\": 52, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"The Hills\", \"Streams\": 5068864, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35305637.0, \"Song ID\": \"7fBv7CLKzipRk6EC6TWHOB\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2015-08-28\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 84.0, \"Danceability\": 0.585, \"Energy\": 0.564, \"Loudness\": -7.063, \"Speechiness\": 0.0515, \"Acousticness\": 0.0671, \"Liveness\": 0.135, \"Tempo\": 113.003, \"Duration (ms)\": 242253.0, \"Valence\": 0.137, \"Chord\": \"C\"}, {\"Index\": 190, \"Highest Charting Position\": 5, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Good Days\", \"Streams\": 5065132, \"Artist\": \"SZA\", \"Artist Followers\": 5881963.0, \"Song ID\": \"3YJJjQPAbDT7mGpX3WtQ9A\", \"Genre\": \"['pop', 'pop rap', 'r&b']\", \"Release Date\": \"2020-12-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 84.0, \"Danceability\": 0.436, \"Energy\": 0.655, \"Loudness\": -8.37, \"Speechiness\": 0.0583, \"Acousticness\": 0.499, \"Liveness\": 0.688, \"Tempo\": 121.002, \"Duration (ms)\": 279204.0, \"Valence\": 0.412, \"Chord\": \"C#/Db\"}, {\"Index\": 191, \"Highest Charting Position\": 191, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Kiss My (Uh Oh)\", \"Streams\": 5063181, \"Artist\": \"Anne-Marie, Little Mix\", \"Artist Followers\": 8148393.0, \"Song ID\": \"0MWiSBKm8Avs8iDIxcertp\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2021-07-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 78.0, \"Danceability\": 0.638, \"Energy\": 0.878, \"Loudness\": -3.639, \"Speechiness\": 0.0484, \"Acousticness\": 0.0151, \"Liveness\": 0.308, \"Tempo\": 103.948, \"Duration (ms)\": 176800.0, \"Valence\": 0.481, \"Chord\": \"F\"}, {\"Index\": 192, \"Highest Charting Position\": 64, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"De Museo\", \"Streams\": 5016125, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36142273.0, \"Song ID\": \"267NGliXM8YLVZiKAD9Otm\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-06\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\", \"Popularity\": 83.0, \"Danceability\": 0.592, \"Energy\": 0.494, \"Loudness\": -10.618, \"Speechiness\": 0.0747, \"Acousticness\": 0.237, \"Liveness\": 0.13, \"Tempo\": 132.037, \"Duration (ms)\": 209771.0, \"Valence\": 0.231, \"Chord\": \"E\"}, {\"Index\": 193, \"Highest Charting Position\": 41, \"Number of Times Charted\": 81, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"7 rings\", \"Streams\": 5002227, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67158068.0, \"Song ID\": \"6ocbgoVGwYJhOv1GgI9NsF\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-02-08\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 85.0, \"Danceability\": 0.778, \"Energy\": 0.317, \"Loudness\": -10.732, \"Speechiness\": 0.334, \"Acousticness\": 0.592, \"Liveness\": 0.0881, \"Tempo\": 140.048, \"Duration (ms)\": 178627.0, \"Valence\": 0.327, \"Chord\": \"C#/Db\"}, {\"Index\": 194, \"Highest Charting Position\": 194, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Chosen (feat. Ty Dolla $ign)\", \"Streams\": 4992405, \"Artist\": \"Blxst, Tyga\", \"Artist Followers\": 167628.0, \"Song ID\": \"1dIWPXMX4kRHj6Dt2DStUQ\", \"Genre\": \"[]\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 84.0, \"Danceability\": 0.571, \"Energy\": 0.767, \"Loudness\": -5.16, \"Speechiness\": 0.287, \"Acousticness\": 0.336, \"Liveness\": 0.0809, \"Tempo\": 93.421, \"Duration (ms)\": 161684.0, \"Valence\": 0.605, \"Chord\": \"D\"}, {\"Index\": 195, \"Highest Charting Position\": 149, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"N\\u00e3o Nasceu pra Namorar\", \"Streams\": 4978559, \"Artist\": \"MC Zaquin, MC Rick\", \"Artist Followers\": 130627.0, \"Song ID\": \"6pQKUKBpwr6GhfhcFFFozo\", \"Genre\": \"['funk bh', 'funk carioca']\", \"Release Date\": \"2021-02-25\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.525, \"Energy\": 0.448, \"Loudness\": -4.075, \"Speechiness\": 0.0443, \"Acousticness\": 0.14, \"Liveness\": 0.0922, \"Tempo\": 83.406, \"Duration (ms)\": 140308.0, \"Valence\": 0.527, \"Chord\": \"C#/Db\"}, {\"Index\": 196, \"Highest Charting Position\": 8, \"Number of Times Charted\": 71, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Breaking Me\", \"Streams\": 4977498, \"Artist\": \"Topic, A7S\", \"Artist Followers\": 151832.0, \"Song ID\": \"3H7ihDc1dqLriiWXwsc2po\", \"Genre\": \"['dance pop', 'edm', 'german dance', 'pop dance', 'pop edm', 'tropical house']\", \"Release Date\": \"2019-12-19\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 84.0, \"Danceability\": 0.789, \"Energy\": 0.72, \"Loudness\": -5.652, \"Speechiness\": 0.218, \"Acousticness\": 0.223, \"Liveness\": 0.129, \"Tempo\": 122.031, \"Duration (ms)\": 166794.0, \"Valence\": 0.664, \"Chord\": \"G#/Ab\"}, {\"Index\": 197, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"penhasco.\", \"Streams\": 4973937, \"Artist\": \"Lu\\u00edsa Sonza\", \"Artist Followers\": 1909059.0, \"Song ID\": \"5VTqW8raQYnj2avZ27nO2a\", \"Genre\": \"['funk carioca', 'pop nacional']\", \"Release Date\": \"2021-07-18\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 80.0, \"Danceability\": 0.43, \"Energy\": 0.467, \"Loudness\": -8.56, \"Speechiness\": 0.051, \"Acousticness\": 0.775, \"Liveness\": 0.0933, \"Tempo\": 77.249, \"Duration (ms)\": 186121.0, \"Valence\": 0.382, \"Chord\": \"G#/Ab\"}, {\"Index\": 198, \"Highest Charting Position\": 58, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Late At Night\", \"Streams\": 4954899, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6603627.0, \"Song ID\": \"1fxYz1s15pyZLsJT0Hdh1m\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 84.0, \"Danceability\": 0.643, \"Energy\": 0.403, \"Loudness\": -11.254, \"Speechiness\": 0.41, \"Acousticness\": 0.343, \"Liveness\": 0.138, \"Tempo\": 98.54, \"Duration (ms)\": 174682.0, \"Valence\": 0.111, \"Chord\": \"C#/Db\"}, {\"Index\": 199, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-23--2021-07-30\", \"Song Name\": \"Verdansk\", \"Streams\": 4950275, \"Artist\": \"Dave\", \"Artist Followers\": 1427540.0, \"Song ID\": \"7IPKXYU2rTMnrLW5IZ7ZI5\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2021-07-22\", \"Weeks Charted\": \"2021-07-23--2021-07-30\", \"Popularity\": 77.0, \"Danceability\": 0.961, \"Energy\": 0.502, \"Loudness\": -8.605, \"Speechiness\": 0.312, \"Acousticness\": 0.28, \"Liveness\": 0.145, \"Tempo\": 117.078, \"Duration (ms)\": 182285.0, \"Valence\": 0.536, \"Chord\": \"D\"}, {\"Index\": 200, \"Highest Charting Position\": 172, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"The Real Slim Shady\", \"Streams\": 4948965, \"Artist\": \"Eminem\", \"Artist Followers\": 46785561.0, \"Song ID\": \"3yfqSUWxFvZELEM4PmlwIR\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2000-05-23\", \"Weeks Charted\": \"2021-07-23--2021-07-30\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 84.0, \"Danceability\": 0.949, \"Energy\": 0.661, \"Loudness\": -4.244, \"Speechiness\": 0.0572, \"Acousticness\": 0.0302, \"Liveness\": 0.0454, \"Tempo\": 104.504, \"Duration (ms)\": 284200.0, \"Valence\": 0.76, \"Chord\": \"F\"}, {\"Index\": 201, \"Highest Charting Position\": 66, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Tell The Vision (feat. Kanye West & Pusha T)\", \"Streams\": 8859168, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"1Eu51GaXEehPMrDMh5QghA\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 57.0, \"Danceability\": 0.662, \"Energy\": 0.686, \"Loudness\": -8.302, \"Speechiness\": 0.332, \"Acousticness\": 0.251, \"Liveness\": 0.349, \"Tempo\": 143.971, \"Duration (ms)\": 215000.0, \"Valence\": 0.678, \"Chord\": \"G\"}, {\"Index\": 202, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Woo Baby (feat. Chris Brown)\", \"Streams\": 7371935, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"6bsqes8Zg9gUULzuCkMUs0\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 56.0, \"Danceability\": 0.563, \"Energy\": 0.672, \"Loudness\": -7.226, \"Speechiness\": 0.0765, \"Acousticness\": 0.359, \"Liveness\": 0.0972, \"Tempo\": 99.772, \"Duration (ms)\": 156000.0, \"Valence\": 0.284, \"Chord\": \"A\"}, {\"Index\": 203, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Holy Smokes\", \"Streams\": 6464206, \"Artist\": \"Trippie Redd, Lil Uzi Vert\", \"Artist Followers\": 6430522.0, \"Song ID\": \"3EpF150nXMSNjiH0bbmXIL\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 79.0, \"Danceability\": 0.437, \"Energy\": 0.527, \"Loudness\": -6.967, \"Speechiness\": 0.465, \"Acousticness\": 0.185, \"Liveness\": 0.153, \"Tempo\": 187.815, \"Duration (ms)\": 181714.0, \"Valence\": 0.701, \"Chord\": \"F#/Gb\"}, {\"Index\": 204, \"Highest Charting Position\": 127, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"More Time\", \"Streams\": 6238351, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"7wAnRqccDr2tzcSKLR4jKl\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 55.0, \"Danceability\": 0.628, \"Energy\": 0.581, \"Loudness\": -8.377, \"Speechiness\": 0.188, \"Acousticness\": 0.46, \"Liveness\": 0.152, \"Tempo\": 145.396, \"Duration (ms)\": 120828.0, \"Valence\": 0.259, \"Chord\": \"D\"}, {\"Index\": 205, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Coupe\", \"Streams\": 6161664, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"7LB3ilSpX1mSMKKztNTnu2\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 54.0, \"Danceability\": 0.912, \"Energy\": 0.589, \"Loudness\": -7.476, \"Speechiness\": 0.2, \"Acousticness\": 0.0332, \"Liveness\": 0.0795, \"Tempo\": 135.921, \"Duration (ms)\": 123549.0, \"Valence\": 0.486, \"Chord\": \"G#/Ab\"}, {\"Index\": 206, \"Highest Charting Position\": 76, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"Holiday\", \"Streams\": 5883145, \"Artist\": \"KSI\", \"Artist Followers\": 2008516.0, \"Song ID\": \"6nV2dFZXpv1JlqDWBeTXRl\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 81.0, \"Danceability\": 0.356, \"Energy\": 0.684, \"Loudness\": -7.347, \"Speechiness\": 0.0878, \"Acousticness\": 0.152, \"Liveness\": 0.101, \"Tempo\": 87.188, \"Duration (ms)\": 193733.0, \"Valence\": 0.347, \"Chord\": \"G#/Ab\"}, {\"Index\": 207, \"Highest Charting Position\": 150, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Manslaughter (feat. Rick Ross & The-Dream)\", \"Streams\": 5822266, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"4byRwLo7EmkCNBU6S8G6u0\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 55.0, \"Danceability\": 0.441, \"Energy\": 0.623, \"Loudness\": -7.331, \"Speechiness\": 0.0414, \"Acousticness\": 0.135, \"Liveness\": 0.14, \"Tempo\": 78.082, \"Duration (ms)\": 249231.0, \"Valence\": 0.285, \"Chord\": \"C#/Db\"}, {\"Index\": 208, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Genius (feat. Lil Tjay & Swae Lee)\", \"Streams\": 5702636, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"2mmRtchzDVpCj9LSyexgjS\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 53.0, \"Danceability\": 0.723, \"Energy\": 0.667, \"Loudness\": -7.524, \"Speechiness\": 0.351, \"Acousticness\": 0.256, \"Liveness\": 0.261, \"Tempo\": 143.044, \"Duration (ms)\": 208112.0, \"Valence\": 0.396, \"Chord\": \"D\"}, {\"Index\": 209, \"Highest Charting Position\": 22, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"WUSYANAME (feat. Youngboy Never Broke Again & Ty Dolla $ign)\", \"Streams\": 5696113, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"5B0kgjHULYJhAQkK5XsMoC\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.493, \"Energy\": 0.653, \"Loudness\": -5.666, \"Speechiness\": 0.0466, \"Acousticness\": 0.269, \"Liveness\": 0.511, \"Tempo\": 142.347, \"Duration (ms)\": 121573.0, \"Valence\": 0.852, \"Chord\": \"C\"}, {\"Index\": 210, \"Highest Charting Position\": 105, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Sommergewitter\", \"Streams\": 5627519, \"Artist\": \"Pashanim\", \"Artist Followers\": 208554.0, \"Song ID\": \"2H7jZg2HliuQhZjfBblLrZ\", \"Genre\": \"['german alternative rap', 'german drill', 'german hip hop', 'german trap']\", \"Release Date\": \"2021-06-24\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 84.0, \"Danceability\": 0.787, \"Energy\": 0.531, \"Loudness\": -10.569, \"Speechiness\": 0.101, \"Acousticness\": 0.132, \"Liveness\": 0.112, \"Tempo\": 91.996, \"Duration (ms)\": 138533.0, \"Valence\": 0.721, \"Chord\": \"B\"}, {\"Index\": 211, \"Highest Charting Position\": 17, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Body (Remix) [feat. ArrDee, E1 (3x3), ZT (3x3), Bugzy Malone, Buni, Fivio Foreign & Darkoo]\", \"Streams\": 5383125, \"Artist\": \"Tion Wayne, Russ Millions\", \"Artist Followers\": 323203.0, \"Song ID\": \"6uvMKqNlrSvcC4NaKnrwjZ\", \"Genre\": \"['london rap']\", \"Release Date\": \"2021-04-22\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 84.0, \"Danceability\": 0.883, \"Energy\": 0.674, \"Loudness\": -8.043, \"Speechiness\": 0.357, \"Acousticness\": 0.21, \"Liveness\": 0.0678, \"Tempo\": 141.02, \"Duration (ms)\": 278085.0, \"Valence\": 0.73, \"Chord\": \"B\"}, {\"Index\": 212, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Brush Em (feat. Rah Swish)\", \"Streams\": 5335271, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6837946.0, \"Song ID\": \"58aW6yZGFl7rVM7SLfLnLL\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-07-31\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 54.0, \"Danceability\": 0.654, \"Energy\": 0.724, \"Loudness\": -6.59, \"Speechiness\": 0.355, \"Acousticness\": 0.106, \"Liveness\": 0.655, \"Tempo\": 71.696, \"Duration (ms)\": 150449.0, \"Valence\": 0.717, \"Chord\": \"D#/Eb\"}, {\"Index\": 213, \"Highest Charting Position\": 13, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"AM\", \"Streams\": 5288927, \"Artist\": \"Nio Garcia, Flow La Movie\", \"Artist Followers\": 2123734.0, \"Song ID\": \"2dNhNlpZAtV4lwAFW45LIv\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-01-28\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 85.0, \"Danceability\": 0.83, \"Energy\": 0.517, \"Loudness\": -6.416, \"Speechiness\": 0.333, \"Acousticness\": 0.399, \"Liveness\": 0.0916, \"Tempo\": 171.959, \"Duration (ms)\": 182496.0, \"Valence\": 0.616, \"Chord\": \"F#/Gb\"}, {\"Index\": 214, \"Highest Charting Position\": 175, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"MI FAI IMPAZZIRE\", \"Streams\": 5242097, \"Artist\": \"BLANCO, Sfera Ebbasta\", \"Artist Followers\": 127364.0, \"Song ID\": \"1x3Qb8np6S1UvpSLthwEJN\", \"Genre\": \"['italian hip hop', 'italian pop']\", \"Release Date\": \"2021-06-17\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\", \"Popularity\": 83.0, \"Danceability\": 0.477, \"Energy\": 0.844, \"Loudness\": -4.87, \"Speechiness\": 0.0458, \"Acousticness\": 0.00273, \"Liveness\": 0.137, \"Tempo\": 169.941, \"Duration (ms)\": 220235.0, \"Valence\": 0.203, \"Chord\": \"B\"}, {\"Index\": 215, \"Highest Charting Position\": 20, \"Number of Times Charted\": 82, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Ride It\", \"Streams\": 5235088, \"Artist\": \"Regard\", \"Artist Followers\": 152226.0, \"Song ID\": \"2tnVG71enUj33Ic2nFN6kZ\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop edm', 'slap house', 'tropical house']\", \"Release Date\": \"2019-07-26\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.88, \"Energy\": 0.751, \"Loudness\": -4.258, \"Speechiness\": 0.0874, \"Acousticness\": 0.177, \"Liveness\": 0.106, \"Tempo\": 117.948, \"Duration (ms)\": 157606.0, \"Valence\": 0.884, \"Chord\": \"G\"}, {\"Index\": 216, \"Highest Charting Position\": 15, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Lost Cause\", \"Streams\": 5203319, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"36fhyo5QlxBW7DrDHIOn1G\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 0.0, \"Danceability\": 0.671, \"Energy\": 0.336, \"Loudness\": -8.494, \"Speechiness\": 0.241, \"Acousticness\": 0.705, \"Liveness\": 0.0577, \"Tempo\": 75.051, \"Duration (ms)\": 212496.0, \"Valence\": 0.518, \"Chord\": \"A#/Bb\"}, {\"Index\": 217, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-16--2021-07-23\", \"Song Name\": \"Shot in the Dark\", \"Streams\": 5173308, \"Artist\": \"John Mayer\", \"Artist Followers\": 5178156.0, \"Song ID\": \"239yM7BAQ2CkNc61ogPGXo\", \"Genre\": \"['neo mellow', 'pop rock', 'singer-songwriter']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-07-16--2021-07-23\", \"Popularity\": 76.0, \"Danceability\": 0.741, \"Energy\": 0.556, \"Loudness\": -9.184, \"Speechiness\": 0.0266, \"Acousticness\": 0.0629, \"Liveness\": 0.103, \"Tempo\": 122.008, \"Duration (ms)\": 249080.0, \"Valence\": 0.587, \"Chord\": \"D\"}, {\"Index\": 218, \"Highest Charting Position\": 71, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Wrecked\", \"Streams\": 5150909, \"Artist\": \"Imagine Dragons\", \"Artist Followers\": 35285425.0, \"Song ID\": \"2d1MywHy6FwKdzxFuSJnwl\", \"Genre\": \"['modern rock', 'pop', 'rock']\", \"Release Date\": \"2021-07-02\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 83.0, \"Danceability\": 0.626, \"Energy\": 0.56, \"Loudness\": -5.82, \"Speechiness\": 0.0288, \"Acousticness\": 0.148, \"Liveness\": 0.109, \"Tempo\": 93.989, \"Duration (ms)\": 244005.0, \"Valence\": 0.229, \"Chord\": \"C\"}, {\"Index\": 219, \"Highest Charting Position\": 79, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Bipolar\", \"Streams\": 5116589, \"Artist\": \"Mc Davi, Mc Pedrinho, Mc Don Juan\", \"Artist Followers\": 2586114.0, \"Song ID\": \"0qxLQ6opocOGyFnlXqJ53x\", \"Genre\": \"['funk carioca', 'funk ostentacao', 'funk paulista']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 84.0, \"Danceability\": 0.601, \"Energy\": 0.36, \"Loudness\": -7.791, \"Speechiness\": 0.0877, \"Acousticness\": 0.586, \"Liveness\": 0.0882, \"Tempo\": 124.993, \"Duration (ms)\": 276480.0, \"Valence\": 0.335, \"Chord\": \"A\"}, {\"Index\": 220, \"Highest Charting Position\": 122, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"His & Hers (feat. Don Toliver, Lil Uzi Vert & Gunna)\", \"Streams\": 5110475, \"Artist\": \"Internet Money\", \"Artist Followers\": 411579.0, \"Song ID\": \"2IePEfMAtqWS6rLXXFZIgI\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-05-14--2021-05-21\", \"Popularity\": 84.0, \"Danceability\": 0.792, \"Energy\": 0.707, \"Loudness\": -5.218, \"Speechiness\": 0.0623, \"Acousticness\": 0.116, \"Liveness\": 0.12, \"Tempo\": 134.997, \"Duration (ms)\": 224042.0, \"Valence\": 0.408, \"Chord\": \"G\"}, {\"Index\": 221, \"Highest Charting Position\": 75, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Follow You\", \"Streams\": 5097187, \"Artist\": \"Imagine Dragons\", \"Artist Followers\": 35285425.0, \"Song ID\": \"7FdUvDkaE24o3FPIWTvzv2\", \"Genre\": \"['modern rock', 'pop', 'rock']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-07-16--2021-07-23\\n2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 84.0, \"Danceability\": 0.542, \"Energy\": 0.732, \"Loudness\": -5.956, \"Speechiness\": 0.0521, \"Acousticness\": 0.00209, \"Liveness\": 0.496, \"Tempo\": 124.912, \"Duration (ms)\": 175644.0, \"Valence\": 0.489, \"Chord\": \"A\"}, {\"Index\": 222, \"Highest Charting Position\": 22, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"We're Good\", \"Streams\": 6318660, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"1diS6nkxMQc3wwC4G1j0bh\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 83.0, \"Danceability\": 0.722, \"Energy\": 0.588, \"Loudness\": -5.932, \"Speechiness\": 0.0544, \"Acousticness\": 0.0319, \"Liveness\": 0.183, \"Tempo\": 134.01, \"Duration (ms)\": 165507.0, \"Valence\": 0.59, \"Chord\": \"F#/Gb\"}, {\"Index\": 223, \"Highest Charting Position\": 4, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Life Goes On\", \"Streams\": 6142975, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"249gnXrbfmV8NG6jTEMSwD\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 84.0, \"Danceability\": 0.566, \"Energy\": 0.716, \"Loudness\": -5.733, \"Speechiness\": 0.0424, \"Acousticness\": 0.00691, \"Liveness\": 0.37, \"Tempo\": 81.068, \"Duration (ms)\": 207481.0, \"Valence\": 0.45, \"Chord\": \"C#/Db\"}, {\"Index\": 224, \"Highest Charting Position\": 28, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"911\", \"Streams\": 6111108, \"Artist\": \"Sech\", \"Artist Followers\": 8758283.0, \"Song ID\": \"27RSJHEA99Y0Vsow7nA37A\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2020-05-29--2020-06-05\", \"Popularity\": 89.0, \"Danceability\": 0.816, \"Energy\": 0.71, \"Loudness\": -3.728, \"Speechiness\": 0.0398, \"Acousticness\": 0.165, \"Liveness\": 0.292, \"Tempo\": 93.02, \"Duration (ms)\": 208631.0, \"Valence\": 0.784, \"Chord\": \"G\"}, {\"Index\": 225, \"Highest Charting Position\": 17, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Baila Conmigo (with Rauw Alejandro)\", \"Streams\": 5588217, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28909504.0, \"Song ID\": \"079Ey5uxL04AKPQgVQwx5h\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 84.0, \"Danceability\": 0.823, \"Energy\": 0.544, \"Loudness\": -7.132, \"Speechiness\": 0.0715, \"Acousticness\": 0.0215, \"Liveness\": 0.0966, \"Tempo\": 149.903, \"Duration (ms)\": 186088.0, \"Valence\": 0.664, \"Chord\": \"F\"}, {\"Index\": 226, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"The Jackie (with J. Cole & Lil Tjay)\", \"Streams\": 5454994, \"Artist\": \"Bas\", \"Artist Followers\": 386757.0, \"Song ID\": \"15qKrPi4Kg0z7g9HlwWyeb\", \"Genre\": \"['hip hop', 'pop rap', 'queens hip hop', 'rap', 'sudanese pop', 'underground hip hop']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-09--2021-07-16\", \"Popularity\": 76.0, \"Danceability\": 0.784, \"Energy\": 0.474, \"Loudness\": -6.139, \"Speechiness\": 0.0524, \"Acousticness\": 0.333, \"Liveness\": 0.278, \"Tempo\": 128.012, \"Duration (ms)\": 204434.0, \"Valence\": 0.64, \"Chord\": \"G#/Ab\"}, {\"Index\": 227, \"Highest Charting Position\": 22, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"hope ur ok\", \"Streams\": 5435614, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6266514.0, \"Song ID\": \"1zejeOnykpCoyVSit6Bwp3\", \"Genre\": \"['pop']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 84.0, \"Danceability\": 0.443, \"Energy\": 0.298, \"Loudness\": -12.181, \"Speechiness\": 0.0644, \"Acousticness\": 0.388, \"Liveness\": 0.103, \"Tempo\": 77.253, \"Duration (ms)\": 209560.0, \"Valence\": 0.172, \"Chord\": \"C\"}, {\"Index\": 228, \"Highest Charting Position\": 169, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Faz Amor Comigo S\\u00f3 Hoje - Ao Vivo\", \"Streams\": 5269757, \"Artist\": \"Israel & Rodolffo, Wesley Safad\\u00e3o\", \"Artist Followers\": 1097789.0, \"Song ID\": \"7Kba4OaxQFQ1zlknQUpNqN\", \"Genre\": \"['sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2021-05-26\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 82.0, \"Danceability\": 0.624, \"Energy\": 0.922, \"Loudness\": -4.628, \"Speechiness\": 0.0439, \"Acousticness\": 0.3, \"Liveness\": 0.112, \"Tempo\": 164.819, \"Duration (ms)\": 148228.0, \"Valence\": 0.884, \"Chord\": \"C#/Db\"}, {\"Index\": 229, \"Highest Charting Position\": 80, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Alcohol-Free\", \"Streams\": 5259503, \"Artist\": \"TWICE\", \"Artist Followers\": 9987114.0, \"Song ID\": \"0BTaaKT4RMbs5M73tOHX5Y\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 82.0, \"Danceability\": 0.688, \"Energy\": 0.909, \"Loudness\": -1.992, \"Speechiness\": 0.0624, \"Acousticness\": 0.0474, \"Liveness\": 0.0674, \"Tempo\": 97.097, \"Duration (ms)\": 210573.0, \"Valence\": 0.702, \"Chord\": \"G#/Ab\"}, {\"Index\": 230, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"WHOLE LOTTA MONEY (feat. Nicki Minaj) - Remix\", \"Streams\": 5186354, \"Artist\": \"BIA\", \"Artist Followers\": 151870.0, \"Song ID\": \"67G6iaOw8DZqp1z8STR89R\", \"Genre\": \"['escape room', 'r&b', 'rap latina', 'trap queen']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-09--2021-07-16\", \"Popularity\": 80.0, \"Danceability\": 0.893, \"Energy\": 0.463, \"Loudness\": -5.301, \"Speechiness\": 0.36, \"Acousticness\": 0.199, \"Liveness\": 0.318, \"Tempo\": 81.026, \"Duration (ms)\": 229601.0, \"Valence\": 0.591, \"Chord\": \"C#/Db\"}, {\"Index\": 231, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-09--2021-07-16\", \"Song Name\": \"Memory\", \"Streams\": 5173178, \"Artist\": \"Kane Brown, blackbear\", \"Artist Followers\": 3507622.0, \"Song ID\": \"34chhNX59Wo9HMFCsI3K8Y\", \"Genre\": \"['contemporary country', 'country road']\", \"Release Date\": \"2021-07-09\", \"Weeks Charted\": \"2021-07-09--2021-07-16\", \"Popularity\": 80.0, \"Danceability\": 0.434, \"Energy\": 0.889, \"Loudness\": -5.684, \"Speechiness\": 0.0509, \"Acousticness\": 0.395, \"Liveness\": 0.273, \"Tempo\": 113.326, \"Duration (ms)\": 153338.0, \"Valence\": 0.845, \"Chord\": \"A\"}, {\"Index\": 232, \"Highest Charting Position\": 183, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Me Fije\", \"Streams\": 5068677, \"Artist\": \"Alex Rose, Rauw Alejandro\", \"Artist Followers\": 2166191.0, \"Song ID\": \"6Et5KimMg3IXwD6lJPGmQw\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2021-03-18\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-05-07--2021-05-14\", \"Popularity\": 83.0, \"Danceability\": 0.76, \"Energy\": 0.674, \"Loudness\": -4.039, \"Speechiness\": 0.0636, \"Acousticness\": 0.396, \"Liveness\": 0.0977, \"Tempo\": 172.024, \"Duration (ms)\": 202307.0, \"Valence\": 0.735, \"Chord\": \"G\"}, {\"Index\": 233, \"Highest Charting Position\": 71, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Volta Beb\\u00ea, Volta Nen\\u00e9m\", \"Streams\": 5041120, \"Artist\": \"Dj Guuga, DJ Ivis\", \"Artist Followers\": 608109.0, \"Song ID\": \"4wQUopWk9Ed7Ng5qpKN5qd\", \"Genre\": \"['funk carioca', 'funk paulista', 'rave funk']\", \"Release Date\": \"2021-03-27\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 79.0, \"Danceability\": 0.583, \"Energy\": 0.918, \"Loudness\": -3.612, \"Speechiness\": 0.0518, \"Acousticness\": 0.288, \"Liveness\": 0.0701, \"Tempo\": 164.081, \"Duration (ms)\": 172973.0, \"Valence\": 0.836, \"Chord\": \"F#/Gb\"}, {\"Index\": 234, \"Highest Charting Position\": 95, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Aloha\", \"Streams\": 5036030, \"Artist\": \"Maluma, Be\\u00e9le, Rauw Alejandro, Mambo Kingz, DJ Luian, Darell\", \"Artist Followers\": 26769304.0, \"Song ID\": \"5RAIMjdrCEjpjaR5tBATXU\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 84.0, \"Danceability\": 0.807, \"Energy\": 0.712, \"Loudness\": -5.757, \"Speechiness\": 0.1, \"Acousticness\": 0.532, \"Liveness\": 0.163, \"Tempo\": 100.004, \"Duration (ms)\": 241659.0, \"Valence\": 0.792, \"Chord\": \"C#/Db\"}, {\"Index\": 235, \"Highest Charting Position\": 184, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Sexo Virtual\", \"Streams\": 4975786, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6080597.0, \"Song ID\": \"0giiXonRhODYy4J1iy4Lb3\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\", \"Popularity\": 82.0, \"Danceability\": 0.704, \"Energy\": 0.739, \"Loudness\": -3.286, \"Speechiness\": 0.112, \"Acousticness\": 0.328, \"Liveness\": 0.0856, \"Tempo\": 179.879, \"Duration (ms)\": 208292.0, \"Valence\": 0.425, \"Chord\": \"G#/Ab\"}, {\"Index\": 236, \"Highest Charting Position\": 141, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Closer\", \"Streams\": 4954679, \"Artist\": \"The Chainsmokers, Halsey\", \"Artist Followers\": 18191658.0, \"Song ID\": \"7BKLCZ1jbUBVqRi2FVlTVw\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2016-07-29\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-01--2021-01-08\\n2020-08-14--2020-08-21\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.748, \"Energy\": 0.524, \"Loudness\": -5.599, \"Speechiness\": 0.0338, \"Acousticness\": 0.414, \"Liveness\": 0.111, \"Tempo\": 95.01, \"Duration (ms)\": 244960.0, \"Valence\": 0.661, \"Chord\": \"G#/Ab\"}, {\"Index\": 237, \"Highest Charting Position\": 194, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Wonderwall - Remastered\", \"Streams\": 4938180, \"Artist\": \"Oasis\", \"Artist Followers\": 6475631.0, \"Song ID\": \"7ygpwy2qP3NbrxVkHvUhXY\", \"Genre\": \"['beatlesque', 'britpop', 'madchester', 'permanent wave', 'rock']\", \"Release Date\": \"1995\", \"Weeks Charted\": \"2021-07-09--2021-07-16\\n2021-05-28--2021-06-04\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 78.0, \"Danceability\": 0.375, \"Energy\": 0.893, \"Loudness\": -4.097, \"Speechiness\": 0.0406, \"Acousticness\": 0.000509, \"Liveness\": 0.187, \"Tempo\": 174.323, \"Duration (ms)\": 258773.0, \"Valence\": 0.434, \"Chord\": \"D\"}, {\"Index\": 238, \"Highest Charting Position\": 101, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Wasting Time ( feat. Drake )\", \"Streams\": 6731106, \"Artist\": \"Brent Faiyaz\", \"Artist Followers\": 1724414.0, \"Song ID\": \"48WidxP9CqyYtk97pwGZ3c\", \"Genre\": \"['dmv rap', 'pop', 'r&b', 'rap']\", \"Release Date\": \"2021-07-01\", \"Weeks Charted\": \"2021-07-02--2021-07-09\", \"Popularity\": 78.0, \"Danceability\": 0.652, \"Energy\": 0.717, \"Loudness\": -3.751, \"Speechiness\": 0.0581, \"Acousticness\": 0.0694, \"Liveness\": 0.0906, \"Tempo\": 89.982, \"Duration (ms)\": 301304.0, \"Valence\": 0.377, \"Chord\": \"G\"}, {\"Index\": 239, \"Highest Charting Position\": 55, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"I Don't Do Drugs (feat. Ariana Grande)\", \"Streams\": 5912293, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0FFsgUoFibYISzMxuGS61W\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 80.0, \"Danceability\": 0.683, \"Energy\": 0.615, \"Loudness\": -5.737, \"Speechiness\": 0.0966, \"Acousticness\": 0.222, \"Liveness\": 0.154, \"Tempo\": 77.014, \"Duration (ms)\": 188893.0, \"Valence\": 0.45, \"Chord\": \"F\"}, {\"Index\": 240, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Renegade (feat. Taylor Swift)\", \"Streams\": 5876058, \"Artist\": \"Big Red Machine\", \"Artist Followers\": 98503.0, \"Song ID\": \"1aU1wpYBSpP0M6IiihY5Ue\", \"Genre\": \"['eau claire indie', 'folktronica']\", \"Release Date\": \"2021-07-02\", \"Weeks Charted\": \"2021-07-02--2021-07-09\", \"Popularity\": 77.0, \"Danceability\": 0.532, \"Energy\": 0.708, \"Loudness\": -8.121, \"Speechiness\": 0.0505, \"Acousticness\": 0.435, \"Liveness\": 0.107, \"Tempo\": 167.977, \"Duration (ms)\": 254467.0, \"Valence\": 0.586, \"Chord\": \"C\"}, {\"Index\": 241, \"Highest Charting Position\": 40, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"JUGGERNAUT (feat. Lil Uzi Vert & Pharrell Williams)\", \"Streams\": 5392334, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"7z4xW9WY86uH3gd1V9pfCM\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 80.0, \"Danceability\": 0.827, \"Energy\": 0.571, \"Loudness\": -7.949, \"Speechiness\": 0.366, \"Acousticness\": 0.0195, \"Liveness\": 0.166, \"Tempo\": 142.034, \"Duration (ms)\": 146419.0, \"Valence\": 0.62, \"Chord\": \"B\"}, {\"Index\": 242, \"Highest Charting Position\": 152, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"All Eyes On Me\", \"Streams\": 5347263, \"Artist\": \"Bo Burnham\", \"Artist Followers\": 1042079.0, \"Song ID\": \"3rV5y8rcQrwRt9fWGLmjOQ\", \"Genre\": \"['comic']\", \"Release Date\": \"2021-06-10\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\", \"Popularity\": 81.0, \"Danceability\": 0.352, \"Energy\": 0.424, \"Loudness\": -10.131, \"Speechiness\": 0.0394, \"Acousticness\": 0.733, \"Liveness\": 0.0664, \"Tempo\": 127.047, \"Duration (ms)\": 302951.0, \"Valence\": 0.141, \"Chord\": \"F#/Gb\"}, {\"Index\": 243, \"Highest Charting Position\": 101, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"EVERY CHANCE I GET (feat. Lil Baby & Lil Durk)\", \"Streams\": 5321544, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6278835.0, \"Song ID\": \"1EJIcDYXwSqipW5dFe4uJz\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 83.0, \"Danceability\": 0.477, \"Energy\": 0.727, \"Loudness\": -4.053, \"Speechiness\": 0.286, \"Acousticness\": 0.000866, \"Liveness\": 0.108, \"Tempo\": 150.062, \"Duration (ms)\": 236524.0, \"Valence\": 0.227, \"Chord\": \"D\"}, {\"Index\": 244, \"Highest Charting Position\": 72, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Dick (feat. Doja Cat)\", \"Streams\": 5258628, \"Artist\": \"StarBoi3\", \"Artist Followers\": 17202.0, \"Song ID\": \"3nY8AqaMNNHHLYV4380ol0\", \"Genre\": \"[]\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 83.0, \"Danceability\": 0.647, \"Energy\": 0.608, \"Loudness\": -6.831, \"Speechiness\": 0.42, \"Acousticness\": 0.13, \"Liveness\": 0.0584, \"Tempo\": 125.994, \"Duration (ms)\": 175238.0, \"Valence\": 0.474, \"Chord\": \"A\"}, {\"Index\": 245, \"Highest Charting Position\": 25, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Solar Power\", \"Streams\": 5234112, \"Artist\": \"Lorde\", \"Artist Followers\": 8083566.0, \"Song ID\": \"3KdoeNlEN0BoAKWzaRLNZa\", \"Genre\": \"['art pop', 'dance pop', 'electropop', 'metropopolis', 'nz pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-06-10\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 81.0, \"Danceability\": 0.735, \"Energy\": 0.47, \"Loudness\": -9.405, \"Speechiness\": 0.1, \"Acousticness\": 0.266, \"Liveness\": 0.32, \"Tempo\": 87.971, \"Duration (ms)\": 192621.0, \"Valence\": 0.897, \"Chord\": \"E\"}, {\"Index\": 246, \"Highest Charting Position\": 4, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Your Power\", \"Streams\": 5135380, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47014200.0, \"Song ID\": \"042Sl6Mn83JHyLEqdK7uI0\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-07-30\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 81.0, \"Danceability\": 0.632, \"Energy\": 0.284, \"Loudness\": -14.025, \"Speechiness\": 0.0801, \"Acousticness\": 0.932, \"Liveness\": 0.233, \"Tempo\": 129.642, \"Duration (ms)\": 245897.0, \"Valence\": 0.208, \"Chord\": \"A\"}, {\"Index\": 247, \"Highest Charting Position\": 189, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-07-02--2021-07-09\", \"Song Name\": \"Lieben wir\", \"Streams\": 5029898, \"Artist\": \"Shirin David\", \"Artist Followers\": 558345.0, \"Song ID\": \"49gzU1IS1B6P3GATSZ5eCE\", \"Genre\": \"['frauenrap', 'german hip hop', 'german pop']\", \"Release Date\": \"2021-07-01\", \"Weeks Charted\": \"2021-07-02--2021-07-09\", \"Popularity\": 77.0, \"Danceability\": 0.871, \"Energy\": 0.669, \"Loudness\": -7.62, \"Speechiness\": 0.329, \"Acousticness\": 0.0113, \"Liveness\": 0.0795, \"Tempo\": 95.939, \"Duration (ms)\": 155363.0, \"Valence\": 0.806, \"Chord\": \"A#/Bb\"}, {\"Index\": 248, \"Highest Charting Position\": 8, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Whoopty\", \"Streams\": 5013017, \"Artist\": \"CJ\", \"Artist Followers\": 180454.0, \"Song ID\": \"5vGLcdRuSbUhD8ScwsGSdA\", \"Genre\": \"['nyc rap']\", \"Release Date\": \"2020-08-20\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 81.0, \"Danceability\": 0.719, \"Energy\": 0.648, \"Loudness\": -7.6, \"Speechiness\": 0.125, \"Acousticness\": 0.2, \"Liveness\": 0.127, \"Tempo\": 140.201, \"Duration (ms)\": 123263.0, \"Valence\": 0.66, \"Chord\": \"D#/Eb\"}, {\"Index\": 249, \"Highest Charting Position\": 55, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Batom de Cereja - Ao Vivo\", \"Streams\": 5011753, \"Artist\": \"Israel & Rodolffo\", \"Artist Followers\": 1097789.0, \"Song ID\": \"2MZQAvsA7aZDssppBLRxYp\", \"Genre\": \"['sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2021-01-29\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 83.0, \"Danceability\": 0.606, \"Energy\": 0.908, \"Loudness\": -6.201, \"Speechiness\": 0.0565, \"Acousticness\": 0.556, \"Liveness\": 0.19, \"Tempo\": 171.966, \"Duration (ms)\": 140942.0, \"Valence\": 0.798, \"Chord\": \"F#/Gb\"}, {\"Index\": 250, \"Highest Charting Position\": 11, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Prisoner (feat. Dua Lipa)\", \"Streams\": 5005018, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15770302.0, \"Song ID\": \"5JqZ3oqF00jkT81foAFvqg\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 79.0, \"Danceability\": 0.781, \"Energy\": 0.67, \"Loudness\": -3.912, \"Speechiness\": 0.0452, \"Acousticness\": 0.0103, \"Liveness\": 0.0761, \"Tempo\": 127.99, \"Duration (ms)\": 169333.0, \"Valence\": 0.595, \"Chord\": \"D#/Eb\"}, {\"Index\": 251, \"Highest Charting Position\": 136, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Stereo Hearts (feat. Adam Levine)\", \"Streams\": 4992345, \"Artist\": \"Gym Class Heroes\", \"Artist Followers\": 1275345.0, \"Song ID\": \"0qOnSQQF0yzuPWsXrQ9paz\", \"Genre\": \"['dance pop', 'pop rap']\", \"Release Date\": \"2011-11-11\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 82.0, \"Danceability\": 0.646, \"Energy\": 0.795, \"Loudness\": -3.293, \"Speechiness\": 0.0976, \"Acousticness\": 0.0319, \"Liveness\": 0.267, \"Tempo\": 89.99, \"Duration (ms)\": 210960.0, \"Valence\": 0.796, \"Chord\": \"A\"}, {\"Index\": 252, \"Highest Charting Position\": 32, \"Number of Times Charted\": 36, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Reloj\", \"Streams\": 4980155, \"Artist\": \"Rauw Alejandro, Anuel AA\", \"Artist Followers\": 6080597.0, \"Song ID\": \"7r9ZhitdQBONTFOiJW5mr8\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-10-22\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 79.0, \"Danceability\": 0.823, \"Energy\": 0.537, \"Loudness\": -2.639, \"Speechiness\": 0.209, \"Acousticness\": 0.176, \"Liveness\": 0.123, \"Tempo\": 175.946, \"Duration (ms)\": 231595.0, \"Valence\": 0.615, \"Chord\": \"G#/Ab\"}, {\"Index\": 253, \"Highest Charting Position\": 81, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"malibu\", \"Streams\": 4973063, \"Artist\": \"sangiovanni\", \"Artist Followers\": 384097.0, \"Song ID\": \"01hEpx8jnOG4q7nDK14Rhi\", \"Genre\": \"[]\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.733, \"Energy\": 0.736, \"Loudness\": -5.123, \"Speechiness\": 0.111, \"Acousticness\": 0.028, \"Liveness\": 0.131, \"Tempo\": 147.897, \"Duration (ms)\": 166216.0, \"Valence\": 0.669, \"Chord\": \"G\"}, {\"Index\": 254, \"Highest Charting Position\": 101, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Eladio Carrion: Bzrp Music Sessions, Vol. 40\", \"Streams\": 4965913, \"Artist\": \"Bizarrap, Eladio Carrion\", \"Artist Followers\": 3126961.0, \"Song ID\": \"1VauUM5CBX7nkLcgafQL2B\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2021-06-09\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 81.0, \"Danceability\": 0.783, \"Energy\": 0.524, \"Loudness\": -6.455, \"Speechiness\": 0.0554, \"Acousticness\": 0.241, \"Liveness\": 0.271, \"Tempo\": 117.496, \"Duration (ms)\": 164896.0, \"Valence\": 0.839, \"Chord\": \"F\"}, {\"Index\": 255, \"Highest Charting Position\": 117, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Do I Wanna Know?\", \"Streams\": 4938586, \"Artist\": \"Arctic Monkeys\", \"Artist Followers\": 12369079.0, \"Song ID\": \"5FVd6KXrgO9B3JPmC8OPst\", \"Genre\": \"['garage rock', 'permanent wave', 'rock', 'sheffield indie']\", \"Release Date\": \"2013-09-09\", \"Weeks Charted\": \"2021-07-02--2021-07-09\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 84.0, \"Danceability\": 0.548, \"Energy\": 0.532, \"Loudness\": -7.596, \"Speechiness\": 0.0323, \"Acousticness\": 0.186, \"Liveness\": 0.217, \"Tempo\": 85.03, \"Duration (ms)\": 272394.0, \"Valence\": 0.405, \"Chord\": \"F\"}, {\"Index\": 256, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"LUMBERJACK\", \"Streams\": 11756283, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"0BiK5BbYNFLb88CCOxBFJe\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\", \"Popularity\": 76.0, \"Danceability\": 0.386, \"Energy\": 0.762, \"Loudness\": -6.341, \"Speechiness\": 0.564, \"Acousticness\": 0.122, \"Liveness\": 0.527, \"Tempo\": 170.691, \"Duration (ms)\": 138312.0, \"Valence\": 0.433, \"Chord\": \"A\"}, {\"Index\": 257, \"Highest Charting Position\": 47, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"LEMONHEAD (feat. 42 Dugg)\", \"Streams\": 11380679, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"5fbHRCsGpFIOLRtlhCRFDR\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 78.0, \"Danceability\": 0.62, \"Energy\": 0.586, \"Loudness\": -6.612, \"Speechiness\": 0.212, \"Acousticness\": 0.155, \"Liveness\": 0.535, \"Tempo\": 137.131, \"Duration (ms)\": 130980.0, \"Valence\": 0.487, \"Chord\": \"C#/Db\"}, {\"Index\": 258, \"Highest Charting Position\": 59, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"HOT WIND BLOWS (feat. Lil Wayne)\", \"Streams\": 9889197, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"3JJL91ilRV6fXhKqu0FGXs\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 77.0, \"Danceability\": 0.371, \"Energy\": 0.75, \"Loudness\": -5.382, \"Speechiness\": 0.402, \"Acousticness\": 0.601, \"Liveness\": 0.482, \"Tempo\": 173.456, \"Duration (ms)\": 155293.0, \"Valence\": 0.729, \"Chord\": \"G\"}, {\"Index\": 259, \"Highest Charting Position\": 63, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"CORSO\", \"Streams\": 9503981, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"46oHvXwpEZOFX518we1nJD\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 77.0, \"Danceability\": 0.703, \"Energy\": 0.845, \"Loudness\": -4.851, \"Speechiness\": 0.337, \"Acousticness\": 0.169, \"Liveness\": 0.122, \"Tempo\": 97.672, \"Duration (ms)\": 146482.0, \"Valence\": 0.745, \"Chord\": \"A#/Bb\"}, {\"Index\": 260, \"Highest Charting Position\": 69, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"SWEET / I THOUGHT YOU WANTED TO DANCE (feat. Brent Faiyaz & Fana Hues)\", \"Streams\": 9142721, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"3EG9FJ0ToLfgnc1IG2Z1wz\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 79.0, \"Danceability\": 0.468, \"Energy\": 0.652, \"Loudness\": -4.912, \"Speechiness\": 0.0722, \"Acousticness\": 0.333, \"Liveness\": 0.55, \"Tempo\": 140.223, \"Duration (ms)\": 588139.0, \"Valence\": 0.39, \"Chord\": \"C\"}, {\"Index\": 261, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"SIR BAUDELAIRE (feat. DJ Drama)\", \"Streams\": 8884283, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"4ydmav4vl7hebadtfZtMrg\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 75.0, \"Danceability\": 0.467, \"Energy\": 0.635, \"Loudness\": -6.115, \"Speechiness\": 0.154, \"Acousticness\": 0.314, \"Liveness\": 0.844, \"Tempo\": 127.596, \"Duration (ms)\": 88625.0, \"Valence\": 0.51, \"Chord\": \"G\"}, {\"Index\": 262, \"Highest Charting Position\": 82, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"MASSA\", \"Streams\": 8218423, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"2goHCrsDJaflEwQ930ef0o\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 74.0, \"Danceability\": 0.685, \"Energy\": 0.855, \"Loudness\": -6.724, \"Speechiness\": 0.438, \"Acousticness\": 0.329, \"Liveness\": 0.301, \"Tempo\": 157.181, \"Duration (ms)\": 223719.0, \"Valence\": 0.46, \"Chord\": \"C#/Db\"}, {\"Index\": 263, \"Highest Charting Position\": 85, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"RUNITUP (feat. Teezo Touchdown)\", \"Streams\": 7917707, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"13HsOwrwTA5HgLuoaDHncP\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 75.0, \"Danceability\": 0.665, \"Energy\": 0.469, \"Loudness\": -7.778, \"Speechiness\": 0.13, \"Acousticness\": 0.565, \"Liveness\": 0.219, \"Tempo\": 115.852, \"Duration (ms)\": 229565.0, \"Valence\": 0.142, \"Chord\": \"A#/Bb\"}, {\"Index\": 264, \"Highest Charting Position\": 108, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"MANIFESTO (feat. Domo Genesis)\", \"Streams\": 6988886, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"6qouBO0wJtYc3k7DfKRUBx\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.454, \"Energy\": 0.866, \"Loudness\": -5.348, \"Speechiness\": 0.391, \"Acousticness\": 0.121, \"Liveness\": 0.167, \"Tempo\": 92.463, \"Duration (ms)\": 175123.0, \"Valence\": 0.518, \"Chord\": \"D\"}, {\"Index\": 265, \"Highest Charting Position\": 121, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Get Into It (Yuh)\", \"Streams\": 6503281, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0W6I02J9xcqK8MtSeosEXb\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 80.0, \"Danceability\": 0.912, \"Energy\": 0.655, \"Loudness\": -6.029, \"Speechiness\": 0.162, \"Acousticness\": 0.315, \"Liveness\": 0.0894, \"Tempo\": 91.942, \"Duration (ms)\": 138293.0, \"Valence\": 0.793, \"Chord\": \"G#/Ab\"}, {\"Index\": 266, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"WILSHIRE\", \"Streams\": 6268542, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"1pbbsI2KGPOMu0HmuGccBu\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.555, \"Energy\": 0.712, \"Loudness\": -7.446, \"Speechiness\": 0.323, \"Acousticness\": 0.0451, \"Liveness\": 0.182, \"Tempo\": 78.958, \"Duration (ms)\": 515865.0, \"Valence\": 0.555, \"Chord\": \"C#/Db\"}, {\"Index\": 267, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"RISE! (feat. DAISY WORLD)\", \"Streams\": 6034281, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6777818.0, \"Song ID\": \"4Hta7Oy5W9HD0UgT1P8PPV\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.766, \"Energy\": 0.814, \"Loudness\": -3.367, \"Speechiness\": 0.0733, \"Acousticness\": 0.044, \"Liveness\": 0.195, \"Tempo\": 108.07, \"Duration (ms)\": 203588.0, \"Valence\": 0.481, \"Chord\": \"D\"}, {\"Index\": 268, \"Highest Charting Position\": 165, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Naked\", \"Streams\": 5527865, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"0CsR9Y9SnC6ZWmekmVqSHz\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 75.0, \"Danceability\": 0.733, \"Energy\": 0.862, \"Loudness\": -5.736, \"Speechiness\": 0.197, \"Acousticness\": 0.374, \"Liveness\": 0.131, \"Tempo\": 111.076, \"Duration (ms)\": 223560.0, \"Valence\": 0.536, \"Chord\": \"G\"}, {\"Index\": 269, \"Highest Charting Position\": 50, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Having Our Way (feat. Drake)\", \"Streams\": 5424579, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"2NM0qHzx4Ohy8iXHEEgwlO\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 79.0, \"Danceability\": 0.927, \"Energy\": 0.538, \"Loudness\": -3.917, \"Speechiness\": 0.116, \"Acousticness\": 0.0312, \"Liveness\": 0.0945, \"Tempo\": 125.983, \"Duration (ms)\": 278191.0, \"Valence\": 0.221, \"Chord\": \"C#/Db\"}, {\"Index\": 270, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Payday (feat. Young Thug)\", \"Streams\": 5393789, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"2HolBGR6tpiWI80MXoV1dJ\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 73.0, \"Danceability\": 0.619, \"Energy\": 0.707, \"Loudness\": -5.791, \"Speechiness\": 0.0499, \"Acousticness\": 0.0366, \"Liveness\": 0.13, \"Tempo\": 168.995, \"Duration (ms)\": 212947.0, \"Valence\": 0.558, \"Chord\": \"C#/Db\"}, {\"Index\": 271, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-25--2021-07-02\", \"Song Name\": \"Been Like This\", \"Streams\": 5362817, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8640063.0, \"Song ID\": \"7y3xU9vEC1s8DSuuoSYKih\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2021-06-25\", \"Weeks Charted\": \"2021-06-25--2021-07-02\", \"Popularity\": 74.0, \"Danceability\": 0.678, \"Energy\": 0.531, \"Loudness\": -5.029, \"Speechiness\": 0.0374, \"Acousticness\": 0.126, \"Liveness\": 0.377, \"Tempo\": 99.008, \"Duration (ms)\": 177373.0, \"Valence\": 0.176, \"Chord\": \"A#/Bb\"}, {\"Index\": 272, \"Highest Charting Position\": 138, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"MILLE (feat. Orietta Berti)\", \"Streams\": 5341887, \"Artist\": \"Fedez, Achille Lauro\", \"Artist Followers\": 1650683.0, \"Song ID\": \"6qdMhG7pRFi0csRlFGvLE4\", \"Genre\": \"['italian adult pop', 'italian pop']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 82.0, \"Danceability\": 0.527, \"Energy\": 0.764, \"Loudness\": -4.297, \"Speechiness\": 0.322, \"Acousticness\": 0.016, \"Liveness\": 0.0273, \"Tempo\": 184.339, \"Duration (ms)\": 175924.0, \"Valence\": 0.829, \"Chord\": \"D\"}, {\"Index\": 273, \"Highest Charting Position\": 10, \"Number of Times Charted\": 49, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"UN DIA (ONE DAY) (Feat. Tainy)\", \"Streams\": 5203364, \"Artist\": \"J Balvin, Dua Lipa, Bad Bunny\", \"Artist Followers\": 29051363.0, \"Song ID\": \"0EhpEsp4L0oRGM0vmeaN5e\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 83.0, \"Danceability\": 0.571, \"Energy\": 0.693, \"Loudness\": -8.234, \"Speechiness\": 0.0545, \"Acousticness\": 0.00536, \"Liveness\": 0.173, \"Tempo\": 168.169, \"Duration (ms)\": 232253.0, \"Valence\": 0.393, \"Chord\": \"F#/Gb\"}, {\"Index\": 274, \"Highest Charting Position\": 1, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Savage Love (Laxed - Siren Beat)\", \"Streams\": 5108950, \"Artist\": \"Jawsh 685, Jason Derulo\", \"Artist Followers\": 100604.0, \"Song ID\": \"1xQ6trAsedVPCdbtDAmk0c\", \"Genre\": \"['nz pop']\", \"Release Date\": \"2020-06-11\", \"Weeks Charted\": \"2021-06-25--2021-07-02\\n2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 82.0, \"Danceability\": 0.767, \"Energy\": 0.481, \"Loudness\": -8.52, \"Speechiness\": 0.0803, \"Acousticness\": 0.234, \"Liveness\": 0.269, \"Tempo\": 150.076, \"Duration (ms)\": 171375.0, \"Valence\": 0.761, \"Chord\": \"C\"}, {\"Index\": 275, \"Highest Charting Position\": 59, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Poblado\", \"Streams\": 6893939, \"Artist\": \"Crissin, Totoy El Frio, Natan & Shander\", \"Artist Followers\": 29051363.0, \"Song ID\": \"1WedZeiezCmCEOzLwhx0hV\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-06-18\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 89.0, \"Danceability\": 0.813, \"Energy\": 0.809, \"Loudness\": -5.382, \"Speechiness\": 0.0846, \"Acousticness\": 0.102, \"Liveness\": 0.377, \"Tempo\": 93.005, \"Duration (ms)\": 393280.0, \"Valence\": 0.646, \"Chord\": \"D#/Eb\"}, {\"Index\": 276, \"Highest Charting Position\": 17, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Hecha Pa' Mi\", \"Streams\": 6308369, \"Artist\": \"Boza\", \"Artist Followers\": 278679.0, \"Song ID\": \"3VvA1wSxukMLsvXoXtlwWx\", \"Genre\": \"['reggaeton']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 83.0, \"Danceability\": 0.725, \"Energy\": 0.756, \"Loudness\": -5.013, \"Speechiness\": 0.0572, \"Acousticness\": 0.362, \"Liveness\": 0.103, \"Tempo\": 100.07, \"Duration (ms)\": 186133.0, \"Valence\": 0.828, \"Chord\": \"E\"}, {\"Index\": 277, \"Highest Charting Position\": 146, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-18--2021-06-25\", \"Song Name\": \"working\", \"Streams\": 5666770, \"Artist\": \"Tate McRae, Khalid\", \"Artist Followers\": 1647262.0, \"Song ID\": \"31sSFHIe4NaxltVFOEIcTa\", \"Genre\": \"['alt z', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-06-17\", \"Weeks Charted\": \"2021-06-18--2021-06-25\", \"Popularity\": 80.0, \"Danceability\": 0.783, \"Energy\": 0.435, \"Loudness\": -7.78, \"Speechiness\": 0.0588, \"Acousticness\": 0.282, \"Liveness\": 0.0833, \"Tempo\": 106.974, \"Duration (ms)\": 210220.0, \"Valence\": 0.512, \"Chord\": \"G\"}, {\"Index\": 278, \"Highest Charting Position\": 112, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Petrouchka (feat. PLK)\", \"Streams\": 5511544, \"Artist\": \"Soso Maness\", \"Artist Followers\": 289437.0, \"Song ID\": \"03y045SZqaC94yfXl1cU4E\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais', 'rap marseille']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\", \"Popularity\": 79.0, \"Danceability\": 0.624, \"Energy\": 0.802, \"Loudness\": -4.818, \"Speechiness\": 0.311, \"Acousticness\": 0.0597, \"Liveness\": 0.252, \"Tempo\": 133.888, \"Duration (ms)\": 189933.0, \"Valence\": 0.818, \"Chord\": \"F#/Gb\"}, {\"Index\": 279, \"Highest Charting Position\": 11, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"p r i d e . i s . t h e . d e v i l (with Lil Baby)\", \"Streams\": 5430260, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5W8jRrZ6tWrTrqnKRtIQBf\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.861, \"Energy\": 0.656, \"Loudness\": -7.867, \"Speechiness\": 0.425, \"Acousticness\": 0.104, \"Liveness\": 0.0986, \"Tempo\": 88.967, \"Duration (ms)\": 218210.0, \"Valence\": 0.331, \"Chord\": \"E\"}, {\"Index\": 280, \"Highest Charting Position\": 6, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"m y . l i f e (with 21 Savage & Morray)\", \"Streams\": 5246577, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"1D3z6HTiQsNmZxjl7F7eoG\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.597, \"Energy\": 0.587, \"Loudness\": -7.026, \"Speechiness\": 0.137, \"Acousticness\": 0.0622, \"Liveness\": 0.214, \"Tempo\": 140.021, \"Duration (ms)\": 218802.0, \"Valence\": 0.0753, \"Chord\": \"G\"}, {\"Index\": 281, \"Highest Charting Position\": 96, \"Number of Times Charted\": 77, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Jocelyn Flores\", \"Streams\": 5220422, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29539807.0, \"Song ID\": \"7m9OqQk4RVRkw9JJdeAw96\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2017-08-25\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.872, \"Energy\": 0.391, \"Loudness\": -9.144, \"Speechiness\": 0.242, \"Acousticness\": 0.469, \"Liveness\": 0.297, \"Tempo\": 134.021, \"Duration (ms)\": 119133.0, \"Valence\": 0.437, \"Chord\": \"C\"}, {\"Index\": 282, \"Highest Charting Position\": 66, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"No Return (with The Kid LAROI & Lil Durk)\", \"Streams\": 5189427, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"23OYT3SFtoJqhiAUqktbc1\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\", \"Popularity\": 80.0, \"Danceability\": 0.479, \"Energy\": 0.645, \"Loudness\": -7.336, \"Speechiness\": 0.302, \"Acousticness\": 0.135, \"Liveness\": 0.0825, \"Tempo\": 155.057, \"Duration (ms)\": 168729.0, \"Valence\": 0.381, \"Chord\": \"F\"}, {\"Index\": 283, \"Highest Charting Position\": 1, \"Number of Times Charted\": 78, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"The Box\", \"Streams\": 5145099, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6603627.0, \"Song ID\": \"0nbXyq5TXYPCO7pr3N8S4I\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.896, \"Energy\": 0.586, \"Loudness\": -6.687, \"Speechiness\": 0.0559, \"Acousticness\": 0.104, \"Liveness\": 0.79, \"Tempo\": 116.971, \"Duration (ms)\": 196653.0, \"Valence\": 0.642, \"Chord\": \"A#/Bb\"}, {\"Index\": 284, \"Highest Charting Position\": 31, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Wellerman - Sea Shanty / 220 KID x Billen Ted Remix\", \"Streams\": 5124606, \"Artist\": \"Nathan Evans\", \"Artist Followers\": 140812.0, \"Song ID\": \"3iw6V4LH7yPj1ESORX9RIN\", \"Genre\": \"[]\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 83.0, \"Danceability\": 0.722, \"Energy\": 0.893, \"Loudness\": -3.255, \"Speechiness\": 0.0475, \"Acousticness\": 0.0441, \"Liveness\": 0.0673, \"Tempo\": 119.932, \"Duration (ms)\": 116750.0, \"Valence\": 0.439, \"Chord\": \"C\"}, {\"Index\": 285, \"Highest Charting Position\": 170, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Can't Hold Us - feat. Ray Dalton\", \"Streams\": 5085147, \"Artist\": \"Macklemore & Ryan Lewis\", \"Artist Followers\": 2562082.0, \"Song ID\": \"3bidbhpOYeV4knp8AIu8Xn\", \"Genre\": \"['modern rock', 'pop rap', 'seattle hip hop']\", \"Release Date\": \"2012-10-09\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.641, \"Energy\": 0.922, \"Loudness\": -4.457, \"Speechiness\": 0.0786, \"Acousticness\": 0.0291, \"Liveness\": 0.0862, \"Tempo\": 146.078, \"Duration (ms)\": 258343.0, \"Valence\": 0.847, \"Chord\": \"D\"}, {\"Index\": 286, \"Highest Charting Position\": 6, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Anyone\", \"Streams\": 5079587, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 1250353.0, \"Song ID\": \"2RwMwWo43LapkA4raptxaB\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-01-31--2020-02-07\", \"Popularity\": 0.0, \"Danceability\": 0.686, \"Energy\": 0.538, \"Loudness\": -8.026, \"Speechiness\": 0.0345, \"Acousticness\": 0.181, \"Liveness\": 0.113, \"Tempo\": 115.884, \"Duration (ms)\": 190779.0, \"Valence\": 0.584, \"Chord\": \"D\"}, {\"Index\": 287, \"Highest Charting Position\": 39, \"Number of Times Charted\": 45, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"my ex's best friend (with blackbear)\", \"Streams\": 5048079, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3864419.0, \"Song ID\": \"7kDUspsoYfLkWnZR7qwHZl\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 83.0, \"Danceability\": 0.731, \"Energy\": 0.675, \"Loudness\": -5.134, \"Speechiness\": 0.0434, \"Acousticness\": 0.00473, \"Liveness\": 0.141, \"Tempo\": 124.939, \"Duration (ms)\": 139461.0, \"Valence\": 0.298, \"Chord\": \"F\"}, {\"Index\": 288, \"Highest Charting Position\": 133, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Just the Way You Are\", \"Streams\": 5043647, \"Artist\": \"Bruno Mars\", \"Artist Followers\": 32574754.0, \"Song ID\": \"7BqBn9nzAq8spo5e7cZ0dJ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2010-10-05\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 80.0, \"Danceability\": 0.637, \"Energy\": 0.843, \"Loudness\": -5.413, \"Speechiness\": 0.0432, \"Acousticness\": 0.0151, \"Liveness\": 0.0876, \"Tempo\": 109.012, \"Duration (ms)\": 220733.0, \"Valence\": 0.434, \"Chord\": \"F\"}, {\"Index\": 289, \"Highest Charting Position\": 17, \"Number of Times Charted\": 78, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"HIGHEST IN THE ROOM\", \"Streams\": 4975720, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17719446.0, \"Song ID\": \"3eekarcy7kvN4yt5ZFzltW\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.598, \"Energy\": 0.427, \"Loudness\": -8.764, \"Speechiness\": 0.0317, \"Acousticness\": 0.0546, \"Liveness\": 0.21, \"Tempo\": 76.469, \"Duration (ms)\": 175721.0, \"Valence\": 0.0605, \"Chord\": \"G\"}, {\"Index\": 290, \"Highest Charting Position\": 7, \"Number of Times Charted\": 65, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Break My Heart\", \"Streams\": 4971176, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27142474.0, \"Song ID\": \"017PF4Q3l4DBUiWoXk4OWT\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 80.0, \"Danceability\": 0.73, \"Energy\": 0.729, \"Loudness\": -3.434, \"Speechiness\": 0.0884, \"Acousticness\": 0.167, \"Liveness\": 0.349, \"Tempo\": 113.011, \"Duration (ms)\": 221820.0, \"Valence\": 0.467, \"Chord\": \"E\"}, {\"Index\": 291, \"Highest Charting Position\": 2, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Laugh Now Cry Later (feat. Lil Durk)\", \"Streams\": 4916860, \"Artist\": \"Drake\", \"Artist Followers\": 56308172.0, \"Song ID\": \"2SAqBLGA283SUiwJ3xOUVI\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 83.0, \"Danceability\": 0.761, \"Energy\": 0.518, \"Loudness\": -8.871, \"Speechiness\": 0.134, \"Acousticness\": 0.244, \"Liveness\": 0.107, \"Tempo\": 133.976, \"Duration (ms)\": 261493.0, \"Valence\": 0.522, \"Chord\": \"C\"}, {\"Index\": 292, \"Highest Charting Position\": 175, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"We Are The People (feat. Bono & The Edge) - Official UEFA EURO 2020 Song\", \"Streams\": 4912036, \"Artist\": \"Martin Garrix\", \"Artist Followers\": 14917926.0, \"Song ID\": \"2iL0W5qi0ivZ9WRXbZ74cS\", \"Genre\": \"['dance pop', 'dutch edm', 'edm', 'pop', 'pop dance', 'progressive house', 'tropical house']\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.66, \"Energy\": 0.733, \"Loudness\": -4.619, \"Speechiness\": 0.0359, \"Acousticness\": 0.248, \"Liveness\": 0.17, \"Tempo\": 119.933, \"Duration (ms)\": 217000.0, \"Valence\": 0.304, \"Chord\": \"C\"}, {\"Index\": 293, \"Highest Charting Position\": 23, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Ella No Es Tuya - Remix\", \"Streams\": 4911162, \"Artist\": \"Rochy RD, Myke Towers, Nicki Nicole\", \"Artist Followers\": 319192.0, \"Song ID\": \"5YYW3yRktprLRr47WK219Y\", \"Genre\": \"['dembow', 'dominican pop', 'rap dominicano', 'trap latino']\", \"Release Date\": \"2021-02-03\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 82.0, \"Danceability\": 0.585, \"Energy\": 0.611, \"Loudness\": -4.132, \"Speechiness\": 0.288, \"Acousticness\": 0.39, \"Liveness\": 0.649, \"Tempo\": 97.041, \"Duration (ms)\": 218107.0, \"Valence\": 0.962, \"Chord\": \"F#/Gb\"}, {\"Index\": 294, \"Highest Charting Position\": 176, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"In the End\", \"Streams\": 4910070, \"Artist\": \"Linkin Park\", \"Artist Followers\": 19584111.0, \"Song ID\": \"60a0Rd6pjrkxjPbaKzXjfq\", \"Genre\": \"['alternative metal', 'nu metal', 'post-grunge', 'rap metal']\", \"Release Date\": \"2000-10-24\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-03-19--2021-03-26\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 83.0, \"Danceability\": 0.556, \"Energy\": 0.864, \"Loudness\": -5.87, \"Speechiness\": 0.0584, \"Acousticness\": 0.00958, \"Liveness\": 0.209, \"Tempo\": 105.143, \"Duration (ms)\": 216880.0, \"Valence\": 0.4, \"Chord\": \"D#/Eb\"}, {\"Index\": 295, \"Highest Charting Position\": 119, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"No Role Modelz\", \"Streams\": 4904401, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"62vpWI1CHwFy7tMIcSStl8\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2014-12-09\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 84.0, \"Danceability\": 0.692, \"Energy\": 0.521, \"Loudness\": -8.465, \"Speechiness\": 0.33, \"Acousticness\": 0.301, \"Liveness\": 0.0565, \"Tempo\": 100.45, \"Duration (ms)\": 292987.0, \"Valence\": 0.463, \"Chord\": \"A#/Bb\"}, {\"Index\": 296, \"Highest Charting Position\": 7, \"Number of Times Charted\": 74, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"SICKO MODE\", \"Streams\": 4898977, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17719446.0, \"Song ID\": \"2xLMifQCjDGFmkHkpNLD9h\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2018-08-03\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.834, \"Energy\": 0.73, \"Loudness\": -3.714, \"Speechiness\": 0.222, \"Acousticness\": 0.00513, \"Liveness\": 0.124, \"Tempo\": 155.008, \"Duration (ms)\": 312820.0, \"Valence\": 0.446, \"Chord\": \"G#/Ab\"}, {\"Index\": 297, \"Highest Charting Position\": 161, \"Number of Times Charted\": 41, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Something Just Like This\", \"Streams\": 4862683, \"Artist\": \"The Chainsmokers, Coldplay\", \"Artist Followers\": 18191658.0, \"Song ID\": \"6RUKPb4LETWmmr3iAEQktW\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2017-04-07\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-02-26--2021-03-05\\n2021-01-01--2021-01-08\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.617, \"Energy\": 0.635, \"Loudness\": -6.769, \"Speechiness\": 0.0317, \"Acousticness\": 0.0498, \"Liveness\": 0.164, \"Tempo\": 103.019, \"Duration (ms)\": 247160.0, \"Valence\": 0.446, \"Chord\": \"B\"}, {\"Index\": 298, \"Highest Charting Position\": 84, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"You\", \"Streams\": 4846549, \"Artist\": \"Regard, Troye Sivan, Tate McRae\", \"Artist Followers\": 152226.0, \"Song ID\": \"2cc8Sw1OnCuA5bV8nqWqpE\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop edm', 'slap house', 'tropical house']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-06-18--2021-06-25\\n2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 83.0, \"Danceability\": 0.691, \"Energy\": 0.695, \"Loudness\": -5.6, \"Speechiness\": 0.0367, \"Acousticness\": 0.0592, \"Liveness\": 0.0647, \"Tempo\": 106.064, \"Duration (ms)\": 233386.0, \"Valence\": 0.514, \"Chord\": \"C\"}, {\"Index\": 299, \"Highest Charting Position\": 84, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Straightenin\", \"Streams\": 7615531, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"3X2r2CnHOJeV5YekPTgBnK\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 77.0, \"Danceability\": 0.847, \"Energy\": 0.629, \"Loudness\": -5.81, \"Speechiness\": 0.102, \"Acousticness\": 0.0318, \"Liveness\": 0.152, \"Tempo\": 135.976, \"Duration (ms)\": 255532.0, \"Valence\": 0.109, \"Chord\": \"A\"}, {\"Index\": 300, \"Highest Charting Position\": 71, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"GANG GANG (with Lil Wayne)\", \"Streams\": 7506580, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"4VW44pawoOHPUjlN7DX5vk\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 78.0, \"Danceability\": 0.752, \"Energy\": 0.563, \"Loudness\": -8.066, \"Speechiness\": 0.209, \"Acousticness\": 0.146, \"Liveness\": 0.103, \"Tempo\": 145.05, \"Duration (ms)\": 178776.0, \"Valence\": 0.551, \"Chord\": \"D#/Eb\"}, {\"Index\": 301, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Black Hearted\", \"Streams\": 6989528, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"25qk9xa71F1POdI4vj7rbi\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 75.0, \"Danceability\": 0.506, \"Energy\": 0.563, \"Loudness\": -7.664, \"Speechiness\": 0.411, \"Acousticness\": 0.0326, \"Liveness\": 0.0856, \"Tempo\": 168.146, \"Duration (ms)\": 190509.0, \"Valence\": 0.153, \"Chord\": \"C#/Db\"}, {\"Index\": 302, \"Highest Charting Position\": 124, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Lost\", \"Streams\": 6410263, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32262679.0, \"Song ID\": \"18XlJEroUwFo0tLZxscgXE\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 79.0, \"Danceability\": 0.766, \"Energy\": 0.706, \"Loudness\": -6.553, \"Speechiness\": 0.16, \"Acousticness\": 0.223, \"Liveness\": 0.064, \"Tempo\": 142.989, \"Duration (ms)\": 172598.0, \"Valence\": 0.766, \"Chord\": \"G\"}, {\"Index\": 303, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Avalanche\", \"Streams\": 6323268, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"4KD0lLJ4OGonZhBeKtct9I\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 71.0, \"Danceability\": 0.917, \"Energy\": 0.623, \"Loudness\": -8.231, \"Speechiness\": 0.135, \"Acousticness\": 0.0985, \"Liveness\": 0.0833, \"Tempo\": 126.063, \"Duration (ms)\": 206272.0, \"Valence\": 0.687, \"Chord\": \"C#/Db\"}, {\"Index\": 304, \"Highest Charting Position\": 59, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"My Head & My Heart\", \"Streams\": 5470147, \"Artist\": \"Ava Max\", \"Artist Followers\": 3911473.0, \"Song ID\": \"1KixkQVDUHggZMU9dUobgm\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 83.0, \"Danceability\": 0.614, \"Energy\": 0.934, \"Loudness\": -3.709, \"Speechiness\": 0.07, \"Acousticness\": 0.0697, \"Liveness\": 0.121, \"Tempo\": 116.001, \"Duration (ms)\": 174760.0, \"Valence\": 0.436, \"Chord\": \"A\"}, {\"Index\": 305, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Malibu (feat. Polo G)\", \"Streams\": 5456648, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"3v1zVVdzNVNt7vmI9VG2gq\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 72.0, \"Danceability\": 0.831, \"Energy\": 0.719, \"Loudness\": -6.836, \"Speechiness\": 0.235, \"Acousticness\": 0.514, \"Liveness\": 0.0675, \"Tempo\": 155.038, \"Duration (ms)\": 248652.0, \"Valence\": 0.859, \"Chord\": \"A#/Bb\"}, {\"Index\": 306, \"Highest Charting Position\": 36, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"GIRL LIKE ME\", \"Streams\": 5395181, \"Artist\": \"Black Eyed Peas, Shakira\", \"Artist Followers\": 5963840.0, \"Song ID\": \"1zLBsSVxETQOfINOLYvT5m\", \"Genre\": \"['dance pop', 'pop', 'pop rap']\", \"Release Date\": \"2020-11-02\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\", \"Popularity\": 82.0, \"Danceability\": 0.965, \"Energy\": 0.485, \"Loudness\": -8.784, \"Speechiness\": 0.191, \"Acousticness\": 0.0206, \"Liveness\": 0.0655, \"Tempo\": 124.025, \"Duration (ms)\": 222523.0, \"Valence\": 0.312, \"Chord\": \"D\"}, {\"Index\": 307, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Clueless (with Pop Smoke & Fivio Foreign)\", \"Streams\": 5335308, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"4CPcZHzSvIBM8AKhdHUwnL\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 74.0, \"Danceability\": 0.734, \"Energy\": 0.712, \"Loudness\": -6.217, \"Speechiness\": 0.201, \"Acousticness\": 0.391, \"Liveness\": 0.103, \"Tempo\": 140.369, \"Duration (ms)\": 165405.0, \"Valence\": 0.674, \"Chord\": \"F#/Gb\"}, {\"Index\": 308, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Modern Day\", \"Streams\": 5322745, \"Artist\": \"Migos\", \"Artist Followers\": 11690201.0, \"Song ID\": \"2Igem6Q4sfvXGJ3JkG7Baw\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 78.0, \"Danceability\": 0.87, \"Energy\": 0.629, \"Loudness\": -7.598, \"Speechiness\": 0.279, \"Acousticness\": 0.173, \"Liveness\": 0.101, \"Tempo\": 134.944, \"Duration (ms)\": 241790.0, \"Valence\": 0.512, \"Chord\": \"B\"}, {\"Index\": 309, \"Highest Charting Position\": 2, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Therefore I Am\", \"Streams\": 5265630, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"0aACcc1jEv2C6VSmmJbllJ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 0.0, \"Danceability\": 0.889, \"Energy\": 0.34, \"Loudness\": -7.773, \"Speechiness\": 0.0697, \"Acousticness\": 0.218, \"Liveness\": 0.055, \"Tempo\": 94.009, \"Duration (ms)\": 174321.0, \"Valence\": 0.716, \"Chord\": \"B\"}, {\"Index\": 310, \"Highest Charting Position\": 12, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"TE MUDASTE\", \"Streams\": 5242347, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36142273.0, \"Song ID\": \"5RubKOuDoPn5Kj5TLVxSxY\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 82.0, \"Danceability\": 0.811, \"Energy\": 0.637, \"Loudness\": -4.835, \"Speechiness\": 0.0591, \"Acousticness\": 0.234, \"Liveness\": 0.118, \"Tempo\": 92.025, \"Duration (ms)\": 130014.0, \"Valence\": 0.471, \"Chord\": \"A#/Bb\"}, {\"Index\": 311, \"Highest Charting Position\": 108, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Tipo Gin - Ao Vivo\", \"Streams\": 5155238, \"Artist\": \"MC Kevin o Chris\", \"Artist Followers\": 2753929.0, \"Song ID\": \"4llr8mcoauwrHBtjGb7F9S\", \"Genre\": \"['funk 150 bpm', 'funk carioca']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 81.0, \"Danceability\": 0.75, \"Energy\": 0.668, \"Loudness\": -4.49, \"Speechiness\": 0.061, \"Acousticness\": 0.78, \"Liveness\": 0.338, \"Tempo\": 94.998, \"Duration (ms)\": 159147.0, \"Valence\": 0.786, \"Chord\": \"C\"}, {\"Index\": 312, \"Highest Charting Position\": 39, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Higher Power\", \"Streams\": 5142982, \"Artist\": \"Coldplay\", \"Artist Followers\": 1250353.0, \"Song ID\": \"4rOEoKL0fHrxBMhVljpbGW\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 0.0, \"Danceability\": 0.507, \"Energy\": 0.828, \"Loudness\": -6.023, \"Speechiness\": 0.0449, \"Acousticness\": 0.00711, \"Liveness\": 0.261, \"Tempo\": 178.032, \"Duration (ms)\": 211295.0, \"Valence\": 0.489, \"Chord\": \"A#/Bb\"}, {\"Index\": 313, \"Highest Charting Position\": 54, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"SUN GOES DOWN\", \"Streams\": 5125477, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5473565.0, \"Song ID\": \"34eF4BoV8FPk0uhAAoqU7h\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\", \"Popularity\": 80.0, \"Danceability\": 0.551, \"Energy\": 0.636, \"Loudness\": -6.798, \"Speechiness\": 0.054, \"Acousticness\": 0.0837, \"Liveness\": 0.112, \"Tempo\": 174.065, \"Duration (ms)\": 168276.0, \"Valence\": 0.148, \"Chord\": \"D\"}, {\"Index\": 314, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-11--2021-06-18\", \"Song Name\": \"Painting Pictures\", \"Streams\": 5119845, \"Artist\": \"Polo G\", \"Artist Followers\": 4840346.0, \"Song ID\": \"25uBGaikHi0DhMiGMfuXYE\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2021-06-11--2021-06-18\", \"Popularity\": 72.0, \"Danceability\": 0.522, \"Energy\": 0.466, \"Loudness\": -8.05, \"Speechiness\": 0.458, \"Acousticness\": 0.331, \"Liveness\": 0.11, \"Tempo\": 78.43, \"Duration (ms)\": 137692.0, \"Valence\": 0.459, \"Chord\": \"D#/Eb\"}, {\"Index\": 315, \"Highest Charting Position\": 1, \"Number of Times Charted\": 55, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Rain On Me (with Ariana Grande)\", \"Streams\": 5041656, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18572085.0, \"Song ID\": \"24ySl2hOPGCDcxBxFIqWBu\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2021-06-11--2021-06-18\\n2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 79.0, \"Danceability\": 0.672, \"Energy\": 0.855, \"Loudness\": -3.764, \"Speechiness\": 0.0397, \"Acousticness\": 0.021, \"Liveness\": 0.323, \"Tempo\": 123.056, \"Duration (ms)\": 182200.0, \"Valence\": 0.646, \"Chord\": \"A\"}, {\"Index\": 316, \"Highest Charting Position\": 97, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Hats Off (feat. Travis Scott)\", \"Streams\": 7324233, \"Artist\": \"Lil Baby, Lil Durk\", \"Artist Followers\": 7805880.0, \"Song ID\": \"4lUmnwRybYH7mMzf16xB0y\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-06-04--2021-06-11\", \"Popularity\": 81.0, \"Danceability\": 0.596, \"Energy\": 0.65, \"Loudness\": -5.167, \"Speechiness\": 0.337, \"Acousticness\": 0.138, \"Liveness\": 0.14, \"Tempo\": 133.997, \"Duration (ms)\": 257428.0, \"Valence\": 0.188, \"Chord\": \"A\"}, {\"Index\": 317, \"Highest Charting Position\": 117, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Last Train Home\", \"Streams\": 6439718, \"Artist\": \"John Mayer\", \"Artist Followers\": 5178156.0, \"Song ID\": \"0tgBtQ0ISnMQOKorrN9HLX\", \"Genre\": \"['neo mellow', 'pop rock', 'singer-songwriter']\", \"Release Date\": \"2021-07-16\", \"Weeks Charted\": \"2021-06-04--2021-06-11\", \"Popularity\": 75.0, \"Danceability\": 0.591, \"Energy\": 0.831, \"Loudness\": -6.612, \"Speechiness\": 0.0355, \"Acousticness\": 0.235, \"Liveness\": 0.0571, \"Tempo\": 93.007, \"Duration (ms)\": 187307.0, \"Valence\": 0.678, \"Chord\": \"E\"}, {\"Index\": 318, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"Voice of the Heroes\", \"Streams\": 6249801, \"Artist\": \"Lil Baby, Lil Durk\", \"Artist Followers\": 7805880.0, \"Song ID\": \"4lUmnwRybYH7mMzf16xB0y\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-06-04--2021-06-11\", \"Popularity\": 81.0, \"Danceability\": 0.596, \"Energy\": 0.65, \"Loudness\": -5.167, \"Speechiness\": 0.337, \"Acousticness\": 0.138, \"Liveness\": 0.14, \"Tempo\": 133.997, \"Duration (ms)\": 257428.0, \"Valence\": 0.188, \"Chord\": \"A\"}, {\"Index\": 319, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-06-04--2021-06-11\", \"Song Name\": \"0X1=LOVESONG (I Know I Love you)\", \"Streams\": 6040553, \"Artist\": \"TOMORROW X TOGETHER, Seori\", \"Artist Followers\": 4136553.0, \"Song ID\": \"1Z8TPHiKeCUyClxV6WTTIf\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-05-31\", \"Weeks Charted\": \"2021-06-04--2021-06-11\", \"Popularity\": 81.0, \"Danceability\": 0.584, \"Energy\": 0.836, \"Loudness\": -4.925, \"Speechiness\": 0.079, \"Acousticness\": 0.0558, \"Liveness\": 0.0663, \"Tempo\": 104.973, \"Duration (ms)\": 202204.0, \"Valence\": 0.484, \"Chord\": \"C\"}, {\"Index\": 320, \"Highest Charting Position\": 10, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"a m a r i\", \"Streams\": 5645966, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"2cnKST6T9qUo2i907lm8zX\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 79.0, \"Danceability\": 0.725, \"Energy\": 0.713, \"Loudness\": -6.173, \"Speechiness\": 0.187, \"Acousticness\": 0.127, \"Liveness\": 0.617, \"Tempo\": 65.988, \"Duration (ms)\": 148421.0, \"Valence\": 0.207, \"Chord\": \"E\"}, {\"Index\": 321, \"Highest Charting Position\": 72, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"NEVER LEFT\", \"Streams\": 5552212, \"Artist\": \"Lil Tecca\", \"Artist Followers\": 4016497.0, \"Song ID\": \"21UkXrc9kD48rNpTMI2ecz\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2021-05-06\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 82.0, \"Danceability\": 0.807, \"Energy\": 0.659, \"Loudness\": -6.92, \"Speechiness\": 0.332, \"Acousticness\": 0.0224, \"Liveness\": 0.309, \"Tempo\": 82.465, \"Duration (ms)\": 168727.0, \"Valence\": 0.438, \"Chord\": \"B\"}, {\"Index\": 322, \"Highest Charting Position\": 27, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Solid (feat. Drake)\", \"Streams\": 5347781, \"Artist\": \"Young Stoner Life, Young Thug, Gunna\", \"Artist Followers\": 61930.0, \"Song ID\": \"6rTInqW3YECMkQsBEHw4sd\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 82.0, \"Danceability\": 0.887, \"Energy\": 0.485, \"Loudness\": -9.358, \"Speechiness\": 0.2, \"Acousticness\": 0.0392, \"Liveness\": 0.141, \"Tempo\": 125.987, \"Duration (ms)\": 215693.0, \"Valence\": 0.328, \"Chord\": \"B\"}, {\"Index\": 323, \"Highest Charting Position\": 21, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"La Nota\", \"Streams\": 5300884, \"Artist\": \"Manuel Turizo, Rauw Alejandro, Myke Towers\", \"Artist Followers\": 7904381.0, \"Song ID\": \"7ndTONDDRFGiPnnhOzOXxq\", \"Genre\": \"['colombian pop', 'latin', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2020-10-08\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 79.0, \"Danceability\": 0.736, \"Energy\": 0.632, \"Loudness\": -4.939, \"Speechiness\": 0.0648, \"Acousticness\": 0.18, \"Liveness\": 0.349, \"Tempo\": 92.03, \"Duration (ms)\": 216107.0, \"Valence\": 0.503, \"Chord\": \"B\"}, {\"Index\": 324, \"Highest Charting Position\": 47, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Golden\", \"Streams\": 5298893, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16112621.0, \"Song ID\": \"45S5WTQEGOB1VHr1Q4FuPl\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 83.0, \"Danceability\": 0.448, \"Energy\": 0.838, \"Loudness\": -5.257, \"Speechiness\": 0.0557, \"Acousticness\": 0.21, \"Liveness\": 0.131, \"Tempo\": 139.863, \"Duration (ms)\": 208907.0, \"Valence\": 0.254, \"Chord\": \"E\"}, {\"Index\": 325, \"Highest Charting Position\": 127, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"CORALINE\", \"Streams\": 5241813, \"Artist\": \"M\\u00e5neskin\", \"Artist Followers\": 3377762.0, \"Song ID\": \"7HMz8o0m7ASQ3ImFPfhWTY\", \"Genre\": \"['indie rock italiano', 'italian pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\", \"Popularity\": 81.0, \"Danceability\": 0.363, \"Energy\": 0.678, \"Loudness\": -4.939, \"Speechiness\": 0.0995, \"Acousticness\": 0.0299, \"Liveness\": 0.324, \"Tempo\": 162.124, \"Duration (ms)\": 300413.0, \"Valence\": 0.321, \"Chord\": \"D\"}, {\"Index\": 326, \"Highest Charting Position\": 3, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"BICHOTA\", \"Streams\": 5201714, \"Artist\": \"KAROL G\", \"Artist Followers\": 1250353.0, \"Song ID\": \"4nYLZSNXJyPq8Jj3cEdykP\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 0.0, \"Danceability\": 0.863, \"Energy\": 0.666, \"Loudness\": -4.158, \"Speechiness\": 0.152, \"Acousticness\": 0.212, \"Liveness\": 0.103, \"Tempo\": 163.908, \"Duration (ms)\": 178947.0, \"Valence\": 0.838, \"Chord\": \"C#/Db\"}, {\"Index\": 327, \"Highest Charting Position\": 96, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Slumber Party (feat. Princess Nokia)\", \"Streams\": 5113574, \"Artist\": \"Ashnikko\", \"Artist Followers\": 1246335.0, \"Song ID\": \"11ZulcYY4lowvcQm4oe3VJ\", \"Genre\": \"['electropop', 'escape room', 'pop']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-06-04--2021-06-11\\n2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 82.0, \"Danceability\": 0.964, \"Energy\": 0.398, \"Loudness\": -8.981, \"Speechiness\": 0.0795, \"Acousticness\": 0.00151, \"Liveness\": 0.101, \"Tempo\": 105.012, \"Duration (ms)\": 178405.0, \"Valence\": 0.563, \"Chord\": \"B\"}, {\"Index\": 328, \"Highest Charting Position\": 170, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Killer (feat. Jack Harlow & Cordae) - Remix\", \"Streams\": 5404939, \"Artist\": \"Eminem\", \"Artist Followers\": 46785561.0, \"Song ID\": \"7zl7kehxesNEo2pYkKXTSe\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-05-28--2021-06-04\", \"Popularity\": 76.0, \"Danceability\": 0.924, \"Energy\": 0.73, \"Loudness\": -6.125, \"Speechiness\": 0.274, \"Acousticness\": 0.0525, \"Liveness\": 0.113, \"Tempo\": 99.01, \"Duration (ms)\": 236666.0, \"Valence\": 0.848, \"Chord\": \"B\"}, {\"Index\": 329, \"Highest Charting Position\": 105, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Liberdade (Quando o Grave Bate Forte)\", \"Streams\": 5378350, \"Artist\": \"Alok, Mc Don Juan, Dj GBR\", \"Artist Followers\": 10334543.0, \"Song ID\": \"2QLbRVzixE282JSQjBz2DG\", \"Genre\": \"['electro house', 'pop nacional', 'slap house']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\", \"Popularity\": 80.0, \"Danceability\": 0.81, \"Energy\": 0.789, \"Loudness\": -4.032, \"Speechiness\": 0.0498, \"Acousticness\": 0.0254, \"Liveness\": 0.104, \"Tempo\": 129.988, \"Duration (ms)\": 150462.0, \"Valence\": 0.432, \"Chord\": \"F#/Gb\"}, {\"Index\": 330, \"Highest Charting Position\": 108, \"Number of Times Charted\": 51, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"All Girls Are The Same\", \"Streams\": 5372180, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"4VXIryQMWpIdGgYR4TrjT1\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2018-12-10\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-08--2020-05-15\\n2020-04-24--2020-05-01\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.671, \"Energy\": 0.529, \"Loudness\": -7.226, \"Speechiness\": 0.307, \"Acousticness\": 0.0769, \"Liveness\": 0.0856, \"Tempo\": 161.989, \"Duration (ms)\": 165820.0, \"Valence\": 0.203, \"Chord\": \"C\"}, {\"Index\": 331, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"734\", \"Streams\": 5368759, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"6vB8bdQCCTDDIH8fhRfuXA\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2021-05-28\", \"Weeks Charted\": \"2021-05-28--2021-06-04\", \"Popularity\": 75.0, \"Danceability\": 0.663, \"Energy\": 0.545, \"Loudness\": -3.93, \"Speechiness\": 0.036, \"Acousticness\": 0.123, \"Liveness\": 0.106, \"Tempo\": 78.452, \"Duration (ms)\": 196147.0, \"Valence\": 0.344, \"Chord\": \"D\"}, {\"Index\": 332, \"Highest Charting Position\": 85, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Boy With Luv (feat. Halsey)\", \"Streams\": 5266625, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"5KawlOMHjWeUjQtnuRs22c\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2019-04-12\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2020-11-20--2020-11-27\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-01-17--2020-01-24\", \"Popularity\": 82.0, \"Danceability\": 0.645, \"Energy\": 0.862, \"Loudness\": -4.757, \"Speechiness\": 0.0965, \"Acousticness\": 0.0923, \"Liveness\": 0.192, \"Tempo\": 119.991, \"Duration (ms)\": 229773.0, \"Valence\": 0.798, \"Chord\": \"B\"}, {\"Index\": 333, \"Highest Charting Position\": 82, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Disco Arranhado - Funk Remix\", \"Streams\": 5207186, \"Artist\": \"Malu, DJ Lucas Beat\", \"Artist Followers\": 74814.0, \"Song ID\": \"2Gjt4rUHBUH0rMKpBg0hF4\", \"Genre\": \"[]\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 80.0, \"Danceability\": 0.747, \"Energy\": 0.725, \"Loudness\": -2.564, \"Speechiness\": 0.363, \"Acousticness\": 0.551, \"Liveness\": 0.0626, \"Tempo\": 129.96, \"Duration (ms)\": 125558.0, \"Valence\": 0.904, \"Chord\": \"D\"}, {\"Index\": 334, \"Highest Charting Position\": 4, \"Number of Times Charted\": 70, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Godzilla (feat. Juice WRLD)\", \"Streams\": 5143522, \"Artist\": \"Eminem\", \"Artist Followers\": 46785561.0, \"Song ID\": \"7FIWs0pqAYbP91WWM0vlTQ\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 83.0, \"Danceability\": 0.808, \"Energy\": 0.745, \"Loudness\": -5.26, \"Speechiness\": 0.342, \"Acousticness\": 0.145, \"Liveness\": 0.292, \"Tempo\": 165.995, \"Duration (ms)\": 210800.0, \"Valence\": 0.829, \"Chord\": \"A#/Bb\"}, {\"Index\": 335, \"Highest Charting Position\": 8, \"Number of Times Charted\": 68, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Blueberry Faygo\", \"Streams\": 5085511, \"Artist\": \"Lil Mosey\", \"Artist Followers\": 3816446.0, \"Song ID\": \"6wJYhPfqk3KGhHRG76WzOh\", \"Genre\": \"['melodic rap', 'rap', 'rap conscient', 'trap', 'vapor trap']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 79.0, \"Danceability\": 0.774, \"Energy\": 0.554, \"Loudness\": -7.909, \"Speechiness\": 0.0383, \"Acousticness\": 0.207, \"Liveness\": 0.132, \"Tempo\": 99.034, \"Duration (ms)\": 162547.0, \"Valence\": 0.349, \"Chord\": \"C\"}, {\"Index\": 336, \"Highest Charting Position\": 129, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Somebody That I Used To Know\", \"Streams\": 5068972, \"Artist\": \"Gotye, Kimbra\", \"Artist Followers\": 2263960.0, \"Song ID\": \"4wCmqSrbyCgxEXROQE6vtV\", \"Genre\": \"['australian pop']\", \"Release Date\": \"2011-01-01\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 76.0, \"Danceability\": 0.864, \"Energy\": 0.495, \"Loudness\": -7.036, \"Speechiness\": 0.037, \"Acousticness\": 0.591, \"Liveness\": 0.0992, \"Tempo\": 129.062, \"Duration (ms)\": 244973.0, \"Valence\": 0.72, \"Chord\": \"C\"}, {\"Index\": 337, \"Highest Charting Position\": 4, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Holy (feat. Chance The Rapper)\", \"Streams\": 5063015, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48504126.0, \"Song ID\": \"5u1n1kITHCxxp8twBcZxWy\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2021-05-28--2021-06-04\\n2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 81.0, \"Danceability\": 0.673, \"Energy\": 0.704, \"Loudness\": -8.056, \"Speechiness\": 0.36, \"Acousticness\": 0.196, \"Liveness\": 0.0898, \"Tempo\": 86.919, \"Duration (ms)\": 212093.0, \"Valence\": 0.372, \"Chord\": \"F#/Gb\"}, {\"Index\": 338, \"Highest Charting Position\": 200, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-28--2021-06-04\", \"Song Name\": \"Vida Louca\", \"Streams\": 5051514, \"Artist\": \"Mc Poze do Rodo, Neo Beats, Mainstreet\", \"Artist Followers\": 448447.0, \"Song ID\": \"7IG7laqVpcvIIULrwWP5SA\", \"Genre\": \"['funk carioca', 'funk ostentacao']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-05-28--2021-06-04\", \"Popularity\": 82.0, \"Danceability\": 0.852, \"Energy\": 0.62, \"Loudness\": -5.79, \"Speechiness\": 0.227, \"Acousticness\": 0.359, \"Liveness\": 0.101, \"Tempo\": 92.464, \"Duration (ms)\": 155676.0, \"Valence\": 0.744, \"Chord\": \"F#/Gb\"}, {\"Index\": 339, \"Highest Charting Position\": 15, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"i n t e r l u d e\", \"Streams\": 7880155, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"08LwMWf5Tcfsd752EPzFV0\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\", \"Popularity\": 76.0, \"Danceability\": 0.77, \"Energy\": 0.574, \"Loudness\": -5.525, \"Speechiness\": 0.106, \"Acousticness\": 0.0617, \"Liveness\": 0.104, \"Tempo\": 98.962, \"Duration (ms)\": 133022.0, \"Valence\": 0.104, \"Chord\": \"C#/Db\"}, {\"Index\": 340, \"Highest Charting Position\": 95, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Butter (Instrumental)\", \"Streams\": 7450126, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"2Ol2sv6gePRdJrZC1hDVNY\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-06-04\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 70.0, \"Danceability\": 0.429, \"Energy\": 0.387, \"Loudness\": -7.486, \"Speechiness\": 0.0753, \"Acousticness\": 0.000178, \"Liveness\": 0.142, \"Tempo\": 109.893, \"Duration (ms)\": 162147.0, \"Valence\": 0.41, \"Chord\": \"C#/Db\"}, {\"Index\": 341, \"Highest Charting Position\": 25, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Film out\", \"Streams\": 7198095, \"Artist\": \"BTS\", \"Artist Followers\": 37106176.0, \"Song ID\": \"3UHPGOkUcE4hE7sqBF4Snt\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2021-04-01\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 81.0, \"Danceability\": 0.499, \"Energy\": 0.709, \"Loudness\": -6.404, \"Speechiness\": 0.134, \"Acousticness\": 0.296, \"Liveness\": 0.331, \"Tempo\": 164.032, \"Duration (ms)\": 214621.0, \"Valence\": 0.314, \"Chord\": \"A#/Bb\"}, {\"Index\": 342, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Voil\\u00e0\", \"Streams\": 6935400, \"Artist\": \"Barbara Pravi\", \"Artist Followers\": 75496.0, \"Song ID\": \"1uAOCTevGnyKIDbgZdOCnE\", \"Genre\": \"['eurovision', 'nouvelle chanson francaise']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 72.0, \"Danceability\": 0.447, \"Energy\": 0.337, \"Loudness\": -8.665, \"Speechiness\": 0.0631, \"Acousticness\": 0.773, \"Liveness\": 0.298, \"Tempo\": 135.379, \"Duration (ms)\": 176816.0, \"Valence\": 0.603, \"Chord\": \"D\"}, {\"Index\": 343, \"Highest Charting Position\": 53, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Shy Away\", \"Streams\": 6634722, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20823062.0, \"Song ID\": \"2nG54Y4a3sH9YpfxMolOyi\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 77.0, \"Danceability\": 0.588, \"Energy\": 0.856, \"Loudness\": -5.242, \"Speechiness\": 0.0316, \"Acousticness\": 0.000818, \"Liveness\": 0.238, \"Tempo\": 96.966, \"Duration (ms)\": 175044.0, \"Valence\": 0.635, \"Chord\": \"A\"}, {\"Index\": 344, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Saturday\", \"Streams\": 6628638, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20823062.0, \"Song ID\": \"60dwJ8dnqZ4WrIdiu7LkNR\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 75.0, \"Danceability\": 0.687, \"Energy\": 0.89, \"Loudness\": -5.99, \"Speechiness\": 0.0344, \"Acousticness\": 0.00396, \"Liveness\": 0.0436, \"Tempo\": 113.06, \"Duration (ms)\": 172232.0, \"Valence\": 0.854, \"Chord\": \"G#/Ab\"}, {\"Index\": 345, \"Highest Charting Position\": 18, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"9 5 . s o u t h\", \"Streams\": 6333126, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5R691ipUYRDYW6ehapjoj6\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 75.0, \"Danceability\": 0.713, \"Energy\": 0.793, \"Loudness\": -5.277, \"Speechiness\": 0.397, \"Acousticness\": 0.271, \"Liveness\": 0.727, \"Tempo\": 71.724, \"Duration (ms)\": 196946.0, \"Valence\": 0.203, \"Chord\": \"D\"}, {\"Index\": 346, \"Highest Charting Position\": 67, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Seeing Green (with Drake & Lil Wayne)\", \"Streams\": 6299936, \"Artist\": \"Nicki Minaj\", \"Artist Followers\": 22161310.0, \"Song ID\": \"1TZv3bujNaYz646eezRE91\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'pop rap', 'post-teen pop', 'queens hip hop']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 77.0, \"Danceability\": 0.573, \"Energy\": 0.867, \"Loudness\": -2.876, \"Speechiness\": 0.168, \"Acousticness\": 0.0853, \"Liveness\": 0.38, \"Tempo\": 74.861, \"Duration (ms)\": 339506.0, \"Valence\": 0.231, \"Chord\": \"F\"}, {\"Index\": 347, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Dark Side\", \"Streams\": 6277641, \"Artist\": \"Blind Channel\", \"Artist Followers\": 121225.0, \"Song ID\": \"1ovFnZv6mUe0LzAbfVqOmh\", \"Genre\": \"['eurovision', 'oulu metal', 'trancecore']\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 72.0, \"Danceability\": 0.571, \"Energy\": 0.955, \"Loudness\": -3.795, \"Speechiness\": 0.105, \"Acousticness\": 0.00254, \"Liveness\": 0.274, \"Tempo\": 98.01, \"Duration (ms)\": 177790.0, \"Valence\": 0.437, \"Chord\": \"G\"}, {\"Index\": 348, \"Highest Charting Position\": 137, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"SHUM\", \"Streams\": 6237019, \"Artist\": \"Go_A\", \"Artist Followers\": 107553.0, \"Song ID\": \"7mEDVrAHDnQJStDo8jKJJm\", \"Genre\": \"['eurovision']\", \"Release Date\": \"2021-03-10\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 75.0, \"Danceability\": 0.527, \"Energy\": 0.737, \"Loudness\": -5.34, \"Speechiness\": 0.0642, \"Acousticness\": 0.05, \"Liveness\": 0.105, \"Tempo\": 116.431, \"Duration (ms)\": 172675.0, \"Valence\": 0.499, \"Chord\": \"E\"}, {\"Index\": 349, \"Highest Charting Position\": 69, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"In the morning\", \"Streams\": 5738325, \"Artist\": \"ITZY\", \"Artist Followers\": 2379448.0, \"Song ID\": \"2QdH0rKlV3d9Y6lWzcnlBH\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 79.0, \"Danceability\": 0.847, \"Energy\": 0.814, \"Loudness\": -4.668, \"Speechiness\": 0.152, \"Acousticness\": 0.0825, \"Liveness\": 0.0948, \"Tempo\": 140.057, \"Duration (ms)\": 172359.0, \"Valence\": 0.711, \"Chord\": \"B\"}, {\"Index\": 350, \"Highest Charting Position\": 27, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"l e t . g o . m y . h a n d (with Bas & 6LACK)\", \"Streams\": 5393643, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"0GAyuCo975IHGxxiLKDufB\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\", \"Popularity\": 73.0, \"Danceability\": 0.583, \"Energy\": 0.625, \"Loudness\": -8.011, \"Speechiness\": 0.277, \"Acousticness\": 0.506, \"Liveness\": 0.196, \"Tempo\": 89.812, \"Duration (ms)\": 266291.0, \"Valence\": 0.516, \"Chord\": \"C#/Db\"}, {\"Index\": 351, \"Highest Charting Position\": 2, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"What\\u2019s Next\", \"Streams\": 5335112, \"Artist\": \"Drake\", \"Artist Followers\": 56308172.0, \"Song ID\": \"3aQem4jVGdhtg116TmJnHz\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 81.0, \"Danceability\": 0.781, \"Energy\": 0.594, \"Loudness\": -6.959, \"Speechiness\": 0.0485, \"Acousticness\": 0.0136, \"Liveness\": 0.162, \"Tempo\": 129.895, \"Duration (ms)\": 178154.0, \"Valence\": 0.0628, \"Chord\": \"C\"}, {\"Index\": 352, \"Highest Charting Position\": 154, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Ramen & OJ\", \"Streams\": 5282702, \"Artist\": \"Joyner Lucas, Lil Baby\", \"Artist Followers\": 1725025.0, \"Song ID\": \"4TIqzdAssasqx3DAe6cG9J\", \"Genre\": \"['boston hip hop', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 81.0, \"Danceability\": 0.597, \"Energy\": 0.571, \"Loudness\": -6.205, \"Speechiness\": 0.293, \"Acousticness\": 0.492, \"Liveness\": 0.093, \"Tempo\": 106.196, \"Duration (ms)\": 218448.0, \"Valence\": 0.165, \"Chord\": \"C#/Db\"}, {\"Index\": 353, \"Highest Charting Position\": 91, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Cloud 9\", \"Streams\": 5252767, \"Artist\": \"Beach Bunny\", \"Artist Followers\": 618444.0, \"Song ID\": \"6vFsBXYczYsP0H3lgunZOm\", \"Genre\": \"['bubblegrunge', 'chicago indie', 'indie pop', 'pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 81.0, \"Danceability\": 0.637, \"Energy\": 0.929, \"Loudness\": -3.593, \"Speechiness\": 0.0491, \"Acousticness\": 0.00167, \"Liveness\": 0.344, \"Tempo\": 80.974, \"Duration (ms)\": 147351.0, \"Valence\": 0.902, \"Chord\": \"E\"}, {\"Index\": 354, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Tout l'univers\", \"Streams\": 5174437, \"Artist\": \"Gjon's Tears\", \"Artist Followers\": 32257.0, \"Song ID\": \"3MvY2XbGYFi6p2dgmdcOYG\", \"Genre\": \"[]\", \"Release Date\": \"2021-03-10\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 69.0, \"Danceability\": 0.534, \"Energy\": 0.365, \"Loudness\": -9.187, \"Speechiness\": 0.033, \"Acousticness\": 0.81, \"Liveness\": 0.158, \"Tempo\": 123.466, \"Duration (ms)\": 183707.0, \"Valence\": 0.237, \"Chord\": \"A\"}, {\"Index\": 355, \"Highest Charting Position\": 64, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Headshot (feat. Polo G & Fivio Foreign)\", \"Streams\": 5174298, \"Artist\": \"Lil Tjay\", \"Artist Followers\": 3553442.0, \"Song ID\": \"4eNOLmx8r2IJAVKvBBL1jv\", \"Genre\": \"['brooklyn drill', 'melodic rap', 'nyc rap']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 81.0, \"Danceability\": 0.808, \"Energy\": 0.639, \"Loudness\": -7.266, \"Speechiness\": 0.279, \"Acousticness\": 0.0802, \"Liveness\": 0.15, \"Tempo\": 118.0, \"Duration (ms)\": 144349.0, \"Valence\": 0.395, \"Chord\": \"C#/Db\"}, {\"Index\": 356, \"Highest Charting Position\": 198, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"Mask\", \"Streams\": 5156496, \"Artist\": \"Dream\", \"Artist Followers\": 727731.0, \"Song ID\": \"3IxMaULfjq4IT2IN6v54PB\", \"Genre\": \"['dream smp']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 76.0, \"Danceability\": 0.636, \"Energy\": 0.749, \"Loudness\": -4.197, \"Speechiness\": 0.0631, \"Acousticness\": 0.195, \"Liveness\": 0.107, \"Tempo\": 117.904, \"Duration (ms)\": 174936.0, \"Valence\": 0.653, \"Chord\": \"C#/Db\"}, {\"Index\": 357, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-21--2021-05-28\", \"Song Name\": \"10 Years\", \"Streams\": 5152139, \"Artist\": \"Da\\u00f0i Freyr\", \"Artist Followers\": 169137.0, \"Song ID\": \"4O0LQKVT6hGmVGNwizmydg\", \"Genre\": \"['icelandic pop', 'sunnlensk tonlist']\", \"Release Date\": \"2021-03-13\", \"Weeks Charted\": \"2021-05-21--2021-05-28\", \"Popularity\": 70.0, \"Danceability\": 0.798, \"Energy\": 0.621, \"Loudness\": -6.916, \"Speechiness\": 0.0391, \"Acousticness\": 0.0141, \"Liveness\": 0.0926, \"Tempo\": 123.038, \"Duration (ms)\": 166000.0, \"Valence\": 0.443, \"Chord\": \"D\"}, {\"Index\": 358, \"Highest Charting Position\": 127, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Choker\", \"Streams\": 5150176, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20823062.0, \"Song ID\": \"732E6ibFkQR5lNIPEeiEnx\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-05-21--2021-05-28\\n2021-04-30--2021-05-07\", \"Popularity\": 72.0, \"Danceability\": 0.7, \"Energy\": 0.664, \"Loudness\": -8.211, \"Speechiness\": 0.0394, \"Acousticness\": 0.306, \"Liveness\": 0.249, \"Tempo\": 142.009, \"Duration (ms)\": 223066.0, \"Valence\": 0.585, \"Chord\": \"G\"}, {\"Index\": 359, \"Highest Charting Position\": 25, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"a p p l y i n g . p r e s s u r e\", \"Streams\": 15967986, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"1d7q712nXjG98HiwHk7HFS\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 71.0, \"Danceability\": 0.699, \"Energy\": 0.759, \"Loudness\": -5.302, \"Speechiness\": 0.311, \"Acousticness\": 0.0814, \"Liveness\": 0.312, \"Tempo\": 83.092, \"Duration (ms)\": 177337.0, \"Valence\": 0.404, \"Chord\": \"C#/Db\"}, {\"Index\": 360, \"Highest Charting Position\": 30, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"1 0 0 . m i l \\u2018 (with Bas)\", \"Streams\": 15171655, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"4n6NDfYake476trCjJRNl0\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 72.0, \"Danceability\": 0.711, \"Energy\": 0.647, \"Loudness\": -5.667, \"Speechiness\": 0.0822, \"Acousticness\": 0.334, \"Liveness\": 0.312, \"Tempo\": 125.092, \"Duration (ms)\": 163302.0, \"Valence\": 0.227, \"Chord\": \"D\"}, {\"Index\": 361, \"Highest Charting Position\": 32, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"p u n c h i n \\u2018 . t h e . c l o c k\", \"Streams\": 14051831, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"57ZUX6TNyKLBydAdVVd02x\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 70.0, \"Danceability\": 0.769, \"Energy\": 0.74, \"Loudness\": -6.579, \"Speechiness\": 0.378, \"Acousticness\": 0.197, \"Liveness\": 0.171, \"Tempo\": 94.104, \"Duration (ms)\": 112579.0, \"Valence\": 0.692, \"Chord\": \"B\"}, {\"Index\": 362, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"t h e . c l i m b . b a c k\", \"Streams\": 12648655, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5lLNBIyjp72btcnrjBG751\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.618, \"Energy\": 0.632, \"Loudness\": -6.973, \"Speechiness\": 0.346, \"Acousticness\": 0.0526, \"Liveness\": 0.353, \"Tempo\": 81.446, \"Duration (ms)\": 306257.0, \"Valence\": 0.319, \"Chord\": \"B\"}, {\"Index\": 363, \"Highest Charting Position\": 48, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"h u n g e r . o n . h i l l s i d e (with Bas)\", \"Streams\": 11647489, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"5BwQjRasNcdRPuVWKcHto2\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 71.0, \"Danceability\": 0.563, \"Energy\": 0.703, \"Loudness\": -5.756, \"Speechiness\": 0.0702, \"Acousticness\": 0.126, \"Liveness\": 0.213, \"Tempo\": 94.983, \"Duration (ms)\": 238972.0, \"Valence\": 0.294, \"Chord\": \"D\"}, {\"Index\": 364, \"Highest Charting Position\": 55, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"c l o s e\", \"Streams\": 10712648, \"Artist\": \"J. Cole\", \"Artist Followers\": 14097410.0, \"Song ID\": \"1D3z6HTiQsNmZxjl7F7eoG\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2021-05-14\", \"Weeks Charted\": \"2021-05-14--2021-05-21\", \"Popularity\": 82.0, \"Danceability\": 0.597, \"Energy\": 0.587, \"Loudness\": -7.026, \"Speechiness\": 0.137, \"Acousticness\": 0.0622, \"Liveness\": 0.214, \"Tempo\": 140.021, \"Duration (ms)\": 218802.0, \"Valence\": 0.0753, \"Chord\": \"G\"}, {\"Index\": 365, \"Highest Charting Position\": 34, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"WITHOUT YOU (with Miley Cyrus)\", \"Streams\": 6081034, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2230022.0, \"Song ID\": \"1EHUQesfVKwbthtNcpBi9g\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 81.0, \"Danceability\": 0.655, \"Energy\": 0.469, \"Loudness\": -6.257, \"Speechiness\": 0.0292, \"Acousticness\": 0.173, \"Liveness\": 0.0956, \"Tempo\": 92.56, \"Duration (ms)\": 161385.0, \"Valence\": 0.467, \"Chord\": \"C\"}, {\"Index\": 366, \"Highest Charting Position\": 92, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Snow Tha Product: Bzrp Music Sessions, Vol. 39\", \"Streams\": 5595839, \"Artist\": \"Bizarrap, Snow Tha Product\", \"Artist Followers\": 3126961.0, \"Song ID\": \"3ke6it1vTmHtz2ApcIVUz5\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2021-04-28\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 78.0, \"Danceability\": 0.83, \"Energy\": 0.748, \"Loudness\": -5.362, \"Speechiness\": 0.162, \"Acousticness\": 0.354, \"Liveness\": 0.0992, \"Tempo\": 133.028, \"Duration (ms)\": 177443.0, \"Valence\": 0.523, \"Chord\": \"C#/Db\"}, {\"Index\": 367, \"Highest Charting Position\": 87, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Travesuras - Remix\", \"Streams\": 5518444, \"Artist\": \"Nio Garcia, Casper Magico, Ozuna, Wisin & Yandel, Myke Towers, Flow La Movie\", \"Artist Followers\": 2123734.0, \"Song ID\": \"0VWLId2RwPCno9s1cJm2Vy\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-03-11\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 81.0, \"Danceability\": 0.739, \"Energy\": 0.788, \"Loudness\": -5.198, \"Speechiness\": 0.0731, \"Acousticness\": 0.0513, \"Liveness\": 0.282, \"Tempo\": 175.996, \"Duration (ms)\": 324426.0, \"Valence\": 0.473, \"Chord\": \"C#/Db\"}, {\"Index\": 368, \"Highest Charting Position\": 148, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Bubblegum Bitch\", \"Streams\": 5375782, \"Artist\": \"MARINA\", \"Artist Followers\": 2918229.0, \"Song ID\": \"0ZFBKLOZLIM16RAUb5eomN\", \"Genre\": \"['dance pop', 'electropop', 'metropopolis', 'pop', 'post-teen pop', 'uk alternative pop']\", \"Release Date\": \"2012-04-30\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 73.0, \"Danceability\": 0.495, \"Energy\": 0.856, \"Loudness\": -5.123, \"Speechiness\": 0.0311, \"Acousticness\": 0.000219, \"Liveness\": 0.103, \"Tempo\": 158.024, \"Duration (ms)\": 154667.0, \"Valence\": 0.609, \"Chord\": \"C\"}, {\"Index\": 369, \"Highest Charting Position\": 5, \"Number of Times Charted\": 142, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Falling\", \"Streams\": 5294368, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16112621.0, \"Song ID\": \"1ZMiCix7XSAbfAJlEZWMCp\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.567, \"Energy\": 0.267, \"Loudness\": -6.502, \"Speechiness\": 0.0299, \"Acousticness\": 0.839, \"Liveness\": 0.089, \"Tempo\": 110.011, \"Duration (ms)\": 240133.0, \"Valence\": 0.0592, \"Chord\": \"E\"}, {\"Index\": 370, \"Highest Charting Position\": 182, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-05-14--2021-05-21\", \"Song Name\": \"Expl\\u00edcito\", \"Streams\": 5278449, \"Artist\": \"Myke Towers\", \"Artist Followers\": 6150675.0, \"Song ID\": \"6qraVL4IJaIj0IuEexYJNa\", \"Genre\": \"['trap latino']\", \"Release Date\": \"2020-12-15\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-03-26--2021-04-02\", \"Popularity\": 81.0, \"Danceability\": 0.828, \"Energy\": 0.83, \"Loudness\": -3.371, \"Speechiness\": 0.047, \"Acousticness\": 0.348, \"Liveness\": 0.0613, \"Tempo\": 95.007, \"Duration (ms)\": 195066.0, \"Valence\": 0.422, \"Chord\": \"D\"}, {\"Index\": 371, \"Highest Charting Position\": 58, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"No Te Enamores - Remix\", \"Streams\": 5218146, \"Artist\": \"Milly, Farruko, Nio Garcia, Jay Wheeler, Amenazzy\", \"Artist Followers\": 22718.0, \"Song ID\": \"2mM3gZ0BbPwPPMelbA8vgt\", \"Genre\": \"['reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 79.0, \"Danceability\": 0.824, \"Energy\": 0.837, \"Loudness\": -4.603, \"Speechiness\": 0.107, \"Acousticness\": 0.573, \"Liveness\": 0.271, \"Tempo\": 100.021, \"Duration (ms)\": 289933.0, \"Valence\": 0.58, \"Chord\": \"F\"}, {\"Index\": 372, \"Highest Charting Position\": 110, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"PROBLEMA\", \"Streams\": 5215973, \"Artist\": \"Daddy Yankee\", \"Artist Followers\": 1250353.0, \"Song ID\": \"7vzPjsX8UzlPKKtV47qGPn\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 0.0, \"Danceability\": 0.773, \"Energy\": 0.8, \"Loudness\": -3.17, \"Speechiness\": 0.0987, \"Acousticness\": 0.0613, \"Liveness\": 0.0327, \"Tempo\": 89.988, \"Duration (ms)\": 184507.0, \"Valence\": 0.842, \"Chord\": \"A#/Bb\"}, {\"Index\": 373, \"Highest Charting Position\": 5, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Lonely (with benny blanco)\", \"Streams\": 5191697, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48504126.0, \"Song ID\": \"4y4spB9m0Q6026KfkAvy9Q\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 80.0, \"Danceability\": 0.631, \"Energy\": 0.239, \"Loudness\": -7.071, \"Speechiness\": 0.0398, \"Acousticness\": 0.864, \"Liveness\": 0.116, \"Tempo\": 79.859, \"Duration (ms)\": 149297.0, \"Valence\": 0.0927, \"Chord\": \"B\"}, {\"Index\": 374, \"Highest Charting Position\": 77, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Cupid's Chokehold / Breakfast in America\", \"Streams\": 5165035, \"Artist\": \"Gym Class Heroes\", \"Artist Followers\": 1275345.0, \"Song ID\": \"2Lhdl74nwwVGOE2Gv35QuK\", \"Genre\": \"['dance pop', 'pop rap']\", \"Release Date\": \"2005-02-22\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 81.0, \"Danceability\": 0.72, \"Energy\": 0.744, \"Loudness\": -6.938, \"Speechiness\": 0.12, \"Acousticness\": 0.237, \"Liveness\": 0.255, \"Tempo\": 78.953, \"Duration (ms)\": 243773.0, \"Valence\": 0.619, \"Chord\": \"C#/Db\"}, {\"Index\": 375, \"Highest Charting Position\": 38, \"Number of Times Charted\": 72, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"If the World Was Ending - feat. Julia Michaels\", \"Streams\": 5127736, \"Artist\": \"JP Saxe\", \"Artist Followers\": 280585.0, \"Song ID\": \"2kJwzbxV2ppxnQoYw4GLBZ\", \"Genre\": \"['alt z', 'canadian contemporary r&b', 'indie cafe pop', 'pop', 'pop rock', 'post-teen pop']\", \"Release Date\": \"2019-10-17\", \"Weeks Charted\": \"2021-05-14--2021-05-21\\n2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.464, \"Energy\": 0.473, \"Loudness\": -10.086, \"Speechiness\": 0.129, \"Acousticness\": 0.866, \"Liveness\": 0.109, \"Tempo\": 75.801, \"Duration (ms)\": 208687.0, \"Valence\": 0.604, \"Chord\": \"C#/Db\"}, {\"Index\": 376, \"Highest Charting Position\": 47, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"I DID IT (feat. Post Malone, Megan Thee Stallion, Lil Baby & DaBaby)\", \"Streams\": 7347891, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6278835.0, \"Song ID\": \"20GrahbI4AzAOWxpYfDKkf\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\", \"Popularity\": 76.0, \"Danceability\": 0.757, \"Energy\": 0.721, \"Loudness\": -2.906, \"Speechiness\": 0.0691, \"Acousticness\": 0.00196, \"Liveness\": 0.647, \"Tempo\": 124.036, \"Duration (ms)\": 165366.0, \"Valence\": 0.364, \"Chord\": \"E\"}, {\"Index\": 377, \"Highest Charting Position\": 61, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Body\", \"Streams\": 5831357, \"Artist\": \"Russ Millions, Tion Wayne\", \"Artist Followers\": 323203.0, \"Song ID\": \"6uvMKqNlrSvcC4NaKnrwjZ\", \"Genre\": \"['london rap']\", \"Release Date\": \"2021-04-22\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 84.0, \"Danceability\": 0.883, \"Energy\": 0.674, \"Loudness\": -8.043, \"Speechiness\": 0.357, \"Acousticness\": 0.21, \"Liveness\": 0.0678, \"Tempo\": 141.02, \"Duration (ms)\": 278085.0, \"Valence\": 0.73, \"Chord\": \"B\"}, {\"Index\": 378, \"Highest Charting Position\": 10, \"Number of Times Charted\": 69, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"everything i wanted\", \"Streams\": 5448680, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"1OC8hMoqAuWmTWJ4heJNlO\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.704, \"Energy\": 0.225, \"Loudness\": -14.454, \"Speechiness\": 0.0994, \"Acousticness\": 0.901, \"Liveness\": 0.106, \"Tempo\": 120.006, \"Duration (ms)\": 245426.0, \"Valence\": 0.243, \"Chord\": \"F#/Gb\"}, {\"Index\": 379, \"Highest Charting Position\": 169, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"What You Need\", \"Streams\": 5346005, \"Artist\": \"Don Toliver\", \"Artist Followers\": 1605329.0, \"Song ID\": \"6LcX2hBbXaJcK4AuefE936\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2021-05-04\", \"Weeks Charted\": \"2021-05-07--2021-05-14\", \"Popularity\": 76.0, \"Danceability\": 0.664, \"Energy\": 0.655, \"Loudness\": -7.327, \"Speechiness\": 0.0461, \"Acousticness\": 0.059, \"Liveness\": 0.17, \"Tempo\": 129.987, \"Duration (ms)\": 217609.0, \"Valence\": 0.13, \"Chord\": \"A#/Bb\"}, {\"Index\": 380, \"Highest Charting Position\": 115, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"L-Gante: Bzrp Music Sessions, Vol.38\", \"Streams\": 5290877, \"Artist\": \"Bizarrap, L-Gante\", \"Artist Followers\": 3126961.0, \"Song ID\": \"1Crj1zkRMpsEjb9NOR6Zof\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2021-03-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 80.0, \"Danceability\": 0.553, \"Energy\": 0.819, \"Loudness\": -3.083, \"Speechiness\": 0.257, \"Acousticness\": 0.368, \"Liveness\": 0.0915, \"Tempo\": 87.913, \"Duration (ms)\": 192348.0, \"Valence\": 0.761, \"Chord\": \"D\"}, {\"Index\": 381, \"Highest Charting Position\": 19, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"HOLIDAY\", \"Streams\": 5264232, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5473565.0, \"Song ID\": \"6zFMeegAMYQo0mt8rXtrli\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 83.0, \"Danceability\": 0.81, \"Energy\": 0.511, \"Loudness\": -6.924, \"Speechiness\": 0.164, \"Acousticness\": 0.12, \"Liveness\": 0.0832, \"Tempo\": 151.947, \"Duration (ms)\": 154998.0, \"Valence\": 0.837, \"Chord\": \"F\"}, {\"Index\": 382, \"Highest Charting Position\": 71, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"At My Worst\", \"Streams\": 5258000, \"Artist\": \"Pink Sweat$\", \"Artist Followers\": 942628.0, \"Song ID\": \"0ri0Han4IRJhzvERHOZTMr\", \"Genre\": \"['bedroom soul', 'pop']\", \"Release Date\": \"2020-07-17\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 79.0, \"Danceability\": 0.813, \"Energy\": 0.415, \"Loudness\": -5.926, \"Speechiness\": 0.0349, \"Acousticness\": 0.777, \"Liveness\": 0.131, \"Tempo\": 91.921, \"Duration (ms)\": 170345.0, \"Valence\": 0.667, \"Chord\": \"C\"}, {\"Index\": 383, \"Highest Charting Position\": 3, \"Number of Times Charted\": 70, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Life Is Good (feat. Drake)\", \"Streams\": 5241227, \"Artist\": \"Future\", \"Artist Followers\": 10488292.0, \"Song ID\": \"5yY9lUy8nbvjM1Uyo1Uqoc\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 81.0, \"Danceability\": 0.676, \"Energy\": 0.609, \"Loudness\": -5.831, \"Speechiness\": 0.481, \"Acousticness\": 0.0706, \"Liveness\": 0.152, \"Tempo\": 142.037, \"Duration (ms)\": 237735.0, \"Valence\": 0.508, \"Chord\": \"D\"}, {\"Index\": 384, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Extasy\", \"Streams\": 5203700, \"Artist\": \"187 Strassenbande, Bonez MC, Frauenarzt\", \"Artist Followers\": 1223734.0, \"Song ID\": \"79lc69ZXfL4WmJIzVSDmWT\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2021-05-13\", \"Weeks Charted\": \"2021-05-07--2021-05-14\", \"Popularity\": 67.0, \"Danceability\": 0.863, \"Energy\": 0.739, \"Loudness\": -5.879, \"Speechiness\": 0.153, \"Acousticness\": 0.0289, \"Liveness\": 0.0931, \"Tempo\": 129.964, \"Duration (ms)\": 174021.0, \"Valence\": 0.547, \"Chord\": \"A\"}, {\"Index\": 385, \"Highest Charting Position\": 7, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Wishing Well\", \"Streams\": 5125706, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"2U5WueTLIK5WJLD7mvDODv\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 83.0, \"Danceability\": 0.65, \"Energy\": 0.613, \"Loudness\": -6.13, \"Speechiness\": 0.128, \"Acousticness\": 0.00336, \"Liveness\": 0.267, \"Tempo\": 149.972, \"Duration (ms)\": 194621.0, \"Valence\": 0.0804, \"Chord\": \"A\"}, {\"Index\": 386, \"Highest Charting Position\": 164, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Fan de Tus Fotos\", \"Streams\": 5103863, \"Artist\": \"Nicky Jam, Romeo Santos\", \"Artist Followers\": 14826679.0, \"Song ID\": \"1mauYRwbpoGQX6itP2FAJC\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2021-02-08\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\", \"Popularity\": 79.0, \"Danceability\": 0.728, \"Energy\": 0.689, \"Loudness\": -5.718, \"Speechiness\": 0.0725, \"Acousticness\": 0.293, \"Liveness\": 0.109, \"Tempo\": 170.089, \"Duration (ms)\": 197647.0, \"Valence\": 0.431, \"Chord\": \"G\"}, {\"Index\": 387, \"Highest Charting Position\": 82, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Tap\\u00e3o Na Raba\", \"Streams\": 5088848, \"Artist\": \"Ra\\u00ed Saia Rodada\", \"Artist Followers\": 1260752.0, \"Song ID\": \"58pgi1RpcU2fVJsxhm7BIr\", \"Genre\": \"['forro']\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 80.0, \"Danceability\": 0.808, \"Energy\": 0.796, \"Loudness\": -3.169, \"Speechiness\": 0.0305, \"Acousticness\": 0.462, \"Liveness\": 0.155, \"Tempo\": 128.048, \"Duration (ms)\": 175047.0, \"Valence\": 0.799, \"Chord\": \"C#/Db\"}, {\"Index\": 388, \"Highest Charting Position\": 66, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Machu Picchu\", \"Streams\": 5062404, \"Artist\": \"Camilo, Evaluna Montaner\", \"Artist Followers\": 10561047.0, \"Song ID\": \"1LXb70u8SLsvBAPWHMCTMe\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2021-03-01\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 76.0, \"Danceability\": 0.788, \"Energy\": 0.789, \"Loudness\": -2.39, \"Speechiness\": 0.124, \"Acousticness\": 0.397, \"Liveness\": 0.226, \"Tempo\": 167.897, \"Duration (ms)\": 179005.0, \"Valence\": 0.867, \"Chord\": \"C\"}, {\"Index\": 389, \"Highest Charting Position\": 4, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Come & Go (with Marshmello)\", \"Streams\": 5037124, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"2Y0wPrPQBrGhoLn14xRYCG\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 83.0, \"Danceability\": 0.625, \"Energy\": 0.814, \"Loudness\": -5.181, \"Speechiness\": 0.0657, \"Acousticness\": 0.0172, \"Liveness\": 0.158, \"Tempo\": 144.991, \"Duration (ms)\": 205485.0, \"Valence\": 0.535, \"Chord\": \"C\"}, {\"Index\": 390, \"Highest Charting Position\": 71, \"Number of Times Charted\": 72, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Robbery\", \"Streams\": 5024884, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19085118.0, \"Song ID\": \"6Hj9jySrnFppAI0sEMCZpJ\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2019-03-08\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.685, \"Energy\": 0.692, \"Loudness\": -5.122, \"Speechiness\": 0.0457, \"Acousticness\": 0.328, \"Liveness\": 0.153, \"Tempo\": 159.966, \"Duration (ms)\": 240051.0, \"Valence\": 0.578, \"Chord\": \"D\"}, {\"Index\": 391, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-05-07--2021-05-14\", \"Song Name\": \"Paradigmas\", \"Streams\": 5018076, \"Artist\": \"Jorge & Mateus\", \"Artist Followers\": 15013645.0, \"Song ID\": \"17UfXrL7Run3GyZJW4uRjC\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2021-04-22\", \"Weeks Charted\": \"2021-05-07--2021-05-14\", \"Popularity\": 72.0, \"Danceability\": 0.686, \"Energy\": 0.789, \"Loudness\": -4.103, \"Speechiness\": 0.126, \"Acousticness\": 0.322, \"Liveness\": 0.4, \"Tempo\": 157.932, \"Duration (ms)\": 157355.0, \"Valence\": 0.822, \"Chord\": \"C#/Db\"}, {\"Index\": 392, \"Highest Charting Position\": 53, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"SugarCrash!\", \"Streams\": 5018005, \"Artist\": \"ElyOtto\", \"Artist Followers\": 85617.0, \"Song ID\": \"2ePtv8MlBO9nuuXABqAfEX\", \"Genre\": \"['weirdcore']\", \"Release Date\": \"2020-08-25\", \"Weeks Charted\": \"2021-05-07--2021-05-14\\n2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 80.0, \"Danceability\": 0.748, \"Energy\": 0.734, \"Loudness\": -6.499, \"Speechiness\": 0.124, \"Acousticness\": 0.524, \"Liveness\": 0.0975, \"Tempo\": 97.753, \"Duration (ms)\": 80081.0, \"Valence\": 0.368, \"Chord\": \"C\"}, {\"Index\": 393, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"durag activity (with Travis Scott)\", \"Streams\": 7939784, \"Artist\": \"Baby Keem\", \"Artist Followers\": 279741.0, \"Song ID\": \"4JJcP0Rv9AgyPD6ZGaC8EE\", \"Genre\": \"['hip hop', 'rap', 'trap', 'underground hip hop']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-04-30--2021-05-07\", \"Popularity\": 75.0, \"Danceability\": 0.89, \"Energy\": 0.701, \"Loudness\": -5.712, \"Speechiness\": 0.342, \"Acousticness\": 0.00306, \"Liveness\": 0.0895, \"Tempo\": 80.462, \"Duration (ms)\": 225020.0, \"Valence\": 0.505, \"Chord\": \"C\"}, {\"Index\": 394, \"Highest Charting Position\": 113, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"love race (feat. Kellin Quinn)\", \"Streams\": 6325080, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3864419.0, \"Song ID\": \"1F9kEuwT29fgqlovIclu81\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2021-04-29\", \"Weeks Charted\": \"2021-04-30--2021-05-07\", \"Popularity\": 76.0, \"Danceability\": 0.517, \"Energy\": 0.848, \"Loudness\": -4.054, \"Speechiness\": 0.0521, \"Acousticness\": 0.00581, \"Liveness\": 0.214, \"Tempo\": 95.906, \"Duration (ms)\": 188779.0, \"Valence\": 0.429, \"Chord\": \"A#/Bb\"}, {\"Index\": 395, \"Highest Charting Position\": 7, \"Number of Times Charted\": 40, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"POPSTAR (feat. Drake)\", \"Streams\": 6127103, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6278835.0, \"Song ID\": \"6EDO9iiTtwNv6waLwa1UUq\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-07-17\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 80.0, \"Danceability\": 0.8, \"Energy\": 0.56, \"Loudness\": -4.818, \"Speechiness\": 0.261, \"Acousticness\": 0.057, \"Liveness\": 0.134, \"Tempo\": 163.071, \"Duration (ms)\": 200221.0, \"Valence\": 0.45, \"Chord\": \"F\"}, {\"Index\": 396, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"LET IT GO (feat. Justin Bieber & 21 Savage)\", \"Streams\": 6083338, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6278835.0, \"Song ID\": \"1cEhrSF6EylAEqdhUGuNpX\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2021-04-30\", \"Weeks Charted\": \"2021-04-30--2021-05-07\", \"Popularity\": 75.0, \"Danceability\": 0.877, \"Energy\": 0.444, \"Loudness\": -7.547, \"Speechiness\": 0.172, \"Acousticness\": 0.24, \"Liveness\": 0.169, \"Tempo\": 129.06, \"Duration (ms)\": 165527.0, \"Valence\": 0.658, \"Chord\": \"G#/Ab\"}, {\"Index\": 397, \"Highest Charting Position\": 137, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-30--2021-05-07\", \"Song Name\": \"Girl From Rio\", \"Streams\": 5768836, \"Artist\": \"Anitta\", \"Artist Followers\": 10740222.0, \"Song ID\": \"6CF085Ol0cVda1WqelybEQ\", \"Genre\": \"['funk carioca', 'funk pop', 'pagode baiano', 'pop nacional']\", \"Release Date\": \"2021-05-21\", \"Weeks Charted\": \"2021-04-30--2021-05-07\", \"Popularity\": 69.0, \"Danceability\": 0.732, \"Energy\": 0.604, \"Loudness\": -7.472, \"Speechiness\": 0.0443, \"Acousticness\": 0.0112, \"Liveness\": 0.219, \"Tempo\": 139.982, \"Duration (ms)\": 195429.0, \"Valence\": 0.732, \"Chord\": \"C\"}, {\"Index\": 398, \"Highest Charting Position\": 10, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"On The Ground\", \"Streams\": 5655879, \"Artist\": \"ROS\\u00c9\", \"Artist Followers\": 1094731.0, \"Song ID\": \"2pn8dNVSpYnAtlKFC8Q0DJ\", \"Genre\": \"[]\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 74.0, \"Danceability\": 0.311, \"Energy\": 0.607, \"Loudness\": -6.578, \"Speechiness\": 0.11, \"Acousticness\": 0.0174, \"Liveness\": 0.131, \"Tempo\": 188.7, \"Duration (ms)\": 168086.0, \"Valence\": 0.286, \"Chord\": \"C#/Db\"}, {\"Index\": 399, \"Highest Charting Position\": 20, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Mr. Perfectly Fine (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5480722, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2CYVETnhM9aytqrazYYwrK\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 74.0, \"Danceability\": 0.66, \"Energy\": 0.817, \"Loudness\": -6.269, \"Speechiness\": 0.0521, \"Acousticness\": 0.162, \"Liveness\": 0.0667, \"Tempo\": 135.942, \"Duration (ms)\": 277592.0, \"Valence\": 0.714, \"Chord\": \"B\"}, {\"Index\": 400, \"Highest Charting Position\": 42, \"Number of Times Charted\": 60, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"when the party's over\", \"Streams\": 5467596, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1250353.0, \"Song ID\": \"5KWwUzVxubgSPmLIUAQhYt\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.484, \"Energy\": 0.103, \"Loudness\": -14.075, \"Speechiness\": 0.0627, \"Acousticness\": 0.979, \"Liveness\": 0.0895, \"Tempo\": 124.011, \"Duration (ms)\": 199931.0, \"Valence\": 0.194, \"Chord\": \"C#/Db\"}, {\"Index\": 401, \"Highest Charting Position\": 63, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Otra Noche Sin Ti\", \"Streams\": 5377794, \"Artist\": \"J Balvin, Khalid\", \"Artist Followers\": 29051363.0, \"Song ID\": \"2CdTLdDjwZdVcm0bresVWx\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\", \"Popularity\": 80.0, \"Danceability\": 0.503, \"Energy\": 0.548, \"Loudness\": -7.564, \"Speechiness\": 0.164, \"Acousticness\": 0.0751, \"Liveness\": 0.145, \"Tempo\": 94.036, \"Duration (ms)\": 228920.0, \"Valence\": 0.441, \"Chord\": \"C\"}, {\"Index\": 402, \"Highest Charting Position\": 33, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Met Him Last Night (feat. Ariana Grande)\", \"Streams\": 5200695, \"Artist\": \"Demi Lovato\", \"Artist Followers\": 20331923.0, \"Song ID\": \"0BI0hfbmqybnd3TezrDME3\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 72.0, \"Danceability\": 0.538, \"Energy\": 0.512, \"Loudness\": -4.548, \"Speechiness\": 0.0262, \"Acousticness\": 0.22, \"Liveness\": 0.101, \"Tempo\": 144.978, \"Duration (ms)\": 204632.0, \"Valence\": 0.12, \"Chord\": \"E\"}, {\"Index\": 403, \"Highest Charting Position\": 100, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Back In Blood (feat. Lil Durk)\", \"Streams\": 5198209, \"Artist\": \"Pooh Shiesty\", \"Artist Followers\": 423237.0, \"Song ID\": \"7JuHVG3qQKQKxC4doneXVW\", \"Genre\": \"['memphis hip hop', 'rap', 'southern hip hop', 'tennessee hip hop', 'trap']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 75.0, \"Danceability\": 0.759, \"Energy\": 0.538, \"Loudness\": -8.256, \"Speechiness\": 0.384, \"Acousticness\": 0.151, \"Liveness\": 0.126, \"Tempo\": 146.933, \"Duration (ms)\": 184490.0, \"Valence\": 0.831, \"Chord\": \"G#/Ab\"}, {\"Index\": 404, \"Highest Charting Position\": 94, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Run It Up (feat. Offset & Moneybagg Yo)\", \"Streams\": 5107084, \"Artist\": \"Lil Tjay\", \"Artist Followers\": 3553442.0, \"Song ID\": \"1dg3qy5DjoJodawfOCgrTP\", \"Genre\": \"['brooklyn drill', 'melodic rap', 'nyc rap']\", \"Release Date\": \"2021-04-02\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 81.0, \"Danceability\": 0.88, \"Energy\": 0.575, \"Loudness\": -6.091, \"Speechiness\": 0.163, \"Acousticness\": 0.415, \"Liveness\": 0.109, \"Tempo\": 120.031, \"Duration (ms)\": 232048.0, \"Valence\": 0.671, \"Chord\": \"F#/Gb\"}, {\"Index\": 405, \"Highest Charting Position\": 37, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Mi Ni\\u00f1a\", \"Streams\": 5026961, \"Artist\": \"Wisin, Myke Towers, Los Legendarios\", \"Artist Followers\": 6929075.0, \"Song ID\": \"2bgcUk2A3jjKbCJ7KPquTi\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-23\", \"Weeks Charted\": \"2021-04-30--2021-05-07\\n2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 79.0, \"Danceability\": 0.823, \"Energy\": 0.821, \"Loudness\": -3.402, \"Speechiness\": 0.166, \"Acousticness\": 0.31, \"Liveness\": 0.143, \"Tempo\": 99.999, \"Duration (ms)\": 213314.0, \"Valence\": 0.791, \"Chord\": \"G#/Ab\"}, {\"Index\": 406, \"Highest Charting Position\": 9, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"As I Am (feat. Khalid)\", \"Streams\": 5896065, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6F2r4HgpJnvKDmkN6JEN6J\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 72.0, \"Danceability\": 0.595, \"Energy\": 0.543, \"Loudness\": -8.149, \"Speechiness\": 0.038, \"Acousticness\": 0.127, \"Liveness\": 0.0975, \"Tempo\": 99.928, \"Duration (ms)\": 174406.0, \"Valence\": 0.109, \"Chord\": \"B\"}, {\"Index\": 407, \"Highest Charting Position\": 150, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Come Through (feat. Chris Brown)\", \"Streams\": 5531998, \"Artist\": \"H.E.R.\", \"Artist Followers\": 4138951.0, \"Song ID\": \"3krZxyBsWEHfEfJegYaWTd\", \"Genre\": \"['alternative r&b', 'dance pop', 'pop', 'r&b']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2021-04-23--2021-04-30\", \"Popularity\": 74.0, \"Danceability\": 0.615, \"Energy\": 0.422, \"Loudness\": -8.019, \"Speechiness\": 0.0504, \"Acousticness\": 0.604, \"Liveness\": 0.112, \"Tempo\": 135.859, \"Duration (ms)\": 214094.0, \"Valence\": 0.185, \"Chord\": \"F\"}, {\"Index\": 408, \"Highest Charting Position\": 33, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Goosebumps\", \"Streams\": 5496962, \"Artist\": \"HVME\", \"Artist Followers\": 17719446.0, \"Song ID\": \"5uEYRdEIh9Bo4fpjDd4Na9\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 87.0, \"Danceability\": 0.841, \"Energy\": 0.593, \"Loudness\": -7.846, \"Speechiness\": 0.0379, \"Acousticness\": 0.418, \"Liveness\": 0.124, \"Tempo\": 124.917, \"Duration (ms)\": 162803.0, \"Valence\": 0.808, \"Chord\": \"C#/Db\"}, {\"Index\": 409, \"Highest Charting Position\": 18, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Put Your Records On\", \"Streams\": 5181180, \"Artist\": \"Ritt Momney\", \"Artist Followers\": 100463.0, \"Song ID\": \"6AGOKlMZWLCaEJGnaROtF9\", \"Genre\": \"['bedroom pop']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 81.0, \"Danceability\": 0.399, \"Energy\": 0.491, \"Loudness\": -10.778, \"Speechiness\": 0.0538, \"Acousticness\": 0.0563, \"Liveness\": 0.11, \"Tempo\": 91.066, \"Duration (ms)\": 210463.0, \"Valence\": 0.151, \"Chord\": \"F#/Gb\"}, {\"Index\": 410, \"Highest Charting Position\": 137, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Facas - Ao Vivo\", \"Streams\": 5141640, \"Artist\": \"Diego & Victor Hugo, Bruno & Marrone\", \"Artist Followers\": 1585593.0, \"Song ID\": \"1ere9b9vDw2N3m9d4uiXxa\", \"Genre\": \"['sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2020-10-15\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 79.0, \"Danceability\": 0.443, \"Energy\": 0.509, \"Loudness\": -5.995, \"Speechiness\": 0.0536, \"Acousticness\": 0.615, \"Liveness\": 0.472, \"Tempo\": 160.984, \"Duration (ms)\": 196380.0, \"Valence\": 0.69, \"Chord\": \"D\"}, {\"Index\": 411, \"Highest Charting Position\": 62, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Train Wreck\", \"Streams\": 5081800, \"Artist\": \"James Arthur\", \"Artist Followers\": 8446147.0, \"Song ID\": \"55Am8neGJkdj2ADaM3aw5H\", \"Genre\": \"['pop', 'post-teen pop', 'talent show', 'uk pop']\", \"Release Date\": \"2016-10-28\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 82.0, \"Danceability\": 0.311, \"Energy\": 0.485, \"Loudness\": -5.726, \"Speechiness\": 0.0365, \"Acousticness\": 0.701, \"Liveness\": 0.0726, \"Tempo\": 77.355, \"Duration (ms)\": 208827.0, \"Valence\": 0.225, \"Chord\": \"F#/Gb\"}, {\"Index\": 412, \"Highest Charting Position\": 7, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Monster (Shawn Mendes & Justin Bieber)\", \"Streams\": 5069268, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 33893352.0, \"Song ID\": \"2Z8yfpFX0ZMavHkcIeHiO1\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 79.0, \"Danceability\": 0.652, \"Energy\": 0.383, \"Loudness\": -7.076, \"Speechiness\": 0.0516, \"Acousticness\": 0.0676, \"Liveness\": 0.0828, \"Tempo\": 145.765, \"Duration (ms)\": 178994.0, \"Valence\": 0.549, \"Chord\": \"D\"}, {\"Index\": 413, \"Highest Charting Position\": 6, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"In Your Eyes\", \"Streams\": 5054319, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"7szuecWAPwGoV1e5vGu8tl\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 81.0, \"Danceability\": 0.667, \"Energy\": 0.719, \"Loudness\": -5.371, \"Speechiness\": 0.0346, \"Acousticness\": 0.00285, \"Liveness\": 0.0736, \"Tempo\": 100.021, \"Duration (ms)\": 237520.0, \"Valence\": 0.717, \"Chord\": \"G\"}, {\"Index\": 414, \"Highest Charting Position\": 101, \"Number of Times Charted\": 68, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"SAD!\", \"Streams\": 5051338, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"3ee8Jmje8o58CHK66QrVC2\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2018-03-16\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 84.0, \"Danceability\": 0.74, \"Energy\": 0.613, \"Loudness\": -4.88, \"Speechiness\": 0.145, \"Acousticness\": 0.258, \"Liveness\": 0.123, \"Tempo\": 75.023, \"Duration (ms)\": 166606.0, \"Valence\": 0.473, \"Chord\": \"G#/Ab\"}, {\"Index\": 415, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"Good Without\", \"Streams\": 4998044, \"Artist\": \"Mimi Webb\", \"Artist Followers\": 130801.0, \"Song ID\": \"15OCqNPYoLziEAsbVnqRj5\", \"Genre\": \"['alt z', 'indie cafe pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-04-23--2021-04-30\", \"Popularity\": 81.0, \"Danceability\": 0.616, \"Energy\": 0.576, \"Loudness\": -5.495, \"Speechiness\": 0.0532, \"Acousticness\": 0.0723, \"Liveness\": 0.375, \"Tempo\": 89.962, \"Duration (ms)\": 182121.0, \"Valence\": 0.269, \"Chord\": \"B\"}, {\"Index\": 416, \"Highest Charting Position\": 19, \"Number of Times Charted\": 66, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"hot girl bummer\", \"Streams\": 4992396, \"Artist\": \"blackbear\", \"Artist Followers\": 4270131.0, \"Song ID\": \"2mt1IqcFyY1zmYZT8Q3xw9\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.782, \"Energy\": 0.559, \"Loudness\": -7.106, \"Speechiness\": 0.0767, \"Acousticness\": 0.125, \"Liveness\": 0.385, \"Tempo\": 129.992, \"Duration (ms)\": 188344.0, \"Valence\": 0.685, \"Chord\": \"F#/Gb\"}, {\"Index\": 417, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-23--2021-04-30\", \"Song Name\": \"When I Was Your Man\", \"Streams\": 4945935, \"Artist\": \"Bruno Mars\", \"Artist Followers\": 32603394.0, \"Song ID\": \"0nJW01T7XtvILxQgC5J7Wh\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2012-12-07\", \"Weeks Charted\": \"2021-04-23--2021-04-30\", \"Popularity\": 82.0, \"Danceability\": 0.612, \"Energy\": 0.28, \"Loudness\": -8.648, \"Speechiness\": 0.0434, \"Acousticness\": 0.932, \"Liveness\": 0.088, \"Tempo\": 72.795, \"Duration (ms)\": 213827.0, \"Valence\": 0.387, \"Chord\": \"C\"}, {\"Index\": 418, \"Highest Charting Position\": 73, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"LOCATION\", \"Streams\": 4940701, \"Artist\": \"KAROL G, Anuel AA, J Balvin\", \"Artist Followers\": 1250353.0, \"Song ID\": \"1aH3EQY5LTXjRZQLpl1Gby\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 0.0, \"Danceability\": 0.772, \"Energy\": 0.758, \"Loudness\": -3.891, \"Speechiness\": 0.0482, \"Acousticness\": 0.0433, \"Liveness\": 0.295, \"Tempo\": 115.977, \"Duration (ms)\": 265240.0, \"Valence\": 0.654, \"Chord\": \"A\"}, {\"Index\": 419, \"Highest Charting Position\": 177, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Stressed Out\", \"Streams\": 4913147, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20823062.0, \"Song ID\": \"3CRDbSIZ4r5MsZ0YwxuEkn\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2015-05-15\", \"Weeks Charted\": \"2021-04-23--2021-04-30\\n2021-04-16--2021-04-23\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 83.0, \"Danceability\": 0.734, \"Energy\": 0.637, \"Loudness\": -5.677, \"Speechiness\": 0.141, \"Acousticness\": 0.0462, \"Liveness\": 0.0602, \"Tempo\": 169.977, \"Duration (ms)\": 202333.0, \"Valence\": 0.648, \"Chord\": \"E\"}, {\"Index\": 420, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Ski\", \"Streams\": 7753784, \"Artist\": \"Young Stoner Life, Young Thug, Gunna\", \"Artist Followers\": 61930.0, \"Song ID\": \"6755DFiZ7CWe2WMdTGW5C1\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-04-16--2021-04-23\", \"Popularity\": 78.0, \"Danceability\": 0.953, \"Energy\": 0.621, \"Loudness\": -7.638, \"Speechiness\": 0.221, \"Acousticness\": 0.017, \"Liveness\": 0.0398, \"Tempo\": 123.016, \"Duration (ms)\": 152333.0, \"Valence\": 0.883, \"Chord\": \"G#/Ab\"}, {\"Index\": 421, \"Highest Charting Position\": 75, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Diamonds Dancing (feat. Travis Scott)\", \"Streams\": 7515766, \"Artist\": \"Young Stoner Life, Young Thug, Gunna\", \"Artist Followers\": 61930.0, \"Song ID\": \"7uZqvqXzzYMKrexKxdcGmd\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2021-04-16\", \"Weeks Charted\": \"2021-04-16--2021-04-23\", \"Popularity\": 69.0, \"Danceability\": 0.851, \"Energy\": 0.703, \"Loudness\": -7.351, \"Speechiness\": 0.303, \"Acousticness\": 0.00949, \"Liveness\": 0.0895, \"Tempo\": 74.017, \"Duration (ms)\": 242600.0, \"Valence\": 0.596, \"Chord\": \"E\"}, {\"Index\": 422, \"Highest Charting Position\": 8, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Love Story (Taylor\\u2019s Version)\", \"Streams\": 6202933, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6YvqWjhGD8mB5QXcbcUKtx\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\", \"Popularity\": 73.0, \"Danceability\": 0.627, \"Energy\": 0.792, \"Loudness\": -4.311, \"Speechiness\": 0.031, \"Acousticness\": 0.13, \"Liveness\": 0.0845, \"Tempo\": 119.054, \"Duration (ms)\": 235767.0, \"Valence\": 0.415, \"Chord\": \"D\"}, {\"Index\": 423, \"Highest Charting Position\": 107, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Ele \\u00c9 Ele, Eu Sou Eu\", \"Streams\": 5380517, \"Artist\": \"Wesley Safad\\u00e3o, Os Bar\\u00f5es Da Pisadinha\", \"Artist Followers\": 9907270.0, \"Song ID\": \"7EWXP47VlXKO3r7mNxuWHw\", \"Genre\": \"['forro']\", \"Release Date\": \"2020-11-12\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 73.0, \"Danceability\": 0.758, \"Energy\": 0.763, \"Loudness\": -8.754, \"Speechiness\": 0.0768, \"Acousticness\": 0.23, \"Liveness\": 0.0703, \"Tempo\": 163.946, \"Duration (ms)\": 155210.0, \"Valence\": 0.854, \"Chord\": \"C#/Db\"}, {\"Index\": 424, \"Highest Charting Position\": 186, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-16--2021-04-23\", \"Song Name\": \"Quero Ver \\u00e9 Me Esquecer (feat. Jorge) - Ao Vivo\", \"Streams\": 5159208, \"Artist\": \"Os Bar\\u00f5es Da Pisadinha\", \"Artist Followers\": 4271775.0, \"Song ID\": \"2SUPbyD77tJuOUbqbxct6l\", \"Genre\": \"['forro', 'piseiro']\", \"Release Date\": \"2021-02-19\", \"Weeks Charted\": \"2021-04-16--2021-04-23\", \"Popularity\": 80.0, \"Danceability\": 0.593, \"Energy\": 0.932, \"Loudness\": -2.324, \"Speechiness\": 0.0526, \"Acousticness\": 0.302, \"Liveness\": 0.133, \"Tempo\": 171.977, \"Duration (ms)\": 147876.0, \"Valence\": 0.913, \"Chord\": \"G#/Ab\"}, {\"Index\": 425, \"Highest Charting Position\": 3, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"willow\", \"Streams\": 5016865, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0lx2cLdOt3piJbcaXIV74f\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 79.0, \"Danceability\": 0.392, \"Energy\": 0.574, \"Loudness\": -9.195, \"Speechiness\": 0.17, \"Acousticness\": 0.833, \"Liveness\": 0.145, \"Tempo\": 81.112, \"Duration (ms)\": 214707.0, \"Valence\": 0.529, \"Chord\": \"G\"}, {\"Index\": 426, \"Highest Charting Position\": 104, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Why'd You Only Call Me When You're High?\", \"Streams\": 4976405, \"Artist\": \"Arctic Monkeys\", \"Artist Followers\": 12375514.0, \"Song ID\": \"086myS9r57YsLbJpU0TgK9\", \"Genre\": \"['garage rock', 'permanent wave', 'rock', 'sheffield indie']\", \"Release Date\": \"2013-09-09\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 82.0, \"Danceability\": 0.691, \"Energy\": 0.631, \"Loudness\": -6.478, \"Speechiness\": 0.0368, \"Acousticness\": 0.0483, \"Liveness\": 0.104, \"Tempo\": 92.004, \"Duration (ms)\": 161124.0, \"Valence\": 0.8, \"Chord\": \"D\"}, {\"Index\": 427, \"Highest Charting Position\": 18, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Afterglow\", \"Streams\": 4965330, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 1250353.0, \"Song ID\": \"5dA45onYgYACRp8C5xEOS9\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\", \"Popularity\": 0.0, \"Danceability\": 0.641, \"Energy\": 0.324, \"Loudness\": -5.851, \"Speechiness\": 0.0299, \"Acousticness\": 0.698, \"Liveness\": 0.328, \"Tempo\": 110.184, \"Duration (ms)\": 185487.0, \"Valence\": 0.273, \"Chord\": \"B\"}, {\"Index\": 428, \"Highest Charting Position\": 43, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"LA CANCI\\u00d3N\", \"Streams\": 4959754, \"Artist\": \"J Balvin, Bad Bunny\", \"Artist Followers\": 29051363.0, \"Song ID\": \"0fea68AdmYNygeTGI4RC18\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2021-04-16--2021-04-23\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.754, \"Energy\": 0.646, \"Loudness\": -5.795, \"Speechiness\": 0.317, \"Acousticness\": 0.152, \"Liveness\": 0.108, \"Tempo\": 176.089, \"Duration (ms)\": 242573.0, \"Valence\": 0.429, \"Chord\": \"G\"}, {\"Index\": 429, \"Highest Charting Position\": 52, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"You Belong With Me (Taylor\\u2019s Version)\", \"Streams\": 9872084, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1qrpoAMXodY6895hGKoUpA\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 73.0, \"Danceability\": 0.632, \"Energy\": 0.773, \"Loudness\": -4.856, \"Speechiness\": 0.0346, \"Acousticness\": 0.0623, \"Liveness\": 0.0885, \"Tempo\": 130.033, \"Duration (ms)\": 231124.0, \"Valence\": 0.474, \"Chord\": \"F#/Gb\"}, {\"Index\": 430, \"Highest Charting Position\": 54, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Fearless (Taylor\\u2019s Version)\", \"Streams\": 9676024, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"77sMIMlNaSURUAXq5coCxE\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 69.0, \"Danceability\": 0.569, \"Energy\": 0.741, \"Loudness\": -4.963, \"Speechiness\": 0.0282, \"Acousticness\": 0.0122, \"Liveness\": 0.333, \"Tempo\": 100.118, \"Duration (ms)\": 241592.0, \"Valence\": 0.43, \"Chord\": \"F\"}, {\"Index\": 431, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"X Gon' Give It To Ya\", \"Streams\": 8638360, \"Artist\": \"DMX\", \"Artist Followers\": 2815928.0, \"Song ID\": \"1zzxoZVylsna2BQB65Ppcb\", \"Genre\": \"['east coast hip hop', 'gangster rap', 'hardcore hip hop', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2007-06-12\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 73.0, \"Danceability\": 0.761, \"Energy\": 0.899, \"Loudness\": -3.09, \"Speechiness\": 0.183, \"Acousticness\": 0.0135, \"Liveness\": 0.0719, \"Tempo\": 95.027, \"Duration (ms)\": 217587.0, \"Valence\": 0.673, \"Chord\": \"A#/Bb\"}, {\"Index\": 432, \"Highest Charting Position\": 80, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Fifteen (Taylor\\u2019s Version)\", \"Streams\": 7852063, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2nqio0SfWg6gh2eCtfuMa5\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 66.0, \"Danceability\": 0.559, \"Energy\": 0.646, \"Loudness\": -4.61, \"Speechiness\": 0.0272, \"Acousticness\": 0.116, \"Liveness\": 0.32, \"Tempo\": 95.466, \"Duration (ms)\": 294419.0, \"Valence\": 0.289, \"Chord\": \"G\"}, {\"Index\": 433, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"The Way I Loved You (Taylor\\u2019s Version)\", \"Streams\": 7736262, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"22bPsP2jCgbLUvh82U0Z3M\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 72.0, \"Danceability\": 0.402, \"Energy\": 0.732, \"Loudness\": -4.665, \"Speechiness\": 0.0484, \"Acousticness\": 0.0033, \"Liveness\": 0.108, \"Tempo\": 161.032, \"Duration (ms)\": 243137.0, \"Valence\": 0.472, \"Chord\": \"F\"}, {\"Index\": 434, \"Highest Charting Position\": 51, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"You All Over Me (feat. Maren Morris) (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 7712896, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5pcjystBtalYeqaiXCcgEY\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\", \"Popularity\": 65.0, \"Danceability\": 0.589, \"Energy\": 0.496, \"Loudness\": -7.606, \"Speechiness\": 0.0377, \"Acousticness\": 0.818, \"Liveness\": 0.101, \"Tempo\": 142.731, \"Duration (ms)\": 220839.0, \"Valence\": 0.44, \"Chord\": \"D\"}, {\"Index\": 435, \"Highest Charting Position\": 93, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Hey Stephen (Taylor\\u2019s Version)\", \"Streams\": 7385864, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"550erGcdD9n6PnwxrvYqZT\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 66.0, \"Danceability\": 0.788, \"Energy\": 0.571, \"Loudness\": -6.135, \"Speechiness\": 0.0296, \"Acousticness\": 0.106, \"Liveness\": 0.0934, \"Tempo\": 115.99, \"Duration (ms)\": 254255.0, \"Valence\": 0.797, \"Chord\": \"F#/Gb\"}, {\"Index\": 436, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"White Horse (Taylor\\u2019s Version)\", \"Streams\": 7039222, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5YL553x8sHderRBDlm3NM3\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 65.0, \"Danceability\": 0.423, \"Energy\": 0.517, \"Loudness\": -7.377, \"Speechiness\": 0.0486, \"Acousticness\": 0.369, \"Liveness\": 0.177, \"Tempo\": 185.262, \"Duration (ms)\": 234516.0, \"Valence\": 0.366, \"Chord\": \"C\"}, {\"Index\": 437, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Forever & Always (Taylor\\u2019s Version)\", \"Streams\": 6566059, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1msEuwSBneBKpVCZQcFTsU\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 66.0, \"Danceability\": 0.598, \"Energy\": 0.821, \"Loudness\": -4.433, \"Speechiness\": 0.0447, \"Acousticness\": 0.0231, \"Liveness\": 0.143, \"Tempo\": 128.03, \"Duration (ms)\": 225328.0, \"Valence\": 0.673, \"Chord\": \"A#/Bb\"}, {\"Index\": 438, \"Highest Charting Position\": 119, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Breathe (feat. Colbie Caillat) (Taylor\\u2019s Version)\", \"Streams\": 6508683, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7HC7R2D8WjXVcUHJyEGjRs\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 64.0, \"Danceability\": 0.506, \"Energy\": 0.626, \"Loudness\": -6.066, \"Speechiness\": 0.0287, \"Acousticness\": 0.156, \"Liveness\": 0.228, \"Tempo\": 148.035, \"Duration (ms)\": 263377.0, \"Valence\": 0.321, \"Chord\": \"C#/Db\"}, {\"Index\": 439, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Ruff Ryders' Anthem\", \"Streams\": 5988511, \"Artist\": \"DMX\", \"Artist Followers\": 2815928.0, \"Song ID\": \"1BKT2I9x4RGKaKqW4up34s\", \"Genre\": \"['east coast hip hop', 'gangster rap', 'hardcore hip hop', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"1998-05-01\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 72.0, \"Danceability\": 0.88, \"Energy\": 0.577, \"Loudness\": -8.093, \"Speechiness\": 0.302, \"Acousticness\": 0.0564, \"Liveness\": 0.201, \"Tempo\": 90.991, \"Duration (ms)\": 214440.0, \"Valence\": 0.74, \"Chord\": \"A#/Bb\"}, {\"Index\": 440, \"Highest Charting Position\": 146, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"That\\u2019s When (feat. Keith Urban) (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5889939, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7eResoqEJJAVTkQYSqvO3P\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 67.0, \"Danceability\": 0.588, \"Energy\": 0.608, \"Loudness\": -7.062, \"Speechiness\": 0.0365, \"Acousticness\": 0.225, \"Liveness\": 0.092, \"Tempo\": 90.201, \"Duration (ms)\": 189496.0, \"Valence\": 0.508, \"Chord\": \"F\"}, {\"Index\": 441, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Tell Me Why (Taylor\\u2019s Version)\", \"Streams\": 5885151, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0k0vFacOHNuArLWMiH60p7\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 63.0, \"Danceability\": 0.578, \"Energy\": 0.909, \"Loudness\": -3.669, \"Speechiness\": 0.0628, \"Acousticness\": 0.0222, \"Liveness\": 0.333, \"Tempo\": 100.023, \"Duration (ms)\": 200576.0, \"Valence\": 0.541, \"Chord\": \"G\"}, {\"Index\": 442, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"You\\u2019re Not Sorry (Taylor\\u2019s Version)\", \"Streams\": 5860405, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6iiAfo4wTA2CVC3Uwx9uh8\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 64.0, \"Danceability\": 0.506, \"Energy\": 0.444, \"Loudness\": -4.99, \"Speechiness\": 0.0285, \"Acousticness\": 0.0538, \"Liveness\": 0.123, \"Tempo\": 133.873, \"Duration (ms)\": 261843.0, \"Valence\": 0.241, \"Chord\": \"F#/Gb\"}, {\"Index\": 443, \"Highest Charting Position\": 40, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Chica Ideal\", \"Streams\": 5217052, \"Artist\": \"Sebastian Yatra, Guaynaa\", \"Artist Followers\": 1250353.0, \"Song ID\": \"6M3Bdl5UtQtmjnYDW69LZQ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 0.0, \"Danceability\": 0.574, \"Energy\": 0.891, \"Loudness\": -3.665, \"Speechiness\": 0.157, \"Acousticness\": 0.0847, \"Liveness\": 0.16, \"Tempo\": 100.978, \"Duration (ms)\": 183240.0, \"Valence\": 0.707, \"Chord\": \"C\"}, {\"Index\": 444, \"Highest Charting Position\": 15, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Relaci\\u00f3n - Remix\", \"Streams\": 5206614, \"Artist\": \"Sech, Daddy Yankee, J Balvin, ROSAL\\u00cdA, Farruko\", \"Artist Followers\": 8758283.0, \"Song ID\": \"35UUpTmrcFXNIVIN26ujXl\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 80.0, \"Danceability\": 0.793, \"Energy\": 0.771, \"Loudness\": -3.417, \"Speechiness\": 0.0959, \"Acousticness\": 0.0337, \"Liveness\": 0.284, \"Tempo\": 171.943, \"Duration (ms)\": 247308.0, \"Valence\": 0.835, \"Chord\": \"F\"}, {\"Index\": 445, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"Don\\u2019t You (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5197564, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"4uuEGH5SVuzkkSFjo2DEiY\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 65.0, \"Danceability\": 0.563, \"Energy\": 0.473, \"Loudness\": -11.548, \"Speechiness\": 0.0503, \"Acousticness\": 0.514, \"Liveness\": 0.109, \"Tempo\": 101.934, \"Duration (ms)\": 208609.0, \"Valence\": 0.405, \"Chord\": \"D#/Eb\"}, {\"Index\": 446, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-09--2021-04-16\", \"Song Name\": \"We Were Happy (Taylor\\u2019s Version) (From The Vault)\", \"Streams\": 5189423, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"34V9RiEPe8MNdU32qJsJa1\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2021-04-09\", \"Weeks Charted\": \"2021-04-09--2021-04-16\", \"Popularity\": 64.0, \"Danceability\": 0.609, \"Energy\": 0.373, \"Loudness\": -8.819, \"Speechiness\": 0.0263, \"Acousticness\": 0.849, \"Liveness\": 0.0779, \"Tempo\": 106.007, \"Duration (ms)\": 244237.0, \"Valence\": 0.13, \"Chord\": \"C\"}, {\"Index\": 447, \"Highest Charting Position\": 153, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"WACHA\", \"Streams\": 5172999, \"Artist\": \"KHEA, Duki\", \"Artist Followers\": 3198705.0, \"Song ID\": \"5RmSunLqeDqNWww8LWhAiK\", \"Genre\": \"['argentine hip hop', 'trap argentino', 'trap latino', 'trap triste']\", \"Release Date\": \"2021-04-01\", \"Weeks Charted\": \"2021-04-09--2021-04-16\\n2021-04-02--2021-04-09\", \"Popularity\": 75.0, \"Danceability\": 0.737, \"Energy\": 0.634, \"Loudness\": -4.25, \"Speechiness\": 0.0424, \"Acousticness\": 0.345, \"Liveness\": 0.111, \"Tempo\": 94.927, \"Duration (ms)\": 206360.0, \"Valence\": 0.528, \"Chord\": \"D#/Eb\"}, {\"Index\": 448, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Dancing With The Devil\", \"Streams\": 5836326, \"Artist\": \"Demi Lovato\", \"Artist Followers\": 20338833.0, \"Song ID\": \"2kONpeXXK70YEs7c0UQbmq\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2021-04-02--2021-04-09\", \"Popularity\": 66.0, \"Danceability\": 0.413, \"Energy\": 0.64, \"Loudness\": -5.811, \"Speechiness\": 0.0427, \"Acousticness\": 0.273, \"Liveness\": 0.11, \"Tempo\": 75.245, \"Duration (ms)\": 243992.0, \"Valence\": 0.149, \"Chord\": \"G#/Ab\"}, {\"Index\": 449, \"Highest Charting Position\": 26, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Gone\", \"Streams\": 5427638, \"Artist\": \"ROS\\u00c9\", \"Artist Followers\": 1099480.0, \"Song ID\": \"2dHoVW9AxJVSRebPRyV2aA\", \"Genre\": \"[]\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 71.0, \"Danceability\": 0.647, \"Energy\": 0.377, \"Loudness\": -6.003, \"Speechiness\": 0.0375, \"Acousticness\": 0.594, \"Liveness\": 0.0768, \"Tempo\": 79.936, \"Duration (ms)\": 207164.0, \"Valence\": 0.653, \"Chord\": \"F#/Gb\"}, {\"Index\": 450, \"Highest Charting Position\": 160, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"What Other People Say\", \"Streams\": 5413003, \"Artist\": \"Sam Fischer, Demi Lovato\", \"Artist Followers\": 122746.0, \"Song ID\": \"2h9TDNEXRhcDIV3fsoEVq9\", \"Genre\": \"['alt z', 'australian pop', 'dance pop', 'indie cafe pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2021-02-04\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\", \"Popularity\": 77.0, \"Danceability\": 0.652, \"Energy\": 0.472, \"Loudness\": -8.084, \"Speechiness\": 0.0399, \"Acousticness\": 0.158, \"Liveness\": 0.121, \"Tempo\": 126.904, \"Duration (ms)\": 194890.0, \"Valence\": 0.24, \"Chord\": \"G\"}, {\"Index\": 451, \"Highest Charting Position\": 88, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Hello (feat. A Boogie Wit da Hoodie)\", \"Streams\": 5323062, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"2r6OAV3WsYtXuXjvJ1lIDi\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-20\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 82.0, \"Danceability\": 0.905, \"Energy\": 0.647, \"Loudness\": -5.065, \"Speechiness\": 0.107, \"Acousticness\": 0.0187, \"Liveness\": 0.282, \"Tempo\": 130.97, \"Duration (ms)\": 190534.0, \"Valence\": 0.367, \"Chord\": \"A#/Bb\"}, {\"Index\": 452, \"Highest Charting Position\": 91, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Hasta Abajo\", \"Streams\": 5269163, \"Artist\": \"Kevin Roldan, Bryant Myers, Lyanno\", \"Artist Followers\": 4026643.0, \"Song ID\": \"4PEfJZpVjdclfzZ9XO8uDw\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'reggaeton colombiano', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 77.0, \"Danceability\": 0.714, \"Energy\": 0.671, \"Loudness\": -5.119, \"Speechiness\": 0.362, \"Acousticness\": 0.289, \"Liveness\": 0.325, \"Tempo\": 169.732, \"Duration (ms)\": 229827.0, \"Valence\": 0.641, \"Chord\": \"F\"}, {\"Index\": 453, \"Highest Charting Position\": 30, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Take You Dancing\", \"Streams\": 5176493, \"Artist\": \"Jason Derulo\", \"Artist Followers\": 9778632.0, \"Song ID\": \"59qrUpoplZxbIZxk6X0Bm3\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2020-07-22\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 82.0, \"Danceability\": 0.789, \"Energy\": 0.711, \"Loudness\": -4.248, \"Speechiness\": 0.041, \"Acousticness\": 0.0332, \"Liveness\": 0.0876, \"Tempo\": 112.985, \"Duration (ms)\": 190306.0, \"Valence\": 0.753, \"Chord\": \"D\"}, {\"Index\": 454, \"Highest Charting Position\": 28, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Unstable (feat. The Kid LAROI)\", \"Streams\": 5137645, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"137mSruegm1u6x9NvwiagR\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 74.0, \"Danceability\": 0.495, \"Energy\": 0.333, \"Loudness\": -10.109, \"Speechiness\": 0.0288, \"Acousticness\": 0.737, \"Liveness\": 0.112, \"Tempo\": 99.757, \"Duration (ms)\": 158324.0, \"Valence\": 0.37, \"Chord\": \"E\"}, {\"Index\": 455, \"Highest Charting Position\": 2, \"Number of Times Charted\": 48, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Stuck with U (with Justin Bieber)\", \"Streams\": 5094660, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"4HBZA5flZLE435QTztThqH\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 84.0, \"Danceability\": 0.597, \"Energy\": 0.45, \"Loudness\": -6.658, \"Speechiness\": 0.0418, \"Acousticness\": 0.223, \"Liveness\": 0.382, \"Tempo\": 178.765, \"Duration (ms)\": 228482.0, \"Valence\": 0.537, \"Chord\": \"G#/Ab\"}, {\"Index\": 456, \"Highest Charting Position\": 120, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Hayloft\", \"Streams\": 5086382, \"Artist\": \"Mother Mother\", \"Artist Followers\": 2110870.0, \"Song ID\": \"2kS6td1yvmpNgZTt1q5pQq\", \"Genre\": \"['indie pop', 'vancouver indie']\", \"Release Date\": \"2008-09-23\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 81.0, \"Danceability\": 0.527, \"Energy\": 0.922, \"Loudness\": -2.666, \"Speechiness\": 0.0728, \"Acousticness\": 0.00475, \"Liveness\": 0.422, \"Tempo\": 95.975, \"Duration (ms)\": 181680.0, \"Valence\": 0.49, \"Chord\": \"A\"}, {\"Index\": 457, \"Highest Charting Position\": 191, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-04-02--2021-04-09\", \"Song Name\": \"Esquema Preferido (feat. Tarc\\u00edsio do Acordeon)\", \"Streams\": 5078174, \"Artist\": \"DJ Ivis\", \"Artist Followers\": 342930.0, \"Song ID\": \"0e6NlGJxYlHvAN8SKxad7N\", \"Genre\": \"['piseiro']\", \"Release Date\": \"2020-11-26\", \"Weeks Charted\": \"2021-04-02--2021-04-09\", \"Popularity\": 73.0, \"Danceability\": 0.676, \"Energy\": 0.823, \"Loudness\": -4.386, \"Speechiness\": 0.102, \"Acousticness\": 0.242, \"Liveness\": 0.0773, \"Tempo\": 160.013, \"Duration (ms)\": 190680.0, \"Valence\": 0.907, \"Chord\": \"F\"}, {\"Index\": 458, \"Highest Charting Position\": 75, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Adem\\u00e1s de M\\u00ed - Remix\", \"Streams\": 5060336, \"Artist\": \"Rusherking, KHEA, Duki, Maria Becerra, LIT killah, Tiago PZK\", \"Artist Followers\": 301217.0, \"Song ID\": \"7I8L3vYCLThw2FDrE6LuzE\", \"Genre\": \"['trap argentino', 'trap latino', 'trap triste']\", \"Release Date\": \"2021-03-04\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 78.0, \"Danceability\": 0.397, \"Energy\": 0.613, \"Loudness\": -5.077, \"Speechiness\": 0.0549, \"Acousticness\": 0.0396, \"Liveness\": 0.192, \"Tempo\": 78.4, \"Duration (ms)\": 330040.0, \"Valence\": 0.405, \"Chord\": \"F#/Gb\"}, {\"Index\": 459, \"Highest Charting Position\": 193, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Payphone\", \"Streams\": 5052717, \"Artist\": \"Maroon 5, Wiz Khalifa\", \"Artist Followers\": 32279979.0, \"Song ID\": \"1LmN9SSHISbtp9LoaR5ZVJ\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2012-01-01\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 74.0, \"Danceability\": 0.739, \"Energy\": 0.756, \"Loudness\": -4.828, \"Speechiness\": 0.0394, \"Acousticness\": 0.0136, \"Liveness\": 0.37, \"Tempo\": 110.028, \"Duration (ms)\": 231387.0, \"Valence\": 0.523, \"Chord\": \"E\"}, {\"Index\": 460, \"Highest Charting Position\": 50, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Ghost\", \"Streams\": 5013450, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6I3mqTwhRpn34SLVafSH7G\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 71.0, \"Danceability\": 0.601, \"Energy\": 0.741, \"Loudness\": -5.569, \"Speechiness\": 0.0478, \"Acousticness\": 0.185, \"Liveness\": 0.415, \"Tempo\": 153.96, \"Duration (ms)\": 153190.0, \"Valence\": 0.441, \"Chord\": \"D\"}, {\"Index\": 461, \"Highest Charting Position\": 37, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Off My Face\", \"Streams\": 5004111, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"3T03rPwlL8NVk1yIaxeD8U\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 75.0, \"Danceability\": 0.509, \"Energy\": 0.228, \"Loudness\": -8.68, \"Speechiness\": 0.0332, \"Acousticness\": 0.92, \"Liveness\": 0.104, \"Tempo\": 90.674, \"Duration (ms)\": 156468.0, \"Valence\": 0.586, \"Chord\": \"E\"}, {\"Index\": 462, \"Highest Charting Position\": 140, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Whats Poppin (feat. DaBaby, Tory Lanez & Lil Wayne) [Remix] - Bonus Track\", \"Streams\": 4972518, \"Artist\": \"Jack Harlow\", \"Artist Followers\": 1053324.0, \"Song ID\": \"0ZLuW8uOXdFNWcI40C0OC2\", \"Genre\": \"['deep underground hip hop', 'kentucky hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\", \"Popularity\": 73.0, \"Danceability\": 0.904, \"Energy\": 0.723, \"Loudness\": -5.224, \"Speechiness\": 0.26, \"Acousticness\": 0.0631, \"Liveness\": 0.185, \"Tempo\": 145.013, \"Duration (ms)\": 227478.0, \"Valence\": 0.835, \"Chord\": \"B\"}, {\"Index\": 463, \"Highest Charting Position\": 188, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Take on Me\", \"Streams\": 4969662, \"Artist\": \"a-ha\", \"Artist Followers\": 1560784.0, \"Song ID\": \"2WfaOiMkCvy7F5fcp2zZ8L\", \"Genre\": \"['new romantic', 'new wave', 'new wave pop', 'permanent wave', 'soft rock', 'synthpop']\", \"Release Date\": \"1985-06-01\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 84.0, \"Danceability\": 0.573, \"Energy\": 0.902, \"Loudness\": -7.638, \"Speechiness\": 0.054, \"Acousticness\": 0.018, \"Liveness\": 0.0928, \"Tempo\": 84.412, \"Duration (ms)\": 225280.0, \"Valence\": 0.876, \"Chord\": \"F#/Gb\"}, {\"Index\": 464, \"Highest Charting Position\": 45, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"BEB\\u00c9\", \"Streams\": 4967348, \"Artist\": \"Camilo, El Alfa\", \"Artist Followers\": 10580764.0, \"Song ID\": \"7D7EH7MGyNHWSkqrszerI1\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-11-25\", \"Weeks Charted\": \"2021-04-02--2021-04-09\\n2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 78.0, \"Danceability\": 0.862, \"Energy\": 0.72, \"Loudness\": -4.048, \"Speechiness\": 0.0379, \"Acousticness\": 0.487, \"Liveness\": 0.0604, \"Tempo\": 129.972, \"Duration (ms)\": 198707.0, \"Valence\": 0.965, \"Chord\": \"E\"}, {\"Index\": 465, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Richer (feat. Polo G)\", \"Streams\": 6292362, \"Artist\": \"Rod Wave\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-03-26--2021-04-02\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 466, \"Highest Charting Position\": 128, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Tu Veneno\", \"Streams\": 6007541, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"5KFHrrBMyGj5MhVbZMM3ts\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 76.0, \"Danceability\": 0.664, \"Energy\": 0.659, \"Loudness\": -4.232, \"Speechiness\": 0.0873, \"Acousticness\": 0.0625, \"Liveness\": 0.0874, \"Tempo\": 175.826, \"Duration (ms)\": 157320.0, \"Valence\": 0.797, \"Chord\": \"A#/Bb\"}, {\"Index\": 467, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Deserve You\", \"Streams\": 5837372, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5NU40QTlXrDUJzDBdv79bg\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 69.0, \"Danceability\": 0.677, \"Energy\": 0.633, \"Loudness\": -7.831, \"Speechiness\": 0.0771, \"Acousticness\": 0.0314, \"Liveness\": 0.112, \"Tempo\": 89.934, \"Duration (ms)\": 187239.0, \"Valence\": 0.409, \"Chord\": \"G\"}, {\"Index\": 468, \"Highest Charting Position\": 44, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"2 Much\", \"Streams\": 5794583, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"0oaY19dUwZimIgzn3ZZLZO\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 70.0, \"Danceability\": 0.583, \"Energy\": 0.444, \"Loudness\": -8.601, \"Speechiness\": 0.0456, \"Acousticness\": 0.593, \"Liveness\": 0.353, \"Tempo\": 119.59, \"Duration (ms)\": 152796.0, \"Valence\": 0.167, \"Chord\": \"A\"}, {\"Index\": 469, \"Highest Charting Position\": 3, \"Number of Times Charted\": 66, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Tusa\", \"Streams\": 5510113, \"Artist\": \"KAROL G, Nicki Minaj\", \"Artist Followers\": 17792779.0, \"Song ID\": \"7k4t7uLgtOxPwTpFmtJNTY\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.803, \"Energy\": 0.715, \"Loudness\": -3.28, \"Speechiness\": 0.298, \"Acousticness\": 0.295, \"Liveness\": 0.0574, \"Tempo\": 101.085, \"Duration (ms)\": 200960.0, \"Valence\": 0.574, \"Chord\": \"D\"}, {\"Index\": 470, \"Highest Charting Position\": 34, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Una Locura\", \"Streams\": 5466954, \"Artist\": \"Ozuna, J Balvin, Chencho Corleone\", \"Artist Followers\": 29238936.0, \"Song ID\": \"5y7DaS3jAc9eZzcSOoUIwU\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 81.0, \"Danceability\": 0.714, \"Energy\": 0.761, \"Loudness\": -4.596, \"Speechiness\": 0.0427, \"Acousticness\": 0.139, \"Liveness\": 0.241, \"Tempo\": 168.022, \"Duration (ms)\": 230693.0, \"Valence\": 0.906, \"Chord\": \"F\"}, {\"Index\": 471, \"Highest Charting Position\": 61, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Loved By You (feat. Burna Boy)\", \"Streams\": 5419040, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2tB9OFgAHjAds3cqquLlvp\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 69.0, \"Danceability\": 0.79, \"Energy\": 0.724, \"Loudness\": -6.972, \"Speechiness\": 0.0852, \"Acousticness\": 0.0696, \"Liveness\": 0.113, \"Tempo\": 101.04, \"Duration (ms)\": 159250.0, \"Valence\": 0.642, \"Chord\": \"C#/Db\"}, {\"Index\": 472, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-26--2021-04-02\", \"Song Name\": \"Girls Like Us\", \"Streams\": 5410730, \"Artist\": \"Zoe Wees\", \"Artist Followers\": 203555.0, \"Song ID\": \"5SFXOMJJ334Wn2PwBHeRZN\", \"Genre\": \"['german pop']\", \"Release Date\": \"2021-01-12\", \"Weeks Charted\": \"2021-03-26--2021-04-02\", \"Popularity\": 78.0, \"Danceability\": 0.444, \"Energy\": 0.648, \"Loudness\": -4.955, \"Speechiness\": 0.0476, \"Acousticness\": 0.288, \"Liveness\": 0.059, \"Tempo\": 125.706, \"Duration (ms)\": 189000.0, \"Valence\": 0.171, \"Chord\": \"C#/Db\"}, {\"Index\": 473, \"Highest Charting Position\": 17, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Lemon Pepper Freestyle (feat. Rick Ross)\", \"Streams\": 5365747, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"4FRW5Nza1Ym91BGV4nFWXI\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 76.0, \"Danceability\": 0.77, \"Energy\": 0.637, \"Loudness\": -5.53, \"Speechiness\": 0.345, \"Acousticness\": 0.103, \"Liveness\": 0.171, \"Tempo\": 94.966, \"Duration (ms)\": 383037.0, \"Valence\": 0.431, \"Chord\": \"C#/Db\"}, {\"Index\": 474, \"Highest Charting Position\": 97, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Esquema Preferido\", \"Streams\": 5356696, \"Artist\": \"DJ Ivis, Tarc\\u00edsio do Acordeon\", \"Artist Followers\": 342930.0, \"Song ID\": \"0e6NlGJxYlHvAN8SKxad7N\", \"Genre\": \"['piseiro']\", \"Release Date\": \"2020-11-26\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 73.0, \"Danceability\": 0.676, \"Energy\": 0.823, \"Loudness\": -4.386, \"Speechiness\": 0.102, \"Acousticness\": 0.242, \"Liveness\": 0.0773, \"Tempo\": 160.013, \"Duration (ms)\": 190680.0, \"Valence\": 0.907, \"Chord\": \"F\"}, {\"Index\": 475, \"Highest Charting Position\": 105, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Love Not War (The Tampa Beat)\", \"Streams\": 5326719, \"Artist\": \"Jason Derulo, Nuka\", \"Artist Followers\": 9778632.0, \"Song ID\": \"4Lt6GXGzYsa1tgkv3nGSTm\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 79.0, \"Danceability\": 0.738, \"Energy\": 0.85, \"Loudness\": -3.049, \"Speechiness\": 0.0642, \"Acousticness\": 0.105, \"Liveness\": 0.23, \"Tempo\": 98.013, \"Duration (ms)\": 192921.0, \"Valence\": 0.865, \"Chord\": \"G#/Ab\"}, {\"Index\": 476, \"Highest Charting Position\": 57, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Die For You (feat. Dominic Fike)\", \"Streams\": 5323412, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"7aely3H8kMj9o0gt6vXHE1\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\", \"Popularity\": 67.0, \"Danceability\": 0.728, \"Energy\": 0.629, \"Loudness\": -6.629, \"Speechiness\": 0.0318, \"Acousticness\": 0.00196, \"Liveness\": 0.0847, \"Tempo\": 135.031, \"Duration (ms)\": 198426.0, \"Valence\": 0.71, \"Chord\": \"C#/Db\"}, {\"Index\": 477, \"Highest Charting Position\": 64, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Starboy\", \"Streams\": 5302285, \"Artist\": \"The Weeknd, Daft Punk\", \"Artist Followers\": 35340069.0, \"Song ID\": \"7MXVkk9YMctZqd1Srtv4MB\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2016-11-25\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 83.0, \"Danceability\": 0.679, \"Energy\": 0.587, \"Loudness\": -7.015, \"Speechiness\": 0.276, \"Acousticness\": 0.141, \"Liveness\": 0.137, \"Tempo\": 186.003, \"Duration (ms)\": 230453.0, \"Valence\": 0.486, \"Chord\": \"G\"}, {\"Index\": 478, \"Highest Charting Position\": 22, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"La T\\u00f3xica\", \"Streams\": 5255393, \"Artist\": \"Farruko\", \"Artist Followers\": 10510156.0, \"Song ID\": \"15OjBeqNX3bShsGYQbteRv\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 78.0, \"Danceability\": 0.659, \"Energy\": 0.701, \"Loudness\": -4.107, \"Speechiness\": 0.164, \"Acousticness\": 0.0882, \"Liveness\": 0.0866, \"Tempo\": 91.97, \"Duration (ms)\": 180520.0, \"Valence\": 0.623, \"Chord\": \"A\"}, {\"Index\": 479, \"Highest Charting Position\": 181, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Cora\\u00e7\\u00e3o Na Cama - Ao Vivo\", \"Streams\": 5211351, \"Artist\": \"Hugo & Guilherme\", \"Artist Followers\": 435936.0, \"Song ID\": \"2nZj5YymF54qhAu7RneVP6\", \"Genre\": \"['sertanejo pop']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2021-03-26--2021-04-02\\n2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\", \"Popularity\": 77.0, \"Danceability\": 0.764, \"Energy\": 0.794, \"Loudness\": -4.096, \"Speechiness\": 0.0589, \"Acousticness\": 0.663, \"Liveness\": 0.34, \"Tempo\": 110.013, \"Duration (ms)\": 173227.0, \"Valence\": 0.721, \"Chord\": \"G#/Ab\"}, {\"Index\": 480, \"Highest Charting Position\": 60, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Love You Different (feat. BEAM)\", \"Streams\": 10024729, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"27UcQ6dAvQrgH9C880rCM3\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-19--2021-03-26\", \"Popularity\": 66.0, \"Danceability\": 0.759, \"Energy\": 0.584, \"Loudness\": -6.655, \"Speechiness\": 0.06, \"Acousticness\": 0.0652, \"Liveness\": 0.16, \"Tempo\": 127.138, \"Duration (ms)\": 186696.0, \"Valence\": 0.374, \"Chord\": \"G#/Ab\"}, {\"Index\": 481, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"Somebody\", \"Streams\": 8912458, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"3rLIv187BhjyweFe89SgLn\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2010-01-01\", \"Weeks Charted\": \"2021-03-19--2021-03-26\", \"Popularity\": 67.0, \"Danceability\": 0.714, \"Energy\": 0.833, \"Loudness\": -5.239, \"Speechiness\": 0.0259, \"Acousticness\": 0.00249, \"Liveness\": 0.298, \"Tempo\": 129.964, \"Duration (ms)\": 220920.0, \"Valence\": 0.663, \"Chord\": \"F\"}, {\"Index\": 482, \"Highest Charting Position\": 152, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-19--2021-03-26\", \"Song Name\": \"White Dress\", \"Streams\": 5796978, \"Artist\": \"Lana Del Rey\", \"Artist Followers\": 13697048.0, \"Song ID\": \"4Hl9rOqYomojCmxYfr25im\", \"Genre\": \"['art pop', 'pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-19--2021-03-26\", \"Popularity\": 65.0, \"Danceability\": 0.493, \"Energy\": 0.263, \"Loudness\": -12.805, \"Speechiness\": 0.0351, \"Acousticness\": 0.926, \"Liveness\": 0.0879, \"Tempo\": 122.792, \"Duration (ms)\": 333710.0, \"Valence\": 0.158, \"Chord\": \"C\"}, {\"Index\": 483, \"Highest Charting Position\": 82, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Polvo\", \"Streams\": 5528508, \"Artist\": \"Nicky Jam, Myke Towers\", \"Artist Followers\": 14831925.0, \"Song ID\": \"68mrW6gXHgupgSiDHgaDi5\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 76.0, \"Danceability\": 0.763, \"Energy\": 0.621, \"Loudness\": -6.169, \"Speechiness\": 0.066, \"Acousticness\": 0.0105, \"Liveness\": 0.106, \"Tempo\": 82.042, \"Duration (ms)\": 211130.0, \"Valence\": 0.582, \"Chord\": \"B\"}, {\"Index\": 484, \"Highest Charting Position\": 138, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Chemtrails Over The Country Club\", \"Streams\": 5418816, \"Artist\": \"Lana Del Rey\", \"Artist Followers\": 13697048.0, \"Song ID\": \"7bPWdJgx8vek7S5i5yAtvG\", \"Genre\": \"['art pop', 'pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-01-15--2021-01-22\", \"Popularity\": 73.0, \"Danceability\": 0.334, \"Energy\": 0.276, \"Loudness\": -13.125, \"Speechiness\": 0.0643, \"Acousticness\": 0.877, \"Liveness\": 0.113, \"Tempo\": 201.025, \"Duration (ms)\": 271177.0, \"Valence\": 0.429, \"Chord\": \"E\"}, {\"Index\": 485, \"Highest Charting Position\": 37, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Parce (feat. Justin Quiles)\", \"Streams\": 5312876, \"Artist\": \"Maluma, Lenny Tav\\u00e1rez\", \"Artist Followers\": 26769304.0, \"Song ID\": \"4RJz8NfIe09gpKMiRUWKhJ\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 78.0, \"Danceability\": 0.691, \"Energy\": 0.739, \"Loudness\": -3.09, \"Speechiness\": 0.229, \"Acousticness\": 0.422, \"Liveness\": 0.11, \"Tempo\": 83.897, \"Duration (ms)\": 248345.0, \"Valence\": 0.884, \"Chord\": \"F\"}, {\"Index\": 486, \"Highest Charting Position\": 40, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Ropa Cara\", \"Streams\": 5249427, \"Artist\": \"Camilo\", \"Artist Followers\": 10580764.0, \"Song ID\": \"7BIy3EGQhg98CsRdKYHnJC\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2021-01-18\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 73.0, \"Danceability\": 0.813, \"Energy\": 0.526, \"Loudness\": -4.787, \"Speechiness\": 0.125, \"Acousticness\": 0.105, \"Liveness\": 0.11, \"Tempo\": 170.002, \"Duration (ms)\": 163320.0, \"Valence\": 0.608, \"Chord\": \"E\"}, {\"Index\": 487, \"Highest Charting Position\": 25, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Vida de Rico\", \"Streams\": 5189822, \"Artist\": \"Camilo\", \"Artist Followers\": 10580764.0, \"Song ID\": \"73nAK3HgQK8dak83Y2WQ8F\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-09-21\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 79.0, \"Danceability\": 0.824, \"Energy\": 0.457, \"Loudness\": -5.428, \"Speechiness\": 0.0543, \"Acousticness\": 0.167, \"Liveness\": 0.041, \"Tempo\": 87.977, \"Duration (ms)\": 187427.0, \"Valence\": 0.95, \"Chord\": \"F#/Gb\"}, {\"Index\": 488, \"Highest Charting Position\": 182, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Devil Eyes\", \"Streams\": 5098581, \"Artist\": \"Hippie Sabotage\", \"Artist Followers\": 713486.0, \"Song ID\": \"7MiZjKawmXTsTNePyTfPyL\", \"Genre\": \"['edm', 'electronic trap']\", \"Release Date\": \"2016-02-05\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 80.0, \"Danceability\": 0.391, \"Energy\": 0.396, \"Loudness\": -8.621, \"Speechiness\": 0.189, \"Acousticness\": 0.702, \"Liveness\": 0.315, \"Tempo\": 99.112, \"Duration (ms)\": 131272.0, \"Valence\": 0.199, \"Chord\": \"C#/Db\"}, {\"Index\": 489, \"Highest Charting Position\": 141, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Ponte Pa' Mi\", \"Streams\": 5082870, \"Artist\": \"Justin Quiles\", \"Artist Followers\": 2897862.0, \"Song ID\": \"4C6BlqqMwjFzOXzqpTeoWR\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-03-19--2021-03-26\\n2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 76.0, \"Danceability\": 0.878, \"Energy\": 0.713, \"Loudness\": -4.566, \"Speechiness\": 0.0948, \"Acousticness\": 0.0581, \"Liveness\": 0.0822, \"Tempo\": 92.028, \"Duration (ms)\": 202373.0, \"Valence\": 0.615, \"Chord\": \"F\"}, {\"Index\": 490, \"Highest Charting Position\": 109, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"D\\u00e1melo To\\u2019 (feat. Myke Towers)\", \"Streams\": 6426522, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"36CiGk9oRdwTnBDMgKEfjl\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 64.0, \"Danceability\": 0.787, \"Energy\": 0.641, \"Loudness\": -7.376, \"Speechiness\": 0.315, \"Acousticness\": 0.101, \"Liveness\": 0.07, \"Tempo\": 182.003, \"Duration (ms)\": 184134.0, \"Valence\": 0.437, \"Chord\": \"G#/Ab\"}, {\"Index\": 491, \"Highest Charting Position\": 121, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"Patience (feat. YUNGBLUD & Polo G)\", \"Streams\": 6155698, \"Artist\": \"KSI\", \"Artist Followers\": 2010879.0, \"Song ID\": \"5J5CpT6bgE6KYKk23jgp9W\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 71.0, \"Danceability\": 0.616, \"Energy\": 0.741, \"Loudness\": -4.272, \"Speechiness\": 0.0426, \"Acousticness\": 0.00251, \"Liveness\": 0.307, \"Tempo\": 122.012, \"Duration (ms)\": 181720.0, \"Valence\": 0.431, \"Chord\": \"G\"}, {\"Index\": 492, \"Highest Charting Position\": 56, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Selfish Love (with Selena Gomez)\", \"Streams\": 6020785, \"Artist\": \"DJ Snake\", \"Artist Followers\": 7408249.0, \"Song ID\": \"3XoflnowYPFRPOh3uFvHcm\", \"Genre\": \"['dance pop', 'edm', 'electronic trap', 'pop', 'pop dance']\", \"Release Date\": \"2021-03-04\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\", \"Popularity\": 74.0, \"Danceability\": 0.723, \"Energy\": 0.646, \"Loudness\": -7.973, \"Speechiness\": 0.102, \"Acousticness\": 0.0206, \"Liveness\": 0.0994, \"Tempo\": 110.971, \"Duration (ms)\": 168649.0, \"Valence\": 0.443, \"Chord\": \"F\"}, {\"Index\": 493, \"Highest Charting Position\": 12, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Snowman\", \"Streams\": 5454807, \"Artist\": \"Sia\", \"Artist Followers\": 20528724.0, \"Song ID\": \"7uoFMmxln0GPXQ0AcCBXRq\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'pop']\", \"Release Date\": \"2018-11-01\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 77.0, \"Danceability\": 0.716, \"Energy\": 0.512, \"Loudness\": -6.257, \"Speechiness\": 0.0331, \"Acousticness\": 0.483, \"Liveness\": 0.0928, \"Tempo\": 104.957, \"Duration (ms)\": 165907.0, \"Valence\": 0.326, \"Chord\": \"C#/Db\"}, {\"Index\": 494, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"DAYWALKER! (feat. CORPSE)\", \"Streams\": 5439646, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3868320.0, \"Song ID\": \"2NnJpRXIlx35Vij3bPZO0h\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 74.0, \"Danceability\": 0.632, \"Energy\": 0.922, \"Loudness\": -2.173, \"Speechiness\": 0.0794, \"Acousticness\": 0.00558, \"Liveness\": 0.0927, \"Tempo\": 88.972, \"Duration (ms)\": 137747.0, \"Valence\": 0.497, \"Chord\": \"G\"}, {\"Index\": 495, \"Highest Charting Position\": 19, \"Number of Times Charted\": 38, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"La Curiosidad\", \"Streams\": 5198514, \"Artist\": \"Jay Wheeler, DJ Nelson, Myke Towers\", \"Artist Followers\": 1650912.0, \"Song ID\": \"4HYDUMY0xSpeBr0AMY9cUz\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 82.0, \"Danceability\": 0.845, \"Energy\": 0.677, \"Loudness\": -4.798, \"Speechiness\": 0.136, \"Acousticness\": 0.269, \"Liveness\": 0.108, \"Tempo\": 90.013, \"Duration (ms)\": 219048.0, \"Valence\": 0.68, \"Chord\": \"B\"}, {\"Index\": 496, \"Highest Charting Position\": 86, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"All We Got (feat. KIDDO)\", \"Streams\": 5156937, \"Artist\": \"Robin Schulz\", \"Artist Followers\": 2786366.0, \"Song ID\": \"1FP9s72rDYty6mfoOEYKnE\", \"Genre\": \"['dance pop', 'deep euro house', 'deep house', 'edm', 'german dance', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 74.0, \"Danceability\": 0.504, \"Energy\": 0.76, \"Loudness\": -4.246, \"Speechiness\": 0.0426, \"Acousticness\": 0.286, \"Liveness\": 0.151, \"Tempo\": 183.933, \"Duration (ms)\": 190218.0, \"Valence\": 0.64, \"Chord\": \"E\"}, {\"Index\": 497, \"Highest Charting Position\": 6, \"Number of Times Charted\": 60, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Say So\", \"Streams\": 5103528, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"3Dv1eDb0MEgF93GpLXlucZ\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-02-26--2021-03-05\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.787, \"Energy\": 0.673, \"Loudness\": -4.583, \"Speechiness\": 0.159, \"Acousticness\": 0.264, \"Liveness\": 0.0904, \"Tempo\": 110.962, \"Duration (ms)\": 237893.0, \"Valence\": 0.779, \"Chord\": \"B\"}, {\"Index\": 498, \"Highest Charting Position\": 157, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Hope\", \"Streams\": 5085527, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"2ZRo7axmMPeSVUvDbGkJah\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2018-03-16\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 84.0, \"Danceability\": 0.592, \"Energy\": 0.457, \"Loudness\": -6.081, \"Speechiness\": 0.0603, \"Acousticness\": 0.661, \"Liveness\": 0.146, \"Tempo\": 146.04, \"Duration (ms)\": 110886.0, \"Valence\": 0.225, \"Chord\": \"A\"}, {\"Index\": 499, \"Highest Charting Position\": 149, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"The Less I Know The Better\", \"Streams\": 5084635, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"6K4t31amVTZDgR3sKmwUJJ\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2015-07-17\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-01-03--2020-01-10\", \"Popularity\": 84.0, \"Danceability\": 0.64, \"Energy\": 0.74, \"Loudness\": -4.083, \"Speechiness\": 0.0284, \"Acousticness\": 0.0115, \"Liveness\": 0.167, \"Tempo\": 116.879, \"Duration (ms)\": 216320.0, \"Valence\": 0.785, \"Chord\": \"E\"}, {\"Index\": 500, \"Highest Charting Position\": 109, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"I Feel It Coming\", \"Streams\": 5079857, \"Artist\": \"The Weeknd, Daft Punk\", \"Artist Followers\": 35340069.0, \"Song ID\": \"3dhjNA0jGA8vHBQ1VdD6vV\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2016-11-25\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 80.0, \"Danceability\": 0.773, \"Energy\": 0.819, \"Loudness\": -5.946, \"Speechiness\": 0.118, \"Acousticness\": 0.428, \"Liveness\": 0.0679, \"Tempo\": 92.987, \"Duration (ms)\": 269187.0, \"Valence\": 0.585, \"Chord\": \"C\"}, {\"Index\": 501, \"Highest Charting Position\": 12, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Mood Swings (feat. Lil Tjay)\", \"Streams\": 5068349, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"5rZlwNFl01HqLWBQGryKSm\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 82.0, \"Danceability\": 0.48, \"Energy\": 0.602, \"Loudness\": -6.335, \"Speechiness\": 0.368, \"Acousticness\": 0.487, \"Liveness\": 0.0848, \"Tempo\": 179.798, \"Duration (ms)\": 213333.0, \"Valence\": 0.269, \"Chord\": \"A#/Bb\"}, {\"Index\": 502, \"Highest Charting Position\": 123, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Someone To You\", \"Streams\": 5054881, \"Artist\": \"BANNERS\", \"Artist Followers\": 419151.0, \"Song ID\": \"2f0pn9DkEJwAzXApnFh5cr\", \"Genre\": \"['indie cafe pop', 'indie poptimism', 'modern rock', 'pop', 'pop rock']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 79.0, \"Danceability\": 0.52, \"Energy\": 0.903, \"Loudness\": -5.497, \"Speechiness\": 0.042, \"Acousticness\": 0.00517, \"Liveness\": 0.254, \"Tempo\": 74.988, \"Duration (ms)\": 219801.0, \"Valence\": 0.652, \"Chord\": \"D\"}, {\"Index\": 503, \"Highest Charting Position\": 198, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"To the Bone\", \"Streams\": 5052557, \"Artist\": \"Pamungkas\", \"Artist Followers\": 1643882.0, \"Song ID\": \"3pCt2wRdBDa2kCisIdHWgF\", \"Genre\": \"['indonesian pop']\", \"Release Date\": \"2019-06-14\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 81.0, \"Danceability\": 0.668, \"Energy\": 0.727, \"Loudness\": -6.55, \"Speechiness\": 0.027, \"Acousticness\": 0.514, \"Liveness\": 0.1, \"Tempo\": 139.991, \"Duration (ms)\": 344571.0, \"Valence\": 0.939, \"Chord\": \"G\"}, {\"Index\": 504, \"Highest Charting Position\": 4, \"Number of Times Charted\": 38, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"How You Like That\", \"Streams\": 5023592, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"4SFknyjLcyTLJFPKD2m96o\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2021-03-12--2021-03-19\\n2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 79.0, \"Danceability\": 0.812, \"Energy\": 0.761, \"Loudness\": -5.222, \"Speechiness\": 0.0812, \"Acousticness\": 0.0465, \"Liveness\": 0.0601, \"Tempo\": 130.032, \"Duration (ms)\": 182956.0, \"Valence\": 0.344, \"Chord\": \"B\"}, {\"Index\": 505, \"Highest Charting Position\": 200, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-12--2021-03-19\", \"Song Name\": \"LOST\", \"Streams\": 5013851, \"Artist\": \"NF, Hopsin\", \"Artist Followers\": 5831194.0, \"Song ID\": \"2MZrOmrVxRmmOoFW6dhenG\", \"Genre\": \"['hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2021-03-11\", \"Weeks Charted\": \"2021-03-12--2021-03-19\", \"Popularity\": 66.0, \"Danceability\": 0.637, \"Energy\": 0.912, \"Loudness\": -3.123, \"Speechiness\": 0.308, \"Acousticness\": 0.352, \"Liveness\": 0.0657, \"Tempo\": 116.919, \"Duration (ms)\": 234852.0, \"Valence\": 0.451, \"Chord\": \"F\"}, {\"Index\": 506, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"VOCE\", \"Streams\": 5510906, \"Artist\": \"Madame\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6CAVxdHTkls5loqUmfM52V\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 0.0, \"Danceability\": 0.615, \"Energy\": 0.834, \"Loudness\": -5.471, \"Speechiness\": 0.0667, \"Acousticness\": 0.105, \"Liveness\": 0.157, \"Tempo\": 112.602, \"Duration (ms)\": 211411.0, \"Valence\": 0.341, \"Chord\": \"G#/Ab\"}, {\"Index\": 507, \"Highest Charting Position\": 64, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"AP - Music from the film Boogie\", \"Streams\": 5462333, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"17vGPZ5EsdvtgAOCD4FLWI\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\", \"Popularity\": 75.0, \"Danceability\": 0.751, \"Energy\": 0.744, \"Loudness\": -6.859, \"Speechiness\": 0.177, \"Acousticness\": 0.152, \"Liveness\": 0.252, \"Tempo\": 148.014, \"Duration (ms)\": 171892.0, \"Valence\": 0.634, \"Chord\": \"C#/Db\"}, {\"Index\": 508, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Life's A Mess II (with Clever & Post Malone)\", \"Streams\": 5393459, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4O3RwH1TFG1EjPezLIYehI\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2021-03-05\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 72.0, \"Danceability\": 0.53, \"Energy\": 0.37, \"Loudness\": -9.989, \"Speechiness\": 0.0279, \"Acousticness\": 0.806, \"Liveness\": 0.112, \"Tempo\": 140.061, \"Duration (ms)\": 206734.0, \"Valence\": 0.701, \"Chord\": \"F#/Gb\"}, {\"Index\": 509, \"Highest Charting Position\": 170, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"CHIAMAMI PER NOME\", \"Streams\": 5321946, \"Artist\": \"Francesca Michielin, Fedez\", \"Artist Followers\": 568711.0, \"Song ID\": \"0ZqHo6eTBHUcOVjZzPvftT\", \"Genre\": \"['italian adult pop', 'italian indie pop', 'italian pop', 'italian pop rock']\", \"Release Date\": \"2021-03-03\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 67.0, \"Danceability\": 0.641, \"Energy\": 0.636, \"Loudness\": -4.318, \"Speechiness\": 0.0414, \"Acousticness\": 0.289, \"Liveness\": 0.125, \"Tempo\": 89.826, \"Duration (ms)\": 222667.0, \"Valence\": 0.285, \"Chord\": \"A#/Bb\"}, {\"Index\": 510, \"Highest Charting Position\": 54, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Antes\", \"Streams\": 5232377, \"Artist\": \"Anuel AA, Ozuna\", \"Artist Followers\": 18306226.0, \"Song ID\": \"73O30uMI7n6DuzBmbtO7kC\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 73.0, \"Danceability\": 0.817, \"Energy\": 0.737, \"Loudness\": -5.453, \"Speechiness\": 0.102, \"Acousticness\": 0.046, \"Liveness\": 0.092, \"Tempo\": 93.985, \"Duration (ms)\": 206587.0, \"Valence\": 0.67, \"Chord\": \"F#/Gb\"}, {\"Index\": 511, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Mona Lisa\", \"Streams\": 5208787, \"Artist\": \"Booba, JSX\", \"Artist Followers\": 2161609.0, \"Song ID\": \"5LYRIyhmlrDAQsYdHEvP0f\", \"Genre\": \"['french hip hop', 'old school rap francais', 'pop urbaine', 'rap conscient']\", \"Release Date\": \"2021-03-04\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 72.0, \"Danceability\": 0.784, \"Energy\": 0.529, \"Loudness\": -7.681, \"Speechiness\": 0.0742, \"Acousticness\": 0.683, \"Liveness\": 0.118, \"Tempo\": 134.041, \"Duration (ms)\": 187362.0, \"Valence\": 0.246, \"Chord\": \"B\"}, {\"Index\": 512, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-03-05--2021-03-12\", \"Song Name\": \"Real As It Gets (feat. EST Gee)\", \"Streams\": 5170861, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"7eX3um6NpOQKWJMGCi97XD\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2021-03-04\", \"Weeks Charted\": \"2021-03-05--2021-03-12\", \"Popularity\": 74.0, \"Danceability\": 0.779, \"Energy\": 0.705, \"Loudness\": -5.891, \"Speechiness\": 0.163, \"Acousticness\": 0.00471, \"Liveness\": 0.0971, \"Tempo\": 140.005, \"Duration (ms)\": 192804.0, \"Valence\": 0.196, \"Chord\": \"F#/Gb\"}, {\"Index\": 513, \"Highest Charting Position\": 24, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Se Te Nota (with Guaynaa)\", \"Streams\": 5168240, \"Artist\": \"Lele Pons\", \"Artist Followers\": 786461.0, \"Song ID\": \"11EnQRgRMJwMAesfkB5pnu\", \"Genre\": \"['latin pop', 'viral pop']\", \"Release Date\": \"2020-09-02\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 77.0, \"Danceability\": 0.905, \"Energy\": 0.686, \"Loudness\": -3.152, \"Speechiness\": 0.0664, \"Acousticness\": 0.0907, \"Liveness\": 0.266, \"Tempo\": 103.013, \"Duration (ms)\": 155825.0, \"Valence\": 0.963, \"Chord\": \"C\"}, {\"Index\": 514, \"Highest Charting Position\": 91, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Head Shoulders Knees & Toes (feat. Norma Jean Martine)\", \"Streams\": 5093408, \"Artist\": \"Ofenbach, Quarterhead\", \"Artist Followers\": 432511.0, \"Song ID\": \"6i7zAdNhzUN2k1HcrBxPHG\", \"Genre\": \"['edm', 'new french touch', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 79.0, \"Danceability\": 0.798, \"Energy\": 0.828, \"Loudness\": -5.36, \"Speechiness\": 0.193, \"Acousticness\": 0.0247, \"Liveness\": 0.121, \"Tempo\": 124.962, \"Duration (ms)\": 156960.0, \"Valence\": 0.6, \"Chord\": \"D\"}, {\"Index\": 515, \"Highest Charting Position\": 152, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Star Shopping\", \"Streams\": 5073657, \"Artist\": \"Lil Peep\", \"Artist Followers\": 7535054.0, \"Song ID\": \"30bqVoKjX479ab90a8Pafp\", \"Genre\": \"['emo rap', 'lgbtq+ hip hop']\", \"Release Date\": \"2015\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 82.0, \"Danceability\": 0.585, \"Energy\": 0.471, \"Loudness\": -9.934, \"Speechiness\": 0.0616, \"Acousticness\": 0.0967, \"Liveness\": 0.115, \"Tempo\": 93.099, \"Duration (ms)\": 142000.0, \"Valence\": 0.323, \"Chord\": \"E\"}, {\"Index\": 516, \"Highest Charting Position\": 61, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Electric Love\", \"Streams\": 5060903, \"Artist\": \"B\\u00d8RNS\", \"Artist Followers\": 1027085.0, \"Song ID\": \"2GiJYvgVaD2HtM8GqD9EgQ\", \"Genre\": \"['modern alternative rock', 'modern rock', 'pop']\", \"Release Date\": \"2015-10-16\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 83.0, \"Danceability\": 0.611, \"Energy\": 0.797, \"Loudness\": -7.627, \"Speechiness\": 0.0533, \"Acousticness\": 0.00543, \"Liveness\": 0.26, \"Tempo\": 120.041, \"Duration (ms)\": 218107.0, \"Valence\": 0.518, \"Chord\": \"F#/Gb\"}, {\"Index\": 517, \"Highest Charting Position\": 112, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Maniac\", \"Streams\": 5044929, \"Artist\": \"Conan Gray\", \"Artist Followers\": 3799104.0, \"Song ID\": \"6KfoDhO4XUWSbnyKjNp9c4\", \"Genre\": \"['alt z', 'bedroom pop', 'electropop', 'indie pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-03-05--2021-03-12\\n2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.628, \"Energy\": 0.639, \"Loudness\": -5.46, \"Speechiness\": 0.0435, \"Acousticness\": 0.00162, \"Liveness\": 0.354, \"Tempo\": 108.045, \"Duration (ms)\": 185773.0, \"Valence\": 0.493, \"Chord\": \"G#/Ab\"}, {\"Index\": 518, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"Only Wanna Be With You - Pok\\u00e9mon 25 Version\", \"Streams\": 7464020, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"3SawmGBjjq8EOYZJV11cJm\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2021-02-25\", \"Weeks Charted\": \"2021-02-26--2021-03-05\", \"Popularity\": 72.0, \"Danceability\": 0.47, \"Energy\": 0.709, \"Loudness\": -4.563, \"Speechiness\": 0.0299, \"Acousticness\": 0.00124, \"Liveness\": 0.302, \"Tempo\": 98.036, \"Duration (ms)\": 241360.0, \"Valence\": 0.247, \"Chord\": \"G\"}, {\"Index\": 519, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"test drive\", \"Streams\": 6591829, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3eZYOQO4UzKrUDYDghtnFw\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-02-19\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\", \"Popularity\": 71.0, \"Danceability\": 0.698, \"Energy\": 0.708, \"Loudness\": -4.943, \"Speechiness\": 0.0454, \"Acousticness\": 0.0251, \"Liveness\": 0.124, \"Tempo\": 115.036, \"Duration (ms)\": 122174.0, \"Valence\": 0.322, \"Chord\": \"A\"}, {\"Index\": 520, \"Highest Charting Position\": 42, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"T\\u00fa Me Dejaste De Querer\", \"Streams\": 5874460, \"Artist\": \"C. Tangana, Ni\\u00f1o de Elche, La H\\u00fangara\", \"Artist Followers\": 1453875.0, \"Song ID\": \"5ddFjrPG8NgQQ6xlOQIVd2\", \"Genre\": \"['urbano espanol']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 75.0, \"Danceability\": 0.823, \"Energy\": 0.723, \"Loudness\": -4.778, \"Speechiness\": 0.229, \"Acousticness\": 0.311, \"Liveness\": 0.0998, \"Tempo\": 83.97, \"Duration (ms)\": 198493.0, \"Valence\": 0.505, \"Chord\": \"E\"}, {\"Index\": 521, \"Highest Charting Position\": 46, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"SO DONE\", \"Streams\": 5440707, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"5psEZhQu6lukjhavJo4AbC\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-10-23\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 74.0, \"Danceability\": 0.719, \"Energy\": 0.598, \"Loudness\": -6.254, \"Speechiness\": 0.077, \"Acousticness\": 0.232, \"Liveness\": 0.115, \"Tempo\": 142.592, \"Duration (ms)\": 126521.0, \"Valence\": 0.303, \"Chord\": \"A\"}, {\"Index\": 522, \"Highest Charting Position\": 35, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Jeans\", \"Streams\": 5145966, \"Artist\": \"Justin Quiles\", \"Artist Followers\": 2897862.0, \"Song ID\": \"3GtnId3Cm1Xa6joCj08nzW\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 75.0, \"Danceability\": 0.807, \"Energy\": 0.656, \"Loudness\": -4.395, \"Speechiness\": 0.105, \"Acousticness\": 0.0165, \"Liveness\": 0.0693, \"Tempo\": 83.943, \"Duration (ms)\": 185840.0, \"Valence\": 0.89, \"Chord\": \"D#/Eb\"}, {\"Index\": 523, \"Highest Charting Position\": 2, \"Number of Times Charted\": 61, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"ROXANNE\", \"Streams\": 5124742, \"Artist\": \"Arizona Zervas\", \"Artist Followers\": 621200.0, \"Song ID\": \"696DnlkuDOXcMAnKlTgXXK\", \"Genre\": \"['pop rap', 'rhode island rap']\", \"Release Date\": \"2019-10-10\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.621, \"Energy\": 0.601, \"Loudness\": -5.616, \"Speechiness\": 0.148, \"Acousticness\": 0.0522, \"Liveness\": 0.46, \"Tempo\": 116.735, \"Duration (ms)\": 163636.0, \"Valence\": 0.457, \"Chord\": \"F#/Gb\"}, {\"Index\": 524, \"Highest Charting Position\": 83, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"rockstar (feat. 21 Savage)\", \"Streams\": 5115990, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"0e7ipj03S05BNilyu5bRzt\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2018-04-27\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-01-29--2021-02-05\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.585, \"Energy\": 0.52, \"Loudness\": -6.136, \"Speechiness\": 0.0712, \"Acousticness\": 0.124, \"Liveness\": 0.131, \"Tempo\": 159.801, \"Duration (ms)\": 218147.0, \"Valence\": 0.129, \"Chord\": \"F\"}, {\"Index\": 525, \"Highest Charting Position\": 185, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-26--2021-03-05\", \"Song Name\": \"P\\u00e1rteme La Cara\", \"Streams\": 5079580, \"Artist\": \"C. Tangana, Ed Maverick\", \"Artist Followers\": 1453875.0, \"Song ID\": \"5gEUDNQvoQjdjklrwPdGwD\", \"Genre\": \"['urbano espanol']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-02-26--2021-03-05\", \"Popularity\": 70.0, \"Danceability\": 0.761, \"Energy\": 0.296, \"Loudness\": -10.22, \"Speechiness\": 0.0484, \"Acousticness\": 0.551, \"Liveness\": 0.134, \"Tempo\": 127.938, \"Duration (ms)\": 167867.0, \"Valence\": 0.579, \"Chord\": \"C\"}, {\"Index\": 526, \"Highest Charting Position\": 80, \"Number of Times Charted\": 57, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Without Me\", \"Streams\": 5016283, \"Artist\": \"Halsey\", \"Artist Followers\": 15663384.0, \"Song ID\": \"5p7ujcrUXASCNwRaWNHR1C\", \"Genre\": \"['dance pop', 'electropop', 'etherpop', 'indie poptimism', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-10-04\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.752, \"Energy\": 0.488, \"Loudness\": -7.05, \"Speechiness\": 0.0705, \"Acousticness\": 0.297, \"Liveness\": 0.0936, \"Tempo\": 136.041, \"Duration (ms)\": 201661.0, \"Valence\": 0.533, \"Chord\": \"F#/Gb\"}, {\"Index\": 527, \"Highest Charting Position\": 33, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"BOOKER T\", \"Streams\": 4995965, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"26w9NTiE9NGjW1ZvIOd1So\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 77.0, \"Danceability\": 0.883, \"Energy\": 0.6, \"Loudness\": -7.188, \"Speechiness\": 0.37, \"Acousticness\": 0.114, \"Liveness\": 0.0931, \"Tempo\": 113.903, \"Duration (ms)\": 156430.0, \"Valence\": 0.691, \"Chord\": \"G\"}, {\"Index\": 528, \"Highest Charting Position\": 5, \"Number of Times Charted\": 53, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Intentions (feat. Quavo)\", \"Streams\": 4994138, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"4umIPjkehX1r7uhmGvXiSV\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 77.0, \"Danceability\": 0.806, \"Energy\": 0.546, \"Loudness\": -6.637, \"Speechiness\": 0.0575, \"Acousticness\": 0.3, \"Liveness\": 0.102, \"Tempo\": 147.986, \"Duration (ms)\": 212867.0, \"Valence\": 0.874, \"Chord\": \"A\"}, {\"Index\": 529, \"Highest Charting Position\": 49, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Sofia\", \"Streams\": 4982892, \"Artist\": \"Clairo\", \"Artist Followers\": 2722638.0, \"Song ID\": \"7B3z0ySL9Rr0XvZEAjWZzM\", \"Genre\": \"['bedroom pop', 'indie pop', 'pop']\", \"Release Date\": \"2019-08-02\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 81.0, \"Danceability\": 0.744, \"Energy\": 0.619, \"Loudness\": -9.805, \"Speechiness\": 0.039, \"Acousticness\": 0.598, \"Liveness\": 0.231, \"Tempo\": 112.997, \"Duration (ms)\": 188387.0, \"Valence\": 0.641, \"Chord\": \"C\"}, {\"Index\": 530, \"Highest Charting Position\": 176, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Photograph\", \"Streams\": 4974880, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"1HNkqx9Ahdgi1Ixy2xkKkL\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2014-06-21\", \"Weeks Charted\": \"2021-02-26--2021-03-05\\n2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-02-07--2020-02-14\\n2020-01-03--2020-01-10\", \"Popularity\": 83.0, \"Danceability\": 0.614, \"Energy\": 0.379, \"Loudness\": -10.48, \"Speechiness\": 0.0476, \"Acousticness\": 0.607, \"Liveness\": 0.0986, \"Tempo\": 107.989, \"Duration (ms)\": 258987.0, \"Valence\": 0.201, \"Chord\": \"E\"}, {\"Index\": 531, \"Highest Charting Position\": 20, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"34+35 Remix (feat. Doja Cat, Megan Thee Stallion) - Remix\", \"Streams\": 6162453, \"Artist\": \"Ariana Grande\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 532, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"Madonna\", \"Streams\": 5936752, \"Artist\": \"Bausa, Apache 207\", \"Artist Followers\": 961181.0, \"Song ID\": \"6a3kNt1UlUOapDKmEr3JzZ\", \"Genre\": \"['german hip hop', 'german pop']\", \"Release Date\": \"2021-02-26\", \"Weeks Charted\": \"2021-02-19--2021-02-26\", \"Popularity\": 68.0, \"Danceability\": 0.806, \"Energy\": 0.565, \"Loudness\": -8.96, \"Speechiness\": 0.113, \"Acousticness\": 0.47, \"Liveness\": 0.0824, \"Tempo\": 116.963, \"Duration (ms)\": 195734.0, \"Valence\": 0.311, \"Chord\": \"B\"}, {\"Index\": 533, \"Highest Charting Position\": 144, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-19--2021-02-26\", \"Song Name\": \"CLOUDS\", \"Streams\": 5897983, \"Artist\": \"NF\", \"Artist Followers\": 5831194.0, \"Song ID\": \"5UMMPHPp6vRP6ghPpSUOzp\", \"Genre\": \"['hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2021-02-18\", \"Weeks Charted\": \"2021-02-19--2021-02-26\", \"Popularity\": 69.0, \"Danceability\": 0.793, \"Energy\": 0.65, \"Loudness\": -3.944, \"Speechiness\": 0.397, \"Acousticness\": 0.371, \"Liveness\": 0.854, \"Tempo\": 128.111, \"Duration (ms)\": 243750.0, \"Valence\": 0.809, \"Chord\": \"C#/Db\"}, {\"Index\": 534, \"Highest Charting Position\": 12, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Wonder\", \"Streams\": 5535339, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 1251372.0, \"Song ID\": \"7jjS2fSD9zuzbEHeVEFJ2w\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 0.0, \"Danceability\": 0.333, \"Energy\": 0.637, \"Loudness\": -4.904, \"Speechiness\": 0.0581, \"Acousticness\": 0.131, \"Liveness\": 0.149, \"Tempo\": 139.898, \"Duration (ms)\": 172693.0, \"Valence\": 0.132, \"Chord\": \"C#/Db\"}, {\"Index\": 535, \"Highest Charting Position\": 50, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Skin\", \"Streams\": 5497942, \"Artist\": \"Sabrina Carpenter\", \"Artist Followers\": 3689546.0, \"Song ID\": \"03B2SfXuvDh1m9F4tqrX07\", \"Genre\": \"['alt z', 'dance pop', 'electropop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 76.0, \"Danceability\": 0.557, \"Energy\": 0.457, \"Loudness\": -5.372, \"Speechiness\": 0.0335, \"Acousticness\": 0.428, \"Liveness\": 0.0567, \"Tempo\": 105.918, \"Duration (ms)\": 177500.0, \"Valence\": 0.328, \"Chord\": \"G\"}, {\"Index\": 536, \"Highest Charting Position\": 62, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Tyler Herro\", \"Streams\": 5168107, \"Artist\": \"Jack Harlow\", \"Artist Followers\": 1053324.0, \"Song ID\": \"4DuUwzP4ALMqpquHU0ltAB\", \"Genre\": \"['deep underground hip hop', 'kentucky hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-10-22\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 76.0, \"Danceability\": 0.794, \"Energy\": 0.756, \"Loudness\": -7.16, \"Speechiness\": 0.136, \"Acousticness\": 0.11, \"Liveness\": 0.247, \"Tempo\": 123.066, \"Duration (ms)\": 156498.0, \"Valence\": 0.775, \"Chord\": \"F\"}, {\"Index\": 537, \"Highest Charting Position\": 173, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Remember That Night?\", \"Streams\": 5116325, \"Artist\": \"Sara Kays\", \"Artist Followers\": 251549.0, \"Song ID\": \"1nYzjrdVQ8RpF93M0jPFW7\", \"Genre\": \"['alt z', 'indie cafe pop', 'modern indie pop', 'pop', 'social media pop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 78.0, \"Danceability\": 0.679, \"Energy\": 0.61, \"Loudness\": -10.936, \"Speechiness\": 0.0305, \"Acousticness\": 0.585, \"Liveness\": 0.156, \"Tempo\": 123.978, \"Duration (ms)\": 227186.0, \"Valence\": 0.554, \"Chord\": \"G\"}, {\"Index\": 538, \"Highest Charting Position\": 128, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Lifestyle (feat. Adam Levine)\", \"Streams\": 5059891, \"Artist\": \"Jason Derulo, Maroon 5\", \"Artist Followers\": 9778632.0, \"Song ID\": \"0osvOdeD3YXZiWkT8MKolJ\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 78.0, \"Danceability\": 0.749, \"Energy\": 0.674, \"Loudness\": -5.128, \"Speechiness\": 0.0366, \"Acousticness\": 0.0209, \"Liveness\": 0.169, \"Tempo\": 123.055, \"Duration (ms)\": 153865.0, \"Valence\": 0.711, \"Chord\": \"A#/Bb\"}, {\"Index\": 539, \"Highest Charting Position\": 177, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Fly Away\", \"Streams\": 5053713, \"Artist\": \"Tones And I\", \"Artist Followers\": 2820477.0, \"Song ID\": \"5ri4zqtWhG07hIuNNDWP76\", \"Genre\": \"['australian pop', 'pop']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 79.0, \"Danceability\": 0.806, \"Energy\": 0.513, \"Loudness\": -6.208, \"Speechiness\": 0.0685, \"Acousticness\": 0.217, \"Liveness\": 0.217, \"Tempo\": 124.988, \"Duration (ms)\": 178157.0, \"Valence\": 0.503, \"Chord\": \"E\"}, {\"Index\": 540, \"Highest Charting Position\": 37, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Despeinada\", \"Streams\": 5004462, \"Artist\": \"Ozuna, Camilo\", \"Artist Followers\": 29238936.0, \"Song ID\": \"0JAZWvvqttGFm4UMDsPQXC\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 75.0, \"Danceability\": 0.734, \"Energy\": 0.775, \"Loudness\": -3.855, \"Speechiness\": 0.0614, \"Acousticness\": 0.186, \"Liveness\": 0.123, \"Tempo\": 166.039, \"Duration (ms)\": 224187.0, \"Valence\": 0.72, \"Chord\": \"G#/Ab\"}, {\"Index\": 541, \"Highest Charting Position\": 14, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"motive (with Doja Cat)\", \"Streams\": 4986037, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"5GkQIP5mWPi4KZLLXeuFTT\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 80.0, \"Danceability\": 0.789, \"Energy\": 0.742, \"Loudness\": -5.664, \"Speechiness\": 0.0652, \"Acousticness\": 0.0681, \"Liveness\": 0.166, \"Tempo\": 116.965, \"Duration (ms)\": 167990.0, \"Valence\": 0.661, \"Chord\": \"A#/Bb\"}, {\"Index\": 542, \"Highest Charting Position\": 28, \"Number of Times Charted\": 57, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"I Don't Care (with Justin Bieber)\", \"Streams\": 4984399, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"3HVWdVOQ0ZA45FuZGSfvns\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-05-10\", \"Weeks Charted\": \"2021-02-19--2021-02-26\\n2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.798, \"Energy\": 0.675, \"Loudness\": -5.041, \"Speechiness\": 0.0442, \"Acousticness\": 0.0912, \"Liveness\": 0.0894, \"Tempo\": 101.956, \"Duration (ms)\": 219947.0, \"Valence\": 0.842, \"Chord\": \"F#/Gb\"}, {\"Index\": 543, \"Highest Charting Position\": 14, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Ay, DiOs M\\u00edo!\", \"Streams\": 5344862, \"Artist\": \"KAROL G\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3PF1mUoD0NgK4ykdt5sk3g\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 0.0, \"Danceability\": 0.715, \"Energy\": 0.706, \"Loudness\": -4.423, \"Speechiness\": 0.195, \"Acousticness\": 0.496, \"Liveness\": 0.106, \"Tempo\": 179.997, \"Duration (ms)\": 189840.0, \"Valence\": 0.522, \"Chord\": \"B\"}, {\"Index\": 544, \"Highest Charting Position\": 83, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Nathy Peluso: Bzrp Music Sessions, Vol. 36\", \"Streams\": 5232509, \"Artist\": \"Bizarrap, Nathy Peluso\", \"Artist Followers\": 3134041.0, \"Song ID\": \"78SeXVRJ7KCqVmOwTiFjnI\", \"Genre\": \"['argentine hip hop', 'pop venezolano', 'trap argentino', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 77.0, \"Danceability\": 0.65, \"Energy\": 0.655, \"Loudness\": -3.71, \"Speechiness\": 0.405, \"Acousticness\": 0.25, \"Liveness\": 0.0691, \"Tempo\": 94.059, \"Duration (ms)\": 171215.0, \"Valence\": 0.735, \"Chord\": \"C#/Db\"}, {\"Index\": 545, \"Highest Charting Position\": 17, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Haw\\u00e1i - Remix\", \"Streams\": 5163323, \"Artist\": \"Maluma, The Weeknd\", \"Artist Followers\": 26784251.0, \"Song ID\": \"0GzuHFG4Ql6DoyxFRnIk3F\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-11-05\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 77.0, \"Danceability\": 0.766, \"Energy\": 0.788, \"Loudness\": -3.128, \"Speechiness\": 0.312, \"Acousticness\": 0.105, \"Liveness\": 0.142, \"Tempo\": 179.984, \"Duration (ms)\": 200482.0, \"Valence\": 0.609, \"Chord\": \"F#/Gb\"}, {\"Index\": 546, \"Highest Charting Position\": 22, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Tattoo - Remix with Camilo\", \"Streams\": 5120753, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6096559.0, \"Song ID\": \"4ZRrLHqzhGRXYj2qcB4s5S\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-07-09\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 78.0, \"Danceability\": 0.848, \"Energy\": 0.637, \"Loudness\": -5.132, \"Speechiness\": 0.156, \"Acousticness\": 0.0413, \"Liveness\": 0.0521, \"Tempo\": 96.988, \"Duration (ms)\": 222680.0, \"Valence\": 0.698, \"Chord\": \"A\"}, {\"Index\": 547, \"Highest Charting Position\": 151, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Meia Noite (Voc\\u00ea tem meu Whatsapp)\", \"Streams\": 5044252, \"Artist\": \"Tarc\\u00edsio do Acordeon\", \"Artist Followers\": 1200248.0, \"Song ID\": \"6sPBi0qLI6KM3yXX56NxsA\", \"Genre\": \"[]\", \"Release Date\": \"2020-12-17\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 67.0, \"Danceability\": 0.709, \"Energy\": 0.816, \"Loudness\": -4.787, \"Speechiness\": 0.0346, \"Acousticness\": 0.685, \"Liveness\": 0.146, \"Tempo\": 150.06, \"Duration (ms)\": 237900.0, \"Valence\": 0.921, \"Chord\": \"B\"}, {\"Index\": 548, \"Highest Charting Position\": 143, \"Number of Times Charted\": 42, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Moonlight\", \"Streams\": 5003825, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"0JP9xo3adEtGSdUEISiszL\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2018-03-16\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2020-09-18--2020-09-25\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.921, \"Energy\": 0.537, \"Loudness\": -5.723, \"Speechiness\": 0.0804, \"Acousticness\": 0.556, \"Liveness\": 0.102, \"Tempo\": 128.009, \"Duration (ms)\": 135090.0, \"Valence\": 0.711, \"Chord\": \"A\"}, {\"Index\": 549, \"Highest Charting Position\": 182, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Thinking out Loud\", \"Streams\": 4995623, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"34gCuhDGsG4bRPIf9bb02f\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2014-06-21\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 82.0, \"Danceability\": 0.781, \"Energy\": 0.445, \"Loudness\": -6.061, \"Speechiness\": 0.0295, \"Acousticness\": 0.474, \"Liveness\": 0.184, \"Tempo\": 78.998, \"Duration (ms)\": 281560.0, \"Valence\": 0.591, \"Chord\": \"D\"}, {\"Index\": 550, \"Highest Charting Position\": 2, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Toosie Slide\", \"Streams\": 4966878, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"127QTOFJsJQp5LbJbu3A1y\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 78.0, \"Danceability\": 0.834, \"Energy\": 0.454, \"Loudness\": -9.75, \"Speechiness\": 0.201, \"Acousticness\": 0.321, \"Liveness\": 0.114, \"Tempo\": 81.618, \"Duration (ms)\": 247059.0, \"Valence\": 0.837, \"Chord\": \"C#/Db\"}, {\"Index\": 551, \"Highest Charting Position\": 167, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Earned It (Fifty Shades Of Grey)\", \"Streams\": 4929647, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"4frLb7nWtsz2ymBE6k2GRP\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2015-08-28\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\", \"Popularity\": 69.0, \"Danceability\": 0.659, \"Energy\": 0.291, \"Loudness\": -8.275, \"Speechiness\": 0.0348, \"Acousticness\": 0.405, \"Liveness\": 0.0771, \"Tempo\": 119.829, \"Duration (ms)\": 277680.0, \"Valence\": 0.406, \"Chord\": \"D\"}, {\"Index\": 552, \"Highest Charting Position\": 9, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"ily (i love you baby) (feat. Emilee)\", \"Streams\": 4908929, \"Artist\": \"Surf Mesa\", \"Artist Followers\": 132855.0, \"Song ID\": \"62aP9fBQKYKxi7PDXwcUAS\", \"Genre\": \"['tropical house']\", \"Release Date\": \"2019-11-26\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 81.0, \"Danceability\": 0.674, \"Energy\": 0.774, \"Loudness\": -7.567, \"Speechiness\": 0.0892, \"Acousticness\": 0.0686, \"Liveness\": 0.393, \"Tempo\": 112.05, \"Duration (ms)\": 176547.0, \"Valence\": 0.33, \"Chord\": \"B\"}, {\"Index\": 553, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-12--2021-02-19\", \"Song Name\": \"Wonderwall\", \"Streams\": 4902737, \"Artist\": \"Oasis\", \"Artist Followers\": 6478565.0, \"Song ID\": \"7ygpwy2qP3NbrxVkHvUhXY\", \"Genre\": \"['beatlesque', 'britpop', 'madchester', 'permanent wave', 'rock']\", \"Release Date\": \"1995\", \"Weeks Charted\": \"2021-02-12--2021-02-19\", \"Popularity\": 78.0, \"Danceability\": 0.375, \"Energy\": 0.893, \"Loudness\": -4.097, \"Speechiness\": 0.0406, \"Acousticness\": 0.000509, \"Liveness\": 0.187, \"Tempo\": 174.323, \"Duration (ms)\": 258773.0, \"Valence\": 0.434, \"Chord\": \"D\"}, {\"Index\": 554, \"Highest Charting Position\": 181, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Everybody Dies In Their Nightmares\", \"Streams\": 4847224, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"3GVkPk8mqxz0itaAriG1L7\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2017-08-25\", \"Weeks Charted\": \"2021-02-12--2021-02-19\\n2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\", \"Popularity\": 83.0, \"Danceability\": 0.734, \"Energy\": 0.57, \"Loudness\": -7.066, \"Speechiness\": 0.133, \"Acousticness\": 0.847, \"Liveness\": 0.112, \"Tempo\": 129.953, \"Duration (ms)\": 95467.0, \"Valence\": 0.689, \"Chord\": \"G\"}, {\"Index\": 555, \"Highest Charting Position\": 27, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Bad Boy (with Young Thug)\", \"Streams\": 6011642, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"43CIWpJaJHRcI4mUSjqgc2\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 76.0, \"Danceability\": 0.697, \"Energy\": 0.674, \"Loudness\": -6.326, \"Speechiness\": 0.0533, \"Acousticness\": 0.00215, \"Liveness\": 0.138, \"Tempo\": 81.535, \"Duration (ms)\": 157355.0, \"Valence\": 0.198, \"Chord\": \"C#/Db\"}, {\"Index\": 556, \"Highest Charting Position\": 19, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Lo Vas A Olvidar (with ROSAL\\u00cdA)\", \"Streams\": 5963380, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"0psS4i5YooJrXfDnGvWRLi\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-01-21\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 68.0, \"Danceability\": 0.343, \"Energy\": 0.243, \"Loudness\": -14.66, \"Speechiness\": 0.0777, \"Acousticness\": 0.721, \"Liveness\": 0.0668, \"Tempo\": 135.154, \"Duration (ms)\": 203464.0, \"Valence\": 0.032, \"Chord\": \"E\"}, {\"Index\": 557, \"Highest Charting Position\": 152, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Floating Through Space\", \"Streams\": 5579697, \"Artist\": \"Sia, David Guetta\", \"Artist Followers\": 20528724.0, \"Song ID\": \"2AceGjiX9isUbXmMZa0Dl1\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'pop']\", \"Release Date\": \"2021-02-04\", \"Weeks Charted\": \"2021-02-05--2021-02-12\", \"Popularity\": 78.0, \"Danceability\": 0.575, \"Energy\": 0.844, \"Loudness\": -4.89, \"Speechiness\": 0.072, \"Acousticness\": 0.00172, \"Liveness\": 0.114, \"Tempo\": 104.914, \"Duration (ms)\": 177801.0, \"Valence\": 0.277, \"Chord\": \"F#/Gb\"}, {\"Index\": 558, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Can't Feel My Face\", \"Streams\": 5479407, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"22VdIZQfgXJea34mQxlt81\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2015-08-28\", \"Weeks Charted\": \"2021-02-05--2021-02-12\", \"Popularity\": 80.0, \"Danceability\": 0.705, \"Energy\": 0.769, \"Loudness\": -5.526, \"Speechiness\": 0.0425, \"Acousticness\": 0.113, \"Liveness\": 0.105, \"Tempo\": 107.949, \"Duration (ms)\": 213520.0, \"Valence\": 0.583, \"Chord\": \"A\"}, {\"Index\": 559, \"Highest Charting Position\": 89, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"You (with Marshmello & Vance Joy)\", \"Streams\": 5342938, \"Artist\": \"benny blanco\", \"Artist Followers\": 804613.0, \"Song ID\": \"1GkHyypTFkUf0QQKwYoXH4\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2021-01-29\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 73.0, \"Danceability\": 0.668, \"Energy\": 0.563, \"Loudness\": -6.433, \"Speechiness\": 0.0522, \"Acousticness\": 0.0493, \"Liveness\": 0.119, \"Tempo\": 103.116, \"Duration (ms)\": 169632.0, \"Valence\": 0.305, \"Chord\": \"B\"}, {\"Index\": 560, \"Highest Charting Position\": 168, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Call Out My Name\", \"Streams\": 5233359, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"09mEdoA6zrmBPgTEN5qXmN\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2018-03-30\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\", \"Popularity\": 80.0, \"Danceability\": 0.461, \"Energy\": 0.593, \"Loudness\": -4.954, \"Speechiness\": 0.0356, \"Acousticness\": 0.17, \"Liveness\": 0.307, \"Tempo\": 134.17, \"Duration (ms)\": 228373.0, \"Valence\": 0.175, \"Chord\": \"C#/Db\"}, {\"Index\": 561, \"Highest Charting Position\": 14, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Midnight Sky\", \"Streams\": 5208100, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"27ycaQnQAxaPiyeg3nr2aB\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 76.0, \"Danceability\": 0.705, \"Energy\": 0.814, \"Loudness\": -5.466, \"Speechiness\": 0.0346, \"Acousticness\": 0.00115, \"Liveness\": 0.203, \"Tempo\": 110.0, \"Duration (ms)\": 223279.0, \"Valence\": 0.259, \"Chord\": \"E\"}, {\"Index\": 562, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-02-05--2021-02-12\", \"Song Name\": \"Pressure (feat. Tove Lo)\", \"Streams\": 5197587, \"Artist\": \"Martin Garrix\", \"Artist Followers\": 14921269.0, \"Song ID\": \"4ga4WvRNhMsIL38pkBbnIN\", \"Genre\": \"['dance pop', 'dutch edm', 'edm', 'pop', 'pop dance', 'progressive house', 'tropical house']\", \"Release Date\": \"2021-02-05\", \"Weeks Charted\": \"2021-02-05--2021-02-12\", \"Popularity\": 76.0, \"Danceability\": 0.859, \"Energy\": 0.558, \"Loudness\": -8.991, \"Speechiness\": 0.0902, \"Acousticness\": 0.659, \"Liveness\": 0.124, \"Tempo\": 114.978, \"Duration (ms)\": 144391.0, \"Valence\": 0.357, \"Chord\": \"G\"}, {\"Index\": 563, \"Highest Charting Position\": 140, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Can You Feel My Heart\", \"Streams\": 5092250, \"Artist\": \"Bring Me The Horizon\", \"Artist Followers\": 3912138.0, \"Song ID\": \"0WSa1sucoNRcEeULlZVQXj\", \"Genre\": \"['melodic metalcore', 'metalcore', 'rock', 'uk metalcore']\", \"Release Date\": \"2013-04-01\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 77.0, \"Danceability\": 0.15, \"Energy\": 0.859, \"Loudness\": -2.827, \"Speechiness\": 0.0595, \"Acousticness\": 0.00201, \"Liveness\": 0.387, \"Tempo\": 170.527, \"Duration (ms)\": 228147.0, \"Valence\": 0.354, \"Chord\": \"E\"}, {\"Index\": 564, \"Highest Charting Position\": 167, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Agua de Jamaica\", \"Streams\": 5072462, \"Artist\": \"Maluma\", \"Artist Followers\": 26784251.0, \"Song ID\": \"41BzKiCrKpUQHS3TP0jmdr\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2021-01-28\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\", \"Popularity\": 75.0, \"Danceability\": 0.664, \"Energy\": 0.665, \"Loudness\": -3.616, \"Speechiness\": 0.0879, \"Acousticness\": 0.123, \"Liveness\": 0.411, \"Tempo\": 173.961, \"Duration (ms)\": 176970.0, \"Valence\": 0.726, \"Chord\": \"A#/Bb\"}, {\"Index\": 565, \"Highest Charting Position\": 162, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Mds\", \"Streams\": 5046418, \"Artist\": \"Kawe, Mc Lele JP\", \"Artist Followers\": 444736.0, \"Song ID\": \"0QglpM23kl9ldvVdoYNZwF\", \"Genre\": \"['brazilian hip hop', 'funk ostentacao']\", \"Release Date\": \"2020-05-19\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\", \"Popularity\": 72.0, \"Danceability\": 0.885, \"Energy\": 0.561, \"Loudness\": -5.331, \"Speechiness\": 0.249, \"Acousticness\": 0.261, \"Liveness\": 0.121, \"Tempo\": 140.02, \"Duration (ms)\": 125143.0, \"Valence\": 0.644, \"Chord\": \"F#/Gb\"}, {\"Index\": 566, \"Highest Charting Position\": 18, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Heartless\", \"Streams\": 4995578, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"6bnF93Rx87YqUBLSgjiMU8\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.537, \"Energy\": 0.746, \"Loudness\": -5.507, \"Speechiness\": 0.15, \"Acousticness\": 0.0236, \"Liveness\": 0.156, \"Tempo\": 170.062, \"Duration (ms)\": 198267.0, \"Valence\": 0.252, \"Chord\": \"A#/Bb\"}, {\"Index\": 567, \"Highest Charting Position\": 20, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"pov\", \"Streams\": 4906738, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3UoULw70kMsiVXxW0L3A33\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 79.0, \"Danceability\": 0.487, \"Energy\": 0.534, \"Loudness\": -5.664, \"Speechiness\": 0.0555, \"Acousticness\": 0.36, \"Liveness\": 0.1, \"Tempo\": 131.798, \"Duration (ms)\": 201882.0, \"Valence\": 0.173, \"Chord\": \"C\"}, {\"Index\": 568, \"Highest Charting Position\": 138, \"Number of Times Charted\": 49, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Be Alright\", \"Streams\": 4900492, \"Artist\": \"Dean Lewis\", \"Artist Followers\": 1692635.0, \"Song ID\": \"3EPXxR3ImUwfayaurPi3cm\", \"Genre\": \"['australian pop', 'indie cafe pop', 'pop', 'pop rock', 'post-teen pop']\", \"Release Date\": \"2018-06-29\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.553, \"Energy\": 0.586, \"Loudness\": -6.319, \"Speechiness\": 0.0362, \"Acousticness\": 0.697, \"Liveness\": 0.0813, \"Tempo\": 126.684, \"Duration (ms)\": 196373.0, \"Valence\": 0.443, \"Chord\": \"B\"}, {\"Index\": 569, \"Highest Charting Position\": 174, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Cry Baby (feat. DaBaby)\", \"Streams\": 4884711, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"4aarlAfLKVCTxUDNgbwhjH\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 76.0, \"Danceability\": 0.957, \"Energy\": 0.437, \"Loudness\": -7.882, \"Speechiness\": 0.359, \"Acousticness\": 0.00402, \"Liveness\": 0.219, \"Tempo\": 130.058, \"Duration (ms)\": 137984.0, \"Valence\": 0.616, \"Chord\": \"B\"}, {\"Index\": 570, \"Highest Charting Position\": 47, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Mi Cuarto\", \"Streams\": 4873380, \"Artist\": \"Jerry Di\", \"Artist Followers\": 149682.0, \"Song ID\": \"6fmQjRuo7XvRFCK2qex5hQ\", \"Genre\": \"['cubaton', 'dominican pop', 'pop venezolano', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2021-02-05--2021-02-12\\n2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 76.0, \"Danceability\": 0.854, \"Energy\": 0.525, \"Loudness\": -4.426, \"Speechiness\": 0.214, \"Acousticness\": 0.819, \"Liveness\": 0.146, \"Tempo\": 97.054, \"Duration (ms)\": 197587.0, \"Valence\": 0.63, \"Chord\": \"C#/Db\"}, {\"Index\": 571, \"Highest Charting Position\": 99, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Ohne Dich\", \"Streams\": 5487774, \"Artist\": \"KASIMIR1441, badm\\u00f3mzjay, WILDBWOYS\", \"Artist Followers\": 197320.0, \"Song ID\": \"4hSJUp6k7QeHLxU32MrLIU\", \"Genre\": \"['german alternative rap', 'german hip hop', 'german trap', 'tekk']\", \"Release Date\": \"2021-01-14\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 70.0, \"Danceability\": 0.807, \"Energy\": 0.535, \"Loudness\": -6.519, \"Speechiness\": 0.349, \"Acousticness\": 0.191, \"Liveness\": 0.125, \"Tempo\": 156.013, \"Duration (ms)\": 125720.0, \"Valence\": 0.925, \"Chord\": \"B\"}, {\"Index\": 572, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-29--2021-02-05\", \"Song Name\": \"Gravity (feat. Tyler, The Creator)\", \"Streams\": 5136895, \"Artist\": \"Brent Faiyaz, DJ Dahi\", \"Artist Followers\": 1726216.0, \"Song ID\": \"6u3CPnFMKANYgfdiifFOiJ\", \"Genre\": \"['dmv rap', 'pop', 'r&b', 'rap']\", \"Release Date\": \"2021-01-29\", \"Weeks Charted\": \"2021-01-29--2021-02-05\", \"Popularity\": 76.0, \"Danceability\": 0.539, \"Energy\": 0.615, \"Loudness\": -8.746, \"Speechiness\": 0.252, \"Acousticness\": 0.173, \"Liveness\": 0.144, \"Tempo\": 163.924, \"Duration (ms)\": 214693.0, \"Valence\": 0.493, \"Chord\": \"C#/Db\"}, {\"Index\": 573, \"Highest Charting Position\": 55, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Vibez\", \"Streams\": 5071718, \"Artist\": \"ZAYN\", \"Artist Followers\": 16655692.0, \"Song ID\": \"709F3MwiVvLD0LQXeKs5Cz\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 69.0, \"Danceability\": 0.635, \"Energy\": 0.659, \"Loudness\": -7.499, \"Speechiness\": 0.116, \"Acousticness\": 0.242, \"Liveness\": 0.105, \"Tempo\": 96.855, \"Duration (ms)\": 163127.0, \"Valence\": 0.34, \"Chord\": \"G\"}, {\"Index\": 574, \"Highest Charting Position\": 103, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"All I Want - From \\\"High School Musical: The Musical: The Series\\\"\", \"Streams\": 5052801, \"Artist\": \"Olivia Rodrigo\", \"Artist Followers\": 6313514.0, \"Song ID\": \"4Yxc55NX3tAXC2mHRAhtcW\", \"Genre\": \"['pop']\", \"Release Date\": \"2019-11-27\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 76.0, \"Danceability\": 0.376, \"Energy\": 0.43, \"Loudness\": -6.585, \"Speechiness\": 0.0328, \"Acousticness\": 0.0902, \"Liveness\": 0.0912, \"Tempo\": 77.599, \"Duration (ms)\": 177323.0, \"Valence\": 0.129, \"Chord\": \"C\"}, {\"Index\": 575, \"Highest Charting Position\": 45, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Daisy\", \"Streams\": 5030670, \"Artist\": \"Ashnikko\", \"Artist Followers\": 1248499.0, \"Song ID\": \"0AUvWawuP0ibk4SQ3sIZjk\", \"Genre\": \"['electropop', 'escape room', 'pop']\", \"Release Date\": \"2020-07-09\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 76.0, \"Danceability\": 0.834, \"Energy\": 0.663, \"Loudness\": -6.143, \"Speechiness\": 0.133, \"Acousticness\": 0.235, \"Liveness\": 0.372, \"Tempo\": 121.876, \"Duration (ms)\": 146523.0, \"Valence\": 0.774, \"Chord\": \"G#/Ab\"}, {\"Index\": 576, \"Highest Charting Position\": 83, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Wasted On You\", \"Streams\": 4948563, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"3cBsEDNhFI9E82vPj3kvi3\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\", \"Popularity\": 76.0, \"Danceability\": 0.505, \"Energy\": 0.657, \"Loudness\": -5.24, \"Speechiness\": 0.0318, \"Acousticness\": 0.373, \"Liveness\": 0.126, \"Tempo\": 196.0, \"Duration (ms)\": 178520.0, \"Valence\": 0.252, \"Chord\": \"B\"}, {\"Index\": 577, \"Highest Charting Position\": 13, \"Number of Times Charted\": 38, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"La Jeepeta - Remix\", \"Streams\": 4942545, \"Artist\": \"Nio Garcia, Anuel AA, Myke Towers, Brray, Juanka\", \"Artist Followers\": 2127531.0, \"Song ID\": \"1mohfLaTJtB2RplHLQVM70\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2021-01-29--2021-02-05\\n2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 75.0, \"Danceability\": 0.815, \"Energy\": 0.715, \"Loudness\": -4.65, \"Speechiness\": 0.207, \"Acousticness\": 0.3, \"Liveness\": 0.091, \"Tempo\": 176.007, \"Duration (ms)\": 345241.0, \"Valence\": 0.786, \"Chord\": \"E\"}, {\"Index\": 578, \"Highest Charting Position\": 137, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-22--2021-01-29\", \"Song Name\": \"Los Dioses\", \"Streams\": 5929507, \"Artist\": \"Anuel AA, Ozuna\", \"Artist Followers\": 18306226.0, \"Song ID\": \"73O30uMI7n6DuzBmbtO7kC\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2021-01-22\", \"Weeks Charted\": \"2021-01-22--2021-01-29\", \"Popularity\": 73.0, \"Danceability\": 0.817, \"Energy\": 0.737, \"Loudness\": -5.453, \"Speechiness\": 0.102, \"Acousticness\": 0.046, \"Liveness\": 0.092, \"Tempo\": 93.985, \"Duration (ms)\": 206587.0, \"Valence\": 0.67, \"Chord\": \"F#/Gb\"}, {\"Index\": 579, \"Highest Charting Position\": 132, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Si Me Tomo Una Cerveza\", \"Streams\": 5427534, \"Artist\": \"Migrantes, Alico\", \"Artist Followers\": 114348.0, \"Song ID\": \"3lCbsHaN1wCxyDzcNN2x4N\", \"Genre\": \"['cumbia pop']\", \"Release Date\": \"2020-11-07\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 74.0, \"Danceability\": 0.72, \"Energy\": 0.613, \"Loudness\": -6.899, \"Speechiness\": 0.0572, \"Acousticness\": 0.185, \"Liveness\": 0.155, \"Tempo\": 84.974, \"Duration (ms)\": 182199.0, \"Valence\": 0.857, \"Chord\": \"C#/Db\"}, {\"Index\": 580, \"Highest Charting Position\": 90, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Somebody\\u2019s Problem\", \"Streams\": 5332437, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"0SErdEdRcVX1uJCf1eTGYH\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2020-11-20--2020-11-27\", \"Popularity\": 70.0, \"Danceability\": 0.657, \"Energy\": 0.54, \"Loudness\": -7.675, \"Speechiness\": 0.0287, \"Acousticness\": 0.662, \"Liveness\": 0.123, \"Tempo\": 136.97, \"Duration (ms)\": 161773.0, \"Valence\": 0.625, \"Chord\": \"F\"}, {\"Index\": 581, \"Highest Charting Position\": 66, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"De Una Vez\", \"Streams\": 5186567, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"1v3lhrZEsOcazqR2QIyyRu\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-03-12\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\", \"Popularity\": 70.0, \"Danceability\": 0.659, \"Energy\": 0.479, \"Loudness\": -6.79, \"Speechiness\": 0.2, \"Acousticness\": 0.152, \"Liveness\": 0.268, \"Tempo\": 163.882, \"Duration (ms)\": 155956.0, \"Valence\": 0.0395, \"Chord\": \"B\"}, {\"Index\": 582, \"Highest Charting Position\": 121, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Way Out (feat. Big Sean)\", \"Streams\": 4962949, \"Artist\": \"Jack Harlow\", \"Artist Followers\": 1053324.0, \"Song ID\": \"6rLi6PyWXu1rPlShuIZpj6\", \"Genre\": \"['deep underground hip hop', 'kentucky hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-09\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 72.0, \"Danceability\": 0.945, \"Energy\": 0.582, \"Loudness\": -8.357, \"Speechiness\": 0.0719, \"Acousticness\": 0.114, \"Liveness\": 0.103, \"Tempo\": 108.025, \"Duration (ms)\": 168906.0, \"Valence\": 0.907, \"Chord\": \"B\"}, {\"Index\": 583, \"Highest Charting Position\": 42, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Diamonds\", \"Streams\": 4931163, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"5hvwx5i67IwnCkjl9VHkNv\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-09-17\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 77.0, \"Danceability\": 0.653, \"Energy\": 0.667, \"Loudness\": -6.764, \"Speechiness\": 0.0423, \"Acousticness\": 0.154, \"Liveness\": 0.107, \"Tempo\": 104.181, \"Duration (ms)\": 213869.0, \"Valence\": 0.556, \"Chord\": \"A#/Bb\"}, {\"Index\": 584, \"Highest Charting Position\": 190, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Dancing in My Room\", \"Streams\": 4914093, \"Artist\": \"347aidan\", \"Artist Followers\": 211500.0, \"Song ID\": \"6Pgmqg15yVexuOgtzuxwoX\", \"Genre\": \"['sad rap']\", \"Release Date\": \"2020-10-26\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\", \"Popularity\": 79.0, \"Danceability\": 0.98, \"Energy\": 0.413, \"Loudness\": -11.052, \"Speechiness\": 0.101, \"Acousticness\": 0.671, \"Liveness\": 0.17, \"Tempo\": 119.993, \"Duration (ms)\": 180139.0, \"Valence\": 0.764, \"Chord\": \"G#/Ab\"}, {\"Index\": 585, \"Highest Charting Position\": 116, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"De Cora <3\", \"Streams\": 4864544, \"Artist\": \"Rauw Alejandro, J Balvin\", \"Artist Followers\": 6096559.0, \"Song ID\": \"22Sh5dlwbERqJAq1fZk5b2\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 73.0, \"Danceability\": 0.811, \"Energy\": 0.683, \"Loudness\": -2.028, \"Speechiness\": 0.241, \"Acousticness\": 0.46, \"Liveness\": 0.128, \"Tempo\": 176.037, \"Duration (ms)\": 190101.0, \"Valence\": 0.571, \"Chord\": \"B\"}, {\"Index\": 586, \"Highest Charting Position\": 10, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"champagne problems\", \"Streams\": 4848954, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0sY6ZUTh4yoctD8VIXz339\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 75.0, \"Danceability\": 0.462, \"Energy\": 0.24, \"Loudness\": -12.077, \"Speechiness\": 0.0377, \"Acousticness\": 0.92, \"Liveness\": 0.113, \"Tempo\": 171.319, \"Duration (ms)\": 244000.0, \"Valence\": 0.32, \"Chord\": \"C\"}, {\"Index\": 587, \"Highest Charting Position\": 37, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Go Crazy\", \"Streams\": 4833081, \"Artist\": \"Chris Brown, Young Thug\", \"Artist Followers\": 14073083.0, \"Song ID\": \"1IIKrJVP1C9N7iPtG6eOsK\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'r&b', 'rap']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2021-01-22--2021-01-29\\n2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 80.0, \"Danceability\": 0.755, \"Energy\": 0.578, \"Loudness\": -8.932, \"Speechiness\": 0.145, \"Acousticness\": 0.316, \"Liveness\": 0.25, \"Tempo\": 94.148, \"Duration (ms)\": 176960.0, \"Valence\": 0.581, \"Chord\": \"C\"}, {\"Index\": 588, \"Highest Charting Position\": 73, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Reminds Me Of You\", \"Streams\": 5942551, \"Artist\": \"Juice WRLD, The Kid LAROI\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5YSHygGN9D0mID1NsVd5my\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-12-08\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 75.0, \"Danceability\": 0.613, \"Energy\": 0.631, \"Loudness\": -6.965, \"Speechiness\": 0.12, \"Acousticness\": 0.0663, \"Liveness\": 0.169, \"Tempo\": 149.992, \"Duration (ms)\": 158033.0, \"Valence\": 0.33, \"Chord\": \"E\"}, {\"Index\": 589, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Don't Play\", \"Streams\": 5119828, \"Artist\": \"Anne-Marie, KSI, Digital Farm Animals\", \"Artist Followers\": 8153871.0, \"Song ID\": \"4I5bvu2KDsrCg0EWHIcvul\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2021-01-15\", \"Weeks Charted\": \"2021-01-15--2021-01-22\", \"Popularity\": 73.0, \"Danceability\": 0.695, \"Energy\": 0.784, \"Loudness\": -6.564, \"Speechiness\": 0.0402, \"Acousticness\": 0.0889, \"Liveness\": 0.0843, \"Tempo\": 128.031, \"Duration (ms)\": 188581.0, \"Valence\": 0.52, \"Chord\": \"F#/Gb\"}, {\"Index\": 590, \"Highest Charting Position\": 108, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"MODO TURBO\", \"Streams\": 4983557, \"Artist\": \"Lu\\u00edsa Sonza, Pabllo Vittar, Anitta\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5217tPOJfhVUY8q9TCKHO1\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-11\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 1.0, \"Danceability\": 0.655, \"Energy\": 0.726, \"Loudness\": -7.628, \"Speechiness\": 0.0796, \"Acousticness\": 0.334, \"Liveness\": 0.232, \"Tempo\": 160.064, \"Duration (ms)\": 150260.0, \"Valence\": 0.766, \"Chord\": \"A#/Bb\"}, {\"Index\": 591, \"Highest Charting Position\": 191, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-15--2021-01-22\", \"Song Name\": \"Buss It\", \"Streams\": 4915403, \"Artist\": \"Erica Banks\", \"Artist Followers\": 41551.0, \"Song ID\": \"25j0Sape7qZbq6ZPLFefTT\", \"Genre\": \"['trap queen']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2021-01-15--2021-01-22\", \"Popularity\": 72.0, \"Danceability\": 0.956, \"Energy\": 0.502, \"Loudness\": -5.995, \"Speechiness\": 0.213, \"Acousticness\": 0.0593, \"Liveness\": 0.238, \"Tempo\": 110.003, \"Duration (ms)\": 187000.0, \"Valence\": 0.795, \"Chord\": \"A\"}, {\"Index\": 592, \"Highest Charting Position\": 41, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Kings & Queens\", \"Streams\": 4855690, \"Artist\": \"Ava Max\", \"Artist Followers\": 3916979.0, \"Song ID\": \"7a53HqqArd4b9NF4XAmlbI\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 82.0, \"Danceability\": 0.637, \"Energy\": 0.69, \"Loudness\": -4.057, \"Speechiness\": 0.0405, \"Acousticness\": 0.00786, \"Liveness\": 0.124, \"Tempo\": 129.857, \"Duration (ms)\": 162399.0, \"Valence\": 0.457, \"Chord\": \"C#/Db\"}, {\"Index\": 593, \"Highest Charting Position\": 6, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Lovesick Girls\", \"Streams\": 4796365, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"4Ws314Ylb27BVsvlZOy30C\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 75.0, \"Danceability\": 0.654, \"Energy\": 0.707, \"Loudness\": -5.661, \"Speechiness\": 0.0664, \"Acousticness\": 0.00559, \"Liveness\": 0.0873, \"Tempo\": 127.97, \"Duration (ms)\": 194765.0, \"Valence\": 0.448, \"Chord\": \"F#/Gb\"}, {\"Index\": 594, \"Highest Charting Position\": 17, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Caramelo\", \"Streams\": 4790233, \"Artist\": \"Ozuna\", \"Artist Followers\": 29238936.0, \"Song ID\": \"3gD4J3RUHy4OUuZ3qAiaiG\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-06-11\", \"Weeks Charted\": \"2021-01-15--2021-01-22\\n2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 74.0, \"Danceability\": 0.728, \"Energy\": 0.806, \"Loudness\": -3.766, \"Speechiness\": 0.0623, \"Acousticness\": 0.0531, \"Liveness\": 0.153, \"Tempo\": 168.084, \"Duration (ms)\": 217547.0, \"Valence\": 0.698, \"Chord\": \"F#/Gb\"}, {\"Index\": 595, \"Highest Charting Position\": 67, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Deep End\", \"Streams\": 5622565, \"Artist\": \"Foushe\\u00e9\", \"Artist Followers\": 411262.0, \"Song ID\": \"2AlYncTpVHKwHb55F9lF6O\", \"Genre\": \"['brooklyn drill', 'nyc rap']\", \"Release Date\": \"2020-06-05\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 72.0, \"Danceability\": 0.868, \"Energy\": 0.479, \"Loudness\": -6.687, \"Speechiness\": 0.445, \"Acousticness\": 0.703, \"Liveness\": 0.102, \"Tempo\": 133.928, \"Duration (ms)\": 115200.0, \"Valence\": 0.776, \"Chord\": \"E\"}, {\"Index\": 596, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Sand In My Boots\", \"Streams\": 5446609, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"0uRrG2jRR5tuifsYIJHEao\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\", \"Popularity\": 75.0, \"Danceability\": 0.403, \"Energy\": 0.537, \"Loudness\": -6.628, \"Speechiness\": 0.031, \"Acousticness\": 0.59, \"Liveness\": 0.112, \"Tempo\": 69.877, \"Duration (ms)\": 202133.0, \"Valence\": 0.414, \"Chord\": \"D#/Eb\"}, {\"Index\": 597, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"865\", \"Streams\": 5160123, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"0sKEilrw1GrBlG6qsTCrP4\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\", \"Popularity\": 70.0, \"Danceability\": 0.532, \"Energy\": 0.584, \"Loudness\": -5.254, \"Speechiness\": 0.0248, \"Acousticness\": 0.723, \"Liveness\": 0.101, \"Tempo\": 88.003, \"Duration (ms)\": 190680.0, \"Valence\": 0.367, \"Chord\": \"G#/Ab\"}, {\"Index\": 598, \"Highest Charting Position\": 53, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"7 Summers\", \"Streams\": 5064504, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"4obHzpwGrjoTuZh2DItEMZ\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2020-09-11--2020-09-18\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 73.0, \"Danceability\": 0.466, \"Energy\": 0.786, \"Loudness\": -5.13, \"Speechiness\": 0.0328, \"Acousticness\": 0.417, \"Liveness\": 0.125, \"Tempo\": 203.903, \"Duration (ms)\": 210507.0, \"Valence\": 0.571, \"Chord\": \"C\"}, {\"Index\": 599, \"Highest Charting Position\": 21, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"HACIENDO QUE ME AMAS\", \"Streams\": 4935633, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"26QApq0cuO9brJigr0C0W4\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 78.0, \"Danceability\": 0.584, \"Energy\": 0.411, \"Loudness\": -7.147, \"Speechiness\": 0.0838, \"Acousticness\": 0.869, \"Liveness\": 0.0955, \"Tempo\": 169.934, \"Duration (ms)\": 217769.0, \"Valence\": 0.412, \"Chord\": \"A#/Bb\"}, {\"Index\": 600, \"Highest Charting Position\": 65, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"La Luz\", \"Streams\": 4906324, \"Artist\": \"Sech, J Balvin\", \"Artist Followers\": 8766508.0, \"Song ID\": \"5zj8WNkBrEzlI5FKeYV4ol\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-10-31\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 70.0, \"Danceability\": 0.665, \"Energy\": 0.697, \"Loudness\": -4.819, \"Speechiness\": 0.154, \"Acousticness\": 0.427, \"Liveness\": 0.599, \"Tempo\": 94.053, \"Duration (ms)\": 216747.0, \"Valence\": 0.556, \"Chord\": \"A\"}, {\"Index\": 601, \"Highest Charting Position\": 17, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"The Woo (feat. 50 Cent & Roddy Ricch)\", \"Streams\": 4892682, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"1H7KnK26kc1YyellpbINEn\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 79.0, \"Danceability\": 0.49, \"Energy\": 0.618, \"Loudness\": -5.655, \"Speechiness\": 0.104, \"Acousticness\": 0.0221, \"Liveness\": 0.259, \"Tempo\": 99.7, \"Duration (ms)\": 201600.0, \"Valence\": 0.286, \"Chord\": \"C#/Db\"}, {\"Index\": 602, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"More Than My Hometown\", \"Streams\": 4879971, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"5OELUCYgOHKFAvCERnAvfS\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\", \"Popularity\": 75.0, \"Danceability\": 0.62, \"Energy\": 0.869, \"Loudness\": -5.479, \"Speechiness\": 0.0462, \"Acousticness\": 0.615, \"Liveness\": 0.131, \"Tempo\": 126.019, \"Duration (ms)\": 216573.0, \"Valence\": 0.597, \"Chord\": \"F#/Gb\"}, {\"Index\": 603, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2021-01-08--2021-01-15\", \"Song Name\": \"Warning\", \"Streams\": 4860714, \"Artist\": \"Morgan Wallen\", \"Artist Followers\": 2147875.0, \"Song ID\": \"64SCQtbRtmO28ks1QhS3w5\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2021-01-08\", \"Weeks Charted\": \"2021-01-08--2021-01-15\", \"Popularity\": 68.0, \"Danceability\": 0.633, \"Energy\": 0.664, \"Loudness\": -5.037, \"Speechiness\": 0.0294, \"Acousticness\": 0.46, \"Liveness\": 0.108, \"Tempo\": 115.058, \"Duration (ms)\": 156747.0, \"Valence\": 0.268, \"Chord\": \"A#/Bb\"}, {\"Index\": 604, \"Highest Charting Position\": 117, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Recairei - Ao Vivo\", \"Streams\": 4815342, \"Artist\": \"Os Bar\\u00f5es Da Pisadinha\", \"Artist Followers\": 4281787.0, \"Song ID\": \"71FrGl0XcpL3VId65tB5mg\", \"Genre\": \"['forro', 'piseiro']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-11-27--2020-12-04\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 69.0, \"Danceability\": 0.582, \"Energy\": 0.937, \"Loudness\": -2.118, \"Speechiness\": 0.0858, \"Acousticness\": 0.449, \"Liveness\": 0.684, \"Tempo\": 168.096, \"Duration (ms)\": 166838.0, \"Valence\": 0.939, \"Chord\": \"A#/Bb\"}, {\"Index\": 605, \"Highest Charting Position\": 5, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Ice Cream (with Selena Gomez)\", \"Streams\": 4812765, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"4JUPEh2DVSXFGExu4Uxevz\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 71.0, \"Danceability\": 0.79, \"Energy\": 0.701, \"Loudness\": -4.81, \"Speechiness\": 0.365, \"Acousticness\": 0.0317, \"Liveness\": 0.0311, \"Tempo\": 159.972, \"Duration (ms)\": 177813.0, \"Valence\": 0.91, \"Chord\": \"A\"}, {\"Index\": 606, \"Highest Charting Position\": 22, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Be Kind (with Halsey)\", \"Streams\": 4790427, \"Artist\": \"Marshmello\", \"Artist Followers\": 31552500.0, \"Song ID\": \"3Z8FwOEN59mRMxDCtb8N0A\", \"Genre\": \"['brostep', 'edm', 'pop', 'pop dance', 'progressive electro house']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 80.0, \"Danceability\": 0.63, \"Energy\": 0.633, \"Loudness\": -7.088, \"Speechiness\": 0.0457, \"Acousticness\": 0.00776, \"Liveness\": 0.0541, \"Tempo\": 93.995, \"Duration (ms)\": 172762.0, \"Valence\": 0.452, \"Chord\": \"E\"}, {\"Index\": 607, \"Highest Charting Position\": 76, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Fever\", \"Streams\": 4769618, \"Artist\": \"Dua Lipa, Ang\\u00e8le\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3wJVBz7gvGTwTWVAxFa6ny\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-10-29\", \"Weeks Charted\": \"2021-01-08--2021-01-15\\n2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 73.0, \"Danceability\": 0.868, \"Energy\": 0.693, \"Loudness\": -7.052, \"Speechiness\": 0.181, \"Acousticness\": 0.0597, \"Liveness\": 0.106, \"Tempo\": 114.999, \"Duration (ms)\": 156911.0, \"Valence\": 0.396, \"Chord\": \"F#/Gb\"}, {\"Index\": 608, \"Highest Charting Position\": 141, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Angst\", \"Streams\": 5317174, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"5yUzqd3H7cmJ1no6B4uTzu\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2021-01-01\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.599, \"Energy\": 0.79, \"Loudness\": -4.352, \"Speechiness\": 0.386, \"Acousticness\": 0.0213, \"Liveness\": 0.0778, \"Tempo\": 100.119, \"Duration (ms)\": 201501.0, \"Valence\": 0.528, \"Chord\": \"A\"}, {\"Index\": 609, \"Highest Charting Position\": 15, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"no body, no crime (feat. HAIM)\", \"Streams\": 4986214, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3RaT22zZsxVYxxKR7TAaYF\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 68.0, \"Danceability\": 0.546, \"Energy\": 0.613, \"Loudness\": -7.589, \"Speechiness\": 0.0264, \"Acousticness\": 0.418, \"Liveness\": 0.103, \"Tempo\": 79.015, \"Duration (ms)\": 215627.0, \"Valence\": 0.535, \"Chord\": \"G\"}, {\"Index\": 610, \"Highest Charting Position\": 13, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Sunday Best\", \"Streams\": 4858392, \"Artist\": \"Surfaces\", \"Artist Followers\": 724903.0, \"Song ID\": \"1Cv1YLb4q0RzL6pybtaMLo\", \"Genre\": \"['bedroom soul', 'pop']\", \"Release Date\": \"2019-01-06\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 80.0, \"Danceability\": 0.878, \"Energy\": 0.525, \"Loudness\": -6.832, \"Speechiness\": 0.0578, \"Acousticness\": 0.183, \"Liveness\": 0.0714, \"Tempo\": 112.022, \"Duration (ms)\": 158571.0, \"Valence\": 0.694, \"Chord\": \"F\"}, {\"Index\": 611, \"Highest Charting Position\": 171, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2021-01-01--2021-01-08\", \"Song Name\": \"Amor ou o Litr\\u00e3o\", \"Streams\": 4848222, \"Artist\": \"Petter Ferraz, Menor Nico\", \"Artist Followers\": 14122.0, \"Song ID\": \"7qmnP8Woc47dLSrMD5MxL1\", \"Genre\": \"[]\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 66.0, \"Danceability\": 0.934, \"Energy\": 0.707, \"Loudness\": -4.214, \"Speechiness\": 0.0646, \"Acousticness\": 0.437, \"Liveness\": 0.0628, \"Tempo\": 138.023, \"Duration (ms)\": 173913.0, \"Valence\": 0.961, \"Chord\": \"A\"}, {\"Index\": 612, \"Highest Charting Position\": 66, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Happier\", \"Streams\": 4655272, \"Artist\": \"Marshmello, Bastille\", \"Artist Followers\": 31552500.0, \"Song ID\": \"2dpaYNEQHiRxtZbfNsse99\", \"Genre\": \"['brostep', 'edm', 'pop', 'pop dance', 'progressive electro house']\", \"Release Date\": \"2018-08-17\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-11-13--2020-11-20\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.687, \"Energy\": 0.792, \"Loudness\": -2.749, \"Speechiness\": 0.0452, \"Acousticness\": 0.191, \"Liveness\": 0.167, \"Tempo\": 100.015, \"Duration (ms)\": 214290.0, \"Valence\": 0.671, \"Chord\": \"F\"}, {\"Index\": 613, \"Highest Charting Position\": 138, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Don't Stop Me Now - Remastered 2011\", \"Streams\": 4630572, \"Artist\": \"Queen\", \"Artist Followers\": 35910149.0, \"Song ID\": \"7hQJA50XrCWABAu5v6QZ4i\", \"Genre\": \"['classic rock', 'glam rock', 'rock']\", \"Release Date\": \"1978-11-10\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-15--2020-05-22\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.563, \"Energy\": 0.865, \"Loudness\": -5.277, \"Speechiness\": 0.16, \"Acousticness\": 0.0472, \"Liveness\": 0.77, \"Tempo\": 156.271, \"Duration (ms)\": 209413.0, \"Valence\": 0.601, \"Chord\": \"F\"}, {\"Index\": 614, \"Highest Charting Position\": 61, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Azul\", \"Streams\": 4606011, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"2lCkncy6bIB0LTMT7kvrD1\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 77.0, \"Danceability\": 0.843, \"Energy\": 0.836, \"Loudness\": -2.474, \"Speechiness\": 0.0695, \"Acousticness\": 0.0816, \"Liveness\": 0.0532, \"Tempo\": 94.018, \"Duration (ms)\": 205933.0, \"Valence\": 0.65, \"Chord\": \"B\"}, {\"Index\": 615, \"Highest Charting Position\": 183, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Basta Voc\\u00ea Me Ligar - Ao Vivo\", \"Streams\": 4580123, \"Artist\": \"Os Bar\\u00f5es Da Pisadinha, Xand Avi\\u00e3o\", \"Artist Followers\": 4281787.0, \"Song ID\": \"3AV1KI22k1jGMz792lDrj1\", \"Genre\": \"['forro', 'piseiro']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\", \"Popularity\": 68.0, \"Danceability\": 0.599, \"Energy\": 0.914, \"Loudness\": -2.415, \"Speechiness\": 0.0629, \"Acousticness\": 0.5, \"Liveness\": 0.694, \"Tempo\": 168.008, \"Duration (ms)\": 182977.0, \"Valence\": 0.831, \"Chord\": \"F\"}, {\"Index\": 616, \"Highest Charting Position\": 49, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Tequila Shots\", \"Streams\": 4540781, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"30KctD1WsHKTIYczXjip5a\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 74.0, \"Danceability\": 0.712, \"Energy\": 0.556, \"Loudness\": -7.214, \"Speechiness\": 0.0531, \"Acousticness\": 0.084, \"Liveness\": 0.527, \"Tempo\": 90.494, \"Duration (ms)\": 193293.0, \"Valence\": 0.22, \"Chord\": \"F\"}, {\"Index\": 617, \"Highest Charting Position\": 27, \"Number of Times Charted\": 45, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Lose Control\", \"Streams\": 4516053, \"Artist\": \"MEDUZA, Becky Hill, Goodboys\", \"Artist Followers\": 441714.0, \"Song ID\": \"7CHi4DtfK4heMlQaudCuHK\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop house', 'tropical house']\", \"Release Date\": \"2019-10-11\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.598, \"Energy\": 0.526, \"Loudness\": -8.659, \"Speechiness\": 0.0415, \"Acousticness\": 0.129, \"Liveness\": 0.14, \"Tempo\": 123.935, \"Duration (ms)\": 168387.0, \"Valence\": 0.529, \"Chord\": \"A#/Bb\"}, {\"Index\": 618, \"Highest Charting Position\": 68, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"I CAN'T STOP ME\", \"Streams\": 4504304, \"Artist\": \"TWICE\", \"Artist Followers\": 9998991.0, \"Song ID\": \"37ZtpRBkHcaq6hHy0X98zn\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-26\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 76.0, \"Danceability\": 0.657, \"Energy\": 0.88, \"Loudness\": -3.672, \"Speechiness\": 0.102, \"Acousticness\": 0.121, \"Liveness\": 0.463, \"Tempo\": 150.084, \"Duration (ms)\": 205493.0, \"Valence\": 0.769, \"Chord\": \"A#/Bb\"}, {\"Index\": 619, \"Highest Charting Position\": 158, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"E-GIRLS ARE RUINING MY LIFE!\", \"Streams\": 4488125, \"Artist\": \"CORPSE, Savage Ga$p\", \"Artist Followers\": 1777797.0, \"Song ID\": \"7bCfHiRcfUjG0YVVNUL7Ve\", \"Genre\": \"['dream smp', 'viral rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2021-01-01--2021-01-08\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 77.0, \"Danceability\": 0.614, \"Energy\": 0.937, \"Loudness\": -7.443, \"Speechiness\": 0.115, \"Acousticness\": 0.00161, \"Liveness\": 0.103, \"Tempo\": 84.98, \"Duration (ms)\": 105176.0, \"Valence\": 0.386, \"Chord\": \"C#/Db\"}, {\"Index\": 620, \"Highest Charting Position\": 1, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"All I Want for Christmas Is You\", \"Streams\": 23235257, \"Artist\": \"Mariah Carey\", \"Artist Followers\": 6931357.0, \"Song ID\": \"0bYg9bo50gSsH3LtXe2SQn\", \"Genre\": \"['dance pop', 'pop', 'r&b', 'urban contemporary']\", \"Release Date\": \"1994-11-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2019-12-27--2020-01-03\", \"Popularity\": 65.0, \"Danceability\": 0.336, \"Energy\": 0.627, \"Loudness\": -7.463, \"Speechiness\": 0.0384, \"Acousticness\": 0.164, \"Liveness\": 0.0708, \"Tempo\": 150.273, \"Duration (ms)\": 241107.0, \"Valence\": 0.35, \"Chord\": \"G\"}, {\"Index\": 621, \"Highest Charting Position\": 2, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Last Christmas\", \"Streams\": 20709328, \"Artist\": \"Wham!\", \"Artist Followers\": 1631876.0, \"Song ID\": \"2FRnf9qhLbvw8fu4IBXx78\", \"Genre\": \"['disco', 'europop', 'new romantic', 'new wave', 'new wave pop', 'soft rock', 'synthpop']\", \"Release Date\": \"1984-11-29\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 63.0, \"Danceability\": 0.735, \"Energy\": 0.478, \"Loudness\": -12.472, \"Speechiness\": 0.0293, \"Acousticness\": 0.189, \"Liveness\": 0.355, \"Tempo\": 107.682, \"Duration (ms)\": 262960.0, \"Valence\": 0.947, \"Chord\": \"D\"}, {\"Index\": 622, \"Highest Charting Position\": 3, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Tell Me\", \"Streams\": 16657592, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"0lizgQ7Qw35od7CYaoMBZb\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2014-11-24\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 61.0, \"Danceability\": 0.525, \"Energy\": 0.621, \"Loudness\": -7.364, \"Speechiness\": 0.116, \"Acousticness\": 0.0489, \"Liveness\": 0.294, \"Tempo\": 191.9, \"Duration (ms)\": 204093.0, \"Valence\": 0.591, \"Chord\": \"G\"}, {\"Index\": 623, \"Highest Charting Position\": 5, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Rockin' Around The Christmas Tree\", \"Streams\": 16613649, \"Artist\": \"Brenda Lee\", \"Artist Followers\": 222627.0, \"Song ID\": \"2EjXfH91m7f8HiJN1yQg97\", \"Genre\": \"['adult standards', 'brill building pop', 'easy listening', 'lounge', 'rockabilly', 'vocal jazz']\", \"Release Date\": \"1964-10-19\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 58.0, \"Danceability\": 0.589, \"Energy\": 0.472, \"Loudness\": -8.749, \"Speechiness\": 0.0502, \"Acousticness\": 0.614, \"Liveness\": 0.505, \"Tempo\": 67.196, \"Duration (ms)\": 126267.0, \"Valence\": 0.898, \"Chord\": \"G#/Ab\"}, {\"Index\": 624, \"Highest Charting Position\": 7, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Jingle Bell Rock\", \"Streams\": 16527404, \"Artist\": \"Bobby Helms\", \"Artist Followers\": 20637.0, \"Song ID\": \"7vQbuQcyTflfCIOu3Uzzya\", \"Genre\": \"[]\", \"Release Date\": \"1957-12-02\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 56.0, \"Danceability\": 0.754, \"Energy\": 0.424, \"Loudness\": -8.463, \"Speechiness\": 0.0363, \"Acousticness\": 0.643, \"Liveness\": 0.0652, \"Tempo\": 119.705, \"Duration (ms)\": 130973.0, \"Valence\": 0.806, \"Chord\": \"D\"}, {\"Index\": 625, \"Highest Charting Position\": 6, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"It's Beginning to Look a Lot like Christmas\", \"Streams\": 15424001, \"Artist\": \"Michael Bubl\\u00e9\", \"Artist Followers\": 4702232.0, \"Song ID\": \"5a1iz510sv2W9Dt1MvFd5R\", \"Genre\": \"['adult standards', 'canadian pop', 'jazz pop', 'lounge']\", \"Release Date\": \"2012-11-09\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 55.0, \"Danceability\": 0.339, \"Energy\": 0.214, \"Loudness\": -11.714, \"Speechiness\": 0.0375, \"Acousticness\": 0.908, \"Liveness\": 0.341, \"Tempo\": 94.775, \"Duration (ms)\": 206640.0, \"Valence\": 0.363, \"Chord\": \"E\"}, {\"Index\": 626, \"Highest Charting Position\": 8, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"It's the Most Wonderful Time of the Year\", \"Streams\": 14582001, \"Artist\": \"Andy Williams\", \"Artist Followers\": 369548.0, \"Song ID\": \"5hslUAKq9I9CG2bAulFkHN\", \"Genre\": \"['adult standards', 'brill building pop', 'easy listening', 'lounge', 'mellow gold', 'vocal jazz']\", \"Release Date\": \"1963-11-24\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 55.0, \"Danceability\": 0.24, \"Energy\": 0.598, \"Loudness\": -8.435, \"Speechiness\": 0.0369, \"Acousticness\": 0.766, \"Liveness\": 0.117, \"Tempo\": 201.629, \"Duration (ms)\": 151933.0, \"Valence\": 0.776, \"Chord\": \"G\"}, {\"Index\": 627, \"Highest Charting Position\": 9, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Underneath the Tree\", \"Streams\": 12266990, \"Artist\": \"Kelly Clarkson\", \"Artist Followers\": 7869617.0, \"Song ID\": \"3YZE5qDV7u1ZD1gZc47ZeR\", \"Genre\": \"['dance pop', 'neo mellow', 'pop', 'pop rock', 'post-teen pop', 'talent show']\", \"Release Date\": \"2013-10-29\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\", \"Popularity\": 49.0, \"Danceability\": 0.509, \"Energy\": 0.812, \"Loudness\": -5.439, \"Speechiness\": 0.0537, \"Acousticness\": 0.00128, \"Liveness\": 0.214, \"Tempo\": 159.878, \"Duration (ms)\": 229640.0, \"Valence\": 0.689, \"Chord\": \"G#/Ab\"}, {\"Index\": 628, \"Highest Charting Position\": 14, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Feliz Navidad\", \"Streams\": 11664490, \"Artist\": \"Jos\\u00e9 Feliciano\", \"Artist Followers\": 239129.0, \"Song ID\": \"0oPdaY4dXtc3ZsaG17V972\", \"Genre\": \"['latin pop', 'puerto rican pop']\", \"Release Date\": \"2002-09-24\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 49.0, \"Danceability\": 0.513, \"Energy\": 0.831, \"Loudness\": -9.004, \"Speechiness\": 0.0383, \"Acousticness\": 0.55, \"Liveness\": 0.336, \"Tempo\": 148.837, \"Duration (ms)\": 182067.0, \"Valence\": 0.963, \"Chord\": \"D\"}, {\"Index\": 629, \"Highest Charting Position\": 11, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Let It Snow! Let It Snow! Let It Snow!\", \"Streams\": 10884855, \"Artist\": \"Dean Martin\", \"Artist Followers\": 1139096.0, \"Song ID\": \"2uFaJJtFpPDc5Pa95XzTvg\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"1959-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 54.0, \"Danceability\": 0.451, \"Energy\": 0.24, \"Loudness\": -14.014, \"Speechiness\": 0.0351, \"Acousticness\": 0.912, \"Liveness\": 0.175, \"Tempo\": 134.009, \"Duration (ms)\": 117147.0, \"Valence\": 0.701, \"Chord\": \"C#/Db\"}, {\"Index\": 630, \"Highest Charting Position\": 19, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Let It Snow! Let It Snow! Let It Snow! (with The B. Swanson Quartet)\", \"Streams\": 10787165, \"Artist\": \"Frank Sinatra\", \"Artist Followers\": 4953667.0, \"Song ID\": \"4kKdvXD0ez7jp1296JmAts\", \"Genre\": \"['adult standards', 'easy listening', 'lounge']\", \"Release Date\": \"1994-11-08\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 53.0, \"Danceability\": 0.652, \"Energy\": 0.259, \"Loudness\": -13.336, \"Speechiness\": 0.0595, \"Acousticness\": 0.903, \"Liveness\": 0.362, \"Tempo\": 142.169, \"Duration (ms)\": 155453.0, \"Valence\": 0.836, \"Chord\": \"D\"}, {\"Index\": 631, \"Highest Charting Position\": 15, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Mistletoe\", \"Streams\": 10609206, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"7xapw9Oy21WpfEcib2ErSA\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2011-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 59.0, \"Danceability\": 0.657, \"Energy\": 0.56, \"Loudness\": -9.049, \"Speechiness\": 0.0467, \"Acousticness\": 0.498, \"Liveness\": 0.0794, \"Tempo\": 161.993, \"Duration (ms)\": 182947.0, \"Valence\": 0.854, \"Chord\": \"F#/Gb\"}, {\"Index\": 632, \"Highest Charting Position\": 16, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Sleigh Ride\", \"Streams\": 10508459, \"Artist\": \"The Ronettes\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5ASM6Qjiav2xPe7gRkQMsQ\", \"Genre\": \"[]\", \"Release Date\": \"1963\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 50.0, \"Danceability\": 0.529, \"Energy\": 0.772, \"Loudness\": -7.013, \"Speechiness\": 0.0287, \"Acousticness\": 0.403, \"Liveness\": 0.316, \"Tempo\": 91.751, \"Duration (ms)\": 181267.0, \"Valence\": 0.853, \"Chord\": \"D\"}, {\"Index\": 633, \"Highest Charting Position\": 17, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Do They Know It's Christmas? - 1984 Version\", \"Streams\": 10476212, \"Artist\": \"Band Aid\", \"Artist Followers\": 4883.0, \"Song ID\": \"0247StOpd3AkeBQzANX4Zf\", \"Genre\": \"['musical advocacy']\", \"Release Date\": \"2004-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 51.0, \"Danceability\": 0.599, \"Energy\": 0.642, \"Loudness\": -6.936, \"Speechiness\": 0.0363, \"Acousticness\": 0.164, \"Liveness\": 0.0992, \"Tempo\": 115.412, \"Duration (ms)\": 222533.0, \"Valence\": 0.349, \"Chord\": \"C\"}, {\"Index\": 634, \"Highest Charting Position\": 23, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Wonderful Christmastime - Edited Version / Remastered 2011\", \"Streams\": 9882989, \"Artist\": \"Paul McCartney\", \"Artist Followers\": 3609658.0, \"Song ID\": \"1SV1fxF65n9NhRHp3KlBuu\", \"Genre\": \"['album rock', 'art rock', 'beatlesque', 'classic rock', 'mellow gold', 'rock', 'soft rock']\", \"Release Date\": \"1980-05-16\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 51.0, \"Danceability\": 0.774, \"Energy\": 0.511, \"Loudness\": -8.914, \"Speechiness\": 0.0319, \"Acousticness\": 0.322, \"Liveness\": 0.0672, \"Tempo\": 94.736, \"Duration (ms)\": 227653.0, \"Valence\": 0.771, \"Chord\": \"B\"}, {\"Index\": 635, \"Highest Charting Position\": 21, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Holly Jolly Christmas\", \"Streams\": 9852792, \"Artist\": \"Michael Bubl\\u00e9\", \"Artist Followers\": 4702232.0, \"Song ID\": \"5PuKlCjfEVIXl0ZBp5ZW9g\", \"Genre\": \"['adult standards', 'canadian pop', 'jazz pop', 'lounge']\", \"Release Date\": \"2012-11-09\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 48.0, \"Danceability\": 0.647, \"Energy\": 0.465, \"Loudness\": -8.308, \"Speechiness\": 0.0428, \"Acousticness\": 0.865, \"Liveness\": 0.0882, \"Tempo\": 151.251, \"Duration (ms)\": 119787.0, \"Valence\": 0.699, \"Chord\": \"G\"}, {\"Index\": 636, \"Highest Charting Position\": 24, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Happy Xmas (War Is Over) - Remastered 2010\", \"Streams\": 9509781, \"Artist\": \"John Lennon, Yoko Ono\", \"Artist Followers\": 4313100.0, \"Song ID\": \"27RYrbL6S02LNVhDWVl38b\", \"Genre\": \"['album rock', 'art rock', 'beatlesque', 'classic rock', 'folk rock', 'mellow gold', 'rock']\", \"Release Date\": \"2010-10-05\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 53.0, \"Danceability\": 0.321, \"Energy\": 0.64, \"Loudness\": -10.023, \"Speechiness\": 0.0324, \"Acousticness\": 0.28, \"Liveness\": 0.718, \"Tempo\": 146.172, \"Duration (ms)\": 214333.0, \"Valence\": 0.414, \"Chord\": \"D\"}, {\"Index\": 637, \"Highest Charting Position\": 22, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Driving Home for Christmas - 2019 Remaster\", \"Streams\": 8804531, \"Artist\": \"Chris Rea\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 638, \"Highest Charting Position\": 32, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"The Christmas Song (Merry Christmas To You)\", \"Streams\": 8478518, \"Artist\": \"Nat King Cole\", \"Artist Followers\": 1634288.0, \"Song ID\": \"4PS1e8f2LvuTFgUs1Cn3ON\", \"Genre\": \"['adult standards', 'lounge', 'soul', 'vocal jazz']\", \"Release Date\": \"1962\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 53.0, \"Danceability\": 0.319, \"Energy\": 0.21, \"Loudness\": -15.231, \"Speechiness\": 0.0341, \"Acousticness\": 0.92, \"Liveness\": 0.138, \"Tempo\": 78.696, \"Duration (ms)\": 192160.0, \"Valence\": 0.209, \"Chord\": \"C#/Db\"}, {\"Index\": 639, \"Highest Charting Position\": 39, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"White Christmas\", \"Streams\": 7045348, \"Artist\": \"Bing Crosby, Ken Darby Singers, John Scott Trotter & His Orchestra\", \"Artist Followers\": 359973.0, \"Song ID\": \"4so0Wek9Ig1p6CRCHuINwW\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'swing', 'vocal jazz']\", \"Release Date\": \"1942-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 51.0, \"Danceability\": 0.317, \"Energy\": 0.158, \"Loudness\": -16.485, \"Speechiness\": 0.0381, \"Acousticness\": 0.673, \"Liveness\": 0.338, \"Tempo\": 130.503, \"Duration (ms)\": 177480.0, \"Valence\": 0.247, \"Chord\": \"A\"}, {\"Index\": 640, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Slay3r\", \"Streams\": 6912271, \"Artist\": \"Playboi Carti\", \"Artist Followers\": 4958353.0, \"Song ID\": \"1eMNW1HQjF1dbb4GtnmpaX\", \"Genre\": \"['atl hip hop', 'plugg', 'rap', 'trap']\", \"Release Date\": \"2020-12-25\", \"Weeks Charted\": \"2020-12-25--2021-01-01\", \"Popularity\": 63.0, \"Danceability\": 0.885, \"Energy\": 0.661, \"Loudness\": -5.062, \"Speechiness\": 0.141, \"Acousticness\": 0.165, \"Liveness\": 0.334, \"Tempo\": 140.028, \"Duration (ms)\": 164591.0, \"Valence\": 0.436, \"Chord\": \"E\"}, {\"Index\": 641, \"Highest Charting Position\": 42, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"A Holly Jolly Christmas - Single Version\", \"Streams\": 6716353, \"Artist\": \"Burl Ives\", \"Artist Followers\": 58479.0, \"Song ID\": \"77khP2fIVhSW23NwxrRluh\", \"Genre\": \"['adult standards', 'american folk revival']\", \"Release Date\": \"1965-01-01\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 49.0, \"Danceability\": 0.683, \"Energy\": 0.375, \"Loudness\": -13.056, \"Speechiness\": 0.0303, \"Acousticness\": 0.579, \"Liveness\": 0.076, \"Tempo\": 140.467, \"Duration (ms)\": 135533.0, \"Valence\": 0.888, \"Chord\": \"C\"}, {\"Index\": 642, \"Highest Charting Position\": 47, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Fairytale of New York (feat. Kirsty MacColl)\", \"Streams\": 6404964, \"Artist\": \"The Pogues\", \"Artist Followers\": 382997.0, \"Song ID\": \"3VTNVsTTu05dmTsVFrmGpK\", \"Genre\": \"['celtic', 'celtic punk', 'celtic rock', 'folk punk', 'irish folk', 'punk']\", \"Release Date\": \"1988-09-05\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 55.0, \"Danceability\": 0.271, \"Energy\": 0.551, \"Loudness\": -7.48, \"Speechiness\": 0.0457, \"Acousticness\": 0.582, \"Liveness\": 0.256, \"Tempo\": 78.111, \"Duration (ms)\": 272467.0, \"Valence\": 0.428, \"Chord\": \"D\"}, {\"Index\": 643, \"Highest Charting Position\": 38, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Merry Christmas Everyone\", \"Streams\": 6052105, \"Artist\": \"Shakin' Stevens\", \"Artist Followers\": 99249.0, \"Song ID\": \"2TE4xW3ImvpltVU0cPcKUn\", \"Genre\": \"['classic uk pop', 'new wave pop', 'rock-and-roll', 'rockabilly', 'soft rock']\", \"Release Date\": \"1991-11-25\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 47.0, \"Danceability\": 0.534, \"Energy\": 0.904, \"Loudness\": -3.315, \"Speechiness\": 0.0369, \"Acousticness\": 0.129, \"Liveness\": 0.128, \"Tempo\": 202.899, \"Duration (ms)\": 220160.0, \"Valence\": 0.96, \"Chord\": \"A\"}, {\"Index\": 644, \"Highest Charting Position\": 62, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Blue Christmas\", \"Streams\": 6007011, \"Artist\": \"Elvis Presley\", \"Artist Followers\": 5698788.0, \"Song ID\": \"3QiAAp20rPC3dcAtKtMaqQ\", \"Genre\": \"['rock-and-roll', 'rockabilly']\", \"Release Date\": \"1957-10-15\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 49.0, \"Danceability\": 0.465, \"Energy\": 0.27, \"Loudness\": -16.661, \"Speechiness\": 0.0425, \"Acousticness\": 0.9, \"Liveness\": 0.145, \"Tempo\": 94.518, \"Duration (ms)\": 129173.0, \"Valence\": 0.58, \"Chord\": \"E\"}, {\"Index\": 645, \"Highest Charting Position\": 65, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Run Rudolph Run - Single Version\", \"Streams\": 5802508, \"Artist\": \"Chuck Berry\", \"Artist Followers\": 1251372.0, \"Song ID\": \"47CIT5hMphuMQkpeyfGQTL\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 0.0, \"Danceability\": 0.647, \"Energy\": 0.876, \"Loudness\": -5.662, \"Speechiness\": 0.185, \"Acousticness\": 0.881, \"Liveness\": 0.26, \"Tempo\": 151.925, \"Duration (ms)\": 162897.0, \"Valence\": 0.949, \"Chord\": \"A#/Bb\"}, {\"Index\": 646, \"Highest Charting Position\": 59, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Claus Is Coming To Town\", \"Streams\": 5801639, \"Artist\": \"The Jackson 5\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5Gz7EYD7JAmItA7FbhKgKb\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 0.0, \"Danceability\": 0.691, \"Energy\": 0.776, \"Loudness\": -4.177, \"Speechiness\": 0.0341, \"Acousticness\": 0.458, \"Liveness\": 0.33, \"Tempo\": 146.861, \"Duration (ms)\": 144080.0, \"Valence\": 0.961, \"Chord\": \"C\"}, {\"Index\": 647, \"Highest Charting Position\": 52, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Baby\", \"Streams\": 5687085, \"Artist\": \"Kylie Minogue\", \"Artist Followers\": 1324920.0, \"Song ID\": \"0cM5URUqqQTpJWonmdzF1J\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'electropop', 'eurodance', 'europop', 'new wave pop', 'pop']\", \"Release Date\": \"2010-11-30\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 42.0, \"Danceability\": 0.685, \"Energy\": 0.391, \"Loudness\": -7.183, \"Speechiness\": 0.0435, \"Acousticness\": 0.744, \"Liveness\": 0.142, \"Tempo\": 87.101, \"Duration (ms)\": 202547.0, \"Valence\": 0.443, \"Chord\": \"C#/Db\"}, {\"Index\": 648, \"Highest Charting Position\": 60, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"It's Beginning to Look a Lot Like Christmas (with Mitchell Ayres & His Orchestra)\", \"Streams\": 5422082, \"Artist\": \"Perry Como, The Fontane Sisters\", \"Artist Followers\": 336373.0, \"Song ID\": \"2pXpURmn6zC5ZYDMms6fwa\", \"Genre\": \"['adult standards', 'brill building pop', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"1999-08-20\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 49.0, \"Danceability\": 0.724, \"Energy\": 0.276, \"Loudness\": -12.25, \"Speechiness\": 0.0599, \"Acousticness\": 0.76, \"Liveness\": 0.116, \"Tempo\": 112.874, \"Duration (ms)\": 155933.0, \"Valence\": 0.718, \"Chord\": \"G\"}, {\"Index\": 649, \"Highest Charting Position\": 69, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas (Baby Please Come Home)\", \"Streams\": 5394054, \"Artist\": \"Darlene Love\", \"Artist Followers\": 1251372.0, \"Song ID\": \"46pF1zFimM582ss1PrMy68\", \"Genre\": \"[]\", \"Release Date\": \"1963\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-12-04--2020-12-11\", \"Popularity\": 45.0, \"Danceability\": 0.325, \"Energy\": 0.759, \"Loudness\": -7.146, \"Speechiness\": 0.053, \"Acousticness\": 0.395, \"Liveness\": 0.0773, \"Tempo\": 126.627, \"Duration (ms)\": 166453.0, \"Valence\": 0.36, \"Chord\": \"G#/Ab\"}, {\"Index\": 650, \"Highest Charting Position\": 66, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Step Into Christmas\", \"Streams\": 5353591, \"Artist\": \"Elton John\", \"Artist Followers\": 7504724.0, \"Song ID\": \"6sBWmE23q6xQHlnEZ8jYPT\", \"Genre\": \"['glam rock', 'mellow gold', 'piano rock']\", \"Release Date\": \"1973-10-05\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 43.0, \"Danceability\": 0.526, \"Energy\": 0.925, \"Loudness\": -5.584, \"Speechiness\": 0.0363, \"Acousticness\": 0.102, \"Liveness\": 0.305, \"Tempo\": 140.308, \"Duration (ms)\": 272394.0, \"Valence\": 0.819, \"Chord\": \"D\"}, {\"Index\": 651, \"Highest Charting Position\": 54, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Show Out (with Skepta & Pop Smoke)\", \"Streams\": 5209372, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"5CFJRZRq6sdKKtRwNPWbYv\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 76.0, \"Danceability\": 0.619, \"Energy\": 0.589, \"Loudness\": -6.531, \"Speechiness\": 0.124, \"Acousticness\": 0.43, \"Liveness\": 0.378, \"Tempo\": 143.896, \"Duration (ms)\": 174960.0, \"Valence\": 0.158, \"Chord\": \"C#/Db\"}, {\"Index\": 652, \"Highest Charting Position\": 166, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Investe Em Mim\", \"Streams\": 5191001, \"Artist\": \"Jonas Esticado\", \"Artist Followers\": 1293055.0, \"Song ID\": \"15k1TDabqSEmyXOwMq9RM7\", \"Genre\": \"['forro', 'sertanejo', 'sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-12-25--2021-01-01\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 72.0, \"Danceability\": 0.632, \"Energy\": 0.953, \"Loudness\": -1.283, \"Speechiness\": 0.0325, \"Acousticness\": 0.317, \"Liveness\": 0.125, \"Tempo\": 160.061, \"Duration (ms)\": 186533.0, \"Valence\": 0.798, \"Chord\": \"A\"}, {\"Index\": 653, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-25--2021-01-01\", \"Song Name\": \"Lance Individual\", \"Streams\": 5152906, \"Artist\": \"Jorge & Mateus\", \"Artist Followers\": 15019109.0, \"Song ID\": \"7GLWWrk1YlkPYqJK3ynIA0\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-12-25--2021-01-01\", \"Popularity\": 72.0, \"Danceability\": 0.752, \"Energy\": 0.62, \"Loudness\": -5.536, \"Speechiness\": 0.0509, \"Acousticness\": 0.309, \"Liveness\": 0.075, \"Tempo\": 117.399, \"Duration (ms)\": 164459.0, \"Valence\": 0.962, \"Chord\": \"F\"}, {\"Index\": 654, \"Highest Charting Position\": 71, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Jingle Bell Rock - Daryl's Version\", \"Streams\": 10522305, \"Artist\": \"Daryl Hall & John Oates\", \"Artist Followers\": 1549216.0, \"Song ID\": \"6pVW5LRWgeLaHudxauOTJU\", \"Genre\": \"['album rock', 'classic rock', 'mellow gold', 'rock', 'soft rock', 'yacht rock']\", \"Release Date\": \"1983-11-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 43.0, \"Danceability\": 0.666, \"Energy\": 0.841, \"Loudness\": -3.592, \"Speechiness\": 0.0312, \"Acousticness\": 0.613, \"Liveness\": 0.113, \"Tempo\": 128.706, \"Duration (ms)\": 126360.0, \"Valence\": 0.84, \"Chord\": \"D\"}, {\"Index\": 655, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Thank God It's Christmas - Non-Album Single\", \"Streams\": 10509961, \"Artist\": \"Queen\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 656, \"Highest Charting Position\": 74, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas Lights\", \"Streams\": 10455065, \"Artist\": \"Coldplay\", \"Artist Followers\": 31161671.0, \"Song ID\": \"4QVdnpSO5JGMFOEl6ys4RQ\", \"Genre\": \"['permanent wave', 'pop']\", \"Release Date\": \"2016-12-16\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 53.0, \"Danceability\": 0.295, \"Energy\": 0.496, \"Loudness\": -9.478, \"Speechiness\": 0.0327, \"Acousticness\": 0.207, \"Liveness\": 0.858, \"Tempo\": 132.062, \"Duration (ms)\": 268521.0, \"Valence\": 0.224, \"Chord\": \"G\"}, {\"Index\": 657, \"Highest Charting Position\": 83, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Have Yourself A Merry Little Christmas\", \"Streams\": 9548924, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"1Qi2wh8fFgDV7tl4Sj3f2K\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2014-12-05\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\", \"Popularity\": 46.0, \"Danceability\": 0.438, \"Energy\": 0.178, \"Loudness\": -9.402, \"Speechiness\": 0.0414, \"Acousticness\": 0.957, \"Liveness\": 0.316, \"Tempo\": 75.248, \"Duration (ms)\": 170964.0, \"Valence\": 0.344, \"Chord\": \"F\"}, {\"Index\": 658, \"Highest Charting Position\": 85, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa's Coming for Us\", \"Streams\": 9474711, \"Artist\": \"Sia\", \"Artist Followers\": 20528724.0, \"Song ID\": \"1N1ZpYUJc9fwrqk53FGgWv\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'pop']\", \"Release Date\": \"2018-11-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 49.0, \"Danceability\": 0.547, \"Energy\": 0.814, \"Loudness\": -6.191, \"Speechiness\": 0.12, \"Acousticness\": 0.0215, \"Liveness\": 0.0475, \"Tempo\": 92.986, \"Duration (ms)\": 205267.0, \"Valence\": 0.724, \"Chord\": \"C#/Db\"}, {\"Index\": 659, \"Highest Charting Position\": 86, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"My Only Wish (This Year)\", \"Streams\": 9457199, \"Artist\": \"Britney Spears\", \"Artist Followers\": 9470311.0, \"Song ID\": \"0YWUHZPJVg4iujddsJDwhM\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2000-11-14\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-04--2020-12-11\", \"Popularity\": 43.0, \"Danceability\": 0.669, \"Energy\": 0.843, \"Loudness\": -3.766, \"Speechiness\": 0.0268, \"Acousticness\": 0.169, \"Liveness\": 0.195, \"Tempo\": 147.08, \"Duration (ms)\": 255400.0, \"Valence\": 0.702, \"Chord\": \"C\"}, {\"Index\": 660, \"Highest Charting Position\": 89, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Baby, It's Cold Outside (feat. Meghan Trainor)\", \"Streams\": 9270017, \"Artist\": \"Brett Eldredge\", \"Artist Followers\": 1298537.0, \"Song ID\": \"5Q2P43CJra0uRAogjHyJDK\", \"Genre\": \"['contemporary country', 'country', 'country road', 'modern country rock']\", \"Release Date\": \"2016-10-28\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 44.0, \"Danceability\": 0.583, \"Energy\": 0.572, \"Loudness\": -4.776, \"Speechiness\": 0.0366, \"Acousticness\": 0.738, \"Liveness\": 0.266, \"Tempo\": 113.998, \"Duration (ms)\": 173560.0, \"Valence\": 0.684, \"Chord\": \"C#/Db\"}, {\"Index\": 661, \"Highest Charting Position\": 92, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Like It's Christmas\", \"Streams\": 9167304, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"1OjmlSFuzYflWjSMTCyTJv\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-04--2020-12-11\", \"Popularity\": 47.0, \"Danceability\": 0.725, \"Energy\": 0.571, \"Loudness\": -6.007, \"Speechiness\": 0.102, \"Acousticness\": 0.0183, \"Liveness\": 0.0519, \"Tempo\": 146.035, \"Duration (ms)\": 200880.0, \"Valence\": 0.61, \"Chord\": \"C#/Db\"}, {\"Index\": 662, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas Without You\", \"Streams\": 8813922, \"Artist\": \"Ava Max\", \"Artist Followers\": 3916979.0, \"Song ID\": \"1QLZKzC2pjP4ySf4ALrNhm\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-10-15\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 45.0, \"Danceability\": 0.654, \"Energy\": 0.596, \"Loudness\": -4.68, \"Speechiness\": 0.0458, \"Acousticness\": 0.424, \"Liveness\": 0.11, \"Tempo\": 118.078, \"Duration (ms)\": 169245.0, \"Valence\": 0.382, \"Chord\": \"C#/Db\"}, {\"Index\": 663, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"You Make It Feel Like Christmas (feat. Blake Shelton)\", \"Streams\": 8696354, \"Artist\": \"Gwen Stefani\", \"Artist Followers\": 4805333.0, \"Song ID\": \"2OQ6a4CfUeYskpTTgyawyJ\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'post-teen pop', 'urban contemporary']\", \"Release Date\": \"2017-10-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.635, \"Energy\": 0.87, \"Loudness\": -4.291, \"Speechiness\": 0.04, \"Acousticness\": 0.0156, \"Liveness\": 0.118, \"Tempo\": 93.0, \"Duration (ms)\": 156773.0, \"Valence\": 0.912, \"Chord\": \"D\"}, {\"Index\": 664, \"Highest Charting Position\": 107, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Gnat\", \"Streams\": 8614955, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"6cS9PmLky2NhLOhpIsUlow\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 70.0, \"Danceability\": 0.835, \"Energy\": 0.869, \"Loudness\": -4.582, \"Speechiness\": 0.27, \"Acousticness\": 0.248, \"Liveness\": 0.462, \"Tempo\": 140.945, \"Duration (ms)\": 224656.0, \"Valence\": 0.82, \"Chord\": \"A#/Bb\"}, {\"Index\": 665, \"Highest Charting Position\": 111, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Joy To The World\", \"Streams\": 8387899, \"Artist\": \"Nat King Cole\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5oWFPbd340pwiXKMO1CQRy\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 0.0, \"Danceability\": 0.59, \"Energy\": 0.305, \"Loudness\": -12.955, \"Speechiness\": 0.032, \"Acousticness\": 0.894, \"Liveness\": 0.14, \"Tempo\": 102.103, \"Duration (ms)\": 86760.0, \"Valence\": 0.545, \"Chord\": \"A#/Bb\"}, {\"Index\": 666, \"Highest Charting Position\": 117, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Claus Is Coming to Town\", \"Streams\": 8177832, \"Artist\": \"Michael Bubl\\u00e9\", \"Artist Followers\": 4702232.0, \"Song ID\": \"1RMDXedcRno6rDBCbNHDJf\", \"Genre\": \"['adult standards', 'canadian pop', 'jazz pop', 'lounge']\", \"Release Date\": \"2012-11-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.594, \"Energy\": 0.389, \"Loudness\": -7.109, \"Speechiness\": 0.0517, \"Acousticness\": 0.785, \"Liveness\": 0.0313, \"Tempo\": 122.331, \"Duration (ms)\": 171093.0, \"Valence\": 0.396, \"Chord\": \"A#/Bb\"}, {\"Index\": 667, \"Highest Charting Position\": 119, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Baby It's Cold Outside (duet with Michael Bubl\\u00e9)\", \"Streams\": 8160534, \"Artist\": \"Idina Menzel\", \"Artist Followers\": 353571.0, \"Song ID\": \"0Ie5uiv54KgCr7P4sYDTHl\", \"Genre\": \"['hollywood', 'show tunes']\", \"Release Date\": \"2014-10-10\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 47.0, \"Danceability\": 0.553, \"Energy\": 0.476, \"Loudness\": -8.869, \"Speechiness\": 0.0649, \"Acousticness\": 0.647, \"Liveness\": 0.281, \"Tempo\": 113.401, \"Duration (ms)\": 166147.0, \"Valence\": 0.558, \"Chord\": \"C\"}, {\"Index\": 668, \"Highest Charting Position\": 22, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"\\u2018tis the damn season\", \"Streams\": 8115520, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7dW84mWkdWE5a6lFWxJCBG\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.575, \"Energy\": 0.434, \"Loudness\": -8.193, \"Speechiness\": 0.0312, \"Acousticness\": 0.735, \"Liveness\": 0.105, \"Tempo\": 145.916, \"Duration (ms)\": 229840.0, \"Valence\": 0.348, \"Chord\": \"F\"}, {\"Index\": 669, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"I Saw Mommy Kissing Santa Claus\", \"Streams\": 8064361, \"Artist\": \"The Jackson 5\", \"Artist Followers\": 1151360.0, \"Song ID\": \"15sxLiiChE5dCW3Y756oas\", \"Genre\": \"['motown', 'soul']\", \"Release Date\": \"1970-10-15\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.583, \"Energy\": 0.712, \"Loudness\": -8.222, \"Speechiness\": 0.0538, \"Acousticness\": 0.263, \"Liveness\": 0.817, \"Tempo\": 128.897, \"Duration (ms)\": 181267.0, \"Valence\": 0.614, \"Chord\": \"D#/Eb\"}, {\"Index\": 670, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Baby (with Henri Ren\\u00e9 & His Orchestra)\", \"Streams\": 8022773, \"Artist\": \"Eartha Kitt, Henri Rene & His Orchestra\", \"Artist Followers\": 127251.0, \"Song ID\": \"1foCxQtxBweJtZmdxhEHVO\", \"Genre\": \"['adult standards', 'lounge', 'torch song', 'vocal jazz']\", \"Release Date\": \"2002\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.7, \"Energy\": 0.139, \"Loudness\": -12.346, \"Speechiness\": 0.0607, \"Acousticness\": 0.902, \"Liveness\": 0.185, \"Tempo\": 84.485, \"Duration (ms)\": 206067.0, \"Valence\": 0.49, \"Chord\": \"G#/Ab\"}, {\"Index\": 671, \"Highest Charting Position\": 127, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Carol of the Bells\", \"Streams\": 7993078, \"Artist\": \"Mykola Dmytrovych Leontovych, John Williams\", \"Artist Followers\": 1024868.0, \"Song ID\": \"4tHqQMWSqmL6YjXwsqthDI\", \"Genre\": \"['soundtrack']\", \"Release Date\": \"1990\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 51.0, \"Danceability\": 0.418, \"Energy\": 0.106, \"Loudness\": -22.507, \"Speechiness\": 0.0448, \"Acousticness\": 0.994, \"Liveness\": 0.179, \"Tempo\": 46.718, \"Duration (ms)\": 85267.0, \"Valence\": 0.8, \"Chord\": \"G#/Ab\"}, {\"Index\": 672, \"Highest Charting Position\": 19, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"gold rush\", \"Streams\": 7901968, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5BK0uqwY9DNfZ630STAEaq\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 70.0, \"Danceability\": 0.512, \"Energy\": 0.462, \"Loudness\": -10.491, \"Speechiness\": 0.0408, \"Acousticness\": 0.83, \"Liveness\": 0.121, \"Tempo\": 112.05, \"Duration (ms)\": 185320.0, \"Valence\": 0.353, \"Chord\": \"A\"}, {\"Index\": 673, \"Highest Charting Position\": 133, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"What Christmas Means To Me\", \"Streams\": 7792643, \"Artist\": \"Stevie Wonder\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6Wn9zkkbWdK42uXCcADkRq\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 0.0, \"Danceability\": 0.545, \"Energy\": 0.7, \"Loudness\": -6.961, \"Speechiness\": 0.0323, \"Acousticness\": 0.0982, \"Liveness\": 0.1, \"Tempo\": 83.506, \"Duration (ms)\": 148147.0, \"Valence\": 0.799, \"Chord\": \"F\"}, {\"Index\": 674, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"The Christmas Song (Shawn Mendes & Camila Cabello)\", \"Streams\": 7536851, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 33893352.0, \"Song ID\": \"0fwxmtpxpMmEMphmJbCAEx\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2020-12-07\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 42.0, \"Danceability\": 0.341, \"Energy\": 0.181, \"Loudness\": -12.073, \"Speechiness\": 0.0366, \"Acousticness\": 0.888, \"Liveness\": 0.137, \"Tempo\": 83.608, \"Duration (ms)\": 196254.0, \"Valence\": 0.212, \"Chord\": \"D\"}, {\"Index\": 675, \"Highest Charting Position\": 144, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Baby, It's Cold Outside\", \"Streams\": 7367482, \"Artist\": \"Dean Martin\", \"Artist Followers\": 1139096.0, \"Song ID\": \"4MrfQL4TYQXJBlZYpAHTuE\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"1959-01-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.469, \"Energy\": 0.196, \"Loudness\": -16.093, \"Speechiness\": 0.0571, \"Acousticness\": 0.882, \"Liveness\": 0.0513, \"Tempo\": 130.036, \"Duration (ms)\": 143733.0, \"Valence\": 0.537, \"Chord\": \"C\"}, {\"Index\": 676, \"Highest Charting Position\": 145, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Santa Claus Is Comin' to Town - Live at C.W. Post College, Greenvale, NY - December 1975\", \"Streams\": 7363913, \"Artist\": \"Bruce Springsteen\", \"Artist Followers\": 4224071.0, \"Song ID\": \"6s2wpWPFPAgKg2LXxi1Oee\", \"Genre\": \"['classic rock', 'heartland rock', 'mellow gold', 'permanent wave', 'rock', 'singer-songwriter']\", \"Release Date\": \"1981\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.357, \"Energy\": 0.668, \"Loudness\": -8.444, \"Speechiness\": 0.0479, \"Acousticness\": 0.362, \"Liveness\": 0.727, \"Tempo\": 139.986, \"Duration (ms)\": 267600.0, \"Valence\": 0.407, \"Chord\": \"C\"}, {\"Index\": 677, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"One More Sleep\", \"Streams\": 7350024, \"Artist\": \"Leona Lewis\", \"Artist Followers\": 2877234.0, \"Song ID\": \"78pn8k7RogKo2oxl0DyX6d\", \"Genre\": \"['british soul', 'dance pop', 'europop', 'pop', 'post-teen pop', 'talent show']\", \"Release Date\": \"2013-12-02\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 42.0, \"Danceability\": 0.638, \"Energy\": 0.813, \"Loudness\": -3.849, \"Speechiness\": 0.0362, \"Acousticness\": 0.464, \"Liveness\": 0.344, \"Tempo\": 112.986, \"Duration (ms)\": 239587.0, \"Valence\": 0.754, \"Chord\": \"B\"}, {\"Index\": 678, \"Highest Charting Position\": 149, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Little Saint Nick - 1991 Remix\", \"Streams\": 7301381, \"Artist\": \"The Beach Boys\", \"Artist Followers\": 1251372.0, \"Song ID\": \"63Lk6VuXdj7S58R3wLdv9r\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 0.0, \"Danceability\": 0.602, \"Energy\": 0.553, \"Loudness\": -9.336, \"Speechiness\": 0.0328, \"Acousticness\": 0.108, \"Liveness\": 0.0512, \"Tempo\": 130.594, \"Duration (ms)\": 118840.0, \"Valence\": 0.971, \"Chord\": \"B\"}, {\"Index\": 679, \"Highest Charting Position\": 150, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Naughty List (with Dixie)\", \"Streams\": 7299201, \"Artist\": \"Liam Payne\", \"Artist Followers\": 8037861.0, \"Song ID\": \"2Y0ktCGrGoGcQFXsGztvhi\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 51.0, \"Danceability\": 0.619, \"Energy\": 0.771, \"Loudness\": -2.204, \"Speechiness\": 0.0601, \"Acousticness\": 0.0318, \"Liveness\": 0.114, \"Tempo\": 81.966, \"Duration (ms)\": 154747.0, \"Valence\": 0.704, \"Chord\": \"A\"}, {\"Index\": 680, \"Highest Charting Position\": 152, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"I'll Be Home\", \"Streams\": 7281773, \"Artist\": \"Meghan Trainor\", \"Artist Followers\": 10606572.0, \"Song ID\": \"0lTurWECr2XL607eJAj1A3\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2015-01-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 45.0, \"Danceability\": 0.542, \"Energy\": 0.37, \"Loudness\": -7.779, \"Speechiness\": 0.0257, \"Acousticness\": 0.318, \"Liveness\": 0.108, \"Tempo\": 84.796, \"Duration (ms)\": 219653.0, \"Valence\": 0.289, \"Chord\": \"D\"}, {\"Index\": 681, \"Highest Charting Position\": 156, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Rudolph The Red-Nosed Reindeer\", \"Streams\": 7227612, \"Artist\": \"Dean Martin\", \"Artist Followers\": 1139096.0, \"Song ID\": \"2L9QLAhrvtP4EYg1lY0Tnw\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"1959-01-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.478, \"Energy\": 0.201, \"Loudness\": -16.768, \"Speechiness\": 0.0332, \"Acousticness\": 0.919, \"Liveness\": 0.0854, \"Tempo\": 136.471, \"Duration (ms)\": 135760.0, \"Valence\": 0.857, \"Chord\": \"G\"}, {\"Index\": 682, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Mistletoe And Holly - Remastered 1999\", \"Streams\": 7225080, \"Artist\": \"Frank Sinatra\", \"Artist Followers\": 4953667.0, \"Song ID\": \"7faDzZnZYqTyYThx2sbHVQ\", \"Genre\": \"['adult standards', 'easy listening', 'lounge']\", \"Release Date\": \"1957-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 38.0, \"Danceability\": 0.607, \"Energy\": 0.103, \"Loudness\": -14.405, \"Speechiness\": 0.0404, \"Acousticness\": 0.804, \"Liveness\": 0.076, \"Tempo\": 110.378, \"Duration (ms)\": 136427.0, \"Valence\": 0.341, \"Chord\": \"A\"}, {\"Index\": 683, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Jingle Bells - Remastered 1999\", \"Streams\": 7182262, \"Artist\": \"Frank Sinatra\", \"Artist Followers\": 4953667.0, \"Song ID\": \"4HEOgBHRCExyYVeTyrXsnL\", \"Genre\": \"['adult standards', 'easy listening', 'lounge']\", \"Release Date\": \"1957-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 36.0, \"Danceability\": 0.512, \"Energy\": 0.339, \"Loudness\": -13.119, \"Speechiness\": 0.0498, \"Acousticness\": 0.727, \"Liveness\": 0.0977, \"Tempo\": 174.609, \"Duration (ms)\": 120693.0, \"Valence\": 0.951, \"Chord\": \"G#/Ab\"}, {\"Index\": 684, \"Highest Charting Position\": 160, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Oh Santa! (feat. Ariana Grande & Jennifer Hudson)\", \"Streams\": 7170169, \"Artist\": \"Mariah Carey\", \"Artist Followers\": 6931357.0, \"Song ID\": \"1Ri9P0ZPrqr6h0REDRdJBd\", \"Genre\": \"['dance pop', 'pop', 'r&b', 'urban contemporary']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 47.0, \"Danceability\": 0.648, \"Energy\": 0.938, \"Loudness\": -3.298, \"Speechiness\": 0.115, \"Acousticness\": 0.0339, \"Liveness\": 0.0564, \"Tempo\": 78.496, \"Duration (ms)\": 200467.0, \"Valence\": 0.849, \"Chord\": \"C#/Db\"}, {\"Index\": 685, \"Highest Charting Position\": 161, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Do You Hear What I Hear? - Remastered 2006\", \"Streams\": 7149158, \"Artist\": \"Bing Crosby\", \"Artist Followers\": 359973.0, \"Song ID\": \"5aDoUmxBsbdpS16alksb5Z\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'swing', 'vocal jazz']\", \"Release Date\": \"2006-01-01\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.566, \"Energy\": 0.246, \"Loudness\": -15.499, \"Speechiness\": 0.0276, \"Acousticness\": 0.813, \"Liveness\": 0.195, \"Tempo\": 101.529, \"Duration (ms)\": 165667.0, \"Valence\": 0.412, \"Chord\": \"A#/Bb\"}, {\"Index\": 686, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Hallelujah\", \"Streams\": 6985392, \"Artist\": \"Pentatonix\", \"Artist Followers\": 3083825.0, \"Song ID\": \"0HZk0QsXPhMNAWNDR3rYE8\", \"Genre\": \"['a cappella']\", \"Release Date\": \"2017-12-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 60.0, \"Danceability\": 0.364, \"Energy\": 0.378, \"Loudness\": -7.381, \"Speechiness\": 0.0331, \"Acousticness\": 0.47, \"Liveness\": 0.339, \"Tempo\": 89.918, \"Duration (ms)\": 268960.0, \"Valence\": 0.366, \"Chord\": \"G\"}, {\"Index\": 687, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"This Christmas\", \"Streams\": 6809438, \"Artist\": \"Donny Hathaway\", \"Artist Followers\": 424935.0, \"Song ID\": \"38xhBO2AKrJnjdjVnhJES6\", \"Genre\": \"['chicago soul', 'classic soul', 'funk', 'motown', 'neo soul', 'quiet storm', 'soul', 'southern soul']\", \"Release Date\": \"1990-04-03\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 42.0, \"Danceability\": 0.634, \"Energy\": 0.645, \"Loudness\": -9.2, \"Speechiness\": 0.0376, \"Acousticness\": 0.292, \"Liveness\": 0.246, \"Tempo\": 93.047, \"Duration (ms)\": 231173.0, \"Valence\": 0.677, \"Chord\": \"F\"}, {\"Index\": 688, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Winter Wonderland\", \"Streams\": 6680928, \"Artist\": \"Tony Bennett\", \"Artist Followers\": 659472.0, \"Song ID\": \"6kkJlaBYdyFcwCg67hW40t\", \"Genre\": \"['adult standards', 'easy listening', 'lounge', 'vocal jazz']\", \"Release Date\": \"2014-12-09\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 29.0, \"Danceability\": 0.604, \"Energy\": 0.497, \"Loudness\": -6.676, \"Speechiness\": 0.0319, \"Acousticness\": 0.727, \"Liveness\": 0.102, \"Tempo\": 126.011, \"Duration (ms)\": 149307.0, \"Valence\": 0.72, \"Chord\": \"C#/Db\"}, {\"Index\": 689, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Christmas Tree Farm\", \"Streams\": 6657404, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2mvabkN1i2gLnGAPUVdwek\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 52.0, \"Danceability\": 0.598, \"Energy\": 0.68, \"Loudness\": -4.505, \"Speechiness\": 0.0331, \"Acousticness\": 0.06, \"Liveness\": 0.324, \"Tempo\": 134.002, \"Duration (ms)\": 228027.0, \"Valence\": 0.437, \"Chord\": \"G\"}, {\"Index\": 690, \"Highest Charting Position\": 182, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Cozy Little Christmas\", \"Streams\": 6652130, \"Artist\": \"Katy Perry\", \"Artist Followers\": 18936929.0, \"Song ID\": \"02FaKXXL7KUtRc7K0k54tL\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-11-15\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.774, \"Energy\": 0.608, \"Loudness\": -6.264, \"Speechiness\": 0.128, \"Acousticness\": 0.128, \"Liveness\": 0.0895, \"Tempo\": 137.494, \"Duration (ms)\": 182521.0, \"Valence\": 0.56, \"Chord\": \"G\"}, {\"Index\": 691, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Merry Christmas, Happy Holidays\", \"Streams\": 6635128, \"Artist\": \"*NSYNC\", \"Artist Followers\": 1564750.0, \"Song ID\": \"4v9WbaxW8HdjqfUiWYWsII\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"1998-10-30\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.643, \"Energy\": 0.939, \"Loudness\": -3.967, \"Speechiness\": 0.0463, \"Acousticness\": 0.104, \"Liveness\": 0.881, \"Tempo\": 104.999, \"Duration (ms)\": 255307.0, \"Valence\": 0.756, \"Chord\": \"F\"}, {\"Index\": 692, \"Highest Charting Position\": 24, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"tolerate it\", \"Streams\": 6635109, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0PurA4JVJ8YQgSVopY8fn6\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-18--2020-12-25\\n2020-12-11--2020-12-18\", \"Popularity\": 67.0, \"Danceability\": 0.316, \"Energy\": 0.361, \"Loudness\": -10.381, \"Speechiness\": 0.0488, \"Acousticness\": 0.878, \"Liveness\": 0.0797, \"Tempo\": 74.952, \"Duration (ms)\": 245440.0, \"Valence\": 0.221, \"Chord\": \"A\"}, {\"Index\": 693, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"Please Come Home for Christmas - 2013 Remaster\", \"Streams\": 6400108, \"Artist\": \"Eagles\", \"Artist Followers\": 6896776.0, \"Song ID\": \"3QIoEi8Enr9uHffwInGIsC\", \"Genre\": \"['album rock', 'classic rock', 'country rock', 'folk rock', 'heartland rock', 'mellow gold', 'rock', 'soft rock', 'yacht rock']\", \"Release Date\": \"1994\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 44.0, \"Danceability\": 0.612, \"Energy\": 0.289, \"Loudness\": -11.568, \"Speechiness\": 0.0421, \"Acousticness\": 0.599, \"Liveness\": 0.0561, \"Tempo\": 183.18, \"Duration (ms)\": 177440.0, \"Valence\": 0.466, \"Chord\": \"A\"}, {\"Index\": 694, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-18--2020-12-25\", \"Song Name\": \"My Kind Of Present\", \"Streams\": 6278993, \"Artist\": \"Meghan Trainor\", \"Artist Followers\": 10606572.0, \"Song ID\": \"2rkb8ijsPapKDMEh0cSe8I\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-12-18--2020-12-25\", \"Popularity\": 41.0, \"Danceability\": 0.485, \"Energy\": 0.444, \"Loudness\": -6.232, \"Speechiness\": 0.195, \"Acousticness\": 0.373, \"Liveness\": 0.0969, \"Tempo\": 179.967, \"Duration (ms)\": 161013.0, \"Valence\": 0.777, \"Chord\": \"C#/Db\"}, {\"Index\": 695, \"Highest Charting Position\": 28, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"happiness\", \"Streams\": 16213589, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"73YUReisjb3A9ActdLLjJQ\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 65.0, \"Danceability\": 0.559, \"Energy\": 0.334, \"Loudness\": -10.733, \"Speechiness\": 0.0376, \"Acousticness\": 0.87, \"Liveness\": 0.114, \"Tempo\": 122.079, \"Duration (ms)\": 315147.0, \"Valence\": 0.211, \"Chord\": \"B\"}, {\"Index\": 696, \"Highest Charting Position\": 34, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"ivy\", \"Streams\": 14519547, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"19CSr8rwW05VJL2F91KFNK\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.515, \"Energy\": 0.545, \"Loudness\": -9.277, \"Speechiness\": 0.0353, \"Acousticness\": 0.855, \"Liveness\": 0.0921, \"Tempo\": 88.856, \"Duration (ms)\": 260440.0, \"Valence\": 0.535, \"Chord\": \"D\"}, {\"Index\": 697, \"Highest Charting Position\": 38, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"dorothea\", \"Streams\": 14392788, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"670fUmXf4KQekzbEgaXyPA\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.605, \"Energy\": 0.488, \"Loudness\": -8.322, \"Speechiness\": 0.0264, \"Acousticness\": 0.696, \"Liveness\": 0.129, \"Tempo\": 119.966, \"Duration (ms)\": 225880.0, \"Valence\": 0.354, \"Chord\": \"E\"}, {\"Index\": 698, \"Highest Charting Position\": 39, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"coney island (feat. The National)\", \"Streams\": 14385703, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3k7ne7VmH43ZPWxPdvPUgR\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.537, \"Energy\": 0.537, \"Loudness\": -11.266, \"Speechiness\": 0.0617, \"Acousticness\": 0.819, \"Liveness\": 0.142, \"Tempo\": 107.895, \"Duration (ms)\": 275320.0, \"Valence\": 0.292, \"Chord\": \"G#/Ab\"}, {\"Index\": 699, \"Highest Charting Position\": 43, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"evermore (feat. Bon Iver)\", \"Streams\": 13810722, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3O5osWf1rSoKMwe6E9ZaXP\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.39, \"Energy\": 0.27, \"Loudness\": -10.673, \"Speechiness\": 0.0308, \"Acousticness\": 0.937, \"Liveness\": 0.111, \"Tempo\": 125.177, \"Duration (ms)\": 304107.0, \"Valence\": 0.32, \"Chord\": \"C#/Db\"}, {\"Index\": 700, \"Highest Charting Position\": 45, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"long story short\", \"Streams\": 13583538, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2o2sgVJIgFXk8GQjWTgI6U\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 66.0, \"Danceability\": 0.546, \"Energy\": 0.73, \"Loudness\": -7.704, \"Speechiness\": 0.0417, \"Acousticness\": 0.66, \"Liveness\": 0.0972, \"Tempo\": 157.895, \"Duration (ms)\": 215920.0, \"Valence\": 0.573, \"Chord\": \"C\"}, {\"Index\": 701, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"cowboy like me\", \"Streams\": 12782098, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1XjHRolIXL2M1EEOUsGGR4\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.604, \"Energy\": 0.517, \"Loudness\": -9.014, \"Speechiness\": 0.0347, \"Acousticness\": 0.768, \"Liveness\": 0.123, \"Tempo\": 127.967, \"Duration (ms)\": 275040.0, \"Valence\": 0.511, \"Chord\": \"C\"}, {\"Index\": 702, \"Highest Charting Position\": 57, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"marjorie\", \"Streams\": 12234761, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"12ntTeqEeTg7GAVpe8Mhpl\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.535, \"Energy\": 0.561, \"Loudness\": -11.609, \"Speechiness\": 0.0484, \"Acousticness\": 0.876, \"Liveness\": 0.115, \"Tempo\": 96.103, \"Duration (ms)\": 257773.0, \"Valence\": 0.287, \"Chord\": \"F\"}, {\"Index\": 703, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"closure\", \"Streams\": 11245393, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"35rdVq36LMHQX0Suw9a6tK\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 62.0, \"Danceability\": 0.689, \"Energy\": 0.704, \"Loudness\": -10.813, \"Speechiness\": 0.245, \"Acousticness\": 0.835, \"Liveness\": 0.134, \"Tempo\": 151.884, \"Duration (ms)\": 180653.0, \"Valence\": 0.92, \"Chord\": \"A\"}, {\"Index\": 704, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"She Knows This\", \"Streams\": 10561183, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"1xzUQMiCoY5pdego0pHMeV\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 64.0, \"Danceability\": 0.39, \"Energy\": 0.724, \"Loudness\": -7.607, \"Speechiness\": 0.0889, \"Acousticness\": 0.162, \"Liveness\": 0.393, \"Tempo\": 165.945, \"Duration (ms)\": 216560.0, \"Valence\": 0.312, \"Chord\": \"F#/Gb\"}, {\"Index\": 705, \"Highest Charting Position\": 97, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Another Day\", \"Streams\": 8901697, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"6myUpr3GDR80Dg3zqNTmmG\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 63.0, \"Danceability\": 0.646, \"Energy\": 0.758, \"Loudness\": -7.75, \"Speechiness\": 0.0708, \"Acousticness\": 0.556, \"Liveness\": 0.335, \"Tempo\": 172.995, \"Duration (ms)\": 199787.0, \"Valence\": 0.0642, \"Chord\": \"E\"}, {\"Index\": 706, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Solo Dolo, Pt. III\", \"Streams\": 7655623, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"27oVCAziETRbNuo5A8LNpg\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 61.0, \"Danceability\": 0.589, \"Energy\": 0.727, \"Loudness\": -6.907, \"Speechiness\": 0.0866, \"Acousticness\": 0.239, \"Liveness\": 0.164, \"Tempo\": 152.058, \"Duration (ms)\": 242267.0, \"Valence\": 0.52, \"Chord\": \"A#/Bb\"}, {\"Index\": 707, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Dive\", \"Streams\": 7524738, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"7Hc3YL8oDiAzbiAW32KXrw\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 60.0, \"Danceability\": 0.64, \"Energy\": 0.621, \"Loudness\": -8.269, \"Speechiness\": 0.0679, \"Acousticness\": 0.67, \"Liveness\": 0.36, \"Tempo\": 123.105, \"Duration (ms)\": 148707.0, \"Valence\": 0.332, \"Chord\": \"A\"}, {\"Index\": 708, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Heaven On Earth\", \"Streams\": 7117347, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"2koUj1Fn5TKFEkChSmBPIb\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 59.0, \"Danceability\": 0.786, \"Energy\": 0.61, \"Loudness\": -6.736, \"Speechiness\": 0.0558, \"Acousticness\": 0.379, \"Liveness\": 0.0765, \"Tempo\": 130.036, \"Duration (ms)\": 201093.0, \"Valence\": 0.228, \"Chord\": \"C\"}, {\"Index\": 709, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Sad People\", \"Streams\": 6865689, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"4nuAslShoN77tq12fzwjUq\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 62.0, \"Danceability\": 0.636, \"Energy\": 0.647, \"Loudness\": -6.971, \"Speechiness\": 0.0381, \"Acousticness\": 0.247, \"Liveness\": 0.113, \"Tempo\": 158.073, \"Duration (ms)\": 176027.0, \"Valence\": 0.416, \"Chord\": \"F\"}, {\"Index\": 710, \"Highest Charting Position\": 152, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Damaged\", \"Streams\": 6763705, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"2n7Ao4nyESBa5ti8gcAbBt\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 57.0, \"Danceability\": 0.625, \"Energy\": 0.581, \"Loudness\": -7.1, \"Speechiness\": 0.0316, \"Acousticness\": 0.553, \"Liveness\": 0.254, \"Tempo\": 142.04, \"Duration (ms)\": 150853.0, \"Valence\": 0.267, \"Chord\": \"G#/Ab\"}, {\"Index\": 711, \"Highest Charting Position\": 17, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"YO VISTO AS\\u00cd\", \"Streams\": 6388079, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5fROvzNghPid8mbKNDYvpJ\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-11--2020-12-18\\n2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 73.0, \"Danceability\": 0.688, \"Energy\": 0.881, \"Loudness\": -4.889, \"Speechiness\": 0.0474, \"Acousticness\": 0.0947, \"Liveness\": 0.0804, \"Tempo\": 123.013, \"Duration (ms)\": 191526.0, \"Valence\": 0.677, \"Chord\": \"G\"}, {\"Index\": 712, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"Beautiful Trip\", \"Streams\": 6108393, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"4IIuCotvqijraSdnVLaFnM\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 54.0, \"Danceability\": 0.331, \"Energy\": 0.513, \"Loudness\": -15.392, \"Speechiness\": 0.632, \"Acousticness\": 0.972, \"Liveness\": 0.882, \"Tempo\": 133.971, \"Duration (ms)\": 37013.0, \"Valence\": 0.42, \"Chord\": \"B\"}, {\"Index\": 713, \"Highest Charting Position\": 185, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-11--2020-12-18\", \"Song Name\": \"The Void\", \"Streams\": 6068816, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"2yg7MXp8nSPaf61HVkhEr3\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-12-11\", \"Weeks Charted\": \"2020-12-11--2020-12-18\", \"Popularity\": 61.0, \"Danceability\": 0.464, \"Energy\": 0.459, \"Loudness\": -8.736, \"Speechiness\": 0.0314, \"Acousticness\": 0.365, \"Liveness\": 0.117, \"Tempo\": 142.017, \"Duration (ms)\": 325413.0, \"Valence\": 0.0786, \"Chord\": \"G\"}, {\"Index\": 714, \"Highest Charting Position\": 1, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"cardigan\", \"Streams\": 5845457, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"4R2kfaDFhslZEMJqAFNpdd\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-12-11--2020-12-18\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 79.0, \"Danceability\": 0.613, \"Energy\": 0.581, \"Loudness\": -8.588, \"Speechiness\": 0.0424, \"Acousticness\": 0.537, \"Liveness\": 0.25, \"Tempo\": 130.033, \"Duration (ms)\": 239560.0, \"Valence\": 0.551, \"Chord\": \"C\"}, {\"Index\": 715, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Real Shit (with benny blanco)\", \"Streams\": 9325928, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"3uVPLtkmDu8pDkYEAVqbgS\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-12-02\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 70.0, \"Danceability\": 0.703, \"Energy\": 0.703, \"Loudness\": -4.672, \"Speechiness\": 0.133, \"Acousticness\": 0.605, \"Liveness\": 0.12, \"Tempo\": 76.017, \"Duration (ms)\": 183783.0, \"Valence\": 0.697, \"Chord\": \"C#/Db\"}, {\"Index\": 716, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Teach Me How To Love\", \"Streams\": 7932101, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 33893352.0, \"Song ID\": \"5LZtB6nxvjIhUoElp3Zqk0\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 68.0, \"Danceability\": 0.592, \"Energy\": 0.885, \"Loudness\": -4.944, \"Speechiness\": 0.0807, \"Acousticness\": 0.0505, \"Liveness\": 0.0843, \"Tempo\": 98.991, \"Duration (ms)\": 202357.0, \"Valence\": 0.731, \"Chord\": \"A\"}, {\"Index\": 717, \"Highest Charting Position\": 138, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Blinding Lights (with ROSAL\\u00cdA) - Remix\", \"Streams\": 6653913, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"7MXgrcOQAJ5VwSNUL0lDd3\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 64.0, \"Danceability\": 0.49, \"Energy\": 0.694, \"Loudness\": -5.793, \"Speechiness\": 0.0618, \"Acousticness\": 0.0133, \"Liveness\": 0.0946, \"Tempo\": 170.903, \"Duration (ms)\": 216123.0, \"Valence\": 0.249, \"Chord\": \"F\"}, {\"Index\": 718, \"Highest Charting Position\": 15, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"WHATS POPPIN (feat. DaBaby, Tory Lanez & Lil Wayne) - Remix\", \"Streams\": 6567755, \"Artist\": \"Tory Lanez, Jack Harlow\", \"Artist Followers\": 3828418.0, \"Song ID\": \"2MbdDtCv5LUVjYy9RuGTgC\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-06-24\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 80.0, \"Danceability\": 0.904, \"Energy\": 0.723, \"Loudness\": -5.224, \"Speechiness\": 0.26, \"Acousticness\": 0.0631, \"Liveness\": 0.185, \"Tempo\": 145.013, \"Duration (ms)\": 227478.0, \"Valence\": 0.835, \"Chord\": \"B\"}, {\"Index\": 719, \"Highest Charting Position\": 29, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"TE DESEO LO MEJOR\", \"Streams\": 6204228, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"23XjN1s3DZC8Q9ZwuorYY4\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.763, \"Energy\": 0.597, \"Loudness\": -5.054, \"Speechiness\": 0.0416, \"Acousticness\": 0.158, \"Liveness\": 0.111, \"Tempo\": 126.054, \"Duration (ms)\": 139576.0, \"Valence\": 0.194, \"Chord\": \"C#/Db\"}, {\"Index\": 720, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-12-04--2020-12-11\", \"Song Name\": \"Errbody\", \"Streams\": 5929516, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"6eVxH9Kyanzrw636zJRPcw\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-12-03\", \"Weeks Charted\": \"2020-12-04--2020-12-11\", \"Popularity\": 68.0, \"Danceability\": 0.887, \"Energy\": 0.606, \"Loudness\": -6.572, \"Speechiness\": 0.324, \"Acousticness\": 0.000407, \"Liveness\": 0.151, \"Tempo\": 139.995, \"Duration (ms)\": 210699.0, \"Valence\": 0.272, \"Chord\": \"D\"}, {\"Index\": 721, \"Highest Charting Position\": 86, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"Angels Like You\", \"Streams\": 5884221, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"1daDRI9ahBonbWD8YcxOIB\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 77.0, \"Danceability\": 0.672, \"Energy\": 0.642, \"Loudness\": -4.035, \"Speechiness\": 0.0313, \"Acousticness\": 0.0981, \"Liveness\": 0.1, \"Tempo\": 121.981, \"Duration (ms)\": 196453.0, \"Valence\": 0.494, \"Chord\": \"F\"}, {\"Index\": 722, \"Highest Charting Position\": 18, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Blue & Grey\", \"Streams\": 5698275, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"0n2moJpAEWHwaPYYjkzMDl\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 77.0, \"Danceability\": 0.547, \"Energy\": 0.605, \"Loudness\": -6.755, \"Speechiness\": 0.0415, \"Acousticness\": 0.42, \"Liveness\": 0.125, \"Tempo\": 121.953, \"Duration (ms)\": 254950.0, \"Valence\": 0.364, \"Chord\": \"G#/Ab\"}, {\"Index\": 723, \"Highest Charting Position\": 46, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Mad at Disney\", \"Streams\": 5436450, \"Artist\": \"salem ilese\", \"Artist Followers\": 133998.0, \"Song ID\": \"7aGyRfJWtLqgJaZoG9lJhE\", \"Genre\": \"['alt z', 'modern indie pop', 'social media pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 76.0, \"Danceability\": 0.738, \"Energy\": 0.621, \"Loudness\": -7.313, \"Speechiness\": 0.0486, \"Acousticness\": 0.424, \"Liveness\": 0.692, \"Tempo\": 113.968, \"Duration (ms)\": 136839.0, \"Valence\": 0.715, \"Chord\": \"C\"}, {\"Index\": 724, \"Highest Charting Position\": 9, \"Number of Times Charted\": 39, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Safaera\", \"Streams\": 5390363, \"Artist\": \"Bad Bunny, Jowell & Randy, \\u00d1engo Flow\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2DEZmgHKAvm41k4J3R2E9Y\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 79.0, \"Danceability\": 0.607, \"Energy\": 0.829, \"Loudness\": -4.074, \"Speechiness\": 0.379, \"Acousticness\": 0.0103, \"Liveness\": 0.107, \"Tempo\": 96.172, \"Duration (ms)\": 295177.0, \"Valence\": 0.685, \"Chord\": \"D\"}, {\"Index\": 725, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"LA DROGA\", \"Streams\": 5375449, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"67ACYA3UI6QMNtHX6b34wX\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.643, \"Energy\": 0.727, \"Loudness\": -5.506, \"Speechiness\": 0.0389, \"Acousticness\": 0.0439, \"Liveness\": 0.123, \"Tempo\": 90.019, \"Duration (ms)\": 162299.0, \"Valence\": 0.295, \"Chord\": \"C#/Db\"}, {\"Index\": 726, \"Highest Charting Position\": 60, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"GO (feat. Juice WRLD)\", \"Streams\": 5370330, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"2rPHUAeUPbNgTmK18FPTiZ\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-06--2020-11-13\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 78.0, \"Danceability\": 0.487, \"Energy\": 0.74, \"Loudness\": -4.973, \"Speechiness\": 0.0944, \"Acousticness\": 0.157, \"Liveness\": 0.612, \"Tempo\": 73.779, \"Duration (ms)\": 181688.0, \"Valence\": 0.522, \"Chord\": \"F#/Gb\"}, {\"Index\": 727, \"Highest Charting Position\": 180, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"Jenny (I Wanna Ruin Our Friendship)\", \"Streams\": 5364223, \"Artist\": \"Studio Killers\", \"Artist Followers\": 181236.0, \"Song ID\": \"4JLBDUYSaOMPYND0iWeSWQ\", \"Genre\": \"[]\", \"Release Date\": \"2020-12-04\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\", \"Popularity\": 72.0, \"Danceability\": 0.668, \"Energy\": 0.798, \"Loudness\": -5.701, \"Speechiness\": 0.0334, \"Acousticness\": 0.00305, \"Liveness\": 0.277, \"Tempo\": 133.928, \"Duration (ms)\": 215280.0, \"Valence\": 0.575, \"Chord\": \"B\"}, {\"Index\": 728, \"Highest Charting Position\": 35, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Mood (Remix) feat. Justin Bieber, J Balvin & iann dior\", \"Streams\": 5314734, \"Artist\": \"24kGoldn\", \"Artist Followers\": 1276406.0, \"Song ID\": \"6FuGJB290AQMAHTfjOYVaK\", \"Genre\": \"['cali rap']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-12-04--2020-12-11\\n2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 77.0, \"Danceability\": 0.721, \"Energy\": 0.745, \"Loudness\": -3.508, \"Speechiness\": 0.0366, \"Acousticness\": 0.151, \"Liveness\": 0.372, \"Tempo\": 90.988, \"Duration (ms)\": 192745.0, \"Valence\": 0.699, \"Chord\": \"G\"}, {\"Index\": 729, \"Highest Charting Position\": 41, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"HOY COBR\\u00c9\", \"Streams\": 12914431, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0tjZv2hChdHZCW1zFXpy1J\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.86, \"Energy\": 0.725, \"Loudness\": -6.7, \"Speechiness\": 0.249, \"Acousticness\": 0.0464, \"Liveness\": 0.0994, \"Tempo\": 145.001, \"Duration (ms)\": 162151.0, \"Valence\": 0.375, \"Chord\": \"B\"}, {\"Index\": 730, \"Highest Charting Position\": 44, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"MALDITA POBREZA\", \"Streams\": 12660806, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0Lsis3LB0XAK6XlTHXaJk2\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 67.0, \"Danceability\": 0.762, \"Energy\": 0.861, \"Loudness\": -4.075, \"Speechiness\": 0.0652, \"Acousticness\": 0.139, \"Liveness\": 0.0956, \"Tempo\": 133.037, \"Duration (ms)\": 213609.0, \"Valence\": 0.588, \"Chord\": \"E\"}, {\"Index\": 731, \"Highest Charting Position\": 48, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"EL MUNDO ES M\\u00cdO\", \"Streams\": 12507010, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"36DHxTW2xdr9GG15T9oK9L\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 67.0, \"Danceability\": 0.716, \"Energy\": 0.522, \"Loudness\": -6.834, \"Speechiness\": 0.0582, \"Acousticness\": 0.166, \"Liveness\": 0.113, \"Tempo\": 76.993, \"Duration (ms)\": 165199.0, \"Valence\": 0.224, \"Chord\": \"F\"}, {\"Index\": 732, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"ANTES QUE SE ACABE\", \"Streams\": 11298839, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"7kjEqI6eZ7YlFrGhxixnlN\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 76.0, \"Danceability\": 0.693, \"Energy\": 0.549, \"Loudness\": -6.098, \"Speechiness\": 0.0577, \"Acousticness\": 0.505, \"Liveness\": 0.324, \"Tempo\": 139.988, \"Duration (ms)\": 221187.0, \"Valence\": 0.473, \"Chord\": \"D\"}, {\"Index\": 733, \"Highest Charting Position\": 59, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"SORRY PAPI\", \"Streams\": 11066606, \"Artist\": \"Bad Bunny, ABRA\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5jZ32WOU7sqzDYbzINwMUk\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 70.0, \"Danceability\": 0.612, \"Energy\": 0.561, \"Loudness\": -6.054, \"Speechiness\": 0.0851, \"Acousticness\": 0.0601, \"Liveness\": 0.145, \"Tempo\": 191.911, \"Duration (ms)\": 163053.0, \"Valence\": 0.393, \"Chord\": \"C#/Db\"}, {\"Index\": 734, \"Highest Charting Position\": 63, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"120\", \"Streams\": 10957181, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3KJ3opyV29269SXkPrc19l\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 72.0, \"Danceability\": 0.636, \"Energy\": 0.656, \"Loudness\": -5.542, \"Speechiness\": 0.0676, \"Acousticness\": 0.451, \"Liveness\": 0.287, \"Tempo\": 171.918, \"Duration (ms)\": 151506.0, \"Valence\": 0.439, \"Chord\": \"D\"}, {\"Index\": 735, \"Highest Charting Position\": 66, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"TRELLAS\", \"Streams\": 10733416, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"09WAnxdBuebQopKhJT3oZS\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 66.0, \"Danceability\": 0.43, \"Energy\": 0.412, \"Loudness\": -5.372, \"Speechiness\": 0.0281, \"Acousticness\": 0.2, \"Liveness\": 0.324, \"Tempo\": 90.872, \"Duration (ms)\": 157673.0, \"Valence\": 0.0508, \"Chord\": \"D\"}, {\"Index\": 736, \"Highest Charting Position\": 83, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"Wonderful Christmastime [Edited Version] - Remastered 2011 / Edited Version\", \"Streams\": 9624871, \"Artist\": \"Paul McCartney\", \"Artist Followers\": 3609658.0, \"Song ID\": \"1SV1fxF65n9NhRHp3KlBuu\", \"Genre\": \"['album rock', 'art rock', 'beatlesque', 'classic rock', 'mellow gold', 'rock', 'soft rock']\", \"Release Date\": \"1980-05-16\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 51.0, \"Danceability\": 0.774, \"Energy\": 0.511, \"Loudness\": -8.914, \"Speechiness\": 0.0319, \"Acousticness\": 0.322, \"Liveness\": 0.0672, \"Tempo\": 94.736, \"Duration (ms)\": 227653.0, \"Valence\": 0.771, \"Chord\": \"B\"}, {\"Index\": 737, \"Highest Charting Position\": 16, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Fly To My Room\", \"Streams\": 8413330, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3QH8rQGNFX8VLbCgZ7uPTS\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 76.0, \"Danceability\": 0.764, \"Energy\": 0.526, \"Loudness\": -7.355, \"Speechiness\": 0.212, \"Acousticness\": 0.0484, \"Liveness\": 0.0718, \"Tempo\": 114.91, \"Duration (ms)\": 222243.0, \"Valence\": 0.588, \"Chord\": \"B\"}, {\"Index\": 738, \"Highest Charting Position\": 24, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Telepathy\", \"Streams\": 7703744, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"2FVpOsjT1iquZ3SpCjZ9Ne\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 77.0, \"Danceability\": 0.787, \"Energy\": 0.669, \"Loudness\": -4.333, \"Speechiness\": 0.0428, \"Acousticness\": 0.00782, \"Liveness\": 0.123, \"Tempo\": 104.994, \"Duration (ms)\": 202313.0, \"Valence\": 0.57, \"Chord\": \"F\"}, {\"Index\": 739, \"Highest Charting Position\": 26, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Dis-ease\", \"Streams\": 7165808, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"54DmTIv86D3sYdiawjULQ0\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 75.0, \"Danceability\": 0.731, \"Energy\": 0.845, \"Loudness\": -5.352, \"Speechiness\": 0.132, \"Acousticness\": 0.0132, \"Liveness\": 0.0782, \"Tempo\": 101.085, \"Duration (ms)\": 239722.0, \"Valence\": 0.484, \"Chord\": \"G#/Ab\"}, {\"Index\": 740, \"Highest Charting Position\": 27, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Stay\", \"Streams\": 7010227, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3ndCsZfq8OVwwkz9mmZvUz\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-11-20--2020-11-27\", \"Popularity\": 76.0, \"Danceability\": 0.582, \"Energy\": 0.693, \"Loudness\": -5.048, \"Speechiness\": 0.0465, \"Acousticness\": 0.114, \"Liveness\": 0.13, \"Tempo\": 125.904, \"Duration (ms)\": 204800.0, \"Valence\": 0.341, \"Chord\": \"F#/Gb\"}, {\"Index\": 741, \"Highest Charting Position\": 151, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Heart Of Glass (Live from the iHeart Festival)\", \"Streams\": 6006877, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"5i7ThJfYLAzp2DyZuFpF6j\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-09-29\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 71.0, \"Danceability\": 0.58, \"Energy\": 0.908, \"Loudness\": -5.303, \"Speechiness\": 0.0341, \"Acousticness\": 0.000335, \"Liveness\": 0.087, \"Tempo\": 115.016, \"Duration (ms)\": 213672.0, \"Valence\": 0.427, \"Chord\": \"E\"}, {\"Index\": 742, \"Highest Charting Position\": 171, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"CANTARES DE NAVIDAD\", \"Streams\": 5842320, \"Artist\": \"Trio Vegabaje\\u00f1o\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2Iv6YBslkxslMJQsxshZh5\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 56.0, \"Danceability\": 0.764, \"Energy\": 0.523, \"Loudness\": -7.371, \"Speechiness\": 0.0406, \"Acousticness\": 0.777, \"Liveness\": 0.352, \"Tempo\": 118.671, \"Duration (ms)\": 199720.0, \"Valence\": 0.962, \"Chord\": \"D\"}, {\"Index\": 743, \"Highest Charting Position\": 172, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-27--2020-12-04\", \"Song Name\": \"Plastic Hearts\", \"Streams\": 5816739, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"6qCsKKS7Ol63SJW3LOIX5R\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-11-27\", \"Weeks Charted\": \"2020-11-27--2020-12-04\", \"Popularity\": 74.0, \"Danceability\": 0.551, \"Energy\": 0.756, \"Loudness\": -4.948, \"Speechiness\": 0.0652, \"Acousticness\": 0.0511, \"Liveness\": 0.0765, \"Tempo\": 175.984, \"Duration (ms)\": 205733.0, \"Valence\": 0.618, \"Chord\": \"D\"}, {\"Index\": 744, \"Highest Charting Position\": 63, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"C\\u00d3MO SE SIENTE - Remix\", \"Streams\": 5463964, \"Artist\": \"Jhay Cortez, Bad Bunny\", \"Artist Followers\": 2435159.0, \"Song ID\": \"2tFwfmceQa1Y6nRPhYbEtC\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-09\", \"Weeks Charted\": \"2020-11-27--2020-12-04\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 81.0, \"Danceability\": 0.807, \"Energy\": 0.606, \"Loudness\": -8.871, \"Speechiness\": 0.088, \"Acousticness\": 0.0946, \"Liveness\": 0.119, \"Tempo\": 92.988, \"Duration (ms)\": 227520.0, \"Valence\": 0.304, \"Chord\": \"D#/Eb\"}, {\"Index\": 745, \"Highest Charting Position\": 78, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Skit\", \"Streams\": 8392247, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4GVwjLRT7oSsKby7Vy8EHr\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-11-20\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 60.0, \"Danceability\": 0.703, \"Energy\": 0.321, \"Loudness\": -13.135, \"Speechiness\": 0.884, \"Acousticness\": 0.864, \"Liveness\": 0.908, \"Tempo\": 114.822, \"Duration (ms)\": 179548.0, \"Valence\": 0.544, \"Chord\": \"E\"}, {\"Index\": 746, \"Highest Charting Position\": 105, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Baby (with J Balvin)\", \"Streams\": 7276896, \"Artist\": \"Sfera Ebbasta\", \"Artist Followers\": 4430628.0, \"Song ID\": \"3eblNP3Zd5b5J3JaOckl8Y\", \"Genre\": \"['italian hip hop', 'italian pop', 'trap italiana']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 69.0, \"Danceability\": 0.755, \"Energy\": 0.882, \"Loudness\": -1.957, \"Speechiness\": 0.0532, \"Acousticness\": 0.125, \"Liveness\": 0.103, \"Tempo\": 99.984, \"Duration (ms)\": 193555.0, \"Valence\": 0.606, \"Chord\": \"A#/Bb\"}, {\"Index\": 747, \"Highest Charting Position\": 82, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Tick Tock (feat. 24kGoldn)\", \"Streams\": 6241923, \"Artist\": \"Clean Bandit, Mabel\", \"Artist Followers\": 4431309.0, \"Song ID\": \"27u7t9d7ZQoyjsCROHuZJ3\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk dance', 'uk funky']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 78.0, \"Danceability\": 0.779, \"Energy\": 0.705, \"Loudness\": -3.895, \"Speechiness\": 0.0344, \"Acousticness\": 0.369, \"Liveness\": 0.124, \"Tempo\": 101.022, \"Duration (ms)\": 178374.0, \"Valence\": 0.946, \"Chord\": \"C\"}, {\"Index\": 748, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Dime C\\u00f3mo Quieres\", \"Streams\": 6152821, \"Artist\": \"Christian Nodal, \\u00c1ngela Aguilar\", \"Artist Followers\": 8123757.0, \"Song ID\": \"4jcxBTrNvyqMJdMDyyjdYV\", \"Genre\": \"['mariachi', 'nuevo regional mexicano', 'ranchera', 'regional mexican']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 75.0, \"Danceability\": 0.839, \"Energy\": 0.667, \"Loudness\": -3.961, \"Speechiness\": 0.031, \"Acousticness\": 0.322, \"Liveness\": 0.244, \"Tempo\": 124.889, \"Duration (ms)\": 171360.0, \"Valence\": 0.878, \"Chord\": \"B\"}, {\"Index\": 749, \"Highest Charting Position\": 162, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Tik Tok (feat. Marracash & Gu\\u00e8 Pequeno)\", \"Streams\": 5504912, \"Artist\": \"Sfera Ebbasta\", \"Artist Followers\": 4430628.0, \"Song ID\": \"3tkYK45AZC0PqJ7MSe6IyJ\", \"Genre\": \"['italian hip hop', 'italian pop', 'trap italiana']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 59.0, \"Danceability\": 0.723, \"Energy\": 0.673, \"Loudness\": -7.636, \"Speechiness\": 0.137, \"Acousticness\": 0.0985, \"Liveness\": 0.323, \"Tempo\": 120.046, \"Duration (ms)\": 230389.0, \"Valence\": 0.302, \"Chord\": \"A\"}, {\"Index\": 750, \"Highest Charting Position\": 88, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Jerusalema (feat. Nomcebo Zikode)\", \"Streams\": 5362508, \"Artist\": \"Master KG\", \"Artist Followers\": 247480.0, \"Song ID\": \"2MlOUXmcofMackX3bxfSwi\", \"Genre\": \"['south african house']\", \"Release Date\": \"2020-01-24\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 78.0, \"Danceability\": 0.88, \"Energy\": 0.483, \"Loudness\": -7.012, \"Speechiness\": 0.0505, \"Acousticness\": 0.0185, \"Liveness\": 0.0607, \"Tempo\": 124.009, \"Duration (ms)\": 342613.0, \"Valence\": 0.827, \"Chord\": \"C#/Db\"}, {\"Index\": 751, \"Highest Charting Position\": 19, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Agua (with J Balvin) - Music From \\\"Sponge On The Run\\\" Movie\", \"Streams\": 5358940, \"Artist\": \"Tainy\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 752, \"Highest Charting Position\": 174, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Abracadabra (feat. Future)\", \"Streams\": 5263469, \"Artist\": \"Sfera Ebbasta\", \"Artist Followers\": 4430628.0, \"Song ID\": \"2GuLouaDNgLGxdJoe0vYf6\", \"Genre\": \"['italian hip hop', 'italian pop', 'trap italiana']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 55.0, \"Danceability\": 0.846, \"Energy\": 0.681, \"Loudness\": -7.091, \"Speechiness\": 0.174, \"Acousticness\": 0.0461, \"Liveness\": 0.112, \"Tempo\": 131.988, \"Duration (ms)\": 192965.0, \"Valence\": 0.809, \"Chord\": \"F\"}, {\"Index\": 753, \"Highest Charting Position\": 36, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Djadja (feat. Maluma) - Remix\", \"Streams\": 5203423, \"Artist\": \"Aya Nakamura\", \"Artist Followers\": 2953525.0, \"Song ID\": \"6AzKhCHOms83jvNVLsz0Bt\", \"Genre\": \"['basshall', 'francoton']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 72.0, \"Danceability\": 0.791, \"Energy\": 0.682, \"Loudness\": -7.328, \"Speechiness\": 0.158, \"Acousticness\": 0.175, \"Liveness\": 0.0926, \"Tempo\": 98.031, \"Duration (ms)\": 166851.0, \"Valence\": 0.672, \"Chord\": \"F\"}, {\"Index\": 754, \"Highest Charting Position\": 140, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"ALWAYS DO\", \"Streams\": 5196635, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"3QCU8BT0zDS9LPVfEhRFEE\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\", \"Popularity\": 76.0, \"Danceability\": 0.762, \"Energy\": 0.426, \"Loudness\": -6.865, \"Speechiness\": 0.113, \"Acousticness\": 0.0442, \"Liveness\": 0.0858, \"Tempo\": 167.827, \"Duration (ms)\": 151705.0, \"Valence\": 0.582, \"Chord\": \"G#/Ab\"}, {\"Index\": 755, \"Highest Charting Position\": 7, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Smile (with The Weeknd)\", \"Streams\": 5164187, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"6wQlQrTY5mVS8EGaFZVwVF\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 75.0, \"Danceability\": 0.694, \"Energy\": 0.685, \"Loudness\": -6.535, \"Speechiness\": 0.133, \"Acousticness\": 0.224, \"Liveness\": 0.124, \"Tempo\": 158.831, \"Duration (ms)\": 196180.0, \"Valence\": 0.306, \"Chord\": \"F#/Gb\"}, {\"Index\": 756, \"Highest Charting Position\": 22, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Pretty Savage\", \"Streams\": 5039047, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"1XnpzbOGptRwfJhZgLbmSr\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 75.0, \"Danceability\": 0.701, \"Energy\": 0.556, \"Loudness\": -7.42, \"Speechiness\": 0.0414, \"Acousticness\": 0.00886, \"Liveness\": 0.106, \"Tempo\": 152.045, \"Duration (ms)\": 201122.0, \"Valence\": 0.333, \"Chord\": \"A\"}, {\"Index\": 757, \"Highest Charting Position\": 41, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Savage Love (Laxed \\u2013 Siren Beat) [BTS Remix]\", \"Streams\": 4995203, \"Artist\": \"Jawsh 685, Jason Derulo\", \"Artist Followers\": 100635.0, \"Song ID\": \"4TgxFMOn5yoESW6zCidCXL\", \"Genre\": \"['nz pop']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 76.0, \"Danceability\": 0.758, \"Energy\": 0.598, \"Loudness\": -5.695, \"Speechiness\": 0.0868, \"Acousticness\": 0.16, \"Liveness\": 0.295, \"Tempo\": 149.836, \"Duration (ms)\": 184905.0, \"Valence\": 0.658, \"Chord\": \"C\"}, {\"Index\": 758, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Mirrors\", \"Streams\": 4988571, \"Artist\": \"Justin Timberlake\", \"Artist Followers\": 11034144.0, \"Song ID\": \"4rHZZAmHpZrA3iH5zx8frV\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2013-03-15\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 78.0, \"Danceability\": 0.574, \"Energy\": 0.512, \"Loudness\": -6.664, \"Speechiness\": 0.0503, \"Acousticness\": 0.234, \"Liveness\": 0.0946, \"Tempo\": 76.899, \"Duration (ms)\": 484147.0, \"Valence\": 0.512, \"Chord\": \"F\"}, {\"Index\": 759, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-20--2020-11-27\", \"Song Name\": \"Hollywood (feat. Diplo)\", \"Streams\": 4920218, \"Artist\": \"Sfera Ebbasta\", \"Artist Followers\": 4430628.0, \"Song ID\": \"0WXU7I74NEN1DMLIT406Wx\", \"Genre\": \"['italian hip hop', 'italian pop', 'trap italiana']\", \"Release Date\": \"2020-12-18\", \"Weeks Charted\": \"2020-11-20--2020-11-27\", \"Popularity\": 63.0, \"Danceability\": 0.848, \"Energy\": 0.708, \"Loudness\": -6.336, \"Speechiness\": 0.0366, \"Acousticness\": 0.153, \"Liveness\": 0.0948, \"Tempo\": 137.973, \"Duration (ms)\": 191869.0, \"Valence\": 0.926, \"Chord\": \"D\"}, {\"Index\": 760, \"Highest Charting Position\": 24, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Runnin\", \"Streams\": 4914682, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"5SWnsxjhdcEDc7LJjq9UHk\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 78.0, \"Danceability\": 0.819, \"Energy\": 0.626, \"Loudness\": -4.574, \"Speechiness\": 0.202, \"Acousticness\": 0.00748, \"Liveness\": 0.167, \"Tempo\": 143.01, \"Duration (ms)\": 195906.0, \"Valence\": 0.415, \"Chord\": \"A#/Bb\"}, {\"Index\": 761, \"Highest Charting Position\": 105, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Are You Bored Yet? (feat. Clairo)\", \"Streams\": 4911995, \"Artist\": \"Wallows\", \"Artist Followers\": 1963296.0, \"Song ID\": \"57RA3JGafJm5zRtKJiKPIm\", \"Genre\": \"['indie pop', 'modern rock', 'pop', 'rock']\", \"Release Date\": \"2019-03-22\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 81.0, \"Danceability\": 0.682, \"Energy\": 0.683, \"Loudness\": -6.444, \"Speechiness\": 0.0287, \"Acousticness\": 0.156, \"Liveness\": 0.273, \"Tempo\": 120.023, \"Duration (ms)\": 178000.0, \"Valence\": 0.64, \"Chord\": \"G#/Ab\"}, {\"Index\": 762, \"Highest Charting Position\": 44, \"Number of Times Charted\": 44, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"10,000 Hours (with Justin Bieber)\", \"Streams\": 4911749, \"Artist\": \"Dan + Shay\", \"Artist Followers\": 2334615.0, \"Song ID\": \"2wrJq5XKLnmhRXHIAf9xBa\", \"Genre\": \"['contemporary country', 'country', 'pop']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.654, \"Energy\": 0.63, \"Loudness\": -4.644, \"Speechiness\": 0.0259, \"Acousticness\": 0.153, \"Liveness\": 0.111, \"Tempo\": 89.991, \"Duration (ms)\": 167693.0, \"Valence\": 0.43, \"Chord\": \"A#/Bb\"}, {\"Index\": 763, \"Highest Charting Position\": 87, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"You Got It\", \"Streams\": 4907925, \"Artist\": \"Vedo\", \"Artist Followers\": 260236.0, \"Song ID\": \"4lsHZ92XCFOQfzJFBTluk8\", \"Genre\": \"['pop r&b', 'r&b']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 79.0, \"Danceability\": 0.762, \"Energy\": 0.433, \"Loudness\": -8.937, \"Speechiness\": 0.187, \"Acousticness\": 0.143, \"Liveness\": 0.118, \"Tempo\": 122.074, \"Duration (ms)\": 203145.0, \"Valence\": 0.394, \"Chord\": \"F\"}, {\"Index\": 764, \"Highest Charting Position\": 129, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Qui\\u00e9reme Mientras Se Pueda\", \"Streams\": 4899440, \"Artist\": \"Manuel Turizo\", \"Artist Followers\": 7909963.0, \"Song ID\": \"34LI7rwi9H8w2S5KTHnv1M\", \"Genre\": \"['colombian pop', 'latin', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 74.0, \"Danceability\": 0.793, \"Energy\": 0.782, \"Loudness\": -3.945, \"Speechiness\": 0.0582, \"Acousticness\": 0.447, \"Liveness\": 0.124, \"Tempo\": 143.86, \"Duration (ms)\": 191945.0, \"Valence\": 0.81, \"Chord\": \"E\"}, {\"Index\": 765, \"Highest Charting Position\": 9, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Party Girl\", \"Streams\": 4878286, \"Artist\": \"StaySolidRocky\", \"Artist Followers\": 150587.0, \"Song ID\": \"5RqR4ZCCKJDcBLIn4sih9l\", \"Genre\": \"['melodic rap']\", \"Release Date\": \"2020-04-21\", \"Weeks Charted\": \"2020-11-20--2020-11-27\\n2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 77.0, \"Danceability\": 0.728, \"Energy\": 0.431, \"Loudness\": -9.966, \"Speechiness\": 0.0622, \"Acousticness\": 0.749, \"Liveness\": 0.0996, \"Tempo\": 130.022, \"Duration (ms)\": 147800.0, \"Valence\": 0.629, \"Chord\": \"F#/Gb\"}, {\"Index\": 766, \"Highest Charting Position\": 95, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Drankin N Smokin\", \"Streams\": 7292247, \"Artist\": \"Future, Lil Uzi Vert\", \"Artist Followers\": 10491105.0, \"Song ID\": \"0k7wmahjkn389wAZdz19Cv\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-11-13--2020-11-20\", \"Popularity\": 78.0, \"Danceability\": 0.752, \"Energy\": 0.658, \"Loudness\": -6.297, \"Speechiness\": 0.342, \"Acousticness\": 0.0421, \"Liveness\": 0.0927, \"Tempo\": 151.951, \"Duration (ms)\": 213520.0, \"Valence\": 0.387, \"Chord\": \"C\"}, {\"Index\": 767, \"Highest Charting Position\": 86, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Be Like That - feat. Swae Lee & Khalid\", \"Streams\": 5929062, \"Artist\": \"Kane Brown\", \"Artist Followers\": 3509653.0, \"Song ID\": \"5f1joOtoMeyppIcJGZQvqJ\", \"Genre\": \"['contemporary country', 'country road']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 79.0, \"Danceability\": 0.727, \"Energy\": 0.626, \"Loudness\": -8.415, \"Speechiness\": 0.0726, \"Acousticness\": 0.0469, \"Liveness\": 0.126, \"Tempo\": 86.97, \"Duration (ms)\": 191406.0, \"Valence\": 0.322, \"Chord\": \"G\"}, {\"Index\": 768, \"Highest Charting Position\": 74, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"MORE\", \"Streams\": 5602168, \"Artist\": \"K/DA, Madison Beer, (G)I-DLE, Lexie Liu, Jaira Burns, Seraphine, League of Legends\", \"Artist Followers\": 1245965.0, \"Song ID\": \"6juLaduD4STCUDWT0AYun4\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2020-10-28\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 73.0, \"Danceability\": 0.66, \"Energy\": 0.787, \"Loudness\": -4.592, \"Speechiness\": 0.032, \"Acousticness\": 0.00257, \"Liveness\": 0.323, \"Tempo\": 142.018, \"Duration (ms)\": 217088.0, \"Valence\": 0.199, \"Chord\": \"C#/Db\"}, {\"Index\": 769, \"Highest Charting Position\": 140, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Enchule\", \"Streams\": 5561227, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6096559.0, \"Song ID\": \"3ThrfRAmijYU098H9q9tAs\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 70.0, \"Danceability\": 0.763, \"Energy\": 0.666, \"Loudness\": -3.316, \"Speechiness\": 0.194, \"Acousticness\": 0.153, \"Liveness\": 0.301, \"Tempo\": 90.086, \"Duration (ms)\": 185719.0, \"Valence\": 0.587, \"Chord\": \"G\"}, {\"Index\": 770, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"Stripes Like Burberry\", \"Streams\": 5445204, \"Artist\": \"Future, Lil Uzi Vert\", \"Artist Followers\": 10491105.0, \"Song ID\": \"6lt8iodSkYWEV0ifKCSlfg\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-11-13--2020-11-20\", \"Popularity\": 56.0, \"Danceability\": 0.758, \"Energy\": 0.574, \"Loudness\": -7.833, \"Speechiness\": 0.217, \"Acousticness\": 0.216, \"Liveness\": 0.144, \"Tempo\": 144.081, \"Duration (ms)\": 274313.0, \"Valence\": 0.706, \"Chord\": \"A\"}, {\"Index\": 771, \"Highest Charting Position\": 117, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Papi Chulo\", \"Streams\": 5361669, \"Artist\": \"Octavian, Skepta\", \"Artist Followers\": 213344.0, \"Song ID\": \"6Juv5N0dNU1imms9c9u1dA\", \"Genre\": \"['afroswing', 'london rap', 'uk alternative hip hop', 'uk hip hop']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 73.0, \"Danceability\": 0.866, \"Energy\": 0.563, \"Loudness\": -6.964, \"Speechiness\": 0.108, \"Acousticness\": 0.185, \"Liveness\": 0.0889, \"Tempo\": 127.954, \"Duration (ms)\": 161668.0, \"Valence\": 0.307, \"Chord\": \"B\"}, {\"Index\": 772, \"Highest Charting Position\": 20, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"off the table (with The Weeknd)\", \"Streams\": 5308945, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"7E1jVNoWuemqUryI4FxsVD\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 67.0, \"Danceability\": 0.411, \"Energy\": 0.522, \"Loudness\": -7.295, \"Speechiness\": 0.0981, \"Acousticness\": 0.519, \"Liveness\": 0.398, \"Tempo\": 88.332, \"Duration (ms)\": 239949.0, \"Valence\": 0.382, \"Chord\": \"C\"}, {\"Index\": 773, \"Highest Charting Position\": 52, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Spicy (feat. Post Malone)\", \"Streams\": 5303146, \"Artist\": \"Ty Dolla $ign\", \"Artist Followers\": 3866304.0, \"Song ID\": \"5IUtvfNvOyVYZUa6AJFrnP\", \"Genre\": \"['hip hop', 'pop', 'pop rap', 'r&b', 'southern hip hop', 'trap', 'trap soul']\", \"Release Date\": \"2020-10-23\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 80.0, \"Danceability\": 0.782, \"Energy\": 0.51, \"Loudness\": -5.724, \"Speechiness\": 0.0419, \"Acousticness\": 0.143, \"Liveness\": 0.115, \"Tempo\": 99.993, \"Duration (ms)\": 143375.0, \"Valence\": 0.118, \"Chord\": \"E\"}, {\"Index\": 774, \"Highest Charting Position\": 124, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"Sweet Melody\", \"Streams\": 5201322, \"Artist\": \"Little Mix\", \"Artist Followers\": 9398941.0, \"Song ID\": \"76Tuo484SLohJakHLnGI3B\", \"Genre\": \"['dance pop', 'girl group', 'pop', 'post-teen pop', 'talent show', 'uk pop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\", \"Popularity\": 73.0, \"Danceability\": 0.448, \"Energy\": 0.824, \"Loudness\": -4.249, \"Speechiness\": 0.057, \"Acousticness\": 0.0739, \"Liveness\": 0.113, \"Tempo\": 119.965, \"Duration (ms)\": 213693.0, \"Valence\": 0.419, \"Chord\": \"F\"}, {\"Index\": 775, \"Highest Charting Position\": 144, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Blueberry Eyes (feat. SUGA of BTS)\", \"Streams\": 5158896, \"Artist\": \"MAX\", \"Artist Followers\": 689627.0, \"Song ID\": \"5dn6QANKbf76pANGjMBida\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'pop rap', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2020-09-15\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 72.0, \"Danceability\": 0.746, \"Energy\": 0.611, \"Loudness\": -7.034, \"Speechiness\": 0.101, \"Acousticness\": 0.454, \"Liveness\": 0.133, \"Tempo\": 149.967, \"Duration (ms)\": 172245.0, \"Valence\": 0.411, \"Chord\": \"C\"}, {\"Index\": 776, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-13--2020-11-20\", \"Song Name\": \"That\\u2019s It\", \"Streams\": 5151014, \"Artist\": \"Future, Lil Uzi Vert\", \"Artist Followers\": 10491105.0, \"Song ID\": \"5n6gBhdEjCuj3obgCoTEFD\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-11-13--2020-11-20\", \"Popularity\": 64.0, \"Danceability\": 0.94, \"Energy\": 0.532, \"Loudness\": -5.998, \"Speechiness\": 0.358, \"Acousticness\": 0.12, \"Liveness\": 0.0925, \"Tempo\": 123.043, \"Duration (ms)\": 228796.0, \"Valence\": 0.599, \"Chord\": \"B\"}, {\"Index\": 777, \"Highest Charting Position\": 157, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Promiscuous\", \"Streams\": 5083648, \"Artist\": \"Nelly Furtado, Timbaland\", \"Artist Followers\": 2688557.0, \"Song ID\": \"2gam98EZKrF9XuOkU13ApN\", \"Genre\": \"['canadian latin', 'canadian pop', 'dance pop', 'pop', 'pop rap']\", \"Release Date\": \"2006-01-01\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 82.0, \"Danceability\": 0.808, \"Energy\": 0.97, \"Loudness\": -6.098, \"Speechiness\": 0.0506, \"Acousticness\": 0.0569, \"Liveness\": 0.154, \"Tempo\": 114.328, \"Duration (ms)\": 242293.0, \"Valence\": 0.868, \"Chord\": \"A#/Bb\"}, {\"Index\": 778, \"Highest Charting Position\": 22, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"GREECE (feat. Drake)\", \"Streams\": 5043665, \"Artist\": \"DJ Khaled\", \"Artist Followers\": 6281829.0, \"Song ID\": \"35RJhm1pEovTBwnNR0zWad\", \"Genre\": \"['hip hop', 'miami hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-07-16\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 77.0, \"Danceability\": 0.695, \"Energy\": 0.343, \"Loudness\": -10.798, \"Speechiness\": 0.0432, \"Acousticness\": 0.0743, \"Liveness\": 0.107, \"Tempo\": 85.84, \"Duration (ms)\": 218902.0, \"Valence\": 0.229, \"Chord\": \"F\"}, {\"Index\": 779, \"Highest Charting Position\": 25, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"just like magic\", \"Streams\": 4980571, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"7Dx9Z6Aon1qPS2N0rHSWTe\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 69.0, \"Danceability\": 0.719, \"Energy\": 0.607, \"Loudness\": -5.156, \"Speechiness\": 0.165, \"Acousticness\": 0.08, \"Liveness\": 0.125, \"Tempo\": 128.006, \"Duration (ms)\": 149900.0, \"Valence\": 0.464, \"Chord\": \"G#/Ab\"}, {\"Index\": 780, \"Highest Charting Position\": 53, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Still Don't Know My Name\", \"Streams\": 4926802, \"Artist\": \"Labrinth\", \"Artist Followers\": 1685215.0, \"Song ID\": \"6N22FZs2ZhPBYi3b9XPajV\", \"Genre\": \"['indie poptimism', 'pop']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 80.0, \"Danceability\": 0.316, \"Energy\": 0.63, \"Loudness\": -5.963, \"Speechiness\": 0.117, \"Acousticness\": 0.471, \"Liveness\": 0.205, \"Tempo\": 89.643, \"Duration (ms)\": 153294.0, \"Valence\": 0.313, \"Chord\": \"F\"}, {\"Index\": 781, \"Highest Charting Position\": 32, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Hasta Que Dios Diga\", \"Streams\": 4899099, \"Artist\": \"Anuel AA, Bad Bunny\", \"Artist Followers\": 18306226.0, \"Song ID\": \"06s3QtMJVXw1AJX3UfvZG1\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 76.0, \"Danceability\": 0.691, \"Energy\": 0.765, \"Loudness\": -4.727, \"Speechiness\": 0.111, \"Acousticness\": 0.464, \"Liveness\": 0.203, \"Tempo\": 174.021, \"Duration (ms)\": 246000.0, \"Valence\": 0.855, \"Chord\": \"G#/Ab\"}, {\"Index\": 782, \"Highest Charting Position\": 102, \"Number of Times Charted\": 46, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Get You The Moon (feat. Sn\\u00f8w)\", \"Streams\": 4872409, \"Artist\": \"Kina\", \"Artist Followers\": 661863.0, \"Song ID\": \"4ZLzoOkj0MPWrTLvooIuaa\", \"Genre\": \"['sad rap']\", \"Release Date\": \"2018-10-08\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.498, \"Energy\": 0.235, \"Loudness\": -16.541, \"Speechiness\": 0.188, \"Acousticness\": 0.72, \"Liveness\": 0.144, \"Tempo\": 118.917, \"Duration (ms)\": 179080.0, \"Valence\": 0.0895, \"Chord\": \"C#/Db\"}, {\"Index\": 783, \"Highest Charting Position\": 162, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Moonwalking in Calabasas (feat. Blueface) - Remix\", \"Streams\": 4863053, \"Artist\": \"DDG\", \"Artist Followers\": 486194.0, \"Song ID\": \"7o4gBbTM6UBLkOYPw9xMCz\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2020-12-02\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 74.0, \"Danceability\": 0.928, \"Energy\": 0.341, \"Loudness\": -10.196, \"Speechiness\": 0.103, \"Acousticness\": 0.0614, \"Liveness\": 0.162, \"Tempo\": 129.966, \"Duration (ms)\": 170233.0, \"Valence\": 0.745, \"Chord\": \"B\"}, {\"Index\": 784, \"Highest Charting Position\": 29, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Forever After All\", \"Streams\": 4746415, \"Artist\": \"Luke Combs\", \"Artist Followers\": 5371000.0, \"Song ID\": \"6IBcOGPsniK3Pso1wHIhew\", \"Genre\": \"['contemporary country']\", \"Release Date\": \"2020-10-23\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 80.0, \"Danceability\": 0.487, \"Energy\": 0.65, \"Loudness\": -5.195, \"Speechiness\": 0.0253, \"Acousticness\": 0.191, \"Liveness\": 0.0933, \"Tempo\": 151.964, \"Duration (ms)\": 232533.0, \"Valence\": 0.456, \"Chord\": \"C\"}, {\"Index\": 785, \"Highest Charting Position\": 76, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Lean (feat. Towy, Osquel, Beltito & Sammy & Falsetto)\", \"Streams\": 4739241, \"Artist\": \"Super Yei, Jone Quest\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 786, \"Highest Charting Position\": 156, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"SLOW DANCING IN THE DARK\", \"Streams\": 4732343, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"0rKtyWc8bvkriBthvHKY8d\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2018-10-26\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-05-08--2020-05-15\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.515, \"Energy\": 0.479, \"Loudness\": -7.458, \"Speechiness\": 0.0261, \"Acousticness\": 0.544, \"Liveness\": 0.191, \"Tempo\": 88.964, \"Duration (ms)\": 209274.0, \"Valence\": 0.284, \"Chord\": \"D#/Eb\"}, {\"Index\": 787, \"Highest Charting Position\": 92, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Don Don\", \"Streams\": 4731423, \"Artist\": \"Daddy Yankee, Anuel AA, Kendo Kaponi\", \"Artist Followers\": 23936368.0, \"Song ID\": \"3kml9ZdpT7UYk1ugkjqOzt\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-11\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 69.0, \"Danceability\": 0.838, \"Energy\": 0.819, \"Loudness\": -4.681, \"Speechiness\": 0.211, \"Acousticness\": 0.285, \"Liveness\": 0.224, \"Tempo\": 105.027, \"Duration (ms)\": 275893.0, \"Valence\": 0.656, \"Chord\": \"F\"}, {\"Index\": 788, \"Highest Charting Position\": 5, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"my future\", \"Streams\": 4721082, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"3YUMWmx8EJq0DurfuIwoGh\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2021-07-30\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 80.0, \"Danceability\": 0.456, \"Energy\": 0.285, \"Loudness\": -10.755, \"Speechiness\": 0.0979, \"Acousticness\": 0.814, \"Liveness\": 0.307, \"Tempo\": 104.89, \"Duration (ms)\": 210005.0, \"Valence\": 0.0809, \"Chord\": \"G#/Ab\"}, {\"Index\": 789, \"Highest Charting Position\": 163, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Nada\", \"Streams\": 4713873, \"Artist\": \"Cali Y El Dandee, Danna Paola\", \"Artist Followers\": 3152313.0, \"Song ID\": \"4K8cyoCDovlc4FvtUr2Hfx\", \"Genre\": \"['champeta', 'colombian pop', 'electro latino', 'latin', 'latin pop', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2020-11-13--2020-11-20\\n2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 76.0, \"Danceability\": 0.684, \"Energy\": 0.808, \"Loudness\": -2.737, \"Speechiness\": 0.061, \"Acousticness\": 0.0518, \"Liveness\": 0.0858, \"Tempo\": 173.905, \"Duration (ms)\": 174027.0, \"Valence\": 0.712, \"Chord\": \"C\"}, {\"Index\": 790, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"safety net (feat. Ty Dolla $ign)\", \"Streams\": 5798744, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"14gkWVFMwdxBMyqBw1wmIg\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 70.0, \"Danceability\": 0.552, \"Energy\": 0.599, \"Loudness\": -5.75, \"Speechiness\": 0.0404, \"Acousticness\": 0.0703, \"Liveness\": 0.0986, \"Tempo\": 161.884, \"Duration (ms)\": 208457.0, \"Valence\": 0.0916, \"Chord\": \"C#/Db\"}, {\"Index\": 791, \"Highest Charting Position\": 31, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"shut up\", \"Streams\": 5282490, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3ko9jEHNt4O5fjKN65ULJp\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 63.0, \"Danceability\": 0.499, \"Energy\": 0.462, \"Loudness\": -5.308, \"Speechiness\": 0.0312, \"Acousticness\": 0.801, \"Liveness\": 0.0946, \"Tempo\": 127.698, \"Duration (ms)\": 157710.0, \"Valence\": 0.599, \"Chord\": \"C\"}, {\"Index\": 792, \"Highest Charting Position\": 42, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"nasty\", \"Streams\": 5249342, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"0sci7ppTZFm4mjcH3nu8yO\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 69.0, \"Danceability\": 0.772, \"Energy\": 0.506, \"Loudness\": -6.558, \"Speechiness\": 0.139, \"Acousticness\": 0.0814, \"Liveness\": 0.182, \"Tempo\": 127.894, \"Duration (ms)\": 200733.0, \"Valence\": 0.456, \"Chord\": \"F#/Gb\"}, {\"Index\": 793, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-11-06--2020-11-13\", \"Song Name\": \"TRAGIC (feat. Youngboy Never Broke Again & Internet Money)\", \"Streams\": 5226940, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"13EW51DKru044OJDJ9Bm8o\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-11-06--2020-11-13\", \"Popularity\": 76.0, \"Danceability\": 0.779, \"Energy\": 0.642, \"Loudness\": -6.321, \"Speechiness\": 0.116, \"Acousticness\": 0.0383, \"Liveness\": 0.2, \"Tempo\": 82.363, \"Duration (ms)\": 153147.0, \"Valence\": 0.388, \"Chord\": \"G#/Ab\"}, {\"Index\": 794, \"Highest Charting Position\": 49, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Ayer Me Llam\\u00f3 Mi Ex (feat. Lenny Santos)\", \"Streams\": 5220504, \"Artist\": \"KHEA\", \"Artist Followers\": 3198705.0, \"Song ID\": \"6C6mUonH6MNdSg5pw7kOc9\", \"Genre\": \"['argentine hip hop', 'trap argentino', 'trap latino', 'trap triste']\", \"Release Date\": \"2020-08-20\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 71.0, \"Danceability\": 0.752, \"Energy\": 0.716, \"Loudness\": -5.2, \"Speechiness\": 0.0325, \"Acousticness\": 0.254, \"Liveness\": 0.243, \"Tempo\": 117.007, \"Duration (ms)\": 206760.0, \"Valence\": 0.553, \"Chord\": \"A#/Bb\"}, {\"Index\": 795, \"Highest Charting Position\": 119, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Madrid (feat. Myke Towers)\", \"Streams\": 5064484, \"Artist\": \"Maluma\", \"Artist Followers\": 26784251.0, \"Song ID\": \"19OXtYzrJyCrQvTbfukt4H\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 73.0, \"Danceability\": 0.764, \"Energy\": 0.741, \"Loudness\": -3.617, \"Speechiness\": 0.101, \"Acousticness\": 0.239, \"Liveness\": 0.107, \"Tempo\": 170.081, \"Duration (ms)\": 198570.0, \"Valence\": 0.802, \"Chord\": \"A\"}, {\"Index\": 796, \"Highest Charting Position\": 85, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Caramelo - Remix\", \"Streams\": 5033798, \"Artist\": \"Ozuna, KAROL G, Myke Towers\", \"Artist Followers\": 29238936.0, \"Song ID\": \"2uu2aGqA2UblCg581Q7l1g\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-08-17\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 72.0, \"Danceability\": 0.754, \"Energy\": 0.796, \"Loudness\": -3.743, \"Speechiness\": 0.139, \"Acousticness\": 0.062, \"Liveness\": 0.204, \"Tempo\": 168.045, \"Duration (ms)\": 233160.0, \"Valence\": 0.62, \"Chord\": \"D#/Eb\"}, {\"Index\": 797, \"Highest Charting Position\": 25, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Mr. Right Now (feat. Drake)\", \"Streams\": 4951481, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"4Q34FP1AT7GEl9oLgNtiWj\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 75.0, \"Danceability\": 0.647, \"Energy\": 0.667, \"Loudness\": -5.563, \"Speechiness\": 0.304, \"Acousticness\": 0.231, \"Liveness\": 0.133, \"Tempo\": 172.08, \"Duration (ms)\": 193839.0, \"Valence\": 0.704, \"Chord\": \"F\"}, {\"Index\": 798, \"Highest Charting Position\": 41, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Got It On Me\", \"Streams\": 4924030, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"25zlnOAzbVoOzIeXSvQFf1\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 78.0, \"Danceability\": 0.688, \"Energy\": 0.647, \"Loudness\": -7.258, \"Speechiness\": 0.19, \"Acousticness\": 0.00815, \"Liveness\": 0.095, \"Tempo\": 88.834, \"Duration (ms)\": 164580.0, \"Valence\": 0.195, \"Chord\": \"D\"}, {\"Index\": 799, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"my hair\", \"Streams\": 4896521, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"6u7gmPOz7pzzaeR9xSBpsR\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 66.0, \"Danceability\": 0.686, \"Energy\": 0.526, \"Loudness\": -6.842, \"Speechiness\": 0.0374, \"Acousticness\": 0.0815, \"Liveness\": 0.144, \"Tempo\": 92.013, \"Duration (ms)\": 158436.0, \"Valence\": 0.372, \"Chord\": \"C\"}, {\"Index\": 800, \"Highest Charting Position\": 59, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"obvious\", \"Streams\": 4865084, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"0q85C1JiECyYIQthz1posA\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\", \"Popularity\": 65.0, \"Danceability\": 0.624, \"Energy\": 0.672, \"Loudness\": -5.334, \"Speechiness\": 0.106, \"Acousticness\": 0.0967, \"Liveness\": 0.155, \"Tempo\": 159.852, \"Duration (ms)\": 146959.0, \"Valence\": 0.26, \"Chord\": \"C\"}, {\"Index\": 801, \"Highest Charting Position\": 30, \"Number of Times Charted\": 45, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Beautiful People (feat. Khalid)\", \"Streams\": 4813796, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"4evmHXcjt3bTUHD1cvny97\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.64, \"Energy\": 0.648, \"Loudness\": -8.113, \"Speechiness\": 0.187, \"Acousticness\": 0.124, \"Liveness\": 0.0802, \"Tempo\": 92.977, \"Duration (ms)\": 197867.0, \"Valence\": 0.548, \"Chord\": \"F\"}, {\"Index\": 802, \"Highest Charting Position\": 29, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Favorito\", \"Streams\": 4787127, \"Artist\": \"Camilo\", \"Artist Followers\": 10580764.0, \"Song ID\": \"0Snbzbd74RLfL0i4nn1vU5\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-26\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 73.0, \"Danceability\": 0.611, \"Energy\": 0.851, \"Loudness\": -2.982, \"Speechiness\": 0.0598, \"Acousticness\": 0.229, \"Liveness\": 0.232, \"Tempo\": 178.032, \"Duration (ms)\": 211613.0, \"Valence\": 0.823, \"Chord\": \"A\"}, {\"Index\": 803, \"Highest Charting Position\": 42, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"After Party\", \"Streams\": 4784580, \"Artist\": \"Don Toliver\", \"Artist Followers\": 1606884.0, \"Song ID\": \"527k23H0A4Q0UJN3vGs0Da\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 80.0, \"Danceability\": 0.629, \"Energy\": 0.692, \"Loudness\": -8.045, \"Speechiness\": 0.0376, \"Acousticness\": 0.00981, \"Liveness\": 0.603, \"Tempo\": 162.948, \"Duration (ms)\": 167916.0, \"Valence\": 0.453, \"Chord\": \"F\"}, {\"Index\": 804, \"Highest Charting Position\": 14, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Rojo\", \"Streams\": 4773792, \"Artist\": \"J Balvin\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3zR9JVqHsILrkNyCOqA6jM\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2020-11-06--2020-11-13\\n2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 0.0, \"Danceability\": 0.652, \"Energy\": 0.595, \"Loudness\": -4.04, \"Speechiness\": 0.117, \"Acousticness\": 0.15, \"Liveness\": 0.0836, \"Tempo\": 172.277, \"Duration (ms)\": 151147.0, \"Valence\": 0.421, \"Chord\": \"B\"}, {\"Index\": 805, \"Highest Charting Position\": 51, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"six thirty\", \"Streams\": 10941573, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"2IKJtXeR5UsaUjZB46fTOK\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 63.0, \"Danceability\": 0.739, \"Energy\": 0.516, \"Loudness\": -7.154, \"Speechiness\": 0.0539, \"Acousticness\": 0.67, \"Liveness\": 0.151, \"Tempo\": 120.109, \"Duration (ms)\": 183874.0, \"Valence\": 0.434, \"Chord\": \"C\"}, {\"Index\": 806, \"Highest Charting Position\": 65, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"love language\", \"Streams\": 9399230, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"6NYtLvyThMT0oALFdJFdzq\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 62.0, \"Danceability\": 0.688, \"Energy\": 0.573, \"Loudness\": -5.03, \"Speechiness\": 0.208, \"Acousticness\": 0.0686, \"Liveness\": 0.0749, \"Tempo\": 110.034, \"Duration (ms)\": 179861.0, \"Valence\": 0.553, \"Chord\": \"A#/Bb\"}, {\"Index\": 807, \"Highest Charting Position\": 66, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"west side\", \"Streams\": 9397167, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"1whfVLMKWqAX3uk97VXsNN\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 62.0, \"Danceability\": 0.688, \"Energy\": 0.455, \"Loudness\": -8.632, \"Speechiness\": 0.199, \"Acousticness\": 0.186, \"Liveness\": 0.0794, \"Tempo\": 87.865, \"Duration (ms)\": 132279.0, \"Valence\": 0.557, \"Chord\": \"B\"}, {\"Index\": 808, \"Highest Charting Position\": 146, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Thriller\", \"Streams\": 5605234, \"Artist\": \"Michael Jackson\", \"Artist Followers\": 19345579.0, \"Song ID\": \"7azo4rpSUh8nXgtonC6Pkq\", \"Genre\": \"['pop', 'r&b', 'soul']\", \"Release Date\": \"2017-09-27\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 68.0, \"Danceability\": 0.764, \"Energy\": 0.887, \"Loudness\": -3.726, \"Speechiness\": 0.0744, \"Acousticness\": 0.0816, \"Liveness\": 0.847, \"Tempo\": 118.427, \"Duration (ms)\": 358053.0, \"Valence\": 0.72, \"Chord\": \"B\"}, {\"Index\": 809, \"Highest Charting Position\": 105, \"Number of Times Charted\": 26, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Dancing With A Stranger (with Normani)\", \"Streams\": 5229835, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"6Qs4SXO9dwPj5GKvVOv8Ki\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2019-01-11\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.741, \"Energy\": 0.52, \"Loudness\": -7.513, \"Speechiness\": 0.0656, \"Acousticness\": 0.45, \"Liveness\": 0.222, \"Tempo\": 102.998, \"Duration (ms)\": 171030.0, \"Valence\": 0.347, \"Chord\": \"G#/Ab\"}, {\"Index\": 810, \"Highest Charting Position\": 91, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Angeklagt\", \"Streams\": 5226264, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"5eu4Lxm5TlI0tKSTTDWJAT\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-10-29\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\", \"Popularity\": 60.0, \"Danceability\": 0.658, \"Energy\": 0.624, \"Loudness\": -9.155, \"Speechiness\": 0.0915, \"Acousticness\": 0.171, \"Liveness\": 0.116, \"Tempo\": 181.942, \"Duration (ms)\": 168991.0, \"Valence\": 0.314, \"Chord\": \"C#/Db\"}, {\"Index\": 811, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Kids Again\", \"Streams\": 5103194, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"1ABS9lKaZ1uXkXCqr9zFO7\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 62.0, \"Danceability\": 0.666, \"Energy\": 0.726, \"Loudness\": -2.998, \"Speechiness\": 0.0262, \"Acousticness\": 0.486, \"Liveness\": 0.0892, \"Tempo\": 128.044, \"Duration (ms)\": 207528.0, \"Valence\": 0.468, \"Chord\": \"B\"}, {\"Index\": 812, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-30--2020-11-06\", \"Song Name\": \"Highway to Hell\", \"Streams\": 5096618, \"Artist\": \"AC/DC\", \"Artist Followers\": 20110171.0, \"Song ID\": \"2zYzyRzz6pRmhPzyfMEC8s\", \"Genre\": \"['australian rock', 'hard rock', 'rock']\", \"Release Date\": \"1979-07-27\", \"Weeks Charted\": \"2020-10-30--2020-11-06\", \"Popularity\": 83.0, \"Danceability\": 0.574, \"Energy\": 0.913, \"Loudness\": -4.793, \"Speechiness\": 0.133, \"Acousticness\": 0.061, \"Liveness\": 0.156, \"Tempo\": 115.728, \"Duration (ms)\": 208400.0, \"Valence\": 0.423, \"Chord\": \"F#/Gb\"}, {\"Index\": 813, \"Highest Charting Position\": 38, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Me Gusta (with Cardi B & Myke Towers)\", \"Streams\": 4914412, \"Artist\": \"Anitta\", \"Artist Followers\": 10741972.0, \"Song ID\": \"7e1VoRlNumuEkXlITMHKLE\", \"Genre\": \"['funk carioca', 'funk pop', 'pagode baiano', 'pop nacional']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\", \"Popularity\": 72.0, \"Danceability\": 0.91, \"Energy\": 0.604, \"Loudness\": -4.392, \"Speechiness\": 0.082, \"Acousticness\": 0.448, \"Liveness\": 0.0863, \"Tempo\": 110.075, \"Duration (ms)\": 180788.0, \"Valence\": 0.807, \"Chord\": \"F#/Gb\"}, {\"Index\": 814, \"Highest Charting Position\": 133, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"24 (feat. Lil Baby)\", \"Streams\": 4904772, \"Artist\": \"Money Man\", \"Artist Followers\": 345027.0, \"Song ID\": \"0xUvi7wldroBzaZCengPa5\", \"Genre\": \"['memphis hip hop', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 74.0, \"Danceability\": 0.868, \"Energy\": 0.638, \"Loudness\": -7.746, \"Speechiness\": 0.0736, \"Acousticness\": 0.146, \"Liveness\": 0.0931, \"Tempo\": 126.03, \"Duration (ms)\": 182857.0, \"Valence\": 0.459, \"Chord\": \"D\"}, {\"Index\": 815, \"Highest Charting Position\": 23, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Relaci\\u00f3n\", \"Streams\": 4825749, \"Artist\": \"Sech\", \"Artist Followers\": 8766508.0, \"Song ID\": \"35UUpTmrcFXNIVIN26ujXl\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-04-10--2020-04-17\", \"Popularity\": 80.0, \"Danceability\": 0.793, \"Energy\": 0.771, \"Loudness\": -3.417, \"Speechiness\": 0.0959, \"Acousticness\": 0.0337, \"Liveness\": 0.284, \"Tempo\": 171.943, \"Duration (ms)\": 247308.0, \"Valence\": 0.835, \"Chord\": \"F\"}, {\"Index\": 816, \"Highest Charting Position\": 14, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"FRANCHISE (feat. Young Thug & M.I.A.)\", \"Streams\": 4821213, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"4jVBIpuOiMj1crqd8LoCrJ\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-10-30--2020-11-06\\n2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 74.0, \"Danceability\": 0.835, \"Energy\": 0.699, \"Loudness\": -5.405, \"Speechiness\": 0.277, \"Acousticness\": 0.00671, \"Liveness\": 0.195, \"Tempo\": 154.981, \"Duration (ms)\": 202795.0, \"Valence\": 0.547, \"Chord\": \"G#/Ab\"}, {\"Index\": 817, \"Highest Charting Position\": 11, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Bet You Wanna (feat. Cardi B)\", \"Streams\": 6846771, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"7iAgNZdotu40NwtoIWJHFe\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 67.0, \"Danceability\": 0.653, \"Energy\": 0.662, \"Loudness\": -6.168, \"Speechiness\": 0.162, \"Acousticness\": 0.00465, \"Liveness\": 0.0626, \"Tempo\": 111.712, \"Duration (ms)\": 161168.0, \"Valence\": 0.674, \"Chord\": \"G\"}, {\"Index\": 818, \"Highest Charting Position\": 82, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Wolves (feat. Post Malone)\", \"Streams\": 5547002, \"Artist\": \"Big Sean\", \"Artist Followers\": 8673345.0, \"Song ID\": \"33gwZOGJWEZ7dRWPqPxBEZ\", \"Genre\": \"['detroit hip hop', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 79.0, \"Danceability\": 0.724, \"Energy\": 0.675, \"Loudness\": -5.267, \"Speechiness\": 0.0867, \"Acousticness\": 0.0978, \"Liveness\": 0.351, \"Tempo\": 160.048, \"Duration (ms)\": 199758.0, \"Valence\": 0.325, \"Chord\": \"D\"}, {\"Index\": 819, \"Highest Charting Position\": 88, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"thank u, next\", \"Streams\": 5079328, \"Artist\": \"Ariana Grande\", \"Artist Followers\": 67208170.0, \"Song ID\": \"3e9HZxeyfWwjeyPAMmWSSQ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-02-08\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.717, \"Energy\": 0.653, \"Loudness\": -5.634, \"Speechiness\": 0.0658, \"Acousticness\": 0.229, \"Liveness\": 0.101, \"Tempo\": 106.966, \"Duration (ms)\": 207320.0, \"Valence\": 0.412, \"Chord\": \"C#/Db\"}, {\"Index\": 820, \"Highest Charting Position\": 19, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"MAMACITA\", \"Streams\": 5016343, \"Artist\": \"Black Eyed Peas, Ozuna, J. Rey Soul\", \"Artist Followers\": 5966748.0, \"Song ID\": \"14wf185UxfNbSy8dwt4r4q\", \"Genre\": \"['dance pop', 'pop', 'pop rap']\", \"Release Date\": \"2020-04-10\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 74.0, \"Danceability\": 0.894, \"Energy\": 0.635, \"Loudness\": -6.929, \"Speechiness\": 0.0473, \"Acousticness\": 0.193, \"Liveness\": 0.0823, \"Tempo\": 105.013, \"Duration (ms)\": 249143.0, \"Valence\": 0.428, \"Chord\": \"D\"}, {\"Index\": 821, \"Highest Charting Position\": 137, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Fake\", \"Streams\": 5010179, \"Artist\": \"Lauv, Conan Gray\", \"Artist Followers\": 4442273.0, \"Song ID\": \"4Gt2kh3QbAGU6yquOWn4aW\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-13\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\", \"Popularity\": 73.0, \"Danceability\": 0.703, \"Energy\": 0.657, \"Loudness\": -5.363, \"Speechiness\": 0.0783, \"Acousticness\": 0.139, \"Liveness\": 0.093, \"Tempo\": 82.96, \"Duration (ms)\": 146375.0, \"Valence\": 0.455, \"Chord\": \"E\"}, {\"Index\": 822, \"Highest Charting Position\": 56, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"OK Not To Be OK\", \"Streams\": 4980744, \"Artist\": \"Marshmello, Demi Lovato\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6PiO7fUEPKnJfaCQbPrIyg\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\", \"Popularity\": 0.0, \"Danceability\": 0.743, \"Energy\": 0.837, \"Loudness\": -5.025, \"Speechiness\": 0.0649, \"Acousticness\": 0.0172, \"Liveness\": 0.0743, \"Tempo\": 103.072, \"Duration (ms)\": 159863.0, \"Valence\": 0.263, \"Chord\": \"C#/Db\"}, {\"Index\": 823, \"Highest Charting Position\": 1, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"THE SCOTTS\", \"Streams\": 4941592, \"Artist\": \"THE SCOTTS, Travis Scott, Kid Cudi\", \"Artist Followers\": 179193.0, \"Song ID\": \"39Yp9wwQiSRIDOvrVg7mbk\", \"Genre\": \"['pop rap']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 79.0, \"Danceability\": 0.716, \"Energy\": 0.537, \"Loudness\": -7.648, \"Speechiness\": 0.0514, \"Acousticness\": 0.233, \"Liveness\": 0.157, \"Tempo\": 129.979, \"Duration (ms)\": 165978.0, \"Valence\": 0.28, \"Chord\": \"C\"}, {\"Index\": 824, \"Highest Charting Position\": 37, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Mamichula - con Nicki Nicole\", \"Streams\": 4817969, \"Artist\": \"Trueno, Bizarrap, Taiu, TATOOL\", \"Artist Followers\": 2172969.0, \"Song ID\": \"0TUW9faHNaBmi89wsYGp9y\", \"Genre\": \"['argentine hip hop', 'trap argentino', 'trap latino']\", \"Release Date\": \"2020-07-23\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 75.0, \"Danceability\": 0.696, \"Energy\": 0.678, \"Loudness\": -5.893, \"Speechiness\": 0.0735, \"Acousticness\": 0.582, \"Liveness\": 0.134, \"Tempo\": 91.985, \"Duration (ms)\": 219202.0, \"Valence\": 0.346, \"Chord\": \"E\"}, {\"Index\": 825, \"Highest Charting Position\": 172, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Let Her Go\", \"Streams\": 4765198, \"Artist\": \"Passenger\", \"Artist Followers\": 2819406.0, \"Song ID\": \"0JmiBCpWc1IAc0et7Xm7FL\", \"Genre\": \"['folk-pop', 'neo mellow', 'pop', 'pop rock']\", \"Release Date\": \"2013-02-17\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 75.0, \"Danceability\": 0.479, \"Energy\": 0.545, \"Loudness\": -7.346, \"Speechiness\": 0.0688, \"Acousticness\": 0.365, \"Liveness\": 0.0963, \"Tempo\": 74.897, \"Duration (ms)\": 252733.0, \"Valence\": 0.243, \"Chord\": \"G\"}, {\"Index\": 826, \"Highest Charting Position\": 26, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Play Date\", \"Streams\": 4745568, \"Artist\": \"Melanie Martinez\", \"Artist Followers\": 10925614.0, \"Song ID\": \"4DpNNXFMMxQEKl7r0ykkWA\", \"Genre\": \"['alt z', 'electropop', 'modern rock', 'pop']\", \"Release Date\": \"2015-08-14\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 80.0, \"Danceability\": 0.68, \"Energy\": 0.729, \"Loudness\": -5.077, \"Speechiness\": 0.0475, \"Acousticness\": 0.612, \"Liveness\": 0.224, \"Tempo\": 123.97, \"Duration (ms)\": 179867.0, \"Valence\": 0.446, \"Chord\": \"F\"}, {\"Index\": 827, \"Highest Charting Position\": 32, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Lose Somebody\", \"Streams\": 4709053, \"Artist\": \"Kygo, OneRepublic\", \"Artist Followers\": 7593792.0, \"Song ID\": \"1sgDyuLooyvEML4oHspNza\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 75.0, \"Danceability\": 0.58, \"Energy\": 0.586, \"Loudness\": -6.883, \"Speechiness\": 0.0357, \"Acousticness\": 0.344, \"Liveness\": 0.0755, \"Tempo\": 147.988, \"Duration (ms)\": 199549.0, \"Valence\": 0.507, \"Chord\": \"C#/Db\"}, {\"Index\": 828, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-23--2020-10-30\", \"Song Name\": \"Someone Like You\", \"Streams\": 4703672, \"Artist\": \"Adele\", \"Artist Followers\": 28335338.0, \"Song ID\": \"1zwMYTA5nlNjZxYrvBB2pV\", \"Genre\": \"['british soul', 'pop', 'pop soul', 'uk pop']\", \"Release Date\": \"2011-01-24\", \"Weeks Charted\": \"2020-10-23--2020-10-30\", \"Popularity\": 77.0, \"Danceability\": 0.556, \"Energy\": 0.319, \"Loudness\": -8.251, \"Speechiness\": 0.0281, \"Acousticness\": 0.893, \"Liveness\": 0.0996, \"Tempo\": 135.187, \"Duration (ms)\": 285240.0, \"Valence\": 0.294, \"Chord\": \"A\"}, {\"Index\": 829, \"Highest Charting Position\": 73, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"It's You\", \"Streams\": 4674658, \"Artist\": \"Ali Gatie\", \"Artist Followers\": 1758300.0, \"Song ID\": \"5DqdesEfbRyOlSS3Tf6c29\", \"Genre\": \"['canadian hip hop', 'pop']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-10-23--2020-10-30\\n2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.732, \"Energy\": 0.463, \"Loudness\": -6.972, \"Speechiness\": 0.0287, \"Acousticness\": 0.374, \"Liveness\": 0.194, \"Tempo\": 95.971, \"Duration (ms)\": 212607.0, \"Valence\": 0.397, \"Chord\": \"B\"}, {\"Index\": 830, \"Highest Charting Position\": 68, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Stunnin' (feat. Harm Franklin)\", \"Streams\": 5183246, \"Artist\": \"Curtis Waters\", \"Artist Followers\": 68875.0, \"Song ID\": \"2JSmxLqt8h7ZpJJkfuLJvK\", \"Genre\": \"[]\", \"Release Date\": \"2020-10-09\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 68.0, \"Danceability\": 0.885, \"Energy\": 0.685, \"Loudness\": -6.429, \"Speechiness\": 0.0627, \"Acousticness\": 0.33, \"Liveness\": 0.148, \"Tempo\": 99.954, \"Duration (ms)\": 144000.0, \"Valence\": 0.937, \"Chord\": \"B\"}, {\"Index\": 831, \"Highest Charting Position\": 35, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Love To Hate Me\", \"Streams\": 5125708, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"7iKDsPfLT0d5mu2htfMKBZ\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 69.0, \"Danceability\": 0.686, \"Energy\": 0.64, \"Loudness\": -5.491, \"Speechiness\": 0.159, \"Acousticness\": 0.0334, \"Liveness\": 0.0801, \"Tempo\": 162.225, \"Duration (ms)\": 171798.0, \"Valence\": 0.597, \"Chord\": \"G#/Ab\"}, {\"Index\": 832, \"Highest Charting Position\": 165, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Hate The Way (feat. blackbear)\", \"Streams\": 5116071, \"Artist\": \"G-Eazy\", \"Artist Followers\": 4894656.0, \"Song ID\": \"3QGppKBPd9gHOgHJzRbVIw\", \"Genre\": \"['hip hop', 'indie pop rap', 'oakland hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-10-16\", \"Weeks Charted\": \"2020-10-16--2020-10-23\", \"Popularity\": 68.0, \"Danceability\": 0.569, \"Energy\": 0.865, \"Loudness\": -3.844, \"Speechiness\": 0.266, \"Acousticness\": 0.0673, \"Liveness\": 0.312, \"Tempo\": 82.011, \"Duration (ms)\": 214363.0, \"Valence\": 0.361, \"Chord\": \"E\"}, {\"Index\": 833, \"Highest Charting Position\": 89, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Bande organis\\u00e9e\", \"Streams\": 5112572, \"Artist\": \"13 Organis\\u00e9, SCH, Kofs, Jul, Naps, Soso Maness, Elams, Solda, Houari\", \"Artist Followers\": 249910.0, \"Song ID\": \"205HNJ73cgpC0LAOnuQiWT\", \"Genre\": \"['french hip hop', 'pop urbaine', 'rap francais', 'rap marseille']\", \"Release Date\": \"2020-08-15\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 72.0, \"Danceability\": 0.901, \"Energy\": 0.939, \"Loudness\": -2.762, \"Speechiness\": 0.274, \"Acousticness\": 0.117, \"Liveness\": 0.0643, \"Tempo\": 142.948, \"Duration (ms)\": 356347.0, \"Valence\": 0.805, \"Chord\": \"F#/Gb\"}, {\"Index\": 834, \"Highest Charting Position\": 32, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Crazy Over You\", \"Streams\": 5056387, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"7qq0EOPW4RRlqdvMBmdd73\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 68.0, \"Danceability\": 0.804, \"Energy\": 0.633, \"Loudness\": -6.186, \"Speechiness\": 0.0612, \"Acousticness\": 0.0371, \"Liveness\": 0.102, \"Tempo\": 115.002, \"Duration (ms)\": 163946.0, \"Valence\": 0.67, \"Chord\": \"E\"}, {\"Index\": 835, \"Highest Charting Position\": 109, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-09--2020-10-16\", \"Song Name\": \"Baby, I'm Jealous (feat. Doja Cat)\", \"Streams\": 4870203, \"Artist\": \"Bebe Rexha\", \"Artist Followers\": 6569150.0, \"Song ID\": \"2fTdRdN73RgIgcUZN33dvt\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-10-09\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\", \"Popularity\": 69.0, \"Danceability\": 0.737, \"Energy\": 0.867, \"Loudness\": -2.259, \"Speechiness\": 0.0458, \"Acousticness\": 0.0398, \"Liveness\": 0.32, \"Tempo\": 98.05, \"Duration (ms)\": 175873.0, \"Valence\": 0.506, \"Chord\": \"B\"}, {\"Index\": 836, \"Highest Charting Position\": 15, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"TKN (feat. Travis Scott)\", \"Streams\": 4752289, \"Artist\": \"ROSAL\\u00cdA\", \"Artist Followers\": 4769627.0, \"Song ID\": \"4w47S36wQGBhGg073q3nt7\", \"Genre\": \"['r&b en espanol']\", \"Release Date\": \"2020-05-28\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 75.0, \"Danceability\": 0.776, \"Energy\": 0.509, \"Loudness\": -6.266, \"Speechiness\": 0.467, \"Acousticness\": 0.192, \"Liveness\": 0.115, \"Tempo\": 94.634, \"Duration (ms)\": 129371.0, \"Valence\": 0.485, \"Chord\": \"C\"}, {\"Index\": 837, \"Highest Charting Position\": 135, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"El Mismo Aire - con Pablo Albor\\u00e1n\", \"Streams\": 4705484, \"Artist\": \"Camilo\", \"Artist Followers\": 10580764.0, \"Song ID\": \"5EbtodsuLbxrFDH6j5avVS\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-06-10\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 75.0, \"Danceability\": 0.483, \"Energy\": 0.492, \"Loudness\": -6.591, \"Speechiness\": 0.295, \"Acousticness\": 0.603, \"Liveness\": 0.323, \"Tempo\": 144.511, \"Duration (ms)\": 188213.0, \"Valence\": 0.66, \"Chord\": \"C\"}, {\"Index\": 838, \"Highest Charting Position\": 18, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Yo Perreo Sola\", \"Streams\": 4680447, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0SqqAgdovOE24BzxIClpjw\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 78.0, \"Danceability\": 0.86, \"Energy\": 0.758, \"Loudness\": -5.16, \"Speechiness\": 0.0695, \"Acousticness\": 0.021, \"Liveness\": 0.344, \"Tempo\": 97.014, \"Duration (ms)\": 172127.0, \"Valence\": 0.453, \"Chord\": \"B\"}, {\"Index\": 839, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-16--2020-10-23\", \"Song Name\": \"Let Me Love You Like A Woman\", \"Streams\": 4665053, \"Artist\": \"Lana Del Rey\", \"Artist Followers\": 13697048.0, \"Song ID\": \"1gxdWpeOUBpvB908fiZs4D\", \"Genre\": \"['art pop', 'pop']\", \"Release Date\": \"2021-03-19\", \"Weeks Charted\": \"2020-10-16--2020-10-23\", \"Popularity\": 67.0, \"Danceability\": 0.303, \"Energy\": 0.249, \"Loudness\": -11.715, \"Speechiness\": 0.111, \"Acousticness\": 0.97, \"Liveness\": 0.117, \"Tempo\": 66.932, \"Duration (ms)\": 200661.0, \"Valence\": 0.131, \"Chord\": \"C\"}, {\"Index\": 840, \"Highest Charting Position\": 69, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"DOLLAZ ON MY HEAD (feat. Young Thug)\", \"Streams\": 4652712, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"3nS9a01VvXHQriLqJYwRqG\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 76.0, \"Danceability\": 0.825, \"Energy\": 0.458, \"Loudness\": -7.47, \"Speechiness\": 0.0577, \"Acousticness\": 0.114, \"Liveness\": 0.102, \"Tempo\": 145.115, \"Duration (ms)\": 197760.0, \"Valence\": 0.161, \"Chord\": \"C\"}, {\"Index\": 841, \"Highest Charting Position\": 54, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Eleg\\u00ed (feat. D\\u00edmelo Flow)\", \"Streams\": 4607003, \"Artist\": \"Rauw Alejandro, Dalex, Lenny Tav\\u00e1rez\", \"Artist Followers\": 6096559.0, \"Song ID\": \"50ZC4PM7hywH27RcCfViau\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-03-26\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 75.0, \"Danceability\": 0.824, \"Energy\": 0.631, \"Loudness\": -2.791, \"Speechiness\": 0.0809, \"Acousticness\": 0.237, \"Liveness\": 0.0531, \"Tempo\": 171.965, \"Duration (ms)\": 197721.0, \"Valence\": 0.678, \"Chord\": \"C\"}, {\"Index\": 842, \"Highest Charting Position\": 77, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"July\", \"Streams\": 4598766, \"Artist\": \"Noah Cyrus\", \"Artist Followers\": 891555.0, \"Song ID\": \"6J2LdBN97cDWn0MLxYh9HB\", \"Genre\": \"['alt z', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.708, \"Energy\": 0.186, \"Loudness\": -8.953, \"Speechiness\": 0.042, \"Acousticness\": 0.868, \"Liveness\": 0.0779, \"Tempo\": 72.541, \"Duration (ms)\": 156106.0, \"Valence\": 0.322, \"Chord\": \"A\"}, {\"Index\": 843, \"Highest Charting Position\": 93, \"Number of Times Charted\": 38, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Bruises\", \"Streams\": 4560503, \"Artist\": \"Lewis Capaldi\", \"Artist Followers\": 8388838.0, \"Song ID\": \"4Of7rzpRpV1mWRbhp5rAqG\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2020-10-16--2020-10-23\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.736, \"Energy\": 0.308, \"Loudness\": -7.83, \"Speechiness\": 0.0677, \"Acousticness\": 0.946, \"Liveness\": 0.186, \"Tempo\": 111.202, \"Duration (ms)\": 220492.0, \"Valence\": 0.361, \"Chord\": \"E\"}, {\"Index\": 844, \"Highest Charting Position\": 46, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"You Never Know\", \"Streams\": 5304382, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"3b7trEcKoglybN5MxGuSaw\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2021-08-03\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 54.0, \"Danceability\": 0.535, \"Energy\": 0.434, \"Loudness\": -5.768, \"Speechiness\": 0.0505, \"Acousticness\": 0.405, \"Liveness\": 0.253, \"Tempo\": 144.497, \"Duration (ms)\": 229236.0, \"Valence\": 0.271, \"Chord\": \"F\"}, {\"Index\": 845, \"Highest Charting Position\": 12, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Supalonely\", \"Streams\": 5089970, \"Artist\": \"BENEE, Gus Dapperton\", \"Artist Followers\": 638337.0, \"Song ID\": \"4nK5YrxbMGZstTLbvj6Gxw\", \"Genre\": \"['alt z', 'nz pop', 'pop']\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 77.0, \"Danceability\": 0.863, \"Energy\": 0.631, \"Loudness\": -4.689, \"Speechiness\": 0.0534, \"Acousticness\": 0.305, \"Liveness\": 0.123, \"Tempo\": 128.977, \"Duration (ms)\": 223480.0, \"Valence\": 0.817, \"Chord\": \"G\"}, {\"Index\": 846, \"Highest Charting Position\": 53, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Glock In My Lap\", \"Streams\": 4947593, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"6pcywuOeGGWeOQzdUyti6k\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\", \"Popularity\": 69.0, \"Danceability\": 0.847, \"Energy\": 0.733, \"Loudness\": -6.439, \"Speechiness\": 0.16, \"Acousticness\": 0.00574, \"Liveness\": 0.151, \"Tempo\": 130.029, \"Duration (ms)\": 193591.0, \"Valence\": 0.202, \"Chord\": \"A#/Bb\"}, {\"Index\": 847, \"Highest Charting Position\": 49, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Better\", \"Streams\": 4933462, \"Artist\": \"ZAYN\", \"Artist Followers\": 16655692.0, \"Song ID\": \"1dLXLETYiZohIZWnse4ypG\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-01-03--2020-01-10\", \"Popularity\": 68.0, \"Danceability\": 0.637, \"Energy\": 0.418, \"Loudness\": -7.137, \"Speechiness\": 0.301, \"Acousticness\": 0.353, \"Liveness\": 0.131, \"Tempo\": 84.295, \"Duration (ms)\": 174517.0, \"Valence\": 0.0807, \"Chord\": \"D\"}, {\"Index\": 848, \"Highest Charting Position\": 59, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"forget me too (feat. Halsey)\", \"Streams\": 4751756, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3868320.0, \"Song ID\": \"1VSuFS7PahCN3SWbOcQ98m\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 78.0, \"Danceability\": 0.654, \"Energy\": 0.875, \"Loudness\": -4.845, \"Speechiness\": 0.0744, \"Acousticness\": 0.000417, \"Liveness\": 0.194, \"Tempo\": 99.975, \"Duration (ms)\": 171621.0, \"Valence\": 0.522, \"Chord\": \"C#/Db\"}, {\"Index\": 849, \"Highest Charting Position\": 110, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Oh Juliana\", \"Streams\": 4751064, \"Artist\": \"Niack\", \"Artist Followers\": 352402.0, \"Song ID\": \"4xWzZmX4K1yyrdtRfbUvjt\", \"Genre\": \"['funk carioca']\", \"Release Date\": \"2020-06-30\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 66.0, \"Danceability\": 0.799, \"Energy\": 0.568, \"Loudness\": -3.089, \"Speechiness\": 0.25, \"Acousticness\": 0.387, \"Liveness\": 0.0892, \"Tempo\": 129.63, \"Duration (ms)\": 153078.0, \"Valence\": 0.963, \"Chord\": \"F#/Gb\"}, {\"Index\": 850, \"Highest Charting Position\": 81, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"PORFA Remix ( Feat. Maluma, Nicky Jam, Sech) - Remix\", \"Streams\": 4727923, \"Artist\": \"Feid, J Balvin, Justin Quiles\", \"Artist Followers\": 613348.0, \"Song ID\": \"7lUdbnz7wsv3C9zzf4WHl9\", \"Genre\": \"['colombian pop', 'latin', 'pop reggaeton', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 70.0, \"Danceability\": 0.793, \"Energy\": 0.737, \"Loudness\": -4.731, \"Speechiness\": 0.0785, \"Acousticness\": 0.0765, \"Liveness\": 0.0747, \"Tempo\": 167.969, \"Duration (ms)\": 333800.0, \"Valence\": 0.697, \"Chord\": \"F#/Gb\"}, {\"Index\": 851, \"Highest Charting Position\": 108, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"No Guidance (feat. Drake)\", \"Streams\": 4641393, \"Artist\": \"Chris Brown\", \"Artist Followers\": 14073083.0, \"Song ID\": \"6XHVuErjQ4XNm6nDPVCxVX\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'r&b', 'rap']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-10-09--2020-10-16\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.696, \"Energy\": 0.454, \"Loudness\": -6.756, \"Speechiness\": 0.153, \"Acousticness\": 0.123, \"Liveness\": 0.155, \"Tempo\": 92.928, \"Duration (ms)\": 260640.0, \"Valence\": 0.136, \"Chord\": \"C#/Db\"}, {\"Index\": 852, \"Highest Charting Position\": 65, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Rich Nigga Shit (feat. Young Thug)\", \"Streams\": 9129562, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"3ruoIF2UnoXdzK8mR61ebq\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 73.0, \"Danceability\": 0.825, \"Energy\": 0.733, \"Loudness\": -5.625, \"Speechiness\": 0.0969, \"Acousticness\": 0.349, \"Liveness\": 0.112, \"Tempo\": 97.974, \"Duration (ms)\": 190331.0, \"Valence\": 0.62, \"Chord\": \"C#/Db\"}, {\"Index\": 853, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Many Men\", \"Streams\": 8675173, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"3CDVMejYHnB1SkEEx0T1N4\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 65.0, \"Danceability\": 0.635, \"Energy\": 0.793, \"Loudness\": -4.333, \"Speechiness\": 0.0322, \"Acousticness\": 0.000647, \"Liveness\": 0.113, \"Tempo\": 77.594, \"Duration (ms)\": 201856.0, \"Valence\": 0.281, \"Chord\": \"A#/Bb\"}, {\"Index\": 854, \"Highest Charting Position\": 77, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Slidin\", \"Streams\": 8243488, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"7fxSLnklnayJNBIKntXedZ\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 64.0, \"Danceability\": 0.774, \"Energy\": 0.706, \"Loudness\": -6.494, \"Speechiness\": 0.355, \"Acousticness\": 0.00163, \"Liveness\": 0.104, \"Tempo\": 152.891, \"Duration (ms)\": 185037.0, \"Valence\": 0.382, \"Chord\": \"D\"}, {\"Index\": 855, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Outta Time (feat. Drake)\", \"Streams\": 7762934, \"Artist\": \"Bryson Tiller\", \"Artist Followers\": 5019909.0, \"Song ID\": \"4SCnCPOUOUXUmCX2uHb3r7\", \"Genre\": \"['kentucky hip hop', 'pop', 'pop rap', 'r&b', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 68.0, \"Danceability\": 0.714, \"Energy\": 0.582, \"Loudness\": -7.272, \"Speechiness\": 0.0808, \"Acousticness\": 0.0129, \"Liveness\": 0.0774, \"Tempo\": 92.819, \"Duration (ms)\": 198822.0, \"Valence\": 0.338, \"Chord\": \"F\"}, {\"Index\": 856, \"Highest Charting Position\": 131, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"My Dawg\", \"Streams\": 6029118, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"42Tohunwlh34o0mgxYx5iq\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 60.0, \"Danceability\": 0.831, \"Energy\": 0.532, \"Loudness\": -5.319, \"Speechiness\": 0.301, \"Acousticness\": 0.0652, \"Liveness\": 0.464, \"Tempo\": 140.105, \"Duration (ms)\": 181716.0, \"Valence\": 0.364, \"Chord\": \"C\"}, {\"Index\": 857, \"Highest Charting Position\": 138, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Snitches & Rats (feat. Young Nudy)\", \"Streams\": 5846760, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"3WaDoMDQRqDdgtCDLxanpN\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 57.0, \"Danceability\": 0.821, \"Energy\": 0.671, \"Loudness\": -5.893, \"Speechiness\": 0.18, \"Acousticness\": 0.00843, \"Liveness\": 0.0972, \"Tempo\": 145.953, \"Duration (ms)\": 187773.0, \"Valence\": 0.494, \"Chord\": \"A\"}, {\"Index\": 858, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Brand New Draco\", \"Streams\": 5841110, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"4V9ynsDPwHtdItksqjuRu0\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 63.0, \"Danceability\": 0.697, \"Energy\": 0.709, \"Loudness\": -6.642, \"Speechiness\": 0.298, \"Acousticness\": 0.041, \"Liveness\": 0.0886, \"Tempo\": 155.023, \"Duration (ms)\": 202420.0, \"Valence\": 0.439, \"Chord\": \"B\"}, {\"Index\": 859, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Lemonade (Feat. Roddy Ricch & Don Toliver) [Remix]\", \"Streams\": 5550390, \"Artist\": \"Internet Money\", \"Artist Followers\": 412466.0, \"Song ID\": \"5sBplhIrmzA4kQGyIOpmDf\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-09-30\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 69.0, \"Danceability\": 0.832, \"Energy\": 0.549, \"Loudness\": -8.259, \"Speechiness\": 0.0602, \"Acousticness\": 0.168, \"Liveness\": 0.11, \"Tempo\": 140.045, \"Duration (ms)\": 181496.0, \"Valence\": 0.384, \"Chord\": \"C#/Db\"}, {\"Index\": 860, \"Highest Charting Position\": 77, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Your Man\", \"Streams\": 5233336, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"6Vgtvd7I5yopJdBuxqjBd2\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-24\", \"Weeks Charted\": \"2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\", \"Popularity\": 68.0, \"Danceability\": 0.785, \"Energy\": 0.818, \"Loudness\": -8.711, \"Speechiness\": 0.099, \"Acousticness\": 0.624, \"Liveness\": 0.149, \"Tempo\": 117.98, \"Duration (ms)\": 163759.0, \"Valence\": 0.0503, \"Chord\": \"G\"}, {\"Index\": 861, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"No Opp Left Behind\", \"Streams\": 5154955, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"50I7FNN2rl2rWiNwGxS146\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 61.0, \"Danceability\": 0.823, \"Energy\": 0.703, \"Loudness\": -2.691, \"Speechiness\": 0.298, \"Acousticness\": 0.0161, \"Liveness\": 0.294, \"Tempo\": 178.043, \"Duration (ms)\": 194214.0, \"Valence\": 0.26, \"Chord\": \"G#/Ab\"}, {\"Index\": 862, \"Highest Charting Position\": 106, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Lets Link\", \"Streams\": 5109038, \"Artist\": \"WhoHeem\", \"Artist Followers\": 25417.0, \"Song ID\": \"6fMzgFFGzWCwiHMzDzNpp5\", \"Genre\": \"['viral rap']\", \"Release Date\": \"2020-08-20\", \"Weeks Charted\": \"2020-10-02--2020-10-09\\n2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 61.0, \"Danceability\": 0.839, \"Energy\": 0.683, \"Loudness\": -9.232, \"Speechiness\": 0.165, \"Acousticness\": 0.00667, \"Liveness\": 0.241, \"Tempo\": 120.003, \"Duration (ms)\": 159955.0, \"Valence\": 0.522, \"Chord\": \"A#/Bb\"}, {\"Index\": 863, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"RIP Luv\", \"Streams\": 4915080, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"1wGnp7ejkCuXRsehXx0PNP\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 62.0, \"Danceability\": 0.63, \"Energy\": 0.399, \"Loudness\": -9.869, \"Speechiness\": 0.178, \"Acousticness\": 0.105, \"Liveness\": 0.234, \"Tempo\": 183.016, \"Duration (ms)\": 214192.0, \"Valence\": 0.0657, \"Chord\": \"F\"}, {\"Index\": 864, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-10-02--2020-10-09\", \"Song Name\": \"Steppin On Niggas\", \"Streams\": 4853661, \"Artist\": \"21 Savage, Metro Boomin\", \"Artist Followers\": 9949044.0, \"Song ID\": \"7FtZFla3ZH6PqsAJ9MvVCM\", \"Genre\": \"['atl hip hop', 'hip hop', 'rap', 'trap']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-10-02--2020-10-09\", \"Popularity\": 57.0, \"Danceability\": 0.849, \"Energy\": 0.635, \"Loudness\": -4.068, \"Speechiness\": 0.254, \"Acousticness\": 0.000608, \"Liveness\": 0.062, \"Tempo\": 89.484, \"Duration (ms)\": 140833.0, \"Valence\": 0.798, \"Chord\": \"G\"}, {\"Index\": 865, \"Highest Charting Position\": 58, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Gimme Love\", \"Streams\": 7471309, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"2hfoyc7ve6xM4ZEiNIiU1B\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-04-16\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 69.0, \"Danceability\": 0.482, \"Energy\": 0.631, \"Loudness\": -6.917, \"Speechiness\": 0.0986, \"Acousticness\": 0.696, \"Liveness\": 0.209, \"Tempo\": 126.576, \"Duration (ms)\": 214558.0, \"Valence\": 0.0743, \"Chord\": \"F\"}, {\"Index\": 866, \"Highest Charting Position\": 97, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Ew\", \"Streams\": 6936305, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"7xcUWyLh6fIMsYjoVI7NnZ\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 67.0, \"Danceability\": 0.48, \"Energy\": 0.373, \"Loudness\": -9.297, \"Speechiness\": 0.0278, \"Acousticness\": 0.804, \"Liveness\": 0.12, \"Tempo\": 114.078, \"Duration (ms)\": 207710.0, \"Valence\": 0.0376, \"Chord\": \"A#/Bb\"}, {\"Index\": 867, \"Highest Charting Position\": 99, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Daylight\", \"Streams\": 6819838, \"Artist\": \"Joji, Diplo\", \"Artist Followers\": 4759367.0, \"Song ID\": \"6Ed1q0X8oSKSm4IIhiQbYg\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-08-06\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-08-07--2020-08-14\", \"Popularity\": 72.0, \"Danceability\": 0.528, \"Energy\": 0.749, \"Loudness\": -7.571, \"Speechiness\": 0.0479, \"Acousticness\": 0.00488, \"Liveness\": 0.0949, \"Tempo\": 163.944, \"Duration (ms)\": 163906.0, \"Valence\": 0.729, \"Chord\": \"G\"}, {\"Index\": 868, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Epidemic\", \"Streams\": 6292620, \"Artist\": \"Polo G\", \"Artist Followers\": 4849204.0, \"Song ID\": \"170DNUSnQRp1tGpppF26pA\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 71.0, \"Danceability\": 0.616, \"Energy\": 0.617, \"Loudness\": -8.431, \"Speechiness\": 0.52, \"Acousticness\": 0.128, \"Liveness\": 0.177, \"Tempo\": 175.929, \"Duration (ms)\": 177273.0, \"Valence\": 0.476, \"Chord\": \"C#/Db\"}, {\"Index\": 869, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"bloody valentine\", \"Streams\": 6032935, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3868320.0, \"Song ID\": \"6mADjHs6FXdroPzEGW6KVJ\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 77.0, \"Danceability\": 0.533, \"Energy\": 0.858, \"Loudness\": -4.212, \"Speechiness\": 0.0766, \"Acousticness\": 0.00021, \"Liveness\": 0.148, \"Tempo\": 160.057, \"Duration (ms)\": 205159.0, \"Valence\": 0.506, \"Chord\": \"D\"}, {\"Index\": 870, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"MODUS\", \"Streams\": 6013371, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"5SjtAe7xzUgHDtNTmt8zS7\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 66.0, \"Danceability\": 0.738, \"Energy\": 0.533, \"Loudness\": -7.617, \"Speechiness\": 0.0492, \"Acousticness\": 0.183, \"Liveness\": 0.115, \"Tempo\": 132.008, \"Duration (ms)\": 207265.0, \"Valence\": 0.262, \"Chord\": \"G\"}, {\"Index\": 871, \"Highest Charting Position\": 145, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Tick Tock\", \"Streams\": 5547939, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"5E7p95xh9Ul4vZp4LEoJwi\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 65.0, \"Danceability\": 0.781, \"Energy\": 0.613, \"Loudness\": -5.582, \"Speechiness\": 0.0524, \"Acousticness\": 0.0399, \"Liveness\": 0.0976, \"Tempo\": 80.53, \"Duration (ms)\": 132215.0, \"Valence\": 0.613, \"Chord\": \"E\"}, {\"Index\": 872, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Sanctuary\", \"Streams\": 5482390, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"3xaugmCyXrVkrDTXbFkMW3\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2019-06-14\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 69.0, \"Danceability\": 0.552, \"Energy\": 0.65, \"Loudness\": -7.199, \"Speechiness\": 0.128, \"Acousticness\": 0.422, \"Liveness\": 0.372, \"Tempo\": 167.788, \"Duration (ms)\": 180019.0, \"Valence\": 0.316, \"Chord\": \"C#/Db\"}, {\"Index\": 873, \"Highest Charting Position\": 112, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"feel something\", \"Streams\": 5463424, \"Artist\": \"Bea Miller\", \"Artist Followers\": 2396662.0, \"Song ID\": \"7JDWhC422Gtk1Bq0mL3OTC\", \"Genre\": \"['alt z', 'dance pop', 'electropop', 'indie cafe pop', 'indie poptimism', 'modern rock', 'pop', 'pop rap', 'post-teen pop', 'talent show']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 75.0, \"Danceability\": 0.74, \"Energy\": 0.415, \"Loudness\": -8.914, \"Speechiness\": 0.0707, \"Acousticness\": 0.242, \"Liveness\": 0.319, \"Tempo\": 136.029, \"Duration (ms)\": 180161.0, \"Valence\": 0.156, \"Chord\": \"C\"}, {\"Index\": 874, \"Highest Charting Position\": 86, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Tap In\", \"Streams\": 5220309, \"Artist\": \"Saweetie\", \"Artist Followers\": 1255573.0, \"Song ID\": \"4Hpib09wXgD84w4uwTPnYD\", \"Genre\": \"['cali rap', 'dance pop', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-06-17\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 73.0, \"Danceability\": 0.954, \"Energy\": 0.696, \"Loudness\": -7.117, \"Speechiness\": 0.204, \"Acousticness\": 0.00576, \"Liveness\": 0.0754, \"Tempo\": 100.036, \"Duration (ms)\": 139413.0, \"Valence\": 0.432, \"Chord\": \"A#/Bb\"}, {\"Index\": 875, \"Highest Charting Position\": 171, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Pretty Boy (feat. Lil Yachty)\", \"Streams\": 5141212, \"Artist\": \"Joji\", \"Artist Followers\": 4759367.0, \"Song ID\": \"0f1G5SHFoFC9lO03gHCGVS\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 66.0, \"Danceability\": 0.656, \"Energy\": 0.776, \"Loudness\": -6.184, \"Speechiness\": 0.0672, \"Acousticness\": 0.16, \"Liveness\": 0.372, \"Tempo\": 156.049, \"Duration (ms)\": 156759.0, \"Valence\": 0.638, \"Chord\": \"F#/Gb\"}, {\"Index\": 876, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"Afterthought\", \"Streams\": 4977405, \"Artist\": \"Joji, BENEE\", \"Artist Followers\": 4759367.0, \"Song ID\": \"6zvqq50PL7io0rprbkrYc9\", \"Genre\": \"['alternative r&b', 'viral pop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 67.0, \"Danceability\": 0.668, \"Energy\": 0.547, \"Loudness\": -8.024, \"Speechiness\": 0.0353, \"Acousticness\": 0.398, \"Liveness\": 0.0931, \"Tempo\": 83.5, \"Duration (ms)\": 194871.0, \"Valence\": 0.192, \"Chord\": \"C#/Db\"}, {\"Index\": 877, \"Highest Charting Position\": 164, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"+Linda\", \"Streams\": 4964708, \"Artist\": \"Dalex\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-08-28--2020-09-04\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 878, \"Highest Charting Position\": 24, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Over Now (with The Weeknd)\", \"Streams\": 4867620, \"Artist\": \"Calvin Harris\", \"Artist Followers\": 21946934.0, \"Song ID\": \"58AGoOGbwsQMhBbH0eFLRR\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'house', 'pop', 'progressive house', 'uk dance']\", \"Release Date\": \"2020-08-28\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 72.0, \"Danceability\": 0.612, \"Energy\": 0.884, \"Loudness\": -4.113, \"Speechiness\": 0.0454, \"Acousticness\": 0.0759, \"Liveness\": 0.247, \"Tempo\": 178.043, \"Duration (ms)\": 210795.0, \"Valence\": 0.679, \"Chord\": \"E\"}, {\"Index\": 879, \"Highest Charting Position\": 14, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Hate The Other Side (with Marshmello & The Kid Laroi)\", \"Streams\": 4851997, \"Artist\": \"Juice WRLD, Polo G\", \"Artist Followers\": 19102888.0, \"Song ID\": \"0ada5XsQGLPUVbmTCkAP49\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 78.0, \"Danceability\": 0.701, \"Energy\": 0.65, \"Loudness\": -6.313, \"Speechiness\": 0.104, \"Acousticness\": 0.291, \"Liveness\": 0.112, \"Tempo\": 90.003, \"Duration (ms)\": 160212.0, \"Valence\": 0.647, \"Chord\": \"F#/Gb\"}, {\"Index\": 880, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-25--2020-10-02\", \"Song Name\": \"drunk face\", \"Streams\": 4834258, \"Artist\": \"Machine Gun Kelly\", \"Artist Followers\": 3868320.0, \"Song ID\": \"3k0YJnqMKRZb8swo86vCkq\", \"Genre\": \"['ohio hip hop', 'pop rap']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-09-25--2020-10-02\", \"Popularity\": 72.0, \"Danceability\": 0.691, \"Energy\": 0.77, \"Loudness\": -4.578, \"Speechiness\": 0.0367, \"Acousticness\": 0.0282, \"Liveness\": 0.497, \"Tempo\": 90.024, \"Duration (ms)\": 143901.0, \"Valence\": 0.344, \"Chord\": \"G\"}, {\"Index\": 881, \"Highest Charting Position\": 76, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Tak Tiki Tak\", \"Streams\": 4761286, \"Artist\": \"Harry Nach\", \"Artist Followers\": 134339.0, \"Song ID\": \"7gwwt1IaAWwmB7af0AcuBM\", \"Genre\": \"['trap chileno', 'trap latino']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\", \"Popularity\": 71.0, \"Danceability\": 0.801, \"Energy\": 0.579, \"Loudness\": -4.78, \"Speechiness\": 0.0813, \"Acousticness\": 0.333, \"Liveness\": 0.172, \"Tempo\": 99.994, \"Duration (ms)\": 212406.0, \"Valence\": 0.231, \"Chord\": \"B\"}, {\"Index\": 882, \"Highest Charting Position\": 26, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"WHATS POPPIN\", \"Streams\": 4745752, \"Artist\": \"Jack Harlow\", \"Artist Followers\": 3828418.0, \"Song ID\": \"2MbdDtCv5LUVjYy9RuGTgC\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-06-24\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 80.0, \"Danceability\": 0.904, \"Energy\": 0.723, \"Loudness\": -5.224, \"Speechiness\": 0.26, \"Acousticness\": 0.0631, \"Liveness\": 0.185, \"Tempo\": 145.013, \"Duration (ms)\": 227478.0, \"Valence\": 0.835, \"Chord\": \"B\"}, {\"Index\": 883, \"Highest Charting Position\": 143, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Money Trees\", \"Streams\": 4632724, \"Artist\": \"Kendrick Lamar, Jay Rock\", \"Artist Followers\": 17931101.0, \"Song ID\": \"2HbKqm4o0w5wEeEFXm2sD4\", \"Genre\": \"['conscious hip hop', 'hip hop', 'rap', 'west coast rap']\", \"Release Date\": \"2012\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 75.0, \"Danceability\": 0.716, \"Energy\": 0.531, \"Loudness\": -7.355, \"Speechiness\": 0.122, \"Acousticness\": 0.0703, \"Liveness\": 0.224, \"Tempo\": 71.994, \"Duration (ms)\": 386907.0, \"Valence\": 0.344, \"Chord\": \"G\"}, {\"Index\": 884, \"Highest Charting Position\": 65, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Blastoff (feat. Juice Wrld & Trippie Redd)\", \"Streams\": 4628159, \"Artist\": \"Internet Money, Diplo\", \"Artist Followers\": 412466.0, \"Song ID\": \"2rFsFjq0D9JAmc0APpCO6P\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-08-29\", \"Weeks Charted\": \"2020-09-25--2020-10-02\\n2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 70.0, \"Danceability\": 0.761, \"Energy\": 0.517, \"Loudness\": -6.916, \"Speechiness\": 0.0927, \"Acousticness\": 0.114, \"Liveness\": 0.157, \"Tempo\": 147.912, \"Duration (ms)\": 174730.0, \"Valence\": 0.46, \"Chord\": \"F\"}, {\"Index\": 885, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"September\", \"Streams\": 5329256, \"Artist\": \"Earth, Wind & Fire\", \"Artist Followers\": 3008916.0, \"Song ID\": \"2grjqo0Frpf2okIBiifQKs\", \"Genre\": \"['disco', 'funk', 'jazz funk', 'motown', 'quiet storm', 'soul']\", \"Release Date\": \"1978-11-23\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 80.0, \"Danceability\": 0.697, \"Energy\": 0.832, \"Loudness\": -7.264, \"Speechiness\": 0.0298, \"Acousticness\": 0.168, \"Liveness\": 0.269, \"Tempo\": 125.926, \"Duration (ms)\": 215093.0, \"Valence\": 0.979, \"Chord\": \"A\"}, {\"Index\": 886, \"Highest Charting Position\": 64, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Secrets\", \"Streams\": 5178107, \"Artist\": \"Regard, RAYE\", \"Artist Followers\": 152237.0, \"Song ID\": \"66W1rVTnEv86dIkFhoiElg\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop edm', 'slap house', 'tropical house']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 78.0, \"Danceability\": 0.848, \"Energy\": 0.768, \"Loudness\": -5.386, \"Speechiness\": 0.0373, \"Acousticness\": 0.0412, \"Liveness\": 0.195, \"Tempo\": 118.961, \"Duration (ms)\": 176767.0, \"Valence\": 0.777, \"Chord\": \"F#/Gb\"}, {\"Index\": 887, \"Highest Charting Position\": 150, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"21\", \"Streams\": 5151406, \"Artist\": \"Polo G\", \"Artist Followers\": 4849204.0, \"Song ID\": \"3JKgcAa7r07ocVWcV8bS0H\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 80.0, \"Danceability\": 0.783, \"Energy\": 0.479, \"Loudness\": -10.646, \"Speechiness\": 0.541, \"Acousticness\": 0.149, \"Liveness\": 0.101, \"Tempo\": 176.027, \"Duration (ms)\": 163798.0, \"Valence\": 0.533, \"Chord\": \"G\"}, {\"Index\": 888, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"BXL ZOO\", \"Streams\": 5101640, \"Artist\": \"Damso, Hamza\", \"Artist Followers\": 3071170.0, \"Song ID\": \"1VBt9dPtYfLnVeKaa6CQPr\", \"Genre\": \"['belgian hip hop', 'french hip hop', 'pop urbaine', 'rap belge', 'rap conscient']\", \"Release Date\": \"2021-04-28\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 62.0, \"Danceability\": 0.745, \"Energy\": 0.656, \"Loudness\": -6.829, \"Speechiness\": 0.203, \"Acousticness\": 0.0604, \"Liveness\": 0.11, \"Tempo\": 137.997, \"Duration (ms)\": 201333.0, \"Valence\": 0.405, \"Chord\": \"B\"}, {\"Index\": 889, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"DEUX TOILES DE MER\", \"Streams\": 5094137, \"Artist\": \"Damso\", \"Artist Followers\": 3071170.0, \"Song ID\": \"6vw0mOQ5vm3C5RPm7Rvl2w\", \"Genre\": \"['belgian hip hop', 'french hip hop', 'pop urbaine', 'rap belge', 'rap conscient']\", \"Release Date\": \"2021-04-28\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 62.0, \"Danceability\": 0.521, \"Energy\": 0.39, \"Loudness\": -9.726, \"Speechiness\": 0.128, \"Acousticness\": 0.582, \"Liveness\": 0.112, \"Tempo\": 104.106, \"Duration (ms)\": 315640.0, \"Valence\": 0.157, \"Chord\": \"G#/Ab\"}, {\"Index\": 890, \"Highest Charting Position\": 4, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"exile (feat. Bon Iver)\", \"Streams\": 4924533, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"4pvb0WLRcMtbPGmtejJJ6y\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 77.0, \"Danceability\": 0.298, \"Energy\": 0.38, \"Loudness\": -8.426, \"Speechiness\": 0.0287, \"Acousticness\": 0.778, \"Liveness\": 0.11, \"Tempo\": 75.602, \"Duration (ms)\": 285634.0, \"Valence\": 0.152, \"Chord\": \"F#/Gb\"}, {\"Index\": 891, \"Highest Charting Position\": 10, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Righteous\", \"Streams\": 4819362, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5dOxHHMOFAbG3VH23t0xNm\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 78.0, \"Danceability\": 0.706, \"Energy\": 0.625, \"Loudness\": -7.426, \"Speechiness\": 0.0314, \"Acousticness\": 0.0417, \"Liveness\": 0.129, \"Tempo\": 142.948, \"Duration (ms)\": 242181.0, \"Valence\": 0.225, \"Chord\": \"C\"}, {\"Index\": 892, \"Highest Charting Position\": 9, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Conversations\", \"Streams\": 4805366, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4K06PO78fW4mnBVenxGNob\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 75.0, \"Danceability\": 0.747, \"Energy\": 0.622, \"Loudness\": -5.825, \"Speechiness\": 0.0838, \"Acousticness\": 0.176, \"Liveness\": 0.151, \"Tempo\": 159.93, \"Duration (ms)\": 181661.0, \"Valence\": 0.57, \"Chord\": \"B\"}, {\"Index\": 893, \"Highest Charting Position\": 181, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Dolly (with Lil Uzi Vert)\", \"Streams\": 4800543, \"Artist\": \"Lil Tecca\", \"Artist Followers\": 4022792.0, \"Song ID\": \"77Xwqkw7VrV8E5FCq9JhO8\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 63.0, \"Danceability\": 0.664, \"Energy\": 0.586, \"Loudness\": -7.813, \"Speechiness\": 0.238, \"Acousticness\": 0.212, \"Liveness\": 0.216, \"Tempo\": 88.502, \"Duration (ms)\": 179813.0, \"Valence\": 0.589, \"Chord\": \"G\"}, {\"Index\": 894, \"Highest Charting Position\": 23, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Chicago Freestyle (feat. Giveon)\", \"Streams\": 4799038, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"4wVOKKEHUJxHCFFNUWDn0B\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 80.0, \"Danceability\": 0.735, \"Energy\": 0.449, \"Loudness\": -7.507, \"Speechiness\": 0.347, \"Acousticness\": 0.629, \"Liveness\": 0.113, \"Tempo\": 122.947, \"Duration (ms)\": 220488.0, \"Valence\": 0.0397, \"Chord\": \"A#/Bb\"}, {\"Index\": 895, \"Highest Charting Position\": 4, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"GOOBA\", \"Streams\": 4690955, \"Artist\": \"6ix9ine\", \"Artist Followers\": 6514102.0, \"Song ID\": \"4NhDYoQTYCdWHTvlbGVgwo\", \"Genre\": \"['emo rap', 'rap']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 70.0, \"Danceability\": 0.611, \"Energy\": 0.688, \"Loudness\": -5.688, \"Speechiness\": 0.341, \"Acousticness\": 0.0264, \"Liveness\": 0.251, \"Tempo\": 178.462, \"Duration (ms)\": 132303.0, \"Valence\": 0.393, \"Chord\": \"C#/Db\"}, {\"Index\": 896, \"Highest Charting Position\": 12, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Physical\", \"Streams\": 4599807, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3AzjcOeAmA57TIOr9zF1ZW\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 77.0, \"Danceability\": 0.647, \"Energy\": 0.844, \"Loudness\": -3.756, \"Speechiness\": 0.0457, \"Acousticness\": 0.0137, \"Liveness\": 0.102, \"Tempo\": 146.967, \"Duration (ms)\": 193829.0, \"Valence\": 0.746, \"Chord\": \"C\"}, {\"Index\": 897, \"Highest Charting Position\": 194, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Hot Stuff\", \"Streams\": 4569978, \"Artist\": \"Kygo, Donna Summer\", \"Artist Followers\": 7593792.0, \"Song ID\": \"00ETaeHUQ6lops3oWU1Wrt\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 71.0, \"Danceability\": 0.681, \"Energy\": 0.773, \"Loudness\": -5.749, \"Speechiness\": 0.148, \"Acousticness\": 0.019, \"Liveness\": 0.11, \"Tempo\": 119.961, \"Duration (ms)\": 199008.0, \"Valence\": 0.429, \"Chord\": \"F\"}, {\"Index\": 898, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-18--2020-09-25\", \"Song Name\": \"Who's Laughing Now\", \"Streams\": 4526982, \"Artist\": \"Ava Max\", \"Artist Followers\": 3916979.0, \"Song ID\": \"1Pmp486RrLRkaEkE3HFHXP\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-09-18--2020-09-25\", \"Popularity\": 73.0, \"Danceability\": 0.648, \"Energy\": 0.641, \"Loudness\": -5.521, \"Speechiness\": 0.0389, \"Acousticness\": 0.00565, \"Liveness\": 0.109, \"Tempo\": 184.021, \"Duration (ms)\": 180348.0, \"Valence\": 0.505, \"Chord\": \"G\"}, {\"Index\": 899, \"Highest Charting Position\": 91, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Sweet but Psycho\", \"Streams\": 4502853, \"Artist\": \"Ava Max\", \"Artist Followers\": 3916979.0, \"Song ID\": \"7DnAm9FOTWE3cUvso43HhI\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-09-18\", \"Weeks Charted\": \"2020-09-18--2020-09-25\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.72, \"Energy\": 0.706, \"Loudness\": -4.719, \"Speechiness\": 0.0473, \"Acousticness\": 0.0684, \"Liveness\": 0.166, \"Tempo\": 133.002, \"Duration (ms)\": 187436.0, \"Valence\": 0.62, \"Chord\": \"C#/Db\"}, {\"Index\": 900, \"Highest Charting Position\": 83, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Del Mar\", \"Streams\": 5698099, \"Artist\": \"Ozuna, Doja Cat, Sia\", \"Artist Followers\": 29238936.0, \"Song ID\": \"5cpJFiNwYyWwFLH0V6B3N8\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 79.0, \"Danceability\": 0.759, \"Energy\": 0.636, \"Loudness\": -5.585, \"Speechiness\": 0.0369, \"Acousticness\": 0.0224, \"Liveness\": 0.166, \"Tempo\": 109.976, \"Duration (ms)\": 214507.0, \"Valence\": 0.536, \"Chord\": \"F#/Gb\"}, {\"Index\": 901, \"Highest Charting Position\": 72, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Hit Different\", \"Streams\": 5049863, \"Artist\": \"SZA, The Neptunes, Pharrell Williams, Ty Dolla $ign\", \"Artist Followers\": 5888533.0, \"Song ID\": \"7Bar1kLTmsRmH6FCKKMEyU\", \"Genre\": \"['pop', 'pop rap', 'r&b']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 74.0, \"Danceability\": 0.679, \"Energy\": 0.516, \"Loudness\": -6.371, \"Speechiness\": 0.0452, \"Acousticness\": 0.199, \"Liveness\": 0.0965, \"Tempo\": 120.074, \"Duration (ms)\": 202008.0, \"Valence\": 0.716, \"Chord\": \"C\"}, {\"Index\": 902, \"Highest Charting Position\": 65, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Nobody's Love\", \"Streams\": 4957966, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32279979.0, \"Song ID\": \"2ST72jD2KVe7f3fbcGyX1b\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2021-06-11\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 73.0, \"Danceability\": 0.485, \"Energy\": 0.567, \"Loudness\": -6.456, \"Speechiness\": 0.0388, \"Acousticness\": 0.316, \"Liveness\": 0.0949, \"Tempo\": 93.676, \"Duration (ms)\": 211254.0, \"Valence\": 0.157, \"Chord\": \"C#/Db\"}, {\"Index\": 903, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"M\\u00e1quina do Tempo\", \"Streams\": 4938139, \"Artist\": \"Matu\\u00ea\", \"Artist Followers\": 3263283.0, \"Song ID\": \"5oI9blwsXC8AkTWw6wASY8\", \"Genre\": \"['r&b brasileiro', 'rap cearense', 'trap brasileiro']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-09-11--2020-09-18\", \"Popularity\": 70.0, \"Danceability\": 0.629, \"Energy\": 0.727, \"Loudness\": -4.387, \"Speechiness\": 0.0499, \"Acousticness\": 0.0647, \"Liveness\": 0.138, \"Tempo\": 149.978, \"Duration (ms)\": 230400.0, \"Valence\": 0.132, \"Chord\": \"E\"}, {\"Index\": 904, \"Highest Charting Position\": 112, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Fuckst mich nur ab\", \"Streams\": 4898520, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"0y8mJFmm4ogCHnfe0oTuT6\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\", \"Popularity\": 63.0, \"Danceability\": 0.817, \"Energy\": 0.468, \"Loudness\": -10.945, \"Speechiness\": 0.287, \"Acousticness\": 0.233, \"Liveness\": 0.0905, \"Tempo\": 104.875, \"Duration (ms)\": 182931.0, \"Valence\": 0.237, \"Chord\": \"C#/Db\"}, {\"Index\": 905, \"Highest Charting Position\": 122, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Jangueo\", \"Streams\": 4877753, \"Artist\": \"Alex Rose, Rafa Pab\\u00f6n\", \"Artist Followers\": 2168452.0, \"Song ID\": \"1bRpSCFv6P2OUhciByeRYR\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 74.0, \"Danceability\": 0.861, \"Energy\": 0.678, \"Loudness\": -4.157, \"Speechiness\": 0.0536, \"Acousticness\": 0.253, \"Liveness\": 0.106, \"Tempo\": 103.994, \"Duration (ms)\": 259600.0, \"Valence\": 0.723, \"Chord\": \"G#/Ab\"}, {\"Index\": 906, \"Highest Charting Position\": 68, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"We Paid (feat. 42 Dugg)\", \"Streams\": 4776686, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"6gxKUmycQX7uyMwJcweFjp\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 76.0, \"Danceability\": 0.926, \"Energy\": 0.542, \"Loudness\": -5.064, \"Speechiness\": 0.293, \"Acousticness\": 0.135, \"Liveness\": 0.0877, \"Tempo\": 135.14, \"Duration (ms)\": 181929.0, \"Valence\": 0.564, \"Chord\": \"C#/Db\"}, {\"Index\": 907, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-11--2020-09-18\", \"Song Name\": \"Ihr Hobby\", \"Streams\": 4723116, \"Artist\": \"Bonez MC, Maxwell\", \"Artist Followers\": 1683006.0, \"Song ID\": \"4aZfvvgfoSfmSZpfwQYzC0\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-09-11--2020-09-18\", \"Popularity\": 59.0, \"Danceability\": 0.774, \"Energy\": 0.814, \"Loudness\": -6.145, \"Speechiness\": 0.0584, \"Acousticness\": 0.204, \"Liveness\": 0.118, \"Tempo\": 109.019, \"Duration (ms)\": 185330.0, \"Valence\": 0.254, \"Chord\": \"A#/Bb\"}, {\"Index\": 908, \"Highest Charting Position\": 150, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"When I Look At You\", \"Streams\": 4652583, \"Artist\": \"Miley Cyrus\", \"Artist Followers\": 15778531.0, \"Song ID\": \"7ywzEdEuVG1lsjsRCGJfLy\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2009-01-01\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 63.0, \"Danceability\": 0.459, \"Energy\": 0.545, \"Loudness\": -4.874, \"Speechiness\": 0.0282, \"Acousticness\": 0.142, \"Liveness\": 0.105, \"Tempo\": 137.941, \"Duration (ms)\": 248587.0, \"Valence\": 0.194, \"Chord\": \"F#/Gb\"}, {\"Index\": 909, \"Highest Charting Position\": 21, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Boss Bitch\", \"Streams\": 4620838, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"78qd8dvwea0Gosb6Fe6j3k\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-01-23\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 81.0, \"Danceability\": 0.707, \"Energy\": 0.955, \"Loudness\": -4.593, \"Speechiness\": 0.222, \"Acousticness\": 0.127, \"Liveness\": 0.202, \"Tempo\": 125.989, \"Duration (ms)\": 134240.0, \"Valence\": 0.575, \"Chord\": \"A#/Bb\"}, {\"Index\": 910, \"Highest Charting Position\": 142, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Ain't It Different (feat. AJ Tracey & Stormzy)\", \"Streams\": 4602336, \"Artist\": \"Headie One\", \"Artist Followers\": 328877.0, \"Song ID\": \"6NJfIydBMYrXvlaXsFxmc8\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2020-08-20\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 69.0, \"Danceability\": 0.767, \"Energy\": 0.569, \"Loudness\": -6.805, \"Speechiness\": 0.216, \"Acousticness\": 0.00988, \"Liveness\": 0.109, \"Tempo\": 77.052, \"Duration (ms)\": 196363.0, \"Valence\": 0.524, \"Chord\": \"E\"}, {\"Index\": 911, \"Highest Charting Position\": 75, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Some Say - Felix Jaehn Remix\", \"Streams\": 4598325, \"Artist\": \"Nea\", \"Artist Followers\": 38111.0, \"Song ID\": \"7C1trmcQQ5n5RNy4l6ziCv\", \"Genre\": \"['scandipop', 'swedish pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 77.0, \"Danceability\": 0.682, \"Energy\": 0.7, \"Loudness\": -5.591, \"Speechiness\": 0.0397, \"Acousticness\": 0.406, \"Liveness\": 0.174, \"Tempo\": 120.03, \"Duration (ms)\": 186878.0, \"Valence\": 0.637, \"Chord\": \"F#/Gb\"}, {\"Index\": 912, \"Highest Charting Position\": 13, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Savage Remix (feat. Beyonc\\u00e9)\", \"Streams\": 4568308, \"Artist\": \"Beyonc\\u00e9, Megan Thee Stallion\", \"Artist Followers\": 28335112.0, \"Song ID\": \"5v4GgrXPMghOnBBLmveLac\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'r&b']\", \"Release Date\": \"2020-04-29\", \"Weeks Charted\": \"2020-09-11--2020-09-18\\n2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 73.0, \"Danceability\": 0.822, \"Energy\": 0.743, \"Loudness\": -4.772, \"Speechiness\": 0.28, \"Acousticness\": 0.016, \"Liveness\": 0.127, \"Tempo\": 84.459, \"Duration (ms)\": 242001.0, \"Valence\": 0.636, \"Chord\": \"A#/Bb\"}, {\"Index\": 913, \"Highest Charting Position\": 115, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Lithuania (feat. Travis Scott)\", \"Streams\": 5949270, \"Artist\": \"Big Sean\", \"Artist Followers\": 8673345.0, \"Song ID\": \"4VLTxHOyFX5FRtkpsFm5Pc\", \"Genre\": \"['detroit hip hop', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-09-04\", \"Weeks Charted\": \"2020-09-04--2020-09-11\", \"Popularity\": 62.0, \"Danceability\": 0.676, \"Energy\": 0.82, \"Loudness\": -5.217, \"Speechiness\": 0.0554, \"Acousticness\": 0.0493, \"Liveness\": 0.615, \"Tempo\": 152.028, \"Duration (ms)\": 199250.0, \"Valence\": 0.618, \"Chord\": \"G\"}, {\"Index\": 914, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-09-04--2020-09-11\", \"Song Name\": \"Tap In (feat. Post Malone, DaBaby & Jack Harlow)\", \"Streams\": 5117128, \"Artist\": \"Saweetie\", \"Artist Followers\": 1255573.0, \"Song ID\": \"5woaU1FNkqCwg6WzWiQPW5\", \"Genre\": \"['cali rap', 'dance pop', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-08-28\", \"Weeks Charted\": \"2020-09-04--2020-09-11\", \"Popularity\": 64.0, \"Danceability\": 0.948, \"Energy\": 0.63, \"Loudness\": -7.011, \"Speechiness\": 0.219, \"Acousticness\": 0.00647, \"Liveness\": 0.0737, \"Tempo\": 100.032, \"Duration (ms)\": 253569.0, \"Valence\": 0.425, \"Chord\": \"C#/Db\"}, {\"Index\": 915, \"Highest Charting Position\": 91, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Not Shy\", \"Streams\": 4982232, \"Artist\": \"ITZY\", \"Artist Followers\": 2384076.0, \"Song ID\": \"4ecVWqbtW6phQGpZMAyqIU\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2020-08-17\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 73.0, \"Danceability\": 0.776, \"Energy\": 0.911, \"Loudness\": -3.08, \"Speechiness\": 0.131, \"Acousticness\": 0.155, \"Liveness\": 0.268, \"Tempo\": 101.027, \"Duration (ms)\": 177728.0, \"Valence\": 0.56, \"Chord\": \"D\"}, {\"Index\": 916, \"Highest Charting Position\": 71, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"The Plan - From the Motion Picture \\\"TENET\\\"\", \"Streams\": 4876238, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"551xyaSJsg8hILXFq9JdST\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2020-08-22\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 67.0, \"Danceability\": 0.433, \"Energy\": 0.443, \"Loudness\": -10.568, \"Speechiness\": 0.0361, \"Acousticness\": 0.0922, \"Liveness\": 0.117, \"Tempo\": 79.903, \"Duration (ms)\": 185851.0, \"Valence\": 0.0363, \"Chord\": \"C#/Db\"}, {\"Index\": 917, \"Highest Charting Position\": 152, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"ADMV\", \"Streams\": 4737291, \"Artist\": \"Maluma\", \"Artist Followers\": 26784251.0, \"Song ID\": \"3eJMSq78dDaFb7VvhNFnq6\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-04-23\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\", \"Popularity\": 72.0, \"Danceability\": 0.565, \"Energy\": 0.39, \"Loudness\": -4.959, \"Speechiness\": 0.0556, \"Acousticness\": 0.817, \"Liveness\": 0.126, \"Tempo\": 163.781, \"Duration (ms)\": 193700.0, \"Valence\": 0.708, \"Chord\": \"A\"}, {\"Index\": 918, \"Highest Charting Position\": 122, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Alane\", \"Streams\": 4668193, \"Artist\": \"Robin Schulz, Wes\", \"Artist Followers\": 2786366.0, \"Song ID\": \"2u6Jm2klS4yvAlbSHlxUwI\", \"Genre\": \"['dance pop', 'deep euro house', 'deep house', 'edm', 'german dance', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 67.0, \"Danceability\": 0.581, \"Energy\": 0.799, \"Loudness\": -6.66, \"Speechiness\": 0.164, \"Acousticness\": 0.0419, \"Liveness\": 0.11, \"Tempo\": 124.002, \"Duration (ms)\": 175016.0, \"Valence\": 0.662, \"Chord\": \"D#/Eb\"}, {\"Index\": 919, \"Highest Charting Position\": 82, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"THE BADDEST\", \"Streams\": 4642057, \"Artist\": \"K/DA, (G)I-DLE, Wolftyla, Bea Miller, League of Legends\", \"Artist Followers\": 1245965.0, \"Song ID\": \"2V4Fx72svQRxrFvNT1eq5f\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2020-08-27\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\", \"Popularity\": 70.0, \"Danceability\": 0.676, \"Energy\": 0.857, \"Loudness\": -4.368, \"Speechiness\": 0.0438, \"Acousticness\": 0.0215, \"Liveness\": 0.254, \"Tempo\": 149.981, \"Duration (ms)\": 162600.0, \"Valence\": 0.717, \"Chord\": \"A#/Bb\"}, {\"Index\": 920, \"Highest Charting Position\": 112, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Desce Pro Play (PA PA PA)\", \"Streams\": 4615520, \"Artist\": \"Mc Zaac, Anitta, Tyga\", \"Artist Followers\": 1555628.0, \"Song ID\": \"4zGtfOglDBfVUypabBwIjQ\", \"Genre\": \"['funk carioca', 'funk pop']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 68.0, \"Danceability\": 0.935, \"Energy\": 0.71, \"Loudness\": -5.085, \"Speechiness\": 0.158, \"Acousticness\": 0.0769, \"Liveness\": 0.173, \"Tempo\": 100.009, \"Duration (ms)\": 168507.0, \"Valence\": 0.635, \"Chord\": \"B\"}, {\"Index\": 921, \"Highest Charting Position\": 103, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Mariposa\", \"Streams\": 4593366, \"Artist\": \"Peach Tree Rascals\", \"Artist Followers\": 177972.0, \"Song ID\": \"4ja2gzrNh9VNigzoXfmbwD\", \"Genre\": \"['alternative r&b', 'chill r&b', 'indie r&b', 'pop']\", \"Release Date\": \"2019-08-28\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 76.0, \"Danceability\": 0.676, \"Energy\": 0.525, \"Loudness\": -5.88, \"Speechiness\": 0.028, \"Acousticness\": 0.617, \"Liveness\": 0.356, \"Tempo\": 112.011, \"Duration (ms)\": 210000.0, \"Valence\": 0.421, \"Chord\": \"A\"}, {\"Index\": 922, \"Highest Charting Position\": 5, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"the 1\", \"Streams\": 4587573, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0Jlcvv8IykzHaSmj49uNW8\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 75.0, \"Danceability\": 0.777, \"Energy\": 0.357, \"Loudness\": -6.942, \"Speechiness\": 0.0522, \"Acousticness\": 0.757, \"Liveness\": 0.108, \"Tempo\": 139.883, \"Duration (ms)\": 210252.0, \"Valence\": 0.172, \"Chord\": \"C\"}, {\"Index\": 923, \"Highest Charting Position\": 11, \"Number of Times Charted\": 37, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"RITMO (Bad Boys For Life)\", \"Streams\": 4585895, \"Artist\": \"Black Eyed Peas, J Balvin\", \"Artist Followers\": 5966748.0, \"Song ID\": \"6cy3ki60hLwimwIje7tALf\", \"Genre\": \"['dance pop', 'pop', 'pop rap']\", \"Release Date\": \"2019-10-12\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.721, \"Energy\": 0.716, \"Loudness\": -7.037, \"Speechiness\": 0.0657, \"Acousticness\": 0.0334, \"Liveness\": 0.237, \"Tempo\": 104.994, \"Duration (ms)\": 221714.0, \"Valence\": 0.667, \"Chord\": \"A#/Bb\"}, {\"Index\": 924, \"Highest Charting Position\": 134, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Unterwegs\", \"Streams\": 4572706, \"Artist\": \"KitschKrieg, Jamule, SFR\", \"Artist Followers\": 166517.0, \"Song ID\": \"7mrWTjhYctgEQb0lJKrVWy\", \"Genre\": \"['german hip hop', 'german pop', 'hamburg hip hop']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 68.0, \"Danceability\": 0.88, \"Energy\": 0.607, \"Loudness\": -7.067, \"Speechiness\": 0.0777, \"Acousticness\": 0.195, \"Liveness\": 0.15, \"Tempo\": 126.039, \"Duration (ms)\": 233905.0, \"Valence\": 0.823, \"Chord\": \"F#/Gb\"}, {\"Index\": 925, \"Highest Charting Position\": 86, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"What's Love Got to Do with It\", \"Streams\": 4538382, \"Artist\": \"Kygo, Tina Turner\", \"Artist Followers\": 7593792.0, \"Song ID\": \"3Be7CLdHZpyzsVijme39cW\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-07-17\", \"Weeks Charted\": \"2020-09-04--2020-09-11\\n2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 74.0, \"Danceability\": 0.75, \"Energy\": 0.664, \"Loudness\": -5.908, \"Speechiness\": 0.154, \"Acousticness\": 0.275, \"Liveness\": 0.0632, \"Tempo\": 105.023, \"Duration (ms)\": 208156.0, \"Valence\": 0.617, \"Chord\": \"G#/Ab\"}, {\"Index\": 926, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Cry About It Later\", \"Streams\": 5306994, \"Artist\": \"Katy Perry\", \"Artist Followers\": 18936929.0, \"Song ID\": \"43WYPxyEfIxlIjNlxQGYzc\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2021-04-23\", \"Weeks Charted\": \"2020-08-28--2020-09-04\", \"Popularity\": 67.0, \"Danceability\": 0.676, \"Energy\": 0.794, \"Loudness\": -4.78, \"Speechiness\": 0.0366, \"Acousticness\": 0.0513, \"Liveness\": 0.0723, \"Tempo\": 125.957, \"Duration (ms)\": 159286.0, \"Valence\": 0.161, \"Chord\": \"D\"}, {\"Index\": 927, \"Highest Charting Position\": 71, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Banana (feat. Shaggy) - DJ FLe - Minisiren Remix\", \"Streams\": 4624448, \"Artist\": \"Conkarah\", \"Artist Followers\": 67074.0, \"Song ID\": \"0dZpw3h6KZhcHec61qwevZ\", \"Genre\": \"['jawaiian']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 70.0, \"Danceability\": 0.824, \"Energy\": 0.854, \"Loudness\": -5.312, \"Speechiness\": 0.177, \"Acousticness\": 0.016, \"Liveness\": 0.117, \"Tempo\": 95.114, \"Duration (ms)\": 210329.0, \"Valence\": 0.896, \"Chord\": \"G#/Ab\"}, {\"Index\": 928, \"Highest Charting Position\": 185, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-28--2020-09-04\", \"Song Name\": \"Gifted (feat. Roddy Ricch)\", \"Streams\": 4609169, \"Artist\": \"Cordae\", \"Artist Followers\": 1492551.0, \"Song ID\": \"0mb3uDw5vfFUcZfJYFOMRu\", \"Genre\": \"['dmv rap', 'hip hop', 'pop rap', 'rap', 'trap', 'underground hip hop', 'vapor trap']\", \"Release Date\": \"2020-08-27\", \"Weeks Charted\": \"2020-08-28--2020-09-04\", \"Popularity\": 65.0, \"Danceability\": 0.653, \"Energy\": 0.603, \"Loudness\": -5.697, \"Speechiness\": 0.171, \"Acousticness\": 0.175, \"Liveness\": 0.18, \"Tempo\": 151.016, \"Duration (ms)\": 168477.0, \"Valence\": 0.551, \"Chord\": \"F\"}, {\"Index\": 929, \"Highest Charting Position\": 27, \"Number of Times Charted\": 36, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"OUT WEST (feat. Young Thug)\", \"Streams\": 4597001, \"Artist\": \"JACKBOYS, Travis Scott\", \"Artist Followers\": 437907.0, \"Song ID\": \"6gi6y1xwmVszDWkUqab1qw\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.802, \"Energy\": 0.591, \"Loudness\": -4.895, \"Speechiness\": 0.225, \"Acousticness\": 0.0104, \"Liveness\": 0.196, \"Tempo\": 139.864, \"Duration (ms)\": 157712.0, \"Valence\": 0.309, \"Chord\": \"G#/Ab\"}, {\"Index\": 930, \"Highest Charting Position\": 174, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Anaranjado\", \"Streams\": 4575403, \"Artist\": \"Jowell & Randy, J Balvin\", \"Artist Followers\": 2919696.0, \"Song ID\": \"5iw28wvyHgj4ppOu5AdcEU\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-07-16\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 66.0, \"Danceability\": 0.763, \"Energy\": 0.58, \"Loudness\": -6.196, \"Speechiness\": 0.144, \"Acousticness\": 0.0466, \"Liveness\": 0.154, \"Tempo\": 175.937, \"Duration (ms)\": 212011.0, \"Valence\": 0.608, \"Chord\": \"G#/Ab\"}, {\"Index\": 931, \"Highest Charting Position\": 111, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Reggaetonera\", \"Streams\": 4564331, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"6yVkakCN460KOVol9ZazjH\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-05-29--2020-06-05\", \"Popularity\": 69.0, \"Danceability\": 0.694, \"Energy\": 0.796, \"Loudness\": -4.164, \"Speechiness\": 0.0565, \"Acousticness\": 0.48, \"Liveness\": 0.108, \"Tempo\": 93.064, \"Duration (ms)\": 212312.0, \"Valence\": 0.515, \"Chord\": \"F#/Gb\"}, {\"Index\": 932, \"Highest Charting Position\": 5, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Sour Candy (with BLACKPINK)\", \"Streams\": 4556900, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"6R6ZoHTypt5lt68MWbzZXv\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-28\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 70.0, \"Danceability\": 0.752, \"Energy\": 0.87, \"Loudness\": -3.812, \"Speechiness\": 0.0623, \"Acousticness\": 0.0604, \"Liveness\": 0.489, \"Tempo\": 120.006, \"Duration (ms)\": 157707.0, \"Valence\": 0.784, \"Chord\": \"A\"}, {\"Index\": 933, \"Highest Charting Position\": 113, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Rags2Riches 2 (feat. Lil Baby)\", \"Streams\": 4547965, \"Artist\": \"Rod Wave\", \"Artist Followers\": 2203386.0, \"Song ID\": \"40TPiJpvwGIyvPjJMDTKfy\", \"Genre\": \"['florida rap']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 60.0, \"Danceability\": 0.874, \"Energy\": 0.443, \"Loudness\": -9.628, \"Speechiness\": 0.241, \"Acousticness\": 0.147, \"Liveness\": 0.124, \"Tempo\": 118.004, \"Duration (ms)\": 235988.0, \"Valence\": 0.298, \"Chord\": \"F\"}, {\"Index\": 934, \"Highest Charting Position\": 31, \"Number of Times Charted\": 34, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Bandit (with YoungBoy Never Broke Again)\", \"Streams\": 4514763, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"6Gg1gjgKi2AK4e0qzsR7sd\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.474, \"Energy\": 0.631, \"Loudness\": -5.884, \"Speechiness\": 0.343, \"Acousticness\": 0.0687, \"Liveness\": 0.132, \"Tempo\": 180.051, \"Duration (ms)\": 189323.0, \"Valence\": 0.425, \"Chord\": \"F\"}, {\"Index\": 935, \"Highest Charting Position\": 117, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"PAM\", \"Streams\": 4501441, \"Artist\": \"Justin Quiles, Daddy Yankee, El Alfa\", \"Artist Followers\": 2897862.0, \"Song ID\": \"0eeKDrQxjqNl5bX5VCHDcn\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-08-28--2020-09-04\\n2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 73.0, \"Danceability\": 0.889, \"Energy\": 0.863, \"Loudness\": -3.011, \"Speechiness\": 0.0757, \"Acousticness\": 0.289, \"Liveness\": 0.0798, \"Tempo\": 112.953, \"Duration (ms)\": 201000.0, \"Valence\": 0.776, \"Chord\": \"B\"}, {\"Index\": 936, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Lemonade\", \"Streams\": 11373347, \"Artist\": \"Internet Money, Gunna, Don Toliver, NAV\", \"Artist Followers\": 412466.0, \"Song ID\": \"02kDW379Yfd5PzW5A6vuGt\", \"Genre\": \"['pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-08-14\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\", \"Popularity\": 82.0, \"Danceability\": 0.799, \"Energy\": 0.66, \"Loudness\": -6.153, \"Speechiness\": 0.079, \"Acousticness\": 0.256, \"Liveness\": 0.111, \"Tempo\": 140.04, \"Duration (ms)\": 195429.0, \"Valence\": 0.471, \"Chord\": \"C#/Db\"}, {\"Index\": 937, \"Highest Charting Position\": 145, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"Fr\\u00fchst\\u00fcck in Paris\", \"Streams\": 5440253, \"Artist\": \"Capital Bra, Cro\", \"Artist Followers\": 4093115.0, \"Song ID\": \"1ddbNJwDjjmCYz1GFGYnsw\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-09-17\", \"Weeks Charted\": \"2020-08-21--2020-08-28\", \"Popularity\": 56.0, \"Danceability\": 0.744, \"Energy\": 0.644, \"Loudness\": -5.562, \"Speechiness\": 0.0641, \"Acousticness\": 0.229, \"Liveness\": 0.204, \"Tempo\": 96.852, \"Duration (ms)\": 151360.0, \"Valence\": 0.577, \"Chord\": \"G#/Ab\"}, {\"Index\": 938, \"Highest Charting Position\": 22, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"ON\", \"Streams\": 5391018, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"2QyuXBcV1LJ2rq01KhreMF\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 77.0, \"Danceability\": 0.583, \"Energy\": 0.817, \"Loudness\": -5.146, \"Speechiness\": 0.0987, \"Acousticness\": 0.118, \"Liveness\": 0.338, \"Tempo\": 105.936, \"Duration (ms)\": 246381.0, \"Valence\": 0.438, \"Chord\": \"A\"}, {\"Index\": 939, \"Highest Charting Position\": 106, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"My Oasis (feat. Burna Boy)\", \"Streams\": 4887204, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"2KoHxhRyWxJzA0VafWd5Nk\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-07-30\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 69.0, \"Danceability\": 0.691, \"Energy\": 0.474, \"Loudness\": -8.742, \"Speechiness\": 0.0583, \"Acousticness\": 0.569, \"Liveness\": 0.099, \"Tempo\": 143.783, \"Duration (ms)\": 179917.0, \"Valence\": 0.381, \"Chord\": \"A#/Bb\"}, {\"Index\": 940, \"Highest Charting Position\": 8, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Life's A Mess (feat. Halsey)\", \"Streams\": 4883202, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5wWAwzGp2OaaoIkwcz6wZs\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 74.0, \"Danceability\": 0.63, \"Energy\": 0.446, \"Loudness\": -8.9, \"Speechiness\": 0.0351, \"Acousticness\": 0.337, \"Liveness\": 0.166, \"Tempo\": 143.078, \"Duration (ms)\": 202193.0, \"Valence\": 0.177, \"Chord\": \"C#/Db\"}, {\"Index\": 941, \"Highest Charting Position\": 56, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"PORFA\", \"Streams\": 4702117, \"Artist\": \"Feid, Justin Quiles\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5PwAiSk3ufe0YwOHRFPHEG\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 0.0, \"Danceability\": 0.843, \"Energy\": 0.549, \"Loudness\": -8.018, \"Speechiness\": 0.164, \"Acousticness\": 0.0948, \"Liveness\": 0.155, \"Tempo\": 83.982, \"Duration (ms)\": 233000.0, \"Valence\": 0.542, \"Chord\": \"F#/Gb\"}, {\"Index\": 942, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"2012\", \"Streams\": 4685894, \"Artist\": \"Bausa, Juju\", \"Artist Followers\": 961181.0, \"Song ID\": \"6bM4daGlfZHtKMQp8tEqVz\", \"Genre\": \"['german hip hop', 'german pop']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-08-21--2020-08-28\", \"Popularity\": 62.0, \"Danceability\": 0.805, \"Energy\": 0.619, \"Loudness\": -7.907, \"Speechiness\": 0.0771, \"Acousticness\": 0.218, \"Liveness\": 0.114, \"Tempo\": 98.995, \"Duration (ms)\": 170200.0, \"Valence\": 0.476, \"Chord\": \"F\"}, {\"Index\": 943, \"Highest Charting Position\": 11, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"august\", \"Streams\": 4586236, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3hUxzQpSfdDqwM3ZTFQY0K\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 76.0, \"Danceability\": 0.532, \"Energy\": 0.623, \"Loudness\": -9.208, \"Speechiness\": 0.0331, \"Acousticness\": 0.538, \"Liveness\": 0.0925, \"Tempo\": 89.937, \"Duration (ms)\": 261923.0, \"Valence\": 0.403, \"Chord\": \"F\"}, {\"Index\": 944, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-21--2020-08-28\", \"Song Name\": \"if i were u (with Lauv)\", \"Streams\": 4561189, \"Artist\": \"blackbear\", \"Artist Followers\": 4272745.0, \"Song ID\": \"0CF1RH8dQKuK2lQPSQw2lZ\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2020-08-19\", \"Weeks Charted\": \"2020-08-21--2020-08-28\", \"Popularity\": 64.0, \"Danceability\": 0.666, \"Energy\": 0.628, \"Loudness\": -5.613, \"Speechiness\": 0.0623, \"Acousticness\": 0.144, \"Liveness\": 0.189, \"Tempo\": 82.992, \"Duration (ms)\": 186468.0, \"Valence\": 0.767, \"Chord\": \"G#/Ab\"}, {\"Index\": 945, \"Highest Charting Position\": 37, \"Number of Times Charted\": 35, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Ballin' (with Roddy Ricch)\", \"Streams\": 4436934, \"Artist\": \"Mustard\", \"Artist Followers\": 881797.0, \"Song ID\": \"3QzAOrNlsabgbMwlZt7TAY\", \"Genre\": \"['cali rap', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.809, \"Energy\": 0.545, \"Loudness\": -6.678, \"Speechiness\": 0.0735, \"Acousticness\": 0.392, \"Liveness\": 0.151, \"Tempo\": 97.008, \"Duration (ms)\": 180435.0, \"Valence\": 0.244, \"Chord\": \"G\"}, {\"Index\": 946, \"Highest Charting Position\": 72, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Stay Gold\", \"Streams\": 4405338, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3Ys2PYl1wyPKQIwyqhP9cQ\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-07-14\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-07-10--2020-07-17\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 73.0, \"Danceability\": 0.723, \"Energy\": 0.634, \"Loudness\": -5.415, \"Speechiness\": 0.0542, \"Acousticness\": 0.0892, \"Liveness\": 0.0787, \"Tempo\": 129.017, \"Duration (ms)\": 243267.0, \"Valence\": 0.582, \"Chord\": \"C#/Db\"}, {\"Index\": 947, \"Highest Charting Position\": 186, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"I'm Yours\", \"Streams\": 4391666, \"Artist\": \"Jason Mraz\", \"Artist Followers\": 6167871.0, \"Song ID\": \"1EzrEOXmMH3G43AXT1y7pA\", \"Genre\": \"['acoustic pop', 'neo mellow', 'pop', 'pop rock']\", \"Release Date\": \"2008-05-12\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\", \"Popularity\": 80.0, \"Danceability\": 0.686, \"Energy\": 0.457, \"Loudness\": -8.322, \"Speechiness\": 0.0468, \"Acousticness\": 0.595, \"Liveness\": 0.105, \"Tempo\": 150.953, \"Duration (ms)\": 242187.0, \"Valence\": 0.718, \"Chord\": \"B\"}, {\"Index\": 948, \"Highest Charting Position\": 136, \"Number of Times Charted\": 32, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Youngblood\", \"Streams\": 4390823, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"2iUXsYOEPhVqEBwsqP70rE\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-06-15\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.596, \"Energy\": 0.854, \"Loudness\": -5.114, \"Speechiness\": 0.463, \"Acousticness\": 0.0169, \"Liveness\": 0.124, \"Tempo\": 120.274, \"Duration (ms)\": 203418.0, \"Valence\": 0.152, \"Chord\": \"G\"}, {\"Index\": 949, \"Highest Charting Position\": 8, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"the last great american dynasty\", \"Streams\": 4389670, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2Eeur20xVqfUoM3Q7EFPFt\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-21--2020-08-28\\n2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.686, \"Energy\": 0.662, \"Loudness\": -8.505, \"Speechiness\": 0.0413, \"Acousticness\": 0.467, \"Liveness\": 0.109, \"Tempo\": 147.922, \"Duration (ms)\": 230999.0, \"Valence\": 0.706, \"Chord\": \"G\"}, {\"Index\": 950, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Levitating (feat. Madonna and Missy Elliott) [The Blessed Madonna Remix]\", \"Streams\": 5254969, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"0pk1hxhJLBSZZ5RKBhcwOa\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-08-13\", \"Weeks Charted\": \"2020-08-14--2020-08-21\", \"Popularity\": 62.0, \"Danceability\": 0.808, \"Energy\": 0.655, \"Loudness\": -7.34, \"Speechiness\": 0.139, \"Acousticness\": 0.0373, \"Liveness\": 0.208, \"Tempo\": 116.029, \"Duration (ms)\": 250280.0, \"Valence\": 0.56, \"Chord\": \"B\"}, {\"Index\": 951, \"Highest Charting Position\": 10, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"my tears ricochet\", \"Streams\": 5111416, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"1MgV7FIyNxIG7WzMRJV5HC\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.456, \"Energy\": 0.263, \"Loudness\": -10.63, \"Speechiness\": 0.0332, \"Acousticness\": 0.806, \"Liveness\": 0.0749, \"Tempo\": 129.86, \"Duration (ms)\": 255894.0, \"Valence\": 0.111, \"Chord\": \"C\"}, {\"Index\": 952, \"Highest Charting Position\": 59, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Rags2Riches (feat. ATR Son Son)\", \"Streams\": 4737306, \"Artist\": \"Rod Wave\", \"Artist Followers\": 2203386.0, \"Song ID\": \"0qg0GJp7HSewRCVPP4fKGk\", \"Genre\": \"['florida rap']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 55.0, \"Danceability\": 0.904, \"Energy\": 0.26, \"Loudness\": -17.57, \"Speechiness\": 0.101, \"Acousticness\": 0.277, \"Liveness\": 0.121, \"Tempo\": 117.967, \"Duration (ms)\": 167147.0, \"Valence\": 0.231, \"Chord\": \"F\"}, {\"Index\": 953, \"Highest Charting Position\": 79, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Flex (feat. Juice WRLD)\", \"Streams\": 4664281, \"Artist\": \"Polo G\", \"Artist Followers\": 4849204.0, \"Song ID\": \"2QqJTIlGKRLJC3onkavYEz\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 76.0, \"Danceability\": 0.752, \"Energy\": 0.673, \"Loudness\": -5.792, \"Speechiness\": 0.153, \"Acousticness\": 0.0538, \"Liveness\": 0.133, \"Tempo\": 164.009, \"Duration (ms)\": 163902.0, \"Valence\": 0.35, \"Chord\": \"A#/Bb\"}, {\"Index\": 954, \"Highest Charting Position\": 77, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Rover (feat. DTG)\", \"Streams\": 4488631, \"Artist\": \"S1mba\", \"Artist Followers\": 46992.0, \"Song ID\": \"4slSrbTK1sNK4I1mDYEthf\", \"Genre\": \"['afroswing', 'social media pop']\", \"Release Date\": \"2020-03-04\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 73.0, \"Danceability\": 0.613, \"Energy\": 0.624, \"Loudness\": -6.66, \"Speechiness\": 0.206, \"Acousticness\": 0.496, \"Liveness\": 0.283, \"Tempo\": 62.948, \"Duration (ms)\": 167917.0, \"Valence\": 0.804, \"Chord\": \"B\"}, {\"Index\": 955, \"Highest Charting Position\": 74, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Only You Freestyle\", \"Streams\": 4480780, \"Artist\": \"Headie One, Drake\", \"Artist Followers\": 328877.0, \"Song ID\": \"4OENnoidV0h8gJV6bhrw7r\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2020-07-20\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 68.0, \"Danceability\": 0.68, \"Energy\": 0.826, \"Loudness\": -2.561, \"Speechiness\": 0.27, \"Acousticness\": 0.562, \"Liveness\": 0.254, \"Tempo\": 146.95, \"Duration (ms)\": 248937.0, \"Valence\": 0.804, \"Chord\": \"F\"}, {\"Index\": 956, \"Highest Charting Position\": 55, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Hallucinate\", \"Streams\": 4472669, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"1nYeVF5vIBxMxfPoL0SIWg\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 72.0, \"Danceability\": 0.627, \"Energy\": 0.69, \"Loudness\": -5.396, \"Speechiness\": 0.139, \"Acousticness\": 0.033, \"Liveness\": 0.0742, \"Tempo\": 122.053, \"Duration (ms)\": 208505.0, \"Valence\": 0.627, \"Chord\": \"A#/Bb\"}, {\"Index\": 957, \"Highest Charting Position\": 100, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"El Efecto\", \"Streams\": 4466143, \"Artist\": \"Rauw Alejandro, Chencho Corleone\", \"Artist Followers\": 6096559.0, \"Song ID\": \"4SJHHpKhcuXwDsCsPqshXj\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2019-03-15\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 76.0, \"Danceability\": 0.849, \"Energy\": 0.781, \"Loudness\": -4.635, \"Speechiness\": 0.159, \"Acousticness\": 0.406, \"Liveness\": 0.0801, \"Tempo\": 84.041, \"Duration (ms)\": 217143.0, \"Valence\": 0.893, \"Chord\": \"C\"}, {\"Index\": 958, \"Highest Charting Position\": 176, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Co\\u00f1o\", \"Streams\": 4462411, \"Artist\": \"Jason Derulo, Puri, Jhorrmountain\", \"Artist Followers\": 9778632.0, \"Song ID\": \"5DV4ZSCqbFv74ui3ZhimXo\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\", \"Popularity\": 69.0, \"Danceability\": 0.899, \"Energy\": 0.528, \"Loudness\": -5.442, \"Speechiness\": 0.181, \"Acousticness\": 0.000554, \"Liveness\": 0.105, \"Tempo\": 100.037, \"Duration (ms)\": 111852.0, \"Valence\": 0.456, \"Chord\": \"A\"}, {\"Index\": 959, \"Highest Charting Position\": 126, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Jolie nana\", \"Streams\": 4449437, \"Artist\": \"Aya Nakamura\", \"Artist Followers\": 2953525.0, \"Song ID\": \"65RWVU6N81CeH65nu52K1U\", \"Genre\": \"['basshall', 'francoton']\", \"Release Date\": \"2020-11-13\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 69.0, \"Danceability\": 0.813, \"Energy\": 0.64, \"Loudness\": -5.908, \"Speechiness\": 0.272, \"Acousticness\": 0.269, \"Liveness\": 0.131, \"Tempo\": 92.989, \"Duration (ms)\": 147076.0, \"Valence\": 0.488, \"Chord\": \"D\"}, {\"Index\": 960, \"Highest Charting Position\": 189, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-08-14--2020-08-21\", \"Song Name\": \"Lovefool\", \"Streams\": 4439790, \"Artist\": \"twocolors\", \"Artist Followers\": 36369.0, \"Song ID\": \"51Of5p3lKZeOg6itfs4og4\", \"Genre\": \"['edm', 'pop dance', 'pop edm', 'tropical house']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\", \"Popularity\": 79.0, \"Danceability\": 0.677, \"Energy\": 0.766, \"Loudness\": -6.896, \"Speechiness\": 0.0568, \"Acousticness\": 0.0219, \"Liveness\": 0.129, \"Tempo\": 123.062, \"Duration (ms)\": 190488.0, \"Valence\": 0.198, \"Chord\": \"F#/Gb\"}, {\"Index\": 961, \"Highest Charting Position\": 17, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"invisible string\", \"Streams\": 4424118, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6VsvKPJ4xjVNKpI8VVZ3SV\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.653, \"Energy\": 0.452, \"Loudness\": -11.143, \"Speechiness\": 0.055, \"Acousticness\": 0.838, \"Liveness\": 0.108, \"Tempo\": 83.433, \"Duration (ms)\": 252881.0, \"Valence\": 0.45, \"Chord\": \"E\"}, {\"Index\": 962, \"Highest Charting Position\": 118, \"Number of Times Charted\": 33, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Higher Love\", \"Streams\": 4392936, \"Artist\": \"Kygo, Whitney Houston\", \"Artist Followers\": 7593792.0, \"Song ID\": \"6oJ6le65B3SEqPwMRNXWjY\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.693, \"Energy\": 0.678, \"Loudness\": -7.159, \"Speechiness\": 0.0324, \"Acousticness\": 0.0151, \"Liveness\": 0.101, \"Tempo\": 103.952, \"Duration (ms)\": 228267.0, \"Valence\": 0.404, \"Chord\": \"G#/Ab\"}, {\"Index\": 963, \"Highest Charting Position\": 185, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Como Llora\", \"Streams\": 4380308, \"Artist\": \"Juanfran\", \"Artist Followers\": 117894.0, \"Song ID\": \"52zq2a71SGs3f1vJuv59ui\", \"Genre\": \"['dominican pop', 'pop reggaeton', 'urbano espanol']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 67.0, \"Danceability\": 0.827, \"Energy\": 0.629, \"Loudness\": -3.966, \"Speechiness\": 0.185, \"Acousticness\": 0.183, \"Liveness\": 0.084, \"Tempo\": 88.064, \"Duration (ms)\": 187500.0, \"Valence\": 0.486, \"Chord\": \"F#/Gb\"}, {\"Index\": 964, \"Highest Charting Position\": 50, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Walk Em Down (feat. Roddy Ricch)\", \"Streams\": 4371370, \"Artist\": \"NLE Choppa\", \"Artist Followers\": 6608815.0, \"Song ID\": \"4cSSL3YafYjM3yjgFO1vJg\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 74.0, \"Danceability\": 0.867, \"Energy\": 0.744, \"Loudness\": -5.171, \"Speechiness\": 0.227, \"Acousticness\": 0.268, \"Liveness\": 0.0713, \"Tempo\": 84.005, \"Duration (ms)\": 173288.0, \"Valence\": 0.645, \"Chord\": \"D\"}, {\"Index\": 965, \"Highest Charting Position\": 74, \"Number of Times Charted\": 31, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Wow.\", \"Streams\": 4351784, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"7xQAfvXzm3AkraOtGPWIZg\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-08-14--2020-08-21\\n2020-08-07--2020-08-14\\n2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.829, \"Energy\": 0.539, \"Loudness\": -7.359, \"Speechiness\": 0.208, \"Acousticness\": 0.136, \"Liveness\": 0.103, \"Tempo\": 99.96, \"Duration (ms)\": 149547.0, \"Valence\": 0.388, \"Chord\": \"B\"}, {\"Index\": 966, \"Highest Charting Position\": 13, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"mirrorball\", \"Streams\": 5564072, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"0ZNU020wNYvgW84iljPkPP\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.553, \"Energy\": 0.413, \"Loudness\": -10.037, \"Speechiness\": 0.0334, \"Acousticness\": 0.687, \"Liveness\": 0.0594, \"Tempo\": 110.107, \"Duration (ms)\": 208978.0, \"Valence\": 0.379, \"Chord\": \"D\"}, {\"Index\": 967, \"Highest Charting Position\": 15, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"seven\", \"Streams\": 5459423, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6KJqZcs9XDgVck7Lg9QOTC\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 69.0, \"Danceability\": 0.596, \"Energy\": 0.488, \"Loudness\": -10.769, \"Speechiness\": 0.0274, \"Acousticness\": 0.9, \"Liveness\": 0.091, \"Tempo\": 94.926, \"Duration (ms)\": 208907.0, \"Valence\": 0.415, \"Chord\": \"E\"}, {\"Index\": 968, \"Highest Charting Position\": 18, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"this is me trying\", \"Streams\": 5128412, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7kt9e9LFSpN1zQtYEl19o1\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.515, \"Energy\": 0.476, \"Loudness\": -9.843, \"Speechiness\": 0.0328, \"Acousticness\": 0.314, \"Liveness\": 0.171, \"Tempo\": 135.886, \"Duration (ms)\": 195097.0, \"Valence\": 0.412, \"Chord\": \"A\"}, {\"Index\": 969, \"Highest Charting Position\": 24, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"betty\", \"Streams\": 5112180, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"5kI4eCXXzyuIUXjQra0Cxi\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.593, \"Energy\": 0.377, \"Loudness\": -8.761, \"Speechiness\": 0.0253, \"Acousticness\": 0.6, \"Liveness\": 0.0976, \"Tempo\": 95.939, \"Duration (ms)\": 294521.0, \"Valence\": 0.502, \"Chord\": \"C\"}, {\"Index\": 970, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"BLIND (feat. Young Thug)\", \"Streams\": 5074613, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"2T5NBwKRySiCR78vVk08vr\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-08-04\", \"Weeks Charted\": \"2020-08-07--2020-08-14\", \"Popularity\": 69.0, \"Danceability\": 0.709, \"Energy\": 0.679, \"Loudness\": -6.503, \"Speechiness\": 0.346, \"Acousticness\": 0.0115, \"Liveness\": 0.0971, \"Tempo\": 162.973, \"Duration (ms)\": 153467.0, \"Valence\": 0.754, \"Chord\": \"B\"}, {\"Index\": 971, \"Highest Charting Position\": 20, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"illicit affairs\", \"Streams\": 5053658, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2NmsngXHeC1GQ9wWrzhOMf\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 70.0, \"Danceability\": 0.559, \"Energy\": 0.31, \"Loudness\": -10.445, \"Speechiness\": 0.0338, \"Acousticness\": 0.881, \"Liveness\": 0.106, \"Tempo\": 119.845, \"Duration (ms)\": 190898.0, \"Valence\": 0.46, \"Chord\": \"A#/Bb\"}, {\"Index\": 972, \"Highest Charting Position\": 170, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"Freak\", \"Streams\": 4736059, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"3aA6xB0tOilDDX17fIJ0Bl\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-08-07\", \"Weeks Charted\": \"2020-08-07--2020-08-14\", \"Popularity\": 75.0, \"Danceability\": 0.688, \"Energy\": 0.716, \"Loudness\": -5.702, \"Speechiness\": 0.0385, \"Acousticness\": 0.0969, \"Liveness\": 0.0989, \"Tempo\": 116.912, \"Duration (ms)\": 284480.0, \"Valence\": 0.373, \"Chord\": \"G\"}, {\"Index\": 973, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-08-07--2020-08-14\", \"Song Name\": \"PUNANI\", \"Streams\": 4625985, \"Artist\": \"6ix9ine\", \"Artist Followers\": 6514102.0, \"Song ID\": \"41xKiK40e7MFu1bqcGSz1d\", \"Genre\": \"['emo rap', 'rap']\", \"Release Date\": \"2020-08-02\", \"Weeks Charted\": \"2020-08-07--2020-08-14\", \"Popularity\": 58.0, \"Danceability\": 0.841, \"Energy\": 0.541, \"Loudness\": -7.121, \"Speechiness\": 0.229, \"Acousticness\": 0.0186, \"Liveness\": 0.123, \"Tempo\": 97.961, \"Duration (ms)\": 115255.0, \"Valence\": 0.42, \"Chord\": \"A\"}, {\"Index\": 974, \"Highest Charting Position\": 50, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Bl\\u00e4ulich\", \"Streams\": 4599408, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"2WRTnY0slmFgWcrmEr8dPj\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 60.0, \"Danceability\": 0.79, \"Energy\": 0.704, \"Loudness\": -7.935, \"Speechiness\": 0.417, \"Acousticness\": 0.069, \"Liveness\": 0.113, \"Tempo\": 154.007, \"Duration (ms)\": 196213.0, \"Valence\": 0.212, \"Chord\": \"A#/Bb\"}, {\"Index\": 975, \"Highest Charting Position\": 170, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Never Let Me Down\", \"Streams\": 4522005, \"Artist\": \"VIZE, Tom Gregory\", \"Artist Followers\": 141016.0, \"Song ID\": \"3bXiWZWR3CoZbhcsqfsMNa\", \"Genre\": \"['dance pop', 'german dance', 'pop dance', 'slap house', 'tropical house']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 61.0, \"Danceability\": 0.758, \"Energy\": 0.848, \"Loudness\": -3.84, \"Speechiness\": 0.0457, \"Acousticness\": 0.21, \"Liveness\": 0.114, \"Tempo\": 127.96, \"Duration (ms)\": 153149.0, \"Valence\": 0.706, \"Chord\": \"A#/Bb\"}, {\"Index\": 976, \"Highest Charting Position\": 16, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Savage\", \"Streams\": 4510218, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"55CHeLEfn5iJ0IIkgaa4si\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-08-07--2020-08-14\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 75.0, \"Danceability\": 0.843, \"Energy\": 0.741, \"Loudness\": -5.609, \"Speechiness\": 0.334, \"Acousticness\": 0.0252, \"Liveness\": 0.096, \"Tempo\": 168.983, \"Duration (ms)\": 155497.0, \"Valence\": 0.68, \"Chord\": \"B\"}, {\"Index\": 977, \"Highest Charting Position\": 29, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"mad woman\", \"Streams\": 6796343, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2QDyYdZyhlP2fp79KZX8Bi\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 67.0, \"Danceability\": 0.592, \"Energy\": 0.699, \"Loudness\": -8.995, \"Speechiness\": 0.0471, \"Acousticness\": 0.655, \"Liveness\": 0.114, \"Tempo\": 141.916, \"Duration (ms)\": 237258.0, \"Valence\": 0.506, \"Chord\": \"D#/Eb\"}, {\"Index\": 978, \"Highest Charting Position\": 33, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"epiphany\", \"Streams\": 6085522, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"08fa9LFcFBTcilB3iq2e2A\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 66.0, \"Danceability\": 0.354, \"Energy\": 0.267, \"Loudness\": -13.69, \"Speechiness\": 0.0281, \"Acousticness\": 0.731, \"Liveness\": 0.0858, \"Tempo\": 94.219, \"Duration (ms)\": 289749.0, \"Valence\": 0.113, \"Chord\": \"C#/Db\"}, {\"Index\": 979, \"Highest Charting Position\": 41, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"peace\", \"Streams\": 5943851, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"7MbT4I8qGntX4fMdqMQgke\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 67.0, \"Danceability\": 0.647, \"Energy\": 0.272, \"Loudness\": -12.906, \"Speechiness\": 0.0916, \"Acousticness\": 0.918, \"Liveness\": 0.0918, \"Tempo\": 150.044, \"Duration (ms)\": 234000.0, \"Valence\": 0.339, \"Chord\": \"F\"}, {\"Index\": 980, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Move Ya Hips (feat. Nicki Minaj & MadeinTYO)\", \"Streams\": 5768616, \"Artist\": \"A$AP Ferg\", \"Artist Followers\": 3037935.0, \"Song ID\": \"13v5IXnvO2BccWwOx5rb4s\", \"Genre\": \"['hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap', 'underground hip hop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 61.0, \"Danceability\": 0.808, \"Energy\": 0.676, \"Loudness\": -4.902, \"Speechiness\": 0.223, \"Acousticness\": 0.0618, \"Liveness\": 0.11, \"Tempo\": 144.018, \"Duration (ms)\": 144973.0, \"Valence\": 0.0763, \"Chord\": \"E\"}, {\"Index\": 981, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Sie ruft\", \"Streams\": 5752169, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"4CyCHkhRsDXUeP5K4Y3xjU\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 59.0, \"Danceability\": 0.819, \"Energy\": 0.507, \"Loudness\": -7.336, \"Speechiness\": 0.0881, \"Acousticness\": 0.482, \"Liveness\": 0.105, \"Tempo\": 130.009, \"Duration (ms)\": 152013.0, \"Valence\": 0.634, \"Chord\": \"C#/Db\"}, {\"Index\": 982, \"Highest Charting Position\": 144, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Tilidin Weg\", \"Streams\": 5674945, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"7idxewQZ24F0gQy2EWE6Ug\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 60.0, \"Danceability\": 0.882, \"Energy\": 0.526, \"Loudness\": -8.553, \"Speechiness\": 0.237, \"Acousticness\": 0.118, \"Liveness\": 0.0835, \"Tempo\": 109.075, \"Duration (ms)\": 180950.0, \"Valence\": 0.182, \"Chord\": \"A#/Bb\"}, {\"Index\": 983, \"Highest Charting Position\": 149, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Over Your Head\", \"Streams\": 5534361, \"Artist\": \"Future, Lil Uzi Vert\", \"Artist Followers\": 10491105.0, \"Song ID\": \"0Tcw8w9pvPrZoORgxsNASW\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 59.0, \"Danceability\": 0.773, \"Energy\": 0.742, \"Loudness\": -5.453, \"Speechiness\": 0.162, \"Acousticness\": 0.00198, \"Liveness\": 0.558, \"Tempo\": 148.949, \"Duration (ms)\": 186843.0, \"Valence\": 0.35, \"Chord\": \"F\"}, {\"Index\": 984, \"Highest Charting Position\": 47, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"hoax\", \"Streams\": 5375944, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6MWoRt97mnSTXZhu3ggi9C\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\", \"Popularity\": 66.0, \"Danceability\": 0.662, \"Energy\": 0.181, \"Loudness\": -15.065, \"Speechiness\": 0.0415, \"Acousticness\": 0.966, \"Liveness\": 0.133, \"Tempo\": 118.819, \"Duration (ms)\": 220043.0, \"Valence\": 0.429, \"Chord\": \"G#/Ab\"}, {\"Index\": 985, \"Highest Charting Position\": 25, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Blood On My Jeans\", \"Streams\": 4978899, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"0fCwrjKfWxF3xQhZrYUw4T\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 73.0, \"Danceability\": 0.868, \"Energy\": 0.55, \"Loudness\": -6.417, \"Speechiness\": 0.226, \"Acousticness\": 0.183, \"Liveness\": 0.109, \"Tempo\": 117.943, \"Duration (ms)\": 154767.0, \"Valence\": 0.464, \"Chord\": \"F#/Gb\"}, {\"Index\": 986, \"Highest Charting Position\": 171, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-31--2020-08-07\", \"Song Name\": \"Narrow Road (feat. Lil Baby)\", \"Streams\": 4828004, \"Artist\": \"NLE Choppa\", \"Artist Followers\": 3372385.0, \"Song ID\": \"3GZd1aDsgKL71Kt3VIp0hc\", \"Genre\": \"['memphis hip hop']\", \"Release Date\": \"2020-07-30\", \"Weeks Charted\": \"2020-07-31--2020-08-07\", \"Popularity\": 64.0, \"Danceability\": 0.614, \"Energy\": 0.553, \"Loudness\": -8.225, \"Speechiness\": 0.169, \"Acousticness\": 0.0306, \"Liveness\": 0.203, \"Tempo\": 159.999, \"Duration (ms)\": 240297.0, \"Valence\": 0.161, \"Chord\": \"G\"}, {\"Index\": 987, \"Highest Charting Position\": 26, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Amarillo\", \"Streams\": 4695091, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"6zEgnpM0qYmHLDnh8WPejL\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 73.0, \"Danceability\": 0.641, \"Energy\": 0.857, \"Loudness\": -5.725, \"Speechiness\": 0.301, \"Acousticness\": 0.013, \"Liveness\": 0.0695, \"Tempo\": 122.728, \"Duration (ms)\": 157733.0, \"Valence\": 0.961, \"Chord\": \"C#/Db\"}, {\"Index\": 988, \"Highest Charting Position\": 179, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Singapur\", \"Streams\": 4661170, \"Artist\": \"El Alfa, Chael Produciendo\", \"Artist Followers\": 1779640.0, \"Song ID\": \"4QfZYDhGZc0T2RDvGiI69E\", \"Genre\": \"['dembow', 'latin', 'rap dominicano', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 69.0, \"Danceability\": 0.853, \"Energy\": 0.909, \"Loudness\": -2.473, \"Speechiness\": 0.229, \"Acousticness\": 0.0522, \"Liveness\": 0.129, \"Tempo\": 112.987, \"Duration (ms)\": 178407.0, \"Valence\": 0.803, \"Chord\": \"G\"}, {\"Index\": 989, \"Highest Charting Position\": 42, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Tattoo\", \"Streams\": 4588064, \"Artist\": \"Rauw Alejandro\", \"Artist Followers\": 6096559.0, \"Song ID\": \"4ZRrLHqzhGRXYj2qcB4s5S\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-07-09\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 78.0, \"Danceability\": 0.848, \"Energy\": 0.637, \"Loudness\": -5.132, \"Speechiness\": 0.156, \"Acousticness\": 0.0413, \"Liveness\": 0.0521, \"Tempo\": 96.988, \"Duration (ms)\": 222680.0, \"Valence\": 0.698, \"Chord\": \"A\"}, {\"Index\": 990, \"Highest Charting Position\": 86, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Ego Death (feat. Kanye West, FKA twigs & Skrillex)\", \"Streams\": 4583475, \"Artist\": \"Ty Dolla $ign\", \"Artist Followers\": 3866304.0, \"Song ID\": \"3Q5cLvkKsHJvYltf8k7HkO\", \"Genre\": \"['hip hop', 'pop', 'pop rap', 'r&b', 'southern hip hop', 'trap', 'trap soul']\", \"Release Date\": \"2020-10-22\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 71.0, \"Danceability\": 0.818, \"Energy\": 0.598, \"Loudness\": -5.948, \"Speechiness\": 0.113, \"Acousticness\": 0.0573, \"Liveness\": 0.634, \"Tempo\": 111.052, \"Duration (ms)\": 231618.0, \"Valence\": 0.331, \"Chord\": \"A#/Bb\"}, {\"Index\": 991, \"Highest Charting Position\": 33, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Morado\", \"Streams\": 4561936, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"3mQ6SLdxxaL52Yte7KF2Ks\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-01-09\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 71.0, \"Danceability\": 0.881, \"Energy\": 0.696, \"Loudness\": -3.838, \"Speechiness\": 0.0797, \"Acousticness\": 0.137, \"Liveness\": 0.0927, \"Tempo\": 97.002, \"Duration (ms)\": 200667.0, \"Valence\": 0.781, \"Chord\": \"B\"}, {\"Index\": 992, \"Highest Charting Position\": 101, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"ocean eyes\", \"Streams\": 4476954, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6pFTDHGJtKOxrQ85xRZ8Ue\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-07-31--2020-08-07\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 1.0, \"Danceability\": 0.358, \"Energy\": 0.372, \"Loudness\": -7.664, \"Speechiness\": 0.0464, \"Acousticness\": 0.81, \"Liveness\": 0.0877, \"Tempo\": 144.833, \"Duration (ms)\": 200387.0, \"Valence\": 0.16, \"Chord\": \"E\"}, {\"Index\": 993, \"Highest Charting Position\": 82, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Lion King On Ice\", \"Streams\": 8293983, \"Artist\": \"J. Cole\", \"Artist Followers\": 14103694.0, \"Song ID\": \"1ZvBVbsaNqHEP6ymXaPGlj\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2020-07-22\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 64.0, \"Danceability\": 0.732, \"Energy\": 0.663, \"Loudness\": -7.616, \"Speechiness\": 0.192, \"Acousticness\": 0.0819, \"Liveness\": 0.115, \"Tempo\": 139.964, \"Duration (ms)\": 210587.0, \"Valence\": 0.227, \"Chord\": \"F#/Gb\"}, {\"Index\": 994, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Andere Welt\", \"Streams\": 5600868, \"Artist\": \"Capital Bra, Clueso, KC Rebell\", \"Artist Followers\": 4093115.0, \"Song ID\": \"5PAAUJTKLT0nCmHUlLdPXb\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-07-23\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 60.0, \"Danceability\": 0.692, \"Energy\": 0.764, \"Loudness\": -5.233, \"Speechiness\": 0.113, \"Acousticness\": 0.574, \"Liveness\": 0.106, \"Tempo\": 84.029, \"Duration (ms)\": 189686.0, \"Valence\": 0.564, \"Chord\": \"F\"}, {\"Index\": 995, \"Highest Charting Position\": 163, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"TELL ME WHY\", \"Streams\": 5056986, \"Artist\": \"The Kid LAROI\", \"Artist Followers\": 2238190.0, \"Song ID\": \"3jlxX3VXPiY3lvBBbppQD3\", \"Genre\": \"['australian hip hop']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 71.0, \"Danceability\": 0.6, \"Energy\": 0.723, \"Loudness\": -4.928, \"Speechiness\": 0.158, \"Acousticness\": 0.109, \"Liveness\": 0.167, \"Tempo\": 149.881, \"Duration (ms)\": 195268.0, \"Valence\": 0.463, \"Chord\": \"F#/Gb\"}, {\"Index\": 996, \"Highest Charting Position\": 37, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Stay High\", \"Streams\": 5047752, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"21CkzgKCBCq5V4XKjiGSIj\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 75.0, \"Danceability\": 0.745, \"Energy\": 0.5, \"Loudness\": -6.184, \"Speechiness\": 0.135, \"Acousticness\": 0.439, \"Liveness\": 0.0943, \"Tempo\": 76.968, \"Duration (ms)\": 168685.0, \"Valence\": 0.433, \"Chord\": \"G#/Ab\"}, {\"Index\": 997, \"Highest Charting Position\": 161, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"What Makes You Beautiful\", \"Streams\": 4966428, \"Artist\": \"One Direction\", \"Artist Followers\": 22536304.0, \"Song ID\": \"4cluDES4hQEUhmXj6TXkSo\", \"Genre\": \"['boy band', 'pop', 'post-teen pop', 'talent show']\", \"Release Date\": \"2012-05-25\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\", \"Popularity\": 82.0, \"Danceability\": 0.726, \"Energy\": 0.787, \"Loudness\": -2.494, \"Speechiness\": 0.0737, \"Acousticness\": 0.009, \"Liveness\": 0.0596, \"Tempo\": 124.99, \"Duration (ms)\": 199987.0, \"Valence\": 0.888, \"Chord\": \"E\"}, {\"Index\": 998, \"Highest Charting Position\": 174, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Shit Changed\", \"Streams\": 4823401, \"Artist\": \"Ufo361, Sonus030\", \"Artist Followers\": 1700759.0, \"Song ID\": \"6du77YHyGWoFjbuHCFBHU3\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-10-02\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 52.0, \"Danceability\": 0.824, \"Energy\": 0.528, \"Loudness\": -9.236, \"Speechiness\": 0.175, \"Acousticness\": 0.144, \"Liveness\": 0.104, \"Tempo\": 157.005, \"Duration (ms)\": 183839.0, \"Valence\": 0.32, \"Chord\": \"A\"}, {\"Index\": 999, \"Highest Charting Position\": 35, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Tell Me U Luv Me (with Trippie Redd)\", \"Streams\": 4798078, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"5JAYDuLRkODlVt6dgoalKk\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 72.0, \"Danceability\": 0.66, \"Energy\": 0.76, \"Loudness\": -5.726, \"Speechiness\": 0.0787, \"Acousticness\": 0.291, \"Liveness\": 0.632, \"Tempo\": 127.984, \"Duration (ms)\": 180129.0, \"Valence\": 0.394, \"Chord\": \"D\"}, {\"Index\": 1000, \"Highest Charting Position\": 27, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Bad Energy\", \"Streams\": 4761155, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"7d94IqWX2UmSKMGUYSGFJG\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 72.0, \"Danceability\": 0.654, \"Energy\": 0.452, \"Loudness\": -6.36, \"Speechiness\": 0.0439, \"Acousticness\": 0.17, \"Liveness\": 0.114, \"Tempo\": 138.034, \"Duration (ms)\": 186749.0, \"Valence\": 0.532, \"Chord\": \"G\"}, {\"Index\": 1001, \"Highest Charting Position\": 24, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Titanic\", \"Streams\": 4687464, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"1YM6c2sxbf2Jacl9IFgn4I\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 71.0, \"Danceability\": 0.567, \"Energy\": 0.545, \"Loudness\": -6.668, \"Speechiness\": 0.0448, \"Acousticness\": 0.168, \"Liveness\": 0.112, \"Tempo\": 174.146, \"Duration (ms)\": 176650.0, \"Valence\": 0.234, \"Chord\": \"C#/Db\"}, {\"Index\": 1002, \"Highest Charting Position\": 31, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Skechers\", \"Streams\": 4669248, \"Artist\": \"DripReport\", \"Artist Followers\": 92356.0, \"Song ID\": \"2alc8VZAzDgdAsL2QMk3hu\", \"Genre\": \"['viral rap']\", \"Release Date\": \"2020-01-12\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 73.0, \"Danceability\": 0.903, \"Energy\": 0.327, \"Loudness\": -9.727, \"Speechiness\": 0.0877, \"Acousticness\": 0.26, \"Liveness\": 0.108, \"Tempo\": 100.008, \"Duration (ms)\": 106000.0, \"Valence\": 0.274, \"Chord\": \"C#/Db\"}, {\"Index\": 1003, \"Highest Charting Position\": 47, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"The Bigger Picture\", \"Streams\": 4629083, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"44gRhRi2OhEf7moAUj6MD1\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-07-24--2020-07-31\\n2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 70.0, \"Danceability\": 0.59, \"Energy\": 0.618, \"Loudness\": -5.756, \"Speechiness\": 0.334, \"Acousticness\": 0.0127, \"Liveness\": 0.244, \"Tempo\": 96.459, \"Duration (ms)\": 252729.0, \"Valence\": 0.153, \"Chord\": \"C#/Db\"}, {\"Index\": 1004, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Story of My Life\", \"Streams\": 4628772, \"Artist\": \"One Direction\", \"Artist Followers\": 22536304.0, \"Song ID\": \"4nVBt6MZDDP6tRVdQTgxJg\", \"Genre\": \"['boy band', 'pop', 'post-teen pop', 'talent show']\", \"Release Date\": \"2013-11-25\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 81.0, \"Danceability\": 0.6, \"Energy\": 0.663, \"Loudness\": -5.802, \"Speechiness\": 0.0477, \"Acousticness\": 0.225, \"Liveness\": 0.119, \"Tempo\": 121.07, \"Duration (ms)\": 245493.0, \"Valence\": 0.286, \"Chord\": \"D#/Eb\"}, {\"Index\": 1005, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-24--2020-07-31\", \"Song Name\": \"Hit My Line\", \"Streams\": 4621205, \"Artist\": \"Logic\", \"Artist Followers\": 5449291.0, \"Song ID\": \"24FR8mXTaiGZPrxnkf1kcP\", \"Genre\": \"['conscious hip hop', 'dmv rap', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-07-24\", \"Weeks Charted\": \"2020-07-24--2020-07-31\", \"Popularity\": 60.0, \"Danceability\": 0.62, \"Energy\": 0.786, \"Loudness\": -5.22, \"Speechiness\": 0.167, \"Acousticness\": 0.143, \"Liveness\": 0.46, \"Tempo\": 164.057, \"Duration (ms)\": 265191.0, \"Valence\": 0.679, \"Chord\": \"A\"}, {\"Index\": 1006, \"Highest Charting Position\": 10, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Party Girl (Remix)\", \"Streams\": 15129295, \"Artist\": \"StaySolidRocky, Lil Uzi Vert\", \"Artist Followers\": 150587.0, \"Song ID\": \"0XkmeG97T4mtYlWRJcrxec\", \"Genre\": \"['melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 62.0, \"Danceability\": 0.752, \"Energy\": 0.375, \"Loudness\": -10.157, \"Speechiness\": 0.204, \"Acousticness\": 0.533, \"Liveness\": 0.175, \"Tempo\": 129.995, \"Duration (ms)\": 147673.0, \"Valence\": 0.591, \"Chord\": \"F#/Gb\"}, {\"Index\": 1007, \"Highest Charting Position\": 43, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Up Up And Away\", \"Streams\": 6229316, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"7pbg3ABlAZv2NiIdKbBBFm\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 72.0, \"Danceability\": 0.661, \"Energy\": 0.665, \"Loudness\": -6.356, \"Speechiness\": 0.053, \"Acousticness\": 0.538, \"Liveness\": 0.0981, \"Tempo\": 75.059, \"Duration (ms)\": 147548.0, \"Valence\": 0.486, \"Chord\": \"E\"}, {\"Index\": 1008, \"Highest Charting Position\": 46, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Man Of The Year\", \"Streams\": 6223001, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"7AvprzMsRJpybaalckaT8c\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 73.0, \"Danceability\": 0.621, \"Energy\": 0.695, \"Loudness\": -5.124, \"Speechiness\": 0.0911, \"Acousticness\": 0.00584, \"Liveness\": 0.086, \"Tempo\": 173.966, \"Duration (ms)\": 136408.0, \"Valence\": 0.298, \"Chord\": \"E\"}, {\"Index\": 1009, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Fighting Demons\", \"Streams\": 5946573, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"0440JCJyIAmINA8KcYgFb5\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 70.0, \"Danceability\": 0.707, \"Energy\": 0.67, \"Loudness\": -6.328, \"Speechiness\": 0.257, \"Acousticness\": 0.0813, \"Liveness\": 0.098, \"Tempo\": 163.099, \"Duration (ms)\": 200629.0, \"Valence\": 0.235, \"Chord\": \"G\"}, {\"Index\": 1010, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Can't Die\", \"Streams\": 5777859, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4PPLJAEYBSOcnzr9TZoqf9\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 71.0, \"Danceability\": 0.652, \"Energy\": 0.671, \"Loudness\": -5.89, \"Speechiness\": 0.0756, \"Acousticness\": 0.0222, \"Liveness\": 0.107, \"Tempo\": 84.008, \"Duration (ms)\": 182922.0, \"Valence\": 0.274, \"Chord\": \"D\"}, {\"Index\": 1011, \"Highest Charting Position\": 44, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Screw Juice\", \"Streams\": 5394197, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4F6YLjakjqWFTgC5qfEwPQ\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 69.0, \"Danceability\": 0.595, \"Energy\": 0.528, \"Loudness\": -7.371, \"Speechiness\": 0.0935, \"Acousticness\": 0.082, \"Liveness\": 0.142, \"Tempo\": 150.075, \"Duration (ms)\": 179464.0, \"Valence\": 0.515, \"Chord\": \"F\"}, {\"Index\": 1012, \"Highest Charting Position\": 129, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Past Life (with Selena Gomez)\", \"Streams\": 5228433, \"Artist\": \"Trevor Daniel\", \"Artist Followers\": 632097.0, \"Song ID\": \"7MN8RYSofZsFROBlEOAzXq\", \"Genre\": \"['alternative r&b', 'melodic rap', 'pop rap']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 47.0, \"Danceability\": 0.575, \"Energy\": 0.543, \"Loudness\": -5.062, \"Speechiness\": 0.0529, \"Acousticness\": 0.102, \"Liveness\": 0.176, \"Tempo\": 159.905, \"Duration (ms)\": 186480.0, \"Valence\": 0.283, \"Chord\": \"D#/Eb\"}, {\"Index\": 1013, \"Highest Charting Position\": 45, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"I Want It\", \"Streams\": 5137482, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"2SVx3uds6jTWALFxevIWMA\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 69.0, \"Danceability\": 0.288, \"Energy\": 0.638, \"Loudness\": -6.935, \"Speechiness\": 0.0779, \"Acousticness\": 0.133, \"Liveness\": 0.14, \"Tempo\": 66.424, \"Duration (ms)\": 173114.0, \"Valence\": 0.147, \"Chord\": \"E\"}, {\"Index\": 1014, \"Highest Charting Position\": 56, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Ransom\", \"Streams\": 5097394, \"Artist\": \"Lil Tecca\", \"Artist Followers\": 4022792.0, \"Song ID\": \"1lOe9qE0vR9zwWQAOk6CoO\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-08-30\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.745, \"Energy\": 0.642, \"Loudness\": -6.257, \"Speechiness\": 0.287, \"Acousticness\": 0.0204, \"Liveness\": 0.0658, \"Tempo\": 179.974, \"Duration (ms)\": 131240.0, \"Valence\": 0.226, \"Chord\": \"G\"}, {\"Index\": 1015, \"Highest Charting Position\": 49, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Diosa\", \"Streams\": 4868180, \"Artist\": \"Myke Towers\", \"Artist Followers\": 6161098.0, \"Song ID\": \"3JHpk0DOTOzyh0777JFAky\", \"Genre\": \"['trap latino']\", \"Release Date\": \"2020-01-24\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 74.0, \"Danceability\": 0.801, \"Energy\": 0.745, \"Loudness\": -3.733, \"Speechiness\": 0.063, \"Acousticness\": 0.398, \"Liveness\": 0.153, \"Tempo\": 104.965, \"Duration (ms)\": 214013.0, \"Valence\": 0.245, \"Chord\": \"F#/Gb\"}, {\"Index\": 1016, \"Highest Charting Position\": 169, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-17--2020-07-24\", \"Song Name\": \"Never Know (feat. SHIRIN DAVID)\", \"Streams\": 4803071, \"Artist\": \"Luciano\", \"Artist Followers\": 942380.0, \"Song ID\": \"5Hkj1XjMJv5QCGc9NwZm6z\", \"Genre\": \"['german drill', 'german hip hop']\", \"Release Date\": \"2020-07-16\", \"Weeks Charted\": \"2020-07-17--2020-07-24\", \"Popularity\": 60.0, \"Danceability\": 0.874, \"Energy\": 0.542, \"Loudness\": -7.064, \"Speechiness\": 0.344, \"Acousticness\": 0.0621, \"Liveness\": 0.181, \"Tempo\": 142.016, \"Duration (ms)\": 196933.0, \"Valence\": 0.481, \"Chord\": \"A#/Bb\"}, {\"Index\": 1017, \"Highest Charting Position\": 5, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"La Dif\\u00edcil\", \"Streams\": 4727554, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"6NfrH0ANGmgBXyxgV2PeXt\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 78.0, \"Danceability\": 0.685, \"Energy\": 0.848, \"Loudness\": -4.561, \"Speechiness\": 0.0858, \"Acousticness\": 0.0861, \"Liveness\": 0.0783, \"Tempo\": 179.87, \"Duration (ms)\": 163084.0, \"Valence\": 0.761, \"Chord\": \"G#/Ab\"}, {\"Index\": 1018, \"Highest Charting Position\": 20, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"TROLLZ (with Nicki Minaj)\", \"Streams\": 4700152, \"Artist\": \"6ix9ine\", \"Artist Followers\": 6514102.0, \"Song ID\": \"3dVvWnj4D8JGkKvo6Hucso\", \"Genre\": \"['emo rap', 'rap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 65.0, \"Danceability\": 0.744, \"Energy\": 0.422, \"Loudness\": -8.946, \"Speechiness\": 0.294, \"Acousticness\": 0.0319, \"Liveness\": 0.11, \"Tempo\": 180.006, \"Duration (ms)\": 202667.0, \"Valence\": 0.493, \"Chord\": \"C#/Db\"}, {\"Index\": 1019, \"Highest Charting Position\": 44, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Old Town Road - Remix\", \"Streams\": 4643817, \"Artist\": \"Lil Nas X, Billy Ray Cyrus\", \"Artist Followers\": 5488666.0, \"Song ID\": \"2YpeDb67231RjR0MgVLzsG\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.878, \"Energy\": 0.619, \"Loudness\": -5.56, \"Speechiness\": 0.102, \"Acousticness\": 0.0533, \"Liveness\": 0.113, \"Tempo\": 136.041, \"Duration (ms)\": 157067.0, \"Valence\": 0.639, \"Chord\": \"F#/Gb\"}, {\"Index\": 1020, \"Highest Charting Position\": 67, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"The Adventures of Moon Man & Slim Shady (with Eminem)\", \"Streams\": 4639929, \"Artist\": \"Kid Cudi\", \"Artist Followers\": 5002317.0, \"Song ID\": \"38iBrrbbXyWaSPkmuDNgjZ\", \"Genre\": \"['hip hop', 'ohio hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\", \"Popularity\": 67.0, \"Danceability\": 0.88, \"Energy\": 0.787, \"Loudness\": -5.189, \"Speechiness\": 0.118, \"Acousticness\": 0.226, \"Liveness\": 0.12, \"Tempo\": 113.018, \"Duration (ms)\": 264834.0, \"Valence\": 0.588, \"Chord\": \"G#/Ab\"}, {\"Index\": 1021, \"Highest Charting Position\": 25, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"China\", \"Streams\": 4627026, \"Artist\": \"Anuel AA, Daddy Yankee, KAROL G, Ozuna, J Balvin\", \"Artist Followers\": 18306226.0, \"Song ID\": \"2ksOAxtIxY8yElEWw8RhgK\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2019-07-19\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.786, \"Energy\": 0.808, \"Loudness\": -3.702, \"Speechiness\": 0.0882, \"Acousticness\": 0.0846, \"Liveness\": 0.0822, \"Tempo\": 105.027, \"Duration (ms)\": 301714.0, \"Valence\": 0.609, \"Chord\": \"G\"}, {\"Index\": 1022, \"Highest Charting Position\": 29, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Hola - Remix\", \"Streams\": 4617726, \"Artist\": \"Dalex, Lenny Tav\\u00e1rez, Chencho Corleone, Juhn, D\\u00edmelo Flow\", \"Artist Followers\": 3600989.0, \"Song ID\": \"5stPVcRqb4qixbafP9e8lt\", \"Genre\": \"['latin', 'r&b en espanol', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-01\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.654, \"Energy\": 0.672, \"Loudness\": -5.98, \"Speechiness\": 0.311, \"Acousticness\": 0.471, \"Liveness\": 0.0781, \"Tempo\": 181.857, \"Duration (ms)\": 249520.0, \"Valence\": 0.343, \"Chord\": \"C\"}, {\"Index\": 1023, \"Highest Charting Position\": 6, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Ignorantes\", \"Streams\": 4613982, \"Artist\": \"Bad Bunny, Sech\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3wYRLYuO1M88d8woWUIxct\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 74.0, \"Danceability\": 0.85, \"Energy\": 0.536, \"Loudness\": -5.161, \"Speechiness\": 0.0599, \"Acousticness\": 0.267, \"Liveness\": 0.0996, \"Tempo\": 96.029, \"Duration (ms)\": 210607.0, \"Valence\": 0.505, \"Chord\": \"C#/Db\"}, {\"Index\": 1024, \"Highest Charting Position\": 2, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Yummy\", \"Streams\": 4599349, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"41L3O37CECZt3N7ziG2z7l\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-03\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 72.0, \"Danceability\": 0.687, \"Energy\": 0.514, \"Loudness\": -6.612, \"Speechiness\": 0.0897, \"Acousticness\": 0.366, \"Liveness\": 0.116, \"Tempo\": 145.921, \"Duration (ms)\": 210427.0, \"Valence\": 0.494, \"Chord\": \"A\"}, {\"Index\": 1025, \"Highest Charting Position\": 29, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"High Fashion (feat. Mustard)\", \"Streams\": 4592772, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6608815.0, \"Song ID\": \"07KXEDMj78x68D884wgVEm\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 77.0, \"Danceability\": 0.831, \"Energy\": 0.499, \"Loudness\": -8.442, \"Speechiness\": 0.114, \"Acousticness\": 0.269, \"Liveness\": 0.3, \"Tempo\": 97.956, \"Duration (ms)\": 220487.0, \"Valence\": 0.511, \"Chord\": \"B\"}, {\"Index\": 1026, \"Highest Charting Position\": 69, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Like That (feat. Gucci Mane)\", \"Streams\": 4565377, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"4EivmOT13NMpNSfTKn9p4s\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2019-11-07\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 77.0, \"Danceability\": 0.879, \"Energy\": 0.498, \"Loudness\": -6.027, \"Speechiness\": 0.18, \"Acousticness\": 0.239, \"Liveness\": 0.0967, \"Tempo\": 106.044, \"Duration (ms)\": 163173.0, \"Valence\": 0.405, \"Chord\": \"E\"}, {\"Index\": 1027, \"Highest Charting Position\": 132, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Goodbyes (feat. Young Thug)\", \"Streams\": 4527742, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"0t3ZvGKlmYmVsDzBJAXK8C\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 78.0, \"Danceability\": 0.548, \"Energy\": 0.653, \"Loudness\": -3.875, \"Speechiness\": 0.081, \"Acousticness\": 0.456, \"Liveness\": 0.103, \"Tempo\": 150.068, \"Duration (ms)\": 174853.0, \"Valence\": 0.163, \"Chord\": \"F\"}, {\"Index\": 1028, \"Highest Charting Position\": 23, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"BOP\", \"Streams\": 4496450, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"6Ozh9Ok6h4Oi1wUSLtBseN\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.769, \"Energy\": 0.787, \"Loudness\": -3.909, \"Speechiness\": 0.367, \"Acousticness\": 0.189, \"Liveness\": 0.129, \"Tempo\": 126.77, \"Duration (ms)\": 159715.0, \"Valence\": 0.836, \"Chord\": \"B\"}, {\"Index\": 1029, \"Highest Charting Position\": 21, \"Number of Times Charted\": 30, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Sigues Con El\", \"Streams\": 4485060, \"Artist\": \"D\\u00edmelo Flow, Arcangel, Sech\", \"Artist Followers\": 231580.0, \"Song ID\": \"7sQKy5vlPQllr0k9IjYJv3\", \"Genre\": \"['latin', 'perreo', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-07-17--2020-07-24\\n2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.883, \"Energy\": 0.668, \"Loudness\": -2.957, \"Speechiness\": 0.113, \"Acousticness\": 0.11, \"Liveness\": 0.0734, \"Tempo\": 87.972, \"Duration (ms)\": 226533.0, \"Valence\": 0.676, \"Chord\": \"A\"}, {\"Index\": 1030, \"Highest Charting Position\": 78, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Anxiety - Intro\", \"Streams\": 8449557, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"02XcRGWPkvomFvzTamEKHg\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 60.0, \"Danceability\": 0.307, \"Energy\": 0.528, \"Loudness\": -11.337, \"Speechiness\": 0.108, \"Acousticness\": 0.972, \"Liveness\": 0.222, \"Tempo\": 174.795, \"Duration (ms)\": 70395.0, \"Valence\": 0.58, \"Chord\": \"B\"}, {\"Index\": 1031, \"Highest Charting Position\": 112, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Juice WRLD Speaks From Heaven - Outro\", \"Streams\": 6682917, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"1OjiYjgPZyxS0AiXiSnuYI\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 59.0, \"Danceability\": 0.392, \"Energy\": 0.373, \"Loudness\": -14.097, \"Speechiness\": 0.0968, \"Acousticness\": 0.991, \"Liveness\": 0.545, \"Tempo\": 121.678, \"Duration (ms)\": 30583.0, \"Valence\": 0.519, \"Chord\": \"C\"}, {\"Index\": 1032, \"Highest Charting Position\": 113, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"The Man, The Myth, The Legend - Interlude\", \"Streams\": 6640728, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"4sjdZEEQvR1sXrRNSuBfbA\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2020-07-10\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 58.0, \"Danceability\": 0.667, \"Energy\": 0.447, \"Loudness\": -14.625, \"Speechiness\": 0.761, \"Acousticness\": 0.916, \"Liveness\": 0.612, \"Tempo\": 83.534, \"Duration (ms)\": 136545.0, \"Valence\": 0.829, \"Chord\": \"D\"}, {\"Index\": 1033, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Tiefschwarz (feat. Samra)\", \"Streams\": 5867111, \"Artist\": \"Kontra K\", \"Artist Followers\": 1818624.0, \"Song ID\": \"7jMMoHhgq6iwVT5ykyxsJt\", \"Genre\": \"['christlicher rap', 'german hip hop']\", \"Release Date\": \"2020-09-25\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 62.0, \"Danceability\": 0.751, \"Energy\": 0.783, \"Loudness\": -5.926, \"Speechiness\": 0.22, \"Acousticness\": 0.0715, \"Liveness\": 0.114, \"Tempo\": 94.003, \"Duration (ms)\": 189739.0, \"Valence\": 0.379, \"Chord\": \"G\"}, {\"Index\": 1034, \"Highest Charting Position\": 57, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Wash Us In The Blood\", \"Streams\": 5586085, \"Artist\": \"Kanye West, Travis Scott\", \"Artist Followers\": 14624703.0, \"Song ID\": \"7mEUjhl6aTztdHCrxoTgBG\", \"Genre\": \"['chicago rap', 'rap']\", \"Release Date\": \"2020-06-30\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 64.0, \"Danceability\": 0.67, \"Energy\": 0.847, \"Loudness\": -4.85, \"Speechiness\": 0.409, \"Acousticness\": 0.184, \"Liveness\": 0.304, \"Tempo\": 137.22, \"Duration (ms)\": 189827.0, \"Valence\": 0.381, \"Chord\": \"A#/Bb\"}, {\"Index\": 1035, \"Highest Charting Position\": 53, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Gangstas\", \"Streams\": 5104422, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"1hg3RlqFZXJb5YgRoK9qmF\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 71.0, \"Danceability\": 0.548, \"Energy\": 0.506, \"Loudness\": -7.434, \"Speechiness\": 0.102, \"Acousticness\": 0.203, \"Liveness\": 0.0788, \"Tempo\": 119.987, \"Duration (ms)\": 160000.0, \"Valence\": 0.557, \"Chord\": \"E\"}, {\"Index\": 1036, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-10--2020-07-17\", \"Song Name\": \"Monster\", \"Streams\": 5030481, \"Artist\": \"Red Velvet - IRENE & SEULGI\", \"Artist Followers\": 383695.0, \"Song ID\": \"6c1QaQHdDhtFMfUkhueuXK\", \"Genre\": \"['k-pop']\", \"Release Date\": \"2020-07-06\", \"Weeks Charted\": \"2020-07-10--2020-07-17\", \"Popularity\": 70.0, \"Danceability\": 0.631, \"Energy\": 0.748, \"Loudness\": -2.569, \"Speechiness\": 0.0488, \"Acousticness\": 0.212, \"Liveness\": 0.537, \"Tempo\": 115.665, \"Duration (ms)\": 178413.0, \"Valence\": 0.351, \"Chord\": \"E\"}, {\"Index\": 1037, \"Highest Charting Position\": 139, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"YAYA\", \"Streams\": 4729070, \"Artist\": \"6ix9ine\", \"Artist Followers\": 6514102.0, \"Song ID\": \"6EfBMJQwe2xLgldra6DaYp\", \"Genre\": \"['emo rap', 'rap']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 60.0, \"Danceability\": 0.672, \"Energy\": 0.733, \"Loudness\": -5.377, \"Speechiness\": 0.0566, \"Acousticness\": 0.00289, \"Liveness\": 0.199, \"Tempo\": 105.043, \"Duration (ms)\": 149857.0, \"Valence\": 0.354, \"Chord\": \"B\"}, {\"Index\": 1038, \"Highest Charting Position\": 174, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Narcos\", \"Streams\": 4633313, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"7mcdgAXmb35dakBnfDIv3q\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 68.0, \"Danceability\": 0.614, \"Energy\": 0.746, \"Loudness\": -3.527, \"Speechiness\": 0.196, \"Acousticness\": 0.347, \"Liveness\": 0.0874, \"Tempo\": 168.072, \"Duration (ms)\": 259250.0, \"Valence\": 0.601, \"Chord\": \"A#/Bb\"}, {\"Index\": 1039, \"Highest Charting Position\": 105, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"This City\", \"Streams\": 4597406, \"Artist\": \"Sam Fischer\", \"Artist Followers\": 122883.0, \"Song ID\": \"3H3r2nKWa3Yk5gt8xgmsEt\", \"Genre\": \"['alt z', 'australian pop', 'dance pop', 'indie cafe pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2019-12-11\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 80.0, \"Danceability\": 0.605, \"Energy\": 0.377, \"Loudness\": -6.213, \"Speechiness\": 0.0443, \"Acousticness\": 0.733, \"Liveness\": 0.0808, \"Tempo\": 73.877, \"Duration (ms)\": 194853.0, \"Valence\": 0.519, \"Chord\": \"B\"}, {\"Index\": 1040, \"Highest Charting Position\": 64, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Make It Rain (feat. Rowdy Rebel)\", \"Streams\": 4594248, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"71d7LaAgPcNcUopu3OzmP7\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 62.0, \"Danceability\": 0.5, \"Energy\": 0.767, \"Loudness\": -4.105, \"Speechiness\": 0.403, \"Acousticness\": 0.162, \"Liveness\": 0.385, \"Tempo\": 159.477, \"Duration (ms)\": 202443.0, \"Valence\": 0.58, \"Chord\": \"C#/Db\"}, {\"Index\": 1041, \"Highest Charting Position\": 46, \"Number of Times Charted\": 29, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lalala\", \"Streams\": 4541965, \"Artist\": \"Y2K, bbno$\", \"Artist Followers\": 268766.0, \"Song ID\": \"51Fjme0JiitpyXKuyQiCDo\", \"Genre\": \"['pop rap']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.843, \"Energy\": 0.39, \"Loudness\": -7.899, \"Speechiness\": 0.0846, \"Acousticness\": 0.178, \"Liveness\": 0.137, \"Tempo\": 129.972, \"Duration (ms)\": 160627.0, \"Valence\": 0.495, \"Chord\": \"D\"}, {\"Index\": 1042, \"Highest Charting Position\": 79, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Something Special\", \"Streams\": 4535580, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"5kkaSMcf4BFlhRRICCKZb6\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-10--2020-07-17\\n2020-07-03--2020-07-10\", \"Popularity\": 72.0, \"Danceability\": 0.739, \"Energy\": 0.616, \"Loudness\": -6.963, \"Speechiness\": 0.0338, \"Acousticness\": 0.252, \"Liveness\": 0.101, \"Tempo\": 91.071, \"Duration (ms)\": 158466.0, \"Valence\": 0.654, \"Chord\": \"G\"}, {\"Index\": 1043, \"Highest Charting Position\": 58, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Aim For The Moon (feat. Quavo)\", \"Streams\": 9011502, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"6O7fPYTsb2mY0PiFt2ymDB\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 67.0, \"Danceability\": 0.713, \"Energy\": 0.605, \"Loudness\": -7.487, \"Speechiness\": 0.107, \"Acousticness\": 0.497, \"Liveness\": 0.115, \"Tempo\": 142.025, \"Duration (ms)\": 175756.0, \"Valence\": 0.432, \"Chord\": \"B\"}, {\"Index\": 1044, \"Highest Charting Position\": 63, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"44 BullDog\", \"Streams\": 8443771, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"7sjFIZ1g5QLJLGja3k592K\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 66.0, \"Danceability\": 0.8, \"Energy\": 0.564, \"Loudness\": -5.817, \"Speechiness\": 0.4, \"Acousticness\": 0.0287, \"Liveness\": 0.112, \"Tempo\": 139.989, \"Duration (ms)\": 150857.0, \"Valence\": 0.318, \"Chord\": \"G#/Ab\"}, {\"Index\": 1045, \"Highest Charting Position\": 88, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Creature (feat. Swae Lee)\", \"Streams\": 7308690, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"3eV2WT9YhfzkxbufnBF8wK\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 66.0, \"Danceability\": 0.794, \"Energy\": 0.717, \"Loudness\": -5.73, \"Speechiness\": 0.251, \"Acousticness\": 0.0511, \"Liveness\": 0.195, \"Tempo\": 141.881, \"Duration (ms)\": 202816.0, \"Valence\": 0.372, \"Chord\": \"G\"}, {\"Index\": 1046, \"Highest Charting Position\": 95, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Yea Yea\", \"Streams\": 7112419, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"0bjgQ24UZGwKikldIyEOgf\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 63.0, \"Danceability\": 0.717, \"Energy\": 0.474, \"Loudness\": -8.383, \"Speechiness\": 0.403, \"Acousticness\": 0.0509, \"Liveness\": 0.139, \"Tempo\": 123.906, \"Duration (ms)\": 185804.0, \"Valence\": 0.448, \"Chord\": \"F\"}, {\"Index\": 1047, \"Highest Charting Position\": 100, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Enjoy Yourself (feat. Karol G)\", \"Streams\": 6620040, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"3NWrHCwvyII4fTx05PN3IO\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 70.0, \"Danceability\": 0.764, \"Energy\": 0.676, \"Loudness\": -6.761, \"Speechiness\": 0.0927, \"Acousticness\": 0.389, \"Liveness\": 0.215, \"Tempo\": 97.02, \"Duration (ms)\": 197938.0, \"Valence\": 0.461, \"Chord\": \"B\"}, {\"Index\": 1048, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Bad Bitch From Tokyo (Intro)\", \"Streams\": 6144736, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"4OGIeHtYhRTJ8iW21UUyZW\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 59.0, \"Danceability\": 0.645, \"Energy\": 0.64, \"Loudness\": -6.871, \"Speechiness\": 0.179, \"Acousticness\": 0.395, \"Liveness\": 0.286, \"Tempo\": 140.248, \"Duration (ms)\": 48000.0, \"Valence\": 0.674, \"Chord\": \"A#/Bb\"}, {\"Index\": 1049, \"Highest Charting Position\": 117, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Snitching (feat. Quavo & Future)\", \"Streams\": 6102253, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"2FhEj9lvEIaJihjFprRrGt\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 59.0, \"Danceability\": 0.944, \"Energy\": 0.579, \"Loudness\": -4.961, \"Speechiness\": 0.191, \"Acousticness\": 0.0381, \"Liveness\": 0.253, \"Tempo\": 135.033, \"Duration (ms)\": 259346.0, \"Valence\": 0.769, \"Chord\": \"G#/Ab\"}, {\"Index\": 1050, \"Highest Charting Position\": 121, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"West Coast Shit (feat. Tyga & Quavo)\", \"Streams\": 5931242, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"1JDhNQ0oOT7XpclZn3aQ8F\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 61.0, \"Danceability\": 0.831, \"Energy\": 0.762, \"Loudness\": -5.656, \"Speechiness\": 0.207, \"Acousticness\": 0.0885, \"Liveness\": 0.107, \"Tempo\": 99.999, \"Duration (ms)\": 192000.0, \"Valence\": 0.495, \"Chord\": \"B\"}, {\"Index\": 1051, \"Highest Charting Position\": 72, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Deep End Freestyle\", \"Streams\": 5280810, \"Artist\": \"Sleepy Hallow, Foushe\\u00e9\", \"Artist Followers\": 411262.0, \"Song ID\": \"2AlYncTpVHKwHb55F9lF6O\", \"Genre\": \"['brooklyn drill', 'nyc rap']\", \"Release Date\": \"2020-06-05\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 72.0, \"Danceability\": 0.868, \"Energy\": 0.479, \"Loudness\": -6.687, \"Speechiness\": 0.445, \"Acousticness\": 0.703, \"Liveness\": 0.102, \"Tempo\": 133.928, \"Duration (ms)\": 115200.0, \"Valence\": 0.776, \"Chord\": \"E\"}, {\"Index\": 1052, \"Highest Charting Position\": 56, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Tommy Lee (feat. Post Malone)\", \"Streams\": 5031845, \"Artist\": \"Tyla Yaweh\", \"Artist Followers\": 359133.0, \"Song ID\": \"5QZKcQDp0tCcvMdyqEciBV\", \"Genre\": \"['cali rap', 'melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 73.0, \"Danceability\": 0.457, \"Energy\": 0.621, \"Loudness\": -5.923, \"Speechiness\": 0.138, \"Acousticness\": 0.218, \"Liveness\": 0.0944, \"Tempo\": 85.359, \"Duration (ms)\": 224638.0, \"Valence\": 0.634, \"Chord\": \"A#/Bb\"}, {\"Index\": 1053, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"Tunnel Vision (Outro)\", \"Streams\": 4907751, \"Artist\": \"Pop Smoke\", \"Artist Followers\": 6852509.0, \"Song ID\": \"2SxR5RitJdsG6wINvJLBSD\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-07-03\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 60.0, \"Danceability\": 0.718, \"Energy\": 0.66, \"Loudness\": -7.39, \"Speechiness\": 0.325, \"Acousticness\": 0.363, \"Liveness\": 0.159, \"Tempo\": 142.879, \"Duration (ms)\": 132587.0, \"Valence\": 0.659, \"Chord\": \"D\"}, {\"Index\": 1054, \"Highest Charting Position\": 7, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Si Veo a Tu Mam\\u00e1\", \"Streams\": 4638728, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"41wtwzCZkXwpnakmwJ239F\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 80.0, \"Danceability\": 0.9, \"Energy\": 0.603, \"Loudness\": -5.313, \"Speechiness\": 0.0646, \"Acousticness\": 0.402, \"Liveness\": 0.134, \"Tempo\": 129.928, \"Duration (ms)\": 170972.0, \"Valence\": 0.824, \"Chord\": \"D\"}, {\"Index\": 1055, \"Highest Charting Position\": 177, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Prospect (ft. Lil Baby)\", \"Streams\": 4571916, \"Artist\": \"iann dior\", \"Artist Followers\": 1276292.0, \"Song ID\": \"4iHSE5R1U8jf84tRn52xRt\", \"Genre\": \"['melodic rap', 'pop rap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\", \"Popularity\": 68.0, \"Danceability\": 0.816, \"Energy\": 0.579, \"Loudness\": -6.097, \"Speechiness\": 0.0867, \"Acousticness\": 0.203, \"Liveness\": 0.127, \"Tempo\": 120.078, \"Duration (ms)\": 226314.0, \"Valence\": 0.43, \"Chord\": \"C#/Db\"}, {\"Index\": 1056, \"Highest Charting Position\": 55, \"Number of Times Charted\": 28, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"No Me Conoce - Remix\", \"Streams\": 4501188, \"Artist\": \"Jhay Cortez, J Balvin, Bad Bunny\", \"Artist Followers\": 2435159.0, \"Song ID\": \"4R8BJggjosTswLxtkw8V7P\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-05-24\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.806, \"Energy\": 0.786, \"Loudness\": -3.831, \"Speechiness\": 0.0741, \"Acousticness\": 0.145, \"Liveness\": 0.0935, \"Tempo\": 91.973, \"Duration (ms)\": 309120.0, \"Valence\": 0.58, \"Chord\": \"A#/Bb\"}, {\"Index\": 1057, \"Highest Charting Position\": 189, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-07-03--2020-07-10\", \"Song Name\": \"El Manual\", \"Streams\": 4470597, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"7kOf0qHO4Rcwk6QJifZDRJ\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-07-03--2020-07-10\", \"Popularity\": 67.0, \"Danceability\": 0.843, \"Energy\": 0.845, \"Loudness\": -2.344, \"Speechiness\": 0.0503, \"Acousticness\": 0.35, \"Liveness\": 0.0527, \"Tempo\": 126.989, \"Duration (ms)\": 210624.0, \"Valence\": 0.898, \"Chord\": \"C\"}, {\"Index\": 1058, \"Highest Charting Position\": 181, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Thunder\", \"Streams\": 4468668, \"Artist\": \"Imagine Dragons\", \"Artist Followers\": 35299488.0, \"Song ID\": \"1zB4vmk8tFRmM9UULNzbLB\", \"Genre\": \"['modern rock', 'pop', 'rock']\", \"Release Date\": \"2017-06-23\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-05--2020-06-12\\n2020-02-07--2020-02-14\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 83.0, \"Danceability\": 0.605, \"Energy\": 0.822, \"Loudness\": -4.833, \"Speechiness\": 0.0438, \"Acousticness\": 0.00671, \"Liveness\": 0.147, \"Tempo\": 167.997, \"Duration (ms)\": 187147.0, \"Valence\": 0.288, \"Chord\": \"C\"}, {\"Index\": 1059, \"Highest Charting Position\": 158, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"El Efecto - Remix\", \"Streams\": 4433384, \"Artist\": \"Rauw Alejandro, Chencho Corleone, KEVVO, Bryant Myers, Lyanno, Dalex\", \"Artist Followers\": 6096559.0, \"Song ID\": \"74j34STf8L6uADnTN69ohv\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 73.0, \"Danceability\": 0.771, \"Energy\": 0.769, \"Loudness\": -3.504, \"Speechiness\": 0.0694, \"Acousticness\": 0.18, \"Liveness\": 0.345, \"Tempo\": 167.969, \"Duration (ms)\": 289899.0, \"Valence\": 0.931, \"Chord\": \"C\"}, {\"Index\": 1060, \"Highest Charting Position\": 122, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Better Now\", \"Streams\": 4431571, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"7dt6x5M1jzdTEt8oCbisTK\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2018-04-27\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.68, \"Energy\": 0.578, \"Loudness\": -5.804, \"Speechiness\": 0.04, \"Acousticness\": 0.331, \"Liveness\": 0.135, \"Tempo\": 145.038, \"Duration (ms)\": 231267.0, \"Valence\": 0.341, \"Chord\": \"A#/Bb\"}, {\"Index\": 1061, \"Highest Charting Position\": 185, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Don't Stop Believin'\", \"Streams\": 4394985, \"Artist\": \"Journey\", \"Artist Followers\": 3731820.0, \"Song ID\": \"4bHsxqR3GMrXTxEPLuK5ue\", \"Genre\": \"['album rock', 'classic rock', 'hard rock', 'mellow gold', 'rock', 'soft rock']\", \"Release Date\": \"1981\", \"Weeks Charted\": \"2020-07-03--2020-07-10\\n2020-06-19--2020-06-26\", \"Popularity\": 81.0, \"Danceability\": 0.5, \"Energy\": 0.748, \"Loudness\": -9.072, \"Speechiness\": 0.0363, \"Acousticness\": 0.127, \"Liveness\": 0.447, \"Tempo\": 118.852, \"Duration (ms)\": 250987.0, \"Valence\": 0.514, \"Chord\": \"E\"}, {\"Index\": 1062, \"Highest Charting Position\": 90, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"BLACK PARADE\", \"Streams\": 5474807, \"Artist\": \"Beyonc\\u00e9\", \"Artist Followers\": 28335112.0, \"Song ID\": \"2qzUpSVI4NnPyWxbXwumTj\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'r&b']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\", \"Popularity\": 61.0, \"Danceability\": 0.824, \"Energy\": 0.555, \"Loudness\": -5.817, \"Speechiness\": 0.05, \"Acousticness\": 0.00337, \"Liveness\": 0.217, \"Tempo\": 120.002, \"Duration (ms)\": 281273.0, \"Valence\": 0.0611, \"Chord\": \"C#/Db\"}, {\"Index\": 1063, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"XXL\", \"Streams\": 5415994, \"Artist\": \"Miksu / Macloud, Summer Cem, Luciano, Jamule\", \"Artist Followers\": 30683.0, \"Song ID\": \"0p3euGPg5LgFeQGC7bBFuR\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 64.0, \"Danceability\": 0.798, \"Energy\": 0.527, \"Loudness\": -7.671, \"Speechiness\": 0.0447, \"Acousticness\": 0.227, \"Liveness\": 0.108, \"Tempo\": 114.008, \"Duration (ms)\": 166173.0, \"Valence\": 0.548, \"Chord\": \"F\"}, {\"Index\": 1064, \"Highest Charting Position\": 70, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Salt\", \"Streams\": 4874960, \"Artist\": \"Ava Max\", \"Artist Followers\": 1251372.0, \"Song ID\": \"2o2p9xH3bkSDLcp6phIF4J\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 1.0, \"Danceability\": 0.693, \"Energy\": 0.835, \"Loudness\": -3.242, \"Speechiness\": 0.0624, \"Acousticness\": 0.131, \"Liveness\": 0.073, \"Tempo\": 128.052, \"Duration (ms)\": 180283.0, \"Valence\": 0.744, \"Chord\": \"F#/Gb\"}, {\"Index\": 1065, \"Highest Charting Position\": 52, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Daisies\", \"Streams\": 4838067, \"Artist\": \"Katy Perry\", \"Artist Followers\": 18936929.0, \"Song ID\": \"4uqh9bualXNHXXwO2wPorc\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 68.0, \"Danceability\": 0.639, \"Energy\": 0.546, \"Loudness\": -5.382, \"Speechiness\": 0.0407, \"Acousticness\": 0.0837, \"Liveness\": 0.122, \"Tempo\": 122.179, \"Duration (ms)\": 173124.0, \"Valence\": 0.149, \"Chord\": \"C#/Db\"}, {\"Index\": 1066, \"Highest Charting Position\": 142, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Emotionally Scarred\", \"Streams\": 4633237, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"7ge7BHazYbVKi8qyZUX1Bm\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 71.0, \"Danceability\": 0.585, \"Energy\": 0.641, \"Loudness\": -4.269, \"Speechiness\": 0.133, \"Acousticness\": 0.0286, \"Liveness\": 0.316, \"Tempo\": 88.284, \"Duration (ms)\": 197530.0, \"Valence\": 0.266, \"Chord\": \"F#/Gb\"}, {\"Index\": 1067, \"Highest Charting Position\": 32, \"Number of Times Charted\": 16, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Myron\", \"Streams\": 4593309, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"56uXDJRCuoS7abX3SkzHKQ\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 76.0, \"Danceability\": 0.771, \"Energy\": 0.654, \"Loudness\": -6.976, \"Speechiness\": 0.298, \"Acousticness\": 0.055, \"Liveness\": 0.214, \"Tempo\": 155.047, \"Duration (ms)\": 224955.0, \"Valence\": 0.573, \"Chord\": \"G#/Ab\"}, {\"Index\": 1068, \"Highest Charting Position\": 67, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"MORE & MORE\", \"Streams\": 4592745, \"Artist\": \"TWICE\", \"Artist Followers\": 9998991.0, \"Song ID\": \"3omvXShuRPM3zbDpWYqf5g\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2020-06-01\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 70.0, \"Danceability\": 0.739, \"Energy\": 0.841, \"Loudness\": -4.162, \"Speechiness\": 0.06, \"Acousticness\": 0.0312, \"Liveness\": 0.173, \"Tempo\": 106.99, \"Duration (ms)\": 199653.0, \"Valence\": 0.562, \"Chord\": \"F\"}, {\"Index\": 1069, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Girls in the Hood\", \"Streams\": 4577209, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"6WbTTAGKrQtCQvmc5BuYfh\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-06-26\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 72.0, \"Danceability\": 0.821, \"Energy\": 0.863, \"Loudness\": -3.159, \"Speechiness\": 0.353, \"Acousticness\": 0.00824, \"Liveness\": 0.0377, \"Tempo\": 180.013, \"Duration (ms)\": 154324.0, \"Valence\": 0.874, \"Chord\": \"F#/Gb\"}, {\"Index\": 1070, \"Highest Charting Position\": 169, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Parasite Eve\", \"Streams\": 4545883, \"Artist\": \"Bring Me The Horizon\", \"Artist Followers\": 3912138.0, \"Song ID\": \"5OxclJsdFESni44YlpNpkR\", \"Genre\": \"['melodic metalcore', 'metalcore', 'rock', 'uk metalcore']\", \"Release Date\": \"2020-06-25\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 67.0, \"Danceability\": 0.589, \"Energy\": 0.797, \"Loudness\": -5.464, \"Speechiness\": 0.15, \"Acousticness\": 0.0289, \"Liveness\": 0.383, \"Tempo\": 102.489, \"Duration (ms)\": 291813.0, \"Valence\": 0.232, \"Chord\": \"A\"}, {\"Index\": 1071, \"Highest Charting Position\": 78, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Sucker\", \"Streams\": 4543863, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"22vgEDb5hykfaTwLuskFGD\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-06-07\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.842, \"Energy\": 0.734, \"Loudness\": -5.065, \"Speechiness\": 0.0588, \"Acousticness\": 0.0427, \"Liveness\": 0.106, \"Tempo\": 137.958, \"Duration (ms)\": 181027.0, \"Valence\": 0.952, \"Chord\": \"C#/Db\"}, {\"Index\": 1072, \"Highest Charting Position\": 147, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"I Like Me Better\", \"Streams\": 4430642, \"Artist\": \"Lauv\", \"Artist Followers\": 4442273.0, \"Song ID\": \"2P91MQbaiQOfbiz9VqhqKQ\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-05-31\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.752, \"Energy\": 0.505, \"Loudness\": -7.621, \"Speechiness\": 0.253, \"Acousticness\": 0.535, \"Liveness\": 0.104, \"Tempo\": 91.97, \"Duration (ms)\": 197437.0, \"Valence\": 0.419, \"Chord\": \"A\"}, {\"Index\": 1073, \"Highest Charting Position\": 116, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"High Hopes\", \"Streams\": 4426791, \"Artist\": \"Panic! At The Disco\", \"Artist Followers\": 10850424.0, \"Song ID\": \"1rqqCSm0Qe4I9rUvWncaom\", \"Genre\": \"['modern rock']\", \"Release Date\": \"2018-06-22\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.579, \"Energy\": 0.904, \"Loudness\": -2.729, \"Speechiness\": 0.0618, \"Acousticness\": 0.193, \"Liveness\": 0.064, \"Tempo\": 82.014, \"Duration (ms)\": 190947.0, \"Valence\": 0.681, \"Chord\": \"F\"}, {\"Index\": 1074, \"Highest Charting Position\": 88, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Money In The Grave (Drake ft. Rick Ross)\", \"Streams\": 4403348, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5ry2OE6R2zPQFDO85XkgRb\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2019-06-15\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.831, \"Energy\": 0.502, \"Loudness\": -4.045, \"Speechiness\": 0.046, \"Acousticness\": 0.101, \"Liveness\": 0.122, \"Tempo\": 100.541, \"Duration (ms)\": 205427.0, \"Valence\": 0.101, \"Chord\": \"A#/Bb\"}, {\"Index\": 1075, \"Highest Charting Position\": 25, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Say So (feat. Nicki Minaj)\", \"Streams\": 4385148, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"11VApNQCWLJdzxWrlmwzUa\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 69.0, \"Danceability\": 0.856, \"Energy\": 0.641, \"Loudness\": -4.64, \"Speechiness\": 0.204, \"Acousticness\": 0.119, \"Liveness\": 0.427, \"Tempo\": 111.004, \"Duration (ms)\": 206221.0, \"Valence\": 0.745, \"Chord\": \"B\"}, {\"Index\": 1076, \"Highest Charting Position\": 189, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Karaoke\", \"Streams\": 4374448, \"Artist\": \"Boomdabash, Alessandra Amoroso\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3n6TeHSnNhDe991nJS2S90\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-10\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 0.0, \"Danceability\": 0.929, \"Energy\": 0.625, \"Loudness\": -5.728, \"Speechiness\": 0.14, \"Acousticness\": 0.289, \"Liveness\": 0.386, \"Tempo\": 122.03, \"Duration (ms)\": 156493.0, \"Valence\": 0.578, \"Chord\": \"C#/Db\"}, {\"Index\": 1077, \"Highest Charting Position\": 36, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Know Your Worth\", \"Streams\": 4374392, \"Artist\": \"Khalid, Disclosure\", \"Artist Followers\": 14190858.0, \"Song ID\": \"0TrPqhAMoaKUFLR7iYDokf\", \"Genre\": \"['pop']\", \"Release Date\": \"2020-02-04\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 76.0, \"Danceability\": 0.79, \"Energy\": 0.694, \"Loudness\": -7.726, \"Speechiness\": 0.0708, \"Acousticness\": 0.145, \"Liveness\": 0.281, \"Tempo\": 103.007, \"Duration (ms)\": 181436.0, \"Valence\": 0.508, \"Chord\": \"A\"}, {\"Index\": 1078, \"Highest Charting Position\": 26, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"No Idea\", \"Streams\": 4369849, \"Artist\": \"Don Toliver\", \"Artist Followers\": 1606884.0, \"Song ID\": \"7AzlLxHn24DxjgQX73F9fU\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 80.0, \"Danceability\": 0.652, \"Energy\": 0.631, \"Loudness\": -5.718, \"Speechiness\": 0.0893, \"Acousticness\": 0.524, \"Liveness\": 0.165, \"Tempo\": 127.998, \"Duration (ms)\": 154424.0, \"Valence\": 0.35, \"Chord\": \"F#/Gb\"}, {\"Index\": 1079, \"Highest Charting Position\": 145, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Airwaves\", \"Streams\": 4352767, \"Artist\": \"Pashanim\", \"Artist Followers\": 208926.0, \"Song ID\": \"5CqkgDH8QZjSqqI3HmYxDD\", \"Genre\": \"['german alternative rap', 'german drill', 'german hip hop', 'german trap']\", \"Release Date\": \"2020-05-14\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 71.0, \"Danceability\": 0.885, \"Energy\": 0.578, \"Loudness\": -7.416, \"Speechiness\": 0.0783, \"Acousticness\": 0.0739, \"Liveness\": 0.102, \"Tempo\": 131.999, \"Duration (ms)\": 178933.0, \"Valence\": 0.388, \"Chord\": \"F\"}, {\"Index\": 1080, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-26--2020-07-03\", \"Song Name\": \"Kill This Love\", \"Streams\": 4341050, \"Artist\": \"BLACKPINK\", \"Artist Followers\": 23848461.0, \"Song ID\": \"6hvczQ05jc1yGlp9zhb95V\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2019-04-05\", \"Weeks Charted\": \"2020-06-26--2020-07-03\", \"Popularity\": 76.0, \"Danceability\": 0.763, \"Energy\": 0.835, \"Loudness\": -5.234, \"Speechiness\": 0.191, \"Acousticness\": 0.323, \"Liveness\": 0.225, \"Tempo\": 131.875, \"Duration (ms)\": 191050.0, \"Valence\": 0.645, \"Chord\": \"D\"}, {\"Index\": 1081, \"Highest Charting Position\": 68, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lights Up\", \"Streams\": 4325411, \"Artist\": \"Harry Styles\", \"Artist Followers\": 16127908.0, \"Song ID\": \"4jAIqgrPjKLTY9Gbez25Qb\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.575, \"Energy\": 0.621, \"Loudness\": -8.165, \"Speechiness\": 0.032, \"Acousticness\": 0.0392, \"Liveness\": 0.141, \"Tempo\": 101.987, \"Duration (ms)\": 172213.0, \"Valence\": 0.27, \"Chord\": \"A#/Bb\"}, {\"Index\": 1082, \"Highest Charting Position\": 14, \"Number of Times Charted\": 27, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Lose You To Love Me\", \"Streams\": 4322088, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4l0Mvzj72xxOpRrp6h8nHi\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.488, \"Energy\": 0.343, \"Loudness\": -8.985, \"Speechiness\": 0.0436, \"Acousticness\": 0.556, \"Liveness\": 0.21, \"Tempo\": 102.819, \"Duration (ms)\": 206459.0, \"Valence\": 0.0978, \"Chord\": \"E\"}, {\"Index\": 1083, \"Highest Charting Position\": 94, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Girls Like You (feat. Cardi B)\", \"Streams\": 4318772, \"Artist\": \"Maroon 5\", \"Artist Followers\": 32279979.0, \"Song ID\": \"6V1bu6o1Yo5ZXnsCJU8Ovk\", \"Genre\": \"['pop', 'pop rock']\", \"Release Date\": \"2018-06-15\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.851, \"Energy\": 0.541, \"Loudness\": -6.825, \"Speechiness\": 0.0505, \"Acousticness\": 0.568, \"Liveness\": 0.13, \"Tempo\": 124.959, \"Duration (ms)\": 235545.0, \"Valence\": 0.448, \"Chord\": \"C\"}, {\"Index\": 1084, \"Highest Charting Position\": 47, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"PA' ROMPERLA\", \"Streams\": 4312675, \"Artist\": \"Bad Bunny, Don Omar\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5XqCz18k96K8tx6DAYM97i\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-06-26--2020-07-03\\n2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 72.0, \"Danceability\": 0.772, \"Energy\": 0.83, \"Loudness\": -5.019, \"Speechiness\": 0.0599, \"Acousticness\": 0.016, \"Liveness\": 0.0843, \"Tempo\": 94.011, \"Duration (ms)\": 194200.0, \"Valence\": 0.697, \"Chord\": \"G\"}, {\"Index\": 1085, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"VACATION\", \"Streams\": 6883487, \"Artist\": \"Tyga\", \"Artist Followers\": 6298789.0, \"Song ID\": \"6q2uIyLqASSpv2SIv2ehWK\", \"Genre\": \"['dance pop', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 51.0, \"Danceability\": 0.821, \"Energy\": 0.61, \"Loudness\": -6.22, \"Speechiness\": 0.0959, \"Acousticness\": 0.0247, \"Liveness\": 0.185, \"Tempo\": 110.973, \"Duration (ms)\": 192936.0, \"Valence\": 0.47, \"Chord\": \"C#/Db\"}, {\"Index\": 1086, \"Highest Charting Position\": 86, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Big Body Benz\", \"Streams\": 6707101, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"2WOJ7D52Ng3myrKlEf4Azj\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-06-18\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 61.0, \"Danceability\": 0.884, \"Energy\": 0.451, \"Loudness\": -8.969, \"Speechiness\": 0.393, \"Acousticness\": 0.0731, \"Liveness\": 0.268, \"Tempo\": 94.024, \"Duration (ms)\": 148284.0, \"Valence\": 0.311, \"Chord\": \"A\"}, {\"Index\": 1087, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Ich wei\\u00df nicht mal wie sie hei\\u00dft\", \"Streams\": 5827600, \"Artist\": \"Capital Bra, Bozza\", \"Artist Followers\": 4093115.0, \"Song ID\": \"4KfL3Ne8bc9bC2PUB8QGwA\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-06-18\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 57.0, \"Danceability\": 0.498, \"Energy\": 0.836, \"Loudness\": -3.905, \"Speechiness\": 0.184, \"Acousticness\": 0.525, \"Liveness\": 0.0994, \"Tempo\": 199.846, \"Duration (ms)\": 168750.0, \"Valence\": 0.609, \"Chord\": \"A#/Bb\"}, {\"Index\": 1088, \"Highest Charting Position\": 101, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"F\\u00fatbol & Rumba (feat. Enrique Iglesias)\", \"Streams\": 5124116, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"2hDe0Ls5mVqs1XJqv7sbcM\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 67.0, \"Danceability\": 0.735, \"Energy\": 0.916, \"Loudness\": -2.082, \"Speechiness\": 0.117, \"Acousticness\": 0.397, \"Liveness\": 0.0918, \"Tempo\": 167.994, \"Duration (ms)\": 221429.0, \"Valence\": 0.691, \"Chord\": \"D\"}, {\"Index\": 1089, \"Highest Charting Position\": 131, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Bleed\", \"Streams\": 5095478, \"Artist\": \"A Boogie Wit da Hoodie\", \"Artist Followers\": 5865895.0, \"Song ID\": \"5XzombolzpiaOSTdj1W0VS\", \"Genre\": \"['melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-06-19\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 61.0, \"Danceability\": 0.698, \"Energy\": 0.572, \"Loudness\": -7.735, \"Speechiness\": 0.198, \"Acousticness\": 0.135, \"Liveness\": 0.154, \"Tempo\": 71.446, \"Duration (ms)\": 176959.0, \"Valence\": 0.391, \"Chord\": \"D\"}, {\"Index\": 1090, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-19--2020-06-26\", \"Song Name\": \"Snow On Tha Bluff\", \"Streams\": 5060764, \"Artist\": \"J. Cole\", \"Artist Followers\": 14103694.0, \"Song ID\": \"1oOEkBNp4zWnkD7nWjJdog\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2020-06-16\", \"Weeks Charted\": \"2020-06-19--2020-06-26\", \"Popularity\": 66.0, \"Danceability\": 0.586, \"Energy\": 0.512, \"Loudness\": -8.819, \"Speechiness\": 0.0668, \"Acousticness\": 0.723, \"Liveness\": 0.119, \"Tempo\": 75.857, \"Duration (ms)\": 235480.0, \"Valence\": 0.235, \"Chord\": \"G#/Ab\"}, {\"Index\": 1091, \"Highest Charting Position\": 113, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Djomb - Bien ou quoi\", \"Streams\": 4924714, \"Artist\": \"Bosh\", \"Artist Followers\": 300500.0, \"Song ID\": \"0KBwGCY9RYD9t2zjeW4h48\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 64.0, \"Danceability\": 0.945, \"Energy\": 0.676, \"Loudness\": -6.6, \"Speechiness\": 0.207, \"Acousticness\": 0.172, \"Liveness\": 0.322, \"Tempo\": 123.109, \"Duration (ms)\": 141893.0, \"Valence\": 0.631, \"Chord\": \"C#/Db\"}, {\"Index\": 1092, \"Highest Charting Position\": 84, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"In Your Eyes (feat. Alida)\", \"Streams\": 4654587, \"Artist\": \"Alida, Robin Schulz\", \"Artist Followers\": 2786366.0, \"Song ID\": \"61ZM92T2zaXIVsqncThQzC\", \"Genre\": \"['dance pop', 'deep euro house', 'deep house', 'edm', 'german dance', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 71.0, \"Danceability\": 0.57, \"Energy\": 0.672, \"Loudness\": -5.888, \"Speechiness\": 0.0716, \"Acousticness\": 0.172, \"Liveness\": 0.0768, \"Tempo\": 120.018, \"Duration (ms)\": 208222.0, \"Valence\": 0.461, \"Chord\": \"G#/Ab\"}, {\"Index\": 1093, \"Highest Charting Position\": 13, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Stupid Love\", \"Streams\": 4609858, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 1251372.0, \"Song ID\": \"1zPwSOUc5MPtPg8EgXAGKU\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-08\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 0.0, \"Danceability\": 0.68, \"Energy\": 0.825, \"Loudness\": -4.296, \"Speechiness\": 0.0702, \"Acousticness\": 0.00173, \"Liveness\": 0.27, \"Tempo\": 117.987, \"Duration (ms)\": 193533.0, \"Valence\": 0.784, \"Chord\": \"G#/Ab\"}, {\"Index\": 1094, \"Highest Charting Position\": 93, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Shotta Flow 5\", \"Streams\": 4513982, \"Artist\": \"NLE Choppa\", \"Artist Followers\": 3372385.0, \"Song ID\": \"1orjH4IkSH9VrWmRCToKV8\", \"Genre\": \"['memphis hip hop']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\", \"Popularity\": 62.0, \"Danceability\": 0.806, \"Energy\": 0.749, \"Loudness\": -5.268, \"Speechiness\": 0.328, \"Acousticness\": 0.0838, \"Liveness\": 0.0621, \"Tempo\": 140.032, \"Duration (ms)\": 145167.0, \"Valence\": 0.77, \"Chord\": \"C#/Db\"}, {\"Index\": 1095, \"Highest Charting Position\": 145, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"IDK You Yet\", \"Streams\": 4473413, \"Artist\": \"Alexander 23\", \"Artist Followers\": 207170.0, \"Song ID\": \"0j1Ia2lQWrcXrQZI4AdJlk\", \"Genre\": \"['alt z', 'indie cafe pop', 'pop', 'post-teen pop', 'social media pop']\", \"Release Date\": \"2020-06-23\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 79.0, \"Danceability\": 0.648, \"Energy\": 0.308, \"Loudness\": -11.729, \"Speechiness\": 0.04, \"Acousticness\": 0.886, \"Liveness\": 0.124, \"Tempo\": 76.997, \"Duration (ms)\": 184638.0, \"Valence\": 0.198, \"Chord\": \"C#/Db\"}, {\"Index\": 1096, \"Highest Charting Position\": 75, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Piece Of Your Heart\", \"Streams\": 4422905, \"Artist\": \"MEDUZA, Goodboys\", \"Artist Followers\": 441714.0, \"Song ID\": \"1DFD5Fotzgn6yYXkYsKiGs\", \"Genre\": \"['dance pop', 'edm', 'pop dance', 'pop house', 'tropical house']\", \"Release Date\": \"2019-02-01\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.677, \"Energy\": 0.744, \"Loudness\": -6.806, \"Speechiness\": 0.0295, \"Acousticness\": 0.0404, \"Liveness\": 0.074, \"Tempo\": 124.08, \"Duration (ms)\": 152913.0, \"Valence\": 0.631, \"Chord\": \"A#/Bb\"}, {\"Index\": 1097, \"Highest Charting Position\": 129, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Na Raba Toma Tap\\u00e3o\", \"Streams\": 4396629, \"Artist\": \"Niack\", \"Artist Followers\": 352402.0, \"Song ID\": \"0AGS6ZRgzobrazmCi6pYMe\", \"Genre\": \"['funk carioca']\", \"Release Date\": \"2020-06-06\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 61.0, \"Danceability\": 0.962, \"Energy\": 0.787, \"Loudness\": 1.509, \"Speechiness\": 0.0554, \"Acousticness\": 0.666, \"Liveness\": 0.176, \"Tempo\": 130.003, \"Duration (ms)\": 165231.0, \"Valence\": 0.968, \"Chord\": \"D#/Eb\"}, {\"Index\": 1098, \"Highest Charting Position\": 14, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"La Santa\", \"Streams\": 4384527, \"Artist\": \"Bad Bunny, Daddy Yankee\", \"Artist Followers\": 36177712.0, \"Song ID\": \"69vlMrzHwATKzupwNcUPyK\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 79.0, \"Danceability\": 0.744, \"Energy\": 0.868, \"Loudness\": -4.524, \"Speechiness\": 0.047, \"Acousticness\": 0.0326, \"Liveness\": 0.0822, \"Tempo\": 93.037, \"Duration (ms)\": 206420.0, \"Valence\": 0.586, \"Chord\": \"C#/Db\"}, {\"Index\": 1099, \"Highest Charting Position\": 125, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Make You Mine\", \"Streams\": 4356213, \"Artist\": \"PUBLIC\", \"Artist Followers\": 165504.0, \"Song ID\": \"5iFwAOB2TFkPJk8sMlxP8g\", \"Genre\": \"['indie rockism']\", \"Release Date\": \"2019-08-09\", \"Weeks Charted\": \"2020-06-19--2020-06-26\\n2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 77.0, \"Danceability\": 0.606, \"Energy\": 0.799, \"Loudness\": -4.452, \"Speechiness\": 0.0261, \"Acousticness\": 0.0128, \"Liveness\": 0.15, \"Tempo\": 103.014, \"Duration (ms)\": 232907.0, \"Valence\": 0.638, \"Chord\": \"A\"}, {\"Index\": 1100, \"Highest Charting Position\": 76, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"ROCKSTAR (feat. Roddy Ricch) - BLM REMIX\", \"Streams\": 7353153, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"4Aykm3xrOFSHrAnv80KUhh\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 62.0, \"Danceability\": 0.747, \"Energy\": 0.689, \"Loudness\": -7.246, \"Speechiness\": 0.242, \"Acousticness\": 0.197, \"Liveness\": 0.0884, \"Tempo\": 89.901, \"Duration (ms)\": 204547.0, \"Valence\": 0.75, \"Chord\": \"B\"}, {\"Index\": 1101, \"Highest Charting Position\": 97, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Make It Rain\", \"Streams\": 6042929, \"Artist\": \"Pop Smoke, Rowdy Rebel\", \"Artist Followers\": 6852509.0, \"Song ID\": \"4TgHt7vKCimpywaiKfl0uj\", \"Genre\": \"['brooklyn drill']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 64.0, \"Danceability\": 0.54, \"Energy\": 0.77, \"Loudness\": -3.981, \"Speechiness\": 0.389, \"Acousticness\": 0.194, \"Liveness\": 0.372, \"Tempo\": 159.494, \"Duration (ms)\": 204000.0, \"Valence\": 0.565, \"Chord\": \"C#/Db\"}, {\"Index\": 1102, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"M' Manc (con Geolier & Sfera Ebbasta)\", \"Streams\": 5171235, \"Artist\": \"Shablo\", \"Artist Followers\": 40045.0, \"Song ID\": \"0MLu1cFYL4ikdRTdasCQT9\", \"Genre\": \"['italian hip hop']\", \"Release Date\": \"2020-06-11\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 66.0, \"Danceability\": 0.703, \"Energy\": 0.704, \"Loudness\": -6.117, \"Speechiness\": 0.0641, \"Acousticness\": 0.048, \"Liveness\": 0.41, \"Tempo\": 139.933, \"Duration (ms)\": 180000.0, \"Valence\": 0.725, \"Chord\": \"F#/Gb\"}, {\"Index\": 1103, \"Highest Charting Position\": 143, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-12--2020-06-19\", \"Song Name\": \"Emotions 2.0\", \"Streams\": 5113459, \"Artist\": \"Ufo361, C\\u00c9LINE\", \"Artist Followers\": 1700759.0, \"Song ID\": \"3yZCjDTxzZxx1kll1sRjGc\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-06-12--2020-06-19\", \"Popularity\": 65.0, \"Danceability\": 0.788, \"Energy\": 0.491, \"Loudness\": -9.884, \"Speechiness\": 0.109, \"Acousticness\": 0.386, \"Liveness\": 0.107, \"Tempo\": 98.543, \"Duration (ms)\": 146028.0, \"Valence\": 0.271, \"Chord\": \"G#/Ab\"}, {\"Index\": 1104, \"Highest Charting Position\": 21, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"P2\", \"Streams\": 4769996, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"3kW4z2pIj5VY5fLjBrMRL5\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 73.0, \"Danceability\": 0.775, \"Energy\": 0.72, \"Loudness\": -5.353, \"Speechiness\": 0.193, \"Acousticness\": 0.0236, \"Liveness\": 0.114, \"Tempo\": 155.086, \"Duration (ms)\": 234627.0, \"Valence\": 0.49, \"Chord\": \"B\"}, {\"Index\": 1105, \"Highest Charting Position\": 79, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Selfish\", \"Streams\": 4754830, \"Artist\": \"Madison Beer\", \"Artist Followers\": 3370013.0, \"Song ID\": \"4PV0uE5pZSh44E3NqNNDEH\", \"Genre\": \"['alt z', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 70.0, \"Danceability\": 0.375, \"Energy\": 0.461, \"Loudness\": -6.202, \"Speechiness\": 0.0279, \"Acousticness\": 0.627, \"Liveness\": 0.386, \"Tempo\": 75.217, \"Duration (ms)\": 223270.0, \"Valence\": 0.233, \"Chord\": \"A\"}, {\"Index\": 1106, \"Highest Charting Position\": 154, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Surrender\", \"Streams\": 4627942, \"Artist\": \"Natalie Taylor\", \"Artist Followers\": 120208.0, \"Song ID\": \"0ecC8p17cDNlxHXkuYqeR6\", \"Genre\": \"[]\", \"Release Date\": \"2019-10-29\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 76.0, \"Danceability\": 0.39, \"Energy\": 0.448, \"Loudness\": -8.57, \"Speechiness\": 0.0276, \"Acousticness\": 0.8, \"Liveness\": 0.107, \"Tempo\": 144.89, \"Duration (ms)\": 183103.0, \"Valence\": 0.077, \"Chord\": \"F\"}, {\"Index\": 1107, \"Highest Charting Position\": 86, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Turks (with Gunna & ft. Travis Scott)\", \"Streams\": 4623279, \"Artist\": \"NAV\", \"Artist Followers\": 2613211.0, \"Song ID\": \"7IMwEtpAiJanqF6vQteZN2\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'hip hop', 'melodic rap', 'pop rap', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 67.0, \"Danceability\": 0.894, \"Energy\": 0.618, \"Loudness\": -4.356, \"Speechiness\": 0.129, \"Acousticness\": 0.0808, \"Liveness\": 0.558, \"Tempo\": 119.1, \"Duration (ms)\": 161320.0, \"Valence\": 0.379, \"Chord\": \"G\"}, {\"Index\": 1108, \"Highest Charting Position\": 48, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"BYE ME FUI\", \"Streams\": 4567732, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0FktnzDqjClqU6iqOZVEs2\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 72.0, \"Danceability\": 0.712, \"Energy\": 0.599, \"Loudness\": -6.342, \"Speechiness\": 0.112, \"Acousticness\": 0.412, \"Liveness\": 0.103, \"Tempo\": 179.788, \"Duration (ms)\": 178000.0, \"Valence\": 0.588, \"Chord\": \"F\"}, {\"Index\": 1109, \"Highest Charting Position\": 15, \"Number of Times Charted\": 25, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Vete\", \"Streams\": 4486408, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5DxXgozhkPLgrbKFY91w0c\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-21\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.886, \"Energy\": 0.672, \"Loudness\": -4.394, \"Speechiness\": 0.188, \"Acousticness\": 0.0363, \"Liveness\": 0.101, \"Tempo\": 91.976, \"Duration (ms)\": 192024.0, \"Valence\": 0.526, \"Chord\": \"C#/Db\"}, {\"Index\": 1110, \"Highest Charting Position\": 43, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Like It Is\", \"Streams\": 4463865, \"Artist\": \"Kygo, Zara Larsson, Tyga\", \"Artist Followers\": 7593792.0, \"Song ID\": \"3frUvGrmGcay91lvFbOgsN\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 68.0, \"Danceability\": 0.794, \"Energy\": 0.728, \"Loudness\": -6.759, \"Speechiness\": 0.114, \"Acousticness\": 0.121, \"Liveness\": 0.227, \"Tempo\": 105.024, \"Duration (ms)\": 183067.0, \"Valence\": 0.36, \"Chord\": \"C#/Db\"}, {\"Index\": 1111, \"Highest Charting Position\": 15, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"My Oh My (feat. DaBaby)\", \"Streams\": 4413457, \"Artist\": \"Camila Cabello\", \"Artist Followers\": 22698747.0, \"Song ID\": \"3yOlyBJuViE2YSGn3nVE1K\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.724, \"Energy\": 0.491, \"Loudness\": -6.024, \"Speechiness\": 0.0296, \"Acousticness\": 0.018, \"Liveness\": 0.0887, \"Tempo\": 105.046, \"Duration (ms)\": 170746.0, \"Valence\": 0.383, \"Chord\": \"G#/Ab\"}, {\"Index\": 1112, \"Highest Charting Position\": 161, \"Number of Times Charted\": 19, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Let Me Down Slowly\", \"Streams\": 4393932, \"Artist\": \"Alec Benjamin\", \"Artist Followers\": 2808285.0, \"Song ID\": \"2qxmye6gAegTMjLKEBoR3d\", \"Genre\": \"['alt z', 'electropop', 'pop']\", \"Release Date\": \"2018-11-16\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.652, \"Energy\": 0.557, \"Loudness\": -5.714, \"Speechiness\": 0.0318, \"Acousticness\": 0.74, \"Liveness\": 0.124, \"Tempo\": 150.073, \"Duration (ms)\": 169354.0, \"Valence\": 0.483, \"Chord\": \"C#/Db\"}, {\"Index\": 1113, \"Highest Charting Position\": 22, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"BELIEVE IT\", \"Streams\": 4361970, \"Artist\": \"PARTYNEXTDOOR, Rihanna\", \"Artist Followers\": 3129968.0, \"Song ID\": \"4HDCLYli2SUdkq9OjmvhSD\", \"Genre\": \"['pop', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap', 'urban contemporary']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-06-12--2020-06-19\\n2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 74.0, \"Danceability\": 0.43, \"Energy\": 0.7, \"Loudness\": -5.35, \"Speechiness\": 0.264, \"Acousticness\": 0.0902, \"Liveness\": 0.216, \"Tempo\": 158.373, \"Duration (ms)\": 183219.0, \"Valence\": 0.731, \"Chord\": \"F#/Gb\"}, {\"Index\": 1114, \"Highest Charting Position\": 86, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Boot\", \"Streams\": 6375562, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"12KENAKQY5JvAsRURN7TzB\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-07-31\", \"Weeks Charted\": \"2020-06-05--2020-06-12\", \"Popularity\": 54.0, \"Danceability\": 0.534, \"Energy\": 0.565, \"Loudness\": -7.546, \"Speechiness\": 0.307, \"Acousticness\": 0.0627, \"Liveness\": 0.112, \"Tempo\": 194.034, \"Duration (ms)\": 193360.0, \"Valence\": 0.529, \"Chord\": \"G#/Ab\"}, {\"Index\": 1115, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"Riot\", \"Streams\": 5163633, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"4aOOExMBUyxKnEYb39SrTg\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2020-06-01\", \"Weeks Charted\": \"2020-06-05--2020-06-12\", \"Popularity\": 70.0, \"Danceability\": 0.509, \"Energy\": 0.542, \"Loudness\": -8.027, \"Speechiness\": 0.442, \"Acousticness\": 0.019, \"Liveness\": 0.23, \"Tempo\": 97.767, \"Duration (ms)\": 78681.0, \"Valence\": 0.151, \"Chord\": \"D#/Eb\"}, {\"Index\": 1116, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-06-05--2020-06-12\", \"Song Name\": \"VALLA NEIN (feat. Luciano)\", \"Streams\": 5029858, \"Artist\": \"KC Rebell, Summer Cem\", \"Artist Followers\": 1101597.0, \"Song ID\": \"2rxxXYtTIFKyrhJpofeoIX\", \"Genre\": \"['german drill', 'german hip hop']\", \"Release Date\": \"2020-06-05\", \"Weeks Charted\": \"2020-06-05--2020-06-12\", \"Popularity\": 55.0, \"Danceability\": 0.761, \"Energy\": 0.657, \"Loudness\": -7.246, \"Speechiness\": 0.138, \"Acousticness\": 0.114, \"Liveness\": 0.356, \"Tempo\": 135.909, \"Duration (ms)\": 182040.0, \"Valence\": 0.589, \"Chord\": \"A#/Bb\"}, {\"Index\": 1117, \"Highest Charting Position\": 27, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"I\\u2019m Ready (with Demi Lovato)\", \"Streams\": 4764355, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"1fipvP2zmef6vN2IwXfJhY\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-04-16\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 68.0, \"Danceability\": 0.501, \"Energy\": 0.674, \"Loudness\": -6.363, \"Speechiness\": 0.0408, \"Acousticness\": 0.00346, \"Liveness\": 0.282, \"Tempo\": 155.051, \"Duration (ms)\": 200838.0, \"Valence\": 0.152, \"Chord\": \"F\"}, {\"Index\": 1118, \"Highest Charting Position\": 63, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"This Is America\", \"Streams\": 4727415, \"Artist\": \"Childish Gambino\", \"Artist Followers\": 8099554.0, \"Song ID\": \"0b9oOr2ZgvyQu88wzixux9\", \"Genre\": \"['atl hip hop', 'hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2018-05-06\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\", \"Popularity\": 71.0, \"Danceability\": 0.854, \"Energy\": 0.463, \"Loudness\": -6.159, \"Speechiness\": 0.137, \"Acousticness\": 0.117, \"Liveness\": 0.354, \"Tempo\": 120.024, \"Duration (ms)\": 225773.0, \"Valence\": 0.549, \"Chord\": \"F\"}, {\"Index\": 1119, \"Highest Charting Position\": 33, \"Number of Times Charted\": 24, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Fantasias\", \"Streams\": 4432324, \"Artist\": \"Rauw Alejandro, Farruko\", \"Artist Followers\": 6096559.0, \"Song ID\": \"6mAN61JH0dzyZpWslS11jy\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2019-08-29\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.879, \"Energy\": 0.703, \"Loudness\": -4.219, \"Speechiness\": 0.0701, \"Acousticness\": 0.143, \"Liveness\": 0.0569, \"Tempo\": 94.004, \"Duration (ms)\": 199711.0, \"Valence\": 0.788, \"Chord\": \"C#/Db\"}, {\"Index\": 1120, \"Highest Charting Position\": 60, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"BAD CON NICKY\", \"Streams\": 4432210, \"Artist\": \"Bad Bunny, Nicky Jam\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5bmSver2b3ZXyuyLKtgnFI\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 71.0, \"Danceability\": 0.59, \"Energy\": 0.729, \"Loudness\": -4.95, \"Speechiness\": 0.0893, \"Acousticness\": 0.321, \"Liveness\": 0.659, \"Tempo\": 93.094, \"Duration (ms)\": 202240.0, \"Valence\": 0.712, \"Chord\": \"G\"}, {\"Index\": 1121, \"Highest Charting Position\": 145, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"If I Can't Have You\", \"Streams\": 4364166, \"Artist\": \"Shawn Mendes\", \"Artist Followers\": 33893352.0, \"Song ID\": \"6LsAAHotRLMOHfCsSfYCsz\", \"Genre\": \"['canadian pop', 'dance pop', 'pop', 'post-teen pop', 'viral pop']\", \"Release Date\": \"2019-05-03\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.692, \"Energy\": 0.809, \"Loudness\": -4.198, \"Speechiness\": 0.0602, \"Acousticness\": 0.524, \"Liveness\": 0.147, \"Tempo\": 123.911, \"Duration (ms)\": 190800.0, \"Valence\": 0.864, \"Chord\": \"D\"}, {\"Index\": 1122, \"Highest Charting Position\": 27, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"What A Man Gotta Do\", \"Streams\": 4360660, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"4wNIkl5XGiAACjFBlDWuSd\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 77.0, \"Danceability\": 0.852, \"Energy\": 0.698, \"Loudness\": -7.206, \"Speechiness\": 0.0629, \"Acousticness\": 0.00839, \"Liveness\": 0.0773, \"Tempo\": 113.039, \"Duration (ms)\": 180645.0, \"Valence\": 0.324, \"Chord\": \"A\"}, {\"Index\": 1123, \"Highest Charting Position\": 50, \"Number of Times Charted\": 23, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Callaita\", \"Streams\": 4350496, \"Artist\": \"Bad Bunny, Tainy\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2TH65lNHgvLxCKXM3apjxI\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-05-31\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.61, \"Energy\": 0.624, \"Loudness\": -4.773, \"Speechiness\": 0.309, \"Acousticness\": 0.6, \"Liveness\": 0.243, \"Tempo\": 176.169, \"Duration (ms)\": 250534.0, \"Valence\": 0.244, \"Chord\": \"D\"}, {\"Index\": 1124, \"Highest Charting Position\": 51, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Solitaires (feat. Travis Scott)\", \"Streams\": 4334669, \"Artist\": \"Future\", \"Artist Followers\": 10491105.0, \"Song ID\": \"4kfeRwpq5KUaqTkgi4TbDF\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 67.0, \"Danceability\": 0.691, \"Energy\": 0.632, \"Loudness\": -7.598, \"Speechiness\": 0.0513, \"Acousticness\": 0.122, \"Liveness\": 0.0646, \"Tempo\": 169.982, \"Duration (ms)\": 205666.0, \"Valence\": 0.488, \"Chord\": \"C#/Db\"}, {\"Index\": 1125, \"Highest Charting Position\": 137, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"XO Tour Llif3\", \"Streams\": 4314080, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7GX5flRQZVHRAGd6B4TmDO\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2017-08-25\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-08--2020-05-15\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 82.0, \"Danceability\": 0.732, \"Energy\": 0.75, \"Loudness\": -6.366, \"Speechiness\": 0.231, \"Acousticness\": 0.00264, \"Liveness\": 0.109, \"Tempo\": 155.096, \"Duration (ms)\": 182707.0, \"Valence\": 0.401, \"Chord\": \"B\"}, {\"Index\": 1126, \"Highest Charting Position\": 189, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"changes\", \"Streams\": 4299334, \"Artist\": \"XXXTENTACION\", \"Artist Followers\": 29566516.0, \"Song ID\": \"7AFASza1mXqntmGtbxXprO\", \"Genre\": \"['emo rap', 'miami hip hop']\", \"Release Date\": \"2018-03-16\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 81.0, \"Danceability\": 0.669, \"Energy\": 0.308, \"Loudness\": -10.068, \"Speechiness\": 0.029, \"Acousticness\": 0.883, \"Liveness\": 0.0984, \"Tempo\": 64.934, \"Duration (ms)\": 121887.0, \"Valence\": 0.52, \"Chord\": \"B\"}, {\"Index\": 1127, \"Highest Charting Position\": 66, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Suicidal (Remix) [feat. Juice WRLD]\", \"Streams\": 4296154, \"Artist\": \"YNW Melly\", \"Artist Followers\": 6332535.0, \"Song ID\": \"4S2uhQE8L9V6p7rj7SiauJ\", \"Genre\": \"['melodic rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 76.0, \"Danceability\": 0.655, \"Energy\": 0.441, \"Loudness\": -5.245, \"Speechiness\": 0.0629, \"Acousticness\": 0.474, \"Liveness\": 0.099, \"Tempo\": 139.957, \"Duration (ms)\": 225857.0, \"Valence\": 0.273, \"Chord\": \"A\"}, {\"Index\": 1128, \"Highest Charting Position\": 30, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Level of Concern\", \"Streams\": 4252898, \"Artist\": \"Twenty One Pilots\", \"Artist Followers\": 20829526.0, \"Song ID\": \"6xZ4Q2k2ompmDppyeESIY8\", \"Genre\": \"['modern rock', 'rock']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-06-05--2020-06-12\\n2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 72.0, \"Danceability\": 0.754, \"Energy\": 0.583, \"Loudness\": -7.34, \"Speechiness\": 0.0432, \"Acousticness\": 0.32, \"Liveness\": 0.144, \"Tempo\": 122.012, \"Duration (ms)\": 220051.0, \"Valence\": 0.77, \"Chord\": \"E\"}, {\"Index\": 1129, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Alice\", \"Streams\": 10342277, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"41A89rj3GoMG6ktN37L7PG\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 64.0, \"Danceability\": 0.723, \"Energy\": 0.88, \"Loudness\": -4.287, \"Speechiness\": 0.038, \"Acousticness\": 0.00334, \"Liveness\": 0.0632, \"Tempo\": 123.036, \"Duration (ms)\": 177600.0, \"Valence\": 0.323, \"Chord\": \"B\"}, {\"Index\": 1130, \"Highest Charting Position\": 58, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Free Woman\", \"Streams\": 9266945, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"4L6ihclQPu1hqP9r3WNJjQ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 63.0, \"Danceability\": 0.731, \"Energy\": 0.927, \"Loudness\": -3.634, \"Speechiness\": 0.0781, \"Acousticness\": 0.0228, \"Liveness\": 0.187, \"Tempo\": 119.006, \"Duration (ms)\": 191467.0, \"Valence\": 0.478, \"Chord\": \"C\"}, {\"Index\": 1131, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Fun Tonight\", \"Streams\": 7907329, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"6hyQVqfHFvsJDjcmj4qrHf\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.645, \"Energy\": 0.923, \"Loudness\": -4.262, \"Speechiness\": 0.0725, \"Acousticness\": 0.364, \"Liveness\": 0.14, \"Tempo\": 117.945, \"Duration (ms)\": 173427.0, \"Valence\": 0.323, \"Chord\": \"B\"}, {\"Index\": 1132, \"Highest Charting Position\": 75, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Sine From Above (with Elton John)\", \"Streams\": 7734309, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"0zzsyWc45eUcSjw4FNHxeN\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 60.0, \"Danceability\": 0.642, \"Energy\": 0.792, \"Loudness\": -5.746, \"Speechiness\": 0.0488, \"Acousticness\": 0.158, \"Liveness\": 0.68, \"Tempo\": 122.965, \"Duration (ms)\": 244880.0, \"Valence\": 0.0903, \"Chord\": \"C\"}, {\"Index\": 1133, \"Highest Charting Position\": 77, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Enigma\", \"Streams\": 7695566, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"7JDbfYUHjDzQPFSDh5lzGs\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 59.0, \"Danceability\": 0.669, \"Energy\": 0.804, \"Loudness\": -4.035, \"Speechiness\": 0.036, \"Acousticness\": 0.0306, \"Liveness\": 0.694, \"Tempo\": 116.001, \"Duration (ms)\": 179760.0, \"Valence\": 0.184, \"Chord\": \"C\"}, {\"Index\": 1134, \"Highest Charting Position\": 79, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Replay\", \"Streams\": 7479618, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"7sKbyYeJnITO1Eh9xd0lKd\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 63.0, \"Danceability\": 0.658, \"Energy\": 0.878, \"Loudness\": -3.875, \"Speechiness\": 0.123, \"Acousticness\": 0.00792, \"Liveness\": 0.944, \"Tempo\": 122.015, \"Duration (ms)\": 186653.0, \"Valence\": 0.683, \"Chord\": \"C#/Db\"}, {\"Index\": 1135, \"Highest Charting Position\": 80, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Plastic Doll\", \"Streams\": 7451452, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"3CidPLqWXqgesJlwYVJZdy\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.743, \"Energy\": 0.853, \"Loudness\": -4.842, \"Speechiness\": 0.04, \"Acousticness\": 0.0019, \"Liveness\": 0.0872, \"Tempo\": 121.028, \"Duration (ms)\": 221667.0, \"Valence\": 0.422, \"Chord\": \"C\"}, {\"Index\": 1136, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Chromatica II\", \"Streams\": 7136521, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"0oQc0F6KUE7QY7k5TU6bic\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.184, \"Energy\": 0.297, \"Loudness\": -14.534, \"Speechiness\": 0.0359, \"Acousticness\": 0.473, \"Liveness\": 0.527, \"Tempo\": 75.824, \"Duration (ms)\": 41867.0, \"Valence\": 0.113, \"Chord\": \"D\"}, {\"Index\": 1137, \"Highest Charting Position\": 91, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Babylon\", \"Streams\": 6996402, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"5DttNeiizFqWUON9hZBqTY\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 61.0, \"Danceability\": 0.698, \"Energy\": 0.799, \"Loudness\": -4.372, \"Speechiness\": 0.0342, \"Acousticness\": 0.0129, \"Liveness\": 0.215, \"Tempo\": 115.957, \"Duration (ms)\": 161733.0, \"Valence\": 0.351, \"Chord\": \"D\"}, {\"Index\": 1138, \"Highest Charting Position\": 93, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Chromatica I\", \"Streams\": 6630385, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"0oQc0F6KUE7QY7k5TU6bic\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.184, \"Energy\": 0.297, \"Loudness\": -14.534, \"Speechiness\": 0.0359, \"Acousticness\": 0.473, \"Liveness\": 0.527, \"Tempo\": 75.824, \"Duration (ms)\": 41867.0, \"Valence\": 0.113, \"Chord\": \"D\"}, {\"Index\": 1139, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"1000 Doves\", \"Streams\": 6069544, \"Artist\": \"Lady Gaga\", \"Artist Followers\": 18585963.0, \"Song ID\": \"62hTXlVQacy3pjBW4ntRPl\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 58.0, \"Danceability\": 0.668, \"Energy\": 0.826, \"Loudness\": -4.466, \"Speechiness\": 0.0383, \"Acousticness\": 0.0236, \"Liveness\": 0.474, \"Tempo\": 122.973, \"Duration (ms)\": 215480.0, \"Valence\": 0.388, \"Chord\": \"A\"}, {\"Index\": 1140, \"Highest Charting Position\": 114, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Broken Glass\", \"Streams\": 5867930, \"Artist\": \"Kygo, Kim Petras\", \"Artist Followers\": 7593792.0, \"Song ID\": \"78ldtCaBRJVp2i91B715L0\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 66.0, \"Danceability\": 0.526, \"Energy\": 0.633, \"Loudness\": -7.002, \"Speechiness\": 0.134, \"Acousticness\": 0.372, \"Liveness\": 0.129, \"Tempo\": 171.044, \"Duration (ms)\": 203947.0, \"Valence\": 0.272, \"Chord\": \"G\"}, {\"Index\": 1141, \"Highest Charting Position\": 131, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"In meinem Benz\", \"Streams\": 5494500, \"Artist\": \"AK AUSSERKONTROLLE, Bonez MC\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 1142, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"FLY\", \"Streams\": 4681054, \"Artist\": \"KC Rebell, Summer Cem\", \"Artist Followers\": 1101597.0, \"Song ID\": \"1WoM4mof0Nl1xPtwf6h6ow\", \"Genre\": \"['german drill', 'german hip hop']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 59.0, \"Danceability\": 0.835, \"Energy\": 0.596, \"Loudness\": -6.637, \"Speechiness\": 0.297, \"Acousticness\": 0.137, \"Liveness\": 0.164, \"Tempo\": 100.706, \"Duration (ms)\": 174893.0, \"Valence\": 0.897, \"Chord\": \"F\"}, {\"Index\": 1143, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"SKRR\", \"Streams\": 4629320, \"Artist\": \"KALIM, Ufo361\", \"Artist Followers\": 218931.0, \"Song ID\": \"2J0adlQth373uw9y0yqWAz\", \"Genre\": \"['german hip hop', 'german trap', 'german underground rap', 'hamburg hip hop']\", \"Release Date\": \"2020-09-24\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 60.0, \"Danceability\": 0.803, \"Energy\": 0.649, \"Loudness\": -6.599, \"Speechiness\": 0.132, \"Acousticness\": 0.163, \"Liveness\": 0.152, \"Tempo\": 125.038, \"Duration (ms)\": 119040.0, \"Valence\": 0.584, \"Chord\": \"A#/Bb\"}, {\"Index\": 1144, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"T.D (Lil Yachty & Tierra Whack feat. A$AP Rocky & Tyler, The Creator)\", \"Streams\": 4601709, \"Artist\": \"Lil Yachty\", \"Artist Followers\": 7358720.0, \"Song ID\": \"0gO3E51A3fqp0ypJ26QbVP\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap', 'underground hip hop', 'viral rap']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 66.0, \"Danceability\": 0.784, \"Energy\": 0.632, \"Loudness\": -6.083, \"Speechiness\": 0.347, \"Acousticness\": 0.156, \"Liveness\": 0.605, \"Tempo\": 124.603, \"Duration (ms)\": 232839.0, \"Valence\": 0.746, \"Chord\": \"A#/Bb\"}, {\"Index\": 1145, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-29--2020-06-05\", \"Song Name\": \"Oprah's Bank Account (Lil Yachty & DaBaby feat. Drake)\", \"Streams\": 4598294, \"Artist\": \"Lil Yachty\", \"Artist Followers\": 7358720.0, \"Song ID\": \"7wsmIIm0xWmtP7TmACXkJn\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap', 'underground hip hop', 'viral rap']\", \"Release Date\": \"2020-03-09\", \"Weeks Charted\": \"2020-05-29--2020-06-05\", \"Popularity\": 69.0, \"Danceability\": 0.836, \"Energy\": 0.617, \"Loudness\": -4.363, \"Speechiness\": 0.0534, \"Acousticness\": 0.17, \"Liveness\": 0.319, \"Tempo\": 138.066, \"Duration (ms)\": 206702.0, \"Valence\": 0.866, \"Chord\": \"C\"}, {\"Index\": 1146, \"Highest Charting Position\": 78, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Roadrunner\", \"Streams\": 4596162, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"0atjNG0rNW2m6zPaiK4Co7\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-09-10\", \"Weeks Charted\": \"2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\", \"Popularity\": 64.0, \"Danceability\": 0.804, \"Energy\": 0.606, \"Loudness\": -9.045, \"Speechiness\": 0.242, \"Acousticness\": 0.137, \"Liveness\": 0.111, \"Tempo\": 99.024, \"Duration (ms)\": 149028.0, \"Valence\": 0.247, \"Chord\": \"G\"}, {\"Index\": 1147, \"Highest Charting Position\": 99, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Freedom\", \"Streams\": 4573723, \"Artist\": \"Kygo, Zak Abel\", \"Artist Followers\": 7593792.0, \"Song ID\": \"5Gj1wG8b12VQdEd3hUuSwo\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-05-29--2020-06-05\\n2020-04-17--2020-04-24\", \"Popularity\": 72.0, \"Danceability\": 0.715, \"Energy\": 0.635, \"Loudness\": -6.591, \"Speechiness\": 0.0791, \"Acousticness\": 0.127, \"Liveness\": 0.0862, \"Tempo\": 112.887, \"Duration (ms)\": 198635.0, \"Valence\": 0.39, \"Chord\": \"G\"}, {\"Index\": 1148, \"Highest Charting Position\": 45, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Fame\", \"Streams\": 4556947, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"3goH7O78TLkV9RhCAyM4AT\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-05-29--2020-06-05\\n2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 62.0, \"Danceability\": 0.811, \"Energy\": 0.645, \"Loudness\": -8.008, \"Speechiness\": 0.104, \"Acousticness\": 0.184, \"Liveness\": 0.103, \"Tempo\": 129.967, \"Duration (ms)\": 173761.0, \"Valence\": 0.474, \"Chord\": \"C#/Db\"}, {\"Index\": 1149, \"Highest Charting Position\": 55, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Daechwita\", \"Streams\": 8908179, \"Artist\": \"Agust D\", \"Artist Followers\": 5564366.0, \"Song ID\": \"0H4ugk6rhnXmTl47ayy9O5\", \"Genre\": \"['k-rap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 77.0, \"Danceability\": 0.65, \"Energy\": 0.827, \"Loudness\": -4.014, \"Speechiness\": 0.0599, \"Acousticness\": 0.0229, \"Liveness\": 0.121, \"Tempo\": 144.995, \"Duration (ms)\": 225668.0, \"Valence\": 0.223, \"Chord\": \"G#/Ab\"}, {\"Index\": 1150, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"COOLER THAN A BITCH (feat. Roddy Ricch)\", \"Streams\": 6642144, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"5LHHKZOwV8XW4LJP2C64mw\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 67.0, \"Danceability\": 0.837, \"Energy\": 0.586, \"Loudness\": -8.521, \"Speechiness\": 0.0807, \"Acousticness\": 0.281, \"Liveness\": 0.134, \"Tempo\": 117.066, \"Duration (ms)\": 197000.0, \"Valence\": 0.618, \"Chord\": \"B\"}, {\"Index\": 1151, \"Highest Charting Position\": 90, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"In Your Eyes (with Doja Cat) - Remix\", \"Streams\": 6511008, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"0UnTaVkntyh3vqvLEvbpQx\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-05-21\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 67.0, \"Danceability\": 0.679, \"Energy\": 0.731, \"Loudness\": -5.522, \"Speechiness\": 0.0319, \"Acousticness\": 0.00518, \"Liveness\": 0.0614, \"Tempo\": 99.984, \"Duration (ms)\": 237912.0, \"Valence\": 0.727, \"Chord\": \"G\"}, {\"Index\": 1152, \"Highest Charting Position\": 92, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"WUNNA\", \"Streams\": 6384306, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"0y7Ao3CVJsyKFmqdjutiIF\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 60.0, \"Danceability\": 0.89, \"Energy\": 0.455, \"Loudness\": -9.0, \"Speechiness\": 0.255, \"Acousticness\": 0.0217, \"Liveness\": 0.11, \"Tempo\": 148.009, \"Duration (ms)\": 158240.0, \"Valence\": 0.313, \"Chord\": \"C\"}, {\"Index\": 1153, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Komm Komm\", \"Streams\": 5552890, \"Artist\": \"Capital Bra\", \"Artist Followers\": 4093115.0, \"Song ID\": \"3US6RbELvvrPw3DcvtJmis\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-05-21\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 53.0, \"Danceability\": 0.485, \"Energy\": 0.793, \"Loudness\": -3.836, \"Speechiness\": 0.426, \"Acousticness\": 0.251, \"Liveness\": 0.146, \"Tempo\": 87.629, \"Duration (ms)\": 160667.0, \"Valence\": 0.371, \"Chord\": \"B\"}, {\"Index\": 1154, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"TOP FLOOR (feat. Travis Scott)\", \"Streams\": 5193309, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"4YhJ3a6kBPGJWX4Ek77sDd\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 63.0, \"Danceability\": 0.823, \"Energy\": 0.504, \"Loudness\": -8.65, \"Speechiness\": 0.16, \"Acousticness\": 0.206, \"Liveness\": 0.417, \"Tempo\": 112.985, \"Duration (ms)\": 169907.0, \"Valence\": 0.481, \"Chord\": \"G#/Ab\"}, {\"Index\": 1155, \"Highest Charting Position\": 54, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Goodbyes (Feat. Young Thug)\", \"Streams\": 5134161, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"0t3ZvGKlmYmVsDzBJAXK8C\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.548, \"Energy\": 0.653, \"Loudness\": -3.875, \"Speechiness\": 0.081, \"Acousticness\": 0.456, \"Liveness\": 0.103, \"Tempo\": 150.068, \"Duration (ms)\": 174853.0, \"Valence\": 0.163, \"Chord\": \"F\"}, {\"Index\": 1156, \"Highest Charting Position\": 59, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"CANCI\\u00d3N CON YANDEL\", \"Streams\": 5132247, \"Artist\": \"Yandel, Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3pm4XtcsRIFFtH2UErk62R\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 76.0, \"Danceability\": 0.75, \"Energy\": 0.741, \"Loudness\": -4.43, \"Speechiness\": 0.402, \"Acousticness\": 0.447, \"Liveness\": 0.121, \"Tempo\": 79.968, \"Duration (ms)\": 209180.0, \"Valence\": 0.495, \"Chord\": \"A\"}, {\"Index\": 1157, \"Highest Charting Position\": 92, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"X (with KAROL G)\", \"Streams\": 5018592, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"77fvnWALKJR0ws1VUx09CY\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\", \"Popularity\": 70.0, \"Danceability\": 0.715, \"Energy\": 0.827, \"Loudness\": -5.09, \"Speechiness\": 0.0617, \"Acousticness\": 0.0485, \"Liveness\": 0.321, \"Tempo\": 117.977, \"Duration (ms)\": 185277.0, \"Valence\": 0.75, \"Chord\": \"E\"}, {\"Index\": 1158, \"Highest Charting Position\": 56, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"M\\u00c1S DE UNA CITA\", \"Streams\": 4987116, \"Artist\": \"Bad Bunny, Zion & Lennox\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4EJHKSnHENfjOxXWryyNtL\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 67.0, \"Danceability\": 0.865, \"Energy\": 0.5, \"Loudness\": -10.805, \"Speechiness\": 0.0861, \"Acousticness\": 0.0122, \"Liveness\": 0.098, \"Tempo\": 92.976, \"Duration (ms)\": 183520.0, \"Valence\": 0.317, \"Chord\": \"F\"}, {\"Index\": 1159, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Together\", \"Streams\": 4861870, \"Artist\": \"Sia\", \"Artist Followers\": 20528724.0, \"Song ID\": \"5id3Rqn7SPj1LX4FfY4nGz\", \"Genre\": \"['australian dance', 'australian pop', 'dance pop', 'pop']\", \"Release Date\": \"2020-05-20\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 71.0, \"Danceability\": 0.521, \"Energy\": 0.877, \"Loudness\": -5.444, \"Speechiness\": 0.0683, \"Acousticness\": 0.0132, \"Liveness\": 0.0929, \"Tempo\": 180.007, \"Duration (ms)\": 205208.0, \"Valence\": 0.199, \"Chord\": \"G\"}, {\"Index\": 1160, \"Highest Charting Position\": 62, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"eight(Prod.&Feat. SUGA of BTS)\", \"Streams\": 4764954, \"Artist\": \"IU\", \"Artist Followers\": 4939593.0, \"Song ID\": \"0pYacDCZuRhcrwGUA5nTBe\", \"Genre\": \"['k-pop']\", \"Release Date\": \"2020-05-06\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 75.0, \"Danceability\": 0.676, \"Energy\": 0.869, \"Loudness\": -1.573, \"Speechiness\": 0.0423, \"Acousticness\": 0.115, \"Liveness\": 0.132, \"Tempo\": 120.029, \"Duration (ms)\": 167573.0, \"Valence\": 0.594, \"Chord\": \"C#/Db\"}, {\"Index\": 1161, \"Highest Charting Position\": 16, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"You should be sad\", \"Streams\": 4761908, \"Artist\": \"Halsey\", \"Artist Followers\": 15663384.0, \"Song ID\": \"7lidXGPXPYLNThITAOTlkK\", \"Genre\": \"['dance pop', 'electropop', 'etherpop', 'indie poptimism', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 76.0, \"Danceability\": 0.591, \"Energy\": 0.585, \"Loudness\": -6.35, \"Speechiness\": 0.0277, \"Acousticness\": 0.143, \"Liveness\": 0.109, \"Tempo\": 110.94, \"Duration (ms)\": 205473.0, \"Valence\": 0.324, \"Chord\": \"D\"}, {\"Index\": 1162, \"Highest Charting Position\": 54, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"CITY OF ANGELS\", \"Streams\": 4645541, \"Artist\": \"24kGoldn\", \"Artist Followers\": 1276406.0, \"Song ID\": \"6ap9lSRJ0iLriGLqoJ44cq\", \"Genre\": \"['cali rap']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 76.0, \"Danceability\": 0.686, \"Energy\": 0.541, \"Loudness\": -4.993, \"Speechiness\": 0.0493, \"Acousticness\": 0.042, \"Liveness\": 0.0675, \"Tempo\": 120.082, \"Duration (ms)\": 112493.0, \"Valence\": 0.724, \"Chord\": \"C\"}, {\"Index\": 1163, \"Highest Charting Position\": 98, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Astronomia\", \"Streams\": 4642284, \"Artist\": \"Vicetone, Tony Igy\", \"Artist Followers\": 378114.0, \"Song ID\": \"3hWfKBt3n7j1xqIy6LA5ve\", \"Genre\": \"['edm', 'electro house', 'pop dance', 'pop edm', 'progressive electro house', 'tropical house']\", \"Release Date\": \"2016-09-16\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 71.0, \"Danceability\": 0.653, \"Energy\": 0.945, \"Loudness\": -2.634, \"Speechiness\": 0.096, \"Acousticness\": 0.00561, \"Liveness\": 0.439, \"Tempo\": 126.093, \"Duration (ms)\": 198095.0, \"Valence\": 0.326, \"Chord\": \"F\"}, {\"Index\": 1164, \"Highest Charting Position\": 7, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"After Hours\", \"Streams\": 4559855, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"2p8IUWQDrpjuFltbdgLOag\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 75.0, \"Danceability\": 0.664, \"Energy\": 0.572, \"Loudness\": -6.099, \"Speechiness\": 0.0305, \"Acousticness\": 0.0811, \"Liveness\": 0.121, \"Tempo\": 108.959, \"Duration (ms)\": 361027.0, \"Valence\": 0.143, \"Chord\": \"F\"}, {\"Index\": 1165, \"Highest Charting Position\": 51, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"BUTTERFLY EFFECT\", \"Streams\": 4537762, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"2cYqizR4lgvp4Qu6IQ3qGN\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2018-08-03\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 79.0, \"Danceability\": 0.763, \"Energy\": 0.628, \"Loudness\": -5.85, \"Speechiness\": 0.05, \"Acousticness\": 0.0531, \"Liveness\": 0.114, \"Tempo\": 140.958, \"Duration (ms)\": 190557.0, \"Valence\": 0.193, \"Chord\": \"B\"}, {\"Index\": 1166, \"Highest Charting Position\": 74, \"Number of Times Charted\": 22, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Never Seen the Rain\", \"Streams\": 4473968, \"Artist\": \"Tones And I\", \"Artist Followers\": 1251372.0, \"Song ID\": \"1xUCDewhwnORlcFflAgml0\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.742, \"Energy\": 0.464, \"Loudness\": -5.624, \"Speechiness\": 0.0318, \"Acousticness\": 0.425, \"Liveness\": 0.284, \"Tempo\": 92.107, \"Duration (ms)\": 200742.0, \"Valence\": 0.281, \"Chord\": \"F#/Gb\"}, {\"Index\": 1167, \"Highest Charting Position\": 120, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Sigues Con El - Remix\", \"Streams\": 4440738, \"Artist\": \"Arcangel, Sech, Romeo Santos\", \"Artist Followers\": 6671084.0, \"Song ID\": \"4Pu0a2TuHOYtI4CCE3HEXI\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-04-10\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 69.0, \"Danceability\": 0.747, \"Energy\": 0.693, \"Loudness\": -2.97, \"Speechiness\": 0.298, \"Acousticness\": 0.102, \"Liveness\": 0.0872, \"Tempo\": 175.994, \"Duration (ms)\": 189567.0, \"Valence\": 0.736, \"Chord\": \"C#/Db\"}, {\"Index\": 1168, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"ANGELS & DEMONS\", \"Streams\": 4435538, \"Artist\": \"jxdn\", \"Artist Followers\": 799682.0, \"Song ID\": \"3mkz6eI4Sram8UhO3teU76\", \"Genre\": \"[]\", \"Release Date\": \"2021-07-02\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 72.0, \"Danceability\": 0.554, \"Energy\": 0.8, \"Loudness\": -3.936, \"Speechiness\": 0.0395, \"Acousticness\": 0.119, \"Liveness\": 0.629, \"Tempo\": 115.056, \"Duration (ms)\": 160120.0, \"Valence\": 0.463, \"Chord\": \"G#/Ab\"}, {\"Index\": 1169, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-22--2020-05-29\", \"Song Name\": \"Conf\\u00eda\", \"Streams\": 4419295, \"Artist\": \"Sech, Daddy Yankee\", \"Artist Followers\": 8766508.0, \"Song ID\": \"5kbps8unnGH4raN5WduZuq\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-21\", \"Weeks Charted\": \"2020-05-22--2020-05-29\", \"Popularity\": 62.0, \"Danceability\": 0.722, \"Energy\": 0.757, \"Loudness\": -3.592, \"Speechiness\": 0.0782, \"Acousticness\": 0.17, \"Liveness\": 0.0657, \"Tempo\": 167.987, \"Duration (ms)\": 202308.0, \"Valence\": 0.763, \"Chord\": \"C\"}, {\"Index\": 1170, \"Highest Charting Position\": 44, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Mu\\u00e9velo\", \"Streams\": 4407165, \"Artist\": \"Nicky Jam, Daddy Yankee\", \"Artist Followers\": 14831925.0, \"Song ID\": \"4VgYtXCVJ7IbWAZ5ryfvEQ\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-01-08\", \"Weeks Charted\": \"2020-05-22--2020-05-29\\n2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 72.0, \"Danceability\": 0.594, \"Energy\": 0.808, \"Loudness\": -2.409, \"Speechiness\": 0.0489, \"Acousticness\": 0.415, \"Liveness\": 0.565, \"Tempo\": 188.09, \"Duration (ms)\": 194892.0, \"Valence\": 0.919, \"Chord\": \"G\"}, {\"Index\": 1171, \"Highest Charting Position\": 105, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"All Bad (feat. Lil Uzi Vert)\", \"Streams\": 6194224, \"Artist\": \"Future\", \"Artist Followers\": 10491105.0, \"Song ID\": \"021lWIHJrURZrmvYQ1xcM8\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 60.0, \"Danceability\": 0.931, \"Energy\": 0.667, \"Loudness\": -7.043, \"Speechiness\": 0.318, \"Acousticness\": 0.0144, \"Liveness\": 0.15, \"Tempo\": 142.039, \"Duration (ms)\": 207739.0, \"Valence\": 0.667, \"Chord\": \"F#/Gb\"}, {\"Index\": 1172, \"Highest Charting Position\": 12, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Pain 1993 (with Playboi Carti)\", \"Streams\": 6085143, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"6Kj17Afjo1OKJYpf5VzCeo\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 67.0, \"Danceability\": 0.825, \"Energy\": 0.373, \"Loudness\": -5.532, \"Speechiness\": 0.108, \"Acousticness\": 0.163, \"Liveness\": 0.368, \"Tempo\": 77.271, \"Duration (ms)\": 149078.0, \"Valence\": 0.12, \"Chord\": \"F\"}, {\"Index\": 1173, \"Highest Charting Position\": 110, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Trillionaire (feat. Youngboy Never Broke Again)\", \"Streams\": 6057848, \"Artist\": \"Future\", \"Artist Followers\": 10491105.0, \"Song ID\": \"740kQ8xwSGloumdiKR5Cwz\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 61.0, \"Danceability\": 0.768, \"Energy\": 0.526, \"Loudness\": -7.182, \"Speechiness\": 0.209, \"Acousticness\": 0.237, \"Liveness\": 0.139, \"Tempo\": 139.999, \"Duration (ms)\": 167552.0, \"Valence\": 0.473, \"Chord\": \"C\"}, {\"Index\": 1174, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Go Stupid\", \"Streams\": 5464816, \"Artist\": \"Polo G, Stunna 4 Vegas, NLE Choppa, Mike WiLL Made-It\", \"Artist Followers\": 4849204.0, \"Song ID\": \"4PklAHGXT5ityno3IA8SKd\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 74.0, \"Danceability\": 0.92, \"Energy\": 0.833, \"Loudness\": -3.18, \"Speechiness\": 0.253, \"Acousticness\": 0.0277, \"Liveness\": 0.0596, \"Tempo\": 141.034, \"Duration (ms)\": 165726.0, \"Valence\": 0.645, \"Chord\": \"C#/Db\"}, {\"Index\": 1175, \"Highest Charting Position\": 149, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"A Gente Fez Amor - Ao Vivo\", \"Streams\": 5006457, \"Artist\": \"Gusttavo Lima\", \"Artist Followers\": 12981319.0, \"Song ID\": \"3tv697PZNnaQN0Mn2zGhS5\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2019-12-05\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-02-07--2020-02-14\\n2020-01-03--2020-01-10\", \"Popularity\": 66.0, \"Danceability\": 0.794, \"Energy\": 0.937, \"Loudness\": -2.44, \"Speechiness\": 0.0336, \"Acousticness\": 0.366, \"Liveness\": 0.962, \"Tempo\": 134.012, \"Duration (ms)\": 237517.0, \"Valence\": 0.826, \"Chord\": \"G#/Ab\"}, {\"Index\": 1176, \"Highest Charting Position\": 173, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Racks 2 Skinny\", \"Streams\": 4729629, \"Artist\": \"Migos\", \"Artist Followers\": 11692972.0, \"Song ID\": \"568OIKgeHyGRD3uWR44JbO\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-05-11\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 61.0, \"Danceability\": 0.814, \"Energy\": 0.584, \"Loudness\": -5.425, \"Speechiness\": 0.0819, \"Acousticness\": 0.00839, \"Liveness\": 0.0646, \"Tempo\": 141.016, \"Duration (ms)\": 178025.0, \"Valence\": 0.405, \"Chord\": \"C#/Db\"}, {\"Index\": 1177, \"Highest Charting Position\": 179, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Be Something (feat. Lil Baby)\", \"Streams\": 4687909, \"Artist\": \"Polo G\", \"Artist Followers\": 4849204.0, \"Song ID\": \"65jw6GhwQW3Db55PxlPEpS\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 69.0, \"Danceability\": 0.829, \"Energy\": 0.52, \"Loudness\": -10.34, \"Speechiness\": 0.294, \"Acousticness\": 0.0232, \"Liveness\": 0.134, \"Tempo\": 136.103, \"Duration (ms)\": 194118.0, \"Valence\": 0.248, \"Chord\": \"G#/Ab\"}, {\"Index\": 1178, \"Highest Charting Position\": 82, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"BENDICIONES\", \"Streams\": 4639997, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2CoMYp2uIKsT09nreEZnZn\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\", \"Popularity\": 67.0, \"Danceability\": 0.828, \"Energy\": 0.581, \"Loudness\": -9.909, \"Speechiness\": 0.0725, \"Acousticness\": 0.0378, \"Liveness\": 0.103, \"Tempo\": 143.995, \"Duration (ms)\": 155060.0, \"Valence\": 0.843, \"Chord\": \"B\"}, {\"Index\": 1179, \"Highest Charting Position\": 126, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"PTSD\", \"Streams\": 4500903, \"Artist\": \"G Herbo, Juice WRLD, Lil Uzi Vert, Chance the Rapper\", \"Artist Followers\": 1253138.0, \"Song ID\": \"1C8ux1YWLMHCenYJFiIV4Z\", \"Genre\": \"['chicago drill', 'chicago rap', 'drill', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-02-28--2020-03-06\", \"Popularity\": 76.0, \"Danceability\": 0.883, \"Energy\": 0.808, \"Loudness\": -3.158, \"Speechiness\": 0.182, \"Acousticness\": 0.0313, \"Liveness\": 0.207, \"Tempo\": 119.01, \"Duration (ms)\": 232065.0, \"Valence\": 0.806, \"Chord\": \"C#/Db\"}, {\"Index\": 1180, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-15--2020-05-22\", \"Song Name\": \"Excitement\", \"Streams\": 4416484, \"Artist\": \"Trippie Redd, PARTYNEXTDOOR\", \"Artist Followers\": 6434201.0, \"Song ID\": \"7FullO2NDkyvxLuxYVKINa\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-10-30\", \"Weeks Charted\": \"2020-05-15--2020-05-22\", \"Popularity\": 69.0, \"Danceability\": 0.443, \"Energy\": 0.536, \"Loudness\": -8.187, \"Speechiness\": 0.0378, \"Acousticness\": 0.0194, \"Liveness\": 0.1, \"Tempo\": 121.967, \"Duration (ms)\": 283285.0, \"Valence\": 0.0391, \"Chord\": \"E\"}, {\"Index\": 1181, \"Highest Charting Position\": 131, \"Number of Times Charted\": 21, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Can We Kiss Forever?\", \"Streams\": 4397385, \"Artist\": \"Kina, Adriana Proenza\", \"Artist Followers\": 661863.0, \"Song ID\": \"58wyJLv6yH1La9NIZPl3ne\", \"Genre\": \"['sad rap']\", \"Release Date\": \"2018-08-31\", \"Weeks Charted\": \"2020-05-15--2020-05-22\\n2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.522, \"Energy\": 0.128, \"Loudness\": -18.717, \"Speechiness\": 0.0357, \"Acousticness\": 0.894, \"Liveness\": 0.0941, \"Tempo\": 109.986, \"Duration (ms)\": 187932.0, \"Valence\": 0.124, \"Chord\": \"E\"}, {\"Index\": 1182, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"SI ELLA SALE\", \"Streams\": 7055918, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"1zaDh3qaGSeSmulNyWlUxm\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 63.0, \"Danceability\": 0.869, \"Energy\": 0.727, \"Loudness\": -7.397, \"Speechiness\": 0.123, \"Acousticness\": 0.0589, \"Liveness\": 0.107, \"Tempo\": 147.967, \"Duration (ms)\": 143240.0, \"Valence\": 0.92, \"Chord\": \"G\"}, {\"Index\": 1183, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"RONCA FREESTYLE\", \"Streams\": 5784075, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"3XZeOzJ9tqnu58YP6cqApI\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 64.0, \"Danceability\": 0.856, \"Energy\": 0.656, \"Loudness\": -6.483, \"Speechiness\": 0.131, \"Acousticness\": 0.165, \"Liveness\": 0.0998, \"Tempo\": 90.041, \"Duration (ms)\": 150060.0, \"Valence\": 0.586, \"Chord\": \"F\"}, {\"Index\": 1184, \"Highest Charting Position\": 130, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Zoo York (feat. Fivio Foreign & Pop Smoke)\", \"Streams\": 5368705, \"Artist\": \"Lil Tjay\", \"Artist Followers\": 3559267.0, \"Song ID\": \"3Ddny34bFoYBb8dIGq5lwp\", \"Genre\": \"['brooklyn drill', 'melodic rap', 'nyc rap']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 70.0, \"Danceability\": 0.565, \"Energy\": 0.569, \"Loudness\": -6.084, \"Speechiness\": 0.379, \"Acousticness\": 0.0352, \"Liveness\": 0.106, \"Tempo\": 92.466, \"Duration (ms)\": 214825.0, \"Valence\": 0.303, \"Chord\": \"F#/Gb\"}, {\"Index\": 1185, \"Highest Charting Position\": 131, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"EN CASITA\", \"Streams\": 5364262, \"Artist\": \"Bad Bunny, Gabriela\", \"Artist Followers\": 36177712.0, \"Song ID\": \"2DhNdoHxavs7Qtf5MnhZD0\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-05-10\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 62.0, \"Danceability\": 0.779, \"Energy\": 0.764, \"Loudness\": -8.217, \"Speechiness\": 0.0938, \"Acousticness\": 0.221, \"Liveness\": 0.0909, \"Tempo\": 158.093, \"Duration (ms)\": 176440.0, \"Valence\": 0.675, \"Chord\": \"C\"}, {\"Index\": 1186, \"Highest Charting Position\": 71, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Qu\\u00e9 Maldici\\u00f3n\", \"Streams\": 4971559, \"Artist\": \"Banda MS de Sergio Liz\\u00e1rraga, Snoop Dogg\", \"Artist Followers\": 12140496.0, \"Song ID\": \"2RxC2peY3FtrurYmbbmanr\", \"Genre\": \"['banda', 'corrido', 'norteno', 'regional mexican']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 69.0, \"Danceability\": 0.755, \"Energy\": 0.531, \"Loudness\": -8.051, \"Speechiness\": 0.196, \"Acousticness\": 0.213, \"Liveness\": 0.13, \"Tempo\": 177.951, \"Duration (ms)\": 203360.0, \"Valence\": 0.683, \"Chord\": \"A\"}, {\"Index\": 1187, \"Highest Charting Position\": 69, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Nicht verdient\", \"Streams\": 4912914, \"Artist\": \"Capital Bra, Loredana\", \"Artist Followers\": 4093115.0, \"Song ID\": \"7v8OynJxOxHoeS5C2UA9Y7\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-04-29\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 58.0, \"Danceability\": 0.719, \"Energy\": 0.65, \"Loudness\": -7.274, \"Speechiness\": 0.232, \"Acousticness\": 0.381, \"Liveness\": 0.167, \"Tempo\": 77.981, \"Duration (ms)\": 176953.0, \"Valence\": 0.488, \"Chord\": \"B\"}, {\"Index\": 1188, \"Highest Charting Position\": 52, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"A Tu Merced\", \"Streams\": 4909499, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4r9jkMEnArtWGH2rL2FZl0\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 82.0, \"Danceability\": 0.86, \"Energy\": 0.791, \"Loudness\": -4.784, \"Speechiness\": 0.0568, \"Acousticness\": 0.169, \"Liveness\": 0.106, \"Tempo\": 92.023, \"Duration (ms)\": 175918.0, \"Valence\": 0.887, \"Chord\": \"C\"}, {\"Index\": 1189, \"Highest Charting Position\": 49, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Demons (feat. Fivio Foreign & Sosa Geek)\", \"Streams\": 4766829, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"05aZ9sAU1YXndHv0FMi9iW\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\", \"Popularity\": 63.0, \"Danceability\": 0.543, \"Energy\": 0.766, \"Loudness\": -3.387, \"Speechiness\": 0.343, \"Acousticness\": 0.423, \"Liveness\": 0.155, \"Tempo\": 106.869, \"Duration (ms)\": 204805.0, \"Valence\": 0.729, \"Chord\": \"C\"}, {\"Index\": 1190, \"Highest Charting Position\": 42, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Moral of the Story\", \"Streams\": 4609358, \"Artist\": \"Ashe\", \"Artist Followers\": 644479.0, \"Song ID\": \"2nC3QhMI9reBIOWutbU3Tj\", \"Genre\": \"['alt z', 'electropop', 'indie pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-02-14\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 75.0, \"Danceability\": 0.572, \"Energy\": 0.406, \"Loudness\": -8.624, \"Speechiness\": 0.0427, \"Acousticness\": 0.587, \"Liveness\": 0.102, \"Tempo\": 119.812, \"Duration (ms)\": 201084.0, \"Valence\": 0.265, \"Chord\": \"A#/Bb\"}, {\"Index\": 1191, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-08--2020-05-15\", \"Song Name\": \"Can I\", \"Streams\": 4603243, \"Artist\": \"Kehlani\", \"Artist Followers\": 4894562.0, \"Song ID\": \"0uDdI4fAXCuNhQbmxENdsO\", \"Genre\": \"['dance pop', 'pop', 'pop rap', 'post-teen pop', 'r&b']\", \"Release Date\": \"2020-05-08\", \"Weeks Charted\": \"2020-05-08--2020-05-15\", \"Popularity\": 68.0, \"Danceability\": 0.574, \"Energy\": 0.791, \"Loudness\": -3.752, \"Speechiness\": 0.11, \"Acousticness\": 0.419, \"Liveness\": 0.0982, \"Tempo\": 119.537, \"Duration (ms)\": 167810.0, \"Valence\": 0.612, \"Chord\": \"C#/Db\"}, {\"Index\": 1192, \"Highest Charting Position\": 46, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"STARGAZING\", \"Streams\": 4499820, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"7wBJfHzpfI3032CSD7CE2m\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2018-08-03\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 76.0, \"Danceability\": 0.487, \"Energy\": 0.789, \"Loudness\": -3.69, \"Speechiness\": 0.044, \"Acousticness\": 0.00947, \"Liveness\": 0.189, \"Tempo\": 150.007, \"Duration (ms)\": 270715.0, \"Valence\": 0.0564, \"Chord\": \"G#/Ab\"}, {\"Index\": 1193, \"Highest Charting Position\": 124, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Eastside (with Halsey & Khalid)\", \"Streams\": 4397708, \"Artist\": \"benny blanco\", \"Artist Followers\": 804613.0, \"Song ID\": \"0d2iYfpKoM0QCKvcLCkBao\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2018-07-12\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.56, \"Energy\": 0.68, \"Loudness\": -7.648, \"Speechiness\": 0.321, \"Acousticness\": 0.555, \"Liveness\": 0.116, \"Tempo\": 89.391, \"Duration (ms)\": 173800.0, \"Valence\": 0.319, \"Chord\": \"F#/Gb\"}, {\"Index\": 1194, \"Highest Charting Position\": 23, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Suicidal\", \"Streams\": 4320116, \"Artist\": \"YNW Melly\", \"Artist Followers\": 6332535.0, \"Song ID\": \"4S2uhQE8L9V6p7rj7SiauJ\", \"Genre\": \"['melodic rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.655, \"Energy\": 0.441, \"Loudness\": -5.245, \"Speechiness\": 0.0629, \"Acousticness\": 0.474, \"Liveness\": 0.099, \"Tempo\": 139.957, \"Duration (ms)\": 225857.0, \"Valence\": 0.273, \"Chord\": \"A\"}, {\"Index\": 1195, \"Highest Charting Position\": 39, \"Number of Times Charted\": 20, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"How Do You Sleep?\", \"Streams\": 4313625, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"6b2RcmUt1g9N9mQ3CbjX2Y\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2019-07-19\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.477, \"Energy\": 0.682, \"Loudness\": -4.931, \"Speechiness\": 0.0925, \"Acousticness\": 0.153, \"Liveness\": 0.0763, \"Tempo\": 110.567, \"Duration (ms)\": 202205.0, \"Valence\": 0.345, \"Chord\": \"C#/Db\"}, {\"Index\": 1196, \"Highest Charting Position\": 4, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"No Time To Die\", \"Streams\": 4293009, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"73SpzrcaHk0RQPFP73vqVR\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2020-02-13\", \"Weeks Charted\": \"2020-05-08--2020-05-15\\n2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 75.0, \"Danceability\": 0.38, \"Energy\": 0.219, \"Loudness\": -13.273, \"Speechiness\": 0.0358, \"Acousticness\": 0.917, \"Liveness\": 0.0827, \"Tempo\": 73.537, \"Duration (ms)\": 242265.0, \"Valence\": 0.0517, \"Chord\": \"E\"}, {\"Index\": 1197, \"Highest Charting Position\": 46, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"D4L\", \"Streams\": 10537097, \"Artist\": \"Future, Drake, Young Thug\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5fHrHoJKfCgBd35zwIBmUK\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 63.0, \"Danceability\": 0.718, \"Energy\": 0.706, \"Loudness\": -5.709, \"Speechiness\": 0.06, \"Acousticness\": 0.0128, \"Liveness\": 0.352, \"Tempo\": 170.004, \"Duration (ms)\": 189176.0, \"Valence\": 0.815, \"Chord\": \"C#/Db\"}, {\"Index\": 1198, \"Highest Charting Position\": 51, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Time Flies\", \"Streams\": 9904749, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5H4mXWKcicuLKDn4Jy0sK7\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 71.0, \"Danceability\": 0.864, \"Energy\": 0.477, \"Loudness\": -5.786, \"Speechiness\": 0.224, \"Acousticness\": 0.201, \"Liveness\": 0.182, \"Tempo\": 86.46, \"Duration (ms)\": 192932.0, \"Valence\": 0.5, \"Chord\": \"A#/Bb\"}, {\"Index\": 1199, \"Highest Charting Position\": 53, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Desires (with Future)\", \"Streams\": 9628215, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"7eYAHC0RbBF9eaqWzT34Aq\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.812, \"Energy\": 0.506, \"Loudness\": -7.706, \"Speechiness\": 0.116, \"Acousticness\": 0.281, \"Liveness\": 0.325, \"Tempo\": 145.074, \"Duration (ms)\": 237946.0, \"Valence\": 0.554, \"Chord\": \"F\"}, {\"Index\": 1200, \"Highest Charting Position\": 55, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Not You Too (feat. Chris Brown)\", \"Streams\": 9284383, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"3Q4gttWQ6hxqWOa3tHoTNi\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.458, \"Energy\": 0.452, \"Loudness\": -9.299, \"Speechiness\": 0.047, \"Acousticness\": 0.342, \"Liveness\": 0.0703, \"Tempo\": 86.318, \"Duration (ms)\": 269680.0, \"Valence\": 0.316, \"Chord\": \"A\"}, {\"Index\": 1201, \"Highest Charting Position\": 67, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Landed\", \"Streams\": 8355036, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"3KixNgUEaDtrKJVzdqjU5q\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 60.0, \"Danceability\": 0.881, \"Energy\": 0.636, \"Loudness\": -4.629, \"Speechiness\": 0.287, \"Acousticness\": 0.00606, \"Liveness\": 0.111, \"Tempo\": 163.949, \"Duration (ms)\": 152195.0, \"Valence\": 0.715, \"Chord\": \"G\"}, {\"Index\": 1202, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"When To Say When\", \"Streams\": 8304928, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"5TCBWmEBrin7etRa4Lswr1\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 60.0, \"Danceability\": 0.41, \"Energy\": 0.82, \"Loudness\": -6.808, \"Speechiness\": 0.533, \"Acousticness\": 0.252, \"Liveness\": 0.538, \"Tempo\": 170.718, \"Duration (ms)\": 223124.0, \"Valence\": 0.526, \"Chord\": \"C#/Db\"}, {\"Index\": 1203, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Deep Pockets\", \"Streams\": 8285754, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"3IvMYBE7A3c7to1aEcfFJk\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 58.0, \"Danceability\": 0.473, \"Energy\": 0.824, \"Loudness\": -3.68, \"Speechiness\": 0.163, \"Acousticness\": 0.482, \"Liveness\": 0.605, \"Tempo\": 77.888, \"Duration (ms)\": 222929.0, \"Valence\": 0.374, \"Chord\": \"G\"}, {\"Index\": 1204, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"War\", \"Streams\": 7821869, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"1I55Ea0zVoSKs6MqW7DQ3i\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.749, \"Energy\": 0.792, \"Loudness\": -4.151, \"Speechiness\": 0.0826, \"Acousticness\": 0.292, \"Liveness\": 0.109, \"Tempo\": 144.064, \"Duration (ms)\": 180000.0, \"Valence\": 0.239, \"Chord\": \"A#/Bb\"}, {\"Index\": 1205, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"From Florida With Love\", \"Streams\": 7216610, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"0YkUwXxnTkeJBvt5upeEtP\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 64.0, \"Danceability\": 0.787, \"Energy\": 0.477, \"Loudness\": -7.837, \"Speechiness\": 0.199, \"Acousticness\": 0.768, \"Liveness\": 0.104, \"Tempo\": 80.506, \"Duration (ms)\": 234783.0, \"Valence\": 0.476, \"Chord\": \"F#/Gb\"}, {\"Index\": 1206, \"Highest Charting Position\": 89, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-05-01--2020-05-08\", \"Song Name\": \"Losses\", \"Streams\": 6894756, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"6fLVTVaHWaEfVKfEgbkf4D\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-05-01--2020-05-08\", \"Popularity\": 57.0, \"Danceability\": 0.551, \"Energy\": 0.57, \"Loudness\": -7.385, \"Speechiness\": 0.351, \"Acousticness\": 0.28, \"Liveness\": 0.424, \"Tempo\": 85.687, \"Duration (ms)\": 271184.0, \"Valence\": 0.505, \"Chord\": \"C#/Db\"}, {\"Index\": 1207, \"Highest Charting Position\": 25, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Turks (feat. Travis Scott)\", \"Streams\": 5594561, \"Artist\": \"NAV, Gunna\", \"Artist Followers\": 2613211.0, \"Song ID\": \"0lSZh5W0wDeurkGzLYY6hf\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'hip hop', 'melodic rap', 'pop rap', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 70.0, \"Danceability\": 0.893, \"Energy\": 0.618, \"Loudness\": -4.425, \"Speechiness\": 0.112, \"Acousticness\": 0.0827, \"Liveness\": 0.542, \"Tempo\": 119.099, \"Duration (ms)\": 161377.0, \"Valence\": 0.389, \"Chord\": \"G\"}, {\"Index\": 1208, \"Highest Charting Position\": 40, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Boyfriend\", \"Streams\": 5236730, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4QnC1bIaMSfDQvF4XDhV5M\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 62.0, \"Danceability\": 0.811, \"Energy\": 0.512, \"Loudness\": -6.381, \"Speechiness\": 0.17, \"Acousticness\": 0.218, \"Liveness\": 0.0768, \"Tempo\": 92.046, \"Duration (ms)\": 161188.0, \"Valence\": 0.346, \"Chord\": \"D\"}, {\"Index\": 1209, \"Highest Charting Position\": 29, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"What If I Told You That I Love You\", \"Streams\": 5234645, \"Artist\": \"Ali Gatie\", \"Artist Followers\": 1758300.0, \"Song ID\": \"6USdi8uX5GNAPYziFhisHb\", \"Genre\": \"['canadian hip hop', 'pop']\", \"Release Date\": \"2021-03-26\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 69.0, \"Danceability\": 0.596, \"Energy\": 0.366, \"Loudness\": -11.144, \"Speechiness\": 0.115, \"Acousticness\": 0.63, \"Liveness\": 0.0554, \"Tempo\": 84.394, \"Duration (ms)\": 193668.0, \"Valence\": 0.229, \"Chord\": \"G\"}, {\"Index\": 1210, \"Highest Charting Position\": 85, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Emotions\", \"Streams\": 4901960, \"Artist\": \"Ufo361\", \"Artist Followers\": 1700759.0, \"Song ID\": \"3yZCjDTxzZxx1kll1sRjGc\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-06-12\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\", \"Popularity\": 65.0, \"Danceability\": 0.788, \"Energy\": 0.491, \"Loudness\": -9.884, \"Speechiness\": 0.109, \"Acousticness\": 0.386, \"Liveness\": 0.107, \"Tempo\": 98.543, \"Duration (ms)\": 146028.0, \"Valence\": 0.271, \"Chord\": \"G#/Ab\"}, {\"Index\": 1211, \"Highest Charting Position\": 32, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"FIND MY WAY\", \"Streams\": 4753495, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"1gVCEnryJhkdQcuC0Kbvor\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 66.0, \"Danceability\": 0.836, \"Energy\": 0.624, \"Loudness\": -6.75, \"Speechiness\": 0.184, \"Acousticness\": 0.187, \"Liveness\": 0.138, \"Tempo\": 103.0, \"Duration (ms)\": 139890.0, \"Valence\": 0.7, \"Chord\": \"E\"}, {\"Index\": 1212, \"Highest Charting Position\": 37, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Keii\", \"Streams\": 4687605, \"Artist\": \"Anuel AA\", \"Artist Followers\": 18306226.0, \"Song ID\": \"5eEQCfq7MXQr6aHLNRUZLs\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton flow', 'trap boricua', 'trap latino']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 67.0, \"Danceability\": 0.708, \"Energy\": 0.797, \"Loudness\": -3.095, \"Speechiness\": 0.0391, \"Acousticness\": 0.4, \"Liveness\": 0.096, \"Tempo\": 88.015, \"Duration (ms)\": 210000.0, \"Valence\": 0.51, \"Chord\": \"C\"}, {\"Index\": 1213, \"Highest Charting Position\": 130, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"God's Plan\", \"Streams\": 4565400, \"Artist\": \"Drake\", \"Artist Followers\": 56327031.0, \"Song ID\": \"6DCZcSspjsKoFjzjrWoCdn\", \"Genre\": \"['canadian hip hop', 'canadian pop', 'hip hop', 'pop rap', 'rap', 'toronto rap']\", \"Release Date\": \"2018-06-29\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 82.0, \"Danceability\": 0.754, \"Energy\": 0.449, \"Loudness\": -9.211, \"Speechiness\": 0.109, \"Acousticness\": 0.0332, \"Liveness\": 0.552, \"Tempo\": 77.169, \"Duration (ms)\": 198973.0, \"Valence\": 0.357, \"Chord\": \"G\"}, {\"Index\": 1214, \"Highest Charting Position\": 103, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"Por Primera Vez\", \"Streams\": 4478685, \"Artist\": \"Camilo, Evaluna Montaner\", \"Artist Followers\": 10580764.0, \"Song ID\": \"0gWbAFRcUyZKdfUxEOuOiD\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-09\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\", \"Popularity\": 70.0, \"Danceability\": 0.716, \"Energy\": 0.588, \"Loudness\": -3.952, \"Speechiness\": 0.116, \"Acousticness\": 0.152, \"Liveness\": 0.0847, \"Tempo\": 165.896, \"Duration (ms)\": 183547.0, \"Valence\": 0.707, \"Chord\": \"C#/Db\"}, {\"Index\": 1215, \"Highest Charting Position\": 32, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"@ MEH\", \"Streams\": 4420187, \"Artist\": \"Playboi Carti\", \"Artist Followers\": 1251372.0, \"Song ID\": \"5rffvRUaCvkPnkwMVcQYgZ\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\", \"Popularity\": 1.0, \"Danceability\": 0.877, \"Energy\": 0.492, \"Loudness\": -8.11, \"Speechiness\": 0.153, \"Acousticness\": 0.0136, \"Liveness\": 0.0678, \"Tempo\": 151.042, \"Duration (ms)\": 166799.0, \"Valence\": 0.4, \"Chord\": \"B\"}, {\"Index\": 1216, \"Highest Charting Position\": 109, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Broke In A Minute\", \"Streams\": 4402281, \"Artist\": \"Tory Lanez\", \"Artist Followers\": 3828418.0, \"Song ID\": \"4xqIYGwwZTEem9U8A42SPF\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-04-10\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-02-07--2020-02-14\", \"Popularity\": 75.0, \"Danceability\": 0.929, \"Energy\": 0.7, \"Loudness\": -5.595, \"Speechiness\": 0.0906, \"Acousticness\": 0.144, \"Liveness\": 0.349, \"Tempo\": 120.009, \"Duration (ms)\": 132024.0, \"Valence\": 0.802, \"Chord\": \"C\"}, {\"Index\": 1217, \"Highest Charting Position\": 139, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Fantasias - Remix\", \"Streams\": 4401019, \"Artist\": \"Rauw Alejandro, Anuel AA, Natti Natasha, Farruko, Lunay\", \"Artist Followers\": 6096559.0, \"Song ID\": \"0A37XY67wSdGqkGjtfW6aV\", \"Genre\": \"['puerto rican pop', 'trap latino']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 70.0, \"Danceability\": 0.816, \"Energy\": 0.72, \"Loudness\": -4.454, \"Speechiness\": 0.0684, \"Acousticness\": 0.206, \"Liveness\": 0.277, \"Tempo\": 94.004, \"Duration (ms)\": 267242.0, \"Valence\": 0.78, \"Chord\": \"C#/Db\"}, {\"Index\": 1218, \"Highest Charting Position\": 38, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"SUGAR\", \"Streams\": 4362442, \"Artist\": \"BROCKHAMPTON\", \"Artist Followers\": 1836564.0, \"Song ID\": \"6U0FIYXCQ3TGrk4tFpLrEA\", \"Genre\": \"['boy band', 'hip hop', 'rap']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-05-01--2020-05-08\\n2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 75.0, \"Danceability\": 0.453, \"Energy\": 0.538, \"Loudness\": -8.212, \"Speechiness\": 0.0638, \"Acousticness\": 0.449, \"Liveness\": 0.19, \"Tempo\": 122.973, \"Duration (ms)\": 204533.0, \"Valence\": 0.516, \"Chord\": \"C#/Db\"}, {\"Index\": 1219, \"Highest Charting Position\": 112, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"90-60-111\", \"Streams\": 5750861, \"Artist\": \"Shirin David\", \"Artist Followers\": 559215.0, \"Song ID\": \"3ZdDYeaZzeYnrP4crgXzPk\", \"Genre\": \"['frauenrap', 'german hip hop', 'german pop']\", \"Release Date\": \"2020-04-23\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 64.0, \"Danceability\": 0.8, \"Energy\": 0.628, \"Loudness\": -6.615, \"Speechiness\": 0.285, \"Acousticness\": 0.103, \"Liveness\": 0.391, \"Tempo\": 143.979, \"Duration (ms)\": 141387.0, \"Valence\": 0.745, \"Chord\": \"D\"}, {\"Index\": 1220, \"Highest Charting Position\": 115, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"YOSEMITE\", \"Streams\": 5686981, \"Artist\": \"Travis Scott\", \"Artist Followers\": 17732077.0, \"Song ID\": \"7lAK3oHbfEnvUQWosrMMpR\", \"Genre\": \"['rap', 'slap house']\", \"Release Date\": \"2018-08-03\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 75.0, \"Danceability\": 0.785, \"Energy\": 0.554, \"Loudness\": -6.571, \"Speechiness\": 0.0409, \"Acousticness\": 0.283, \"Liveness\": 0.116, \"Tempo\": 128.047, \"Duration (ms)\": 150043.0, \"Valence\": 0.144, \"Chord\": \"C\"}, {\"Index\": 1221, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Houdini (feat. Swarmz & Tion Wayne)\", \"Streams\": 4914429, \"Artist\": \"KSI\", \"Artist Followers\": 2010879.0, \"Song ID\": \"3lay6f81Lhy0qp2Uvp4cNJ\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 58.0, \"Danceability\": 0.572, \"Energy\": 0.519, \"Loudness\": -8.054, \"Speechiness\": 0.243, \"Acousticness\": 0.000415, \"Liveness\": 0.129, \"Tempo\": 100.453, \"Duration (ms)\": 169355.0, \"Valence\": 0.704, \"Chord\": \"A#/Bb\"}, {\"Index\": 1222, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"Sasuke\", \"Streams\": 4701551, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"0ROE31C8Wu4neZoR9stM9e\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 56.0, \"Danceability\": 0.859, \"Energy\": 0.477, \"Loudness\": -6.116, \"Speechiness\": 0.428, \"Acousticness\": 0.00414, \"Liveness\": 0.0819, \"Tempo\": 145.979, \"Duration (ms)\": 251336.0, \"Valence\": 0.153, \"Chord\": \"C#/Db\"}, {\"Index\": 1223, \"Highest Charting Position\": 47, \"Number of Times Charted\": 15, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Me Gusta\", \"Streams\": 4440661, \"Artist\": \"Shakira, Anuel AA\", \"Artist Followers\": 22136717.0, \"Song ID\": \"5Xhqh4lwJPtMUTsdBztN1a\", \"Genre\": \"['colombian pop', 'dance pop', 'latin', 'latin pop', 'pop']\", \"Release Date\": \"2020-01-13\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 72.0, \"Danceability\": 0.775, \"Energy\": 0.696, \"Loudness\": -5.184, \"Speechiness\": 0.0681, \"Acousticness\": 0.0559, \"Liveness\": 0.157, \"Tempo\": 92.007, \"Duration (ms)\": 190570.0, \"Valence\": 0.775, \"Chord\": \"C#/Db\"}, {\"Index\": 1224, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-24--2020-05-01\", \"Song Name\": \"If You\\u2019re Too Shy (Let Me Know) - Edit\", \"Streams\": 4429092, \"Artist\": \"The 1975\", \"Artist Followers\": 5044278.0, \"Song ID\": \"3iEqGBZ2wcpVzhiAcwXVC6\", \"Genre\": \"['modern alternative rock', 'modern rock', 'pop', 'rock']\", \"Release Date\": \"2020-04-23\", \"Weeks Charted\": \"2020-04-24--2020-05-01\", \"Popularity\": 59.0, \"Danceability\": 0.651, \"Energy\": 0.806, \"Loudness\": -4.842, \"Speechiness\": 0.0311, \"Acousticness\": 0.00399, \"Liveness\": 0.0927, \"Tempo\": 125.641, \"Duration (ms)\": 239877.0, \"Valence\": 0.386, \"Chord\": \"D\"}, {\"Index\": 1225, \"Highest Charting Position\": 80, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Alone, Pt. II\", \"Streams\": 4395061, \"Artist\": \"Alan Walker, Ava Max\", \"Artist Followers\": 29679430.0, \"Song ID\": \"0bMbDctzMmTyK2j74j3nF3\", \"Genre\": \"['electro house']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.67, \"Energy\": 0.668, \"Loudness\": -4.306, \"Speechiness\": 0.0422, \"Acousticness\": 0.536, \"Liveness\": 0.133, \"Tempo\": 88.033, \"Duration (ms)\": 179053.0, \"Valence\": 0.608, \"Chord\": \"D#/Eb\"}, {\"Index\": 1226, \"Highest Charting Position\": 97, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Tutu\", \"Streams\": 4393037, \"Artist\": \"Camilo, Pedro Cap\\u00f3\", \"Artist Followers\": 10580764.0, \"Song ID\": \"1nocRtwyNPVtGcIJqfgdzZ\", \"Genre\": \"['colombian pop', 'reggaeton colombiano']\", \"Release Date\": \"2019-08-09\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.731, \"Energy\": 0.832, \"Loudness\": -2.592, \"Speechiness\": 0.0503, \"Acousticness\": 0.273, \"Liveness\": 0.0665, \"Tempo\": 146.013, \"Duration (ms)\": 178613.0, \"Valence\": 0.94, \"Chord\": \"A\"}, {\"Index\": 1227, \"Highest Charting Position\": 85, \"Number of Times Charted\": 17, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Hate Me (with Juice WRLD)\", \"Streams\": 4367368, \"Artist\": \"Ellie Goulding\", \"Artist Followers\": 9747805.0, \"Song ID\": \"6kls8cSlUyHW2BUOkDJIZE\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'indietronica', 'metropopolis', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2019-06-26\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.657, \"Energy\": 0.768, \"Loudness\": -4.628, \"Speechiness\": 0.0507, \"Acousticness\": 0.108, \"Liveness\": 0.144, \"Tempo\": 75.025, \"Duration (ms)\": 186223.0, \"Valence\": 0.759, \"Chord\": \"G#/Ab\"}, {\"Index\": 1228, \"Highest Charting Position\": 109, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Still Be Friends (feat. Tory Lanez & Tyga)\", \"Streams\": 4299422, \"Artist\": \"G-Eazy\", \"Artist Followers\": 4894656.0, \"Song ID\": \"0JjM9bKm4wrwohMslcm892\", \"Genre\": \"['hip hop', 'indie pop rap', 'oakland hip hop', 'pop rap', 'rap']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 76.0, \"Danceability\": 0.803, \"Energy\": 0.759, \"Loudness\": -4.692, \"Speechiness\": 0.0494, \"Acousticness\": 0.00509, \"Liveness\": 0.0921, \"Tempo\": 104.0, \"Duration (ms)\": 213308.0, \"Valence\": 0.284, \"Chord\": \"G\"}, {\"Index\": 1229, \"Highest Charting Position\": 74, \"Number of Times Charted\": 18, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Blanco\", \"Streams\": 4214147, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"2rc7BkzO8qepMFAxHtOrXc\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-04-24--2020-05-01\\n2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.87, \"Energy\": 0.706, \"Loudness\": -5.395, \"Speechiness\": 0.126, \"Acousticness\": 0.0253, \"Liveness\": 0.0872, \"Tempo\": 100.013, \"Duration (ms)\": 145800.0, \"Valence\": 0.593, \"Chord\": \"A\"}, {\"Index\": 1230, \"Highest Charting Position\": 78, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"PICK UP (feat. Quavo)\", \"Streams\": 7065060, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"5gNOINI5dXZVom2b36LMOd\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 65.0, \"Danceability\": 0.915, \"Energy\": 0.612, \"Loudness\": -4.535, \"Speechiness\": 0.407, \"Acousticness\": 0.0944, \"Liveness\": 0.115, \"Tempo\": 129.93, \"Duration (ms)\": 118547.0, \"Valence\": 0.758, \"Chord\": \"C#/Db\"}, {\"Index\": 1231, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"JUMP (feat. YoungBoy Never Broke Again)\", \"Streams\": 6033348, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"0oT9ElXYSxvnOOagP9efDq\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 62.0, \"Danceability\": 0.896, \"Energy\": 0.72, \"Loudness\": -6.262, \"Speechiness\": 0.355, \"Acousticness\": 0.169, \"Liveness\": 0.252, \"Tempo\": 140.1, \"Duration (ms)\": 212093.0, \"Valence\": 0.966, \"Chord\": \"C\"}, {\"Index\": 1232, \"Highest Charting Position\": 156, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"LIGHTSKIN SH*T (feat. Future & jetsonmade)\", \"Streams\": 4861875, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"16oi4OiKmkO51l60F5R9kR\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 56.0, \"Danceability\": 0.932, \"Energy\": 0.578, \"Loudness\": -4.478, \"Speechiness\": 0.366, \"Acousticness\": 0.115, \"Liveness\": 0.115, \"Tempo\": 129.991, \"Duration (ms)\": 111173.0, \"Valence\": 0.623, \"Chord\": \"A\"}, {\"Index\": 1233, \"Highest Charting Position\": 16, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"That Way - Bonus Track\", \"Streams\": 4825741, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2ajzBr7vwHTEBeqDzcsNRC\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.712, \"Energy\": 0.598, \"Loudness\": -5.368, \"Speechiness\": 0.0388, \"Acousticness\": 0.0546, \"Liveness\": 0.154, \"Tempo\": 130.007, \"Duration (ms)\": 212354.0, \"Valence\": 0.504, \"Chord\": \"G\"}, {\"Index\": 1234, \"Highest Charting Position\": 162, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"No Me Ame\", \"Streams\": 4822090, \"Artist\": \"Rvssian, Anuel AA, Juice WRLD\", \"Artist Followers\": 1397067.0, \"Song ID\": \"2AuWgceaQyfMoI3EGavwGb\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 64.0, \"Danceability\": 0.68, \"Energy\": 0.766, \"Loudness\": -4.799, \"Speechiness\": 0.0923, \"Acousticness\": 0.0411, \"Liveness\": 0.116, \"Tempo\": 160.095, \"Duration (ms)\": 180000.0, \"Valence\": 0.28, \"Chord\": \"B\"}, {\"Index\": 1235, \"Highest Charting Position\": 80, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"I'll Wait\", \"Streams\": 4674532, \"Artist\": \"Kygo, Sasha Alex Sloan\", \"Artist Followers\": 7593792.0, \"Song ID\": \"6Q3K9gVUZRMZqZKrXovbM2\", \"Genre\": \"['edm', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2020-04-03\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 70.0, \"Danceability\": 0.611, \"Energy\": 0.651, \"Loudness\": -6.973, \"Speechiness\": 0.0589, \"Acousticness\": 0.144, \"Liveness\": 0.105, \"Tempo\": 122.983, \"Duration (ms)\": 215361.0, \"Valence\": 0.351, \"Chord\": \"C#/Db\"}, {\"Index\": 1236, \"Highest Charting Position\": 63, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Oprah\\u2019s Bank Account (Lil Yachty & DaBaby feat. Drake)\", \"Streams\": 4618744, \"Artist\": \"Lil Yachty\", \"Artist Followers\": 7358720.0, \"Song ID\": \"7wsmIIm0xWmtP7TmACXkJn\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap', 'underground hip hop', 'viral rap']\", \"Release Date\": \"2020-03-09\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 69.0, \"Danceability\": 0.836, \"Energy\": 0.617, \"Loudness\": -4.363, \"Speechiness\": 0.0534, \"Acousticness\": 0.17, \"Liveness\": 0.319, \"Tempo\": 138.066, \"Duration (ms)\": 206702.0, \"Valence\": 0.866, \"Chord\": \"C\"}, {\"Index\": 1237, \"Highest Charting Position\": 180, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-17--2020-04-24\", \"Song Name\": \"BLAME IT ON BABY\", \"Streams\": 4616034, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"0jWm0VyD8p3MrSInczpows\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2020-04-17\", \"Weeks Charted\": \"2020-04-17--2020-04-24\", \"Popularity\": 57.0, \"Danceability\": 0.875, \"Energy\": 0.687, \"Loudness\": -5.734, \"Speechiness\": 0.387, \"Acousticness\": 0.236, \"Liveness\": 0.141, \"Tempo\": 109.791, \"Duration (ms)\": 125907.0, \"Valence\": 0.864, \"Chord\": \"A\"}, {\"Index\": 1238, \"Highest Charting Position\": 128, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Follow\", \"Streams\": 4593449, \"Artist\": \"KAROL G, Anuel AA\", \"Artist Followers\": 17792779.0, \"Song ID\": \"2w1rq80FIrbxeJy9WYURxw\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-04-01\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 63.0, \"Danceability\": 0.735, \"Energy\": 0.787, \"Loudness\": -4.375, \"Speechiness\": 0.16, \"Acousticness\": 0.667, \"Liveness\": 0.0721, \"Tempo\": 168.997, \"Duration (ms)\": 203093.0, \"Valence\": 0.455, \"Chord\": \"G\"}, {\"Index\": 1239, \"Highest Charting Position\": 156, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"3 Nights\", \"Streams\": 4411998, \"Artist\": \"Dominic Fike\", \"Artist Followers\": 554042.0, \"Song ID\": \"1tNJrcVe6gwLEiZCtprs1u\", \"Genre\": \"['alternative pop rock', 'pop']\", \"Release Date\": \"2018-10-16\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.815, \"Energy\": 0.518, \"Loudness\": -6.594, \"Speechiness\": 0.0897, \"Acousticness\": 0.223, \"Liveness\": 0.104, \"Tempo\": 151.891, \"Duration (ms)\": 177667.0, \"Valence\": 0.877, \"Chord\": \"G\"}, {\"Index\": 1240, \"Highest Charting Position\": 163, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"The Take (feat. Chris Brown)\", \"Streams\": 4394195, \"Artist\": \"Tory Lanez\", \"Artist Followers\": 3828418.0, \"Song ID\": \"0Odu228D0yGcFySGuxU4rY\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-04-17--2020-04-24\\n2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 73.0, \"Danceability\": 0.464, \"Energy\": 0.547, \"Loudness\": -8.137, \"Speechiness\": 0.339, \"Acousticness\": 0.0511, \"Liveness\": 0.155, \"Tempo\": 67.003, \"Duration (ms)\": 221492.0, \"Valence\": 0.423, \"Chord\": \"G\"}, {\"Index\": 1241, \"Highest Charting Position\": 101, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Stupid Again\", \"Streams\": 5938996, \"Artist\": \"Tory Lanez\", \"Artist Followers\": 3828418.0, \"Song ID\": \"1fPnUpoXCpD2NDI4vPVeLw\", \"Genre\": \"['canadian hip hop', 'canadian trap', 'melodic rap', 'pop rap', 'r&b', 'rap', 'toronto rap', 'trap']\", \"Release Date\": \"2020-04-10\", \"Weeks Charted\": \"2020-04-10--2020-04-17\", \"Popularity\": 66.0, \"Danceability\": 0.775, \"Energy\": 0.823, \"Loudness\": -4.941, \"Speechiness\": 0.0635, \"Acousticness\": 0.0881, \"Liveness\": 0.309, \"Tempo\": 120.059, \"Duration (ms)\": 174848.0, \"Valence\": 0.65, \"Chord\": \"F\"}, {\"Index\": 1242, \"Highest Charting Position\": 127, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"Shotz Fired\", \"Streams\": 5291167, \"Artist\": \"Bonez MC\", \"Artist Followers\": 1683006.0, \"Song ID\": \"0dy5NFDnx5fuZvE8ZXEX35\", \"Genre\": \"['german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-04-10--2020-04-17\", \"Popularity\": 59.0, \"Danceability\": 0.839, \"Energy\": 0.594, \"Loudness\": -9.087, \"Speechiness\": 0.139, \"Acousticness\": 0.249, \"Liveness\": 0.165, \"Tempo\": 76.007, \"Duration (ms)\": 179844.0, \"Valence\": 0.58, \"Chord\": \"C\"}, {\"Index\": 1243, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-04-10--2020-04-17\", \"Song Name\": \"BaeBae\", \"Streams\": 5290730, \"Artist\": \"Samra\", \"Artist Followers\": 1045091.0, \"Song ID\": \"1yYBOIXO2H9LDqEPui42GM\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-04-09\", \"Weeks Charted\": \"2020-04-10--2020-04-17\", \"Popularity\": 57.0, \"Danceability\": 0.628, \"Energy\": 0.712, \"Loudness\": -4.864, \"Speechiness\": 0.156, \"Acousticness\": 0.282, \"Liveness\": 0.156, \"Tempo\": 86.627, \"Duration (ms)\": 167827.0, \"Valence\": 0.45, \"Chord\": \"E\"}, {\"Index\": 1244, \"Highest Charting Position\": 30, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"To Die For\", \"Streams\": 4527835, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"2ZTYlnhhV1UAReg7wIGolx\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 70.0, \"Danceability\": 0.483, \"Energy\": 0.361, \"Loudness\": -7.889, \"Speechiness\": 0.0738, \"Acousticness\": 0.832, \"Liveness\": 0.098, \"Tempo\": 171.649, \"Duration (ms)\": 193795.0, \"Valence\": 0.307, \"Chord\": \"C\"}, {\"Index\": 1245, \"Highest Charting Position\": 86, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"WANNABE\", \"Streams\": 4383521, \"Artist\": \"ITZY\", \"Artist Followers\": 2384076.0, \"Song ID\": \"6tCssnvTUREcperDOUTqvA\", \"Genre\": \"['k-pop girl group']\", \"Release Date\": \"2020-03-09\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\", \"Popularity\": 75.0, \"Danceability\": 0.809, \"Energy\": 0.911, \"Loudness\": -4.41, \"Speechiness\": 0.0617, \"Acousticness\": 0.00795, \"Liveness\": 0.181, \"Tempo\": 122.035, \"Duration (ms)\": 191242.0, \"Valence\": 0.64, \"Chord\": \"F#/Gb\"}, {\"Index\": 1246, \"Highest Charting Position\": 152, \"Number of Times Charted\": 13, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Takeaway\", \"Streams\": 4359727, \"Artist\": \"The Chainsmokers, ILLENIUM, Lennon Stella\", \"Artist Followers\": 18195884.0, \"Song ID\": \"3g0mEQx3NTanacLseoP0Gw\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.528, \"Energy\": 0.511, \"Loudness\": -8.144, \"Speechiness\": 0.0324, \"Acousticness\": 0.126, \"Liveness\": 0.101, \"Tempo\": 100.1, \"Duration (ms)\": 209880.0, \"Valence\": 0.351, \"Chord\": \"D#/Eb\"}, {\"Index\": 1247, \"Highest Charting Position\": 190, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"Heart On Ice\", \"Streams\": 4324610, \"Artist\": \"Rod Wave\", \"Artist Followers\": 2203386.0, \"Song ID\": \"6fWa5CRgy0z30OeGZyMBvD\", \"Genre\": \"['florida rap']\", \"Release Date\": \"2019-06-14\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 70.0, \"Danceability\": 0.733, \"Energy\": 0.389, \"Loudness\": -8.468, \"Speechiness\": 0.0738, \"Acousticness\": 0.0513, \"Liveness\": 0.141, \"Tempo\": 157.878, \"Duration (ms)\": 159670.0, \"Valence\": 0.244, \"Chord\": \"A#/Bb\"}, {\"Index\": 1248, \"Highest Charting Position\": 194, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"La Cama - Remix\", \"Streams\": 4261965, \"Artist\": \"Lunay, Myke Towers, Ozuna, Chencho Corleone, Rauw Alejandro\", \"Artist Followers\": 4963516.0, \"Song ID\": \"2tGENA8xef0wABdHvyXwv9\", \"Genre\": \"['latin', 'latin pop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\", \"Popularity\": 69.0, \"Danceability\": 0.737, \"Energy\": 0.832, \"Loudness\": -2.622, \"Speechiness\": 0.0798, \"Acousticness\": 0.12, \"Liveness\": 0.255, \"Tempo\": 173.986, \"Duration (ms)\": 330240.0, \"Valence\": 0.865, \"Chord\": \"D\"}, {\"Index\": 1249, \"Highest Charting Position\": 105, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Go Stupid (feat. NLE Choppa & Mike WiLL Made-It)\", \"Streams\": 4244510, \"Artist\": \"Polo G, Stunna 4 Vegas\", \"Artist Followers\": 4849204.0, \"Song ID\": \"0L8OsjxbagaGkJI0PezdRg\", \"Genre\": \"['chicago rap']\", \"Release Date\": \"2020-05-15\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 41.0, \"Danceability\": 0.922, \"Energy\": 0.813, \"Loudness\": -3.268, \"Speechiness\": 0.251, \"Acousticness\": 0.0198, \"Liveness\": 0.0539, \"Tempo\": 141.087, \"Duration (ms)\": 165726.0, \"Valence\": 0.724, \"Chord\": \"C#/Db\"}, {\"Index\": 1250, \"Highest Charting Position\": 192, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Cradles\", \"Streams\": 4218201, \"Artist\": \"Sub Urban\", \"Artist Followers\": 908351.0, \"Song ID\": \"1y4jsQt7MjnZhiD1L6qFBC\", \"Genre\": \"['modern indie pop']\", \"Release Date\": \"2019-01-04\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 73.0, \"Danceability\": 0.534, \"Energy\": 0.589, \"Loudness\": -1.865, \"Speechiness\": 0.325, \"Acousticness\": 0.256, \"Liveness\": 0.176, \"Tempo\": 78.616, \"Duration (ms)\": 209829.0, \"Valence\": 0.632, \"Chord\": \"C#/Db\"}, {\"Index\": 1251, \"Highest Charting Position\": 117, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Good as Hell (feat. Ariana Grande)\", \"Streams\": 4176083, \"Artist\": \"Lizzo\", \"Artist Followers\": 3991674.0, \"Song ID\": \"07Oz5StQ7GRoygNLaXs2pd\", \"Genre\": \"['dance pop', 'escape room', 'minnesota hip hop', 'pop', 'pop rap', 'post-teen pop', 'trap queen']\", \"Release Date\": \"2016\", \"Weeks Charted\": \"2020-04-10--2020-04-17\\n2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 71.0, \"Danceability\": 0.668, \"Energy\": 0.892, \"Loudness\": -3.001, \"Speechiness\": 0.0645, \"Acousticness\": 0.298, \"Liveness\": 0.735, \"Tempo\": 95.927, \"Duration (ms)\": 159011.0, \"Valence\": 0.478, \"Chord\": \"F\"}, {\"Index\": 1252, \"Highest Charting Position\": 15, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Forever (feat. Post Malone & Clever)\", \"Streams\": 6517807, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2ZlCGeK30BLRNSPC832pNZ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 68.0, \"Danceability\": 0.825, \"Energy\": 0.483, \"Loudness\": -5.746, \"Speechiness\": 0.08, \"Acousticness\": 0.538, \"Liveness\": 0.204, \"Tempo\": 139.98, \"Duration (ms)\": 219933.0, \"Valence\": 0.892, \"Chord\": \"G#/Ab\"}, {\"Index\": 1253, \"Highest Charting Position\": 46, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"I Love Me\", \"Streams\": 5449099, \"Artist\": \"Demi Lovato\", \"Artist Followers\": 20338833.0, \"Song ID\": \"2IHLaN6wwYKQ3S24NsQqpA\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.664, \"Energy\": 0.561, \"Loudness\": -7.031, \"Speechiness\": 0.0495, \"Acousticness\": 0.00261, \"Liveness\": 0.0764, \"Tempo\": 150.093, \"Duration (ms)\": 203672.0, \"Valence\": 0.713, \"Chord\": \"F#/Gb\"}, {\"Index\": 1254, \"Highest Charting Position\": 103, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Old Me\", \"Streams\": 4724056, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"58qO4dGa5SgNdtvqvpewyz\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 67.0, \"Danceability\": 0.722, \"Energy\": 0.62, \"Loudness\": -3.639, \"Speechiness\": 0.0483, \"Acousticness\": 0.313, \"Liveness\": 0.26, \"Tempo\": 127.978, \"Duration (ms)\": 186786.0, \"Valence\": 0.474, \"Chord\": \"C\"}, {\"Index\": 1255, \"Highest Charting Position\": 29, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Pero Ya No\", \"Streams\": 4666658, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"75pQqzwgCjUOSSy5CpmAjy\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 72.0, \"Danceability\": 0.882, \"Energy\": 0.612, \"Loudness\": -6.103, \"Speechiness\": 0.118, \"Acousticness\": 0.0475, \"Liveness\": 0.182, \"Tempo\": 147.982, \"Duration (ms)\": 160638.0, \"Valence\": 0.742, \"Chord\": \"E\"}, {\"Index\": 1256, \"Highest Charting Position\": 24, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Hardest To Love\", \"Streams\": 4553544, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"6kWxIqQDsKFYCJGbU4AjCX\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.467, \"Energy\": 0.608, \"Loudness\": -7.847, \"Speechiness\": 0.0707, \"Acousticness\": 0.0909, \"Liveness\": 0.125, \"Tempo\": 80.957, \"Duration (ms)\": 211400.0, \"Valence\": 0.108, \"Chord\": \"A#/Bb\"}, {\"Index\": 1257, \"Highest Charting Position\": 191, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-04-03--2020-04-10\", \"Song Name\": \"BRABA\", \"Streams\": 4452819, \"Artist\": \"Lu\\u00edsa Sonza\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6DEEuFNv0K3aJtFYZag8gv\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-11\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 0.0, \"Danceability\": 0.812, \"Energy\": 0.689, \"Loudness\": -5.113, \"Speechiness\": 0.0619, \"Acousticness\": 0.181, \"Liveness\": 0.0784, \"Tempo\": 144.011, \"Duration (ms)\": 129782.0, \"Valence\": 0.663, \"Chord\": \"C\"}, {\"Index\": 1258, \"Highest Charting Position\": 77, \"Number of Times Charted\": 14, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Woah\", \"Streams\": 4425610, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"598yNsG1JFrGd4n2kMoz7F\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 69.0, \"Danceability\": 0.882, \"Energy\": 0.602, \"Loudness\": -5.554, \"Speechiness\": 0.245, \"Acousticness\": 0.0177, \"Liveness\": 0.178, \"Tempo\": 142.959, \"Duration (ms)\": 183011.0, \"Valence\": 0.43, \"Chord\": \"B\"}, {\"Index\": 1259, \"Highest Charting Position\": 69, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Pretty Please\", \"Streams\": 4305034, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"6DXZiYUbrYgrVIhfX3U9Z2\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-27--2020-04-03\", \"Popularity\": 67.0, \"Danceability\": 0.906, \"Energy\": 0.474, \"Loudness\": -6.124, \"Speechiness\": 0.194, \"Acousticness\": 0.0311, \"Liveness\": 0.286, \"Tempo\": 106.976, \"Duration (ms)\": 194607.0, \"Valence\": 0.656, \"Chord\": \"C#/Db\"}, {\"Index\": 1260, \"Highest Charting Position\": 170, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"I.F.L.Y.\", \"Streams\": 4284951, \"Artist\": \"Bazzi\", \"Artist Followers\": 4421378.0, \"Song ID\": \"4a6q8CR2hzLk2plDkSxkfD\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-08-09\", \"Weeks Charted\": \"2020-04-03--2020-04-10\\n2020-03-13--2020-03-20\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 76.0, \"Danceability\": 0.812, \"Energy\": 0.519, \"Loudness\": -4.823, \"Speechiness\": 0.0385, \"Acousticness\": 0.379, \"Liveness\": 0.13, \"Tempo\": 104.954, \"Duration (ms)\": 165714.0, \"Valence\": 0.554, \"Chord\": \"D\"}, {\"Index\": 1261, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Cool\", \"Streams\": 8136247, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"4Ulqu89XempybuL8ApUeqL\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.469, \"Energy\": 0.785, \"Loudness\": -4.015, \"Speechiness\": 0.0664, \"Acousticness\": 0.133, \"Liveness\": 0.0931, \"Tempo\": 89.719, \"Duration (ms)\": 209583.0, \"Valence\": 0.79, \"Chord\": \"F\"}, {\"Index\": 1262, \"Highest Charting Position\": 71, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Future Nostalgia\", \"Streams\": 8091754, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3iYNJX4FTRGlfMQySjlGNr\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.875, \"Energy\": 0.813, \"Loudness\": -4.502, \"Speechiness\": 0.0579, \"Acousticness\": 0.00618, \"Liveness\": 0.321, \"Tempo\": 114.993, \"Duration (ms)\": 184882.0, \"Valence\": 0.859, \"Chord\": \"G\"}, {\"Index\": 1263, \"Highest Charting Position\": 92, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Good In Bed\", \"Streams\": 6802068, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"3pyodt4pb554dMz8fCv7oi\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 64.0, \"Danceability\": 0.68, \"Energy\": 0.701, \"Loudness\": -5.001, \"Speechiness\": 0.0917, \"Acousticness\": 0.138, \"Liveness\": 0.168, \"Tempo\": 94.06, \"Duration (ms)\": 218754.0, \"Valence\": 0.649, \"Chord\": \"F\"}, {\"Index\": 1264, \"Highest Charting Position\": 27, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Scared To Live\", \"Streams\": 6566099, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"4BGZF4oLbTL0pWm7C18pbv\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 66.0, \"Danceability\": 0.504, \"Energy\": 0.498, \"Loudness\": -8.24, \"Speechiness\": 0.0499, \"Acousticness\": 0.131, \"Liveness\": 0.0929, \"Tempo\": 87.221, \"Duration (ms)\": 191307.0, \"Valence\": 0.196, \"Chord\": \"C\"}, {\"Index\": 1265, \"Highest Charting Position\": 21, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Alone Again\", \"Streams\": 6055294, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"6b5P51m8xx2XA6U7sdNZ5E\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 66.0, \"Danceability\": 0.218, \"Energy\": 0.652, \"Loudness\": -7.953, \"Speechiness\": 0.0641, \"Acousticness\": 0.033, \"Liveness\": 0.172, \"Tempo\": 65.375, \"Duration (ms)\": 250053.0, \"Valence\": 0.0599, \"Chord\": \"E\"}, {\"Index\": 1266, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Boys Will Be Boys\", \"Streams\": 6015914, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"4szI7zRh7kLApCSqiB6R7b\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2021-02-11\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 63.0, \"Danceability\": 0.768, \"Energy\": 0.486, \"Loudness\": -5.954, \"Speechiness\": 0.0353, \"Acousticness\": 0.408, \"Liveness\": 0.098, \"Tempo\": 125.021, \"Duration (ms)\": 166266.0, \"Valence\": 0.519, \"Chord\": \"D#/Eb\"}, {\"Index\": 1267, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Auto Blu\", \"Streams\": 5995116, \"Artist\": \"Shiva, Eiffel 65\", \"Artist Followers\": 561372.0, \"Song ID\": \"5swpvba5YLqVDy1nbzUdog\", \"Genre\": \"['italian hip hop', 'trap italiana']\", \"Release Date\": \"2020-03-26\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 56.0, \"Danceability\": 0.82, \"Energy\": 0.783, \"Loudness\": -6.146, \"Speechiness\": 0.0621, \"Acousticness\": 0.0158, \"Liveness\": 0.0938, \"Tempo\": 130.015, \"Duration (ms)\": 166087.0, \"Valence\": 0.653, \"Chord\": \"F\"}, {\"Index\": 1268, \"Highest Charting Position\": 132, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Du bist mein\", \"Streams\": 5878493, \"Artist\": \"Zuna, Loredana, SRNO\", \"Artist Followers\": 900975.0, \"Song ID\": \"719aY5gAzJbx2PHjyalZQu\", \"Genre\": \"['albanian hip hop', 'german hip hop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 54.0, \"Danceability\": 0.761, \"Energy\": 0.556, \"Loudness\": -6.943, \"Speechiness\": 0.364, \"Acousticness\": 0.138, \"Liveness\": 0.0976, \"Tempo\": 187.81, \"Duration (ms)\": 160357.0, \"Valence\": 0.521, \"Chord\": \"C#/Db\"}, {\"Index\": 1269, \"Highest Charting Position\": 28, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Too Late\", \"Streams\": 5867746, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"2K9Ovn1o2bTGqbsABGC6m3\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.638, \"Energy\": 0.863, \"Loudness\": -5.221, \"Speechiness\": 0.132, \"Acousticness\": 0.052, \"Liveness\": 0.685, \"Tempo\": 120.077, \"Duration (ms)\": 239973.0, \"Valence\": 0.226, \"Chord\": \"E\"}, {\"Index\": 1270, \"Highest Charting Position\": 136, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Wildflower\", \"Streams\": 5791343, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"6qlcjGJPTZEwR8nf2nSe9C\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.644, \"Energy\": 0.768, \"Loudness\": -4.316, \"Speechiness\": 0.0455, \"Acousticness\": 0.174, \"Liveness\": 0.469, \"Tempo\": 108.992, \"Duration (ms)\": 220536.0, \"Valence\": 0.598, \"Chord\": \"F#/Gb\"}, {\"Index\": 1271, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Faith\", \"Streams\": 5730081, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"3orEOtd8CPL8GFlpRpKuoE\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.375, \"Energy\": 0.605, \"Loudness\": -7.268, \"Speechiness\": 0.0729, \"Acousticness\": 0.612, \"Liveness\": 0.147, \"Tempo\": 175.946, \"Duration (ms)\": 283227.0, \"Valence\": 0.128, \"Chord\": \"C\"}, {\"Index\": 1272, \"Highest Charting Position\": 35, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Snowchild\", \"Streams\": 5423997, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"3WlbeuhfRSqU7ylK2Ui5U7\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 66.0, \"Danceability\": 0.55, \"Energy\": 0.611, \"Loudness\": -7.475, \"Speechiness\": 0.137, \"Acousticness\": 0.162, \"Liveness\": 0.121, \"Tempo\": 148.062, \"Duration (ms)\": 247187.0, \"Valence\": 0.243, \"Chord\": \"C\"}, {\"Index\": 1273, \"Highest Charting Position\": 37, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Escape From LA\", \"Streams\": 5307288, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"1sOW4PuG5X3Ie3EXUhAopJ\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.404, \"Energy\": 0.524, \"Loudness\": -8.996, \"Speechiness\": 0.0593, \"Acousticness\": 0.0456, \"Liveness\": 0.199, \"Tempo\": 145.74, \"Duration (ms)\": 355960.0, \"Valence\": 0.168, \"Chord\": \"F\"}, {\"Index\": 1274, \"Highest Charting Position\": 161, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Allein sein\", \"Streams\": 5119993, \"Artist\": \"Ufo361\", \"Artist Followers\": 1700759.0, \"Song ID\": \"2TrhpvxwuF6hrboTdRXwnS\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 54.0, \"Danceability\": 0.774, \"Energy\": 0.588, \"Loudness\": -8.529, \"Speechiness\": 0.225, \"Acousticness\": 0.0386, \"Liveness\": 0.258, \"Tempo\": 75.978, \"Duration (ms)\": 147353.0, \"Valence\": 0.392, \"Chord\": \"C#/Db\"}, {\"Index\": 1275, \"Highest Charting Position\": 44, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Bichiyal\", \"Streams\": 4946613, \"Artist\": \"Bad Bunny, Yaviah\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4j4w4CXm6BSr0s25wAWrrX\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 75.0, \"Danceability\": 0.737, \"Energy\": 0.766, \"Loudness\": -4.242, \"Speechiness\": 0.0458, \"Acousticness\": 0.31, \"Liveness\": 0.114, \"Tempo\": 93.956, \"Duration (ms)\": 196500.0, \"Valence\": 0.662, \"Chord\": \"A#/Bb\"}, {\"Index\": 1276, \"Highest Charting Position\": 85, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Medusa\", \"Streams\": 4901559, \"Artist\": \"Jhay Cortez, Anuel AA, J Balvin\", \"Artist Followers\": 2435159.0, \"Song ID\": \"3qM0vBxIe4VUbK0Z0smuVP\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-05\", \"Weeks Charted\": \"2020-03-27--2020-04-03\\n2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 70.0, \"Danceability\": 0.886, \"Energy\": 0.604, \"Loudness\": -7.293, \"Speechiness\": 0.208, \"Acousticness\": 0.194, \"Liveness\": 0.107, \"Tempo\": 98.023, \"Duration (ms)\": 305333.0, \"Valence\": 0.383, \"Chord\": \"C\"}, {\"Index\": 1277, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Break Up Song\", \"Streams\": 4593343, \"Artist\": \"Little Mix\", \"Artist Followers\": 9398941.0, \"Song ID\": \"5HArmECc1y0lCHKVKDKXa4\", \"Genre\": \"['dance pop', 'girl group', 'pop', 'post-teen pop', 'talent show', 'uk pop']\", \"Release Date\": \"2020-11-06\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 65.0, \"Danceability\": 0.631, \"Energy\": 0.75, \"Loudness\": -5.416, \"Speechiness\": 0.0394, \"Acousticness\": 0.00388, \"Liveness\": 0.286, \"Tempo\": 90.019, \"Duration (ms)\": 200293.0, \"Valence\": 0.593, \"Chord\": \"F\"}, {\"Index\": 1278, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-27--2020-04-03\", \"Song Name\": \"Teeth\", \"Streams\": 4571612, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"26wLOs3ZuHJa2Ihhx6QIE6\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-03-27--2020-04-03\", \"Popularity\": 78.0, \"Danceability\": 0.749, \"Energy\": 0.461, \"Loudness\": -2.961, \"Speechiness\": 0.0416, \"Acousticness\": 0.0516, \"Liveness\": 0.0738, \"Tempo\": 139.02, \"Duration (ms)\": 204887.0, \"Valence\": 0.42, \"Chord\": \"A#/Bb\"}, {\"Index\": 1279, \"Highest Charting Position\": 51, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Repeat After Me (Interlude)\", \"Streams\": 10058303, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"40U8d12pC5UHqmHwXjHjjl\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 63.0, \"Danceability\": 0.555, \"Energy\": 0.619, \"Loudness\": -7.918, \"Speechiness\": 0.0314, \"Acousticness\": 0.0323, \"Liveness\": 0.0917, \"Tempo\": 95.032, \"Duration (ms)\": 195813.0, \"Valence\": 0.141, \"Chord\": \"C\"}, {\"Index\": 1280, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Until I Bleed Out\", \"Streams\": 9132077, \"Artist\": \"The Weeknd\", \"Artist Followers\": 35340069.0, \"Song ID\": \"2BcnxwxBuar5wjCaLqm5N3\", \"Genre\": \"['canadian contemporary r&b', 'canadian pop', 'pop']\", \"Release Date\": \"2020-03-20\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 63.0, \"Danceability\": 0.245, \"Energy\": 0.394, \"Loudness\": -9.887, \"Speechiness\": 0.0374, \"Acousticness\": 0.423, \"Liveness\": 0.093, \"Tempo\": 115.233, \"Duration (ms)\": 190173.0, \"Valence\": 0.148, \"Chord\": \"C\"}, {\"Index\": 1281, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Rosa\", \"Streams\": 7564893, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"464uJVLmr0fDJGXOnciaDe\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 64.0, \"Danceability\": 0.651, \"Energy\": 0.561, \"Loudness\": -5.715, \"Speechiness\": 0.25, \"Acousticness\": 0.25, \"Liveness\": 0.435, \"Tempo\": 175.992, \"Duration (ms)\": 189827.0, \"Valence\": 0.369, \"Chord\": \"A\"}, {\"Index\": 1282, \"Highest Charting Position\": 88, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Gris\", \"Streams\": 7514854, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"1syf62zw48zu4FrPwMtDHk\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 65.0, \"Danceability\": 0.849, \"Energy\": 0.709, \"Loudness\": -4.717, \"Speechiness\": 0.0794, \"Acousticness\": 0.229, \"Liveness\": 0.329, \"Tempo\": 93.06, \"Duration (ms)\": 176627.0, \"Valence\": 0.916, \"Chord\": \"F#/Gb\"}, {\"Index\": 1283, \"Highest Charting Position\": 103, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Negro\", \"Streams\": 6651425, \"Artist\": \"J Balvin\", \"Artist Followers\": 29067437.0, \"Song ID\": \"2hsA9YWuF3C9Gosi4dpjJN\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 67.0, \"Danceability\": 0.795, \"Energy\": 0.911, \"Loudness\": -2.228, \"Speechiness\": 0.0875, \"Acousticness\": 0.0157, \"Liveness\": 0.131, \"Tempo\": 164.081, \"Duration (ms)\": 182093.0, \"Valence\": 0.8, \"Chord\": \"C\"}, {\"Index\": 1284, \"Highest Charting Position\": 134, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Verde\", \"Streams\": 5745393, \"Artist\": \"J Balvin, Sky Rompiendo\", \"Artist Followers\": 29067437.0, \"Song ID\": \"3HTbI3yUJQw3fP0Po8qLcD\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 63.0, \"Danceability\": 0.828, \"Energy\": 0.738, \"Loudness\": -4.295, \"Speechiness\": 0.0516, \"Acousticness\": 0.0381, \"Liveness\": 0.0917, \"Tempo\": 94.995, \"Duration (ms)\": 142547.0, \"Valence\": 0.818, \"Chord\": \"G#/Ab\"}, {\"Index\": 1285, \"Highest Charting Position\": 15, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Baby Pluto\", \"Streams\": 5600261, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7hav1MHURQf5SAoPk0egqh\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 69.0, \"Danceability\": 0.772, \"Energy\": 0.634, \"Loudness\": -6.101, \"Speechiness\": 0.212, \"Acousticness\": 0.135, \"Liveness\": 0.432, \"Tempo\": 160.052, \"Duration (ms)\": 210261.0, \"Valence\": 0.671, \"Chord\": \"A#/Bb\"}, {\"Index\": 1286, \"Highest Charting Position\": 31, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Lo Mein\", \"Streams\": 5231134, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"6CUP2khYzdphXebxVTfPE3\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 67.0, \"Danceability\": 0.855, \"Energy\": 0.676, \"Loudness\": -5.736, \"Speechiness\": 0.325, \"Acousticness\": 0.0888, \"Liveness\": 0.144, \"Tempo\": 133.082, \"Duration (ms)\": 195299.0, \"Valence\": 0.509, \"Chord\": \"C#/Db\"}, {\"Index\": 1287, \"Highest Charting Position\": 113, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"No Judgement\", \"Streams\": 5082563, \"Artist\": \"Niall Horan\", \"Artist Followers\": 7564659.0, \"Song ID\": \"5IUOU5xkzGHsRFOYNu3GSK\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 65.0, \"Danceability\": 0.723, \"Energy\": 0.726, \"Loudness\": -3.835, \"Speechiness\": 0.0472, \"Acousticness\": 0.0564, \"Liveness\": 0.057, \"Tempo\": 100.051, \"Duration (ms)\": 176283.0, \"Valence\": 0.962, \"Chord\": \"C#/Db\"}, {\"Index\": 1288, \"Highest Charting Position\": 57, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Futsal Shuffle 2020 - Bonus Track\", \"Streams\": 5068849, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2fOlBMkWR7lXJfqp5VTbDG\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 63.0, \"Danceability\": 0.879, \"Energy\": 0.448, \"Loudness\": -8.57, \"Speechiness\": 0.222, \"Acousticness\": 0.0346, \"Liveness\": 0.224, \"Tempo\": 136.985, \"Duration (ms)\": 198913.0, \"Valence\": 0.278, \"Chord\": \"G\"}, {\"Index\": 1289, \"Highest Charting Position\": 163, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"Arco\\u00edris\", \"Streams\": 5044774, \"Artist\": \"J Balvin, Mr Eazi\", \"Artist Followers\": 29067437.0, \"Song ID\": \"5zzbORcD0GwLY0wQHP1Xs1\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 62.0, \"Danceability\": 0.731, \"Energy\": 0.787, \"Loudness\": -5.26, \"Speechiness\": 0.0721, \"Acousticness\": 0.0853, \"Liveness\": 0.316, \"Tempo\": 92.971, \"Duration (ms)\": 186693.0, \"Valence\": 0.393, \"Chord\": \"E\"}, {\"Index\": 1290, \"Highest Charting Position\": 65, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"TOES (feat. Lil Baby & Moneybagg Yo)\", \"Streams\": 4878903, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"2FvD20Z8aoWIePi7PoN8sG\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 73.0, \"Danceability\": 0.816, \"Energy\": 0.582, \"Loudness\": -4.141, \"Speechiness\": 0.341, \"Acousticness\": 0.0794, \"Liveness\": 0.0916, \"Tempo\": 160.004, \"Duration (ms)\": 136366.0, \"Valence\": 0.542, \"Chord\": \"G#/Ab\"}, {\"Index\": 1291, \"Highest Charting Position\": 42, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Feel Me\", \"Streams\": 4765672, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"6XXYdF6pJR1K3wKvuxmu7n\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 63.0, \"Danceability\": 0.71, \"Energy\": 0.808, \"Loudness\": -6.703, \"Speechiness\": 0.0433, \"Acousticness\": 0.44, \"Liveness\": 0.0734, \"Tempo\": 99.989, \"Duration (ms)\": 226003.0, \"Valence\": 0.392, \"Chord\": \"D\"}, {\"Index\": 1292, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-20--2020-03-27\", \"Song Name\": \"H <3 T E L\", \"Streams\": 4701388, \"Artist\": \"Dardan, Monet192\", \"Artist Followers\": 861082.0, \"Song ID\": \"3S1NOXjDr2A4xXXsWo8kLr\", \"Genre\": \"['albanian hip hop', 'german hip hop']\", \"Release Date\": \"2020-05-22\", \"Weeks Charted\": \"2020-03-20--2020-03-27\", \"Popularity\": 34.0, \"Danceability\": 0.726, \"Energy\": 0.646, \"Loudness\": -6.9, \"Speechiness\": 0.0977, \"Acousticness\": 0.0495, \"Liveness\": 0.112, \"Tempo\": 134.999, \"Duration (ms)\": 163253.0, \"Valence\": 0.58, \"Chord\": \"C#/Db\"}, {\"Index\": 1293, \"Highest Charting Position\": 63, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"25/8\", \"Streams\": 4684378, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4NqQaovM14WR2hNPMFxgjb\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 71.0, \"Danceability\": 0.761, \"Energy\": 0.732, \"Loudness\": -5.469, \"Speechiness\": 0.0549, \"Acousticness\": 0.092, \"Liveness\": 0.0716, \"Tempo\": 151.982, \"Duration (ms)\": 243276.0, \"Valence\": 0.542, \"Chord\": \"E\"}, {\"Index\": 1294, \"Highest Charting Position\": 81, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Se Me Olvid\\u00f3\", \"Streams\": 4591194, \"Artist\": \"Christian Nodal\", \"Artist Followers\": 8123757.0, \"Song ID\": \"7paFC3FEu1WtPVP4Do6VZN\", \"Genre\": \"['mariachi', 'nuevo regional mexicano', 'ranchera', 'regional mexican']\", \"Release Date\": \"2020-05-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 71.0, \"Danceability\": 0.65, \"Energy\": 0.558, \"Loudness\": -3.082, \"Speechiness\": 0.0309, \"Acousticness\": 0.368, \"Liveness\": 0.303, \"Tempo\": 141.82, \"Duration (ms)\": 159533.0, \"Valence\": 0.725, \"Chord\": \"C\"}, {\"Index\": 1295, \"Highest Charting Position\": 130, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"B.S. (feat. H.E.R.)\", \"Streams\": 4557817, \"Artist\": \"Jhen\\u00e9 Aiko\", \"Artist Followers\": 4720858.0, \"Song ID\": \"63wx9vdskaXbYxyDx4oJCZ\", \"Genre\": \"['alternative r&b', 'dance pop', 'pop', 'pop rap', 'r&b', 'urban contemporary']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 72.0, \"Danceability\": 0.617, \"Energy\": 0.525, \"Loudness\": -10.426, \"Speechiness\": 0.12, \"Acousticness\": 0.554, \"Liveness\": 0.135, \"Tempo\": 135.781, \"Duration (ms)\": 212867.0, \"Valence\": 0.377, \"Chord\": \"G#/Ab\"}, {\"Index\": 1296, \"Highest Charting Position\": 45, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Soli\\u00e1\", \"Streams\": 4516243, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"7sOfmPd18RWp3FoCzpa7Kw\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 72.0, \"Danceability\": 0.71, \"Energy\": 0.81, \"Loudness\": -5.507, \"Speechiness\": 0.0854, \"Acousticness\": 0.117, \"Liveness\": 0.154, \"Tempo\": 92.041, \"Duration (ms)\": 159282.0, \"Valence\": 0.184, \"Chord\": \"D\"}, {\"Index\": 1297, \"Highest Charting Position\": 55, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Est\\u00e1 Cabr\\u00f3n Ser Yo\", \"Streams\": 4438261, \"Artist\": \"Bad Bunny, Anuel AA\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4saHEjXw7O1NXJOzBkUKKG\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-20--2020-03-27\\n2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.81, \"Energy\": 0.854, \"Loudness\": -3.999, \"Speechiness\": 0.254, \"Acousticness\": 0.0732, \"Liveness\": 0.123, \"Tempo\": 154.083, \"Duration (ms)\": 227939.0, \"Valence\": 0.879, \"Chord\": \"A#/Bb\"}, {\"Index\": 1298, \"Highest Charting Position\": 61, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Bean (Kobe) [feat. Chief Keef]\", \"Streams\": 9039518, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"0IpnZchq8ek2A6pGEP2Qb1\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 67.0, \"Danceability\": 0.733, \"Energy\": 0.567, \"Loudness\": -6.718, \"Speechiness\": 0.319, \"Acousticness\": 0.0129, \"Liveness\": 0.382, \"Tempo\": 75.491, \"Duration (ms)\": 238816.0, \"Valence\": 0.319, \"Chord\": \"C\"}, {\"Index\": 1299, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Yessirskiii\", \"Streams\": 8374259, \"Artist\": \"Lil Uzi Vert, 21 Savage\", \"Artist Followers\": 11821805.0, \"Song ID\": \"59JWp4PjZ9TRM8cmtaDYB1\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 70.0, \"Danceability\": 0.895, \"Energy\": 0.739, \"Loudness\": -6.633, \"Speechiness\": 0.283, \"Acousticness\": 0.0183, \"Liveness\": 0.102, \"Tempo\": 140.007, \"Duration (ms)\": 219340.0, \"Valence\": 0.763, \"Chord\": \"G#/Ab\"}, {\"Index\": 1300, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Cardigan\", \"Streams\": 6586204, \"Artist\": \"Don Toliver\", \"Artist Followers\": 1606884.0, \"Song ID\": \"0Li1OuXXfi7950ilZUFGkF\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 70.0, \"Danceability\": 0.747, \"Energy\": 0.497, \"Loudness\": -6.542, \"Speechiness\": 0.0401, \"Acousticness\": 0.248, \"Liveness\": 0.138, \"Tempo\": 142.046, \"Duration (ms)\": 158709.0, \"Valence\": 0.0663, \"Chord\": \"E\"}, {\"Index\": 1301, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Silly Watch\", \"Streams\": 6442451, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"5egD7A5x9AHdVO2fMo3Wbo\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 65.0, \"Danceability\": 0.903, \"Energy\": 0.535, \"Loudness\": -6.238, \"Speechiness\": 0.286, \"Acousticness\": 0.0298, \"Liveness\": 0.0851, \"Tempo\": 130.117, \"Duration (ms)\": 195692.0, \"Valence\": 0.157, \"Chord\": \"G#/Ab\"}, {\"Index\": 1302, \"Highest Charting Position\": 70, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Hablamos Ma\\u00f1ana\", \"Streams\": 6105711, \"Artist\": \"Bad Bunny, Duki, Pablo Chill-E\", \"Artist Followers\": 36177712.0, \"Song ID\": \"1V8XneTrX6kKeoxYbk4x6h\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.683, \"Energy\": 0.677, \"Loudness\": -4.496, \"Speechiness\": 0.0469, \"Acousticness\": 0.0869, \"Liveness\": 0.0998, \"Tempo\": 156.019, \"Duration (ms)\": 240253.0, \"Valence\": 0.514, \"Chord\": \"C#/Db\"}, {\"Index\": 1303, \"Highest Charting Position\": 126, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Lotus\", \"Streams\": 6017103, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4SnlSaLJJ7reJMCHM5YUuX\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 58.0, \"Danceability\": 0.802, \"Energy\": 0.748, \"Loudness\": -5.708, \"Speechiness\": 0.207, \"Acousticness\": 0.24, \"Liveness\": 0.165, \"Tempo\": 150.063, \"Duration (ms)\": 193861.0, \"Valence\": 0.516, \"Chord\": \"G#/Ab\"}, {\"Index\": 1304, \"Highest Charting Position\": 126, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Lettre \\u00e0 une femme\", \"Streams\": 5895243, \"Artist\": \"Ninho\", \"Artist Followers\": 4764552.0, \"Song ID\": \"10rwyGbKAWZ8JZbL7uHl28\", \"Genre\": \"['french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2020-03-07\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 54.0, \"Danceability\": 0.487, \"Energy\": 0.398, \"Loudness\": -9.901, \"Speechiness\": 0.0697, \"Acousticness\": 0.835, \"Liveness\": 0.12, \"Tempo\": 149.367, \"Duration (ms)\": 157766.0, \"Valence\": 0.905, \"Chord\": \"C#/Db\"}, {\"Index\": 1305, \"Highest Charting Position\": 57, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Que Malo\", \"Streams\": 5544180, \"Artist\": \"Bad Bunny, \\u00d1engo Flow\", \"Artist Followers\": 36177712.0, \"Song ID\": \"53v2u51nq3CxiKUNphRzP1\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.802, \"Energy\": 0.787, \"Loudness\": -6.181, \"Speechiness\": 0.0599, \"Acousticness\": 0.0832, \"Liveness\": 0.153, \"Tempo\": 94.026, \"Duration (ms)\": 167975.0, \"Valence\": 0.446, \"Chord\": \"G\"}, {\"Index\": 1306, \"Highest Charting Position\": 147, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Leaders (feat. NAV)\", \"Streams\": 5496780, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4D7NrSeqkTarBrJ80b2sBc\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 60.0, \"Danceability\": 0.95, \"Energy\": 0.654, \"Loudness\": -5.895, \"Speechiness\": 0.307, \"Acousticness\": 0.0744, \"Liveness\": 0.138, \"Tempo\": 132.936, \"Duration (ms)\": 194844.0, \"Valence\": 0.886, \"Chord\": \"C\"}, {\"Index\": 1307, \"Highest Charting Position\": 149, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Strawberry Peels (feat. Young Thug & Gunna)\", \"Streams\": 5468083, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4lAQfuREAHG8IC0PiiigBt\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 59.0, \"Danceability\": 0.862, \"Energy\": 0.65, \"Loudness\": -6.978, \"Speechiness\": 0.355, \"Acousticness\": 0.0207, \"Liveness\": 0.568, \"Tempo\": 131.194, \"Duration (ms)\": 115350.0, \"Valence\": 0.658, \"Chord\": \"A#/Bb\"}, {\"Index\": 1308, \"Highest Charting Position\": 60, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"La Zona\", \"Streams\": 5440382, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5kqNIqFjijuzvVLhuY9B8j\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.762, \"Energy\": 0.801, \"Loudness\": -3.661, \"Speechiness\": 0.0409, \"Acousticness\": 0.2, \"Liveness\": 0.254, \"Tempo\": 93.992, \"Duration (ms)\": 136893.0, \"Valence\": 0.81, \"Chord\": \"C#/Db\"}, {\"Index\": 1309, \"Highest Charting Position\": 153, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Wassup (feat. Future)\", \"Streams\": 5415044, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"19Ec2gbNtQTE44IizcPjtD\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 57.0, \"Danceability\": 0.762, \"Energy\": 0.622, \"Loudness\": -6.293, \"Speechiness\": 0.223, \"Acousticness\": 0.352, \"Liveness\": 0.145, \"Tempo\": 130.019, \"Duration (ms)\": 193314.0, \"Valence\": 0.626, \"Chord\": \"F\"}, {\"Index\": 1310, \"Highest Charting Position\": 69, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Una Vez\", \"Streams\": 5411302, \"Artist\": \"Bad Bunny, Mora\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5J7teKIJGtqVypgYI6sqXj\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 77.0, \"Danceability\": 0.55, \"Energy\": 0.598, \"Loudness\": -5.402, \"Speechiness\": 0.0831, \"Acousticness\": 0.132, \"Liveness\": 0.0955, \"Tempo\": 83.836, \"Duration (ms)\": 232496.0, \"Valence\": 0.543, \"Chord\": \"B\"}, {\"Index\": 1311, \"Highest Charting Position\": 158, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Moon Relate\", \"Streams\": 5324545, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4sWGHlZGM1XA7TyWdtBAbA\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 58.0, \"Danceability\": 0.867, \"Energy\": 0.768, \"Loudness\": -3.73, \"Speechiness\": 0.0791, \"Acousticness\": 0.18, \"Liveness\": 0.254, \"Tempo\": 102.021, \"Duration (ms)\": 181826.0, \"Valence\": 0.34, \"Chord\": \"G\"}, {\"Index\": 1312, \"Highest Charting Position\": 163, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Black And White\", \"Streams\": 5204120, \"Artist\": \"Niall Horan\", \"Artist Followers\": 7564659.0, \"Song ID\": \"7rpNuuoMbid56XkDsx2FjE\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 75.0, \"Danceability\": 0.443, \"Energy\": 0.582, \"Loudness\": -6.02, \"Speechiness\": 0.0482, \"Acousticness\": 0.0301, \"Liveness\": 0.127, \"Tempo\": 147.589, \"Duration (ms)\": 193090.0, \"Valence\": 0.239, \"Chord\": \"D\"}, {\"Index\": 1313, \"Highest Charting Position\": 81, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"The Other Side (from Trolls World Tour)\", \"Streams\": 5193927, \"Artist\": \"SZA, Justin Timberlake\", \"Artist Followers\": 5888533.0, \"Song ID\": \"463PQggkmk5tTw8ug0ahOX\", \"Genre\": \"['pop', 'pop rap', 'r&b']\", \"Release Date\": \"2020-02-26\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 68.0, \"Danceability\": 0.76, \"Energy\": 0.607, \"Loudness\": -6.274, \"Speechiness\": 0.0964, \"Acousticness\": 0.00277, \"Liveness\": 0.132, \"Tempo\": 105.979, \"Duration (ms)\": 188187.0, \"Valence\": 0.709, \"Chord\": \"G\"}, {\"Index\": 1314, \"Highest Charting Position\": 53, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Whine Up\", \"Streams\": 5130783, \"Artist\": \"Nicky Jam, Anuel AA\", \"Artist Followers\": 14831925.0, \"Song ID\": \"2pWOMNQJW3g2zmGjP0Vkb0\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-01\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.817, \"Energy\": 0.665, \"Loudness\": -6.224, \"Speechiness\": 0.0758, \"Acousticness\": 0.0549, \"Liveness\": 0.103, \"Tempo\": 104.957, \"Duration (ms)\": 215460.0, \"Valence\": 0.662, \"Chord\": \"A\"}, {\"Index\": 1315, \"Highest Charting Position\": 37, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Ayy Macarena\", \"Streams\": 5046905, \"Artist\": \"Tyga\", \"Artist Followers\": 6298789.0, \"Song ID\": \"6LcauUZjF1eXQrgqMUecHX\", \"Genre\": \"['dance pop', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2019-11-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.816, \"Energy\": 0.629, \"Loudness\": -5.568, \"Speechiness\": 0.226, \"Acousticness\": 0.133, \"Liveness\": 0.0692, \"Tempo\": 96.493, \"Duration (ms)\": 131607.0, \"Valence\": 0.714, \"Chord\": \"D\"}, {\"Index\": 1316, \"Highest Charting Position\": 177, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Trap This Way (This Way)\", \"Streams\": 5043990, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7vTspUAmMKFkUpKL9HLZNL\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 59.0, \"Danceability\": 0.71, \"Energy\": 0.586, \"Loudness\": -5.331, \"Speechiness\": 0.381, \"Acousticness\": 0.248, \"Liveness\": 0.193, \"Tempo\": 175.987, \"Duration (ms)\": 185439.0, \"Valence\": 0.207, \"Chord\": \"D\"}, {\"Index\": 1317, \"Highest Charting Position\": 113, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Who (feat. BTS)\", \"Streams\": 5004752, \"Artist\": \"Lauv\", \"Artist Followers\": 4442273.0, \"Song ID\": \"2qG81jL9UIP54uS8gYyP4k\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 74.0, \"Danceability\": 0.632, \"Energy\": 0.345, \"Loudness\": -8.0, \"Speechiness\": 0.0349, \"Acousticness\": 0.551, \"Liveness\": 0.104, \"Tempo\": 141.641, \"Duration (ms)\": 180413.0, \"Valence\": 0.0818, \"Chord\": \"B\"}, {\"Index\": 1318, \"Highest Charting Position\": 51, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Homecoming\", \"Streams\": 4988839, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"6vxU64pcIuQ38O015Zy4qj\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 63.0, \"Danceability\": 0.929, \"Energy\": 0.563, \"Loudness\": -7.428, \"Speechiness\": 0.49, \"Acousticness\": 0.000592, \"Liveness\": 0.244, \"Tempo\": 129.957, \"Duration (ms)\": 213885.0, \"Valence\": 0.353, \"Chord\": \"A\"}, {\"Index\": 1319, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Got The Guap (feat. Young Thug)\", \"Streams\": 4946997, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"1HF6P40Z7nfExGaB1Gk99v\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 58.0, \"Danceability\": 0.837, \"Energy\": 0.601, \"Loudness\": -5.628, \"Speechiness\": 0.198, \"Acousticness\": 0.21, \"Liveness\": 0.0928, \"Tempo\": 142.977, \"Duration (ms)\": 176756.0, \"Valence\": 0.749, \"Chord\": \"G#/Ab\"}, {\"Index\": 1320, \"Highest Charting Position\": 53, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Prices\", \"Streams\": 4898167, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4YcWzLSnGqLjSCycuSMHnn\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 65.0, \"Danceability\": 0.786, \"Energy\": 0.683, \"Loudness\": -5.397, \"Speechiness\": 0.205, \"Acousticness\": 0.173, \"Liveness\": 0.706, \"Tempo\": 126.002, \"Duration (ms)\": 233333.0, \"Valence\": 0.57, \"Chord\": \"G\"}, {\"Index\": 1321, \"Highest Charting Position\": 188, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"I Can Show You\", \"Streams\": 4831405, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"0AhJag7VI8uFf3mJFsTwvf\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 57.0, \"Danceability\": 0.817, \"Energy\": 0.656, \"Loudness\": -7.086, \"Speechiness\": 0.277, \"Acousticness\": 0.051, \"Liveness\": 0.115, \"Tempo\": 139.915, \"Duration (ms)\": 120076.0, \"Valence\": 0.314, \"Chord\": \"A#/Bb\"}, {\"Index\": 1322, \"Highest Charting Position\": 52, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"I'm Sorry\", \"Streams\": 4818039, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"1xcOYJxDa5pObgxY1r0I9c\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\", \"Popularity\": 60.0, \"Danceability\": 0.858, \"Energy\": 0.547, \"Loudness\": -5.822, \"Speechiness\": 0.29, \"Acousticness\": 0.213, \"Liveness\": 0.104, \"Tempo\": 128.02, \"Duration (ms)\": 211883.0, \"Valence\": 0.303, \"Chord\": \"C#/Db\"}, {\"Index\": 1323, \"Highest Charting Position\": 19, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Black Swan\", \"Streams\": 4802069, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3bkkMZEAhx7rTVz1C0itRQ\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 70.0, \"Danceability\": 0.719, \"Energy\": 0.758, \"Loudness\": -5.167, \"Speechiness\": 0.0851, \"Acousticness\": 0.137, \"Liveness\": 0.129, \"Tempo\": 147.023, \"Duration (ms)\": 198261.0, \"Valence\": 0.49, \"Chord\": \"D\"}, {\"Index\": 1324, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Bad Child\", \"Streams\": 4787180, \"Artist\": \"Tones And I\", \"Artist Followers\": 1251372.0, \"Song ID\": \"2hBeHlR2d7wFJVLcj2fivL\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 0.0, \"Danceability\": 0.756, \"Energy\": 0.553, \"Loudness\": -4.24, \"Speechiness\": 0.0343, \"Acousticness\": 0.404, \"Liveness\": 0.158, \"Tempo\": 117.992, \"Duration (ms)\": 221467.0, \"Valence\": 0.597, \"Chord\": \"F#/Gb\"}, {\"Index\": 1325, \"Highest Charting Position\": 61, \"Number of Times Charted\": 12, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Adicto (with Anuel AA & Ozuna)\", \"Streams\": 4785720, \"Artist\": \"Tainy\", \"Artist Followers\": 509411.0, \"Song ID\": \"3jbT1Y5MoPwEIpZndDDwVq\", \"Genre\": \"['latin', 'latin hip hop', 'latin pop', 'pop reggaeton', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-08-22\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.734, \"Energy\": 0.836, \"Loudness\": -4.803, \"Speechiness\": 0.0735, \"Acousticness\": 0.017, \"Liveness\": 0.179, \"Tempo\": 80.002, \"Duration (ms)\": 270741.0, \"Valence\": 0.623, \"Chord\": \"A#/Bb\"}, {\"Index\": 1326, \"Highest Charting Position\": 66, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"<3\", \"Streams\": 4755477, \"Artist\": \"Bad Bunny\", \"Artist Followers\": 36177712.0, \"Song ID\": \"4MZSqgwlE71CWZ6qQ3gkKm\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 69.0, \"Danceability\": 0.631, \"Energy\": 0.665, \"Loudness\": -7.589, \"Speechiness\": 0.229, \"Acousticness\": 0.602, \"Liveness\": 0.152, \"Tempo\": 80.353, \"Duration (ms)\": 157967.0, \"Valence\": 0.634, \"Chord\": \"A#/Bb\"}, {\"Index\": 1327, \"Highest Charting Position\": 198, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-13--2020-03-20\", \"Song Name\": \"Bad Girls, Good Vibes\", \"Streams\": 4752181, \"Artist\": \"Ufo361\", \"Artist Followers\": 1700759.0, \"Song ID\": \"7IxGslFZA5QhgXbUsDmcjf\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-03-13\", \"Weeks Charted\": \"2020-03-13--2020-03-20\", \"Popularity\": 53.0, \"Danceability\": 0.826, \"Energy\": 0.368, \"Loudness\": -12.761, \"Speechiness\": 0.133, \"Acousticness\": 0.516, \"Liveness\": 0.0914, \"Tempo\": 127.977, \"Duration (ms)\": 107446.0, \"Valence\": 0.158, \"Chord\": \"G\"}, {\"Index\": 1328, \"Highest Charting Position\": 120, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Liberdade Provis\\u00f3ria - Ao Vivo\", \"Streams\": 4730891, \"Artist\": \"Henrique & Juliano\", \"Artist Followers\": 13312073.0, \"Song ID\": \"3Ghyp3X5Ua9ypHnBIgOObI\", \"Genre\": \"['sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-03-13--2020-03-20\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 58.0, \"Danceability\": 0.668, \"Energy\": 0.684, \"Loudness\": -5.937, \"Speechiness\": 0.0527, \"Acousticness\": 0.627, \"Liveness\": 0.923, \"Tempo\": 108.138, \"Duration (ms)\": 187986.0, \"Valence\": 0.7, \"Chord\": \"C#/Db\"}, {\"Index\": 1329, \"Highest Charting Position\": 60, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"POP\", \"Streams\": 10484727, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"1jDbQz6tr52WgScCTXMnaN\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 58.0, \"Danceability\": 0.741, \"Energy\": 0.599, \"Loudness\": -6.672, \"Speechiness\": 0.419, \"Acousticness\": 0.00961, \"Liveness\": 0.785, \"Tempo\": 139.891, \"Duration (ms)\": 227474.0, \"Valence\": 0.276, \"Chord\": \"C#/Db\"}, {\"Index\": 1330, \"Highest Charting Position\": 61, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Celebration Station\", \"Streams\": 10396969, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"25B5fGr9K0VdZJiRFsnMO4\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 61.0, \"Danceability\": 0.748, \"Energy\": 0.771, \"Loudness\": -4.156, \"Speechiness\": 0.15, \"Acousticness\": 0.101, \"Liveness\": 0.135, \"Tempo\": 142.086, \"Duration (ms)\": 195058.0, \"Valence\": 0.792, \"Chord\": \"F#/Gb\"}, {\"Index\": 1331, \"Highest Charting Position\": 64, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Bigger Than Life\", \"Streams\": 9974143, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2oHDJHNondITqbl8xZ9vPn\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 62.0, \"Danceability\": 0.776, \"Energy\": 0.752, \"Loudness\": -4.711, \"Speechiness\": 0.193, \"Acousticness\": 0.325, \"Liveness\": 0.33, \"Tempo\": 140.013, \"Duration (ms)\": 192705.0, \"Valence\": 0.716, \"Chord\": \"G#/Ab\"}, {\"Index\": 1332, \"Highest Charting Position\": 68, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Venetia\", \"Streams\": 9824605, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"3BYIzNZ3t9lRQCACXSMLrT\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 63.0, \"Danceability\": 0.775, \"Energy\": 0.757, \"Loudness\": -4.139, \"Speechiness\": 0.175, \"Acousticness\": 0.162, \"Liveness\": 0.148, \"Tempo\": 142.933, \"Duration (ms)\": 188800.0, \"Valence\": 0.562, \"Chord\": \"A\"}, {\"Index\": 1333, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"You Better Move\", \"Streams\": 9533898, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"6YAxCn4juTWn5hWl2hzHGw\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 60.0, \"Danceability\": 0.842, \"Energy\": 0.556, \"Loudness\": -6.793, \"Speechiness\": 0.442, \"Acousticness\": 0.159, \"Liveness\": 0.204, \"Tempo\": 118.836, \"Duration (ms)\": 196639.0, \"Valence\": 0.306, \"Chord\": \"G#/Ab\"}, {\"Index\": 1334, \"Highest Charting Position\": 93, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Chrome Heart Tags\", \"Streams\": 8219307, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"46mT9NR7N9Zf5MolcrBgE3\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 57.0, \"Danceability\": 0.702, \"Energy\": 0.768, \"Loudness\": -4.055, \"Speechiness\": 0.0669, \"Acousticness\": 0.541, \"Liveness\": 0.105, \"Tempo\": 70.056, \"Duration (ms)\": 212821.0, \"Valence\": 0.574, \"Chord\": \"C\"}, {\"Index\": 1335, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Bust Me\", \"Streams\": 7828045, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"4wBcaYqLPm7EtDVoJQORU4\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 57.0, \"Danceability\": 0.734, \"Energy\": 0.703, \"Loudness\": -6.256, \"Speechiness\": 0.355, \"Acousticness\": 0.237, \"Liveness\": 0.413, \"Tempo\": 151.923, \"Duration (ms)\": 194452.0, \"Valence\": 0.608, \"Chord\": \"B\"}, {\"Index\": 1336, \"Highest Charting Position\": 46, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Ren\\u00e9\", \"Streams\": 7240117, \"Artist\": \"Residente\", \"Artist Followers\": 878491.0, \"Song ID\": \"6gm12xlADJwiBbHIKBXzGW\", \"Genre\": \"['venezuelan hip hop']\", \"Release Date\": \"2020-02-27\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 65.0, \"Danceability\": 0.486, \"Energy\": 0.388, \"Loudness\": -9.326, \"Speechiness\": 0.126, \"Acousticness\": 0.435, \"Liveness\": 0.196, \"Tempo\": 90.471, \"Duration (ms)\": 457592.0, \"Valence\": 0.467, \"Chord\": \"C\"}, {\"Index\": 1337, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Secure The Bag\", \"Streams\": 7053947, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"7gHZGXSJzM29WA384suYY2\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 57.0, \"Danceability\": 0.803, \"Energy\": 0.719, \"Loudness\": -4.485, \"Speechiness\": 0.392, \"Acousticness\": 0.344, \"Liveness\": 0.425, \"Tempo\": 129.945, \"Duration (ms)\": 238425.0, \"Valence\": 0.549, \"Chord\": \"C\"}, {\"Index\": 1338, \"Highest Charting Position\": 140, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Urgency (feat. Syd)\", \"Streams\": 6224412, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"5KlPy74NOEAt8jC3FYURnQ\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 53.0, \"Danceability\": 0.619, \"Energy\": 0.784, \"Loudness\": -6.11, \"Speechiness\": 0.123, \"Acousticness\": 0.0326, \"Liveness\": 0.315, \"Tempo\": 156.035, \"Duration (ms)\": 181161.0, \"Valence\": 0.471, \"Chord\": \"C#/Db\"}, {\"Index\": 1339, \"Highest Charting Position\": 34, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"ON (Feat. Sia)\", \"Streams\": 6219276, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3IB5qOeMayvpOdHxYCL5tZ\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 64.0, \"Danceability\": 0.591, \"Energy\": 0.848, \"Loudness\": -4.397, \"Speechiness\": 0.0828, \"Acousticness\": 0.137, \"Liveness\": 0.372, \"Tempo\": 105.922, \"Duration (ms)\": 246816.0, \"Valence\": 0.386, \"Chord\": \"A\"}, {\"Index\": 1340, \"Highest Charting Position\": 99, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"P FKN R\", \"Streams\": 6041127, \"Artist\": \"Bad Bunny, Kendo Kaponi, Arcangel\", \"Artist Followers\": 36177712.0, \"Song ID\": \"0fgsKar6uBO08vzHXkTjWi\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 66.0, \"Danceability\": 0.82, \"Energy\": 0.635, \"Loudness\": -5.749, \"Speechiness\": 0.0772, \"Acousticness\": 0.409, \"Liveness\": 0.244, \"Tempo\": 101.024, \"Duration (ms)\": 258280.0, \"Valence\": 0.528, \"Chord\": \"F\"}, {\"Index\": 1341, \"Highest Charting Position\": 108, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Modern Loneliness\", \"Streams\": 6020508, \"Artist\": \"Lauv\", \"Artist Followers\": 4442273.0, \"Song ID\": \"1eyek0KJEh2v5HQ9uQSybb\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 68.0, \"Danceability\": 0.702, \"Energy\": 0.508, \"Loudness\": -7.105, \"Speechiness\": 0.035, \"Acousticness\": 0.144, \"Liveness\": 0.108, \"Tempo\": 82.008, \"Duration (ms)\": 252337.0, \"Valence\": 0.143, \"Chord\": \"G#/Ab\"}, {\"Index\": 1342, \"Highest Charting Position\": 65, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Heatin Up (feat. Gunna)\", \"Streams\": 6004839, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"7KSSdFCBHCfq4KPzz78ghk\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 66.0, \"Danceability\": 0.788, \"Energy\": 0.436, \"Loudness\": -9.435, \"Speechiness\": 0.364, \"Acousticness\": 0.0611, \"Liveness\": 0.0979, \"Tempo\": 129.847, \"Duration (ms)\": 177314.0, \"Valence\": 0.341, \"Chord\": \"C#/Db\"}, {\"Index\": 1343, \"Highest Charting Position\": 159, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"SKYBOX\", \"Streams\": 5846484, \"Artist\": \"Gunna\", \"Artist Followers\": 3337982.0, \"Song ID\": \"7GwYENSg87oERcW0Wacd6m\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 59.0, \"Danceability\": 0.779, \"Energy\": 0.707, \"Loudness\": -6.527, \"Speechiness\": 0.16, \"Acousticness\": 0.0991, \"Liveness\": 0.0934, \"Tempo\": 140.894, \"Duration (ms)\": 178097.0, \"Valence\": 0.343, \"Chord\": \"C#/Db\"}, {\"Index\": 1344, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"Young & Alive\", \"Streams\": 5578323, \"Artist\": \"Bazzi\", \"Artist Followers\": 4421378.0, \"Song ID\": \"5RsKelNxucrDxgMbZ3vd3W\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-05\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 71.0, \"Danceability\": 0.716, \"Energy\": 0.563, \"Loudness\": -5.486, \"Speechiness\": 0.0425, \"Acousticness\": 0.326, \"Liveness\": 0.119, \"Tempo\": 86.005, \"Duration (ms)\": 160465.0, \"Valence\": 0.495, \"Chord\": \"D#/Eb\"}, {\"Index\": 1345, \"Highest Charting Position\": 169, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"i'm so tired...\", \"Streams\": 5547770, \"Artist\": \"Lauv, Troye Sivan\", \"Artist Followers\": 4442273.0, \"Song ID\": \"4vjpLMyL3ZO6aphdYr8XYw\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-01-03--2020-01-10\", \"Popularity\": 77.0, \"Danceability\": 0.599, \"Energy\": 0.733, \"Loudness\": -7.058, \"Speechiness\": 0.203, \"Acousticness\": 0.176, \"Liveness\": 0.242, \"Tempo\": 102.211, \"Duration (ms)\": 162583.0, \"Valence\": 0.534, \"Chord\": \"B\"}, {\"Index\": 1346, \"Highest Charting Position\": 53, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Numbers (feat. Roddy Ricch, Gunna and London On Da Track)\", \"Streams\": 5487069, \"Artist\": \"A Boogie Wit da Hoodie\", \"Artist Followers\": 5865895.0, \"Song ID\": \"733c1CWmIGymoQXdp7Us88\", \"Genre\": \"['melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\", \"Popularity\": 68.0, \"Danceability\": 0.819, \"Energy\": 0.654, \"Loudness\": -6.665, \"Speechiness\": 0.136, \"Acousticness\": 0.517, \"Liveness\": 0.0996, \"Tempo\": 133.503, \"Duration (ms)\": 188563.0, \"Valence\": 0.455, \"Chord\": \"B\"}, {\"Index\": 1347, \"Highest Charting Position\": 105, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Girl\", \"Streams\": 5434180, \"Artist\": \"Myke Towers\", \"Artist Followers\": 6161098.0, \"Song ID\": \"43NqTeL8pgBxKHPMiJKUP5\", \"Genre\": \"['trap latino']\", \"Release Date\": \"2020-01-24\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 72.0, \"Danceability\": 0.733, \"Energy\": 0.708, \"Loudness\": -4.957, \"Speechiness\": 0.0937, \"Acousticness\": 0.0325, \"Liveness\": 0.324, \"Tempo\": 93.021, \"Duration (ms)\": 186427.0, \"Valence\": 0.694, \"Chord\": \"F#/Gb\"}, {\"Index\": 1348, \"Highest Charting Position\": 104, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Puesto Pa' Guerrial\", \"Streams\": 5359969, \"Artist\": \"Bad Bunny, Myke Towers\", \"Artist Followers\": 36177712.0, \"Song ID\": \"5gCg2qMPzKkW4jS4dBKdDs\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-02-29\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\", \"Popularity\": 64.0, \"Danceability\": 0.867, \"Energy\": 0.686, \"Loudness\": -5.342, \"Speechiness\": 0.221, \"Acousticness\": 0.311, \"Liveness\": 0.1, \"Tempo\": 139.968, \"Duration (ms)\": 190207.0, \"Valence\": 0.658, \"Chord\": \"E\"}, {\"Index\": 1349, \"Highest Charting Position\": 114, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Definitivamente\", \"Streams\": 5325447, \"Artist\": \"Daddy Yankee, Sech\", \"Artist Followers\": 23936368.0, \"Song ID\": \"113PlnpZbHd3WIqeYjhZWv\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 66.0, \"Danceability\": 0.813, \"Energy\": 0.764, \"Loudness\": -3.39, \"Speechiness\": 0.105, \"Acousticness\": 0.586, \"Liveness\": 0.253, \"Tempo\": 100.047, \"Duration (ms)\": 217773.0, \"Valence\": 0.429, \"Chord\": \"G#/Ab\"}, {\"Index\": 1350, \"Highest Charting Position\": 41, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"South of the Border (feat. Camila Cabello & Cardi B)\", \"Streams\": 5315827, \"Artist\": \"Ed Sheeran\", \"Artist Followers\": 83337783.0, \"Song ID\": \"4vUmTMuQqjdnvlZmAH61Qk\", \"Genre\": \"['pop', 'uk pop']\", \"Release Date\": \"2019-07-12\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.857, \"Energy\": 0.621, \"Loudness\": -6.376, \"Speechiness\": 0.0825, \"Acousticness\": 0.148, \"Liveness\": 0.0865, \"Tempo\": 97.989, \"Duration (ms)\": 204467.0, \"Valence\": 0.668, \"Chord\": \"A\"}, {\"Index\": 1351, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"I Fall Apart\", \"Streams\": 5251918, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"75ZvA4QfFiZvzhj2xkaWAh\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2016-12-09\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 80.0, \"Danceability\": 0.556, \"Energy\": 0.538, \"Loudness\": -5.408, \"Speechiness\": 0.0382, \"Acousticness\": 0.0689, \"Liveness\": 0.196, \"Tempo\": 143.95, \"Duration (ms)\": 223347.0, \"Valence\": 0.291, \"Chord\": \"G#/Ab\"}, {\"Index\": 1352, \"Highest Charting Position\": 191, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-03-06--2020-03-13\", \"Song Name\": \"fuck, i'm lonely (with Anne-Marie)\", \"Streams\": 5226991, \"Artist\": \"Lauv\", \"Artist Followers\": 4442273.0, \"Song ID\": \"09PGubKAMryhOWv1LHpCYz\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\", \"Popularity\": 74.0, \"Danceability\": 0.806, \"Energy\": 0.558, \"Loudness\": -6.46, \"Speechiness\": 0.0683, \"Acousticness\": 0.482, \"Liveness\": 0.0618, \"Tempo\": 95.016, \"Duration (ms)\": 198973.0, \"Valence\": 0.678, \"Chord\": \"A\"}, {\"Index\": 1353, \"Highest Charting Position\": 78, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Aventura\", \"Streams\": 5206102, \"Artist\": \"Lunay, Ozuna, Anuel AA\", \"Artist Followers\": 4963516.0, \"Song ID\": \"37zdqI4r1gswIzczSBkRon\", \"Genre\": \"['latin', 'latin pop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-10-25\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.729, \"Energy\": 0.726, \"Loudness\": -3.208, \"Speechiness\": 0.0422, \"Acousticness\": 0.223, \"Liveness\": 0.101, \"Tempo\": 92.025, \"Duration (ms)\": 217130.0, \"Valence\": 0.876, \"Chord\": \"F\"}, {\"Index\": 1354, \"Highest Charting Position\": 12, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Rare\", \"Streams\": 5195842, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"7HMmFQsKsljwTw8bS7lu19\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 68.0, \"Danceability\": 0.838, \"Energy\": 0.545, \"Loudness\": -6.713, \"Speechiness\": 0.0706, \"Acousticness\": 0.208, \"Liveness\": 0.103, \"Tempo\": 114.998, \"Duration (ms)\": 220590.0, \"Valence\": 0.631, \"Chord\": \"F\"}, {\"Index\": 1355, \"Highest Charting Position\": 69, \"Number of Times Charted\": 11, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"VIBEZ\", \"Streams\": 5121486, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"0fySG6A6qLE8IvDpayb5bM\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.768, \"Energy\": 0.652, \"Loudness\": -2.708, \"Speechiness\": 0.307, \"Acousticness\": 0.113, \"Liveness\": 0.107, \"Tempo\": 154.187, \"Duration (ms)\": 144935.0, \"Valence\": 0.777, \"Chord\": \"C#/Db\"}, {\"Index\": 1356, \"Highest Charting Position\": 69, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Mean It\", \"Streams\": 5110064, \"Artist\": \"Lauv, LANY\", \"Artist Followers\": 4442273.0, \"Song ID\": \"3uc8AGNL0KbvISIrjnfRvN\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-06\", \"Weeks Charted\": \"2020-03-06--2020-03-13\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.746, \"Energy\": 0.45, \"Loudness\": -8.543, \"Speechiness\": 0.0872, \"Acousticness\": 0.0407, \"Liveness\": 0.172, \"Tempo\": 95.998, \"Duration (ms)\": 232853.0, \"Valence\": 0.336, \"Chord\": \"G\"}, {\"Index\": 1357, \"Highest Charting Position\": 49, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"That Way\", \"Streams\": 12059592, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"5raTDhlbxFDnpn89bxArdH\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2020-03-01\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 67.0, \"Danceability\": 0.719, \"Energy\": 0.611, \"Loudness\": -5.01, \"Speechiness\": 0.0403, \"Acousticness\": 0.0582, \"Liveness\": 0.155, \"Tempo\": 129.962, \"Duration (ms)\": 212354.0, \"Valence\": 0.489, \"Chord\": \"G\"}, {\"Index\": 1358, \"Highest Charting Position\": 106, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Live Off My Closet (feat. Future)\", \"Streams\": 7410327, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"6AyWdCtEn1DdxjnxPeojR2\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 59.0, \"Danceability\": 0.807, \"Energy\": 0.678, \"Loudness\": -3.244, \"Speechiness\": 0.177, \"Acousticness\": 0.0345, \"Liveness\": 0.0986, \"Tempo\": 147.004, \"Duration (ms)\": 173061.0, \"Valence\": 0.21, \"Chord\": \"F#/Gb\"}, {\"Index\": 1359, \"Highest Charting Position\": 123, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Commercial (feat. Lil Uzi Vert)\", \"Streams\": 6540577, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"3tDqEKKUs6gf8zMvSuLyLA\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-02-28\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 67.0, \"Danceability\": 0.892, \"Energy\": 0.486, \"Loudness\": -8.637, \"Speechiness\": 0.384, \"Acousticness\": 0.048, \"Liveness\": 0.146, \"Tempo\": 120.998, \"Duration (ms)\": 214215.0, \"Valence\": 0.535, \"Chord\": \"B\"}, {\"Index\": 1360, \"Highest Charting Position\": 75, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Sum 2 Prove\", \"Streams\": 6497610, \"Artist\": \"Lil Baby\", \"Artist Followers\": 7816213.0, \"Song ID\": \"2u3EyuCqqV31woqGvO9LBz\", \"Genre\": \"['atl hip hop', 'atl trap', 'rap', 'trap']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 71.0, \"Danceability\": 0.823, \"Energy\": 0.552, \"Loudness\": -7.57, \"Speechiness\": 0.324, \"Acousticness\": 0.0174, \"Liveness\": 0.122, \"Tempo\": 124.038, \"Duration (ms)\": 205760.0, \"Valence\": 0.418, \"Chord\": \"E\"}, {\"Index\": 1361, \"Highest Charting Position\": 47, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Filter\", \"Streams\": 5913946, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"0ono6UCNVZ1XqOm6j78Blu\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 79.0, \"Danceability\": 0.781, \"Energy\": 0.762, \"Loudness\": -5.188, \"Speechiness\": 0.0626, \"Acousticness\": 0.0222, \"Liveness\": 0.121, \"Tempo\": 110.042, \"Duration (ms)\": 180221.0, \"Valence\": 0.86, \"Chord\": \"A#/Bb\"}, {\"Index\": 1362, \"Highest Charting Position\": 151, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Matrix\", \"Streams\": 5724739, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"7ygVaACDENw4PgLbN1awFE\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-02-24\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 55.0, \"Danceability\": 0.789, \"Energy\": 0.509, \"Loudness\": -8.766, \"Speechiness\": 0.291, \"Acousticness\": 0.768, \"Liveness\": 0.272, \"Tempo\": 114.957, \"Duration (ms)\": 183793.0, \"Valence\": 0.418, \"Chord\": \"A\"}, {\"Index\": 1363, \"Highest Charting Position\": 91, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Bellaquita - Remix\", \"Streams\": 5676621, \"Artist\": \"Dalex, Lenny Tav\\u00e1rez, Anitta, Natti Natasha, Farruko, Justin Quiles\", \"Artist Followers\": 3600989.0, \"Song ID\": \"1Xnn1TPyr5h0hpRAT4B4EA\", \"Genre\": \"['latin', 'r&b en espanol', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.795, \"Energy\": 0.715, \"Loudness\": -3.582, \"Speechiness\": 0.0838, \"Acousticness\": 0.141, \"Liveness\": 0.179, \"Tempo\": 165.941, \"Duration (ms)\": 304733.0, \"Valence\": 0.758, \"Chord\": \"C#/Db\"}, {\"Index\": 1364, \"Highest Charting Position\": 139, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Infeliz\", \"Streams\": 5490386, \"Artist\": \"Arcangel, Bad Bunny\", \"Artist Followers\": 6671084.0, \"Song ID\": \"4z6wo6PJG4Fve45OXK6D9m\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-12-20\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 72.0, \"Danceability\": 0.713, \"Energy\": 0.798, \"Loudness\": -3.147, \"Speechiness\": 0.219, \"Acousticness\": 0.366, \"Liveness\": 0.246, \"Tempo\": 176.073, \"Duration (ms)\": 221103.0, \"Valence\": 0.721, \"Chord\": \"C#/Db\"}, {\"Index\": 1365, \"Highest Charting Position\": 60, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Que Tire Pa Lante\", \"Streams\": 5436773, \"Artist\": \"Daddy Yankee\", \"Artist Followers\": 23936368.0, \"Song ID\": \"6RyaV7owmVU6fzEPE17sF1\", \"Genre\": \"['latin', 'latin hip hop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-10-18\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.658, \"Energy\": 0.901, \"Loudness\": -2.814, \"Speechiness\": 0.0357, \"Acousticness\": 0.0478, \"Liveness\": 0.12, \"Tempo\": 93.979, \"Duration (ms)\": 210520.0, \"Valence\": 0.708, \"Chord\": \"G\"}, {\"Index\": 1366, \"Highest Charting Position\": 32, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Futsal Shuffle 2020\", \"Streams\": 5386512, \"Artist\": \"Lil Uzi Vert\", \"Artist Followers\": 11821805.0, \"Song ID\": \"2Ec33AVlkTTq8BHFgBTdQs\", \"Genre\": \"['melodic rap', 'philly rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-12\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.881, \"Energy\": 0.457, \"Loudness\": -8.191, \"Speechiness\": 0.156, \"Acousticness\": 0.0327, \"Liveness\": 0.231, \"Tempo\": 136.97, \"Duration (ms)\": 198913.0, \"Valence\": 0.296, \"Chord\": \"G\"}, {\"Index\": 1367, \"Highest Charting Position\": 123, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"GOODMORNINGTOKYO!\", \"Streams\": 5286044, \"Artist\": \"TOKYO\\u2019S REVENGE\", \"Artist Followers\": 313480.0, \"Song ID\": \"0Q2n5yzl2XRqYbV77tZNYp\", \"Genre\": \"['meme rap', 'sad rap', 'vapor trap', 'viral rap']\", \"Release Date\": \"2019-10-18\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 74.0, \"Danceability\": 0.907, \"Energy\": 0.539, \"Loudness\": -7.782, \"Speechiness\": 0.36, \"Acousticness\": 0.0408, \"Liveness\": 0.253, \"Tempo\": 124.918, \"Duration (ms)\": 150115.0, \"Valence\": 0.664, \"Chord\": \"E\"}, {\"Index\": 1368, \"Highest Charting Position\": 58, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Own It (feat. Ed Sheeran & Burna Boy)\", \"Streams\": 5273046, \"Artist\": \"Stormzy\", \"Artist Followers\": 2317758.0, \"Song ID\": \"4QPEwDdOMhY7rNS05mTyMR\", \"Genre\": \"['grime', 'uk hip hop']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.817, \"Energy\": 0.781, \"Loudness\": -4.178, \"Speechiness\": 0.112, \"Acousticness\": 0.00838, \"Liveness\": 0.123, \"Tempo\": 104.0, \"Duration (ms)\": 216707.0, \"Valence\": 0.359, \"Chord\": \"G\"}, {\"Index\": 1369, \"Highest Charting Position\": 128, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Life Is Good (feat. Drake, DaBaby & Lil Baby) - Remix\", \"Streams\": 5260351, \"Artist\": \"Future\", \"Artist Followers\": 10491105.0, \"Song ID\": \"4iiWcajF1fEUpwcUewc464\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2020-02-15\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 61.0, \"Danceability\": 0.81, \"Energy\": 0.566, \"Loudness\": -8.33, \"Speechiness\": 0.433, \"Acousticness\": 0.107, \"Liveness\": 0.122, \"Tempo\": 142.069, \"Duration (ms)\": 315346.0, \"Valence\": 0.582, \"Chord\": \"F\"}, {\"Index\": 1370, \"Highest Charting Position\": 58, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"My Time\", \"Streams\": 5212053, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4vTgx6h4seHvkuFh84JXYP\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\", \"Popularity\": 74.0, \"Danceability\": 0.674, \"Energy\": 0.64, \"Loudness\": -5.139, \"Speechiness\": 0.0339, \"Acousticness\": 0.151, \"Liveness\": 0.0925, \"Tempo\": 99.908, \"Duration (ms)\": 234458.0, \"Valence\": 0.664, \"Chord\": \"C\"}, {\"Index\": 1371, \"Highest Charting Position\": 184, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"100k Cash\", \"Streams\": 5192813, \"Artist\": \"Capital Bra, Samra\", \"Artist Followers\": 4093115.0, \"Song ID\": \"033if6Adj8fwBYsQzHOfQ8\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-02-27\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 52.0, \"Danceability\": 0.701, \"Energy\": 0.714, \"Loudness\": -5.906, \"Speechiness\": 0.524, \"Acousticness\": 0.289, \"Liveness\": 0.0883, \"Tempo\": 86.91, \"Duration (ms)\": 173353.0, \"Valence\": 0.604, \"Chord\": \"A#/Bb\"}, {\"Index\": 1372, \"Highest Charting Position\": 185, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-28--2020-03-06\", \"Song Name\": \"Drown (feat. Clinton Kane)\", \"Streams\": 5186141, \"Artist\": \"Martin Garrix\", \"Artist Followers\": 14921269.0, \"Song ID\": \"4RVtBlHFKj51Ipvpfv5ER4\", \"Genre\": \"['dance pop', 'dutch edm', 'edm', 'pop', 'pop dance', 'progressive house', 'tropical house']\", \"Release Date\": \"2020-02-27\", \"Weeks Charted\": \"2020-02-28--2020-03-06\", \"Popularity\": 74.0, \"Danceability\": 0.573, \"Energy\": 0.739, \"Loudness\": -5.455, \"Speechiness\": 0.0581, \"Acousticness\": 0.212, \"Liveness\": 0.175, \"Tempo\": 120.077, \"Duration (ms)\": 174062.0, \"Valence\": 0.363, \"Chord\": \"A\"}, {\"Index\": 1373, \"Highest Charting Position\": 103, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"me & ur ghost\", \"Streams\": 5184069, \"Artist\": \"blackbear\", \"Artist Followers\": 4272745.0, \"Song ID\": \"38KsRHYE10bG0paU78gL9r\", \"Genre\": \"['electropop', 'pop', 'pop rap']\", \"Release Date\": \"2020-08-21\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 71.0, \"Danceability\": 0.742, \"Energy\": 0.679, \"Loudness\": -4.594, \"Speechiness\": 0.0259, \"Acousticness\": 0.0488, \"Liveness\": 0.0754, \"Tempo\": 100.041, \"Duration (ms)\": 201398.0, \"Valence\": 0.856, \"Chord\": \"G\"}, {\"Index\": 1374, \"Highest Charting Position\": 146, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"QUE PRETENDES\", \"Streams\": 5141047, \"Artist\": \"J Balvin, Bad Bunny\", \"Artist Followers\": 29067437.0, \"Song ID\": \"25ZAibhr3bdlMCLmubZDVt\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-06-28\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.639, \"Energy\": 0.791, \"Loudness\": -4.443, \"Speechiness\": 0.253, \"Acousticness\": 0.0275, \"Liveness\": 0.362, \"Tempo\": 92.603, \"Duration (ms)\": 222347.0, \"Valence\": 0.939, \"Chord\": \"A#/Bb\"}, {\"Index\": 1375, \"Highest Charting Position\": 140, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"You Need To Calm Down\", \"Streams\": 5115153, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"6RRNNciQGZEXnqk8SQ9yv5\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 78.0, \"Danceability\": 0.771, \"Energy\": 0.671, \"Loudness\": -5.617, \"Speechiness\": 0.0553, \"Acousticness\": 0.00929, \"Liveness\": 0.0637, \"Tempo\": 85.026, \"Duration (ms)\": 171360.0, \"Valence\": 0.714, \"Chord\": \"D\"}, {\"Index\": 1376, \"Highest Charting Position\": 90, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Quizas\", \"Streams\": 5112244, \"Artist\": \"Rich Music LTD, Sech, Dalex, Justin Quiles, Lenny Tav\\u00e1rez, Feid, Wisin, Zion\", \"Artist Followers\": 206225.0, \"Song ID\": \"5Id5B3dxJZhPcV9GzgYZZe\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-10-11\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.727, \"Energy\": 0.815, \"Loudness\": -2.454, \"Speechiness\": 0.153, \"Acousticness\": 0.0258, \"Liveness\": 0.231, \"Tempo\": 176.075, \"Duration (ms)\": 216067.0, \"Valence\": 0.677, \"Chord\": \"D#/Eb\"}, {\"Index\": 1377, \"Highest Charting Position\": 106, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Soltera - Remix\", \"Streams\": 5078459, \"Artist\": \"Lunay, Daddy Yankee, Bad Bunny\", \"Artist Followers\": 4963516.0, \"Song ID\": \"1c0hsvHLELX6y8qymnpLKL\", \"Genre\": \"['latin', 'latin pop', 'reggaeton', 'reggaeton flow', 'trap latino']\", \"Release Date\": \"2019-05-10\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.795, \"Energy\": 0.783, \"Loudness\": -4.271, \"Speechiness\": 0.0432, \"Acousticness\": 0.361, \"Liveness\": 0.437, \"Tempo\": 92.01, \"Duration (ms)\": 266087.0, \"Valence\": 0.799, \"Chord\": \"F\"}, {\"Index\": 1378, \"Highest Charting Position\": 46, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Trampoline (with ZAYN)\", \"Streams\": 5075520, \"Artist\": \"SHAED\", \"Artist Followers\": 139434.0, \"Song ID\": \"1iQDltZqI7BXnHrFy4Qo1k\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-09-26\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 73.0, \"Danceability\": 0.619, \"Energy\": 0.459, \"Loudness\": -5.782, \"Speechiness\": 0.0334, \"Acousticness\": 0.56, \"Liveness\": 0.137, \"Tempo\": 126.803, \"Duration (ms)\": 184280.0, \"Valence\": 0.498, \"Chord\": \"G\"}, {\"Index\": 1379, \"Highest Charting Position\": 82, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Truth Hurts\", \"Streams\": 5024683, \"Artist\": \"Lizzo\", \"Artist Followers\": 3991674.0, \"Song ID\": \"3HWzoMvoF3TQfYg4UPszDq\", \"Genre\": \"['dance pop', 'escape room', 'minnesota hip hop', 'pop', 'pop rap', 'post-teen pop', 'trap queen']\", \"Release Date\": \"2019-04-19\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.715, \"Energy\": 0.624, \"Loudness\": -3.046, \"Speechiness\": 0.114, \"Acousticness\": 0.11, \"Liveness\": 0.123, \"Tempo\": 158.087, \"Duration (ms)\": 173325.0, \"Valence\": 0.412, \"Chord\": \"E\"}, {\"Index\": 1380, \"Highest Charting Position\": 91, \"Number of Times Charted\": 10, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"bury a friend\", \"Streams\": 5020303, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"7p6ZK1vOxKELFwlDfwkJCp\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-02-28--2020-03-06\\n2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 1.0, \"Danceability\": 0.887, \"Energy\": 0.388, \"Loudness\": -14.505, \"Speechiness\": 0.349, \"Acousticness\": 0.739, \"Liveness\": 0.106, \"Tempo\": 120.035, \"Duration (ms)\": 193143.0, \"Valence\": 0.205, \"Chord\": \"G#/Ab\"}, {\"Index\": 1381, \"Highest Charting Position\": 54, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Louder than bombs\", \"Streams\": 10016907, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3op7HNwLli54MBjFGzIlZO\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.643, \"Energy\": 0.667, \"Loudness\": -6.993, \"Speechiness\": 0.152, \"Acousticness\": 0.0433, \"Liveness\": 0.0904, \"Tempo\": 145.999, \"Duration (ms)\": 217404.0, \"Valence\": 0.485, \"Chord\": \"C\"}, {\"Index\": 1382, \"Highest Charting Position\": 56, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"UGH!\", \"Streams\": 9991177, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"1aKuG1GG76xPLUkjBbQo3W\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.72, \"Energy\": 0.824, \"Loudness\": -5.086, \"Speechiness\": 0.128, \"Acousticness\": 0.0394, \"Liveness\": 0.0509, \"Tempo\": 165.998, \"Duration (ms)\": 225012.0, \"Valence\": 0.333, \"Chord\": \"A#/Bb\"}, {\"Index\": 1383, \"Highest Charting Position\": 67, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"00:00 (Zero O\\u2019Clock)\", \"Streams\": 9372219, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4AlihYDqxXshKhvh5tnMfP\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.566, \"Energy\": 0.548, \"Loudness\": -6.456, \"Speechiness\": 0.0579, \"Acousticness\": 0.0802, \"Liveness\": 0.11, \"Tempo\": 157.999, \"Duration (ms)\": 250296.0, \"Valence\": 0.196, \"Chord\": \"C#/Db\"}, {\"Index\": 1384, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Friends\", \"Streams\": 8822365, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"7w05lsU2VLSeiT8Nukrv5M\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.55, \"Energy\": 0.747, \"Loudness\": -5.211, \"Speechiness\": 0.0407, \"Acousticness\": 0.0668, \"Liveness\": 0.0536, \"Tempo\": 79.98, \"Duration (ms)\": 199339.0, \"Valence\": 0.648, \"Chord\": \"C#/Db\"}, {\"Index\": 1385, \"Highest Charting Position\": 75, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"We are Bulletproof : the Eternal\", \"Streams\": 8516710, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"44WLOqH7QayQOQdeUHeKUK\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.526, \"Energy\": 0.575, \"Loudness\": -5.215, \"Speechiness\": 0.0309, \"Acousticness\": 0.225, \"Liveness\": 0.108, \"Tempo\": 84.047, \"Duration (ms)\": 261543.0, \"Valence\": 0.19, \"Chord\": \"A\"}, {\"Index\": 1386, \"Highest Charting Position\": 79, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Inner Child\", \"Streams\": 8312399, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"4BKOjYosPhw334moS3wlbO\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 71.0, \"Danceability\": 0.589, \"Energy\": 0.696, \"Loudness\": -7.981, \"Speechiness\": 0.0725, \"Acousticness\": 0.017, \"Liveness\": 0.0808, \"Tempo\": 134.953, \"Duration (ms)\": 233266.0, \"Valence\": 0.332, \"Chord\": \"B\"}, {\"Index\": 1387, \"Highest Charting Position\": 84, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Moon\", \"Streams\": 7850129, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"1xfXXujIlLZAx5wpu46Nyk\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 72.0, \"Danceability\": 0.703, \"Energy\": 0.646, \"Loudness\": -6.658, \"Speechiness\": 0.0596, \"Acousticness\": 0.0104, \"Liveness\": 0.191, \"Tempo\": 141.87, \"Duration (ms)\": 208590.0, \"Valence\": 0.64, \"Chord\": \"F#/Gb\"}, {\"Index\": 1388, \"Highest Charting Position\": 104, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Outro : Ego\", \"Streams\": 6857808, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"3r9FFjLrAIQjoR8pSHVPC9\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 69.0, \"Danceability\": 0.808, \"Energy\": 0.903, \"Loudness\": -3.106, \"Speechiness\": 0.0958, \"Acousticness\": 0.0121, \"Liveness\": 0.0993, \"Tempo\": 116.988, \"Duration (ms)\": 196199.0, \"Valence\": 0.473, \"Chord\": \"C\"}, {\"Index\": 1389, \"Highest Charting Position\": 109, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Interlude : Shadow\", \"Streams\": 6655856, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"2Nib4r0saYQf2pUV4RFDhl\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 68.0, \"Danceability\": 0.385, \"Energy\": 0.798, \"Loudness\": -6.439, \"Speechiness\": 0.483, \"Acousticness\": 0.115, \"Liveness\": 0.181, \"Tempo\": 149.756, \"Duration (ms)\": 259821.0, \"Valence\": 0.141, \"Chord\": \"A\"}, {\"Index\": 1390, \"Highest Charting Position\": 120, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Respect\", \"Streams\": 6373954, \"Artist\": \"BTS\", \"Artist Followers\": 37151476.0, \"Song ID\": \"37TSJmYKLxXmx8OehFpqMN\", \"Genre\": \"['k-pop', 'k-pop boy group']\", \"Release Date\": \"2020-02-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 67.0, \"Danceability\": 0.661, \"Energy\": 0.84, \"Loudness\": -4.805, \"Speechiness\": 0.116, \"Acousticness\": 0.00485, \"Liveness\": 0.287, \"Tempo\": 91.457, \"Duration (ms)\": 237540.0, \"Valence\": 0.524, \"Chord\": \"C\"}, {\"Index\": 1391, \"Highest Charting Position\": 154, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Tudo Ok\", \"Streams\": 5510844, \"Artist\": \"Thiaguinho MT, Mila, JS o M\\u00e3o de Ouro\", \"Artist Followers\": 28017.0, \"Song ID\": \"4HUZBG98TYbxSR9V1V2DWS\", \"Genre\": \"['brega funk', 'funk carioca']\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 57.0, \"Danceability\": 0.814, \"Energy\": 0.755, \"Loudness\": -6.164, \"Speechiness\": 0.0942, \"Acousticness\": 0.239, \"Liveness\": 0.306, \"Tempo\": 79.976, \"Duration (ms)\": 178500.0, \"Valence\": 0.963, \"Chord\": \"B\"}, {\"Index\": 1392, \"Highest Charting Position\": 128, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Perreo en La Luna\", \"Streams\": 5135469, \"Artist\": \"Rich Music LTD, Sech, Dalex, Justin Quiles, Lenny Tav\\u00e1rez, Feid\", \"Artist Followers\": 206225.0, \"Song ID\": \"0RDgqtvOHLwcI6yz9bjsZV\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-10-11\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.711, \"Energy\": 0.757, \"Loudness\": -4.188, \"Speechiness\": 0.29, \"Acousticness\": 0.268, \"Liveness\": 0.367, \"Tempo\": 174.013, \"Duration (ms)\": 218587.0, \"Valence\": 0.724, \"Chord\": \"C#/Db\"}, {\"Index\": 1393, \"Highest Charting Position\": 129, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Lose Yourself - From \\\"8 Mile\\\" Soundtrack\", \"Streams\": 5118004, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5Z01UMMf7V1o0MzF86s6WJ\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2005-12-06\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 75.0, \"Danceability\": 0.692, \"Energy\": 0.744, \"Loudness\": -4.565, \"Speechiness\": 0.257, \"Acousticness\": 0.00868, \"Liveness\": 0.359, \"Tempo\": 171.374, \"Duration (ms)\": 326467.0, \"Valence\": 0.0612, \"Chord\": \"D\"}, {\"Index\": 1394, \"Highest Charting Position\": 118, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"all the good girls go to hell\", \"Streams\": 5074485, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"6IRdLKIyS4p7XNiP8r6rsx\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-03-29\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.726, \"Energy\": 0.444, \"Loudness\": -8.922, \"Speechiness\": 0.372, \"Acousticness\": 0.283, \"Liveness\": 0.177, \"Tempo\": 185.044, \"Duration (ms)\": 168840.0, \"Valence\": 0.569, \"Chord\": \"G#/Ab\"}, {\"Index\": 1395, \"Highest Charting Position\": 155, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"SENTAD\\u00c3O\", \"Streams\": 5013019, \"Artist\": \"PEDRO SAMPAIO, Felipe Original, JS o M\\u00e3o de Ouro\", \"Artist Followers\": 1050520.0, \"Song ID\": \"4lKuzrdZrJuCAedbIslF3A\", \"Genre\": \"['funk carioca']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2019-12-27--2020-01-03\", \"Popularity\": 64.0, \"Danceability\": 0.68, \"Energy\": 0.869, \"Loudness\": -1.94, \"Speechiness\": 0.0589, \"Acousticness\": 0.178, \"Liveness\": 0.223, \"Tempo\": 173.997, \"Duration (ms)\": 143448.0, \"Valence\": 0.924, \"Chord\": \"F#/Gb\"}, {\"Index\": 1396, \"Highest Charting Position\": 182, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Lottery (Renegade)\", \"Streams\": 4994448, \"Artist\": \"K CAMP\", \"Artist Followers\": 1347589.0, \"Song ID\": \"4dZTZbmJBCCofAExHwefda\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'pop r&b', 'pop rap', 'r&b', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 61.0, \"Danceability\": 0.915, \"Energy\": 0.556, \"Loudness\": -8.601, \"Speechiness\": 0.216, \"Acousticness\": 0.0145, \"Liveness\": 0.0733, \"Tempo\": 148.964, \"Duration (ms)\": 170947.0, \"Valence\": 0.67, \"Chord\": \"C#/Db\"}, {\"Index\": 1397, \"Highest Charting Position\": 104, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Si Te Vas\", \"Streams\": 4954292, \"Artist\": \"Sech, Ozuna\", \"Artist Followers\": 8766508.0, \"Song ID\": \"6Y4PDQv4XjYjHLeLmvyOt0\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-09-26\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.73, \"Energy\": 0.644, \"Loudness\": -4.124, \"Speechiness\": 0.132, \"Acousticness\": 0.0933, \"Liveness\": 0.143, \"Tempo\": 174.101, \"Duration (ms)\": 204907.0, \"Valence\": 0.554, \"Chord\": \"C\"}, {\"Index\": 1398, \"Highest Charting Position\": 121, \"Number of Times Charted\": 8, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Que Calor (with J Balvin & El Alfa)\", \"Streams\": 4950254, \"Artist\": \"Major Lazer, Diplo\", \"Artist Followers\": 6223652.0, \"Song ID\": \"3iQGDAAKMrlJarnaYNgnSE\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'moombahton', 'pop', 'pop dance', 'pop rap']\", \"Release Date\": \"2019-12-13\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 29.0, \"Danceability\": 0.873, \"Energy\": 0.656, \"Loudness\": -6.043, \"Speechiness\": 0.068, \"Acousticness\": 0.00477, \"Liveness\": 0.0726, \"Tempo\": 125.982, \"Duration (ms)\": 206811.0, \"Valence\": 0.546, \"Chord\": \"G#/Ab\"}, {\"Index\": 1399, \"Highest Charting Position\": 186, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Rich Rich\", \"Streams\": 4938864, \"Artist\": \"Ufo361\", \"Artist Followers\": 1700759.0, \"Song ID\": \"2QfmSvSMwTXcvlIkU0w1Yk\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 50.0, \"Danceability\": 0.548, \"Energy\": 0.648, \"Loudness\": -4.796, \"Speechiness\": 0.292, \"Acousticness\": 0.0842, \"Liveness\": 0.123, \"Tempo\": 141.937, \"Duration (ms)\": 204319.0, \"Valence\": 0.232, \"Chord\": \"E\"}, {\"Index\": 1400, \"Highest Charting Position\": 86, \"Number of Times Charted\": 9, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Indeciso\", \"Streams\": 4897374, \"Artist\": \"Reik, J Balvin, Lalo Ebratt\", \"Artist Followers\": 1251372.0, \"Song ID\": \"0FnPT2g07W4aXuHjniC1of\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-09\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.738, \"Energy\": 0.748, \"Loudness\": -4.902, \"Speechiness\": 0.0453, \"Acousticness\": 0.182, \"Liveness\": 0.109, \"Tempo\": 94.949, \"Duration (ms)\": 217253.0, \"Valence\": 0.896, \"Chord\": \"C\"}, {\"Index\": 1401, \"Highest Charting Position\": 148, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"i love you\", \"Streams\": 4863910, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"0np7TYPZSum9xTxe9QTr21\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-02-21--2020-02-28\\n2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-03--2020-01-10\", \"Popularity\": 2.0, \"Danceability\": 0.42, \"Energy\": 0.131, \"Loudness\": -18.435, \"Speechiness\": 0.0382, \"Acousticness\": 0.953, \"Liveness\": 0.109, \"Tempo\": 137.421, \"Duration (ms)\": 291796.0, \"Valence\": 0.12, \"Chord\": \"C\"}, {\"Index\": 1402, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-21--2020-02-28\", \"Song Name\": \"Mejor\", \"Streams\": 4851895, \"Artist\": \"Dalex, Sech\", \"Artist Followers\": 3600989.0, \"Song ID\": \"6C1jKbkCUgFws7M0M4oGCB\", \"Genre\": \"['latin', 'r&b en espanol', 'reggaeton', 'trap latino']\", \"Release Date\": \"2020-03-19\", \"Weeks Charted\": \"2020-02-21--2020-02-28\", \"Popularity\": 63.0, \"Danceability\": 0.524, \"Energy\": 0.577, \"Loudness\": -4.501, \"Speechiness\": 0.18, \"Acousticness\": 0.185, \"Liveness\": 0.103, \"Tempo\": 175.396, \"Duration (ms)\": 201361.0, \"Valence\": 0.19, \"Chord\": \"D\"}, {\"Index\": 1403, \"Highest Charting Position\": 57, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Give No Fxk\", \"Streams\": 9652399, \"Artist\": \"Migos, Travis Scott, Young Thug\", \"Artist Followers\": 11692972.0, \"Song ID\": \"6ZelF5APDN5r6XnFqcnvWR\", \"Genre\": \"['atl hip hop', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 59.0, \"Danceability\": 0.904, \"Energy\": 0.627, \"Loudness\": -5.608, \"Speechiness\": 0.222, \"Acousticness\": 0.0303, \"Liveness\": 0.0923, \"Tempo\": 145.976, \"Duration (ms)\": 224243.0, \"Valence\": 0.236, \"Chord\": \"C#/Db\"}, {\"Index\": 1404, \"Highest Charting Position\": 61, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Come Around Me\", \"Streams\": 9533583, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2o9LAypwGH4ctV0i9boo6d\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 66.0, \"Danceability\": 0.648, \"Energy\": 0.681, \"Loudness\": -8.389, \"Speechiness\": 0.0378, \"Acousticness\": 0.263, \"Liveness\": 0.0971, \"Tempo\": 157.941, \"Duration (ms)\": 200773.0, \"Valence\": 0.767, \"Chord\": \"D\"}, {\"Index\": 1405, \"Highest Charting Position\": 64, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Habitual\", \"Streams\": 9120086, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"40qyPyljksBEqlNw5sW37T\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 62.0, \"Danceability\": 0.764, \"Energy\": 0.443, \"Loudness\": -6.625, \"Speechiness\": 0.0439, \"Acousticness\": 0.52, \"Liveness\": 0.0749, \"Tempo\": 138.999, \"Duration (ms)\": 168200.0, \"Valence\": 0.63, \"Chord\": \"E\"}, {\"Index\": 1406, \"Highest Charting Position\": 65, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"All Around Me\", \"Streams\": 9010535, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5Py8zRKGkZvgHniVVtvNCN\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 63.0, \"Danceability\": 0.566, \"Energy\": 0.438, \"Loudness\": -7.564, \"Speechiness\": 0.0367, \"Acousticness\": 0.809, \"Liveness\": 0.212, \"Tempo\": 117.127, \"Duration (ms)\": 136907.0, \"Valence\": 0.692, \"Chord\": \"C\"}, {\"Index\": 1407, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Get Me (feat. Kehlani)\", \"Streams\": 8362828, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5VwwpU7KsLhgfbMEecedhJ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 61.0, \"Danceability\": 0.832, \"Energy\": 0.508, \"Loudness\": -6.913, \"Speechiness\": 0.149, \"Acousticness\": 0.0492, \"Liveness\": 0.107, \"Tempo\": 109.352, \"Duration (ms)\": 185427.0, \"Valence\": 0.75, \"Chord\": \"F#/Gb\"}, {\"Index\": 1408, \"Highest Charting Position\": 79, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Second Emotion (feat. Travis Scott)\", \"Streams\": 8109572, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"1PnAx788sAvcI3ZxTlEyX8\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 61.0, \"Danceability\": 0.796, \"Energy\": 0.777, \"Loudness\": -6.112, \"Speechiness\": 0.0567, \"Acousticness\": 0.0276, \"Liveness\": 0.095, \"Tempo\": 141.97, \"Duration (ms)\": 202720.0, \"Valence\": 0.96, \"Chord\": \"B\"}, {\"Index\": 1409, \"Highest Charting Position\": 85, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Running Over (feat. Lil Dicky)\", \"Streams\": 7493188, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"75nKBP8jQu681pTNCtrEnn\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.774, \"Energy\": 0.603, \"Loudness\": -7.319, \"Speechiness\": 0.0591, \"Acousticness\": 0.438, \"Liveness\": 0.0869, \"Tempo\": 149.982, \"Duration (ms)\": 179627.0, \"Valence\": 0.977, \"Chord\": \"B\"}, {\"Index\": 1410, \"Highest Charting Position\": 86, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Available\", \"Streams\": 7473249, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"1b6tPXXCV2fSNtR3SKWUQA\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.702, \"Energy\": 0.608, \"Loudness\": -6.843, \"Speechiness\": 0.0359, \"Acousticness\": 0.0736, \"Liveness\": 0.129, \"Tempo\": 75.012, \"Duration (ms)\": 195333.0, \"Valence\": 0.597, \"Chord\": \"D#/Eb\"}, {\"Index\": 1411, \"Highest Charting Position\": 96, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Breathe Deeper\", \"Streams\": 7142364, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"3LbZIhU0smEU5SUnxod4j4\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 66.0, \"Danceability\": 0.664, \"Energy\": 0.848, \"Loudness\": -4.51, \"Speechiness\": 0.0322, \"Acousticness\": 0.0245, \"Liveness\": 0.172, \"Tempo\": 104.998, \"Duration (ms)\": 372867.0, \"Valence\": 0.502, \"Chord\": \"B\"}, {\"Index\": 1412, \"Highest Charting Position\": 103, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Changes\", \"Streams\": 6865229, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"521Os1SMlxmsoevsqyjNmJ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 62.0, \"Danceability\": 0.485, \"Energy\": 0.412, \"Loudness\": -7.766, \"Speechiness\": 0.042, \"Acousticness\": 0.738, \"Liveness\": 0.12, \"Tempo\": 64.062, \"Duration (ms)\": 135493.0, \"Valence\": 0.612, \"Chord\": \"A\"}, {\"Index\": 1413, \"Highest Charting Position\": 116, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Confirmation\", \"Streams\": 6520106, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"60brXKLTC15vK0av5gIldm\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.438, \"Energy\": 0.315, \"Loudness\": -8.186, \"Speechiness\": 0.0375, \"Acousticness\": 0.608, \"Liveness\": 0.151, \"Tempo\": 190.064, \"Duration (ms)\": 170587.0, \"Valence\": 0.449, \"Chord\": \"G#/Ab\"}, {\"Index\": 1414, \"Highest Charting Position\": 122, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Mios mit Bars\", \"Streams\": 6341141, \"Artist\": \"Luciano\", \"Artist Followers\": 942380.0, \"Song ID\": \"7Ek9e3eIuktIFjpDRQfmHE\", \"Genre\": \"['german drill', 'german hip hop']\", \"Release Date\": \"2020-02-13\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 57.0, \"Danceability\": 0.677, \"Energy\": 0.633, \"Loudness\": -7.353, \"Speechiness\": 0.0467, \"Acousticness\": 0.111, \"Liveness\": 0.217, \"Tempo\": 145.012, \"Duration (ms)\": 232147.0, \"Valence\": 0.404, \"Chord\": \"A\"}, {\"Index\": 1415, \"Highest Charting Position\": 135, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"E.T.A.\", \"Streams\": 6008945, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6PzOPrXx8tJEqace76yrv2\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 58.0, \"Danceability\": 0.465, \"Energy\": 0.494, \"Loudness\": -7.595, \"Speechiness\": 0.066, \"Acousticness\": 0.49, \"Liveness\": 0.127, \"Tempo\": 127.298, \"Duration (ms)\": 176733.0, \"Valence\": 0.457, \"Chord\": \"E\"}, {\"Index\": 1416, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Borderline\", \"Streams\": 5921044, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"5hM5arv9KDbCHS0k9uqwjr\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 77.0, \"Danceability\": 0.621, \"Energy\": 0.873, \"Loudness\": -3.067, \"Speechiness\": 0.0369, \"Acousticness\": 0.0406, \"Liveness\": 0.0824, \"Tempo\": 97.96, \"Duration (ms)\": 237800.0, \"Valence\": 0.873, \"Chord\": \"F\"}, {\"Index\": 1417, \"Highest Charting Position\": 141, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Take It Out On Me\", \"Streams\": 5858768, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"39nTNk5MfyiiRupTwn1iyC\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 54.0, \"Danceability\": 0.772, \"Energy\": 0.616, \"Loudness\": -4.673, \"Speechiness\": 0.102, \"Acousticness\": 0.00337, \"Liveness\": 0.104, \"Tempo\": 129.967, \"Duration (ms)\": 178013.0, \"Valence\": 0.279, \"Chord\": \"G\"}, {\"Index\": 1418, \"Highest Charting Position\": 67, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"No Shame\", \"Streams\": 5835260, \"Artist\": \"5 Seconds of Summer\", \"Artist Followers\": 7744095.0, \"Song ID\": \"5EbidH3lGB30WuDsoR4km6\", \"Genre\": \"['boy band', 'dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-03-27\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 62.0, \"Danceability\": 0.576, \"Energy\": 0.807, \"Loudness\": -3.019, \"Speechiness\": 0.0374, \"Acousticness\": 0.0185, \"Liveness\": 0.0963, \"Tempo\": 90.932, \"Duration (ms)\": 192737.0, \"Valence\": 0.479, \"Chord\": \"G\"}, {\"Index\": 1419, \"Highest Charting Position\": 160, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Might Not Give Up (feat. Young Thug)\", \"Streams\": 5503902, \"Artist\": \"A Boogie Wit da Hoodie\", \"Artist Followers\": 5865895.0, \"Song ID\": \"4l2rsMfr20dj6nf6i6F3Y8\", \"Genre\": \"['melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 57.0, \"Danceability\": 0.687, \"Energy\": 0.592, \"Loudness\": -6.378, \"Speechiness\": 0.224, \"Acousticness\": 0.203, \"Liveness\": 0.279, \"Tempo\": 178.83, \"Duration (ms)\": 225266.0, \"Valence\": 0.246, \"Chord\": \"D\"}, {\"Index\": 1420, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"That's What Love Is\", \"Streams\": 5440037, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"2hLu8L8SNfCN4yKyPdX0h3\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 59.0, \"Danceability\": 0.639, \"Energy\": 0.437, \"Loudness\": -6.959, \"Speechiness\": 0.0355, \"Acousticness\": 0.692, \"Liveness\": 0.12, \"Tempo\": 147.575, \"Duration (ms)\": 165120.0, \"Valence\": 0.751, \"Chord\": \"A\"}, {\"Index\": 1421, \"Highest Charting Position\": 80, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Forever Yours - Avicii Tribute\", \"Streams\": 5421905, \"Artist\": \"Kygo, Sandro Cavazza\", \"Artist Followers\": 1251372.0, \"Song ID\": \"418ohXmKnlngIosIn6gG0H\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-10\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 15.0, \"Danceability\": 0.53, \"Energy\": 0.612, \"Loudness\": -8.794, \"Speechiness\": 0.0518, \"Acousticness\": 0.253, \"Liveness\": 0.246, \"Tempo\": 119.255, \"Duration (ms)\": 193847.0, \"Valence\": 0.433, \"Chord\": \"A#/Bb\"}, {\"Index\": 1422, \"Highest Charting Position\": 68, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Baby\", \"Streams\": 5376451, \"Artist\": \"Joker Bra, VIZE\", \"Artist Followers\": 191521.0, \"Song ID\": \"1V7JaMp11LKGwKiVmSetf0\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-01-30\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 63.0, \"Danceability\": 0.771, \"Energy\": 0.921, \"Loudness\": -4.228, \"Speechiness\": 0.109, \"Acousticness\": 0.166, \"Liveness\": 0.119, \"Tempo\": 128.021, \"Duration (ms)\": 148125.0, \"Valence\": 0.56, \"Chord\": \"C#/Db\"}, {\"Index\": 1423, \"Highest Charting Position\": 175, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"One More Year\", \"Streams\": 5279739, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"5ozqshq2dtU7SYCpCBu0NE\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 56.0, \"Danceability\": 0.602, \"Energy\": 0.88, \"Loudness\": -5.414, \"Speechiness\": 0.0354, \"Acousticness\": 0.057, \"Liveness\": 0.284, \"Tempo\": 114.009, \"Duration (ms)\": 324013.0, \"Valence\": 0.493, \"Chord\": \"C#/Db\"}, {\"Index\": 1424, \"Highest Charting Position\": 14, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Good News\", \"Streams\": 5210780, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"1DWZUa5Mzf2BwzpHtgbHPY\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 75.0, \"Danceability\": 0.794, \"Energy\": 0.32, \"Loudness\": -12.92, \"Speechiness\": 0.173, \"Acousticness\": 0.853, \"Liveness\": 0.112, \"Tempo\": 174.088, \"Duration (ms)\": 342040.0, \"Valence\": 0.241, \"Chord\": \"C#/Db\"}, {\"Index\": 1425, \"Highest Charting Position\": 141, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"wish you were gay\", \"Streams\": 5187997, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"3Fj47GNK2kUF0uaEDgXLaD\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-03-29\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.853, \"Energy\": 0.351, \"Loudness\": -10.198, \"Speechiness\": 0.241, \"Acousticness\": 0.39, \"Liveness\": 0.752, \"Tempo\": 118.028, \"Duration (ms)\": 221543.0, \"Valence\": 0.282, \"Chord\": \"G\"}, {\"Index\": 1426, \"Highest Charting Position\": 61, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Only The Young - Featured in Miss Americana\", \"Streams\": 5111068, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2slqvGLwzZZYsT4K4Y1GBC\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 63.0, \"Danceability\": 0.56, \"Energy\": 0.78, \"Loudness\": -4.895, \"Speechiness\": 0.0517, \"Acousticness\": 0.00244, \"Liveness\": 0.0714, \"Tempo\": 93.516, \"Duration (ms)\": 157507.0, \"Valence\": 0.602, \"Chord\": \"F\"}, {\"Index\": 1427, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"Lost In Yesterday\", \"Streams\": 5096624, \"Artist\": \"Tame Impala\", \"Artist Followers\": 5064200.0, \"Song ID\": \"5JWPUEov2wlX7c0jhYZpeB\", \"Genre\": \"['australian psych', 'neo-psychedelic']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 69.0, \"Danceability\": 0.569, \"Energy\": 0.84, \"Loudness\": -4.123, \"Speechiness\": 0.118, \"Acousticness\": 0.0295, \"Liveness\": 0.0995, \"Tempo\": 183.059, \"Duration (ms)\": 249587.0, \"Valence\": 0.749, \"Chord\": \"C#/Db\"}, {\"Index\": 1428, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-14--2020-02-21\", \"Song Name\": \"At Least For Now\", \"Streams\": 5033764, \"Artist\": \"Justin Bieber\", \"Artist Followers\": 48544923.0, \"Song ID\": \"6VLkgf5YmLixsabdqiCVGU\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-14--2020-02-21\", \"Popularity\": 54.0, \"Danceability\": 0.375, \"Energy\": 0.304, \"Loudness\": -9.897, \"Speechiness\": 0.0325, \"Acousticness\": 0.683, \"Liveness\": 0.196, \"Tempo\": 83.832, \"Duration (ms)\": 149653.0, \"Valence\": 0.295, \"Chord\": \"A\"}, {\"Index\": 1429, \"Highest Charting Position\": 167, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"you should see me in a crown\", \"Streams\": 4988054, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 1251372.0, \"Song ID\": \"6WbvBhwCaUuYHcHGEuVgqo\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 0.0, \"Danceability\": 0.683, \"Energy\": 0.534, \"Loudness\": -10.348, \"Speechiness\": 0.189, \"Acousticness\": 0.519, \"Liveness\": 0.148, \"Tempo\": 150.469, \"Duration (ms)\": 180567.0, \"Valence\": 0.284, \"Chord\": \"E\"}, {\"Index\": 1430, \"Highest Charting Position\": 186, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Too Good At Goodbyes\", \"Streams\": 4984764, \"Artist\": \"Sam Smith\", \"Artist Followers\": 17097317.0, \"Song ID\": \"3VlbOrM6nYPprVvzBZllE5\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop', 'uk pop']\", \"Release Date\": \"2017-11-03\", \"Weeks Charted\": \"2020-02-14--2020-02-21\\n2020-02-07--2020-02-14\", \"Popularity\": 72.0, \"Danceability\": 0.681, \"Energy\": 0.372, \"Loudness\": -8.237, \"Speechiness\": 0.0432, \"Acousticness\": 0.64, \"Liveness\": 0.169, \"Tempo\": 91.873, \"Duration (ms)\": 201000.0, \"Valence\": 0.476, \"Chord\": \"F\"}, {\"Index\": 1431, \"Highest Charting Position\": 7, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Intentions\", \"Streams\": 28509534, \"Artist\": \"Justin Bieber, Quavo\", \"Artist Followers\": 48544923.0, \"Song ID\": \"4umIPjkehX1r7uhmGvXiSV\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-07--2020-02-14\", \"Popularity\": 77.0, \"Danceability\": 0.806, \"Energy\": 0.546, \"Loudness\": -6.637, \"Speechiness\": 0.0575, \"Acousticness\": 0.3, \"Liveness\": 0.102, \"Tempo\": 147.986, \"Duration (ms)\": 212867.0, \"Valence\": 0.874, \"Chord\": \"A\"}, {\"Index\": 1432, \"Highest Charting Position\": 105, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Yikes\", \"Streams\": 6561188, \"Artist\": \"Nicki Minaj\", \"Artist Followers\": 22170982.0, \"Song ID\": \"75dLEqanQTupF3dtP9exT5\", \"Genre\": \"['dance pop', 'hip pop', 'pop', 'pop rap', 'post-teen pop', 'queens hip hop']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-02-07--2020-02-14\", \"Popularity\": 70.0, \"Danceability\": 0.911, \"Energy\": 0.637, \"Loudness\": -8.381, \"Speechiness\": 0.447, \"Acousticness\": 0.0409, \"Liveness\": 0.238, \"Tempo\": 149.996, \"Duration (ms)\": 156882.0, \"Valence\": 0.66, \"Chord\": \"G#/Ab\"}, {\"Index\": 1433, \"Highest Charting Position\": 66, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Yellow Hearts\", \"Streams\": 6554824, \"Artist\": \"Ant Saunders\", \"Artist Followers\": 82522.0, \"Song ID\": \"2W4yABdLc4Jnds67Poi5Nl\", \"Genre\": \"['chill r&b', 'pop']\", \"Release Date\": \"2019-06-18\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.866, \"Energy\": 0.438, \"Loudness\": -8.943, \"Speechiness\": 0.0719, \"Acousticness\": 0.177, \"Liveness\": 0.0743, \"Tempo\": 129.039, \"Duration (ms)\": 223258.0, \"Valence\": 0.695, \"Chord\": \"G\"}, {\"Index\": 1434, \"Highest Charting Position\": 120, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Birthday\", \"Streams\": 6207326, \"Artist\": \"Anne-Marie\", \"Artist Followers\": 8153871.0, \"Song ID\": \"5hff5RQeE84pznOt8WEWeO\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-02-07--2020-02-14\", \"Popularity\": 65.0, \"Danceability\": 0.609, \"Energy\": 0.785, \"Loudness\": -3.32, \"Speechiness\": 0.0891, \"Acousticness\": 0.0502, \"Liveness\": 0.171, \"Tempo\": 151.995, \"Duration (ms)\": 181467.0, \"Valence\": 0.756, \"Chord\": \"B\"}, {\"Index\": 1435, \"Highest Charting Position\": 16, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"HIGHEST IN THE ROOM (feat. ROSAL\\u00cdA & Lil Baby) - REMIX\", \"Streams\": 6107499, \"Artist\": \"Travis Scott\", \"Artist Followers\": 437907.0, \"Song ID\": \"7h0d2h0fUmzbs7zeFigJPn\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.559, \"Energy\": 0.491, \"Loudness\": -6.406, \"Speechiness\": 0.0346, \"Acousticness\": 0.0567, \"Liveness\": 0.0992, \"Tempo\": 153.131, \"Duration (ms)\": 244874.0, \"Valence\": 0.114, \"Chord\": \"D\"}, {\"Index\": 1436, \"Highest Charting Position\": 65, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Good as Hell (feat. Ariana Grande) - Remix\", \"Streams\": 6066001, \"Artist\": \"Lizzo\", \"Artist Followers\": 3991674.0, \"Song ID\": \"07Oz5StQ7GRoygNLaXs2pd\", \"Genre\": \"['dance pop', 'escape room', 'minnesota hip hop', 'pop', 'pop rap', 'post-teen pop', 'trap queen']\", \"Release Date\": \"2016\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.668, \"Energy\": 0.892, \"Loudness\": -3.001, \"Speechiness\": 0.0645, \"Acousticness\": 0.298, \"Liveness\": 0.735, \"Tempo\": 95.927, \"Duration (ms)\": 159011.0, \"Valence\": 0.478, \"Chord\": \"F\"}, {\"Index\": 1437, \"Highest Charting Position\": 70, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"I Do It (ft. Big Sean, Lil Baby)\", \"Streams\": 5561205, \"Artist\": \"Lil Wayne\", \"Artist Followers\": 10710088.0, \"Song ID\": \"1bRO28yzxgO3y3UmNR29TZ\", \"Genre\": \"['hip hop', 'new orleans rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2020-01-31\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 60.0, \"Danceability\": 0.804, \"Energy\": 0.528, \"Loudness\": -3.231, \"Speechiness\": 0.378, \"Acousticness\": 0.125, \"Liveness\": 0.41, \"Tempo\": 138.005, \"Duration (ms)\": 184440.0, \"Valence\": 0.321, \"Chord\": \"C#/Db\"}, {\"Index\": 1438, \"Highest Charting Position\": 45, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Get Me\", \"Streams\": 5236560, \"Artist\": \"Justin Bieber, Kehlani\", \"Artist Followers\": 48544923.0, \"Song ID\": \"5VwwpU7KsLhgfbMEecedhJ\", \"Genre\": \"['canadian pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-02-14\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 61.0, \"Danceability\": 0.832, \"Energy\": 0.508, \"Loudness\": -6.913, \"Speechiness\": 0.149, \"Acousticness\": 0.0492, \"Liveness\": 0.107, \"Tempo\": 109.352, \"Duration (ms)\": 185427.0, \"Valence\": 0.75, \"Chord\": \"F#/Gb\"}, {\"Index\": 1439, \"Highest Charting Position\": 95, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Yo x Ti, Tu x Mi\", \"Streams\": 5202210, \"Artist\": \"ROSAL\\u00cdA, Ozuna\", \"Artist Followers\": 4769627.0, \"Song ID\": \"7BlBVFwvbWvcwNcUarQmjk\", \"Genre\": \"['r&b en espanol']\", \"Release Date\": \"2019-08-15\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.78, \"Energy\": 0.759, \"Loudness\": -3.292, \"Speechiness\": 0.225, \"Acousticness\": 0.462, \"Liveness\": 0.143, \"Tempo\": 91.952, \"Duration (ms)\": 201040.0, \"Valence\": 0.579, \"Chord\": \"C#/Db\"}, {\"Index\": 1440, \"Highest Charting Position\": 161, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"DJ No Pare (feat. Zion, Dalex, Lenny Tav\\u00e1rez) - Remix\", \"Streams\": 5148516, \"Artist\": \"Justin Quiles, Natti Natasha, Farruko\", \"Artist Followers\": 2897862.0, \"Song ID\": \"1ndyl3wJCFs872XZ3ztPk6\", \"Genre\": \"['latin', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.743, \"Energy\": 0.709, \"Loudness\": -3.922, \"Speechiness\": 0.0879, \"Acousticness\": 0.0451, \"Liveness\": 0.0809, \"Tempo\": 170.001, \"Duration (ms)\": 258600.0, \"Valence\": 0.831, \"Chord\": \"D#/Eb\"}, {\"Index\": 1441, \"Highest Charting Position\": 160, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"EARFQUAKE\", \"Streams\": 5079657, \"Artist\": \"Tyler, The Creator\", \"Artist Followers\": 6782693.0, \"Song ID\": \"5hVghJ4KaYES3BFUATCYn0\", \"Genre\": \"['hip hop', 'rap']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\", \"Popularity\": 79.0, \"Danceability\": 0.554, \"Energy\": 0.498, \"Loudness\": -8.866, \"Speechiness\": 0.0685, \"Acousticness\": 0.23, \"Liveness\": 0.795, \"Tempo\": 79.635, \"Duration (ms)\": 190067.0, \"Valence\": 0.413, \"Chord\": \"A\"}, {\"Index\": 1442, \"Highest Charting Position\": 157, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Pa' Olvidarme De Ella\", \"Streams\": 5066711, \"Artist\": \"Piso 21, Christian Nodal\", \"Artist Followers\": 7226268.0, \"Song ID\": \"1cVlW9WQiGlFdWUXFdFZGh\", \"Genre\": \"['colombian pop', 'latin', 'latin pop', 'reggaeton', 'reggaeton colombiano', 'trap latino']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.728, \"Energy\": 0.542, \"Loudness\": -5.195, \"Speechiness\": 0.0514, \"Acousticness\": 0.259, \"Liveness\": 0.136, \"Tempo\": 90.016, \"Duration (ms)\": 227234.0, \"Valence\": 0.637, \"Chord\": \"C\"}, {\"Index\": 1443, \"Highest Charting Position\": 89, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Loco Contigo (feat. J. Balvin & Tyga)\", \"Streams\": 5013732, \"Artist\": \"DJ Snake, J Balvin\", \"Artist Followers\": 7408249.0, \"Song ID\": \"6osaMSJh9NguagEDQcZaKx\", \"Genre\": \"['dance pop', 'edm', 'electronic trap', 'pop', 'pop dance']\", \"Release Date\": \"2019-07-25\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.694, \"Energy\": 0.758, \"Loudness\": -2.986, \"Speechiness\": 0.218, \"Acousticness\": 0.278, \"Liveness\": 0.102, \"Tempo\": 192.091, \"Duration (ms)\": 185195.0, \"Valence\": 0.371, \"Chord\": \"B\"}, {\"Index\": 1444, \"Highest Charting Position\": 54, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Psycho\", \"Streams\": 4991751, \"Artist\": \"Red Velvet\", \"Artist Followers\": 5688315.0, \"Song ID\": \"3CYH422oy1cZNoo0GTG1TK\", \"Genre\": \"['k-pop', 'k-pop girl group']\", \"Release Date\": \"2019-12-23\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.664, \"Energy\": 0.666, \"Loudness\": -2.203, \"Speechiness\": 0.0446, \"Acousticness\": 0.193, \"Liveness\": 0.0854, \"Tempo\": 139.987, \"Duration (ms)\": 210560.0, \"Valence\": 0.405, \"Chord\": \"G#/Ab\"}, {\"Index\": 1445, \"Highest Charting Position\": 113, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Suge\", \"Streams\": 4986299, \"Artist\": \"DaBaby\", \"Artist Followers\": 7601122.0, \"Song ID\": \"2gwkD6igEhQbDQegRCcdoB\", \"Genre\": \"['north carolina hip hop', 'rap']\", \"Release Date\": \"2019-03-01\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.876, \"Energy\": 0.662, \"Loudness\": -6.482, \"Speechiness\": 0.426, \"Acousticness\": 0.0608, \"Liveness\": 0.127, \"Tempo\": 75.445, \"Duration (ms)\": 163320.0, \"Valence\": 0.844, \"Chord\": \"D\"}, {\"Index\": 1446, \"Highest Charting Position\": 101, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Con Altura\", \"Streams\": 4961249, \"Artist\": \"ROSAL\\u00cdA, J Balvin, El Guincho\", \"Artist Followers\": 4769627.0, \"Song ID\": \"2qG5sZ7Si6sdK74qLxedYM\", \"Genre\": \"['r&b en espanol']\", \"Release Date\": \"2019-03-28\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.882, \"Energy\": 0.689, \"Loudness\": -4.027, \"Speechiness\": 0.124, \"Acousticness\": 0.39, \"Liveness\": 0.0501, \"Tempo\": 97.963, \"Duration (ms)\": 161627.0, \"Valence\": 0.746, \"Chord\": \"F#/Gb\"}, {\"Index\": 1447, \"Highest Charting Position\": 140, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Only Human\", \"Streams\": 4953866, \"Artist\": \"Jonas Brothers\", \"Artist Followers\": 5436999.0, \"Song ID\": \"0DiDStADDVh3SvAsoJAFMk\", \"Genre\": \"['boy band', 'dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-06-07\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.795, \"Energy\": 0.496, \"Loudness\": -5.883, \"Speechiness\": 0.0722, \"Acousticness\": 0.108, \"Liveness\": 0.0645, \"Tempo\": 94.01, \"Duration (ms)\": 183000.0, \"Valence\": 0.874, \"Chord\": \"C\"}, {\"Index\": 1448, \"Highest Charting Position\": 51, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Eleven\", \"Streams\": 4947780, \"Artist\": \"Khalid\", \"Artist Followers\": 14190858.0, \"Song ID\": \"18O00Y7yrkJ0pRXm1n21Og\", \"Genre\": \"['pop']\", \"Release Date\": \"2020-05-01\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\", \"Popularity\": 68.0, \"Danceability\": 0.679, \"Energy\": 0.408, \"Loudness\": -9.754, \"Speechiness\": 0.0882, \"Acousticness\": 0.133, \"Liveness\": 0.23, \"Tempo\": 129.079, \"Duration (ms)\": 206080.0, \"Valence\": 0.151, \"Chord\": \"E\"}, {\"Index\": 1449, \"Highest Charting Position\": 135, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Talk (feat. Disclosure)\", \"Streams\": 4940984, \"Artist\": \"Khalid\", \"Artist Followers\": 14190858.0, \"Song ID\": \"6TqXcAFInzjp0bODyvrWEq\", \"Genre\": \"['pop']\", \"Release Date\": \"2019-04-05\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.9, \"Energy\": 0.4, \"Loudness\": -8.575, \"Speechiness\": 0.127, \"Acousticness\": 0.0516, \"Liveness\": 0.0599, \"Tempo\": 135.984, \"Duration (ms)\": 197573.0, \"Valence\": 0.346, \"Chord\": \"C\"}, {\"Index\": 1450, \"Highest Charting Position\": 117, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Hot (Remix) [feat. Gunna and Travis Scott]\", \"Streams\": 4905155, \"Artist\": \"Travis Scott, Young Thug\", \"Artist Followers\": 3337982.0, \"Song ID\": \"56AMYGJzxBO6p8v0wEe9de\", \"Genre\": \"['atl hip hop', 'hip hop', 'melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-11-01\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.845, \"Energy\": 0.631, \"Loudness\": -8.206, \"Speechiness\": 0.216, \"Acousticness\": 0.188, \"Liveness\": 0.0806, \"Tempo\": 111.983, \"Duration (ms)\": 279907.0, \"Valence\": 0.545, \"Chord\": \"G\"}, {\"Index\": 1451, \"Highest Charting Position\": 192, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-02-07--2020-02-14\", \"Song Name\": \"Weiss\", \"Streams\": 4872077, \"Artist\": \"Samra\", \"Artist Followers\": 1045091.0, \"Song ID\": \"38YP1STiBe3AZevFFJILf4\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-02-07\", \"Weeks Charted\": \"2020-02-07--2020-02-14\", \"Popularity\": 56.0, \"Danceability\": 0.6, \"Energy\": 0.525, \"Loudness\": -6.585, \"Speechiness\": 0.423, \"Acousticness\": 0.393, \"Liveness\": 0.111, \"Tempo\": 96.989, \"Duration (ms)\": 162702.0, \"Valence\": 0.436, \"Chord\": \"D\"}, {\"Index\": 1452, \"Highest Charting Position\": 105, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Con Calma\", \"Streams\": 4861378, \"Artist\": \"Daddy Yankee, Snow\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3GIhMWNecxw8GyCFwviF6v\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-12\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 3.0, \"Danceability\": 0.737, \"Energy\": 0.86, \"Loudness\": -2.652, \"Speechiness\": 0.0594, \"Acousticness\": 0.11, \"Liveness\": 0.0574, \"Tempo\": 93.989, \"Duration (ms)\": 193227.0, \"Valence\": 0.656, \"Chord\": \"G#/Ab\"}, {\"Index\": 1453, \"Highest Charting Position\": 148, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"MIDDLE CHILD\", \"Streams\": 4836113, \"Artist\": \"J. Cole\", \"Artist Followers\": 14103694.0, \"Song ID\": \"2JvzF1RMd7lE3KmFlsyZD8\", \"Genre\": \"['conscious hip hop', 'hip hop', 'north carolina hip hop', 'rap']\", \"Release Date\": \"2019-01-23\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.837, \"Energy\": 0.364, \"Loudness\": -11.713, \"Speechiness\": 0.276, \"Acousticness\": 0.149, \"Liveness\": 0.271, \"Tempo\": 123.984, \"Duration (ms)\": 213594.0, \"Valence\": 0.463, \"Chord\": \"G#/Ab\"}, {\"Index\": 1454, \"Highest Charting Position\": 136, \"Number of Times Charted\": 7, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Otro Trago - Remix\", \"Streams\": 4803294, \"Artist\": \"Sech, Ozuna, Anuel AA, Darell, Nicky Jam\", \"Artist Followers\": 8766508.0, \"Song ID\": \"4bTZeO72FwMa6wKOiqoynL\", \"Genre\": \"['latin', 'panamanian pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-07-26\", \"Weeks Charted\": \"2020-02-07--2020-02-14\\n2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.725, \"Energy\": 0.79, \"Loudness\": -2.331, \"Speechiness\": 0.197, \"Acousticness\": 0.0711, \"Liveness\": 0.0602, \"Tempo\": 175.988, \"Duration (ms)\": 287773.0, \"Valence\": 0.763, \"Chord\": \"C\"}, {\"Index\": 1455, \"Highest Charting Position\": 113, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"FML\", \"Streams\": 6350496, \"Artist\": \"Arizona Zervas\", \"Artist Followers\": 621200.0, \"Song ID\": \"6lruHh1jF7ezgbLv72xYmf\", \"Genre\": \"['pop rap', 'rhode island rap']\", \"Release Date\": \"2018-06-03\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 74.0, \"Danceability\": 0.822, \"Energy\": 0.575, \"Loudness\": -5.95, \"Speechiness\": 0.0934, \"Acousticness\": 0.113, \"Liveness\": 0.106, \"Tempo\": 100.087, \"Duration (ms)\": 223000.0, \"Valence\": 0.616, \"Chord\": \"F\"}, {\"Index\": 1456, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"King Of My City\", \"Streams\": 5922748, \"Artist\": \"A Boogie Wit da Hoodie\", \"Artist Followers\": 1251372.0, \"Song ID\": \"4JEz0Iz8PnzHe5B0CkYSjP\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 0.0, \"Danceability\": 0.679, \"Energy\": 0.679, \"Loudness\": -6.747, \"Speechiness\": 0.167, \"Acousticness\": 0.443, \"Liveness\": 0.153, \"Tempo\": 119.921, \"Duration (ms)\": 148676.0, \"Valence\": 0.245, \"Chord\": \"E\"}, {\"Index\": 1457, \"Highest Charting Position\": 22, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Those Kinda Nights (feat. Ed Sheeran)\", \"Streams\": 5823422, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"0VSzREd1OjEWJ9tXoFHRQH\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 66.0, \"Danceability\": 0.794, \"Energy\": 0.637, \"Loudness\": -6.29, \"Speechiness\": 0.339, \"Acousticness\": 0.028, \"Liveness\": 0.0919, \"Tempo\": 103.868, \"Duration (ms)\": 177693.0, \"Valence\": 0.393, \"Chord\": \"E\"}, {\"Index\": 1458, \"Highest Charting Position\": 136, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Mon Ami\", \"Streams\": 5774770, \"Artist\": \"Samra\", \"Artist Followers\": 1045091.0, \"Song ID\": \"1R4xkZXQUQ8QJtAdwHkSgC\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-01-29\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 53.0, \"Danceability\": 0.801, \"Energy\": 0.731, \"Loudness\": -3.723, \"Speechiness\": 0.383, \"Acousticness\": 0.188, \"Liveness\": 0.111, \"Tempo\": 105.666, \"Duration (ms)\": 138409.0, \"Valence\": 0.537, \"Chord\": \"G#/Ab\"}, {\"Index\": 1459, \"Highest Charting Position\": 120, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Break My Stride\", \"Streams\": 5312936, \"Artist\": \"Matthew Wilder\", \"Artist Followers\": 30386.0, \"Song ID\": \"1mCsF9Tw4AkIZOjvZbZZdT\", \"Genre\": \"['new wave pop']\", \"Release Date\": \"1983-03-19\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 73.0, \"Danceability\": 0.917, \"Energy\": 0.588, \"Loudness\": -11.047, \"Speechiness\": 0.0607, \"Acousticness\": 0.195, \"Liveness\": 0.0914, \"Tempo\": 110.077, \"Duration (ms)\": 184480.0, \"Valence\": 0.828, \"Chord\": \"A#/Bb\"}, {\"Index\": 1460, \"Highest Charting Position\": 76, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Kein Wort\", \"Streams\": 5208651, \"Artist\": \"Juju, Loredana, Miksu / Macloud\", \"Artist Followers\": 486474.0, \"Song ID\": \"1hoLUVBx0ixX3kn0EX0P5n\", \"Genre\": \"['frauenrap', 'german hip hop', 'german pop']\", \"Release Date\": \"2020-01-16\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.746, \"Energy\": 0.592, \"Loudness\": -6.861, \"Speechiness\": 0.0914, \"Acousticness\": 0.462, \"Liveness\": 0.187, \"Tempo\": 160.065, \"Duration (ms)\": 162094.0, \"Valence\": 0.629, \"Chord\": \"F#/Gb\"}, {\"Index\": 1461, \"Highest Charting Position\": 86, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Graveyard\", \"Streams\": 5044853, \"Artist\": \"Halsey\", \"Artist Followers\": 15663384.0, \"Song ID\": \"2ufmtcIFdFpuUYBPXK5f67\", \"Genre\": \"['dance pop', 'electropop', 'etherpop', 'indie poptimism', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.667, \"Energy\": 0.583, \"Loudness\": -5.127, \"Speechiness\": 0.0747, \"Acousticness\": 0.231, \"Liveness\": 0.181, \"Tempo\": 92.043, \"Duration (ms)\": 181806.0, \"Valence\": 0.187, \"Chord\": \"B\"}, {\"Index\": 1462, \"Highest Charting Position\": 183, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Wake Up Call (feat. Trippie Redd)\", \"Streams\": 5029979, \"Artist\": \"KSI\", \"Artist Followers\": 2010879.0, \"Song ID\": \"5MYzajZVxBaPT2JUSRa99L\", \"Genre\": \"['uk hip hop']\", \"Release Date\": \"2020-01-27\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 56.0, \"Danceability\": 0.642, \"Energy\": 0.669, \"Loudness\": -5.774, \"Speechiness\": 0.0486, \"Acousticness\": 0.318, \"Liveness\": 0.119, \"Tempo\": 156.084, \"Duration (ms)\": 175067.0, \"Valence\": 0.227, \"Chord\": \"F#/Gb\"}, {\"Index\": 1463, \"Highest Charting Position\": 131, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Turn Me On (feat. Vula)\", \"Streams\": 4925843, \"Artist\": \"Riton, Oliver Heldens\", \"Artist Followers\": 83743.0, \"Song ID\": \"0qaWEvPkts34WF68r8Dzx9\", \"Genre\": \"['dance pop', 'house', 'pop dance', 'tropical house', 'uk dance']\", \"Release Date\": \"2019-09-13\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.737, \"Energy\": 0.828, \"Loudness\": -4.711, \"Speechiness\": 0.0396, \"Acousticness\": 0.0149, \"Liveness\": 0.0862, \"Tempo\": 124.051, \"Duration (ms)\": 208474.0, \"Valence\": 0.517, \"Chord\": \"B\"}, {\"Index\": 1464, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"Hips Don't Lie (feat. Wyclef Jean)\", \"Streams\": 4918636, \"Artist\": \"Shakira\", \"Artist Followers\": 22136717.0, \"Song ID\": \"3ZFTkvIE7kyPt6Nu3PEa7V\", \"Genre\": \"['colombian pop', 'dance pop', 'latin', 'latin pop', 'pop']\", \"Release Date\": \"2005-11-28\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 83.0, \"Danceability\": 0.778, \"Energy\": 0.824, \"Loudness\": -5.892, \"Speechiness\": 0.0707, \"Acousticness\": 0.284, \"Liveness\": 0.405, \"Tempo\": 100.024, \"Duration (ms)\": 218093.0, \"Valence\": 0.758, \"Chord\": \"A#/Bb\"}, {\"Index\": 1465, \"Highest Charting Position\": 106, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Liar\", \"Streams\": 4896939, \"Artist\": \"Camila Cabello\", \"Artist Followers\": 22698747.0, \"Song ID\": \"7LzouaWGFCy4tkXDOOnEyM\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-09-04\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 69.0, \"Danceability\": 0.74, \"Energy\": 0.498, \"Loudness\": -6.684, \"Speechiness\": 0.0456, \"Acousticness\": 0.0169, \"Liveness\": 0.319, \"Tempo\": 98.016, \"Duration (ms)\": 207039.0, \"Valence\": 0.652, \"Chord\": \"B\"}, {\"Index\": 1466, \"Highest Charting Position\": 191, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Going Bad (feat. Drake)\", \"Streams\": 4889500, \"Artist\": \"Meek Mill\", \"Artist Followers\": 5241145.0, \"Song ID\": \"2IRZnDFmlqMuOrYOLnZZyc\", \"Genre\": \"['hip hop', 'philly rap', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2018-11-30\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.889, \"Energy\": 0.496, \"Loudness\": -6.365, \"Speechiness\": 0.0905, \"Acousticness\": 0.259, \"Liveness\": 0.252, \"Tempo\": 86.003, \"Duration (ms)\": 180522.0, \"Valence\": 0.544, \"Chord\": \"E\"}, {\"Index\": 1467, \"Highest Charting Position\": 193, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-31--2020-02-07\", \"Song Name\": \"ME! (feat. Brendon Urie of Panic! At The Disco)\", \"Streams\": 4884909, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"2Rk4JlNc2TPmZe2af99d45\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-08-23\", \"Weeks Charted\": \"2020-01-31--2020-02-07\", \"Popularity\": 77.0, \"Danceability\": 0.61, \"Energy\": 0.83, \"Loudness\": -4.105, \"Speechiness\": 0.0571, \"Acousticness\": 0.033, \"Liveness\": 0.118, \"Tempo\": 182.162, \"Duration (ms)\": 193000.0, \"Valence\": 0.728, \"Chord\": \"C\"}, {\"Index\": 1468, \"Highest Charting Position\": 134, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Panini\", \"Streams\": 4867723, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5488666.0, \"Song ID\": \"1000nHvUdawXuUHgBod4Wv\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2019-09-13\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.703, \"Energy\": 0.594, \"Loudness\": -6.146, \"Speechiness\": 0.0752, \"Acousticness\": 0.342, \"Liveness\": 0.123, \"Tempo\": 153.848, \"Duration (ms)\": 114893.0, \"Valence\": 0.475, \"Chord\": \"F\"}, {\"Index\": 1469, \"Highest Charting Position\": 191, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"idontwannabeyouanymore\", \"Streams\": 4824483, \"Artist\": \"Billie Eilish\", \"Artist Followers\": 47061119.0, \"Song ID\": \"41zXlQxzTi6cGAjpOXyLYH\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2017-12-22\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\", \"Popularity\": 78.0, \"Danceability\": 0.483, \"Energy\": 0.412, \"Loudness\": -8.461, \"Speechiness\": 0.0402, \"Acousticness\": 0.737, \"Liveness\": 0.116, \"Tempo\": 170.163, \"Duration (ms)\": 203569.0, \"Valence\": 0.247, \"Chord\": \"G\"}, {\"Index\": 1470, \"Highest Charting Position\": 158, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"The London (feat. J. Cole & Travis Scott)\", \"Streams\": 4791732, \"Artist\": \"J. Cole, Young Thug\", \"Artist Followers\": 6383275.0, \"Song ID\": \"7DcvwMAiqKJQD1rrdfxSDx\", \"Genre\": \"['atl hip hop', 'atl trap', 'gangster rap', 'hip hop', 'melodic rap', 'pop rap', 'rap', 'trap']\", \"Release Date\": \"2019-05-23\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 72.0, \"Danceability\": 0.796, \"Energy\": 0.586, \"Loudness\": -6.946, \"Speechiness\": 0.147, \"Acousticness\": 0.0247, \"Liveness\": 0.132, \"Tempo\": 97.981, \"Duration (ms)\": 200107.0, \"Valence\": 0.179, \"Chord\": \"E\"}, {\"Index\": 1471, \"Highest Charting Position\": 123, \"Number of Times Charted\": 6, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"223's (feat. 9lokknine)\", \"Streams\": 4781697, \"Artist\": \"YNW Melly\", \"Artist Followers\": 6332535.0, \"Song ID\": \"4sjiIpEv617LDXaidKioOI\", \"Genre\": \"['melodic rap', 'trap']\", \"Release Date\": \"2019-08-09\", \"Weeks Charted\": \"2020-01-31--2020-02-07\\n2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.932, \"Energy\": 0.547, \"Loudness\": -7.787, \"Speechiness\": 0.333, \"Acousticness\": 0.0388, \"Liveness\": 0.0924, \"Tempo\": 94.998, \"Duration (ms)\": 176640.0, \"Valence\": 0.695, \"Chord\": \"C\"}, {\"Index\": 1472, \"Highest Charting Position\": 26, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Darkness\", \"Streams\": 7618955, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5SiZJoLXp3WOl3J4C8IK0d\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 65.0, \"Danceability\": 0.671, \"Energy\": 0.623, \"Loudness\": -7.161, \"Speechiness\": 0.308, \"Acousticness\": 0.00998, \"Liveness\": 0.643, \"Tempo\": 75.055, \"Duration (ms)\": 337147.0, \"Valence\": 0.195, \"Chord\": \"D\"}, {\"Index\": 1473, \"Highest Charting Position\": 30, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"You Gon\\u2019 Learn (feat. Royce Da 5'9\\\" & White Gold)\", \"Streams\": 7157402, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"0GQ5bFTVFFKpwNPc7KwQnB\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 66.0, \"Danceability\": 0.68, \"Energy\": 0.82, \"Loudness\": -4.197, \"Speechiness\": 0.151, \"Acousticness\": 0.0614, \"Liveness\": 0.597, \"Tempo\": 140.033, \"Duration (ms)\": 234653.0, \"Valence\": 0.243, \"Chord\": \"E\"}, {\"Index\": 1474, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Blue World\", \"Streams\": 7060589, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"2hwOoMtWPtTSSn6WHV7Vp5\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 75.0, \"Danceability\": 0.742, \"Energy\": 0.553, \"Loudness\": -8.98, \"Speechiness\": 0.419, \"Acousticness\": 0.389, \"Liveness\": 0.0694, \"Tempo\": 84.931, \"Duration (ms)\": 209440.0, \"Valence\": 0.508, \"Chord\": \"G#/Ab\"}, {\"Index\": 1475, \"Highest Charting Position\": 99, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Liberdade Provis\\u00f3ria\", \"Streams\": 6442626, \"Artist\": \"Henrique & Juliano\", \"Artist Followers\": 13312073.0, \"Song ID\": \"1vG3YuKRYqPwTmNmYgqkpg\", \"Genre\": \"['sertanejo pop', 'sertanejo universitario']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.668, \"Energy\": 0.684, \"Loudness\": -5.937, \"Speechiness\": 0.0527, \"Acousticness\": 0.627, \"Liveness\": 0.923, \"Tempo\": 108.138, \"Duration (ms)\": 187986.0, \"Valence\": 0.7, \"Chord\": \"C#/Db\"}, {\"Index\": 1476, \"Highest Charting Position\": 32, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Unaccommodating (feat. Young M.A)\", \"Streams\": 6374807, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"0q2vG0UVuy6ajjcpkQHdZM\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 65.0, \"Danceability\": 0.852, \"Energy\": 0.752, \"Loudness\": -5.793, \"Speechiness\": 0.0597, \"Acousticness\": 0.0169, \"Liveness\": 0.394, \"Tempo\": 89.95, \"Duration (ms)\": 216600.0, \"Valence\": 0.389, \"Chord\": \"C#/Db\"}, {\"Index\": 1477, \"Highest Charting Position\": 129, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Donuts\", \"Streams\": 6113037, \"Artist\": \"Gzuz\", \"Artist Followers\": 1140383.0, \"Song ID\": \"5XVPNr0CAoUn1jD033Ucoo\", \"Genre\": \"['deep german hip hop', 'german hip hop', 'hamburg hip hop']\", \"Release Date\": \"2020-02-13\", \"Weeks Charted\": \"2020-01-24--2020-01-31\", \"Popularity\": 62.0, \"Danceability\": 0.784, \"Energy\": 0.703, \"Loudness\": -7.491, \"Speechiness\": 0.236, \"Acousticness\": 0.0973, \"Liveness\": 0.0754, \"Tempo\": 141.035, \"Duration (ms)\": 162938.0, \"Valence\": 0.556, \"Chord\": \"B\"}, {\"Index\": 1478, \"Highest Charting Position\": 44, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Leaving Heaven (feat. Skylar Grey)\", \"Streams\": 5466161, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5CpsIb7SMFHjmAG8RvIWfq\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.661, \"Energy\": 0.748, \"Loudness\": -4.809, \"Speechiness\": 0.206, \"Acousticness\": 0.175, \"Liveness\": 0.254, \"Tempo\": 171.983, \"Duration (ms)\": 265947.0, \"Valence\": 0.509, \"Chord\": \"D\"}, {\"Index\": 1479, \"Highest Charting Position\": 164, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Zu Ende\", \"Streams\": 5297101, \"Artist\": \"Samra, ELIF\", \"Artist Followers\": 1045091.0, \"Song ID\": \"0Vl4eICpXMjtiK0RhdaWov\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2020-01-23\", \"Weeks Charted\": \"2020-01-24--2020-01-31\", \"Popularity\": 57.0, \"Danceability\": 0.707, \"Energy\": 0.747, \"Loudness\": -5.212, \"Speechiness\": 0.279, \"Acousticness\": 0.307, \"Liveness\": 0.183, \"Tempo\": 80.025, \"Duration (ms)\": 197861.0, \"Valence\": 0.491, \"Chord\": \"G#/Ab\"}, {\"Index\": 1480, \"Highest Charting Position\": 171, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"B.I.T.C.H.\", \"Streams\": 5215211, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"06scTb0zbkxYNgpAB3J9fN\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-01-24\", \"Weeks Charted\": \"2020-01-24--2020-01-31\", \"Popularity\": 59.0, \"Danceability\": 0.742, \"Energy\": 0.731, \"Loudness\": -4.362, \"Speechiness\": 0.306, \"Acousticness\": 0.0851, \"Liveness\": 0.131, \"Tempo\": 174.019, \"Duration (ms)\": 183143.0, \"Valence\": 0.547, \"Chord\": \"B\"}, {\"Index\": 1481, \"Highest Charting Position\": 56, \"Number of Times Charted\": 5, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Look At Her Now\", \"Streams\": 5066377, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 1251372.0, \"Song ID\": \"2XUPkAie1nz9SYIhbdIVWb\", \"Genre\": \"[]\", \"Release Date\": \"2021-08-13\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 0.0, \"Danceability\": 0.753, \"Energy\": 0.564, \"Loudness\": -7.908, \"Speechiness\": 0.251, \"Acousticness\": 0.114, \"Liveness\": 0.359, \"Tempo\": 77.341, \"Duration (ms)\": 162596.0, \"Valence\": 0.55, \"Chord\": \"A#/Bb\"}, {\"Index\": 1482, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-24--2020-01-31\", \"Song Name\": \"Bi Sonraki Hayat\\u0131mda Gel\", \"Streams\": 5037967, \"Artist\": \"Murda, Ezhel\", \"Artist Followers\": 862965.0, \"Song ID\": \"5SYkeNpjhJPFUMOP5TK8iw\", \"Genre\": \"['basshall', 'turkish trap']\", \"Release Date\": \"2020-08-28\", \"Weeks Charted\": \"2020-01-24--2020-01-31\", \"Popularity\": 57.0, \"Danceability\": 0.933, \"Energy\": 0.448, \"Loudness\": -4.491, \"Speechiness\": 0.136, \"Acousticness\": 0.0253, \"Liveness\": 0.104, \"Tempo\": 103.981, \"Duration (ms)\": 167350.0, \"Valence\": 0.737, \"Chord\": \"G#/Ab\"}, {\"Index\": 1483, \"Highest Charting Position\": 126, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Legends\", \"Streams\": 4922369, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"1Knctxx9vGZxpZfF66BIEa\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2018-06-22\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.594, \"Energy\": 0.798, \"Loudness\": -5.244, \"Speechiness\": 0.0844, \"Acousticness\": 0.115, \"Liveness\": 0.143, \"Tempo\": 142.049, \"Duration (ms)\": 191840.0, \"Valence\": 0.381, \"Chord\": \"E\"}, {\"Index\": 1484, \"Highest Charting Position\": 157, \"Number of Times Charted\": 4, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"11 PM\", \"Streams\": 4891989, \"Artist\": \"Maluma\", \"Artist Followers\": 26784251.0, \"Song ID\": \"7KbF6AdprOXEEHlsq11Z6d\", \"Genre\": \"['latin', 'reggaeton', 'reggaeton colombiano']\", \"Release Date\": \"2019-05-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.777, \"Energy\": 0.712, \"Loudness\": -4.84, \"Speechiness\": 0.277, \"Acousticness\": 0.217, \"Liveness\": 0.091, \"Tempo\": 95.692, \"Duration (ms)\": 175733.0, \"Valence\": 0.68, \"Chord\": \"A#/Bb\"}, {\"Index\": 1485, \"Highest Charting Position\": 182, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Post Malone (feat. RANI)\", \"Streams\": 4855270, \"Artist\": \"Sam Feldt\", \"Artist Followers\": 639516.0, \"Song ID\": \"0qc4QlcCxVTGyShurEv1UU\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'pop', 'pop dance', 'pop edm', 'tropical house']\", \"Release Date\": \"2019-05-24\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.59, \"Energy\": 0.642, \"Loudness\": -3.87, \"Speechiness\": 0.122, \"Acousticness\": 0.0771, \"Liveness\": 0.105, \"Tempo\": 107.356, \"Duration (ms)\": 174444.0, \"Valence\": 0.651, \"Chord\": \"G\"}, {\"Index\": 1486, \"Highest Charting Position\": 52, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"In Too Deep\", \"Streams\": 4824037, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"7Dj2wqPYXfSRFwa6qyOztr\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-24--2020-01-31\\n2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.72, \"Energy\": 0.767, \"Loudness\": -5.839, \"Speechiness\": 0.214, \"Acousticness\": 0.0387, \"Liveness\": 0.202, \"Tempo\": 88.966, \"Duration (ms)\": 194707.0, \"Valence\": 0.595, \"Chord\": \"A#/Bb\"}, {\"Index\": 1487, \"Highest Charting Position\": 57, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Premonition - Intro\", \"Streams\": 10830400, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"7ccTcabbJlCJiIqtrSSwBk\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.847, \"Energy\": 0.637, \"Loudness\": -5.193, \"Speechiness\": 0.367, \"Acousticness\": 0.0258, \"Liveness\": 0.382, \"Tempo\": 165.979, \"Duration (ms)\": 173893.0, \"Valence\": 0.511, \"Chord\": \"C#/Db\"}, {\"Index\": 1488, \"Highest Charting Position\": 62, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"I Can See\", \"Streams\": 10086930, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"3R8CyhJfVjvgIROd5RSGhQ\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.699, \"Energy\": 0.503, \"Loudness\": -9.922, \"Speechiness\": 0.0882, \"Acousticness\": 0.391, \"Liveness\": 0.0996, \"Tempo\": 114.86, \"Duration (ms)\": 220853.0, \"Valence\": 0.0546, \"Chord\": \"F\"}, {\"Index\": 1489, \"Highest Charting Position\": 69, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Hand Me Downs\", \"Streams\": 9521654, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"2Yv2mHzr5AQavVdwQjEokV\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.677, \"Energy\": 0.33, \"Loudness\": -11.198, \"Speechiness\": 0.149, \"Acousticness\": 0.474, \"Liveness\": 0.064, \"Tempo\": 68.985, \"Duration (ms)\": 298440.0, \"Valence\": 0.336, \"Chord\": \"D\"}, {\"Index\": 1490, \"Highest Charting Position\": 70, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"No Regrets (feat. Don Toliver)\", \"Streams\": 9493884, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"1lO9CZo6eDrOy0S7khgryG\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 63.0, \"Danceability\": 0.756, \"Energy\": 0.747, \"Loudness\": -5.407, \"Speechiness\": 0.046, \"Acousticness\": 0.0048, \"Liveness\": 0.588, \"Tempo\": 134.935, \"Duration (ms)\": 200947.0, \"Valence\": 0.0687, \"Chord\": \"A\"}, {\"Index\": 1491, \"Highest Charting Position\": 71, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Complicated\", \"Streams\": 9443725, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"3WfSNAoj2D8C9noPSGZZFM\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.831, \"Energy\": 0.36, \"Loudness\": -8.073, \"Speechiness\": 0.052, \"Acousticness\": 0.136, \"Liveness\": 0.0703, \"Tempo\": 75.014, \"Duration (ms)\": 232212.0, \"Valence\": 0.601, \"Chord\": \"C\"}, {\"Index\": 1492, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Lock It Up (feat. Anderson .Paak)\", \"Streams\": 9328951, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"1qwMkkRiD5jqLeUUjfgblh\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.848, \"Energy\": 0.745, \"Loudness\": -3.052, \"Speechiness\": 0.221, \"Acousticness\": 0.0949, \"Liveness\": 0.0796, \"Tempo\": 137.024, \"Duration (ms)\": 170227.0, \"Valence\": 0.516, \"Chord\": \"F#/Gb\"}, {\"Index\": 1493, \"Highest Charting Position\": 73, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Marsh\", \"Streams\": 9260007, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"34d7sGX6WUqq8f04e7CSNF\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.871, \"Energy\": 0.493, \"Loudness\": -6.356, \"Speechiness\": 0.205, \"Acousticness\": 0.0134, \"Liveness\": 0.385, \"Tempo\": 144.989, \"Duration (ms)\": 200573.0, \"Valence\": 0.0495, \"Chord\": \"C#/Db\"}, {\"Index\": 1494, \"Highest Charting Position\": 74, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Stepdad\", \"Streams\": 9159901, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"3QVHSV8YKYq4L8tI5rnFgj\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 61.0, \"Danceability\": 0.779, \"Energy\": 0.805, \"Loudness\": -3.121, \"Speechiness\": 0.178, \"Acousticness\": 0.018, \"Liveness\": 0.321, \"Tempo\": 145.68, \"Duration (ms)\": 213413.0, \"Valence\": 0.557, \"Chord\": \"C#/Db\"}, {\"Index\": 1495, \"Highest Charting Position\": 83, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Yah Yah (feat. Royce Da 5'9\\\", Black Thought, Q-Tip & Denaun)\", \"Streams\": 8695060, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"5mZXWEH2eh8zMZGCxT5aW0\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.458, \"Energy\": 0.966, \"Loudness\": -2.107, \"Speechiness\": 0.384, \"Acousticness\": 0.14, \"Liveness\": 0.11, \"Tempo\": 183.586, \"Duration (ms)\": 286960.0, \"Valence\": 0.356, \"Chord\": \"C#/Db\"}, {\"Index\": 1496, \"Highest Charting Position\": 90, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Never Love Again\", \"Streams\": 8335790, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"40YbWniIEmqy6s58fYXLUh\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.747, \"Energy\": 0.899, \"Loudness\": -5.125, \"Speechiness\": 0.246, \"Acousticness\": 0.1, \"Liveness\": 0.486, \"Tempo\": 92.029, \"Duration (ms)\": 177547.0, \"Valence\": 0.581, \"Chord\": \"F\"}, {\"Index\": 1497, \"Highest Charting Position\": 91, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Woods\", \"Streams\": 8329349, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"3Qa944OTMZkg8DHjET8JQv\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 64.0, \"Danceability\": 0.779, \"Energy\": 0.362, \"Loudness\": -10.847, \"Speechiness\": 0.0474, \"Acousticness\": 0.135, \"Liveness\": 0.111, \"Tempo\": 85.011, \"Duration (ms)\": 286387.0, \"Valence\": 0.46, \"Chord\": \"C\"}, {\"Index\": 1498, \"Highest Charting Position\": 94, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Farewell\", \"Streams\": 8277608, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"74gykWHknHDrg4eMdcmdRq\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 61.0, \"Danceability\": 0.89, \"Energy\": 0.664, \"Loudness\": -6.625, \"Speechiness\": 0.106, \"Acousticness\": 0.00487, \"Liveness\": 0.257, \"Tempo\": 93.007, \"Duration (ms)\": 247733.0, \"Valence\": 0.467, \"Chord\": \"E\"}, {\"Index\": 1499, \"Highest Charting Position\": 98, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Everybody\", \"Streams\": 8172098, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"1OuN92HcVG6NVpWbeESNB3\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 62.0, \"Danceability\": 0.875, \"Energy\": 0.599, \"Loudness\": -9.077, \"Speechiness\": 0.138, \"Acousticness\": 0.0333, \"Liveness\": 0.113, \"Tempo\": 152.061, \"Duration (ms)\": 256507.0, \"Valence\": 0.112, \"Chord\": \"A\"}, {\"Index\": 1500, \"Highest Charting Position\": 100, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Alfred - Interlude\", \"Streams\": 8030151, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"4EmunTy7kNBYQivOa8F6b8\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 57.0, \"Danceability\": 0.429, \"Energy\": 0.231, \"Loudness\": -20.43, \"Speechiness\": 0.402, \"Acousticness\": 0.878, \"Liveness\": 0.279, \"Tempo\": 74.545, \"Duration (ms)\": 30133.0, \"Valence\": 0.914, \"Chord\": \"F\"}, {\"Index\": 1501, \"Highest Charting Position\": 102, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Little Engine\", \"Streams\": 7913461, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"4qNWEOMyexn7b8Icyk29t9\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.769, \"Energy\": 0.811, \"Loudness\": -4.162, \"Speechiness\": 0.228, \"Acousticness\": 0.0234, \"Liveness\": 0.0451, \"Tempo\": 155.081, \"Duration (ms)\": 177293.0, \"Valence\": 0.76, \"Chord\": \"A#/Bb\"}, {\"Index\": 1502, \"Highest Charting Position\": 113, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"I Will (feat. KXNG Crooked, Royce Da 5'9\\\" & Joell Ortiz)\", \"Streams\": 7115414, \"Artist\": \"Eminem\", \"Artist Followers\": 46814751.0, \"Song ID\": \"3CJbxqRQ0JNCqboWDNUUeX\", \"Genre\": \"['detroit hip hop', 'hip hop', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.635, \"Energy\": 0.543, \"Loudness\": -5.941, \"Speechiness\": 0.067, \"Acousticness\": 0.0454, \"Liveness\": 0.272, \"Tempo\": 98.743, \"Duration (ms)\": 303000.0, \"Valence\": 0.036, \"Chord\": \"G#/Ab\"}, {\"Index\": 1503, \"Highest Charting Position\": 115, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Still Learning\", \"Streams\": 7050815, \"Artist\": \"Halsey\", \"Artist Followers\": 15663384.0, \"Song ID\": \"2Mfv5HaqnI18Q9JRv9hqnn\", \"Genre\": \"['dance pop', 'electropop', 'etherpop', 'indie poptimism', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 59.0, \"Danceability\": 0.708, \"Energy\": 0.661, \"Loudness\": -6.543, \"Speechiness\": 0.0546, \"Acousticness\": 0.0396, \"Liveness\": 0.113, \"Tempo\": 102.046, \"Duration (ms)\": 211784.0, \"Valence\": 0.317, \"Chord\": \"C\"}, {\"Index\": 1504, \"Highest Charting Position\": 118, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Surf\", \"Streams\": 6960699, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"1kwnxJNVl7cwcU98RvMBaR\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 67.0, \"Danceability\": 0.828, \"Energy\": 0.182, \"Loudness\": -13.066, \"Speechiness\": 0.166, \"Acousticness\": 0.754, \"Liveness\": 0.15, \"Tempo\": 147.279, \"Duration (ms)\": 330507.0, \"Valence\": 0.231, \"Chord\": \"C#/Db\"}, {\"Index\": 1505, \"Highest Charting Position\": 139, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"That's On Me\", \"Streams\": 6462701, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"0udOCZp7yk0Ml92C0k8H8D\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 60.0, \"Danceability\": 0.583, \"Energy\": 0.499, \"Loudness\": -10.086, \"Speechiness\": 0.0261, \"Acousticness\": 0.591, \"Liveness\": 0.33, \"Tempo\": 155.199, \"Duration (ms)\": 217868.0, \"Valence\": 0.342, \"Chord\": \"A#/Bb\"}, {\"Index\": 1506, \"Highest Charting Position\": 148, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Once A Day\", \"Streams\": 6159873, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"26G5nmIx7Yvq79bIIluyZV\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 61.0, \"Danceability\": 0.762, \"Energy\": 0.054, \"Loudness\": -16.735, \"Speechiness\": 0.0503, \"Acousticness\": 0.947, \"Liveness\": 0.124, \"Tempo\": 96.838, \"Duration (ms)\": 160267.0, \"Valence\": 0.339, \"Chord\": \"D\"}, {\"Index\": 1507, \"Highest Charting Position\": 155, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Big Drip\", \"Streams\": 6010373, \"Artist\": \"Ufo361, Future\", \"Artist Followers\": 1700759.0, \"Song ID\": \"7HZoWhGQaKg97OsqG7HLOS\", \"Genre\": \"['german cloud rap', 'german hip hop']\", \"Release Date\": \"2020-04-24\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 48.0, \"Danceability\": 0.791, \"Energy\": 0.535, \"Loudness\": -6.753, \"Speechiness\": 0.311, \"Acousticness\": 0.0448, \"Liveness\": 0.129, \"Tempo\": 158.922, \"Duration (ms)\": 173785.0, \"Valence\": 0.443, \"Chord\": \"C\"}, {\"Index\": 1508, \"Highest Charting Position\": 157, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Hands\", \"Streams\": 5934464, \"Artist\": \"Mac Miller\", \"Artist Followers\": 6189454.0, \"Song ID\": \"6CrnvqCxBKVWahSiQwOesM\", \"Genre\": \"['hip hop', 'pittsburgh rap', 'rap']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 58.0, \"Danceability\": 0.739, \"Energy\": 0.627, \"Loudness\": -8.608, \"Speechiness\": 0.171, \"Acousticness\": 0.0459, \"Liveness\": 0.159, \"Tempo\": 74.962, \"Duration (ms)\": 199981.0, \"Valence\": 0.542, \"Chord\": \"C\"}, {\"Index\": 1509, \"Highest Charting Position\": 167, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Dans l'espace (feat. Heuss l'Enfoir\\u00e9)\", \"Streams\": 5678754, \"Artist\": \"Gambi\", \"Artist Followers\": 951798.0, \"Song ID\": \"2KAkkba3PaYFegfmYpUITv\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2020-01-17\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 59.0, \"Danceability\": 0.916, \"Energy\": 0.57, \"Loudness\": -6.278, \"Speechiness\": 0.18, \"Acousticness\": 0.0286, \"Liveness\": 0.0851, \"Tempo\": 110.05, \"Duration (ms)\": 169702.0, \"Valence\": 0.7, \"Chord\": \"C#/Db\"}, {\"Index\": 1510, \"Highest Charting Position\": 168, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-17--2020-01-24\", \"Song Name\": \"Blanche\", \"Streams\": 5656775, \"Artist\": \"Maes, Booba\", \"Artist Followers\": 1603670.0, \"Song ID\": \"5GyyPRvEwdI4wJSUbzxHQv\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2020-01-16\", \"Weeks Charted\": \"2020-01-17--2020-01-24\", \"Popularity\": 65.0, \"Danceability\": 0.776, \"Energy\": 0.713, \"Loudness\": -6.121, \"Speechiness\": 0.143, \"Acousticness\": 0.525, \"Liveness\": 0.306, \"Tempo\": 127.987, \"Duration (ms)\": 193453.0, \"Valence\": 0.551, \"Chord\": \"E\"}, {\"Index\": 1511, \"Highest Charting Position\": 87, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Vulnerable\", \"Streams\": 7531094, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"11OwAR3GlBj9E35Cznf7Lj\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 55.0, \"Danceability\": 0.695, \"Energy\": 0.573, \"Loudness\": -8.882, \"Speechiness\": 0.167, \"Acousticness\": 0.132, \"Liveness\": 0.156, \"Tempo\": 100.031, \"Duration (ms)\": 192172.0, \"Valence\": 0.38, \"Chord\": \"A#/Bb\"}, {\"Index\": 1512, \"Highest Charting Position\": 90, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Dance Again\", \"Streams\": 7394604, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"5sK3o66yupTNIK6gWgzGjf\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 56.0, \"Danceability\": 0.784, \"Energy\": 0.552, \"Loudness\": -7.261, \"Speechiness\": 0.0871, \"Acousticness\": 0.0447, \"Liveness\": 0.192, \"Tempo\": 111.984, \"Duration (ms)\": 170498.0, \"Valence\": 0.465, \"Chord\": \"C#/Db\"}, {\"Index\": 1513, \"Highest Charting Position\": 107, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Ring\", \"Streams\": 6693229, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"11Ey4yJVeWEsA73KjACkVY\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 55.0, \"Danceability\": 0.873, \"Energy\": 0.51, \"Loudness\": -5.35, \"Speechiness\": 0.0661, \"Acousticness\": 0.565, \"Liveness\": 0.0738, \"Tempo\": 110.953, \"Duration (ms)\": 148776.0, \"Valence\": 0.871, \"Chord\": \"D#/Eb\"}, {\"Index\": 1514, \"Highest Charting Position\": 111, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Crowded Room (feat. 6LACK)\", \"Streams\": 6483001, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"2C0hTkdEoikhKzDCJl32QZ\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 55.0, \"Danceability\": 0.724, \"Energy\": 0.415, \"Loudness\": -8.408, \"Speechiness\": 0.0518, \"Acousticness\": 0.764, \"Liveness\": 0.103, \"Tempo\": 89.999, \"Duration (ms)\": 186459.0, \"Valence\": 0.328, \"Chord\": \"G\"}, {\"Index\": 1515, \"Highest Charting Position\": 119, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"People You Know\", \"Streams\": 6255954, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"63mdJr3NMY3wReOkNE6c6W\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 54.0, \"Danceability\": 0.695, \"Energy\": 0.62, \"Loudness\": -8.082, \"Speechiness\": 0.0521, \"Acousticness\": 0.0881, \"Liveness\": 0.111, \"Tempo\": 150.032, \"Duration (ms)\": 194900.0, \"Valence\": 0.62, \"Chord\": \"G#/Ab\"}, {\"Index\": 1516, \"Highest Charting Position\": 83, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Up All Night\", \"Streams\": 5834918, \"Artist\": \"Khalid\", \"Artist Followers\": 14190858.0, \"Song ID\": \"1mpD5Q8IM32I4bF6eCpU74\", \"Genre\": \"['pop']\", \"Release Date\": \"2019-11-14\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 69.0, \"Danceability\": 0.665, \"Energy\": 0.712, \"Loudness\": -7.536, \"Speechiness\": 0.0527, \"Acousticness\": 0.00103, \"Liveness\": 0.102, \"Tempo\": 93.992, \"Duration (ms)\": 157220.0, \"Valence\": 0.669, \"Chord\": \"C#/Db\"}, {\"Index\": 1517, \"Highest Charting Position\": 111, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Nice To Meet Ya\", \"Streams\": 5730427, \"Artist\": \"Niall Horan\", \"Artist Followers\": 7564659.0, \"Song ID\": \"3cphb8kdsjElYR7r5icK3H\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-10-04\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 68.0, \"Danceability\": 0.591, \"Energy\": 0.841, \"Loudness\": -4.351, \"Speechiness\": 0.0304, \"Acousticness\": 0.0119, \"Liveness\": 0.395, \"Tempo\": 109.034, \"Duration (ms)\": 158805.0, \"Valence\": 0.392, \"Chord\": \"E\"}, {\"Index\": 1518, \"Highest Charting Position\": 102, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Into the Unknown\", \"Streams\": 5705999, \"Artist\": \"Idina Menzel, AURORA\", \"Artist Followers\": 1251372.0, \"Song ID\": \"3Z0oQ8r78OUaHvGPiDBR3W\", \"Genre\": \"[]\", \"Release Date\": \"2019-11-15\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.323, \"Energy\": 0.405, \"Loudness\": -8.533, \"Speechiness\": 0.0413, \"Acousticness\": 0.849, \"Liveness\": 0.138, \"Tempo\": 145.104, \"Duration (ms)\": 194848.0, \"Valence\": 0.274, \"Chord\": \"A#/Bb\"}, {\"Index\": 1519, \"Highest Charting Position\": 161, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Let Me Get Me\", \"Streams\": 5356671, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"0uFForNKQPvgSCnxlZIhQy\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 51.0, \"Danceability\": 0.826, \"Energy\": 0.571, \"Loudness\": -9.263, \"Speechiness\": 0.0426, \"Acousticness\": 0.249, \"Liveness\": 0.215, \"Tempo\": 121.06, \"Duration (ms)\": 189145.0, \"Valence\": 0.475, \"Chord\": \"D\"}, {\"Index\": 1520, \"Highest Charting Position\": 166, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"A Sweeter Place (feat. Kid Cudi)\", \"Streams\": 5291134, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4bb94wZVF1cX66vQjNeJTX\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 52.0, \"Danceability\": 0.583, \"Energy\": 0.777, \"Loudness\": -6.991, \"Speechiness\": 0.185, \"Acousticness\": 0.109, \"Liveness\": 0.108, \"Tempo\": 190.054, \"Duration (ms)\": 263306.0, \"Valence\": 0.31, \"Chord\": \"A#/Bb\"}, {\"Index\": 1521, \"Highest Charting Position\": 131, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Stuck In A Dream (feat. Gunna)\", \"Streams\": 5258047, \"Artist\": \"Lil Mosey\", \"Artist Followers\": 3818503.0, \"Song ID\": \"7iHHxY2NLlJRAmlAmC4ahQ\", \"Genre\": \"['melodic rap', 'rap', 'rap conscient', 'trap', 'vapor trap']\", \"Release Date\": \"2019-11-08\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.748, \"Energy\": 0.648, \"Loudness\": -6.445, \"Speechiness\": 0.0816, \"Acousticness\": 0.484, \"Liveness\": 0.126, \"Tempo\": 139.952, \"Duration (ms)\": 123560.0, \"Valence\": 0.726, \"Chord\": \"A#/Bb\"}, {\"Index\": 1522, \"Highest Charting Position\": 138, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Take What You Want (feat. Ozzy Osbourne & Travis Scott)\", \"Streams\": 5199618, \"Artist\": \"Post Malone\", \"Artist Followers\": 33663701.0, \"Song ID\": \"7CZyCXKG6d5ALeq41sLzbw\", \"Genre\": \"['dfw rap', 'melodic rap', 'rap']\", \"Release Date\": \"2019-09-06\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 75.0, \"Danceability\": 0.499, \"Energy\": 0.8, \"Loudness\": -2.665, \"Speechiness\": 0.0502, \"Acousticness\": 0.0906, \"Liveness\": 0.147, \"Tempo\": 139.919, \"Duration (ms)\": 229573.0, \"Valence\": 0.272, \"Chord\": \"C#/Db\"}, {\"Index\": 1523, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Tip Toe (feat. A Boogie Wit da Hoodie)\", \"Streams\": 5150724, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6608815.0, \"Song ID\": \"6ztvsy3C6hPjVg9j4x1XKJ\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 63.0, \"Danceability\": 0.757, \"Energy\": 0.673, \"Loudness\": -8.513, \"Speechiness\": 0.141, \"Acousticness\": 0.095, \"Liveness\": 0.338, \"Tempo\": 92.958, \"Duration (ms)\": 185806.0, \"Valence\": 0.574, \"Chord\": \"C#/Db\"}, {\"Index\": 1524, \"Highest Charting Position\": 182, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Start Wit Me (feat. Gunna)\", \"Streams\": 5085706, \"Artist\": \"Roddy Ricch\", \"Artist Followers\": 6608815.0, \"Song ID\": \"7A20WnLkjtZU2d7hIB6Ziu\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\", \"Popularity\": 68.0, \"Danceability\": 0.886, \"Energy\": 0.479, \"Loudness\": -8.054, \"Speechiness\": 0.334, \"Acousticness\": 0.077, \"Liveness\": 0.135, \"Tempo\": 130.029, \"Duration (ms)\": 158692.0, \"Valence\": 0.408, \"Chord\": \"E\"}, {\"Index\": 1525, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Diamonds (with Normani)\", \"Streams\": 4981484, \"Artist\": \"Megan Thee Stallion\", \"Artist Followers\": 4794212.0, \"Song ID\": \"0PQsrLxPbOBBwwmXCnGvcF\", \"Genre\": \"['houston rap', 'pop', 'pop rap', 'trap queen']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 58.0, \"Danceability\": 0.785, \"Energy\": 0.753, \"Loudness\": -3.841, \"Speechiness\": 0.0873, \"Acousticness\": 0.188, \"Liveness\": 0.265, \"Tempo\": 94.012, \"Duration (ms)\": 199301.0, \"Valence\": 0.488, \"Chord\": \"C#/Db\"}, {\"Index\": 1526, \"Highest Charting Position\": 140, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Don't Call Me Up\", \"Streams\": 4931458, \"Artist\": \"Mabel\", \"Artist Followers\": 1374784.0, \"Song ID\": \"5WHTFyqSii0lmT9R21abT8\", \"Genre\": \"['dance pop', 'edm', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2019-01-18\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.674, \"Energy\": 0.881, \"Loudness\": -2.853, \"Speechiness\": 0.147, \"Acousticness\": 0.296, \"Liveness\": 0.0793, \"Tempo\": 98.994, \"Duration (ms)\": 178480.0, \"Valence\": 0.234, \"Chord\": \"A\"}, {\"Index\": 1527, \"Highest Charting Position\": 177, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Death\", \"Streams\": 4929396, \"Artist\": \"Trippie Redd, DaBaby\", \"Artist Followers\": 6434201.0, \"Song ID\": \"3Kd6Wp3lG5HXMB2dlvuy7y\", \"Genre\": \"['melodic rap', 'rap', 'trap']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 65.0, \"Danceability\": 0.802, \"Energy\": 0.82, \"Loudness\": -5.969, \"Speechiness\": 0.146, \"Acousticness\": 0.0579, \"Liveness\": 0.149, \"Tempo\": 164.005, \"Duration (ms)\": 172196.0, \"Valence\": 0.613, \"Chord\": \"A#/Bb\"}, {\"Index\": 1528, \"Highest Charting Position\": 133, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Calma - Remix\", \"Streams\": 4879713, \"Artist\": \"Pedro Cap\\u00f3, Farruko\", \"Artist Followers\": 1353049.0, \"Song ID\": \"5iwz1NiezX7WWjnCgY5TH4\", \"Genre\": \"['latin', 'latin pop', 'puerto rican pop']\", \"Release Date\": \"2018-10-05\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.826, \"Energy\": 0.773, \"Loudness\": -4.218, \"Speechiness\": 0.0524, \"Acousticness\": 0.323, \"Liveness\": 0.143, \"Tempo\": 126.899, \"Duration (ms)\": 238200.0, \"Valence\": 0.761, \"Chord\": \"B\"}, {\"Index\": 1529, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Cut You Off\", \"Streams\": 4874380, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"4OtHGdb0KqEbaWb6edUnR9\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 51.0, \"Danceability\": 0.855, \"Energy\": 0.294, \"Loudness\": -8.676, \"Speechiness\": 0.286, \"Acousticness\": 0.3, \"Liveness\": 0.091, \"Tempo\": 139.745, \"Duration (ms)\": 182017.0, \"Valence\": 0.842, \"Chord\": \"F\"}, {\"Index\": 1530, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-10--2020-01-17\", \"Song Name\": \"Kinda Crazy\", \"Streams\": 4866777, \"Artist\": \"Selena Gomez\", \"Artist Followers\": 28931149.0, \"Song ID\": \"59iGOjPSOcPLGl3vqEStUp\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2020-01-10\", \"Weeks Charted\": \"2020-01-10--2020-01-17\", \"Popularity\": 49.0, \"Danceability\": 0.691, \"Energy\": 0.446, \"Loudness\": -10.304, \"Speechiness\": 0.0472, \"Acousticness\": 0.484, \"Liveness\": 0.183, \"Tempo\": 93.03, \"Duration (ms)\": 212436.0, \"Valence\": 0.534, \"Chord\": \"B\"}, {\"Index\": 1531, \"Highest Charting Position\": 179, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"2002\", \"Streams\": 4831644, \"Artist\": \"Anne-Marie\", \"Artist Followers\": 8153871.0, \"Song ID\": \"2BgEsaKNfHUdlh97KmvFyo\", \"Genre\": \"['dance pop', 'pop', 'pop dance', 'post-teen pop', 'tropical house', 'uk pop']\", \"Release Date\": \"2018-04-27\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.697, \"Energy\": 0.683, \"Loudness\": -2.881, \"Speechiness\": 0.117, \"Acousticness\": 0.0372, \"Liveness\": 0.137, \"Tempo\": 96.133, \"Duration (ms)\": 186987.0, \"Valence\": 0.603, \"Chord\": \"C#/Db\"}, {\"Index\": 1532, \"Highest Charting Position\": 153, \"Number of Times Charted\": 3, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Taki Taki (feat. Selena Gomez, Ozuna & Cardi B)\", \"Streams\": 4816702, \"Artist\": \"DJ Snake\", \"Artist Followers\": 7408249.0, \"Song ID\": \"0KoiMHhqKLoL4xM54rcWYY\", \"Genre\": \"['dance pop', 'edm', 'electronic trap', 'pop', 'pop dance']\", \"Release Date\": \"2019-07-25\", \"Weeks Charted\": \"2020-01-10--2020-01-17\\n2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.842, \"Energy\": 0.801, \"Loudness\": -4.167, \"Speechiness\": 0.228, \"Acousticness\": 0.157, \"Liveness\": 0.0642, \"Tempo\": 95.881, \"Duration (ms)\": 212500.0, \"Valence\": 0.617, \"Chord\": \"G#/Ab\"}, {\"Index\": 1533, \"Highest Charting Position\": 107, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Family\", \"Streams\": 6145132, \"Artist\": \"The Chainsmokers, Kygo\", \"Artist Followers\": 18195884.0, \"Song ID\": \"3TKpJrY9q49Mj1JOsM9zGL\", \"Genre\": \"['dance pop', 'edm', 'electropop', 'pop', 'pop dance', 'tropical house']\", \"Release Date\": \"2019-12-06\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 67.0, \"Danceability\": 0.584, \"Energy\": 0.607, \"Loudness\": -6.605, \"Speechiness\": 0.0356, \"Acousticness\": 0.426, \"Liveness\": 0.101, \"Tempo\": 117.817, \"Duration (ms)\": 194827.0, \"Valence\": 0.374, \"Chord\": \"B\"}, {\"Index\": 1534, \"Highest Charting Position\": 36, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"GANG GANG\", \"Streams\": 5898484, \"Artist\": \"JACKBOYS, Sheck Wes\", \"Artist Followers\": 437907.0, \"Song ID\": \"6uJONCdr2rC65BNmCnTBWK\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 69.0, \"Danceability\": 0.859, \"Energy\": 0.6, \"Loudness\": -4.63, \"Speechiness\": 0.301, \"Acousticness\": 0.071, \"Liveness\": 0.353, \"Tempo\": 123.017, \"Duration (ms)\": 244761.0, \"Valence\": 0.568, \"Chord\": \"G\"}, {\"Index\": 1535, \"Highest Charting Position\": 39, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Had Enough (feat. Quavo & Offset)\", \"Streams\": 5748010, \"Artist\": \"Don Toliver\", \"Artist Followers\": 437907.0, \"Song ID\": \"7LGWmZaoS7jZJ5tEi9EcDi\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.75, \"Energy\": 0.789, \"Loudness\": -4.578, \"Speechiness\": 0.108, \"Acousticness\": 0.253, \"Liveness\": 0.129, \"Tempo\": 147.957, \"Duration (ms)\": 157133.0, \"Valence\": 0.673, \"Chord\": \"D\"}, {\"Index\": 1536, \"Highest Charting Position\": 38, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"WHAT TO DO? (feat. Don Toliver)\", \"Streams\": 5586351, \"Artist\": \"JACKBOYS, Travis Scott\", \"Artist Followers\": 437907.0, \"Song ID\": \"4AO1XhrgJczQ9bNVxdfKQe\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.643, \"Energy\": 0.594, \"Loudness\": -5.191, \"Speechiness\": 0.0312, \"Acousticness\": 0.0695, \"Liveness\": 0.115, \"Tempo\": 118.037, \"Duration (ms)\": 250142.0, \"Valence\": 0.195, \"Chord\": \"A\"}, {\"Index\": 1537, \"Highest Charting Position\": 125, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Writing on the Wall (feat. Post Malone, Cardi B & Rvssian)\", \"Streams\": 5229616, \"Artist\": \"French Montana\", \"Artist Followers\": 4039037.0, \"Song ID\": \"7x9nXsowok1JszkVztI5NI\", \"Genre\": \"['gangster rap', 'hip hop', 'pop rap', 'rap', 'southern hip hop', 'trap']\", \"Release Date\": \"2019-09-27\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 59.0, \"Danceability\": 0.773, \"Energy\": 0.836, \"Loudness\": -2.326, \"Speechiness\": 0.153, \"Acousticness\": 0.283, \"Liveness\": 0.0828, \"Tempo\": 112.01, \"Duration (ms)\": 201271.0, \"Valence\": 0.497, \"Chord\": \"A\"}, {\"Index\": 1538, \"Highest Charting Position\": 169, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"VALENTINO\", \"Streams\": 4935492, \"Artist\": \"24kGoldn\", \"Artist Followers\": 1276406.0, \"Song ID\": \"6piAUJJQFD8oHDUr0b7l7q\", \"Genre\": \"['cali rap']\", \"Release Date\": \"2019-11-22\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 74.0, \"Danceability\": 0.746, \"Energy\": 0.717, \"Loudness\": -4.841, \"Speechiness\": 0.179, \"Acousticness\": 0.199, \"Liveness\": 0.132, \"Tempo\": 150.964, \"Duration (ms)\": 179133.0, \"Valence\": 0.523, \"Chord\": \"A\"}, {\"Index\": 1539, \"Highest Charting Position\": 176, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"fuck, i'm lonely (with Anne-Marie) - from \\u201c13 Reasons Why: Season 3\\u201d\", \"Streams\": 4856458, \"Artist\": \"Lauv\", \"Artist Followers\": null, \"Song ID\": null, \"Genre\": null, \"Release Date\": null, \"Weeks Charted\": \"2020-01-03--2020-01-10\", \"Popularity\": null, \"Danceability\": null, \"Energy\": null, \"Loudness\": null, \"Speechiness\": null, \"Acousticness\": null, \"Liveness\": null, \"Tempo\": null, \"Duration (ms)\": null, \"Valence\": null, \"Chord\": null}, {\"Index\": 1540, \"Highest Charting Position\": 150, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Roller\", \"Streams\": 4732292, \"Artist\": \"Apache 207\", \"Artist Followers\": 1674348.0, \"Song ID\": \"6hw1Sy9wZ8UCxYGdpKrU6M\", \"Genre\": \"['german hip hop']\", \"Release Date\": \"2019-10-25\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.941, \"Energy\": 0.758, \"Loudness\": -6.47, \"Speechiness\": 0.17, \"Acousticness\": 0.0256, \"Liveness\": 0.193, \"Tempo\": 128.017, \"Duration (ms)\": 157093.0, \"Valence\": 0.683, \"Chord\": \"A#/Bb\"}, {\"Index\": 1541, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2020-01-03--2020-01-10\", \"Song Name\": \"Never Really Over\", \"Streams\": 4679948, \"Artist\": \"Katy Perry\", \"Artist Followers\": 18936929.0, \"Song ID\": \"5PYQUBXc7NYeI1obMKSJK0\", \"Genre\": \"['dance pop', 'pop', 'post-teen pop']\", \"Release Date\": \"2019-05-31\", \"Weeks Charted\": \"2020-01-03--2020-01-10\", \"Popularity\": 74.0, \"Danceability\": 0.77, \"Energy\": 0.882, \"Loudness\": -4.792, \"Speechiness\": 0.0602, \"Acousticness\": 0.194, \"Liveness\": 0.316, \"Tempo\": 99.991, \"Duration (ms)\": 223523.0, \"Valence\": 0.385, \"Chord\": \"G#/Ab\"}, {\"Index\": 1542, \"Highest Charting Position\": 145, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"One Kiss (with Dua Lipa)\", \"Streams\": 4594157, \"Artist\": \"Calvin Harris\", \"Artist Followers\": 21946934.0, \"Song ID\": \"7ef4DlsgrMEH11cDZd32M6\", \"Genre\": \"['dance pop', 'edm', 'electro house', 'house', 'pop', 'progressive house', 'uk dance']\", \"Release Date\": \"2018-04-06\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.791, \"Energy\": 0.862, \"Loudness\": -3.24, \"Speechiness\": 0.11, \"Acousticness\": 0.037, \"Liveness\": 0.0814, \"Tempo\": 123.994, \"Duration (ms)\": 214847.0, \"Valence\": 0.592, \"Chord\": \"A\"}, {\"Index\": 1543, \"Highest Charting Position\": 192, \"Number of Times Charted\": 2, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Fantas\\u00eda\", \"Streams\": 4543012, \"Artist\": \"Ozuna\", \"Artist Followers\": 29238936.0, \"Song ID\": \"40rXWke6SnXiGkSmaT8ZUr\", \"Genre\": \"['latin', 'puerto rican pop', 'reggaeton', 'trap latino']\", \"Release Date\": \"2019-11-29\", \"Weeks Charted\": \"2020-01-03--2020-01-10\\n2019-12-27--2020-01-03\", \"Popularity\": 59.0, \"Danceability\": 0.695, \"Energy\": 0.719, \"Loudness\": -5.938, \"Speechiness\": 0.0903, \"Acousticness\": 0.227, \"Liveness\": 0.0884, \"Tempo\": 180.074, \"Duration (ms)\": 175187.0, \"Valence\": 0.781, \"Chord\": \"D\"}, {\"Index\": 1544, \"Highest Charting Position\": 59, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Trampoline\", \"Streams\": 8896030, \"Artist\": \"SHAED, ZAYN\", \"Artist Followers\": 139434.0, \"Song ID\": \"1iQDltZqI7BXnHrFy4Qo1k\", \"Genre\": \"['electropop', 'pop']\", \"Release Date\": \"2019-09-26\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 73.0, \"Danceability\": 0.619, \"Energy\": 0.459, \"Loudness\": -5.782, \"Speechiness\": 0.0334, \"Acousticness\": 0.56, \"Liveness\": 0.137, \"Tempo\": 126.803, \"Duration (ms)\": 184280.0, \"Valence\": 0.498, \"Chord\": \"G\"}, {\"Index\": 1545, \"Highest Charting Position\": 72, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"GATTI\", \"Streams\": 7685470, \"Artist\": \"JACKBOYS, Pop Smoke, Travis Scott\", \"Artist Followers\": 437907.0, \"Song ID\": \"40mjsnRjCpycdUw3xhS20g\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 77.0, \"Danceability\": 0.594, \"Energy\": 0.676, \"Loudness\": -5.808, \"Speechiness\": 0.344, \"Acousticness\": 0.135, \"Liveness\": 0.163, \"Tempo\": 143.477, \"Duration (ms)\": 181145.0, \"Valence\": 0.472, \"Chord\": \"D\"}, {\"Index\": 1546, \"Highest Charting Position\": 128, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Candy\", \"Streams\": 5632102, \"Artist\": \"Doja Cat\", \"Artist Followers\": 8671649.0, \"Song ID\": \"1VJwtWR6z7SpZRwipI12be\", \"Genre\": \"['dance pop', 'pop']\", \"Release Date\": \"2018-03-30\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 71.0, \"Danceability\": 0.689, \"Energy\": 0.516, \"Loudness\": -5.857, \"Speechiness\": 0.0444, \"Acousticness\": 0.513, \"Liveness\": 0.163, \"Tempo\": 124.876, \"Duration (ms)\": 190920.0, \"Valence\": 0.209, \"Chord\": \"G#/Ab\"}, {\"Index\": 1547, \"Highest Charting Position\": 143, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"JACKBOYS\", \"Streams\": 5363493, \"Artist\": \"JACKBOYS\", \"Artist Followers\": 437907.0, \"Song ID\": \"62zKJrpbLxz6InR3tGyr7o\", \"Genre\": \"['rap', 'trap']\", \"Release Date\": \"2019-12-27\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 56.0, \"Danceability\": 0.413, \"Energy\": 0.13, \"Loudness\": -25.166, \"Speechiness\": 0.0336, \"Acousticness\": 0.9, \"Liveness\": 0.111, \"Tempo\": 123.342, \"Duration (ms)\": 46837.0, \"Valence\": 0.0676, \"Chord\": \"C\"}, {\"Index\": 1548, \"Highest Charting Position\": 156, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Combatchy (feat. MC Rebecca)\", \"Streams\": 5149797, \"Artist\": \"Anitta, Lexa, Lu\\u00edsa Sonza\", \"Artist Followers\": 10741972.0, \"Song ID\": \"2bPtwnrpFNEe8N7Q85kLHw\", \"Genre\": \"['funk carioca', 'funk pop', 'pagode baiano', 'pop nacional']\", \"Release Date\": \"2019-11-20\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 64.0, \"Danceability\": 0.826, \"Energy\": 0.73, \"Loudness\": -3.032, \"Speechiness\": 0.0809, \"Acousticness\": 0.383, \"Liveness\": 0.0197, \"Tempo\": 150.134, \"Duration (ms)\": 157600.0, \"Valence\": 0.605, \"Chord\": \"C#/Db\"}, {\"Index\": 1549, \"Highest Charting Position\": 178, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Old Town Road\", \"Streams\": 4852004, \"Artist\": \"Lil Nas X\", \"Artist Followers\": 5488666.0, \"Song ID\": \"2YpeDb67231RjR0MgVLzsG\", \"Genre\": \"['lgbtq+ hip hop', 'pop rap']\", \"Release Date\": \"2019-06-21\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.878, \"Energy\": 0.619, \"Loudness\": -5.56, \"Speechiness\": 0.102, \"Acousticness\": 0.0533, \"Liveness\": 0.113, \"Tempo\": 136.041, \"Duration (ms)\": 157067.0, \"Valence\": 0.639, \"Chord\": \"F#/Gb\"}, {\"Index\": 1550, \"Highest Charting Position\": 187, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Let Me Know (I Wonder Why Freestyle)\", \"Streams\": 4701532, \"Artist\": \"Juice WRLD\", \"Artist Followers\": 19102888.0, \"Song ID\": \"3wwo0bJvDSorOpNfzEkfXx\", \"Genre\": \"['chicago rap', 'melodic rap']\", \"Release Date\": \"2019-12-07\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 76.0, \"Danceability\": 0.635, \"Energy\": 0.537, \"Loudness\": -7.895, \"Speechiness\": 0.0832, \"Acousticness\": 0.172, \"Liveness\": 0.418, \"Tempo\": 125.028, \"Duration (ms)\": 215381.0, \"Valence\": 0.383, \"Chord\": \"G\"}, {\"Index\": 1551, \"Highest Charting Position\": 190, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Ne reviens pas\", \"Streams\": 4676857, \"Artist\": \"Gradur, Heuss L'enfoir\\u00e9\", \"Artist Followers\": 1390813.0, \"Song ID\": \"4TnFANpjVwVKWzkxNzIyFH\", \"Genre\": \"['francoton', 'french hip hop', 'pop urbaine', 'rap francais']\", \"Release Date\": \"2019-11-29\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 62.0, \"Danceability\": 0.932, \"Energy\": 0.778, \"Loudness\": -3.384, \"Speechiness\": 0.0638, \"Acousticness\": 0.212, \"Liveness\": 0.168, \"Tempo\": 124.996, \"Duration (ms)\": 188613.0, \"Valence\": 0.933, \"Chord\": \"A#/Bb\"}, {\"Index\": 1552, \"Highest Charting Position\": 195, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"New Rules\", \"Streams\": 4630675, \"Artist\": \"Dua Lipa\", \"Artist Followers\": 27167675.0, \"Song ID\": \"2ekn2ttSfGqwhhate0LSR0\", \"Genre\": \"['dance pop', 'pop', 'uk pop']\", \"Release Date\": \"2017-06-02\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 79.0, \"Danceability\": 0.762, \"Energy\": 0.7, \"Loudness\": -6.021, \"Speechiness\": 0.0694, \"Acousticness\": 0.00261, \"Liveness\": 0.153, \"Tempo\": 116.073, \"Duration (ms)\": 209320.0, \"Valence\": 0.608, \"Chord\": \"A\"}, {\"Index\": 1553, \"Highest Charting Position\": 196, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Cheirosa - Ao Vivo\", \"Streams\": 4623030, \"Artist\": \"Jorge & Mateus\", \"Artist Followers\": 15019109.0, \"Song ID\": \"2PWjKmjyTZeDpmOUa3a5da\", \"Genre\": \"['sertanejo', 'sertanejo universitario']\", \"Release Date\": \"2019-10-11\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 66.0, \"Danceability\": 0.528, \"Energy\": 0.87, \"Loudness\": -3.123, \"Speechiness\": 0.0851, \"Acousticness\": 0.24, \"Liveness\": 0.333, \"Tempo\": 152.37, \"Duration (ms)\": 181930.0, \"Valence\": 0.714, \"Chord\": \"B\"}, {\"Index\": 1554, \"Highest Charting Position\": 197, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Havana (feat. Young Thug)\", \"Streams\": 4620876, \"Artist\": \"Camila Cabello\", \"Artist Followers\": 22698747.0, \"Song ID\": \"1rfofaqEpACxVEHIZBJe6W\", \"Genre\": \"['dance pop', 'electropop', 'pop', 'post-teen pop']\", \"Release Date\": \"2018-01-12\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 81.0, \"Danceability\": 0.765, \"Energy\": 0.523, \"Loudness\": -4.333, \"Speechiness\": 0.03, \"Acousticness\": 0.184, \"Liveness\": 0.132, \"Tempo\": 104.988, \"Duration (ms)\": 217307.0, \"Valence\": 0.394, \"Chord\": \"D\"}, {\"Index\": 1555, \"Highest Charting Position\": 198, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Surtada - Remix Brega Funk\", \"Streams\": 4607385, \"Artist\": \"Dad\\u00e1 Bolad\\u00e3o, Tati Zaqui, OIK\", \"Artist Followers\": 208630.0, \"Song ID\": \"5F8ffc8KWKNawllr5WsW0r\", \"Genre\": \"['brega funk', 'funk carioca']\", \"Release Date\": \"2019-09-25\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 60.0, \"Danceability\": 0.832, \"Energy\": 0.55, \"Loudness\": -7.026, \"Speechiness\": 0.0587, \"Acousticness\": 0.249, \"Liveness\": 0.182, \"Tempo\": 154.064, \"Duration (ms)\": 152784.0, \"Valence\": 0.881, \"Chord\": \"F\"}, {\"Index\": 1556, \"Highest Charting Position\": 199, \"Number of Times Charted\": 1, \"Week of Highest Charting\": \"2019-12-27--2020-01-03\", \"Song Name\": \"Lover (Remix) [feat. Shawn Mendes]\", \"Streams\": 4595450, \"Artist\": \"Taylor Swift\", \"Artist Followers\": 42227614.0, \"Song ID\": \"3i9UVldZOE0aD0JnyfAZZ0\", \"Genre\": \"['pop', 'post-teen pop']\", \"Release Date\": \"2019-11-13\", \"Weeks Charted\": \"2019-12-27--2020-01-03\", \"Popularity\": 70.0, \"Danceability\": 0.448, \"Energy\": 0.603, \"Loudness\": -7.176, \"Speechiness\": 0.064, \"Acousticness\": 0.433, \"Liveness\": 0.0862, \"Tempo\": 205.272, \"Duration (ms)\": 221307.0, \"Valence\": 0.422, \"Chord\": \"G\"}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 27,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "brush = alt.selection_interval(empty='none')\n",
    "\n",
    "chart = alt.Chart(df).mark_circle().encode(\n",
    "    x = \"Energy\",\n",
    "    y = \"Loudness\",\n",
    "    color = alt.condition(brush,\n",
    "                          alt.Color('Acousticness:Q', scale=alt.Scale(scheme='turbo',reverse=True)),\n",
    "                          alt.value(\"lightgrey\")),\n",
    ").add_selection(\n",
    "    brush,\n",
    ").properties(\n",
    "    width = 720,\n",
    "    height = 450,\n",
    "    title=\"Spotify dataset from Kaggle\"\n",
    ")\n",
    "\n",
    "chart"
   ]
  }
 ],
 "metadata": {
  "jupytext": {
   "text_representation": {
    "extension": ".md",
    "format_name": "myst",
    "format_version": 0.13,
    "jupytext_version": "1.10.3"
   }
  },
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.8.12"
  },
  "source_map": [
   12,
   17,
   22,
   27,
   32,
   34,
   42,
   47,
   51,
   56,
   60,
   62,
   66,
   68,
   72,
   80,
   92,
   94,
   98,
   103,
   112,
   119,
   123,
   128,
   137,
   146,
   154,
   156,
   160,
   162,
   166,
   168,
   172,
   176,
   183,
   187,
   194,
   198,
   205,
   212,
   223,
   230,
   235,
   241,
   247,
   250,
   254,
   259,
   264,
   268,
   273,
   279,
   286,
   292
  ]
 },
 "nbformat": 4,
 "nbformat_minor": 5
}